#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 20506
#define LARGE_STATE_COUNT 2924
#define SYMBOL_COUNT 421
#define ALIAS_COUNT 12
#define TOKEN_COUNT 144
#define EXTERNAL_TOKEN_COUNT 6
#define FIELD_COUNT 15
#define MAX_ALIAS_SEQUENCE_LENGTH 11
#define PRODUCTION_ID_COUNT 137

enum ts_symbol_identifiers {
  sym__lowercase_identifier = 1,
  sym_shebang = 2,
  anon_sym_SEMI_SEMI = 3,
  anon_sym_let = 4,
  anon_sym_rec = 5,
  anon_sym_and = 6,
  anon_sym_COLON_GT = 7,
  anon_sym_EQ = 8,
  anon_sym_TILDE = 9,
  anon_sym_QMARK = 10,
  anon_sym_COLON = 11,
  anon_sym_LPAREN = 12,
  anon_sym_RPAREN = 13,
  anon_sym_external = 14,
  anon_sym_type = 15,
  anon_sym_nonrec = 16,
  anon_sym_private = 17,
  anon_sym_DOT_DOT = 18,
  anon_sym_PLUS_EQ = 19,
  anon_sym_COMMA = 20,
  anon_sym_PLUS = 21,
  anon_sym_BANG = 22,
  anon_sym_DASH = 23,
  anon_sym__ = 24,
  anon_sym_COLON_EQ = 25,
  anon_sym_PIPE = 26,
  anon_sym_LBRACK = 27,
  anon_sym_RBRACK = 28,
  anon_sym_true = 29,
  anon_sym_false = 30,
  anon_sym_of = 31,
  anon_sym_COLON2 = 32,
  anon_sym_DOT = 33,
  anon_sym_DASH_GT = 34,
  anon_sym_STAR = 35,
  anon_sym_LBRACE = 36,
  anon_sym_SEMI = 37,
  anon_sym_RBRACE = 38,
  anon_sym_mutable = 39,
  anon_sym_constraint = 40,
  anon_sym_exception = 41,
  anon_sym_module = 42,
  anon_sym_open = 43,
  anon_sym_include = 44,
  anon_sym_class = 45,
  anon_sym_virtual = 46,
  anon_sym_val = 47,
  anon_sym_sig = 48,
  anon_sym_end = 49,
  anon_sym_with = 50,
  anon_sym_functor = 51,
  anon_sym_struct = 52,
  anon_sym_object = 53,
  anon_sym_inherit = 54,
  anon_sym_method = 55,
  anon_sym_in = 56,
  anon_sym_fun = 57,
  anon_sym_as = 58,
  anon_sym_initializer = 59,
  anon_sym_LBRACK_GT = 60,
  anon_sym_LBRACK_LT = 61,
  anon_sym_GT = 62,
  anon_sym_AMP = 63,
  anon_sym_LT = 64,
  anon_sym_POUND = 65,
  anon_sym_COLON_COLON = 66,
  anon_sym_LBRACK_PIPE = 67,
  anon_sym_PIPE_RBRACK = 68,
  anon_sym_LT_DASH = 69,
  anon_sym_if = 70,
  anon_sym_then = 71,
  anon_sym_else = 72,
  anon_sym_while = 73,
  anon_sym_do = 74,
  anon_sym_done = 75,
  anon_sym_for = 76,
  anon_sym_to = 77,
  anon_sym_downto = 78,
  anon_sym_match = 79,
  anon_sym_when = 80,
  anon_sym_function = 81,
  anon_sym_try = 82,
  anon_sym_assert = 83,
  anon_sym_lazy = 84,
  anon_sym_new = 85,
  anon_sym_LBRACE_LT = 86,
  anon_sym_GT_RBRACE = 87,
  anon_sym_begin = 88,
  sym_ocamlyacc_value = 89,
  anon_sym_effect = 90,
  aux_sym_attribute_token1 = 91,
  anon_sym_LBRACK_AT_AT = 92,
  anon_sym_LBRACK_AT_AT_AT = 93,
  anon_sym_LBRACK_PERCENT = 94,
  anon_sym_LBRACE_PERCENT = 95,
  aux_sym_quoted_extension_token1 = 96,
  anon_sym_LBRACK_PERCENT_PERCENT = 97,
  anon_sym_LBRACE_PERCENT_PERCENT = 98,
  anon_sym_PERCENT = 99,
  aux_sym_number_token1 = 100,
  aux_sym_signed_number_token1 = 101,
  anon_sym_SQUOTE = 102,
  anon_sym_SQUOTE2 = 103,
  aux_sym_character_content_token1 = 104,
  aux_sym_character_content_token2 = 105,
  anon_sym_DQUOTE = 106,
  aux_sym_string_content_token1 = 107,
  aux_sym_string_content_token2 = 108,
  aux_sym_string_content_token3 = 109,
  aux_sym_string_content_token4 = 110,
  aux_sym_string_content_token5 = 111,
  aux_sym_quoted_string_content_token1 = 112,
  aux_sym_escape_sequence_token1 = 113,
  aux_sym_escape_sequence_token2 = 114,
  aux_sym_escape_sequence_token3 = 115,
  aux_sym_escape_sequence_token4 = 116,
  sym_conversion_specification = 117,
  sym_pretty_printing_indication = 118,
  sym_prefix_operator = 119,
  aux_sym_sign_operator_token1 = 120,
  sym_hash_operator = 121,
  sym_pow_operator = 122,
  sym_mult_operator = 123,
  aux_sym_add_operator_token1 = 124,
  sym_concat_operator = 125,
  sym_rel_operator = 126,
  sym_and_operator = 127,
  sym_or_operator = 128,
  sym_assign_operator = 129,
  sym_indexing_operator = 130,
  sym_let_operator = 131,
  sym_let_and_operator = 132,
  sym_match_operator = 133,
  sym__uppercase_identifier = 134,
  aux_sym_directive_token1 = 135,
  aux_sym_type_variable_token1 = 136,
  aux_sym_tag_token1 = 137,
  aux_sym_attribute_id_token1 = 138,
  sym_comment = 139,
  sym__left_quoted_string_delimiter = 140,
  sym__right_quoted_string_delimiter = 141,
  sym_line_number_directive = 142,
  sym__null = 143,
  sym_compilation_unit = 144,
  sym__structure = 145,
  sym_expression_item = 146,
  sym__signature = 147,
  sym_toplevel_directive = 148,
  sym__structure_item = 149,
  sym_value_definition = 150,
  sym_let_binding = 151,
  sym_parameter = 152,
  sym_external = 153,
  sym_type_definition = 154,
  sym_type_binding = 155,
  sym__type_params = 156,
  sym__type_param = 157,
  sym__type_equation = 158,
  sym_variant_declaration = 159,
  sym_constructor_declaration = 160,
  sym__constructor_argument = 161,
  sym_record_declaration = 162,
  sym_field_declaration = 163,
  sym_type_constraint = 164,
  sym_exception_definition = 165,
  sym_module_definition = 166,
  sym_module_binding = 167,
  sym_module_parameter = 168,
  sym_module_type_definition = 169,
  sym_open_module = 170,
  sym_include_module = 171,
  sym_class_definition = 172,
  sym_class_binding = 173,
  sym_class_type_definition = 174,
  sym_class_type_binding = 175,
  sym__signature_item = 176,
  sym_value_specification = 177,
  sym_include_module_type = 178,
  sym__module_typed = 179,
  sym__module_type = 180,
  sym_signature = 181,
  sym_module_type_constraint = 182,
  sym_constrain_type = 183,
  sym_constrain_module = 184,
  sym_constrain_module_type = 185,
  sym_module_type_of = 186,
  sym_functor_type = 187,
  sym_parenthesized_module_type = 188,
  sym__simple_module_expression = 189,
  sym__module_expression = 190,
  sym_structure = 191,
  sym_functor = 192,
  sym_module_application = 193,
  sym_typed_module_expression = 194,
  sym_packed_module = 195,
  sym_parenthesized_module_expression = 196,
  sym__class_typed = 197,
  sym__simple_class_type = 198,
  sym__class_type = 199,
  sym_instantiated_class_type = 200,
  sym_class_body_type = 201,
  sym__class_field_specification = 202,
  sym_inheritance_specification = 203,
  sym_instance_variable_specification = 204,
  sym_method_specification = 205,
  sym_type_parameter_constraint = 206,
  sym_let_open_class_type = 207,
  sym_class_function_type = 208,
  sym__simple_class_expression = 209,
  sym__class_expression = 210,
  sym_instantiated_class = 211,
  sym_typed_class_expression = 212,
  sym_class_function = 213,
  sym_class_application = 214,
  sym_let_class_expression = 215,
  sym__class_field = 216,
  sym_inheritance_definition = 217,
  sym_instance_variable_definition = 218,
  sym_method_definition = 219,
  sym_class_initializer = 220,
  sym_let_open_class_expression = 221,
  sym_parenthesized_class_expression = 222,
  sym__typed = 223,
  sym__simple_typed = 224,
  sym__polymorphic_typed = 225,
  sym__polymorphic_type = 226,
  sym_polymorphic_type = 227,
  sym__abstract_type = 228,
  sym__parenthesized_abstract_type = 229,
  sym__simple_type = 230,
  sym__tuple_type = 231,
  sym__type = 232,
  sym_function_type = 233,
  sym_typed_label = 234,
  sym_tuple_type = 235,
  sym_constructed_type = 236,
  sym_aliased_type = 237,
  sym_local_open_type = 238,
  sym_polymorphic_variant_type = 239,
  sym__tag_spec = 240,
  sym_tag_specification = 241,
  sym_package_type = 242,
  sym_object_type = 243,
  sym_method_type = 244,
  sym_hash_type = 245,
  sym_parenthesized_type = 246,
  sym__simple_expression = 247,
  sym__expression = 248,
  sym__sequence_expression = 249,
  sym_typed_expression = 250,
  sym_product_expression = 251,
  sym_cons_expression = 252,
  sym_list_expression = 253,
  sym_array_expression = 254,
  sym_record_expression = 255,
  sym_field_expression = 256,
  sym_application_expression = 257,
  sym_labeled_argument = 258,
  sym_prefix_expression = 259,
  sym_sign_expression = 260,
  sym_hash_expression = 261,
  sym_infix_expression = 262,
  sym_field_get_expression = 263,
  sym_array_get_expression = 264,
  sym_string_get_expression = 265,
  sym_bigarray_get_expression = 266,
  sym_set_expression = 267,
  sym_if_expression = 268,
  sym_then_clause = 269,
  sym_else_clause = 270,
  sym_while_expression = 271,
  sym_do_clause = 272,
  sym_for_expression = 273,
  sym_sequence_expression = 274,
  sym_match_expression = 275,
  sym__match_cases = 276,
  sym_match_case = 277,
  sym_guard = 278,
  sym_refutation_case = 279,
  sym_function_expression = 280,
  sym_fun_expression = 281,
  sym_try_expression = 282,
  sym_let_expression = 283,
  sym_coercion_expression = 284,
  sym_assert_expression = 285,
  sym_lazy_expression = 286,
  sym_let_module_expression = 287,
  sym_let_open_expression = 288,
  sym_local_open_expression = 289,
  sym_package_expression = 290,
  sym_let_exception_expression = 291,
  sym_new_expression = 292,
  sym_object_copy_expression = 293,
  sym_instance_variable_expression = 294,
  sym_method_invocation = 295,
  sym_object_expression = 296,
  sym_parenthesized_expression = 297,
  sym__simple_pattern = 298,
  sym__effect_pattern = 299,
  sym__pattern = 300,
  sym__binding_pattern = 301,
  sym_alias_pattern = 302,
  sym_alias_binding_pattern = 303,
  sym_typed_pattern = 304,
  sym_typed_binding_pattern = 305,
  sym_or_pattern = 306,
  sym_or_binding_pattern = 307,
  sym_constructor_pattern = 308,
  sym_constructor_binding_pattern = 309,
  sym_tag_pattern = 310,
  sym_tag_binding_pattern = 311,
  sym_polymorphic_variant_pattern = 312,
  sym_tuple_pattern = 313,
  sym_tuple_binding_pattern = 314,
  sym_record_pattern = 315,
  sym_field_pattern = 316,
  sym_record_binding_pattern = 317,
  sym_field_binding_pattern = 318,
  sym_list_pattern = 319,
  sym_list_binding_pattern = 320,
  sym_cons_pattern = 321,
  sym_cons_binding_pattern = 322,
  sym_array_pattern = 323,
  sym_array_binding_pattern = 324,
  sym_range_pattern = 325,
  sym_lazy_pattern = 326,
  sym_lazy_binding_pattern = 327,
  sym_local_open_pattern = 328,
  sym_local_open_binding_pattern = 329,
  sym_package_pattern = 330,
  sym_parenthesized_pattern = 331,
  sym_parenthesized_binding_pattern = 332,
  sym_exception_pattern = 333,
  sym_effect_pattern = 334,
  sym_attribute = 335,
  sym_item_attribute = 336,
  sym_floating_attribute = 337,
  sym_attribute_payload = 338,
  sym_extension = 339,
  sym_quoted_extension = 340,
  sym_item_extension = 341,
  sym_quoted_item_extension = 342,
  sym__attribute = 343,
  sym__constant = 344,
  sym__signed_constant = 345,
  sym_number = 346,
  sym_signed_number = 347,
  sym_character = 348,
  sym_character_content = 349,
  sym_string = 350,
  sym_string_content = 351,
  sym_quoted_string = 352,
  sym__quoted_string = 353,
  sym_quoted_string_content = 354,
  sym_escape_sequence = 355,
  sym_boolean = 356,
  sym_unit = 357,
  sym_sign_operator = 358,
  sym__infix_operator = 359,
  sym_add_operator = 360,
  sym_indexing_operator_path = 361,
  sym__value_name = 362,
  sym__simple_value_pattern = 363,
  sym_parenthesized_operator = 364,
  sym_value_path = 365,
  sym_module_path = 366,
  sym_extended_module_path = 367,
  sym_module_type_path = 368,
  sym_field_path = 369,
  sym_constructor_path = 370,
  sym_type_constructor_path = 371,
  sym_class_path = 372,
  sym_class_type_path = 373,
  sym__instance_variable_name = 374,
  sym__constructor_name = 375,
  sym_directive = 376,
  sym_type_variable = 377,
  sym_tag = 378,
  sym_attribute_id = 379,
  aux_sym__structure_repeat1 = 380,
  aux_sym__structure_repeat2 = 381,
  aux_sym_expression_item_repeat1 = 382,
  aux_sym__signature_repeat1 = 383,
  aux_sym_value_definition_repeat1 = 384,
  aux_sym_let_binding_repeat1 = 385,
  aux_sym_external_repeat1 = 386,
  aux_sym_type_definition_repeat1 = 387,
  aux_sym_type_binding_repeat1 = 388,
  aux_sym__type_params_repeat1 = 389,
  aux_sym_variant_declaration_repeat1 = 390,
  aux_sym_constructor_declaration_repeat1 = 391,
  aux_sym__constructor_argument_repeat1 = 392,
  aux_sym_record_declaration_repeat1 = 393,
  aux_sym_module_definition_repeat1 = 394,
  aux_sym_module_binding_repeat1 = 395,
  aux_sym_class_definition_repeat1 = 396,
  aux_sym_class_type_definition_repeat1 = 397,
  aux_sym_module_type_constraint_repeat1 = 398,
  aux_sym_instantiated_class_type_repeat1 = 399,
  aux_sym_class_body_type_repeat1 = 400,
  aux_sym_instance_variable_specification_repeat1 = 401,
  aux_sym_method_specification_repeat1 = 402,
  aux_sym_class_application_repeat1 = 403,
  aux_sym__abstract_type_repeat1 = 404,
  aux_sym_polymorphic_variant_type_repeat1 = 405,
  aux_sym_polymorphic_variant_type_repeat2 = 406,
  aux_sym_tag_specification_repeat1 = 407,
  aux_sym_object_type_repeat1 = 408,
  aux_sym_list_expression_repeat1 = 409,
  aux_sym_record_expression_repeat1 = 410,
  aux_sym__match_cases_repeat1 = 411,
  aux_sym_object_copy_expression_repeat1 = 412,
  aux_sym_object_expression_repeat1 = 413,
  aux_sym_record_pattern_repeat1 = 414,
  aux_sym_record_binding_pattern_repeat1 = 415,
  aux_sym_list_pattern_repeat1 = 416,
  aux_sym_list_binding_pattern_repeat1 = 417,
  aux_sym_string_content_repeat1 = 418,
  aux_sym_quoted_string_content_repeat1 = 419,
  aux_sym_attribute_id_repeat1 = 420,
  alias_sym_class_name = 421,
  alias_sym_class_type_name = 422,
  alias_sym_constructor_name = 423,
  alias_sym_field_name = 424,
  alias_sym_instance_variable_name = 425,
  alias_sym_label_name = 426,
  alias_sym_method_name = 427,
  alias_sym_module_name = 428,
  alias_sym_module_type_name = 429,
  alias_sym_type_constructor = 430,
  alias_sym_value_name = 431,
  alias_sym_value_pattern = 432,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym__lowercase_identifier] = "_lowercase_identifier",
  [sym_shebang] = "shebang",
  [anon_sym_SEMI_SEMI] = ";;",
  [anon_sym_let] = "let",
  [anon_sym_rec] = "rec",
  [anon_sym_and] = "and",
  [anon_sym_COLON_GT] = ":>",
  [anon_sym_EQ] = "=",
  [anon_sym_TILDE] = "~",
  [anon_sym_QMARK] = "\?",
  [anon_sym_COLON] = ":",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_external] = "external",
  [anon_sym_type] = "type",
  [anon_sym_nonrec] = "nonrec",
  [anon_sym_private] = "private",
  [anon_sym_DOT_DOT] = "..",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_COMMA] = ",",
  [anon_sym_PLUS] = "+",
  [anon_sym_BANG] = "!",
  [anon_sym_DASH] = "-",
  [anon_sym__] = "_",
  [anon_sym_COLON_EQ] = ":=",
  [anon_sym_PIPE] = "|",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_true] = "true",
  [anon_sym_false] = "false",
  [anon_sym_of] = "of",
  [anon_sym_COLON2] = ":",
  [anon_sym_DOT] = ".",
  [anon_sym_DASH_GT] = "->",
  [anon_sym_STAR] = "*",
  [anon_sym_LBRACE] = "{",
  [anon_sym_SEMI] = ";",
  [anon_sym_RBRACE] = "}",
  [anon_sym_mutable] = "mutable",
  [anon_sym_constraint] = "constraint",
  [anon_sym_exception] = "exception",
  [anon_sym_module] = "module",
  [anon_sym_open] = "open",
  [anon_sym_include] = "include",
  [anon_sym_class] = "class",
  [anon_sym_virtual] = "virtual",
  [anon_sym_val] = "val",
  [anon_sym_sig] = "sig",
  [anon_sym_end] = "end",
  [anon_sym_with] = "with",
  [anon_sym_functor] = "functor",
  [anon_sym_struct] = "struct",
  [anon_sym_object] = "object",
  [anon_sym_inherit] = "inherit",
  [anon_sym_method] = "method",
  [anon_sym_in] = "in",
  [anon_sym_fun] = "fun",
  [anon_sym_as] = "as",
  [anon_sym_initializer] = "initializer",
  [anon_sym_LBRACK_GT] = "[>",
  [anon_sym_LBRACK_LT] = "[<",
  [anon_sym_GT] = ">",
  [anon_sym_AMP] = "&",
  [anon_sym_LT] = "<",
  [anon_sym_POUND] = "#",
  [anon_sym_COLON_COLON] = "::",
  [anon_sym_LBRACK_PIPE] = "[|",
  [anon_sym_PIPE_RBRACK] = "|]",
  [anon_sym_LT_DASH] = "<-",
  [anon_sym_if] = "if",
  [anon_sym_then] = "then",
  [anon_sym_else] = "else",
  [anon_sym_while] = "while",
  [anon_sym_do] = "do",
  [anon_sym_done] = "done",
  [anon_sym_for] = "for",
  [anon_sym_to] = "to",
  [anon_sym_downto] = "downto",
  [anon_sym_match] = "match",
  [anon_sym_when] = "when",
  [anon_sym_function] = "function",
  [anon_sym_try] = "try",
  [anon_sym_assert] = "assert",
  [anon_sym_lazy] = "lazy",
  [anon_sym_new] = "new",
  [anon_sym_LBRACE_LT] = "{<",
  [anon_sym_GT_RBRACE] = ">}",
  [anon_sym_begin] = "begin",
  [sym_ocamlyacc_value] = "ocamlyacc_value",
  [anon_sym_effect] = "effect",
  [aux_sym_attribute_token1] = "[@",
  [anon_sym_LBRACK_AT_AT] = "[@@",
  [anon_sym_LBRACK_AT_AT_AT] = "[@@@",
  [anon_sym_LBRACK_PERCENT] = "[%",
  [anon_sym_LBRACE_PERCENT] = "{%",
  [aux_sym_quoted_extension_token1] = "quoted_extension_token1",
  [anon_sym_LBRACK_PERCENT_PERCENT] = "[%%",
  [anon_sym_LBRACE_PERCENT_PERCENT] = "{%%",
  [anon_sym_PERCENT] = "%",
  [aux_sym_number_token1] = "number_token1",
  [aux_sym_signed_number_token1] = "signed_number_token1",
  [anon_sym_SQUOTE] = "'",
  [anon_sym_SQUOTE2] = "'",
  [aux_sym_character_content_token1] = "character_content_token1",
  [aux_sym_character_content_token2] = "character_content_token2",
  [anon_sym_DQUOTE] = "\"",
  [aux_sym_string_content_token1] = "string_content_token1",
  [aux_sym_string_content_token2] = "string_content_token2",
  [aux_sym_string_content_token3] = "string_content_token3",
  [aux_sym_string_content_token4] = "escape_sequence",
  [aux_sym_string_content_token5] = "escape_sequence",
  [aux_sym_quoted_string_content_token1] = "quoted_string_content_token1",
  [aux_sym_escape_sequence_token1] = "escape_sequence_token1",
  [aux_sym_escape_sequence_token2] = "escape_sequence_token2",
  [aux_sym_escape_sequence_token3] = "escape_sequence_token3",
  [aux_sym_escape_sequence_token4] = "escape_sequence_token4",
  [sym_conversion_specification] = "conversion_specification",
  [sym_pretty_printing_indication] = "pretty_printing_indication",
  [sym_prefix_operator] = "prefix_operator",
  [aux_sym_sign_operator_token1] = "sign_operator_token1",
  [sym_hash_operator] = "hash_operator",
  [sym_pow_operator] = "pow_operator",
  [sym_mult_operator] = "mult_operator",
  [aux_sym_add_operator_token1] = "add_operator_token1",
  [sym_concat_operator] = "concat_operator",
  [sym_rel_operator] = "rel_operator",
  [sym_and_operator] = "and_operator",
  [sym_or_operator] = "or_operator",
  [sym_assign_operator] = "assign_operator",
  [sym_indexing_operator] = "indexing_operator",
  [sym_let_operator] = "let_operator",
  [sym_let_and_operator] = "let_and_operator",
  [sym_match_operator] = "match_operator",
  [sym__uppercase_identifier] = "_uppercase_identifier",
  [aux_sym_directive_token1] = "directive_token1",
  [aux_sym_type_variable_token1] = "type_variable_token1",
  [aux_sym_tag_token1] = "tag_token1",
  [aux_sym_attribute_id_token1] = "attribute_id_token1",
  [sym_comment] = "comment",
  [sym__left_quoted_string_delimiter] = "_left_quoted_string_delimiter",
  [sym__right_quoted_string_delimiter] = "_right_quoted_string_delimiter",
  [sym_line_number_directive] = "line_number_directive",
  [sym__null] = "_null",
  [sym_compilation_unit] = "compilation_unit",
  [sym__structure] = "_structure",
  [sym_expression_item] = "expression_item",
  [sym__signature] = "_signature",
  [sym_toplevel_directive] = "toplevel_directive",
  [sym__structure_item] = "_structure_item",
  [sym_value_definition] = "value_definition",
  [sym_let_binding] = "let_binding",
  [sym_parameter] = "parameter",
  [sym_external] = "external",
  [sym_type_definition] = "type_definition",
  [sym_type_binding] = "type_binding",
  [sym__type_params] = "_type_params",
  [sym__type_param] = "_type_param",
  [sym__type_equation] = "_type_equation",
  [sym_variant_declaration] = "variant_declaration",
  [sym_constructor_declaration] = "constructor_declaration",
  [sym__constructor_argument] = "_constructor_argument",
  [sym_record_declaration] = "record_declaration",
  [sym_field_declaration] = "field_declaration",
  [sym_type_constraint] = "type_constraint",
  [sym_exception_definition] = "exception_definition",
  [sym_module_definition] = "module_definition",
  [sym_module_binding] = "module_binding",
  [sym_module_parameter] = "module_parameter",
  [sym_module_type_definition] = "module_type_definition",
  [sym_open_module] = "open_module",
  [sym_include_module] = "include_module",
  [sym_class_definition] = "class_definition",
  [sym_class_binding] = "class_binding",
  [sym_class_type_definition] = "class_type_definition",
  [sym_class_type_binding] = "class_type_binding",
  [sym__signature_item] = "_signature_item",
  [sym_value_specification] = "value_specification",
  [sym_include_module_type] = "include_module_type",
  [sym__module_typed] = "_module_typed",
  [sym__module_type] = "_module_type",
  [sym_signature] = "signature",
  [sym_module_type_constraint] = "module_type_constraint",
  [sym_constrain_type] = "constrain_type",
  [sym_constrain_module] = "constrain_module",
  [sym_constrain_module_type] = "constrain_module_type",
  [sym_module_type_of] = "module_type_of",
  [sym_functor_type] = "functor_type",
  [sym_parenthesized_module_type] = "parenthesized_module_type",
  [sym__simple_module_expression] = "_simple_module_expression",
  [sym__module_expression] = "_module_expression",
  [sym_structure] = "structure",
  [sym_functor] = "functor",
  [sym_module_application] = "module_application",
  [sym_typed_module_expression] = "typed_module_expression",
  [sym_packed_module] = "packed_module",
  [sym_parenthesized_module_expression] = "parenthesized_module_expression",
  [sym__class_typed] = "_class_typed",
  [sym__simple_class_type] = "_simple_class_type",
  [sym__class_type] = "_class_type",
  [sym_instantiated_class_type] = "instantiated_class_type",
  [sym_class_body_type] = "class_body_type",
  [sym__class_field_specification] = "_class_field_specification",
  [sym_inheritance_specification] = "inheritance_specification",
  [sym_instance_variable_specification] = "instance_variable_specification",
  [sym_method_specification] = "method_specification",
  [sym_type_parameter_constraint] = "type_parameter_constraint",
  [sym_let_open_class_type] = "let_open_class_type",
  [sym_class_function_type] = "class_function_type",
  [sym__simple_class_expression] = "_simple_class_expression",
  [sym__class_expression] = "_class_expression",
  [sym_instantiated_class] = "instantiated_class",
  [sym_typed_class_expression] = "typed_class_expression",
  [sym_class_function] = "class_function",
  [sym_class_application] = "class_application",
  [sym_let_class_expression] = "let_class_expression",
  [sym__class_field] = "_class_field",
  [sym_inheritance_definition] = "inheritance_definition",
  [sym_instance_variable_definition] = "instance_variable_definition",
  [sym_method_definition] = "method_definition",
  [sym_class_initializer] = "class_initializer",
  [sym_let_open_class_expression] = "let_open_class_expression",
  [sym_parenthesized_class_expression] = "parenthesized_class_expression",
  [sym__typed] = "_typed",
  [sym__simple_typed] = "_simple_typed",
  [sym__polymorphic_typed] = "_polymorphic_typed",
  [sym__polymorphic_type] = "_polymorphic_type",
  [sym_polymorphic_type] = "polymorphic_type",
  [sym__abstract_type] = "_abstract_type",
  [sym__parenthesized_abstract_type] = "abstract_type",
  [sym__simple_type] = "_simple_type",
  [sym__tuple_type] = "_tuple_type",
  [sym__type] = "_type",
  [sym_function_type] = "function_type",
  [sym_typed_label] = "typed_label",
  [sym_tuple_type] = "tuple_type",
  [sym_constructed_type] = "constructed_type",
  [sym_aliased_type] = "aliased_type",
  [sym_local_open_type] = "local_open_type",
  [sym_polymorphic_variant_type] = "polymorphic_variant_type",
  [sym__tag_spec] = "_tag_spec",
  [sym_tag_specification] = "tag_specification",
  [sym_package_type] = "package_type",
  [sym_object_type] = "object_type",
  [sym_method_type] = "method_type",
  [sym_hash_type] = "hash_type",
  [sym_parenthesized_type] = "parenthesized_type",
  [sym__simple_expression] = "_simple_expression",
  [sym__expression] = "_expression",
  [sym__sequence_expression] = "_sequence_expression",
  [sym_typed_expression] = "typed_expression",
  [sym_product_expression] = "product_expression",
  [sym_cons_expression] = "cons_expression",
  [sym_list_expression] = "list_expression",
  [sym_array_expression] = "array_expression",
  [sym_record_expression] = "record_expression",
  [sym_field_expression] = "field_expression",
  [sym_application_expression] = "application_expression",
  [sym_labeled_argument] = "labeled_argument",
  [sym_prefix_expression] = "prefix_expression",
  [sym_sign_expression] = "sign_expression",
  [sym_hash_expression] = "hash_expression",
  [sym_infix_expression] = "infix_expression",
  [sym_field_get_expression] = "field_get_expression",
  [sym_array_get_expression] = "array_get_expression",
  [sym_string_get_expression] = "string_get_expression",
  [sym_bigarray_get_expression] = "bigarray_get_expression",
  [sym_set_expression] = "set_expression",
  [sym_if_expression] = "if_expression",
  [sym_then_clause] = "then_clause",
  [sym_else_clause] = "else_clause",
  [sym_while_expression] = "while_expression",
  [sym_do_clause] = "do_clause",
  [sym_for_expression] = "for_expression",
  [sym_sequence_expression] = "sequence_expression",
  [sym_match_expression] = "match_expression",
  [sym__match_cases] = "_match_cases",
  [sym_match_case] = "match_case",
  [sym_guard] = "guard",
  [sym_refutation_case] = "refutation_case",
  [sym_function_expression] = "function_expression",
  [sym_fun_expression] = "fun_expression",
  [sym_try_expression] = "try_expression",
  [sym_let_expression] = "let_expression",
  [sym_coercion_expression] = "coercion_expression",
  [sym_assert_expression] = "assert_expression",
  [sym_lazy_expression] = "lazy_expression",
  [sym_let_module_expression] = "let_module_expression",
  [sym_let_open_expression] = "let_open_expression",
  [sym_local_open_expression] = "local_open_expression",
  [sym_package_expression] = "package_expression",
  [sym_let_exception_expression] = "let_exception_expression",
  [sym_new_expression] = "new_expression",
  [sym_object_copy_expression] = "object_copy_expression",
  [sym_instance_variable_expression] = "instance_variable_expression",
  [sym_method_invocation] = "method_invocation",
  [sym_object_expression] = "object_expression",
  [sym_parenthesized_expression] = "parenthesized_expression",
  [sym__simple_pattern] = "_simple_pattern",
  [sym__effect_pattern] = "_effect_pattern",
  [sym__pattern] = "_pattern",
  [sym__binding_pattern] = "_binding_pattern",
  [sym_alias_pattern] = "alias_pattern",
  [sym_alias_binding_pattern] = "alias_pattern",
  [sym_typed_pattern] = "typed_pattern",
  [sym_typed_binding_pattern] = "typed_pattern",
  [sym_or_pattern] = "or_pattern",
  [sym_or_binding_pattern] = "or_pattern",
  [sym_constructor_pattern] = "constructor_pattern",
  [sym_constructor_binding_pattern] = "constructor_pattern",
  [sym_tag_pattern] = "tag_pattern",
  [sym_tag_binding_pattern] = "tag_pattern",
  [sym_polymorphic_variant_pattern] = "polymorphic_variant_pattern",
  [sym_tuple_pattern] = "tuple_pattern",
  [sym_tuple_binding_pattern] = "tuple_pattern",
  [sym_record_pattern] = "record_pattern",
  [sym_field_pattern] = "field_pattern",
  [sym_record_binding_pattern] = "record_binding_pattern",
  [sym_field_binding_pattern] = "field_pattern",
  [sym_list_pattern] = "list_pattern",
  [sym_list_binding_pattern] = "list_binding_pattern",
  [sym_cons_pattern] = "cons_pattern",
  [sym_cons_binding_pattern] = "cons_pattern",
  [sym_array_pattern] = "array_pattern",
  [sym_array_binding_pattern] = "array_binding_pattern",
  [sym_range_pattern] = "range_pattern",
  [sym_lazy_pattern] = "lazy_pattern",
  [sym_lazy_binding_pattern] = "lazy_pattern",
  [sym_local_open_pattern] = "local_open_pattern",
  [sym_local_open_binding_pattern] = "local_open_pattern",
  [sym_package_pattern] = "package_pattern",
  [sym_parenthesized_pattern] = "parenthesized_pattern",
  [sym_parenthesized_binding_pattern] = "parenthesized_pattern",
  [sym_exception_pattern] = "exception_pattern",
  [sym_effect_pattern] = "effect_pattern",
  [sym_attribute] = "attribute",
  [sym_item_attribute] = "item_attribute",
  [sym_floating_attribute] = "floating_attribute",
  [sym_attribute_payload] = "attribute_payload",
  [sym_extension] = "extension",
  [sym_quoted_extension] = "quoted_extension",
  [sym_item_extension] = "item_extension",
  [sym_quoted_item_extension] = "quoted_item_extension",
  [sym__attribute] = "_attribute",
  [sym__constant] = "_constant",
  [sym__signed_constant] = "_signed_constant",
  [sym_number] = "number",
  [sym_signed_number] = "signed_number",
  [sym_character] = "character",
  [sym_character_content] = "character_content",
  [sym_string] = "string",
  [sym_string_content] = "string_content",
  [sym_quoted_string] = "quoted_string",
  [sym__quoted_string] = "_quoted_string",
  [sym_quoted_string_content] = "quoted_string_content",
  [sym_escape_sequence] = "escape_sequence",
  [sym_boolean] = "boolean",
  [sym_unit] = "unit",
  [sym_sign_operator] = "sign_operator",
  [sym__infix_operator] = "_infix_operator",
  [sym_add_operator] = "add_operator",
  [sym_indexing_operator_path] = "indexing_operator_path",
  [sym__value_name] = "_value_name",
  [sym__simple_value_pattern] = "_simple_value_pattern",
  [sym_parenthesized_operator] = "parenthesized_operator",
  [sym_value_path] = "value_path",
  [sym_module_path] = "module_path",
  [sym_extended_module_path] = "extended_module_path",
  [sym_module_type_path] = "module_type_path",
  [sym_field_path] = "field_path",
  [sym_constructor_path] = "constructor_path",
  [sym_type_constructor_path] = "type_constructor_path",
  [sym_class_path] = "class_path",
  [sym_class_type_path] = "class_type_path",
  [sym__instance_variable_name] = "_instance_variable_name",
  [sym__constructor_name] = "_constructor_name",
  [sym_directive] = "directive",
  [sym_type_variable] = "type_variable",
  [sym_tag] = "tag",
  [sym_attribute_id] = "attribute_id",
  [aux_sym__structure_repeat1] = "_structure_repeat1",
  [aux_sym__structure_repeat2] = "_structure_repeat2",
  [aux_sym_expression_item_repeat1] = "expression_item_repeat1",
  [aux_sym__signature_repeat1] = "_signature_repeat1",
  [aux_sym_value_definition_repeat1] = "value_definition_repeat1",
  [aux_sym_let_binding_repeat1] = "let_binding_repeat1",
  [aux_sym_external_repeat1] = "external_repeat1",
  [aux_sym_type_definition_repeat1] = "type_definition_repeat1",
  [aux_sym_type_binding_repeat1] = "type_binding_repeat1",
  [aux_sym__type_params_repeat1] = "_type_params_repeat1",
  [aux_sym_variant_declaration_repeat1] = "variant_declaration_repeat1",
  [aux_sym_constructor_declaration_repeat1] = "constructor_declaration_repeat1",
  [aux_sym__constructor_argument_repeat1] = "_constructor_argument_repeat1",
  [aux_sym_record_declaration_repeat1] = "record_declaration_repeat1",
  [aux_sym_module_definition_repeat1] = "module_definition_repeat1",
  [aux_sym_module_binding_repeat1] = "module_binding_repeat1",
  [aux_sym_class_definition_repeat1] = "class_definition_repeat1",
  [aux_sym_class_type_definition_repeat1] = "class_type_definition_repeat1",
  [aux_sym_module_type_constraint_repeat1] = "module_type_constraint_repeat1",
  [aux_sym_instantiated_class_type_repeat1] = "instantiated_class_type_repeat1",
  [aux_sym_class_body_type_repeat1] = "class_body_type_repeat1",
  [aux_sym_instance_variable_specification_repeat1] = "instance_variable_specification_repeat1",
  [aux_sym_method_specification_repeat1] = "method_specification_repeat1",
  [aux_sym_class_application_repeat1] = "class_application_repeat1",
  [aux_sym__abstract_type_repeat1] = "_abstract_type_repeat1",
  [aux_sym_polymorphic_variant_type_repeat1] = "polymorphic_variant_type_repeat1",
  [aux_sym_polymorphic_variant_type_repeat2] = "polymorphic_variant_type_repeat2",
  [aux_sym_tag_specification_repeat1] = "tag_specification_repeat1",
  [aux_sym_object_type_repeat1] = "object_type_repeat1",
  [aux_sym_list_expression_repeat1] = "list_expression_repeat1",
  [aux_sym_record_expression_repeat1] = "record_expression_repeat1",
  [aux_sym__match_cases_repeat1] = "_match_cases_repeat1",
  [aux_sym_object_copy_expression_repeat1] = "object_copy_expression_repeat1",
  [aux_sym_object_expression_repeat1] = "object_expression_repeat1",
  [aux_sym_record_pattern_repeat1] = "record_pattern_repeat1",
  [aux_sym_record_binding_pattern_repeat1] = "record_binding_pattern_repeat1",
  [aux_sym_list_pattern_repeat1] = "list_pattern_repeat1",
  [aux_sym_list_binding_pattern_repeat1] = "list_binding_pattern_repeat1",
  [aux_sym_string_content_repeat1] = "string_content_repeat1",
  [aux_sym_quoted_string_content_repeat1] = "quoted_string_content_repeat1",
  [aux_sym_attribute_id_repeat1] = "attribute_id_repeat1",
  [alias_sym_class_name] = "class_name",
  [alias_sym_class_type_name] = "class_type_name",
  [alias_sym_constructor_name] = "constructor_name",
  [alias_sym_field_name] = "field_name",
  [alias_sym_instance_variable_name] = "instance_variable_name",
  [alias_sym_label_name] = "label_name",
  [alias_sym_method_name] = "method_name",
  [alias_sym_module_name] = "module_name",
  [alias_sym_module_type_name] = "module_type_name",
  [alias_sym_type_constructor] = "type_constructor",
  [alias_sym_value_name] = "value_name",
  [alias_sym_value_pattern] = "value_pattern",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym__lowercase_identifier] = sym__lowercase_identifier,
  [sym_shebang] = sym_shebang,
  [anon_sym_SEMI_SEMI] = anon_sym_SEMI_SEMI,
  [anon_sym_let] = anon_sym_let,
  [anon_sym_rec] = anon_sym_rec,
  [anon_sym_and] = anon_sym_and,
  [anon_sym_COLON_GT] = anon_sym_COLON_GT,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_external] = anon_sym_external,
  [anon_sym_type] = anon_sym_type,
  [anon_sym_nonrec] = anon_sym_nonrec,
  [anon_sym_private] = anon_sym_private,
  [anon_sym_DOT_DOT] = anon_sym_DOT_DOT,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym__] = anon_sym__,
  [anon_sym_COLON_EQ] = anon_sym_COLON_EQ,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_true] = anon_sym_true,
  [anon_sym_false] = anon_sym_false,
  [anon_sym_of] = anon_sym_of,
  [anon_sym_COLON2] = anon_sym_COLON,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_DASH_GT] = anon_sym_DASH_GT,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_mutable] = anon_sym_mutable,
  [anon_sym_constraint] = anon_sym_constraint,
  [anon_sym_exception] = anon_sym_exception,
  [anon_sym_module] = anon_sym_module,
  [anon_sym_open] = anon_sym_open,
  [anon_sym_include] = anon_sym_include,
  [anon_sym_class] = anon_sym_class,
  [anon_sym_virtual] = anon_sym_virtual,
  [anon_sym_val] = anon_sym_val,
  [anon_sym_sig] = anon_sym_sig,
  [anon_sym_end] = anon_sym_end,
  [anon_sym_with] = anon_sym_with,
  [anon_sym_functor] = anon_sym_functor,
  [anon_sym_struct] = anon_sym_struct,
  [anon_sym_object] = anon_sym_object,
  [anon_sym_inherit] = anon_sym_inherit,
  [anon_sym_method] = anon_sym_method,
  [anon_sym_in] = anon_sym_in,
  [anon_sym_fun] = anon_sym_fun,
  [anon_sym_as] = anon_sym_as,
  [anon_sym_initializer] = anon_sym_initializer,
  [anon_sym_LBRACK_GT] = anon_sym_LBRACK_GT,
  [anon_sym_LBRACK_LT] = anon_sym_LBRACK_LT,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_POUND] = anon_sym_POUND,
  [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
  [anon_sym_LBRACK_PIPE] = anon_sym_LBRACK_PIPE,
  [anon_sym_PIPE_RBRACK] = anon_sym_PIPE_RBRACK,
  [anon_sym_LT_DASH] = anon_sym_LT_DASH,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_then] = anon_sym_then,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_do] = anon_sym_do,
  [anon_sym_done] = anon_sym_done,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_to] = anon_sym_to,
  [anon_sym_downto] = anon_sym_downto,
  [anon_sym_match] = anon_sym_match,
  [anon_sym_when] = anon_sym_when,
  [anon_sym_function] = anon_sym_function,
  [anon_sym_try] = anon_sym_try,
  [anon_sym_assert] = anon_sym_assert,
  [anon_sym_lazy] = anon_sym_lazy,
  [anon_sym_new] = anon_sym_new,
  [anon_sym_LBRACE_LT] = anon_sym_LBRACE_LT,
  [anon_sym_GT_RBRACE] = anon_sym_GT_RBRACE,
  [anon_sym_begin] = anon_sym_begin,
  [sym_ocamlyacc_value] = sym_ocamlyacc_value,
  [anon_sym_effect] = anon_sym_effect,
  [aux_sym_attribute_token1] = aux_sym_attribute_token1,
  [anon_sym_LBRACK_AT_AT] = anon_sym_LBRACK_AT_AT,
  [anon_sym_LBRACK_AT_AT_AT] = anon_sym_LBRACK_AT_AT_AT,
  [anon_sym_LBRACK_PERCENT] = anon_sym_LBRACK_PERCENT,
  [anon_sym_LBRACE_PERCENT] = anon_sym_LBRACE_PERCENT,
  [aux_sym_quoted_extension_token1] = aux_sym_quoted_extension_token1,
  [anon_sym_LBRACK_PERCENT_PERCENT] = anon_sym_LBRACK_PERCENT_PERCENT,
  [anon_sym_LBRACE_PERCENT_PERCENT] = anon_sym_LBRACE_PERCENT_PERCENT,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [aux_sym_number_token1] = aux_sym_number_token1,
  [aux_sym_signed_number_token1] = aux_sym_signed_number_token1,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [anon_sym_SQUOTE2] = anon_sym_SQUOTE,
  [aux_sym_character_content_token1] = aux_sym_character_content_token1,
  [aux_sym_character_content_token2] = aux_sym_character_content_token2,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [aux_sym_string_content_token1] = aux_sym_string_content_token1,
  [aux_sym_string_content_token2] = aux_sym_string_content_token2,
  [aux_sym_string_content_token3] = aux_sym_string_content_token3,
  [aux_sym_string_content_token4] = sym_escape_sequence,
  [aux_sym_string_content_token5] = sym_escape_sequence,
  [aux_sym_quoted_string_content_token1] = aux_sym_quoted_string_content_token1,
  [aux_sym_escape_sequence_token1] = aux_sym_escape_sequence_token1,
  [aux_sym_escape_sequence_token2] = aux_sym_escape_sequence_token2,
  [aux_sym_escape_sequence_token3] = aux_sym_escape_sequence_token3,
  [aux_sym_escape_sequence_token4] = aux_sym_escape_sequence_token4,
  [sym_conversion_specification] = sym_conversion_specification,
  [sym_pretty_printing_indication] = sym_pretty_printing_indication,
  [sym_prefix_operator] = sym_prefix_operator,
  [aux_sym_sign_operator_token1] = aux_sym_sign_operator_token1,
  [sym_hash_operator] = sym_hash_operator,
  [sym_pow_operator] = sym_pow_operator,
  [sym_mult_operator] = sym_mult_operator,
  [aux_sym_add_operator_token1] = aux_sym_add_operator_token1,
  [sym_concat_operator] = sym_concat_operator,
  [sym_rel_operator] = sym_rel_operator,
  [sym_and_operator] = sym_and_operator,
  [sym_or_operator] = sym_or_operator,
  [sym_assign_operator] = sym_assign_operator,
  [sym_indexing_operator] = sym_indexing_operator,
  [sym_let_operator] = sym_let_operator,
  [sym_let_and_operator] = sym_let_and_operator,
  [sym_match_operator] = sym_match_operator,
  [sym__uppercase_identifier] = sym__uppercase_identifier,
  [aux_sym_directive_token1] = aux_sym_directive_token1,
  [aux_sym_type_variable_token1] = aux_sym_type_variable_token1,
  [aux_sym_tag_token1] = aux_sym_tag_token1,
  [aux_sym_attribute_id_token1] = aux_sym_attribute_id_token1,
  [sym_comment] = sym_comment,
  [sym__left_quoted_string_delimiter] = sym__left_quoted_string_delimiter,
  [sym__right_quoted_string_delimiter] = sym__right_quoted_string_delimiter,
  [sym_line_number_directive] = sym_line_number_directive,
  [sym__null] = sym__null,
  [sym_compilation_unit] = sym_compilation_unit,
  [sym__structure] = sym__structure,
  [sym_expression_item] = sym_expression_item,
  [sym__signature] = sym__signature,
  [sym_toplevel_directive] = sym_toplevel_directive,
  [sym__structure_item] = sym__structure_item,
  [sym_value_definition] = sym_value_definition,
  [sym_let_binding] = sym_let_binding,
  [sym_parameter] = sym_parameter,
  [sym_external] = sym_external,
  [sym_type_definition] = sym_type_definition,
  [sym_type_binding] = sym_type_binding,
  [sym__type_params] = sym__type_params,
  [sym__type_param] = sym__type_param,
  [sym__type_equation] = sym__type_equation,
  [sym_variant_declaration] = sym_variant_declaration,
  [sym_constructor_declaration] = sym_constructor_declaration,
  [sym__constructor_argument] = sym__constructor_argument,
  [sym_record_declaration] = sym_record_declaration,
  [sym_field_declaration] = sym_field_declaration,
  [sym_type_constraint] = sym_type_constraint,
  [sym_exception_definition] = sym_exception_definition,
  [sym_module_definition] = sym_module_definition,
  [sym_module_binding] = sym_module_binding,
  [sym_module_parameter] = sym_module_parameter,
  [sym_module_type_definition] = sym_module_type_definition,
  [sym_open_module] = sym_open_module,
  [sym_include_module] = sym_include_module,
  [sym_class_definition] = sym_class_definition,
  [sym_class_binding] = sym_class_binding,
  [sym_class_type_definition] = sym_class_type_definition,
  [sym_class_type_binding] = sym_class_type_binding,
  [sym__signature_item] = sym__signature_item,
  [sym_value_specification] = sym_value_specification,
  [sym_include_module_type] = sym_include_module_type,
  [sym__module_typed] = sym__module_typed,
  [sym__module_type] = sym__module_type,
  [sym_signature] = sym_signature,
  [sym_module_type_constraint] = sym_module_type_constraint,
  [sym_constrain_type] = sym_constrain_type,
  [sym_constrain_module] = sym_constrain_module,
  [sym_constrain_module_type] = sym_constrain_module_type,
  [sym_module_type_of] = sym_module_type_of,
  [sym_functor_type] = sym_functor_type,
  [sym_parenthesized_module_type] = sym_parenthesized_module_type,
  [sym__simple_module_expression] = sym__simple_module_expression,
  [sym__module_expression] = sym__module_expression,
  [sym_structure] = sym_structure,
  [sym_functor] = sym_functor,
  [sym_module_application] = sym_module_application,
  [sym_typed_module_expression] = sym_typed_module_expression,
  [sym_packed_module] = sym_packed_module,
  [sym_parenthesized_module_expression] = sym_parenthesized_module_expression,
  [sym__class_typed] = sym__class_typed,
  [sym__simple_class_type] = sym__simple_class_type,
  [sym__class_type] = sym__class_type,
  [sym_instantiated_class_type] = sym_instantiated_class_type,
  [sym_class_body_type] = sym_class_body_type,
  [sym__class_field_specification] = sym__class_field_specification,
  [sym_inheritance_specification] = sym_inheritance_specification,
  [sym_instance_variable_specification] = sym_instance_variable_specification,
  [sym_method_specification] = sym_method_specification,
  [sym_type_parameter_constraint] = sym_type_parameter_constraint,
  [sym_let_open_class_type] = sym_let_open_class_type,
  [sym_class_function_type] = sym_class_function_type,
  [sym__simple_class_expression] = sym__simple_class_expression,
  [sym__class_expression] = sym__class_expression,
  [sym_instantiated_class] = sym_instantiated_class,
  [sym_typed_class_expression] = sym_typed_class_expression,
  [sym_class_function] = sym_class_function,
  [sym_class_application] = sym_class_application,
  [sym_let_class_expression] = sym_let_class_expression,
  [sym__class_field] = sym__class_field,
  [sym_inheritance_definition] = sym_inheritance_definition,
  [sym_instance_variable_definition] = sym_instance_variable_definition,
  [sym_method_definition] = sym_method_definition,
  [sym_class_initializer] = sym_class_initializer,
  [sym_let_open_class_expression] = sym_let_open_class_expression,
  [sym_parenthesized_class_expression] = sym_parenthesized_class_expression,
  [sym__typed] = sym__typed,
  [sym__simple_typed] = sym__simple_typed,
  [sym__polymorphic_typed] = sym__polymorphic_typed,
  [sym__polymorphic_type] = sym__polymorphic_type,
  [sym_polymorphic_type] = sym_polymorphic_type,
  [sym__abstract_type] = sym__abstract_type,
  [sym__parenthesized_abstract_type] = sym__parenthesized_abstract_type,
  [sym__simple_type] = sym__simple_type,
  [sym__tuple_type] = sym__tuple_type,
  [sym__type] = sym__type,
  [sym_function_type] = sym_function_type,
  [sym_typed_label] = sym_typed_label,
  [sym_tuple_type] = sym_tuple_type,
  [sym_constructed_type] = sym_constructed_type,
  [sym_aliased_type] = sym_aliased_type,
  [sym_local_open_type] = sym_local_open_type,
  [sym_polymorphic_variant_type] = sym_polymorphic_variant_type,
  [sym__tag_spec] = sym__tag_spec,
  [sym_tag_specification] = sym_tag_specification,
  [sym_package_type] = sym_package_type,
  [sym_object_type] = sym_object_type,
  [sym_method_type] = sym_method_type,
  [sym_hash_type] = sym_hash_type,
  [sym_parenthesized_type] = sym_parenthesized_type,
  [sym__simple_expression] = sym__simple_expression,
  [sym__expression] = sym__expression,
  [sym__sequence_expression] = sym__sequence_expression,
  [sym_typed_expression] = sym_typed_expression,
  [sym_product_expression] = sym_product_expression,
  [sym_cons_expression] = sym_cons_expression,
  [sym_list_expression] = sym_list_expression,
  [sym_array_expression] = sym_array_expression,
  [sym_record_expression] = sym_record_expression,
  [sym_field_expression] = sym_field_expression,
  [sym_application_expression] = sym_application_expression,
  [sym_labeled_argument] = sym_labeled_argument,
  [sym_prefix_expression] = sym_prefix_expression,
  [sym_sign_expression] = sym_sign_expression,
  [sym_hash_expression] = sym_hash_expression,
  [sym_infix_expression] = sym_infix_expression,
  [sym_field_get_expression] = sym_field_get_expression,
  [sym_array_get_expression] = sym_array_get_expression,
  [sym_string_get_expression] = sym_string_get_expression,
  [sym_bigarray_get_expression] = sym_bigarray_get_expression,
  [sym_set_expression] = sym_set_expression,
  [sym_if_expression] = sym_if_expression,
  [sym_then_clause] = sym_then_clause,
  [sym_else_clause] = sym_else_clause,
  [sym_while_expression] = sym_while_expression,
  [sym_do_clause] = sym_do_clause,
  [sym_for_expression] = sym_for_expression,
  [sym_sequence_expression] = sym_sequence_expression,
  [sym_match_expression] = sym_match_expression,
  [sym__match_cases] = sym__match_cases,
  [sym_match_case] = sym_match_case,
  [sym_guard] = sym_guard,
  [sym_refutation_case] = sym_refutation_case,
  [sym_function_expression] = sym_function_expression,
  [sym_fun_expression] = sym_fun_expression,
  [sym_try_expression] = sym_try_expression,
  [sym_let_expression] = sym_let_expression,
  [sym_coercion_expression] = sym_coercion_expression,
  [sym_assert_expression] = sym_assert_expression,
  [sym_lazy_expression] = sym_lazy_expression,
  [sym_let_module_expression] = sym_let_module_expression,
  [sym_let_open_expression] = sym_let_open_expression,
  [sym_local_open_expression] = sym_local_open_expression,
  [sym_package_expression] = sym_package_expression,
  [sym_let_exception_expression] = sym_let_exception_expression,
  [sym_new_expression] = sym_new_expression,
  [sym_object_copy_expression] = sym_object_copy_expression,
  [sym_instance_variable_expression] = sym_instance_variable_expression,
  [sym_method_invocation] = sym_method_invocation,
  [sym_object_expression] = sym_object_expression,
  [sym_parenthesized_expression] = sym_parenthesized_expression,
  [sym__simple_pattern] = sym__simple_pattern,
  [sym__effect_pattern] = sym__effect_pattern,
  [sym__pattern] = sym__pattern,
  [sym__binding_pattern] = sym__binding_pattern,
  [sym_alias_pattern] = sym_alias_pattern,
  [sym_alias_binding_pattern] = sym_alias_pattern,
  [sym_typed_pattern] = sym_typed_pattern,
  [sym_typed_binding_pattern] = sym_typed_pattern,
  [sym_or_pattern] = sym_or_pattern,
  [sym_or_binding_pattern] = sym_or_pattern,
  [sym_constructor_pattern] = sym_constructor_pattern,
  [sym_constructor_binding_pattern] = sym_constructor_pattern,
  [sym_tag_pattern] = sym_tag_pattern,
  [sym_tag_binding_pattern] = sym_tag_pattern,
  [sym_polymorphic_variant_pattern] = sym_polymorphic_variant_pattern,
  [sym_tuple_pattern] = sym_tuple_pattern,
  [sym_tuple_binding_pattern] = sym_tuple_pattern,
  [sym_record_pattern] = sym_record_pattern,
  [sym_field_pattern] = sym_field_pattern,
  [sym_record_binding_pattern] = sym_record_binding_pattern,
  [sym_field_binding_pattern] = sym_field_pattern,
  [sym_list_pattern] = sym_list_pattern,
  [sym_list_binding_pattern] = sym_list_binding_pattern,
  [sym_cons_pattern] = sym_cons_pattern,
  [sym_cons_binding_pattern] = sym_cons_pattern,
  [sym_array_pattern] = sym_array_pattern,
  [sym_array_binding_pattern] = sym_array_binding_pattern,
  [sym_range_pattern] = sym_range_pattern,
  [sym_lazy_pattern] = sym_lazy_pattern,
  [sym_lazy_binding_pattern] = sym_lazy_pattern,
  [sym_local_open_pattern] = sym_local_open_pattern,
  [sym_local_open_binding_pattern] = sym_local_open_pattern,
  [sym_package_pattern] = sym_package_pattern,
  [sym_parenthesized_pattern] = sym_parenthesized_pattern,
  [sym_parenthesized_binding_pattern] = sym_parenthesized_pattern,
  [sym_exception_pattern] = sym_exception_pattern,
  [sym_effect_pattern] = sym_effect_pattern,
  [sym_attribute] = sym_attribute,
  [sym_item_attribute] = sym_item_attribute,
  [sym_floating_attribute] = sym_floating_attribute,
  [sym_attribute_payload] = sym_attribute_payload,
  [sym_extension] = sym_extension,
  [sym_quoted_extension] = sym_quoted_extension,
  [sym_item_extension] = sym_item_extension,
  [sym_quoted_item_extension] = sym_quoted_item_extension,
  [sym__attribute] = sym__attribute,
  [sym__constant] = sym__constant,
  [sym__signed_constant] = sym__signed_constant,
  [sym_number] = sym_number,
  [sym_signed_number] = sym_signed_number,
  [sym_character] = sym_character,
  [sym_character_content] = sym_character_content,
  [sym_string] = sym_string,
  [sym_string_content] = sym_string_content,
  [sym_quoted_string] = sym_quoted_string,
  [sym__quoted_string] = sym__quoted_string,
  [sym_quoted_string_content] = sym_quoted_string_content,
  [sym_escape_sequence] = sym_escape_sequence,
  [sym_boolean] = sym_boolean,
  [sym_unit] = sym_unit,
  [sym_sign_operator] = sym_sign_operator,
  [sym__infix_operator] = sym__infix_operator,
  [sym_add_operator] = sym_add_operator,
  [sym_indexing_operator_path] = sym_indexing_operator_path,
  [sym__value_name] = sym__value_name,
  [sym__simple_value_pattern] = sym__simple_value_pattern,
  [sym_parenthesized_operator] = sym_parenthesized_operator,
  [sym_value_path] = sym_value_path,
  [sym_module_path] = sym_module_path,
  [sym_extended_module_path] = sym_extended_module_path,
  [sym_module_type_path] = sym_module_type_path,
  [sym_field_path] = sym_field_path,
  [sym_constructor_path] = sym_constructor_path,
  [sym_type_constructor_path] = sym_type_constructor_path,
  [sym_class_path] = sym_class_path,
  [sym_class_type_path] = sym_class_type_path,
  [sym__instance_variable_name] = sym__instance_variable_name,
  [sym__constructor_name] = sym__constructor_name,
  [sym_directive] = sym_directive,
  [sym_type_variable] = sym_type_variable,
  [sym_tag] = sym_tag,
  [sym_attribute_id] = sym_attribute_id,
  [aux_sym__structure_repeat1] = aux_sym__structure_repeat1,
  [aux_sym__structure_repeat2] = aux_sym__structure_repeat2,
  [aux_sym_expression_item_repeat1] = aux_sym_expression_item_repeat1,
  [aux_sym__signature_repeat1] = aux_sym__signature_repeat1,
  [aux_sym_value_definition_repeat1] = aux_sym_value_definition_repeat1,
  [aux_sym_let_binding_repeat1] = aux_sym_let_binding_repeat1,
  [aux_sym_external_repeat1] = aux_sym_external_repeat1,
  [aux_sym_type_definition_repeat1] = aux_sym_type_definition_repeat1,
  [aux_sym_type_binding_repeat1] = aux_sym_type_binding_repeat1,
  [aux_sym__type_params_repeat1] = aux_sym__type_params_repeat1,
  [aux_sym_variant_declaration_repeat1] = aux_sym_variant_declaration_repeat1,
  [aux_sym_constructor_declaration_repeat1] = aux_sym_constructor_declaration_repeat1,
  [aux_sym__constructor_argument_repeat1] = aux_sym__constructor_argument_repeat1,
  [aux_sym_record_declaration_repeat1] = aux_sym_record_declaration_repeat1,
  [aux_sym_module_definition_repeat1] = aux_sym_module_definition_repeat1,
  [aux_sym_module_binding_repeat1] = aux_sym_module_binding_repeat1,
  [aux_sym_class_definition_repeat1] = aux_sym_class_definition_repeat1,
  [aux_sym_class_type_definition_repeat1] = aux_sym_class_type_definition_repeat1,
  [aux_sym_module_type_constraint_repeat1] = aux_sym_module_type_constraint_repeat1,
  [aux_sym_instantiated_class_type_repeat1] = aux_sym_instantiated_class_type_repeat1,
  [aux_sym_class_body_type_repeat1] = aux_sym_class_body_type_repeat1,
  [aux_sym_instance_variable_specification_repeat1] = aux_sym_instance_variable_specification_repeat1,
  [aux_sym_method_specification_repeat1] = aux_sym_method_specification_repeat1,
  [aux_sym_class_application_repeat1] = aux_sym_class_application_repeat1,
  [aux_sym__abstract_type_repeat1] = aux_sym__abstract_type_repeat1,
  [aux_sym_polymorphic_variant_type_repeat1] = aux_sym_polymorphic_variant_type_repeat1,
  [aux_sym_polymorphic_variant_type_repeat2] = aux_sym_polymorphic_variant_type_repeat2,
  [aux_sym_tag_specification_repeat1] = aux_sym_tag_specification_repeat1,
  [aux_sym_object_type_repeat1] = aux_sym_object_type_repeat1,
  [aux_sym_list_expression_repeat1] = aux_sym_list_expression_repeat1,
  [aux_sym_record_expression_repeat1] = aux_sym_record_expression_repeat1,
  [aux_sym__match_cases_repeat1] = aux_sym__match_cases_repeat1,
  [aux_sym_object_copy_expression_repeat1] = aux_sym_object_copy_expression_repeat1,
  [aux_sym_object_expression_repeat1] = aux_sym_object_expression_repeat1,
  [aux_sym_record_pattern_repeat1] = aux_sym_record_pattern_repeat1,
  [aux_sym_record_binding_pattern_repeat1] = aux_sym_record_binding_pattern_repeat1,
  [aux_sym_list_pattern_repeat1] = aux_sym_list_pattern_repeat1,
  [aux_sym_list_binding_pattern_repeat1] = aux_sym_list_binding_pattern_repeat1,
  [aux_sym_string_content_repeat1] = aux_sym_string_content_repeat1,
  [aux_sym_quoted_string_content_repeat1] = aux_sym_quoted_string_content_repeat1,
  [aux_sym_attribute_id_repeat1] = aux_sym_attribute_id_repeat1,
  [alias_sym_class_name] = alias_sym_class_name,
  [alias_sym_class_type_name] = alias_sym_class_type_name,
  [alias_sym_constructor_name] = alias_sym_constructor_name,
  [alias_sym_field_name] = alias_sym_field_name,
  [alias_sym_instance_variable_name] = alias_sym_instance_variable_name,
  [alias_sym_label_name] = alias_sym_label_name,
  [alias_sym_method_name] = alias_sym_method_name,
  [alias_sym_module_name] = alias_sym_module_name,
  [alias_sym_module_type_name] = alias_sym_module_type_name,
  [alias_sym_type_constructor] = alias_sym_type_constructor,
  [alias_sym_value_name] = alias_sym_value_name,
  [alias_sym_value_pattern] = alias_sym_value_pattern,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym__lowercase_identifier] = {
    .visible = false,
    .named = true,
  },
  [sym_shebang] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SEMI_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_let] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_rec] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_and] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_external] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_type] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_nonrec] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_private] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_true] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_false] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_of] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_mutable] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_constraint] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_exception] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_module] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_open] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_include] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_class] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_virtual] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_val] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sig] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_end] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_with] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_functor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_struct] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_object] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_inherit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_method] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_in] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_fun] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_as] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_initializer] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUND] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_then] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_do] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_done] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_to] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_downto] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_match] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_when] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_function] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_try] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_assert] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_lazy] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_new] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_begin] = {
    .visible = true,
    .named = false,
  },
  [sym_ocamlyacc_value] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_effect] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_attribute_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK_AT_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK_AT_AT_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_quoted_extension_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_LBRACK_PERCENT_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE_PERCENT_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_number_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_signed_number_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_character_content_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_character_content_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_string_content_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_content_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_content_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_content_token4] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_string_content_token5] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_quoted_string_content_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_escape_sequence_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_escape_sequence_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_escape_sequence_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_escape_sequence_token4] = {
    .visible = false,
    .named = false,
  },
  [sym_conversion_specification] = {
    .visible = true,
    .named = true,
  },
  [sym_pretty_printing_indication] = {
    .visible = true,
    .named = true,
  },
  [sym_prefix_operator] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_sign_operator_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_hash_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_pow_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_mult_operator] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_add_operator_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_concat_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_rel_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_and_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_or_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_assign_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_indexing_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_let_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_let_and_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_match_operator] = {
    .visible = true,
    .named = true,
  },
  [sym__uppercase_identifier] = {
    .visible = false,
    .named = true,
  },
  [aux_sym_directive_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_variable_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tag_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_attribute_id_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym__left_quoted_string_delimiter] = {
    .visible = false,
    .named = true,
  },
  [sym__right_quoted_string_delimiter] = {
    .visible = false,
    .named = true,
  },
  [sym_line_number_directive] = {
    .visible = true,
    .named = true,
  },
  [sym__null] = {
    .visible = false,
    .named = true,
  },
  [sym_compilation_unit] = {
    .visible = true,
    .named = true,
  },
  [sym__structure] = {
    .visible = false,
    .named = true,
  },
  [sym_expression_item] = {
    .visible = true,
    .named = true,
  },
  [sym__signature] = {
    .visible = false,
    .named = true,
  },
  [sym_toplevel_directive] = {
    .visible = true,
    .named = true,
  },
  [sym__structure_item] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_value_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_let_binding] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_external] = {
    .visible = true,
    .named = true,
  },
  [sym_type_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_type_binding] = {
    .visible = true,
    .named = true,
  },
  [sym__type_params] = {
    .visible = false,
    .named = true,
  },
  [sym__type_param] = {
    .visible = false,
    .named = true,
  },
  [sym__type_equation] = {
    .visible = false,
    .named = true,
  },
  [sym_variant_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_constructor_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__constructor_argument] = {
    .visible = false,
    .named = true,
  },
  [sym_record_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_field_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_type_constraint] = {
    .visible = true,
    .named = true,
  },
  [sym_exception_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_module_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_module_binding] = {
    .visible = true,
    .named = true,
  },
  [sym_module_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_module_type_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_open_module] = {
    .visible = true,
    .named = true,
  },
  [sym_include_module] = {
    .visible = true,
    .named = true,
  },
  [sym_class_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_class_binding] = {
    .visible = true,
    .named = true,
  },
  [sym_class_type_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_class_type_binding] = {
    .visible = true,
    .named = true,
  },
  [sym__signature_item] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_value_specification] = {
    .visible = true,
    .named = true,
  },
  [sym_include_module_type] = {
    .visible = true,
    .named = true,
  },
  [sym__module_typed] = {
    .visible = false,
    .named = true,
  },
  [sym__module_type] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_signature] = {
    .visible = true,
    .named = true,
  },
  [sym_module_type_constraint] = {
    .visible = true,
    .named = true,
  },
  [sym_constrain_type] = {
    .visible = true,
    .named = true,
  },
  [sym_constrain_module] = {
    .visible = true,
    .named = true,
  },
  [sym_constrain_module_type] = {
    .visible = true,
    .named = true,
  },
  [sym_module_type_of] = {
    .visible = true,
    .named = true,
  },
  [sym_functor_type] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_module_type] = {
    .visible = true,
    .named = true,
  },
  [sym__simple_module_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__module_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_structure] = {
    .visible = true,
    .named = true,
  },
  [sym_functor] = {
    .visible = true,
    .named = true,
  },
  [sym_module_application] = {
    .visible = true,
    .named = true,
  },
  [sym_typed_module_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_packed_module] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_module_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__class_typed] = {
    .visible = false,
    .named = true,
  },
  [sym__simple_class_type] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__class_type] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_instantiated_class_type] = {
    .visible = true,
    .named = true,
  },
  [sym_class_body_type] = {
    .visible = true,
    .named = true,
  },
  [sym__class_field_specification] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_inheritance_specification] = {
    .visible = true,
    .named = true,
  },
  [sym_instance_variable_specification] = {
    .visible = true,
    .named = true,
  },
  [sym_method_specification] = {
    .visible = true,
    .named = true,
  },
  [sym_type_parameter_constraint] = {
    .visible = true,
    .named = true,
  },
  [sym_let_open_class_type] = {
    .visible = true,
    .named = true,
  },
  [sym_class_function_type] = {
    .visible = true,
    .named = true,
  },
  [sym__simple_class_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__class_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_instantiated_class] = {
    .visible = true,
    .named = true,
  },
  [sym_typed_class_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_class_function] = {
    .visible = true,
    .named = true,
  },
  [sym_class_application] = {
    .visible = true,
    .named = true,
  },
  [sym_let_class_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__class_field] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_inheritance_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_instance_variable_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_method_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_class_initializer] = {
    .visible = true,
    .named = true,
  },
  [sym_let_open_class_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_class_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__typed] = {
    .visible = false,
    .named = true,
  },
  [sym__simple_typed] = {
    .visible = false,
    .named = true,
  },
  [sym__polymorphic_typed] = {
    .visible = false,
    .named = true,
  },
  [sym__polymorphic_type] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_polymorphic_type] = {
    .visible = true,
    .named = true,
  },
  [sym__abstract_type] = {
    .visible = false,
    .named = true,
  },
  [sym__parenthesized_abstract_type] = {
    .visible = true,
    .named = true,
  },
  [sym__simple_type] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__tuple_type] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__type] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_function_type] = {
    .visible = true,
    .named = true,
  },
  [sym_typed_label] = {
    .visible = true,
    .named = true,
  },
  [sym_tuple_type] = {
    .visible = true,
    .named = true,
  },
  [sym_constructed_type] = {
    .visible = true,
    .named = true,
  },
  [sym_aliased_type] = {
    .visible = true,
    .named = true,
  },
  [sym_local_open_type] = {
    .visible = true,
    .named = true,
  },
  [sym_polymorphic_variant_type] = {
    .visible = true,
    .named = true,
  },
  [sym__tag_spec] = {
    .visible = false,
    .named = true,
  },
  [sym_tag_specification] = {
    .visible = true,
    .named = true,
  },
  [sym_package_type] = {
    .visible = true,
    .named = true,
  },
  [sym_object_type] = {
    .visible = true,
    .named = true,
  },
  [sym_method_type] = {
    .visible = true,
    .named = true,
  },
  [sym_hash_type] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_type] = {
    .visible = true,
    .named = true,
  },
  [sym__simple_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__sequence_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_typed_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_product_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_cons_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_list_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_array_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_record_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_field_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_application_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_labeled_argument] = {
    .visible = true,
    .named = true,
  },
  [sym_prefix_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_sign_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hash_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_infix_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_field_get_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_array_get_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_string_get_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_bigarray_get_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_set_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_if_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_then_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_else_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_while_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_do_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_for_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_sequence_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_match_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__match_cases] = {
    .visible = false,
    .named = true,
  },
  [sym_match_case] = {
    .visible = true,
    .named = true,
  },
  [sym_guard] = {
    .visible = true,
    .named = true,
  },
  [sym_refutation_case] = {
    .visible = true,
    .named = true,
  },
  [sym_function_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_fun_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_try_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_let_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_coercion_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_assert_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_lazy_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_let_module_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_let_open_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_local_open_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_package_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_let_exception_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_new_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_object_copy_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_instance_variable_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_method_invocation] = {
    .visible = true,
    .named = true,
  },
  [sym_object_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__simple_pattern] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__effect_pattern] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__pattern] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__binding_pattern] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_alias_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_alias_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_typed_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_typed_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_or_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_or_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_constructor_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_constructor_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_tag_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_tag_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_polymorphic_variant_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_tuple_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_tuple_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_record_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_field_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_record_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_field_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_list_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_list_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_cons_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_cons_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_array_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_array_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_range_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_lazy_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_lazy_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_local_open_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_local_open_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_package_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_exception_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_effect_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym_item_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym_floating_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute_payload] = {
    .visible = true,
    .named = true,
  },
  [sym_extension] = {
    .visible = true,
    .named = true,
  },
  [sym_quoted_extension] = {
    .visible = true,
    .named = true,
  },
  [sym_item_extension] = {
    .visible = true,
    .named = true,
  },
  [sym_quoted_item_extension] = {
    .visible = true,
    .named = true,
  },
  [sym__attribute] = {
    .visible = false,
    .named = true,
  },
  [sym__constant] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__signed_constant] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_number] = {
    .visible = true,
    .named = true,
  },
  [sym_signed_number] = {
    .visible = true,
    .named = true,
  },
  [sym_character] = {
    .visible = true,
    .named = true,
  },
  [sym_character_content] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_string_content] = {
    .visible = true,
    .named = true,
  },
  [sym_quoted_string] = {
    .visible = true,
    .named = true,
  },
  [sym__quoted_string] = {
    .visible = false,
    .named = true,
  },
  [sym_quoted_string_content] = {
    .visible = true,
    .named = true,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean] = {
    .visible = true,
    .named = true,
  },
  [sym_unit] = {
    .visible = true,
    .named = true,
  },
  [sym_sign_operator] = {
    .visible = true,
    .named = true,
  },
  [sym__infix_operator] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_add_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_indexing_operator_path] = {
    .visible = true,
    .named = true,
  },
  [sym__value_name] = {
    .visible = false,
    .named = true,
  },
  [sym__simple_value_pattern] = {
    .visible = false,
    .named = true,
  },
  [sym_parenthesized_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_value_path] = {
    .visible = true,
    .named = true,
  },
  [sym_module_path] = {
    .visible = true,
    .named = true,
  },
  [sym_extended_module_path] = {
    .visible = true,
    .named = true,
  },
  [sym_module_type_path] = {
    .visible = true,
    .named = true,
  },
  [sym_field_path] = {
    .visible = true,
    .named = true,
  },
  [sym_constructor_path] = {
    .visible = true,
    .named = true,
  },
  [sym_type_constructor_path] = {
    .visible = true,
    .named = true,
  },
  [sym_class_path] = {
    .visible = true,
    .named = true,
  },
  [sym_class_type_path] = {
    .visible = true,
    .named = true,
  },
  [sym__instance_variable_name] = {
    .visible = false,
    .named = true,
  },
  [sym__constructor_name] = {
    .visible = false,
    .named = true,
  },
  [sym_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_type_variable] = {
    .visible = true,
    .named = true,
  },
  [sym_tag] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute_id] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__structure_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__structure_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_expression_item_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__signature_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_value_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_let_binding_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_external_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_binding_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__type_params_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_variant_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_constructor_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__constructor_argument_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_record_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_module_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_module_binding_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_type_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_module_type_constraint_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_instantiated_class_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_body_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_instance_variable_specification_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_method_specification_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_application_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__abstract_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_polymorphic_variant_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_polymorphic_variant_type_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tag_specification_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_object_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_record_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__match_cases_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_object_copy_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_object_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_record_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_record_binding_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_binding_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_content_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_quoted_string_content_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_attribute_id_repeat1] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_class_name] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_class_type_name] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_constructor_name] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_field_name] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_instance_variable_name] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_label_name] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_method_name] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_module_name] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_module_type_name] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_type_constructor] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_value_name] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_value_pattern] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_argument = 1,
  field_body = 2,
  field_class = 3,
  field_condition = 4,
  field_continuation = 5,
  field_effect = 6,
  field_from = 7,
  field_function = 8,
  field_functor = 9,
  field_left = 10,
  field_name = 11,
  field_operator = 12,
  field_pattern = 13,
  field_right = 14,
  field_to = 15,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_argument] = "argument",
  [field_body] = "body",
  [field_class] = "class",
  [field_condition] = "condition",
  [field_continuation] = "continuation",
  [field_effect] = "effect",
  [field_from] = "from",
  [field_function] = "function",
  [field_functor] = "functor",
  [field_left] = "left",
  [field_name] = "name",
  [field_operator] = "operator",
  [field_pattern] = "pattern",
  [field_right] = "right",
  [field_to] = "to",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [3] = {.index = 0, .length = 1},
  [7] = {.index = 0, .length = 1},
  [9] = {.index = 0, .length = 1},
  [12] = {.index = 1, .length = 1},
  [14] = {.index = 2, .length = 1},
  [15] = {.index = 3, .length = 2},
  [16] = {.index = 1, .length = 1},
  [18] = {.index = 5, .length = 1},
  [23] = {.index = 0, .length = 1},
  [25] = {.index = 6, .length = 2},
  [26] = {.index = 8, .length = 1},
  [27] = {.index = 9, .length = 2},
  [28] = {.index = 11, .length = 1},
  [30] = {.index = 12, .length = 2},
  [33] = {.index = 12, .length = 2},
  [35] = {.index = 14, .length = 1},
  [36] = {.index = 12, .length = 2},
  [37] = {.index = 15, .length = 1},
  [39] = {.index = 12, .length = 2},
  [40] = {.index = 16, .length = 1},
  [42] = {.index = 1, .length = 1},
  [43] = {.index = 1, .length = 1},
  [44] = {.index = 17, .length = 1},
  [47] = {.index = 18, .length = 3},
  [48] = {.index = 21, .length = 2},
  [49] = {.index = 23, .length = 2},
  [50] = {.index = 25, .length = 1},
  [51] = {.index = 26, .length = 2},
  [52] = {.index = 28, .length = 2},
  [53] = {.index = 28, .length = 2},
  [54] = {.index = 26, .length = 2},
  [55] = {.index = 30, .length = 2},
  [56] = {.index = 26, .length = 2},
  [57] = {.index = 32, .length = 1},
  [58] = {.index = 1, .length = 1},
  [59] = {.index = 12, .length = 2},
  [60] = {.index = 14, .length = 1},
  [61] = {.index = 28, .length = 2},
  [62] = {.index = 33, .length = 2},
  [63] = {.index = 26, .length = 2},
  [64] = {.index = 35, .length = 2},
  [68] = {.index = 2, .length = 1},
  [69] = {.index = 2, .length = 1},
  [70] = {.index = 37, .length = 1},
  [72] = {.index = 38, .length = 2},
  [74] = {.index = 40, .length = 2},
  [75] = {.index = 42, .length = 2},
  [76] = {.index = 42, .length = 2},
  [77] = {.index = 44, .length = 2},
  [78] = {.index = 40, .length = 2},
  [79] = {.index = 28, .length = 2},
  [80] = {.index = 46, .length = 1},
  [81] = {.index = 42, .length = 2},
  [82] = {.index = 47, .length = 1},
  [83] = {.index = 48, .length = 1},
  [85] = {.index = 40, .length = 2},
  [86] = {.index = 49, .length = 2},
  [87] = {.index = 51, .length = 2},
  [88] = {.index = 14, .length = 1},
  [89] = {.index = 14, .length = 1},
  [90] = {.index = 28, .length = 2},
  [91] = {.index = 53, .length = 1},
  [93] = {.index = 54, .length = 2},
  [94] = {.index = 44, .length = 2},
  [95] = {.index = 56, .length = 1},
  [96] = {.index = 54, .length = 2},
  [99] = {.index = 48, .length = 1},
  [100] = {.index = 57, .length = 2},
  [101] = {.index = 30, .length = 2},
  [102] = {.index = 30, .length = 2},
  [103] = {.index = 42, .length = 2},
  [104] = {.index = 59, .length = 1},
  [106] = {.index = 44, .length = 2},
  [107] = {.index = 60, .length = 2},
  [108] = {.index = 62, .length = 2},
  [109] = {.index = 64, .length = 2},
  [110] = {.index = 66, .length = 2},
  [111] = {.index = 44, .length = 2},
  [112] = {.index = 54, .length = 2},
  [113] = {.index = 66, .length = 2},
  [114] = {.index = 44, .length = 2},
  [115] = {.index = 54, .length = 2},
  [116] = {.index = 68, .length = 3},
  [117] = {.index = 62, .length = 2},
  [118] = {.index = 71, .length = 2},
  [119] = {.index = 73, .length = 2},
  [120] = {.index = 75, .length = 2},
  [121] = {.index = 77, .length = 2},
  [122] = {.index = 79, .length = 2},
  [123] = {.index = 60, .length = 2},
  [124] = {.index = 81, .length = 2},
  [125] = {.index = 79, .length = 2},
  [126] = {.index = 60, .length = 2},
  [127] = {.index = 83, .length = 3},
  [128] = {.index = 75, .length = 2},
  [129] = {.index = 86, .length = 2},
  [130] = {.index = 88, .length = 2},
  [131] = {.index = 90, .length = 1},
  [132] = {.index = 91, .length = 2},
  [133] = {.index = 71, .length = 2},
  [134] = {.index = 71, .length = 2},
  [135] = {.index = 93, .length = 2},
  [136] = {.index = 95, .length = 2},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_name, 0},
  [1] =
    {field_name, 1},
  [2] =
    {field_name, 2},
  [3] =
    {field_argument, 1},
    {field_functor, 0},
  [5] =
    {field_pattern, 0},
  [6] =
    {field_operator, 0},
    {field_right, 1},
  [8] =
    {field_argument, 0},
  [9] =
    {field_argument, 1, .inherited = true},
    {field_function, 0},
  [11] =
    {field_left, 0},
  [12] =
    {field_body, 2},
    {field_name, 0},
  [14] =
    {field_name, 3},
  [15] =
    {field_functor, 0},
  [16] =
    {field_pattern, 1},
  [17] =
    {field_condition, 1},
  [18] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [21] =
    {field_argument, 0, .inherited = true},
    {field_argument, 1, .inherited = true},
  [23] =
    {field_left, 0},
    {field_right, 2},
  [25] =
    {field_body, 2},
  [26] =
    {field_body, 3},
    {field_name, 0},
  [28] =
    {field_body, 3},
    {field_name, 1},
  [30] =
    {field_body, 4},
    {field_name, 2},
  [32] =
    {field_body, 3},
  [33] =
    {field_argument, 1, .inherited = true},
    {field_class, 0},
  [35] =
    {field_body, 2},
    {field_pattern, 0},
  [37] =
    {field_condition, 2},
  [38] =
    {field_left, 0},
    {field_right, 3},
  [40] =
    {field_body, 4},
    {field_name, 0},
  [42] =
    {field_body, 4},
    {field_name, 1},
  [44] =
    {field_body, 5},
    {field_name, 3},
  [46] =
    {field_name, 4},
  [47] =
    {field_pattern, 2},
  [48] =
    {field_pattern, 3},
  [49] =
    {field_body, 3},
    {field_pattern, 0},
  [51] =
    {field_continuation, 3},
    {field_effect, 1},
  [53] =
    {field_body, 4},
  [54] =
    {field_body, 5},
    {field_name, 1},
  [56] =
    {field_name, 5},
  [57] =
    {field_body, 4},
    {field_pattern, 0},
  [59] =
    {field_body, 5},
  [60] =
    {field_body, 6},
    {field_name, 3},
  [62] =
    {field_body, 6},
    {field_name, 4},
  [64] =
    {field_body, 5},
    {field_pattern, 0},
  [66] =
    {field_body, 5},
    {field_name, 2},
  [68] =
    {field_from, 3},
    {field_name, 1},
    {field_to, 5},
  [71] =
    {field_body, 7},
    {field_name, 3},
  [73] =
    {field_body, 7},
    {field_name, 4},
  [75] =
    {field_body, 7},
    {field_name, 5},
  [77] =
    {field_body, 6},
    {field_pattern, 0},
  [79] =
    {field_body, 6},
    {field_name, 2},
  [81] =
    {field_body, 6},
    {field_name, 1},
  [83] =
    {field_from, 4},
    {field_name, 2},
    {field_to, 6},
  [86] =
    {field_body, 8},
    {field_name, 4},
  [88] =
    {field_body, 8},
    {field_name, 5},
  [90] =
    {field_pattern, 4},
  [91] =
    {field_body, 7},
    {field_name, 2},
  [93] =
    {field_body, 9},
    {field_name, 5},
  [95] =
    {field_body, 8},
    {field_name, 3},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [1] = {
    [0] = alias_sym_value_name,
  },
  [2] = {
    [0] = sym_type_variable,
  },
  [3] = {
    [0] = alias_sym_type_constructor,
  },
  [4] = {
    [0] = alias_sym_type_constructor,
  },
  [5] = {
    [0] = alias_sym_module_name,
  },
  [6] = {
    [0] = alias_sym_constructor_name,
  },
  [7] = {
    [0] = alias_sym_module_name,
  },
  [8] = {
    [0] = alias_sym_module_type_name,
  },
  [9] = {
    [0] = alias_sym_class_name,
  },
  [10] = {
    [0] = alias_sym_instance_variable_name,
  },
  [11] = {
    [1] = sym_type_variable,
  },
  [12] = {
    [1] = alias_sym_type_constructor,
  },
  [13] = {
    [0] = alias_sym_constructor_name,
    [1] = alias_sym_constructor_name,
  },
  [14] = {
    [2] = alias_sym_module_type_name,
  },
  [16] = {
    [1] = alias_sym_class_name,
  },
  [17] = {
    [0] = alias_sym_value_pattern,
  },
  [19] = {
    [0] = sym_record_pattern,
  },
  [20] = {
    [0] = sym_list_pattern,
  },
  [21] = {
    [0] = sym_array_pattern,
  },
  [22] = {
    [0] = alias_sym_field_name,
  },
  [24] = {
    [0] = alias_sym_class_name,
  },
  [29] = {
    [2] = sym_type_variable,
  },
  [30] = {
    [0] = alias_sym_type_constructor,
  },
  [31] = {
    [2] = alias_sym_type_constructor,
  },
  [32] = {
    [2] = alias_sym_module_name,
  },
  [34] = {
    [1] = alias_sym_constructor_name,
  },
  [35] = {
    [3] = alias_sym_module_type_name,
  },
  [36] = {
    [0] = alias_sym_module_name,
  },
  [38] = {
    [2] = alias_sym_module_type_name,
  },
  [39] = {
    [0] = alias_sym_class_name,
  },
  [41] = {
    [0] = alias_sym_class_type_name,
  },
  [43] = {
    [1] = alias_sym_method_name,
  },
  [45] = {
    [1] = alias_sym_label_name,
  },
  [46] = {
    [2] = alias_sym_method_name,
  },
  [51] = {
    [0] = alias_sym_type_constructor,
  },
  [52] = {
    [1] = alias_sym_type_constructor,
  },
  [55] = {
    [2] = alias_sym_module_type_name,
  },
  [56] = {
    [0] = alias_sym_module_name,
  },
  [58] = {
    [1] = alias_sym_module_name,
  },
  [59] = {
    [0] = alias_sym_class_type_name,
  },
  [60] = {
    [3] = alias_sym_class_name,
  },
  [61] = {
    [1] = alias_sym_class_name,
  },
  [63] = {
    [0] = alias_sym_class_name,
  },
  [65] = {
    [0] = alias_sym_method_name,
  },
  [66] = {
    [0] = alias_sym_label_name,
  },
  [67] = {
    [2] = alias_sym_field_name,
  },
  [69] = {
    [2] = alias_sym_method_name,
  },
  [71] = {
    [2] = alias_sym_class_name,
  },
  [73] = {
    [0] = sym__parenthesized_abstract_type,
  },
  [74] = {
    [0] = alias_sym_type_constructor,
  },
  [75] = {
    [1] = alias_sym_type_constructor,
  },
  [77] = {
    [3] = alias_sym_module_type_name,
  },
  [78] = {
    [0] = alias_sym_module_name,
  },
  [79] = {
    [1] = alias_sym_class_type_name,
  },
  [80] = {
    [4] = alias_sym_class_name,
  },
  [81] = {
    [1] = alias_sym_class_name,
  },
  [83] = {
    [1] = alias_sym_label_name,
  },
  [84] = {
    [2] = alias_sym_class_type_name,
  },
  [85] = {
    [0] = alias_sym_class_name,
  },
  [89] = {
    [3] = alias_sym_method_name,
  },
  [90] = {
    [1] = alias_sym_method_name,
  },
  [92] = {
    [1] = alias_sym_field_name,
  },
  [93] = {
    [1] = alias_sym_type_constructor,
  },
  [94] = {
    [3] = alias_sym_class_name,
  },
  [95] = {
    [5] = alias_sym_class_name,
  },
  [96] = {
    [1] = alias_sym_class_name,
  },
  [97] = {
    [3] = alias_sym_module_name,
  },
  [98] = {
    [1] = alias_sym_method_name,
  },
  [102] = {
    [2] = alias_sym_method_name,
  },
  [103] = {
    [1] = alias_sym_method_name,
  },
  [105] = {
    [2] = alias_sym_label_name,
  },
  [106] = {
    [3] = alias_sym_class_type_name,
  },
  [107] = {
    [3] = alias_sym_class_name,
  },
  [108] = {
    [4] = alias_sym_class_name,
  },
  [113] = {
    [2] = alias_sym_method_name,
  },
  [114] = {
    [3] = alias_sym_method_name,
  },
  [115] = {
    [1] = alias_sym_method_name,
  },
  [117] = {
    [4] = alias_sym_class_type_name,
  },
  [118] = {
    [3] = alias_sym_class_name,
  },
  [119] = {
    [4] = alias_sym_class_name,
  },
  [120] = {
    [5] = alias_sym_class_name,
  },
  [125] = {
    [2] = alias_sym_method_name,
  },
  [126] = {
    [3] = alias_sym_method_name,
  },
  [128] = {
    [5] = alias_sym_class_type_name,
  },
  [129] = {
    [4] = alias_sym_class_name,
  },
  [130] = {
    [5] = alias_sym_class_name,
  },
  [131] = {
    [1] = alias_sym_label_name,
  },
  [134] = {
    [3] = alias_sym_method_name,
  },
  [135] = {
    [5] = alias_sym_class_name,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym__abstract_type, 2,
    sym__abstract_type,
    sym__parenthesized_abstract_type,
  sym_record_binding_pattern, 2,
    sym_record_binding_pattern,
    sym_record_pattern,
  sym_list_binding_pattern, 2,
    sym_list_binding_pattern,
    sym_list_pattern,
  sym_array_binding_pattern, 2,
    sym_array_binding_pattern,
    sym_array_pattern,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 2,
  [4] = 2,
  [5] = 2,
  [6] = 2,
  [7] = 2,
  [8] = 2,
  [9] = 2,
  [10] = 2,
  [11] = 2,
  [12] = 2,
  [13] = 2,
  [14] = 2,
  [15] = 15,
  [16] = 2,
  [17] = 2,
  [18] = 2,
  [19] = 2,
  [20] = 2,
  [21] = 15,
  [22] = 22,
  [23] = 2,
  [24] = 2,
  [25] = 2,
  [26] = 2,
  [27] = 2,
  [28] = 2,
  [29] = 2,
  [30] = 2,
  [31] = 15,
  [32] = 2,
  [33] = 2,
  [34] = 15,
  [35] = 2,
  [36] = 2,
  [37] = 2,
  [38] = 2,
  [39] = 2,
  [40] = 2,
  [41] = 2,
  [42] = 2,
  [43] = 2,
  [44] = 2,
  [45] = 2,
  [46] = 2,
  [47] = 2,
  [48] = 2,
  [49] = 2,
  [50] = 2,
  [51] = 2,
  [52] = 2,
  [53] = 2,
  [54] = 2,
  [55] = 2,
  [56] = 2,
  [57] = 2,
  [58] = 2,
  [59] = 2,
  [60] = 2,
  [61] = 2,
  [62] = 2,
  [63] = 2,
  [64] = 2,
  [65] = 2,
  [66] = 2,
  [67] = 2,
  [68] = 2,
  [69] = 2,
  [70] = 2,
  [71] = 2,
  [72] = 2,
  [73] = 2,
  [74] = 2,
  [75] = 2,
  [76] = 2,
  [77] = 2,
  [78] = 2,
  [79] = 2,
  [80] = 2,
  [81] = 2,
  [82] = 2,
  [83] = 83,
  [84] = 2,
  [85] = 2,
  [86] = 86,
  [87] = 2,
  [88] = 2,
  [89] = 89,
  [90] = 89,
  [91] = 91,
  [92] = 89,
  [93] = 89,
  [94] = 89,
  [95] = 91,
  [96] = 89,
  [97] = 97,
  [98] = 98,
  [99] = 89,
  [100] = 97,
  [101] = 101,
  [102] = 102,
  [103] = 101,
  [104] = 102,
  [105] = 98,
  [106] = 89,
  [107] = 107,
  [108] = 89,
  [109] = 89,
  [110] = 107,
  [111] = 89,
  [112] = 89,
  [113] = 89,
  [114] = 89,
  [115] = 89,
  [116] = 89,
  [117] = 89,
  [118] = 89,
  [119] = 89,
  [120] = 89,
  [121] = 89,
  [122] = 89,
  [123] = 89,
  [124] = 89,
  [125] = 89,
  [126] = 89,
  [127] = 89,
  [128] = 89,
  [129] = 89,
  [130] = 130,
  [131] = 131,
  [132] = 130,
  [133] = 131,
  [134] = 130,
  [135] = 89,
  [136] = 130,
  [137] = 89,
  [138] = 131,
  [139] = 131,
  [140] = 131,
  [141] = 130,
  [142] = 131,
  [143] = 131,
  [144] = 131,
  [145] = 130,
  [146] = 130,
  [147] = 131,
  [148] = 131,
  [149] = 131,
  [150] = 130,
  [151] = 130,
  [152] = 130,
  [153] = 130,
  [154] = 130,
  [155] = 130,
  [156] = 130,
  [157] = 131,
  [158] = 131,
  [159] = 130,
  [160] = 130,
  [161] = 130,
  [162] = 130,
  [163] = 131,
  [164] = 131,
  [165] = 131,
  [166] = 130,
  [167] = 130,
  [168] = 131,
  [169] = 131,
  [170] = 131,
  [171] = 131,
  [172] = 130,
  [173] = 130,
  [174] = 130,
  [175] = 130,
  [176] = 131,
  [177] = 130,
  [178] = 130,
  [179] = 131,
  [180] = 131,
  [181] = 130,
  [182] = 131,
  [183] = 130,
  [184] = 89,
  [185] = 131,
  [186] = 130,
  [187] = 130,
  [188] = 131,
  [189] = 130,
  [190] = 131,
  [191] = 89,
  [192] = 131,
  [193] = 131,
  [194] = 130,
  [195] = 131,
  [196] = 130,
  [197] = 130,
  [198] = 131,
  [199] = 131,
  [200] = 130,
  [201] = 131,
  [202] = 130,
  [203] = 130,
  [204] = 130,
  [205] = 130,
  [206] = 131,
  [207] = 131,
  [208] = 131,
  [209] = 131,
  [210] = 131,
  [211] = 130,
  [212] = 131,
  [213] = 131,
  [214] = 130,
  [215] = 89,
  [216] = 131,
  [217] = 89,
  [218] = 131,
  [219] = 130,
  [220] = 130,
  [221] = 130,
  [222] = 89,
  [223] = 89,
  [224] = 89,
  [225] = 131,
  [226] = 131,
  [227] = 89,
  [228] = 89,
  [229] = 89,
  [230] = 89,
  [231] = 89,
  [232] = 89,
  [233] = 89,
  [234] = 89,
  [235] = 89,
  [236] = 89,
  [237] = 89,
  [238] = 89,
  [239] = 89,
  [240] = 89,
  [241] = 89,
  [242] = 89,
  [243] = 89,
  [244] = 89,
  [245] = 245,
  [246] = 245,
  [247] = 89,
  [248] = 245,
  [249] = 245,
  [250] = 245,
  [251] = 89,
  [252] = 245,
  [253] = 89,
  [254] = 245,
  [255] = 245,
  [256] = 245,
  [257] = 245,
  [258] = 89,
  [259] = 245,
  [260] = 89,
  [261] = 245,
  [262] = 245,
  [263] = 245,
  [264] = 245,
  [265] = 245,
  [266] = 245,
  [267] = 245,
  [268] = 245,
  [269] = 245,
  [270] = 245,
  [271] = 245,
  [272] = 245,
  [273] = 245,
  [274] = 245,
  [275] = 245,
  [276] = 245,
  [277] = 245,
  [278] = 245,
  [279] = 245,
  [280] = 245,
  [281] = 245,
  [282] = 245,
  [283] = 245,
  [284] = 245,
  [285] = 245,
  [286] = 245,
  [287] = 245,
  [288] = 89,
  [289] = 245,
  [290] = 245,
  [291] = 245,
  [292] = 245,
  [293] = 245,
  [294] = 245,
  [295] = 295,
  [296] = 296,
  [297] = 296,
  [298] = 298,
  [299] = 299,
  [300] = 296,
  [301] = 301,
  [302] = 302,
  [303] = 296,
  [304] = 299,
  [305] = 295,
  [306] = 299,
  [307] = 298,
  [308] = 299,
  [309] = 302,
  [310] = 299,
  [311] = 298,
  [312] = 298,
  [313] = 296,
  [314] = 299,
  [315] = 298,
  [316] = 299,
  [317] = 298,
  [318] = 299,
  [319] = 296,
  [320] = 298,
  [321] = 295,
  [322] = 302,
  [323] = 301,
  [324] = 295,
  [325] = 298,
  [326] = 299,
  [327] = 296,
  [328] = 299,
  [329] = 296,
  [330] = 302,
  [331] = 296,
  [332] = 298,
  [333] = 296,
  [334] = 302,
  [335] = 298,
  [336] = 299,
  [337] = 296,
  [338] = 299,
  [339] = 299,
  [340] = 302,
  [341] = 296,
  [342] = 295,
  [343] = 302,
  [344] = 295,
  [345] = 298,
  [346] = 298,
  [347] = 302,
  [348] = 299,
  [349] = 298,
  [350] = 296,
  [351] = 295,
  [352] = 295,
  [353] = 302,
  [354] = 296,
  [355] = 299,
  [356] = 298,
  [357] = 357,
  [358] = 296,
  [359] = 299,
  [360] = 296,
  [361] = 298,
  [362] = 299,
  [363] = 298,
  [364] = 302,
  [365] = 295,
  [366] = 296,
  [367] = 296,
  [368] = 299,
  [369] = 298,
  [370] = 295,
  [371] = 298,
  [372] = 299,
  [373] = 299,
  [374] = 298,
  [375] = 298,
  [376] = 295,
  [377] = 296,
  [378] = 299,
  [379] = 296,
  [380] = 298,
  [381] = 299,
  [382] = 298,
  [383] = 299,
  [384] = 295,
  [385] = 296,
  [386] = 296,
  [387] = 296,
  [388] = 302,
  [389] = 299,
  [390] = 302,
  [391] = 296,
  [392] = 295,
  [393] = 298,
  [394] = 302,
  [395] = 295,
  [396] = 302,
  [397] = 302,
  [398] = 296,
  [399] = 296,
  [400] = 298,
  [401] = 296,
  [402] = 357,
  [403] = 302,
  [404] = 295,
  [405] = 302,
  [406] = 295,
  [407] = 302,
  [408] = 302,
  [409] = 299,
  [410] = 299,
  [411] = 295,
  [412] = 302,
  [413] = 295,
  [414] = 299,
  [415] = 298,
  [416] = 298,
  [417] = 296,
  [418] = 296,
  [419] = 295,
  [420] = 299,
  [421] = 298,
  [422] = 298,
  [423] = 299,
  [424] = 298,
  [425] = 296,
  [426] = 296,
  [427] = 299,
  [428] = 295,
  [429] = 298,
  [430] = 302,
  [431] = 295,
  [432] = 299,
  [433] = 302,
  [434] = 298,
  [435] = 296,
  [436] = 299,
  [437] = 298,
  [438] = 296,
  [439] = 298,
  [440] = 296,
  [441] = 357,
  [442] = 296,
  [443] = 299,
  [444] = 298,
  [445] = 299,
  [446] = 296,
  [447] = 298,
  [448] = 296,
  [449] = 299,
  [450] = 295,
  [451] = 298,
  [452] = 302,
  [453] = 296,
  [454] = 299,
  [455] = 296,
  [456] = 295,
  [457] = 302,
  [458] = 295,
  [459] = 302,
  [460] = 296,
  [461] = 299,
  [462] = 302,
  [463] = 298,
  [464] = 295,
  [465] = 295,
  [466] = 298,
  [467] = 296,
  [468] = 299,
  [469] = 299,
  [470] = 295,
  [471] = 298,
  [472] = 298,
  [473] = 299,
  [474] = 299,
  [475] = 298,
  [476] = 298,
  [477] = 302,
  [478] = 296,
  [479] = 295,
  [480] = 302,
  [481] = 295,
  [482] = 299,
  [483] = 302,
  [484] = 296,
  [485] = 296,
  [486] = 296,
  [487] = 295,
  [488] = 302,
  [489] = 302,
  [490] = 298,
  [491] = 295,
  [492] = 302,
  [493] = 299,
  [494] = 357,
  [495] = 295,
  [496] = 299,
  [497] = 296,
  [498] = 298,
  [499] = 499,
  [500] = 499,
  [501] = 499,
  [502] = 499,
  [503] = 499,
  [504] = 504,
  [505] = 301,
  [506] = 301,
  [507] = 499,
  [508] = 499,
  [509] = 499,
  [510] = 499,
  [511] = 499,
  [512] = 499,
  [513] = 499,
  [514] = 504,
  [515] = 499,
  [516] = 499,
  [517] = 499,
  [518] = 499,
  [519] = 499,
  [520] = 499,
  [521] = 499,
  [522] = 499,
  [523] = 499,
  [524] = 499,
  [525] = 499,
  [526] = 499,
  [527] = 499,
  [528] = 499,
  [529] = 499,
  [530] = 499,
  [531] = 499,
  [532] = 499,
  [533] = 499,
  [534] = 499,
  [535] = 499,
  [536] = 499,
  [537] = 504,
  [538] = 499,
  [539] = 499,
  [540] = 499,
  [541] = 499,
  [542] = 301,
  [543] = 504,
  [544] = 499,
  [545] = 499,
  [546] = 499,
  [547] = 499,
  [548] = 499,
  [549] = 301,
  [550] = 499,
  [551] = 551,
  [552] = 551,
  [553] = 553,
  [554] = 554,
  [555] = 555,
  [556] = 556,
  [557] = 557,
  [558] = 551,
  [559] = 551,
  [560] = 560,
  [561] = 554,
  [562] = 562,
  [563] = 563,
  [564] = 564,
  [565] = 562,
  [566] = 563,
  [567] = 564,
  [568] = 568,
  [569] = 551,
  [570] = 570,
  [571] = 571,
  [572] = 572,
  [573] = 573,
  [574] = 301,
  [575] = 555,
  [576] = 556,
  [577] = 577,
  [578] = 568,
  [579] = 577,
  [580] = 570,
  [581] = 571,
  [582] = 572,
  [583] = 555,
  [584] = 556,
  [585] = 585,
  [586] = 586,
  [587] = 577,
  [588] = 560,
  [589] = 554,
  [590] = 555,
  [591] = 568,
  [592] = 585,
  [593] = 301,
  [594] = 557,
  [595] = 585,
  [596] = 572,
  [597] = 573,
  [598] = 556,
  [599] = 557,
  [600] = 600,
  [601] = 568,
  [602] = 602,
  [603] = 603,
  [604] = 573,
  [605] = 600,
  [606] = 606,
  [607] = 600,
  [608] = 606,
  [609] = 609,
  [610] = 555,
  [611] = 611,
  [612] = 572,
  [613] = 606,
  [614] = 600,
  [615] = 573,
  [616] = 556,
  [617] = 586,
  [618] = 553,
  [619] = 553,
  [620] = 571,
  [621] = 568,
  [622] = 570,
  [623] = 577,
  [624] = 553,
  [625] = 571,
  [626] = 551,
  [627] = 555,
  [628] = 556,
  [629] = 568,
  [630] = 562,
  [631] = 563,
  [632] = 606,
  [633] = 633,
  [634] = 560,
  [635] = 555,
  [636] = 556,
  [637] = 568,
  [638] = 553,
  [639] = 639,
  [640] = 570,
  [641] = 555,
  [642] = 554,
  [643] = 556,
  [644] = 644,
  [645] = 562,
  [646] = 564,
  [647] = 568,
  [648] = 563,
  [649] = 564,
  [650] = 570,
  [651] = 571,
  [652] = 557,
  [653] = 572,
  [654] = 577,
  [655] = 585,
  [656] = 573,
  [657] = 570,
  [658] = 571,
  [659] = 572,
  [660] = 660,
  [661] = 555,
  [662] = 564,
  [663] = 563,
  [664] = 556,
  [665] = 564,
  [666] = 563,
  [667] = 577,
  [668] = 562,
  [669] = 577,
  [670] = 562,
  [671] = 560,
  [672] = 577,
  [673] = 560,
  [674] = 606,
  [675] = 600,
  [676] = 606,
  [677] = 577,
  [678] = 560,
  [679] = 577,
  [680] = 553,
  [681] = 577,
  [682] = 577,
  [683] = 554,
  [684] = 577,
  [685] = 553,
  [686] = 554,
  [687] = 551,
  [688] = 606,
  [689] = 600,
  [690] = 554,
  [691] = 557,
  [692] = 600,
  [693] = 573,
  [694] = 585,
  [695] = 551,
  [696] = 557,
  [697] = 560,
  [698] = 554,
  [699] = 553,
  [700] = 573,
  [701] = 586,
  [702] = 606,
  [703] = 562,
  [704] = 563,
  [705] = 600,
  [706] = 573,
  [707] = 585,
  [708] = 562,
  [709] = 557,
  [710] = 564,
  [711] = 585,
  [712] = 554,
  [713] = 563,
  [714] = 568,
  [715] = 585,
  [716] = 577,
  [717] = 564,
  [718] = 557,
  [719] = 573,
  [720] = 551,
  [721] = 570,
  [722] = 571,
  [723] = 723,
  [724] = 600,
  [725] = 572,
  [726] = 570,
  [727] = 572,
  [728] = 606,
  [729] = 571,
  [730] = 570,
  [731] = 553,
  [732] = 554,
  [733] = 555,
  [734] = 557,
  [735] = 556,
  [736] = 568,
  [737] = 585,
  [738] = 573,
  [739] = 600,
  [740] = 557,
  [741] = 551,
  [742] = 564,
  [743] = 577,
  [744] = 555,
  [745] = 571,
  [746] = 572,
  [747] = 606,
  [748] = 556,
  [749] = 568,
  [750] = 553,
  [751] = 577,
  [752] = 562,
  [753] = 563,
  [754] = 564,
  [755] = 553,
  [756] = 585,
  [757] = 577,
  [758] = 585,
  [759] = 555,
  [760] = 556,
  [761] = 586,
  [762] = 573,
  [763] = 600,
  [764] = 577,
  [765] = 606,
  [766] = 563,
  [767] = 562,
  [768] = 551,
  [769] = 568,
  [770] = 554,
  [771] = 551,
  [772] = 557,
  [773] = 585,
  [774] = 560,
  [775] = 577,
  [776] = 585,
  [777] = 573,
  [778] = 555,
  [779] = 553,
  [780] = 556,
  [781] = 573,
  [782] = 600,
  [783] = 551,
  [784] = 568,
  [785] = 560,
  [786] = 606,
  [787] = 600,
  [788] = 606,
  [789] = 611,
  [790] = 553,
  [791] = 791,
  [792] = 562,
  [793] = 563,
  [794] = 564,
  [795] = 602,
  [796] = 560,
  [797] = 554,
  [798] = 557,
  [799] = 555,
  [800] = 562,
  [801] = 556,
  [802] = 570,
  [803] = 571,
  [804] = 572,
  [805] = 568,
  [806] = 563,
  [807] = 564,
  [808] = 577,
  [809] = 603,
  [810] = 555,
  [811] = 606,
  [812] = 556,
  [813] = 568,
  [814] = 633,
  [815] = 600,
  [816] = 609,
  [817] = 585,
  [818] = 555,
  [819] = 573,
  [820] = 556,
  [821] = 568,
  [822] = 573,
  [823] = 553,
  [824] = 572,
  [825] = 644,
  [826] = 554,
  [827] = 555,
  [828] = 556,
  [829] = 571,
  [830] = 660,
  [831] = 551,
  [832] = 568,
  [833] = 585,
  [834] = 554,
  [835] = 557,
  [836] = 557,
  [837] = 577,
  [838] = 585,
  [839] = 573,
  [840] = 560,
  [841] = 562,
  [842] = 563,
  [843] = 577,
  [844] = 600,
  [845] = 585,
  [846] = 564,
  [847] = 573,
  [848] = 606,
  [849] = 577,
  [850] = 553,
  [851] = 554,
  [852] = 557,
  [853] = 600,
  [854] = 577,
  [855] = 606,
  [856] = 570,
  [857] = 571,
  [858] = 572,
  [859] = 577,
  [860] = 551,
  [861] = 553,
  [862] = 577,
  [863] = 554,
  [864] = 606,
  [865] = 600,
  [866] = 573,
  [867] = 585,
  [868] = 570,
  [869] = 557,
  [870] = 554,
  [871] = 553,
  [872] = 553,
  [873] = 577,
  [874] = 570,
  [875] = 585,
  [876] = 606,
  [877] = 600,
  [878] = 878,
  [879] = 573,
  [880] = 557,
  [881] = 585,
  [882] = 557,
  [883] = 568,
  [884] = 554,
  [885] = 560,
  [886] = 555,
  [887] = 571,
  [888] = 573,
  [889] = 557,
  [890] = 572,
  [891] = 560,
  [892] = 572,
  [893] = 571,
  [894] = 570,
  [895] = 723,
  [896] = 600,
  [897] = 606,
  [898] = 556,
  [899] = 568,
  [900] = 600,
  [901] = 553,
  [902] = 560,
  [903] = 562,
  [904] = 563,
  [905] = 564,
  [906] = 557,
  [907] = 551,
  [908] = 554,
  [909] = 564,
  [910] = 563,
  [911] = 555,
  [912] = 570,
  [913] = 556,
  [914] = 571,
  [915] = 568,
  [916] = 660,
  [917] = 572,
  [918] = 577,
  [919] = 551,
  [920] = 562,
  [921] = 563,
  [922] = 560,
  [923] = 564,
  [924] = 563,
  [925] = 555,
  [926] = 556,
  [927] = 568,
  [928] = 562,
  [929] = 585,
  [930] = 577,
  [931] = 562,
  [932] = 573,
  [933] = 560,
  [934] = 555,
  [935] = 564,
  [936] = 585,
  [937] = 556,
  [938] = 606,
  [939] = 570,
  [940] = 571,
  [941] = 568,
  [942] = 600,
  [943] = 606,
  [944] = 573,
  [945] = 553,
  [946] = 600,
  [947] = 606,
  [948] = 572,
  [949] = 551,
  [950] = 555,
  [951] = 572,
  [952] = 556,
  [953] = 568,
  [954] = 555,
  [955] = 554,
  [956] = 611,
  [957] = 611,
  [958] = 560,
  [959] = 557,
  [960] = 551,
  [961] = 577,
  [962] = 555,
  [963] = 562,
  [964] = 553,
  [965] = 556,
  [966] = 563,
  [967] = 568,
  [968] = 564,
  [969] = 585,
  [970] = 554,
  [971] = 556,
  [972] = 573,
  [973] = 570,
  [974] = 560,
  [975] = 600,
  [976] = 577,
  [977] = 571,
  [978] = 978,
  [979] = 555,
  [980] = 556,
  [981] = 551,
  [982] = 568,
  [983] = 557,
  [984] = 551,
  [985] = 571,
  [986] = 572,
  [987] = 606,
  [988] = 585,
  [989] = 553,
  [990] = 577,
  [991] = 570,
  [992] = 992,
  [993] = 564,
  [994] = 563,
  [995] = 568,
  [996] = 560,
  [997] = 573,
  [998] = 562,
  [999] = 556,
  [1000] = 556,
  [1001] = 577,
  [1002] = 560,
  [1003] = 577,
  [1004] = 878,
  [1005] = 562,
  [1006] = 562,
  [1007] = 563,
  [1008] = 564,
  [1009] = 553,
  [1010] = 551,
  [1011] = 606,
  [1012] = 563,
  [1013] = 600,
  [1014] = 573,
  [1015] = 585,
  [1016] = 570,
  [1017] = 571,
  [1018] = 555,
  [1019] = 557,
  [1020] = 572,
  [1021] = 554,
  [1022] = 723,
  [1023] = 644,
  [1024] = 1024,
  [1025] = 600,
  [1026] = 568,
  [1027] = 1027,
  [1028] = 553,
  [1029] = 606,
  [1030] = 600,
  [1031] = 573,
  [1032] = 585,
  [1033] = 556,
  [1034] = 557,
  [1035] = 554,
  [1036] = 1036,
  [1037] = 560,
  [1038] = 555,
  [1039] = 556,
  [1040] = 555,
  [1041] = 560,
  [1042] = 563,
  [1043] = 564,
  [1044] = 557,
  [1045] = 551,
  [1046] = 568,
  [1047] = 562,
  [1048] = 633,
  [1049] = 551,
  [1050] = 568,
  [1051] = 556,
  [1052] = 563,
  [1053] = 555,
  [1054] = 553,
  [1055] = 606,
  [1056] = 564,
  [1057] = 878,
  [1058] = 568,
  [1059] = 570,
  [1060] = 556,
  [1061] = 570,
  [1062] = 571,
  [1063] = 551,
  [1064] = 551,
  [1065] = 572,
  [1066] = 555,
  [1067] = 555,
  [1068] = 556,
  [1069] = 568,
  [1070] = 571,
  [1071] = 791,
  [1072] = 606,
  [1073] = 600,
  [1074] = 554,
  [1075] = 557,
  [1076] = 602,
  [1077] = 572,
  [1078] = 1078,
  [1079] = 603,
  [1080] = 555,
  [1081] = 573,
  [1082] = 570,
  [1083] = 571,
  [1084] = 572,
  [1085] = 571,
  [1086] = 556,
  [1087] = 570,
  [1088] = 572,
  [1089] = 568,
  [1090] = 553,
  [1091] = 611,
  [1092] = 554,
  [1093] = 568,
  [1094] = 585,
  [1095] = 1095,
  [1096] = 560,
  [1097] = 562,
  [1098] = 563,
  [1099] = 577,
  [1100] = 556,
  [1101] = 560,
  [1102] = 564,
  [1103] = 557,
  [1104] = 555,
  [1105] = 878,
  [1106] = 555,
  [1107] = 556,
  [1108] = 568,
  [1109] = 577,
  [1110] = 1110,
  [1111] = 609,
  [1112] = 564,
  [1113] = 570,
  [1114] = 571,
  [1115] = 572,
  [1116] = 572,
  [1117] = 571,
  [1118] = 570,
  [1119] = 551,
  [1120] = 568,
  [1121] = 556,
  [1122] = 563,
  [1123] = 555,
  [1124] = 557,
  [1125] = 553,
  [1126] = 557,
  [1127] = 639,
  [1128] = 560,
  [1129] = 564,
  [1130] = 562,
  [1131] = 585,
  [1132] = 586,
  [1133] = 577,
  [1134] = 577,
  [1135] = 553,
  [1136] = 562,
  [1137] = 563,
  [1138] = 564,
  [1139] = 606,
  [1140] = 600,
  [1141] = 560,
  [1142] = 1142,
  [1143] = 570,
  [1144] = 573,
  [1145] = 562,
  [1146] = 723,
  [1147] = 571,
  [1148] = 572,
  [1149] = 585,
  [1150] = 557,
  [1151] = 554,
  [1152] = 573,
  [1153] = 553,
  [1154] = 600,
  [1155] = 606,
  [1156] = 600,
  [1157] = 573,
  [1158] = 585,
  [1159] = 557,
  [1160] = 560,
  [1161] = 554,
  [1162] = 791,
  [1163] = 554,
  [1164] = 1164,
  [1165] = 978,
  [1166] = 606,
  [1167] = 577,
  [1168] = 560,
  [1169] = 609,
  [1170] = 551,
  [1171] = 606,
  [1172] = 568,
  [1173] = 553,
  [1174] = 554,
  [1175] = 556,
  [1176] = 577,
  [1177] = 555,
  [1178] = 568,
  [1179] = 555,
  [1180] = 556,
  [1181] = 562,
  [1182] = 563,
  [1183] = 564,
  [1184] = 570,
  [1185] = 571,
  [1186] = 572,
  [1187] = 585,
  [1188] = 556,
  [1189] = 572,
  [1190] = 557,
  [1191] = 568,
  [1192] = 555,
  [1193] = 551,
  [1194] = 551,
  [1195] = 791,
  [1196] = 602,
  [1197] = 1078,
  [1198] = 573,
  [1199] = 600,
  [1200] = 571,
  [1201] = 606,
  [1202] = 570,
  [1203] = 585,
  [1204] = 573,
  [1205] = 560,
  [1206] = 603,
  [1207] = 600,
  [1208] = 551,
  [1209] = 791,
  [1210] = 1095,
  [1211] = 609,
  [1212] = 555,
  [1213] = 556,
  [1214] = 553,
  [1215] = 572,
  [1216] = 562,
  [1217] = 571,
  [1218] = 570,
  [1219] = 563,
  [1220] = 564,
  [1221] = 577,
  [1222] = 564,
  [1223] = 564,
  [1224] = 563,
  [1225] = 577,
  [1226] = 633,
  [1227] = 554,
  [1228] = 562,
  [1229] = 577,
  [1230] = 577,
  [1231] = 553,
  [1232] = 606,
  [1233] = 600,
  [1234] = 570,
  [1235] = 573,
  [1236] = 571,
  [1237] = 585,
  [1238] = 572,
  [1239] = 557,
  [1240] = 554,
  [1241] = 568,
  [1242] = 568,
  [1243] = 557,
  [1244] = 556,
  [1245] = 563,
  [1246] = 560,
  [1247] = 562,
  [1248] = 585,
  [1249] = 555,
  [1250] = 553,
  [1251] = 978,
  [1252] = 551,
  [1253] = 560,
  [1254] = 568,
  [1255] = 556,
  [1256] = 560,
  [1257] = 551,
  [1258] = 606,
  [1259] = 562,
  [1260] = 563,
  [1261] = 564,
  [1262] = 553,
  [1263] = 551,
  [1264] = 577,
  [1265] = 602,
  [1266] = 600,
  [1267] = 573,
  [1268] = 573,
  [1269] = 600,
  [1270] = 570,
  [1271] = 571,
  [1272] = 572,
  [1273] = 555,
  [1274] = 555,
  [1275] = 606,
  [1276] = 551,
  [1277] = 551,
  [1278] = 1278,
  [1279] = 577,
  [1280] = 556,
  [1281] = 978,
  [1282] = 577,
  [1283] = 560,
  [1284] = 562,
  [1285] = 1285,
  [1286] = 577,
  [1287] = 585,
  [1288] = 577,
  [1289] = 560,
  [1290] = 1290,
  [1291] = 553,
  [1292] = 554,
  [1293] = 606,
  [1294] = 600,
  [1295] = 563,
  [1296] = 1296,
  [1297] = 564,
  [1298] = 573,
  [1299] = 551,
  [1300] = 562,
  [1301] = 554,
  [1302] = 585,
  [1303] = 563,
  [1304] = 557,
  [1305] = 564,
  [1306] = 554,
  [1307] = 1095,
  [1308] = 568,
  [1309] = 572,
  [1310] = 577,
  [1311] = 557,
  [1312] = 571,
  [1313] = 570,
  [1314] = 570,
  [1315] = 564,
  [1316] = 562,
  [1317] = 563,
  [1318] = 571,
  [1319] = 572,
  [1320] = 554,
  [1321] = 551,
  [1322] = 564,
  [1323] = 553,
  [1324] = 606,
  [1325] = 551,
  [1326] = 557,
  [1327] = 600,
  [1328] = 1328,
  [1329] = 563,
  [1330] = 570,
  [1331] = 571,
  [1332] = 572,
  [1333] = 573,
  [1334] = 570,
  [1335] = 1335,
  [1336] = 585,
  [1337] = 560,
  [1338] = 577,
  [1339] = 562,
  [1340] = 571,
  [1341] = 609,
  [1342] = 562,
  [1343] = 563,
  [1344] = 564,
  [1345] = 577,
  [1346] = 1095,
  [1347] = 633,
  [1348] = 570,
  [1349] = 571,
  [1350] = 572,
  [1351] = 572,
  [1352] = 551,
  [1353] = 557,
  [1354] = 577,
  [1355] = 553,
  [1356] = 606,
  [1357] = 600,
  [1358] = 1358,
  [1359] = 573,
  [1360] = 585,
  [1361] = 557,
  [1362] = 554,
  [1363] = 577,
  [1364] = 577,
  [1365] = 560,
  [1366] = 554,
  [1367] = 553,
  [1368] = 560,
  [1369] = 551,
  [1370] = 562,
  [1371] = 1371,
  [1372] = 563,
  [1373] = 564,
  [1374] = 606,
  [1375] = 600,
  [1376] = 603,
  [1377] = 573,
  [1378] = 570,
  [1379] = 571,
  [1380] = 585,
  [1381] = 572,
  [1382] = 603,
  [1383] = 1078,
  [1384] = 585,
  [1385] = 551,
  [1386] = 577,
  [1387] = 560,
  [1388] = 562,
  [1389] = 557,
  [1390] = 791,
  [1391] = 577,
  [1392] = 555,
  [1393] = 556,
  [1394] = 563,
  [1395] = 553,
  [1396] = 560,
  [1397] = 562,
  [1398] = 563,
  [1399] = 564,
  [1400] = 570,
  [1401] = 571,
  [1402] = 573,
  [1403] = 600,
  [1404] = 606,
  [1405] = 568,
  [1406] = 577,
  [1407] = 1407,
  [1408] = 572,
  [1409] = 557,
  [1410] = 554,
  [1411] = 554,
  [1412] = 644,
  [1413] = 568,
  [1414] = 564,
  [1415] = 554,
  [1416] = 553,
  [1417] = 553,
  [1418] = 606,
  [1419] = 600,
  [1420] = 573,
  [1421] = 585,
  [1422] = 557,
  [1423] = 553,
  [1424] = 570,
  [1425] = 577,
  [1426] = 553,
  [1427] = 572,
  [1428] = 560,
  [1429] = 562,
  [1430] = 563,
  [1431] = 564,
  [1432] = 606,
  [1433] = 551,
  [1434] = 600,
  [1435] = 573,
  [1436] = 585,
  [1437] = 570,
  [1438] = 571,
  [1439] = 572,
  [1440] = 554,
  [1441] = 557,
  [1442] = 1442,
  [1443] = 554,
  [1444] = 571,
  [1445] = 1445,
  [1446] = 570,
  [1447] = 564,
  [1448] = 1448,
  [1449] = 660,
  [1450] = 553,
  [1451] = 606,
  [1452] = 563,
  [1453] = 562,
  [1454] = 600,
  [1455] = 573,
  [1456] = 1456,
  [1457] = 577,
  [1458] = 585,
  [1459] = 1459,
  [1460] = 571,
  [1461] = 551,
  [1462] = 572,
  [1463] = 560,
  [1464] = 562,
  [1465] = 1465,
  [1466] = 563,
  [1467] = 564,
  [1468] = 570,
  [1469] = 1078,
  [1470] = 571,
  [1471] = 577,
  [1472] = 557,
  [1473] = 554,
  [1474] = 585,
  [1475] = 572,
  [1476] = 554,
  [1477] = 553,
  [1478] = 577,
  [1479] = 553,
  [1480] = 560,
  [1481] = 660,
  [1482] = 606,
  [1483] = 551,
  [1484] = 555,
  [1485] = 600,
  [1486] = 606,
  [1487] = 600,
  [1488] = 560,
  [1489] = 573,
  [1490] = 585,
  [1491] = 573,
  [1492] = 557,
  [1493] = 600,
  [1494] = 562,
  [1495] = 563,
  [1496] = 564,
  [1497] = 570,
  [1498] = 571,
  [1499] = 572,
  [1500] = 554,
  [1501] = 551,
  [1502] = 573,
  [1503] = 554,
  [1504] = 606,
  [1505] = 585,
  [1506] = 644,
  [1507] = 557,
  [1508] = 602,
  [1509] = 1509,
  [1510] = 1509,
  [1511] = 1511,
  [1512] = 1512,
  [1513] = 1513,
  [1514] = 1514,
  [1515] = 1514,
  [1516] = 1516,
  [1517] = 1509,
  [1518] = 1513,
  [1519] = 1512,
  [1520] = 1511,
  [1521] = 1512,
  [1522] = 1511,
  [1523] = 1509,
  [1524] = 1509,
  [1525] = 1516,
  [1526] = 1516,
  [1527] = 301,
  [1528] = 1509,
  [1529] = 1516,
  [1530] = 1511,
  [1531] = 1512,
  [1532] = 1514,
  [1533] = 1513,
  [1534] = 1513,
  [1535] = 1513,
  [1536] = 1514,
  [1537] = 1512,
  [1538] = 1511,
  [1539] = 1509,
  [1540] = 1514,
  [1541] = 1514,
  [1542] = 1513,
  [1543] = 1516,
  [1544] = 1516,
  [1545] = 1509,
  [1546] = 1511,
  [1547] = 1512,
  [1548] = 1513,
  [1549] = 1514,
  [1550] = 1514,
  [1551] = 1512,
  [1552] = 1513,
  [1553] = 1509,
  [1554] = 1516,
  [1555] = 1512,
  [1556] = 1511,
  [1557] = 1516,
  [1558] = 1511,
  [1559] = 1509,
  [1560] = 1511,
  [1561] = 1512,
  [1562] = 1513,
  [1563] = 1514,
  [1564] = 1509,
  [1565] = 1516,
  [1566] = 1509,
  [1567] = 1516,
  [1568] = 1514,
  [1569] = 1513,
  [1570] = 1512,
  [1571] = 1511,
  [1572] = 1511,
  [1573] = 1512,
  [1574] = 1513,
  [1575] = 1514,
  [1576] = 1516,
  [1577] = 1509,
  [1578] = 1516,
  [1579] = 1509,
  [1580] = 1509,
  [1581] = 1516,
  [1582] = 301,
  [1583] = 1514,
  [1584] = 1513,
  [1585] = 1512,
  [1586] = 1511,
  [1587] = 1511,
  [1588] = 1512,
  [1589] = 1513,
  [1590] = 1514,
  [1591] = 1509,
  [1592] = 1516,
  [1593] = 1516,
  [1594] = 1509,
  [1595] = 1511,
  [1596] = 1512,
  [1597] = 1513,
  [1598] = 1514,
  [1599] = 1509,
  [1600] = 1509,
  [1601] = 1514,
  [1602] = 1513,
  [1603] = 1516,
  [1604] = 1516,
  [1605] = 1511,
  [1606] = 1512,
  [1607] = 1511,
  [1608] = 1512,
  [1609] = 1513,
  [1610] = 1514,
  [1611] = 1514,
  [1612] = 1509,
  [1613] = 1512,
  [1614] = 1516,
  [1615] = 1513,
  [1616] = 1513,
  [1617] = 1511,
  [1618] = 1512,
  [1619] = 1511,
  [1620] = 1514,
  [1621] = 1511,
  [1622] = 1512,
  [1623] = 1514,
  [1624] = 1516,
  [1625] = 1509,
  [1626] = 1513,
  [1627] = 1514,
  [1628] = 1509,
  [1629] = 1516,
  [1630] = 1511,
  [1631] = 1512,
  [1632] = 1514,
  [1633] = 1513,
  [1634] = 1513,
  [1635] = 1514,
  [1636] = 1512,
  [1637] = 1511,
  [1638] = 1516,
  [1639] = 1514,
  [1640] = 1509,
  [1641] = 1516,
  [1642] = 1516,
  [1643] = 1511,
  [1644] = 1512,
  [1645] = 1511,
  [1646] = 1514,
  [1647] = 1512,
  [1648] = 1513,
  [1649] = 1513,
  [1650] = 1513,
  [1651] = 1516,
  [1652] = 1514,
  [1653] = 1514,
  [1654] = 1509,
  [1655] = 1512,
  [1656] = 1511,
  [1657] = 1509,
  [1658] = 1516,
  [1659] = 1514,
  [1660] = 1514,
  [1661] = 1513,
  [1662] = 1513,
  [1663] = 1511,
  [1664] = 1512,
  [1665] = 1516,
  [1666] = 1509,
  [1667] = 1513,
  [1668] = 1514,
  [1669] = 1512,
  [1670] = 1509,
  [1671] = 1516,
  [1672] = 1511,
  [1673] = 1512,
  [1674] = 1511,
  [1675] = 1512,
  [1676] = 1513,
  [1677] = 1514,
  [1678] = 1509,
  [1679] = 1516,
  [1680] = 1511,
  [1681] = 1509,
  [1682] = 1516,
  [1683] = 1512,
  [1684] = 1513,
  [1685] = 1514,
  [1686] = 1516,
  [1687] = 1514,
  [1688] = 1509,
  [1689] = 1509,
  [1690] = 1516,
  [1691] = 1511,
  [1692] = 1513,
  [1693] = 1514,
  [1694] = 1511,
  [1695] = 1513,
  [1696] = 1512,
  [1697] = 1512,
  [1698] = 1512,
  [1699] = 1513,
  [1700] = 1514,
  [1701] = 1511,
  [1702] = 1511,
  [1703] = 1516,
  [1704] = 1509,
  [1705] = 1516,
  [1706] = 1513,
  [1707] = 1509,
  [1708] = 1513,
  [1709] = 1516,
  [1710] = 1509,
  [1711] = 1511,
  [1712] = 1516,
  [1713] = 1509,
  [1714] = 1714,
  [1715] = 1512,
  [1716] = 1512,
  [1717] = 1512,
  [1718] = 1511,
  [1719] = 1511,
  [1720] = 1512,
  [1721] = 1513,
  [1722] = 1514,
  [1723] = 1509,
  [1724] = 1516,
  [1725] = 1516,
  [1726] = 1511,
  [1727] = 1512,
  [1728] = 1509,
  [1729] = 1513,
  [1730] = 1514,
  [1731] = 1509,
  [1732] = 1513,
  [1733] = 1514,
  [1734] = 1516,
  [1735] = 1511,
  [1736] = 1514,
  [1737] = 1513,
  [1738] = 1512,
  [1739] = 1511,
  [1740] = 1512,
  [1741] = 1514,
  [1742] = 1514,
  [1743] = 1513,
  [1744] = 1511,
  [1745] = 1513,
  [1746] = 1514,
  [1747] = 1512,
  [1748] = 1513,
  [1749] = 1514,
  [1750] = 1509,
  [1751] = 1516,
  [1752] = 1509,
  [1753] = 1516,
  [1754] = 1511,
  [1755] = 1511,
  [1756] = 1509,
  [1757] = 1516,
  [1758] = 1512,
  [1759] = 1511,
  [1760] = 1714,
  [1761] = 1513,
  [1762] = 1516,
  [1763] = 1512,
  [1764] = 1514,
  [1765] = 1512,
  [1766] = 1509,
  [1767] = 1767,
  [1768] = 1509,
  [1769] = 1511,
  [1770] = 1516,
  [1771] = 1767,
  [1772] = 1513,
  [1773] = 1773,
  [1774] = 1774,
  [1775] = 1775,
  [1776] = 1776,
  [1777] = 1774,
  [1778] = 1778,
  [1779] = 1779,
  [1780] = 1780,
  [1781] = 1773,
  [1782] = 1782,
  [1783] = 1783,
  [1784] = 1784,
  [1785] = 1785,
  [1786] = 1775,
  [1787] = 1774,
  [1788] = 1779,
  [1789] = 1780,
  [1790] = 1790,
  [1791] = 1791,
  [1792] = 1790,
  [1793] = 1767,
  [1794] = 1791,
  [1795] = 1791,
  [1796] = 1790,
  [1797] = 1780,
  [1798] = 1785,
  [1799] = 1778,
  [1800] = 1776,
  [1801] = 1779,
  [1802] = 1784,
  [1803] = 1783,
  [1804] = 1782,
  [1805] = 1805,
  [1806] = 1773,
  [1807] = 1805,
  [1808] = 1805,
  [1809] = 1775,
  [1810] = 1778,
  [1811] = 1785,
  [1812] = 1773,
  [1813] = 1782,
  [1814] = 1773,
  [1815] = 1767,
  [1816] = 1784,
  [1817] = 1783,
  [1818] = 1783,
  [1819] = 1774,
  [1820] = 1773,
  [1821] = 1784,
  [1822] = 1782,
  [1823] = 1805,
  [1824] = 1785,
  [1825] = 1782,
  [1826] = 1775,
  [1827] = 1776,
  [1828] = 1774,
  [1829] = 1779,
  [1830] = 1780,
  [1831] = 1790,
  [1832] = 1776,
  [1833] = 1791,
  [1834] = 1790,
  [1835] = 1791,
  [1836] = 1780,
  [1837] = 1779,
  [1838] = 1774,
  [1839] = 1775,
  [1840] = 1785,
  [1841] = 1784,
  [1842] = 1776,
  [1843] = 1783,
  [1844] = 1782,
  [1845] = 1773,
  [1846] = 1778,
  [1847] = 1805,
  [1848] = 1783,
  [1849] = 1784,
  [1850] = 1778,
  [1851] = 1791,
  [1852] = 1790,
  [1853] = 1780,
  [1854] = 1779,
  [1855] = 1785,
  [1856] = 1774,
  [1857] = 1775,
  [1858] = 1776,
  [1859] = 1785,
  [1860] = 1775,
  [1861] = 1774,
  [1862] = 1784,
  [1863] = 1779,
  [1864] = 1780,
  [1865] = 1790,
  [1866] = 1866,
  [1867] = 1778,
  [1868] = 1791,
  [1869] = 1778,
  [1870] = 1783,
  [1871] = 1782,
  [1872] = 1791,
  [1873] = 1790,
  [1874] = 1780,
  [1875] = 1779,
  [1876] = 1778,
  [1877] = 1774,
  [1878] = 1773,
  [1879] = 1775,
  [1880] = 1791,
  [1881] = 1790,
  [1882] = 1780,
  [1883] = 1776,
  [1884] = 1779,
  [1885] = 1774,
  [1886] = 1785,
  [1887] = 1775,
  [1888] = 1785,
  [1889] = 1784,
  [1890] = 1783,
  [1891] = 1782,
  [1892] = 1773,
  [1893] = 1784,
  [1894] = 1778,
  [1895] = 1805,
  [1896] = 1783,
  [1897] = 1791,
  [1898] = 1805,
  [1899] = 1782,
  [1900] = 1773,
  [1901] = 1778,
  [1902] = 1776,
  [1903] = 1778,
  [1904] = 1780,
  [1905] = 1805,
  [1906] = 1791,
  [1907] = 1790,
  [1908] = 1776,
  [1909] = 301,
  [1910] = 1780,
  [1911] = 1779,
  [1912] = 1778,
  [1913] = 1779,
  [1914] = 1774,
  [1915] = 1775,
  [1916] = 1785,
  [1917] = 1774,
  [1918] = 1775,
  [1919] = 1785,
  [1920] = 1791,
  [1921] = 1790,
  [1922] = 1791,
  [1923] = 1790,
  [1924] = 1780,
  [1925] = 1779,
  [1926] = 1780,
  [1927] = 1774,
  [1928] = 1775,
  [1929] = 1785,
  [1930] = 1784,
  [1931] = 1783,
  [1932] = 1782,
  [1933] = 1773,
  [1934] = 1779,
  [1935] = 1805,
  [1936] = 1774,
  [1937] = 1775,
  [1938] = 1785,
  [1939] = 1784,
  [1940] = 1776,
  [1941] = 1784,
  [1942] = 1778,
  [1943] = 1783,
  [1944] = 1782,
  [1945] = 1784,
  [1946] = 1791,
  [1947] = 1773,
  [1948] = 1790,
  [1949] = 1783,
  [1950] = 1780,
  [1951] = 1779,
  [1952] = 1805,
  [1953] = 1774,
  [1954] = 1790,
  [1955] = 1783,
  [1956] = 1782,
  [1957] = 1773,
  [1958] = 1805,
  [1959] = 1773,
  [1960] = 1778,
  [1961] = 1805,
  [1962] = 1775,
  [1963] = 1714,
  [1964] = 1778,
  [1965] = 1791,
  [1966] = 1790,
  [1967] = 1780,
  [1968] = 1791,
  [1969] = 1805,
  [1970] = 1790,
  [1971] = 1785,
  [1972] = 1780,
  [1973] = 1779,
  [1974] = 1774,
  [1975] = 1775,
  [1976] = 1785,
  [1977] = 1784,
  [1978] = 1773,
  [1979] = 1783,
  [1980] = 1782,
  [1981] = 1779,
  [1982] = 1778,
  [1983] = 1773,
  [1984] = 1784,
  [1985] = 1782,
  [1986] = 1805,
  [1987] = 1783,
  [1988] = 1775,
  [1989] = 1778,
  [1990] = 1785,
  [1991] = 1784,
  [1992] = 1782,
  [1993] = 1782,
  [1994] = 1783,
  [1995] = 1783,
  [1996] = 1784,
  [1997] = 1782,
  [1998] = 1773,
  [1999] = 1805,
  [2000] = 1791,
  [2001] = 1790,
  [2002] = 1785,
  [2003] = 1780,
  [2004] = 1775,
  [2005] = 1778,
  [2006] = 1779,
  [2007] = 1774,
  [2008] = 1775,
  [2009] = 1785,
  [2010] = 1784,
  [2011] = 1774,
  [2012] = 1783,
  [2013] = 1782,
  [2014] = 1773,
  [2015] = 1791,
  [2016] = 1779,
  [2017] = 1790,
  [2018] = 1714,
  [2019] = 1774,
  [2020] = 1805,
  [2021] = 1780,
  [2022] = 1790,
  [2023] = 1780,
  [2024] = 1778,
  [2025] = 1791,
  [2026] = 1773,
  [2027] = 1778,
  [2028] = 1778,
  [2029] = 1805,
  [2030] = 1791,
  [2031] = 1790,
  [2032] = 1791,
  [2033] = 1790,
  [2034] = 1791,
  [2035] = 1790,
  [2036] = 1780,
  [2037] = 1779,
  [2038] = 1774,
  [2039] = 1775,
  [2040] = 1785,
  [2041] = 1784,
  [2042] = 1780,
  [2043] = 1783,
  [2044] = 1782,
  [2045] = 1773,
  [2046] = 1779,
  [2047] = 1782,
  [2048] = 2048,
  [2049] = 1805,
  [2050] = 1779,
  [2051] = 1774,
  [2052] = 1775,
  [2053] = 1785,
  [2054] = 1784,
  [2055] = 1783,
  [2056] = 1782,
  [2057] = 1778,
  [2058] = 1776,
  [2059] = 1780,
  [2060] = 1773,
  [2061] = 1778,
  [2062] = 1783,
  [2063] = 1805,
  [2064] = 1784,
  [2065] = 1714,
  [2066] = 1805,
  [2067] = 1778,
  [2068] = 1774,
  [2069] = 1779,
  [2070] = 1791,
  [2071] = 1785,
  [2072] = 1776,
  [2073] = 1774,
  [2074] = 1791,
  [2075] = 1790,
  [2076] = 1780,
  [2077] = 1779,
  [2078] = 1775,
  [2079] = 1785,
  [2080] = 1784,
  [2081] = 1774,
  [2082] = 1775,
  [2083] = 1783,
  [2084] = 1785,
  [2085] = 1784,
  [2086] = 1783,
  [2087] = 1782,
  [2088] = 1775,
  [2089] = 1773,
  [2090] = 1790,
  [2091] = 1805,
  [2092] = 1785,
  [2093] = 1780,
  [2094] = 1782,
  [2095] = 1779,
  [2096] = 1778,
  [2097] = 1784,
  [2098] = 1774,
  [2099] = 1783,
  [2100] = 1782,
  [2101] = 1791,
  [2102] = 1790,
  [2103] = 1780,
  [2104] = 1779,
  [2105] = 1773,
  [2106] = 1775,
  [2107] = 1774,
  [2108] = 1775,
  [2109] = 1785,
  [2110] = 1784,
  [2111] = 1783,
  [2112] = 1782,
  [2113] = 1785,
  [2114] = 1784,
  [2115] = 1773,
  [2116] = 1773,
  [2117] = 1805,
  [2118] = 1767,
  [2119] = 1805,
  [2120] = 1805,
  [2121] = 1778,
  [2122] = 1776,
  [2123] = 1783,
  [2124] = 301,
  [2125] = 1775,
  [2126] = 1714,
  [2127] = 1782,
  [2128] = 1805,
  [2129] = 1791,
  [2130] = 1790,
  [2131] = 1780,
  [2132] = 1779,
  [2133] = 1774,
  [2134] = 1775,
  [2135] = 1785,
  [2136] = 1784,
  [2137] = 1783,
  [2138] = 1773,
  [2139] = 1805,
  [2140] = 1778,
  [2141] = 1805,
  [2142] = 1782,
  [2143] = 1773,
  [2144] = 1774,
  [2145] = 1779,
  [2146] = 1805,
  [2147] = 1778,
  [2148] = 1778,
  [2149] = 2048,
  [2150] = 1780,
  [2151] = 1805,
  [2152] = 1773,
  [2153] = 1791,
  [2154] = 1790,
  [2155] = 1780,
  [2156] = 1779,
  [2157] = 1774,
  [2158] = 1790,
  [2159] = 1775,
  [2160] = 1785,
  [2161] = 1791,
  [2162] = 1790,
  [2163] = 1784,
  [2164] = 1783,
  [2165] = 1791,
  [2166] = 1782,
  [2167] = 1773,
  [2168] = 1790,
  [2169] = 1780,
  [2170] = 1805,
  [2171] = 1776,
  [2172] = 1779,
  [2173] = 1774,
  [2174] = 1775,
  [2175] = 1785,
  [2176] = 1784,
  [2177] = 1783,
  [2178] = 1782,
  [2179] = 1782,
  [2180] = 1773,
  [2181] = 1776,
  [2182] = 1783,
  [2183] = 1780,
  [2184] = 1784,
  [2185] = 1805,
  [2186] = 1805,
  [2187] = 1779,
  [2188] = 1791,
  [2189] = 1778,
  [2190] = 1774,
  [2191] = 1775,
  [2192] = 1785,
  [2193] = 1784,
  [2194] = 1785,
  [2195] = 1783,
  [2196] = 1782,
  [2197] = 1775,
  [2198] = 1773,
  [2199] = 1774,
  [2200] = 1779,
  [2201] = 1805,
  [2202] = 1778,
  [2203] = 1776,
  [2204] = 2204,
  [2205] = 1780,
  [2206] = 1778,
  [2207] = 1773,
  [2208] = 1791,
  [2209] = 1805,
  [2210] = 1790,
  [2211] = 1780,
  [2212] = 1779,
  [2213] = 1774,
  [2214] = 1775,
  [2215] = 1782,
  [2216] = 1785,
  [2217] = 1783,
  [2218] = 1784,
  [2219] = 1783,
  [2220] = 1782,
  [2221] = 1784,
  [2222] = 1785,
  [2223] = 1778,
  [2224] = 1773,
  [2225] = 1775,
  [2226] = 2204,
  [2227] = 1774,
  [2228] = 1779,
  [2229] = 1780,
  [2230] = 1791,
  [2231] = 1790,
  [2232] = 1780,
  [2233] = 1790,
  [2234] = 1791,
  [2235] = 1779,
  [2236] = 1790,
  [2237] = 1791,
  [2238] = 1775,
  [2239] = 1785,
  [2240] = 1805,
  [2241] = 1778,
  [2242] = 1784,
  [2243] = 1783,
  [2244] = 1782,
  [2245] = 1773,
  [2246] = 1776,
  [2247] = 2247,
  [2248] = 2248,
  [2249] = 1791,
  [2250] = 1805,
  [2251] = 1790,
  [2252] = 1780,
  [2253] = 1779,
  [2254] = 1774,
  [2255] = 1775,
  [2256] = 1785,
  [2257] = 1784,
  [2258] = 1773,
  [2259] = 1778,
  [2260] = 1782,
  [2261] = 1783,
  [2262] = 1784,
  [2263] = 1785,
  [2264] = 1775,
  [2265] = 1774,
  [2266] = 1779,
  [2267] = 1780,
  [2268] = 1790,
  [2269] = 1791,
  [2270] = 1778,
  [2271] = 1783,
  [2272] = 1776,
  [2273] = 1782,
  [2274] = 1805,
  [2275] = 1773,
  [2276] = 1805,
  [2277] = 1805,
  [2278] = 1776,
  [2279] = 1773,
  [2280] = 1791,
  [2281] = 1778,
  [2282] = 1773,
  [2283] = 1782,
  [2284] = 1776,
  [2285] = 1782,
  [2286] = 1783,
  [2287] = 1784,
  [2288] = 1783,
  [2289] = 1784,
  [2290] = 1785,
  [2291] = 1785,
  [2292] = 1775,
  [2293] = 1774,
  [2294] = 1790,
  [2295] = 1780,
  [2296] = 1779,
  [2297] = 1775,
  [2298] = 1774,
  [2299] = 1779,
  [2300] = 1780,
  [2301] = 1779,
  [2302] = 1791,
  [2303] = 1790,
  [2304] = 1791,
  [2305] = 1790,
  [2306] = 1780,
  [2307] = 1779,
  [2308] = 1774,
  [2309] = 1780,
  [2310] = 1775,
  [2311] = 1785,
  [2312] = 1784,
  [2313] = 1783,
  [2314] = 1790,
  [2315] = 1782,
  [2316] = 1791,
  [2317] = 1773,
  [2318] = 1767,
  [2319] = 1774,
  [2320] = 1775,
  [2321] = 1785,
  [2322] = 1791,
  [2323] = 1778,
  [2324] = 1778,
  [2325] = 1776,
  [2326] = 1805,
  [2327] = 1805,
  [2328] = 1790,
  [2329] = 1784,
  [2330] = 1780,
  [2331] = 1779,
  [2332] = 1774,
  [2333] = 1776,
  [2334] = 1778,
  [2335] = 1775,
  [2336] = 1805,
  [2337] = 1773,
  [2338] = 1785,
  [2339] = 1784,
  [2340] = 1783,
  [2341] = 1782,
  [2342] = 1778,
  [2343] = 1782,
  [2344] = 1783,
  [2345] = 1784,
  [2346] = 1785,
  [2347] = 1773,
  [2348] = 1791,
  [2349] = 1790,
  [2350] = 1780,
  [2351] = 1779,
  [2352] = 1774,
  [2353] = 1775,
  [2354] = 1774,
  [2355] = 1775,
  [2356] = 1785,
  [2357] = 1784,
  [2358] = 1783,
  [2359] = 1779,
  [2360] = 1780,
  [2361] = 1783,
  [2362] = 1805,
  [2363] = 1782,
  [2364] = 1773,
  [2365] = 1790,
  [2366] = 1805,
  [2367] = 1773,
  [2368] = 1791,
  [2369] = 1782,
  [2370] = 1773,
  [2371] = 1778,
  [2372] = 1778,
  [2373] = 1791,
  [2374] = 1782,
  [2375] = 1776,
  [2376] = 1805,
  [2377] = 1783,
  [2378] = 1784,
  [2379] = 1773,
  [2380] = 1782,
  [2381] = 1785,
  [2382] = 1783,
  [2383] = 1784,
  [2384] = 1785,
  [2385] = 1775,
  [2386] = 1775,
  [2387] = 1774,
  [2388] = 1779,
  [2389] = 1780,
  [2390] = 1774,
  [2391] = 1790,
  [2392] = 1791,
  [2393] = 1779,
  [2394] = 1778,
  [2395] = 1778,
  [2396] = 1780,
  [2397] = 1805,
  [2398] = 1773,
  [2399] = 1782,
  [2400] = 1783,
  [2401] = 1784,
  [2402] = 1778,
  [2403] = 1785,
  [2404] = 1775,
  [2405] = 1774,
  [2406] = 1790,
  [2407] = 1779,
  [2408] = 1780,
  [2409] = 1790,
  [2410] = 1791,
  [2411] = 1714,
  [2412] = 1714,
  [2413] = 1767,
  [2414] = 1767,
  [2415] = 1767,
  [2416] = 1714,
  [2417] = 1714,
  [2418] = 1767,
  [2419] = 1767,
  [2420] = 1767,
  [2421] = 1714,
  [2422] = 1714,
  [2423] = 301,
  [2424] = 301,
  [2425] = 301,
  [2426] = 1767,
  [2427] = 301,
  [2428] = 301,
  [2429] = 1714,
  [2430] = 301,
  [2431] = 1767,
  [2432] = 1714,
  [2433] = 1767,
  [2434] = 1714,
  [2435] = 301,
  [2436] = 1767,
  [2437] = 1714,
  [2438] = 1714,
  [2439] = 1767,
  [2440] = 2440,
  [2441] = 1714,
  [2442] = 301,
  [2443] = 2440,
  [2444] = 2444,
  [2445] = 2445,
  [2446] = 2440,
  [2447] = 2440,
  [2448] = 2440,
  [2449] = 2440,
  [2450] = 2440,
  [2451] = 2445,
  [2452] = 1767,
  [2453] = 2444,
  [2454] = 2440,
  [2455] = 2445,
  [2456] = 2444,
  [2457] = 301,
  [2458] = 2445,
  [2459] = 2444,
  [2460] = 2460,
  [2461] = 2461,
  [2462] = 2461,
  [2463] = 1767,
  [2464] = 1714,
  [2465] = 2461,
  [2466] = 301,
  [2467] = 301,
  [2468] = 2461,
  [2469] = 301,
  [2470] = 2461,
  [2471] = 2460,
  [2472] = 2461,
  [2473] = 301,
  [2474] = 301,
  [2475] = 2460,
  [2476] = 301,
  [2477] = 2460,
  [2478] = 2460,
  [2479] = 1714,
  [2480] = 2480,
  [2481] = 301,
  [2482] = 301,
  [2483] = 2480,
  [2484] = 301,
  [2485] = 301,
  [2486] = 301,
  [2487] = 1767,
  [2488] = 2488,
  [2489] = 1767,
  [2490] = 1714,
  [2491] = 2491,
  [2492] = 2480,
  [2493] = 2480,
  [2494] = 1714,
  [2495] = 2488,
  [2496] = 1714,
  [2497] = 2491,
  [2498] = 1714,
  [2499] = 1767,
  [2500] = 1714,
  [2501] = 1714,
  [2502] = 1714,
  [2503] = 1767,
  [2504] = 1714,
  [2505] = 1767,
  [2506] = 1714,
  [2507] = 1767,
  [2508] = 1767,
  [2509] = 1767,
  [2510] = 2491,
  [2511] = 2488,
  [2512] = 1714,
  [2513] = 2488,
  [2514] = 1714,
  [2515] = 1767,
  [2516] = 1714,
  [2517] = 1714,
  [2518] = 1767,
  [2519] = 2488,
  [2520] = 2491,
  [2521] = 1767,
  [2522] = 2491,
  [2523] = 1714,
  [2524] = 1767,
  [2525] = 1714,
  [2526] = 1714,
  [2527] = 1714,
  [2528] = 1767,
  [2529] = 2529,
  [2530] = 2529,
  [2531] = 2529,
  [2532] = 2529,
  [2533] = 2529,
  [2534] = 2529,
  [2535] = 2529,
  [2536] = 2536,
  [2537] = 2488,
  [2538] = 2538,
  [2539] = 2539,
  [2540] = 1714,
  [2541] = 2541,
  [2542] = 2542,
  [2543] = 2543,
  [2544] = 2543,
  [2545] = 2539,
  [2546] = 2546,
  [2547] = 2491,
  [2548] = 2548,
  [2549] = 2549,
  [2550] = 2549,
  [2551] = 2546,
  [2552] = 2548,
  [2553] = 2553,
  [2554] = 2553,
  [2555] = 2538,
  [2556] = 2541,
  [2557] = 2536,
  [2558] = 2542,
  [2559] = 2559,
  [2560] = 2542,
  [2561] = 2536,
  [2562] = 2562,
  [2563] = 2543,
  [2564] = 2549,
  [2565] = 2548,
  [2566] = 2539,
  [2567] = 2548,
  [2568] = 2546,
  [2569] = 2539,
  [2570] = 2541,
  [2571] = 2542,
  [2572] = 2553,
  [2573] = 2543,
  [2574] = 2549,
  [2575] = 2553,
  [2576] = 2541,
  [2577] = 2539,
  [2578] = 2546,
  [2579] = 2538,
  [2580] = 2538,
  [2581] = 2553,
  [2582] = 2546,
  [2583] = 2538,
  [2584] = 2549,
  [2585] = 2548,
  [2586] = 2536,
  [2587] = 2541,
  [2588] = 2536,
  [2589] = 2542,
  [2590] = 2543,
  [2591] = 2591,
  [2592] = 2591,
  [2593] = 2559,
  [2594] = 2591,
  [2595] = 2591,
  [2596] = 2445,
  [2597] = 2562,
  [2598] = 2559,
  [2599] = 2444,
  [2600] = 2562,
  [2601] = 2601,
  [2602] = 2602,
  [2603] = 2602,
  [2604] = 2602,
  [2605] = 2602,
  [2606] = 2602,
  [2607] = 2602,
  [2608] = 2602,
  [2609] = 2602,
  [2610] = 2602,
  [2611] = 2602,
  [2612] = 2602,
  [2613] = 2602,
  [2614] = 2602,
  [2615] = 2602,
  [2616] = 2602,
  [2617] = 2602,
  [2618] = 2602,
  [2619] = 2602,
  [2620] = 2602,
  [2621] = 2602,
  [2622] = 2602,
  [2623] = 2602,
  [2624] = 2602,
  [2625] = 2602,
  [2626] = 2602,
  [2627] = 2627,
  [2628] = 2602,
  [2629] = 2602,
  [2630] = 2602,
  [2631] = 2602,
  [2632] = 2602,
  [2633] = 2633,
  [2634] = 2602,
  [2635] = 2602,
  [2636] = 2602,
  [2637] = 2637,
  [2638] = 2602,
  [2639] = 2602,
  [2640] = 2602,
  [2641] = 2602,
  [2642] = 2642,
  [2643] = 2602,
  [2644] = 2644,
  [2645] = 2602,
  [2646] = 2602,
  [2647] = 2602,
  [2648] = 2602,
  [2649] = 2602,
  [2650] = 2602,
  [2651] = 2651,
  [2652] = 2651,
  [2653] = 2651,
  [2654] = 2651,
  [2655] = 2651,
  [2656] = 2651,
  [2657] = 2651,
  [2658] = 2651,
  [2659] = 2651,
  [2660] = 2651,
  [2661] = 2651,
  [2662] = 2651,
  [2663] = 2651,
  [2664] = 2651,
  [2665] = 2651,
  [2666] = 2651,
  [2667] = 2651,
  [2668] = 2651,
  [2669] = 2651,
  [2670] = 2651,
  [2671] = 2651,
  [2672] = 2651,
  [2673] = 2651,
  [2674] = 2651,
  [2675] = 2651,
  [2676] = 2651,
  [2677] = 2651,
  [2678] = 2651,
  [2679] = 2651,
  [2680] = 2651,
  [2681] = 2651,
  [2682] = 2651,
  [2683] = 2651,
  [2684] = 2480,
  [2685] = 2651,
  [2686] = 2651,
  [2687] = 2651,
  [2688] = 2651,
  [2689] = 2651,
  [2690] = 2651,
  [2691] = 2651,
  [2692] = 2651,
  [2693] = 2651,
  [2694] = 2651,
  [2695] = 2651,
  [2696] = 2651,
  [2697] = 2651,
  [2698] = 2651,
  [2699] = 2651,
  [2700] = 2700,
  [2701] = 2701,
  [2702] = 2702,
  [2703] = 2703,
  [2704] = 2700,
  [2705] = 2701,
  [2706] = 2702,
  [2707] = 2700,
  [2708] = 2700,
  [2709] = 2709,
  [2710] = 2701,
  [2711] = 2709,
  [2712] = 2709,
  [2713] = 2703,
  [2714] = 2703,
  [2715] = 2702,
  [2716] = 2701,
  [2717] = 2701,
  [2718] = 2700,
  [2719] = 2703,
  [2720] = 2701,
  [2721] = 2702,
  [2722] = 2703,
  [2723] = 2709,
  [2724] = 2709,
  [2725] = 2709,
  [2726] = 2709,
  [2727] = 2703,
  [2728] = 2702,
  [2729] = 2700,
  [2730] = 2700,
  [2731] = 2709,
  [2732] = 2703,
  [2733] = 2700,
  [2734] = 2701,
  [2735] = 2700,
  [2736] = 2702,
  [2737] = 2709,
  [2738] = 2701,
  [2739] = 2702,
  [2740] = 2700,
  [2741] = 2702,
  [2742] = 2700,
  [2743] = 2700,
  [2744] = 2709,
  [2745] = 2703,
  [2746] = 2701,
  [2747] = 2709,
  [2748] = 2701,
  [2749] = 2702,
  [2750] = 2703,
  [2751] = 2709,
  [2752] = 2703,
  [2753] = 2701,
  [2754] = 2702,
  [2755] = 2702,
  [2756] = 2703,
  [2757] = 2709,
  [2758] = 2700,
  [2759] = 2709,
  [2760] = 2703,
  [2761] = 2700,
  [2762] = 2701,
  [2763] = 2702,
  [2764] = 2703,
  [2765] = 2700,
  [2766] = 2709,
  [2767] = 2701,
  [2768] = 2702,
  [2769] = 2701,
  [2770] = 2709,
  [2771] = 2703,
  [2772] = 2702,
  [2773] = 2700,
  [2774] = 2709,
  [2775] = 2700,
  [2776] = 2700,
  [2777] = 2703,
  [2778] = 2701,
  [2779] = 2703,
  [2780] = 2702,
  [2781] = 2702,
  [2782] = 2709,
  [2783] = 2703,
  [2784] = 2701,
  [2785] = 2700,
  [2786] = 2701,
  [2787] = 2703,
  [2788] = 2702,
  [2789] = 2709,
  [2790] = 2702,
  [2791] = 2701,
  [2792] = 2702,
  [2793] = 2701,
  [2794] = 2702,
  [2795] = 2709,
  [2796] = 2700,
  [2797] = 2703,
  [2798] = 2709,
  [2799] = 2709,
  [2800] = 2700,
  [2801] = 2709,
  [2802] = 2700,
  [2803] = 2703,
  [2804] = 2701,
  [2805] = 2702,
  [2806] = 2700,
  [2807] = 2709,
  [2808] = 2703,
  [2809] = 2702,
  [2810] = 2700,
  [2811] = 2701,
  [2812] = 2702,
  [2813] = 2702,
  [2814] = 2701,
  [2815] = 2700,
  [2816] = 2703,
  [2817] = 2703,
  [2818] = 2491,
  [2819] = 2701,
  [2820] = 2703,
  [2821] = 2700,
  [2822] = 2709,
  [2823] = 2709,
  [2824] = 2709,
  [2825] = 2700,
  [2826] = 2709,
  [2827] = 2703,
  [2828] = 2703,
  [2829] = 2701,
  [2830] = 2702,
  [2831] = 2701,
  [2832] = 2702,
  [2833] = 2709,
  [2834] = 2700,
  [2835] = 2702,
  [2836] = 2700,
  [2837] = 2702,
  [2838] = 2703,
  [2839] = 2701,
  [2840] = 2701,
  [2841] = 2702,
  [2842] = 2702,
  [2843] = 2702,
  [2844] = 2709,
  [2845] = 2702,
  [2846] = 2701,
  [2847] = 2703,
  [2848] = 2701,
  [2849] = 2701,
  [2850] = 2703,
  [2851] = 2701,
  [2852] = 2702,
  [2853] = 2703,
  [2854] = 2488,
  [2855] = 2703,
  [2856] = 2703,
  [2857] = 2709,
  [2858] = 2709,
  [2859] = 2700,
  [2860] = 2703,
  [2861] = 2709,
  [2862] = 2700,
  [2863] = 2709,
  [2864] = 2701,
  [2865] = 2701,
  [2866] = 2700,
  [2867] = 2702,
  [2868] = 2703,
  [2869] = 2709,
  [2870] = 2703,
  [2871] = 2701,
  [2872] = 2700,
  [2873] = 2700,
  [2874] = 2702,
  [2875] = 2701,
  [2876] = 2702,
  [2877] = 2703,
  [2878] = 2700,
  [2879] = 2701,
  [2880] = 2703,
  [2881] = 2709,
  [2882] = 1714,
  [2883] = 2700,
  [2884] = 2709,
  [2885] = 2709,
  [2886] = 2700,
  [2887] = 2700,
  [2888] = 2703,
  [2889] = 2709,
  [2890] = 2703,
  [2891] = 2701,
  [2892] = 2701,
  [2893] = 2702,
  [2894] = 2701,
  [2895] = 2702,
  [2896] = 2703,
  [2897] = 2897,
  [2898] = 2709,
  [2899] = 2709,
  [2900] = 2702,
  [2901] = 2700,
  [2902] = 2702,
  [2903] = 2701,
  [2904] = 2703,
  [2905] = 2709,
  [2906] = 2700,
  [2907] = 2700,
  [2908] = 2701,
  [2909] = 2709,
  [2910] = 2703,
  [2911] = 2701,
  [2912] = 2702,
  [2913] = 2702,
  [2914] = 2701,
  [2915] = 2700,
  [2916] = 2701,
  [2917] = 2702,
  [2918] = 2702,
  [2919] = 2703,
  [2920] = 2703,
  [2921] = 2709,
  [2922] = 2700,
  [2923] = 2700,
  [2924] = 2924,
  [2925] = 2925,
  [2926] = 2926,
  [2927] = 2927,
  [2928] = 2928,
  [2929] = 2929,
  [2930] = 2930,
  [2931] = 2931,
  [2932] = 2932,
  [2933] = 2933,
  [2934] = 2933,
  [2935] = 2929,
  [2936] = 2926,
  [2937] = 2932,
  [2938] = 2931,
  [2939] = 2930,
  [2940] = 2924,
  [2941] = 2927,
  [2942] = 2925,
  [2943] = 2943,
  [2944] = 2928,
  [2945] = 2945,
  [2946] = 2945,
  [2947] = 2943,
  [2948] = 2559,
  [2949] = 2928,
  [2950] = 2928,
  [2951] = 2945,
  [2952] = 2943,
  [2953] = 2928,
  [2954] = 2928,
  [2955] = 2591,
  [2956] = 2956,
  [2957] = 2957,
  [2958] = 2928,
  [2959] = 2928,
  [2960] = 2943,
  [2961] = 2928,
  [2962] = 2956,
  [2963] = 2957,
  [2964] = 2928,
  [2965] = 2928,
  [2966] = 2966,
  [2967] = 2966,
  [2968] = 2968,
  [2969] = 2966,
  [2970] = 2966,
  [2971] = 2971,
  [2972] = 2972,
  [2973] = 2930,
  [2974] = 2931,
  [2975] = 2932,
  [2976] = 2966,
  [2977] = 2971,
  [2978] = 2971,
  [2979] = 2933,
  [2980] = 2929,
  [2981] = 2926,
  [2982] = 2982,
  [2983] = 2983,
  [2984] = 2927,
  [2985] = 2985,
  [2986] = 2986,
  [2987] = 2987,
  [2988] = 2988,
  [2989] = 2924,
  [2990] = 2990,
  [2991] = 2991,
  [2992] = 2992,
  [2993] = 2924,
  [2994] = 2966,
  [2995] = 2971,
  [2996] = 2996,
  [2997] = 2997,
  [2998] = 2998,
  [2999] = 2999,
  [3000] = 3000,
  [3001] = 3001,
  [3002] = 3002,
  [3003] = 3003,
  [3004] = 3004,
  [3005] = 3005,
  [3006] = 3006,
  [3007] = 3007,
  [3008] = 3008,
  [3009] = 3009,
  [3010] = 2971,
  [3011] = 3011,
  [3012] = 3012,
  [3013] = 3013,
  [3014] = 3014,
  [3015] = 2926,
  [3016] = 2929,
  [3017] = 2933,
  [3018] = 3018,
  [3019] = 3019,
  [3020] = 3020,
  [3021] = 3021,
  [3022] = 2966,
  [3023] = 3023,
  [3024] = 3024,
  [3025] = 3025,
  [3026] = 3026,
  [3027] = 3027,
  [3028] = 2932,
  [3029] = 2931,
  [3030] = 2930,
  [3031] = 3031,
  [3032] = 2925,
  [3033] = 3033,
  [3034] = 3034,
  [3035] = 3035,
  [3036] = 3013,
  [3037] = 3037,
  [3038] = 3038,
  [3039] = 3039,
  [3040] = 3040,
  [3041] = 2971,
  [3042] = 3042,
  [3043] = 2956,
  [3044] = 3000,
  [3045] = 2966,
  [3046] = 3046,
  [3047] = 3047,
  [3048] = 3048,
  [3049] = 3049,
  [3050] = 3050,
  [3051] = 3051,
  [3052] = 3052,
  [3053] = 3053,
  [3054] = 3033,
  [3055] = 2966,
  [3056] = 3031,
  [3057] = 2966,
  [3058] = 2957,
  [3059] = 3059,
  [3060] = 2924,
  [3061] = 3024,
  [3062] = 3011,
  [3063] = 2999,
  [3064] = 2997,
  [3065] = 2966,
  [3066] = 2926,
  [3067] = 2929,
  [3068] = 2933,
  [3069] = 3000,
  [3070] = 2932,
  [3071] = 2931,
  [3072] = 2966,
  [3073] = 2930,
  [3074] = 3000,
  [3075] = 2990,
  [3076] = 2966,
  [3077] = 2987,
  [3078] = 2985,
  [3079] = 2966,
  [3080] = 2966,
  [3081] = 2927,
  [3082] = 2966,
  [3083] = 3039,
  [3084] = 2957,
  [3085] = 2925,
  [3086] = 2966,
  [3087] = 2956,
  [3088] = 2982,
  [3089] = 2983,
  [3090] = 2971,
  [3091] = 2927,
  [3092] = 2925,
  [3093] = 2971,
  [3094] = 2925,
  [3095] = 2968,
  [3096] = 2927,
  [3097] = 2971,
  [3098] = 2966,
  [3099] = 3000,
  [3100] = 2957,
  [3101] = 2956,
  [3102] = 2971,
  [3103] = 2972,
  [3104] = 2986,
  [3105] = 2971,
  [3106] = 2988,
  [3107] = 3107,
  [3108] = 3108,
  [3109] = 3109,
  [3110] = 3110,
  [3111] = 3111,
  [3112] = 2991,
  [3113] = 2992,
  [3114] = 3000,
  [3115] = 2996,
  [3116] = 3116,
  [3117] = 2998,
  [3118] = 3001,
  [3119] = 3002,
  [3120] = 3120,
  [3121] = 3121,
  [3122] = 3122,
  [3123] = 3123,
  [3124] = 3124,
  [3125] = 3125,
  [3126] = 3003,
  [3127] = 3107,
  [3128] = 3128,
  [3129] = 3129,
  [3130] = 2966,
  [3131] = 3131,
  [3132] = 3132,
  [3133] = 3133,
  [3134] = 2971,
  [3135] = 3108,
  [3136] = 3109,
  [3137] = 3110,
  [3138] = 3111,
  [3139] = 3059,
  [3140] = 3004,
  [3141] = 3053,
  [3142] = 3005,
  [3143] = 3006,
  [3144] = 3007,
  [3145] = 3000,
  [3146] = 3008,
  [3147] = 3009,
  [3148] = 3148,
  [3149] = 3012,
  [3150] = 2966,
  [3151] = 3014,
  [3152] = 3018,
  [3153] = 3019,
  [3154] = 3154,
  [3155] = 2966,
  [3156] = 3020,
  [3157] = 3021,
  [3158] = 3023,
  [3159] = 3025,
  [3160] = 3034,
  [3161] = 3035,
  [3162] = 3037,
  [3163] = 3038,
  [3164] = 3040,
  [3165] = 3042,
  [3166] = 3116,
  [3167] = 3046,
  [3168] = 3047,
  [3169] = 3048,
  [3170] = 3049,
  [3171] = 3050,
  [3172] = 3051,
  [3173] = 2930,
  [3174] = 2931,
  [3175] = 2932,
  [3176] = 3052,
  [3177] = 3120,
  [3178] = 3121,
  [3179] = 2971,
  [3180] = 3013,
  [3181] = 3039,
  [3182] = 3122,
  [3183] = 2933,
  [3184] = 3027,
  [3185] = 2929,
  [3186] = 2926,
  [3187] = 3000,
  [3188] = 3123,
  [3189] = 3124,
  [3190] = 3125,
  [3191] = 3026,
  [3192] = 3128,
  [3193] = 3129,
  [3194] = 3131,
  [3195] = 3132,
  [3196] = 3133,
  [3197] = 3148,
  [3198] = 3154,
  [3199] = 3000,
  [3200] = 2971,
  [3201] = 2924,
  [3202] = 2966,
  [3203] = 2966,
  [3204] = 2966,
  [3205] = 3205,
  [3206] = 3206,
  [3207] = 3207,
  [3208] = 3208,
  [3209] = 2971,
  [3210] = 3205,
  [3211] = 3206,
  [3212] = 3207,
  [3213] = 3208,
  [3214] = 3000,
  [3215] = 2971,
  [3216] = 3000,
  [3217] = 3027,
  [3218] = 3026,
  [3219] = 2966,
  [3220] = 2966,
  [3221] = 2562,
  [3222] = 3027,
  [3223] = 3000,
  [3224] = 3000,
  [3225] = 3026,
  [3226] = 2966,
  [3227] = 3000,
  [3228] = 2966,
  [3229] = 3000,
  [3230] = 2971,
  [3231] = 2966,
  [3232] = 3039,
  [3233] = 3013,
  [3234] = 2971,
  [3235] = 2966,
  [3236] = 2971,
  [3237] = 3000,
  [3238] = 2966,
  [3239] = 3053,
  [3240] = 3000,
  [3241] = 3059,
  [3242] = 2957,
  [3243] = 2956,
  [3244] = 2966,
  [3245] = 2971,
  [3246] = 2444,
  [3247] = 2445,
  [3248] = 2966,
  [3249] = 2966,
  [3250] = 2971,
  [3251] = 3000,
  [3252] = 3000,
  [3253] = 2971,
  [3254] = 2966,
  [3255] = 2971,
  [3256] = 2966,
  [3257] = 2971,
  [3258] = 3059,
  [3259] = 3000,
  [3260] = 3000,
  [3261] = 3013,
  [3262] = 3039,
  [3263] = 3000,
  [3264] = 2966,
  [3265] = 2971,
  [3266] = 3026,
  [3267] = 3000,
  [3268] = 3027,
  [3269] = 2971,
  [3270] = 3000,
  [3271] = 3053,
  [3272] = 2966,
  [3273] = 3000,
  [3274] = 3000,
  [3275] = 2966,
  [3276] = 2966,
  [3277] = 3059,
  [3278] = 3027,
  [3279] = 3026,
  [3280] = 3053,
  [3281] = 3000,
  [3282] = 3000,
  [3283] = 3039,
  [3284] = 3026,
  [3285] = 3013,
  [3286] = 3039,
  [3287] = 2971,
  [3288] = 3059,
  [3289] = 3000,
  [3290] = 2966,
  [3291] = 2971,
  [3292] = 3039,
  [3293] = 3013,
  [3294] = 2971,
  [3295] = 2966,
  [3296] = 3027,
  [3297] = 3013,
  [3298] = 3053,
  [3299] = 3026,
  [3300] = 3000,
  [3301] = 3053,
  [3302] = 3059,
  [3303] = 3000,
  [3304] = 2966,
  [3305] = 2966,
  [3306] = 2971,
  [3307] = 2971,
  [3308] = 3000,
  [3309] = 2971,
  [3310] = 3053,
  [3311] = 3027,
  [3312] = 3059,
  [3313] = 3313,
  [3314] = 3314,
  [3315] = 2930,
  [3316] = 3111,
  [3317] = 2931,
  [3318] = 2932,
  [3319] = 3314,
  [3320] = 2956,
  [3321] = 3321,
  [3322] = 3314,
  [3323] = 3321,
  [3324] = 2998,
  [3325] = 2957,
  [3326] = 3321,
  [3327] = 3314,
  [3328] = 3321,
  [3329] = 2968,
  [3330] = 3321,
  [3331] = 3110,
  [3332] = 3109,
  [3333] = 3314,
  [3334] = 3046,
  [3335] = 3335,
  [3336] = 3321,
  [3337] = 2983,
  [3338] = 3314,
  [3339] = 2982,
  [3340] = 2972,
  [3341] = 2998,
  [3342] = 3321,
  [3343] = 3314,
  [3344] = 3107,
  [3345] = 2986,
  [3346] = 2933,
  [3347] = 2929,
  [3348] = 2926,
  [3349] = 2983,
  [3350] = 2988,
  [3351] = 3108,
  [3352] = 3109,
  [3353] = 3110,
  [3354] = 3111,
  [3355] = 2982,
  [3356] = 2927,
  [3357] = 2991,
  [3358] = 2992,
  [3359] = 3314,
  [3360] = 3108,
  [3361] = 2996,
  [3362] = 3314,
  [3363] = 3001,
  [3364] = 3002,
  [3365] = 3107,
  [3366] = 3003,
  [3367] = 2982,
  [3368] = 3107,
  [3369] = 3004,
  [3370] = 3205,
  [3371] = 3005,
  [3372] = 3006,
  [3373] = 2985,
  [3374] = 3007,
  [3375] = 3008,
  [3376] = 3009,
  [3377] = 2968,
  [3378] = 3012,
  [3379] = 3014,
  [3380] = 3108,
  [3381] = 3109,
  [3382] = 3110,
  [3383] = 3111,
  [3384] = 3018,
  [3385] = 3019,
  [3386] = 3020,
  [3387] = 3321,
  [3388] = 2957,
  [3389] = 3021,
  [3390] = 3116,
  [3391] = 3314,
  [3392] = 2956,
  [3393] = 3116,
  [3394] = 3321,
  [3395] = 3120,
  [3396] = 3023,
  [3397] = 3025,
  [3398] = 3121,
  [3399] = 3122,
  [3400] = 3123,
  [3401] = 3034,
  [3402] = 3321,
  [3403] = 3035,
  [3404] = 3037,
  [3405] = 2983,
  [3406] = 3124,
  [3407] = 3038,
  [3408] = 3125,
  [3409] = 3314,
  [3410] = 3116,
  [3411] = 3128,
  [3412] = 3129,
  [3413] = 3131,
  [3414] = 3321,
  [3415] = 3415,
  [3416] = 3040,
  [3417] = 3417,
  [3418] = 3042,
  [3419] = 2990,
  [3420] = 3314,
  [3421] = 3132,
  [3422] = 3321,
  [3423] = 3423,
  [3424] = 3133,
  [3425] = 3321,
  [3426] = 3426,
  [3427] = 3046,
  [3428] = 3120,
  [3429] = 3121,
  [3430] = 3430,
  [3431] = 3122,
  [3432] = 3123,
  [3433] = 3335,
  [3434] = 3124,
  [3435] = 3125,
  [3436] = 3148,
  [3437] = 3128,
  [3438] = 3314,
  [3439] = 3047,
  [3440] = 2927,
  [3441] = 3441,
  [3442] = 3314,
  [3443] = 3129,
  [3444] = 3128,
  [3445] = 3321,
  [3446] = 3048,
  [3447] = 3049,
  [3448] = 3050,
  [3449] = 3129,
  [3450] = 3131,
  [3451] = 2924,
  [3452] = 3154,
  [3453] = 3314,
  [3454] = 3051,
  [3455] = 3132,
  [3456] = 3111,
  [3457] = 2972,
  [3458] = 3110,
  [3459] = 3133,
  [3460] = 3124,
  [3461] = 3052,
  [3462] = 3321,
  [3463] = 3148,
  [3464] = 2997,
  [3465] = 3109,
  [3466] = 3314,
  [3467] = 3154,
  [3468] = 3120,
  [3469] = 3121,
  [3470] = 3122,
  [3471] = 2982,
  [3472] = 3123,
  [3473] = 3124,
  [3474] = 3125,
  [3475] = 3033,
  [3476] = 2986,
  [3477] = 3314,
  [3478] = 3031,
  [3479] = 3128,
  [3480] = 3024,
  [3481] = 3108,
  [3482] = 3321,
  [3483] = 3011,
  [3484] = 3129,
  [3485] = 3131,
  [3486] = 3131,
  [3487] = 2999,
  [3488] = 3132,
  [3489] = 2997,
  [3490] = 3011,
  [3491] = 2990,
  [3492] = 3133,
  [3493] = 2985,
  [3494] = 2987,
  [3495] = 2985,
  [3496] = 3415,
  [3497] = 2988,
  [3498] = 3024,
  [3499] = 3314,
  [3500] = 3321,
  [3501] = 3154,
  [3502] = 2991,
  [3503] = 3206,
  [3504] = 3205,
  [3505] = 3505,
  [3506] = 3207,
  [3507] = 2992,
  [3508] = 3321,
  [3509] = 3206,
  [3510] = 3415,
  [3511] = 3430,
  [3512] = 3207,
  [3513] = 2996,
  [3514] = 3208,
  [3515] = 3205,
  [3516] = 3206,
  [3517] = 3207,
  [3518] = 3001,
  [3519] = 3208,
  [3520] = 3002,
  [3521] = 3417,
  [3522] = 3148,
  [3523] = 3003,
  [3524] = 3423,
  [3525] = 3314,
  [3526] = 3125,
  [3527] = 3031,
  [3528] = 3033,
  [3529] = 3426,
  [3530] = 3321,
  [3531] = 3430,
  [3532] = 3052,
  [3533] = 3441,
  [3534] = 3321,
  [3535] = 3031,
  [3536] = 3004,
  [3537] = 3314,
  [3538] = 3005,
  [3539] = 3033,
  [3540] = 3006,
  [3541] = 3132,
  [3542] = 3133,
  [3543] = 3024,
  [3544] = 3107,
  [3545] = 3314,
  [3546] = 3321,
  [3547] = 2999,
  [3548] = 2925,
  [3549] = 3011,
  [3550] = 3321,
  [3551] = 2999,
  [3552] = 3321,
  [3553] = 3314,
  [3554] = 3007,
  [3555] = 2997,
  [3556] = 3008,
  [3557] = 3009,
  [3558] = 2999,
  [3559] = 2444,
  [3560] = 3012,
  [3561] = 2445,
  [3562] = 3321,
  [3563] = 3014,
  [3564] = 2968,
  [3565] = 2990,
  [3566] = 3321,
  [3567] = 3051,
  [3568] = 3321,
  [3569] = 3335,
  [3570] = 3335,
  [3571] = 3050,
  [3572] = 3321,
  [3573] = 3018,
  [3574] = 3314,
  [3575] = 2987,
  [3576] = 3019,
  [3577] = 3335,
  [3578] = 3020,
  [3579] = 2985,
  [3580] = 3314,
  [3581] = 3314,
  [3582] = 2987,
  [3583] = 2972,
  [3584] = 3154,
  [3585] = 3321,
  [3586] = 3314,
  [3587] = 3314,
  [3588] = 2986,
  [3589] = 3148,
  [3590] = 2930,
  [3591] = 3321,
  [3592] = 3321,
  [3593] = 2988,
  [3594] = 3021,
  [3595] = 2931,
  [3596] = 3314,
  [3597] = 3049,
  [3598] = 2932,
  [3599] = 2991,
  [3600] = 3048,
  [3601] = 2992,
  [3602] = 3047,
  [3603] = 2996,
  [3604] = 2998,
  [3605] = 3046,
  [3606] = 3001,
  [3607] = 3002,
  [3608] = 3003,
  [3609] = 3004,
  [3610] = 3005,
  [3611] = 3006,
  [3612] = 2933,
  [3613] = 3314,
  [3614] = 3007,
  [3615] = 3008,
  [3616] = 3441,
  [3617] = 3430,
  [3618] = 2929,
  [3619] = 2926,
  [3620] = 3426,
  [3621] = 3423,
  [3622] = 3417,
  [3623] = 3314,
  [3624] = 2445,
  [3625] = 2444,
  [3626] = 3009,
  [3627] = 3415,
  [3628] = 3012,
  [3629] = 3014,
  [3630] = 3018,
  [3631] = 3321,
  [3632] = 3019,
  [3633] = 3205,
  [3634] = 3020,
  [3635] = 3123,
  [3636] = 2968,
  [3637] = 3021,
  [3638] = 3023,
  [3639] = 3023,
  [3640] = 3025,
  [3641] = 3314,
  [3642] = 2925,
  [3643] = 3025,
  [3644] = 3321,
  [3645] = 3034,
  [3646] = 3314,
  [3647] = 3042,
  [3648] = 3035,
  [3649] = 3040,
  [3650] = 3038,
  [3651] = 3208,
  [3652] = 3034,
  [3653] = 3037,
  [3654] = 3314,
  [3655] = 3035,
  [3656] = 3038,
  [3657] = 3037,
  [3658] = 3038,
  [3659] = 3040,
  [3660] = 3037,
  [3661] = 3035,
  [3662] = 3042,
  [3663] = 3034,
  [3664] = 2990,
  [3665] = 3321,
  [3666] = 3314,
  [3667] = 3040,
  [3668] = 3042,
  [3669] = 3033,
  [3670] = 3314,
  [3671] = 3314,
  [3672] = 3025,
  [3673] = 3023,
  [3674] = 3031,
  [3675] = 3046,
  [3676] = 3047,
  [3677] = 3048,
  [3678] = 3314,
  [3679] = 3049,
  [3680] = 3024,
  [3681] = 3321,
  [3682] = 3050,
  [3683] = 3051,
  [3684] = 3684,
  [3685] = 3335,
  [3686] = 3314,
  [3687] = 3321,
  [3688] = 3011,
  [3689] = 3047,
  [3690] = 3021,
  [3691] = 2972,
  [3692] = 3048,
  [3693] = 3321,
  [3694] = 3049,
  [3695] = 3122,
  [3696] = 3121,
  [3697] = 2987,
  [3698] = 3050,
  [3699] = 3684,
  [3700] = 3116,
  [3701] = 3321,
  [3702] = 3314,
  [3703] = 3321,
  [3704] = 3052,
  [3705] = 3051,
  [3706] = 3206,
  [3707] = 3321,
  [3708] = 3207,
  [3709] = 3020,
  [3710] = 3335,
  [3711] = 3314,
  [3712] = 3314,
  [3713] = 3314,
  [3714] = 2986,
  [3715] = 2988,
  [3716] = 2991,
  [3717] = 3314,
  [3718] = 2924,
  [3719] = 3321,
  [3720] = 3321,
  [3721] = 3120,
  [3722] = 2997,
  [3723] = 3019,
  [3724] = 3002,
  [3725] = 3018,
  [3726] = 3014,
  [3727] = 3052,
  [3728] = 2983,
  [3729] = 2996,
  [3730] = 3012,
  [3731] = 2992,
  [3732] = 3208,
  [3733] = 3001,
  [3734] = 3314,
  [3735] = 3321,
  [3736] = 3009,
  [3737] = 3008,
  [3738] = 3321,
  [3739] = 3321,
  [3740] = 3006,
  [3741] = 3005,
  [3742] = 3004,
  [3743] = 3003,
  [3744] = 3744,
  [3745] = 2998,
  [3746] = 3007,
  [3747] = 3314,
  [3748] = 3321,
  [3749] = 2991,
  [3750] = 3008,
  [3751] = 2929,
  [3752] = 2988,
  [3753] = 2926,
  [3754] = 2991,
  [3755] = 2992,
  [3756] = 3756,
  [3757] = 3154,
  [3758] = 3033,
  [3759] = 3034,
  [3760] = 2996,
  [3761] = 3756,
  [3762] = 3025,
  [3763] = 3148,
  [3764] = 3035,
  [3765] = 3037,
  [3766] = 3756,
  [3767] = 3133,
  [3768] = 3132,
  [3769] = 3038,
  [3770] = 3756,
  [3771] = 3756,
  [3772] = 3131,
  [3773] = 3129,
  [3774] = 3128,
  [3775] = 2986,
  [3776] = 3125,
  [3777] = 3124,
  [3778] = 3123,
  [3779] = 3122,
  [3780] = 2990,
  [3781] = 3121,
  [3782] = 3034,
  [3783] = 3035,
  [3784] = 3001,
  [3785] = 3002,
  [3786] = 3120,
  [3787] = 3037,
  [3788] = 3040,
  [3789] = 3042,
  [3790] = 3756,
  [3791] = 2983,
  [3792] = 3756,
  [3793] = 3756,
  [3794] = 3756,
  [3795] = 3795,
  [3796] = 3033,
  [3797] = 3046,
  [3798] = 2933,
  [3799] = 3031,
  [3800] = 3800,
  [3801] = 3021,
  [3802] = 3800,
  [3803] = 3756,
  [3804] = 3009,
  [3805] = 2924,
  [3806] = 3047,
  [3807] = 3756,
  [3808] = 3038,
  [3809] = 3756,
  [3810] = 3024,
  [3811] = 3795,
  [3812] = 3154,
  [3813] = 3800,
  [3814] = 3756,
  [3815] = 3048,
  [3816] = 3756,
  [3817] = 2925,
  [3818] = 3756,
  [3819] = 3049,
  [3820] = 3040,
  [3821] = 3042,
  [3822] = 2983,
  [3823] = 2924,
  [3824] = 3050,
  [3825] = 3051,
  [3826] = 3108,
  [3827] = 3827,
  [3828] = 3116,
  [3829] = 2932,
  [3830] = 3011,
  [3831] = 3756,
  [3832] = 3148,
  [3833] = 2931,
  [3834] = 2930,
  [3835] = 3756,
  [3836] = 3756,
  [3837] = 3795,
  [3838] = 3052,
  [3839] = 3109,
  [3840] = 2999,
  [3841] = 2997,
  [3842] = 3025,
  [3843] = 3023,
  [3844] = 3756,
  [3845] = 3827,
  [3846] = 3110,
  [3847] = 2968,
  [3848] = 3756,
  [3849] = 3133,
  [3850] = 3795,
  [3851] = 3800,
  [3852] = 3756,
  [3853] = 3756,
  [3854] = 3132,
  [3855] = 3023,
  [3856] = 3111,
  [3857] = 3131,
  [3858] = 3205,
  [3859] = 3046,
  [3860] = 3756,
  [3861] = 2926,
  [3862] = 2929,
  [3863] = 3206,
  [3864] = 3207,
  [3865] = 3208,
  [3866] = 2933,
  [3867] = 3129,
  [3868] = 3128,
  [3869] = 3756,
  [3870] = 3021,
  [3871] = 3205,
  [3872] = 3008,
  [3873] = 3206,
  [3874] = 3207,
  [3875] = 3208,
  [3876] = 3024,
  [3877] = 2998,
  [3878] = 3047,
  [3879] = 3011,
  [3880] = 3125,
  [3881] = 3124,
  [3882] = 2932,
  [3883] = 2931,
  [3884] = 3006,
  [3885] = 2930,
  [3886] = 3123,
  [3887] = 3122,
  [3888] = 2999,
  [3889] = 2997,
  [3890] = 3020,
  [3891] = 3121,
  [3892] = 3019,
  [3893] = 3120,
  [3894] = 2990,
  [3895] = 3756,
  [3896] = 3756,
  [3897] = 2968,
  [3898] = 3111,
  [3899] = 2982,
  [3900] = 3756,
  [3901] = 3018,
  [3902] = 3756,
  [3903] = 3014,
  [3904] = 3110,
  [3905] = 3012,
  [3906] = 2987,
  [3907] = 3109,
  [3908] = 2956,
  [3909] = 2957,
  [3910] = 2927,
  [3911] = 3800,
  [3912] = 3108,
  [3913] = 2972,
  [3914] = 3756,
  [3915] = 3756,
  [3916] = 3048,
  [3917] = 3756,
  [3918] = 3756,
  [3919] = 3756,
  [3920] = 3049,
  [3921] = 3050,
  [3922] = 3051,
  [3923] = 3756,
  [3924] = 2972,
  [3925] = 3756,
  [3926] = 3003,
  [3927] = 2982,
  [3928] = 2957,
  [3929] = 2956,
  [3930] = 3107,
  [3931] = 3116,
  [3932] = 3756,
  [3933] = 3756,
  [3934] = 3756,
  [3935] = 3031,
  [3936] = 3004,
  [3937] = 3005,
  [3938] = 2986,
  [3939] = 3756,
  [3940] = 2988,
  [3941] = 3795,
  [3942] = 3756,
  [3943] = 3007,
  [3944] = 2998,
  [3945] = 3006,
  [3946] = 3020,
  [3947] = 3005,
  [3948] = 3007,
  [3949] = 2992,
  [3950] = 3004,
  [3951] = 3019,
  [3952] = 3018,
  [3953] = 3014,
  [3954] = 3756,
  [3955] = 3003,
  [3956] = 3756,
  [3957] = 3052,
  [3958] = 3002,
  [3959] = 3001,
  [3960] = 2925,
  [3961] = 2985,
  [3962] = 2996,
  [3963] = 3012,
  [3964] = 2985,
  [3965] = 3009,
  [3966] = 3756,
  [3967] = 2927,
  [3968] = 2987,
  [3969] = 3107,
  [3970] = 2925,
  [3971] = 3012,
  [3972] = 2983,
  [3973] = 2985,
  [3974] = 3974,
  [3975] = 3827,
  [3976] = 3974,
  [3977] = 3123,
  [3978] = 2957,
  [3979] = 3124,
  [3980] = 3033,
  [3981] = 3125,
  [3982] = 3001,
  [3983] = 3974,
  [3984] = 3002,
  [3985] = 3974,
  [3986] = 3108,
  [3987] = 3003,
  [3988] = 3031,
  [3989] = 3004,
  [3990] = 3005,
  [3991] = 3974,
  [3992] = 3208,
  [3993] = 3154,
  [3994] = 3111,
  [3995] = 3109,
  [3996] = 2925,
  [3997] = 3116,
  [3998] = 3208,
  [3999] = 3207,
  [4000] = 3206,
  [4001] = 2926,
  [4002] = 3154,
  [4003] = 3207,
  [4004] = 3974,
  [4005] = 2929,
  [4006] = 3206,
  [4007] = 2998,
  [4008] = 2932,
  [4009] = 2933,
  [4010] = 3006,
  [4011] = 3974,
  [4012] = 3974,
  [4013] = 3205,
  [4014] = 3024,
  [4015] = 2998,
  [4016] = 2956,
  [4017] = 3974,
  [4018] = 3148,
  [4019] = 3007,
  [4020] = 3120,
  [4021] = 4021,
  [4022] = 3121,
  [4023] = 3974,
  [4024] = 3205,
  [4025] = 2927,
  [4026] = 2982,
  [4027] = 3008,
  [4028] = 3974,
  [4029] = 3009,
  [4030] = 3974,
  [4031] = 2985,
  [4032] = 3122,
  [4033] = 2999,
  [4034] = 3974,
  [4035] = 3012,
  [4036] = 2927,
  [4037] = 4021,
  [4038] = 2968,
  [4039] = 3974,
  [4040] = 2999,
  [4041] = 3052,
  [4042] = 4042,
  [4043] = 3014,
  [4044] = 3018,
  [4045] = 2968,
  [4046] = 2957,
  [4047] = 3123,
  [4048] = 3128,
  [4049] = 3974,
  [4050] = 3974,
  [4051] = 3011,
  [4052] = 4042,
  [4053] = 3046,
  [4054] = 3124,
  [4055] = 3051,
  [4056] = 3050,
  [4057] = 3974,
  [4058] = 2990,
  [4059] = 3049,
  [4060] = 3974,
  [4061] = 3048,
  [4062] = 3047,
  [4063] = 3019,
  [4064] = 3020,
  [4065] = 3974,
  [4066] = 4066,
  [4067] = 3021,
  [4068] = 3974,
  [4069] = 3974,
  [4070] = 2987,
  [4071] = 2930,
  [4072] = 3827,
  [4073] = 3974,
  [4074] = 3974,
  [4075] = 3107,
  [4076] = 3122,
  [4077] = 3023,
  [4078] = 3025,
  [4079] = 3827,
  [4080] = 3034,
  [4081] = 3035,
  [4082] = 3974,
  [4083] = 3974,
  [4084] = 3110,
  [4085] = 3037,
  [4086] = 3974,
  [4087] = 3038,
  [4088] = 3042,
  [4089] = 3974,
  [4090] = 3974,
  [4091] = 3040,
  [4092] = 3148,
  [4093] = 2931,
  [4094] = 3046,
  [4095] = 3974,
  [4096] = 3040,
  [4097] = 3042,
  [4098] = 2997,
  [4099] = 3038,
  [4100] = 3125,
  [4101] = 3974,
  [4102] = 3129,
  [4103] = 3033,
  [4104] = 2972,
  [4105] = 3974,
  [4106] = 3974,
  [4107] = 2992,
  [4108] = 2932,
  [4109] = 3974,
  [4110] = 3037,
  [4111] = 3035,
  [4112] = 3034,
  [4113] = 3128,
  [4114] = 3031,
  [4115] = 3047,
  [4116] = 2991,
  [4117] = 3048,
  [4118] = 3049,
  [4119] = 3025,
  [4120] = 3023,
  [4121] = 2933,
  [4122] = 3129,
  [4123] = 2986,
  [4124] = 3974,
  [4125] = 2924,
  [4126] = 3974,
  [4127] = 2987,
  [4128] = 3050,
  [4129] = 2929,
  [4130] = 3051,
  [4131] = 3974,
  [4132] = 2988,
  [4133] = 2997,
  [4134] = 3120,
  [4135] = 3974,
  [4136] = 3021,
  [4137] = 2930,
  [4138] = 3024,
  [4139] = 3131,
  [4140] = 2990,
  [4141] = 3020,
  [4142] = 3019,
  [4143] = 3131,
  [4144] = 3018,
  [4145] = 3014,
  [4146] = 3974,
  [4147] = 4066,
  [4148] = 3827,
  [4149] = 3974,
  [4150] = 2926,
  [4151] = 2982,
  [4152] = 3111,
  [4153] = 3110,
  [4154] = 3109,
  [4155] = 3009,
  [4156] = 3108,
  [4157] = 3974,
  [4158] = 2988,
  [4159] = 2986,
  [4160] = 2983,
  [4161] = 3052,
  [4162] = 3008,
  [4163] = 2931,
  [4164] = 2972,
  [4165] = 3007,
  [4166] = 3011,
  [4167] = 2991,
  [4168] = 3107,
  [4169] = 2924,
  [4170] = 3974,
  [4171] = 3121,
  [4172] = 2992,
  [4173] = 3116,
  [4174] = 3132,
  [4175] = 3133,
  [4176] = 3974,
  [4177] = 3133,
  [4178] = 3006,
  [4179] = 3005,
  [4180] = 2996,
  [4181] = 3974,
  [4182] = 3974,
  [4183] = 2956,
  [4184] = 3004,
  [4185] = 3132,
  [4186] = 3003,
  [4187] = 3001,
  [4188] = 2996,
  [4189] = 3002,
  [4190] = 4190,
  [4191] = 4191,
  [4192] = 2987,
  [4193] = 4193,
  [4194] = 3131,
  [4195] = 2985,
  [4196] = 3011,
  [4197] = 3003,
  [4198] = 3827,
  [4199] = 3128,
  [4200] = 4200,
  [4201] = 4193,
  [4202] = 4202,
  [4203] = 4193,
  [4204] = 4191,
  [4205] = 4193,
  [4206] = 3205,
  [4207] = 4191,
  [4208] = 4066,
  [4209] = 3107,
  [4210] = 3038,
  [4211] = 4193,
  [4212] = 4190,
  [4213] = 4191,
  [4214] = 4191,
  [4215] = 3008,
  [4216] = 2992,
  [4217] = 4193,
  [4218] = 3009,
  [4219] = 3123,
  [4220] = 4042,
  [4221] = 3109,
  [4222] = 3125,
  [4223] = 3148,
  [4224] = 3207,
  [4225] = 3019,
  [4226] = 3023,
  [4227] = 3206,
  [4228] = 3048,
  [4229] = 4191,
  [4230] = 3025,
  [4231] = 3050,
  [4232] = 4191,
  [4233] = 4190,
  [4234] = 4193,
  [4235] = 4190,
  [4236] = 4190,
  [4237] = 4191,
  [4238] = 4193,
  [4239] = 3009,
  [4240] = 4190,
  [4241] = 3154,
  [4242] = 4193,
  [4243] = 4191,
  [4244] = 4190,
  [4245] = 3005,
  [4246] = 3019,
  [4247] = 4066,
  [4248] = 3034,
  [4249] = 3023,
  [4250] = 2999,
  [4251] = 2982,
  [4252] = 4042,
  [4253] = 4191,
  [4254] = 3033,
  [4255] = 3020,
  [4256] = 4193,
  [4257] = 3124,
  [4258] = 3047,
  [4259] = 3048,
  [4260] = 3111,
  [4261] = 3033,
  [4262] = 4191,
  [4263] = 2999,
  [4264] = 4191,
  [4265] = 4190,
  [4266] = 4193,
  [4267] = 3110,
  [4268] = 4191,
  [4269] = 3031,
  [4270] = 2986,
  [4271] = 4193,
  [4272] = 4190,
  [4273] = 4190,
  [4274] = 3206,
  [4275] = 3120,
  [4276] = 3012,
  [4277] = 3207,
  [4278] = 2997,
  [4279] = 2983,
  [4280] = 4042,
  [4281] = 3035,
  [4282] = 3110,
  [4283] = 4191,
  [4284] = 3001,
  [4285] = 3012,
  [4286] = 2996,
  [4287] = 2972,
  [4288] = 4191,
  [4289] = 4193,
  [4290] = 4193,
  [4291] = 4190,
  [4292] = 4193,
  [4293] = 4202,
  [4294] = 3014,
  [4295] = 3042,
  [4296] = 4193,
  [4297] = 3040,
  [4298] = 4191,
  [4299] = 4190,
  [4300] = 3827,
  [4301] = 4190,
  [4302] = 2983,
  [4303] = 3154,
  [4304] = 3121,
  [4305] = 3051,
  [4306] = 4190,
  [4307] = 4200,
  [4308] = 4200,
  [4309] = 3008,
  [4310] = 4202,
  [4311] = 4193,
  [4312] = 4190,
  [4313] = 2986,
  [4314] = 4193,
  [4315] = 3052,
  [4316] = 4191,
  [4317] = 3002,
  [4318] = 4190,
  [4319] = 3121,
  [4320] = 3108,
  [4321] = 4202,
  [4322] = 4193,
  [4323] = 3031,
  [4324] = 3131,
  [4325] = 3011,
  [4326] = 3024,
  [4327] = 4190,
  [4328] = 4191,
  [4329] = 3003,
  [4330] = 4191,
  [4331] = 3125,
  [4332] = 4193,
  [4333] = 4193,
  [4334] = 4191,
  [4335] = 3004,
  [4336] = 3132,
  [4337] = 3025,
  [4338] = 4200,
  [4339] = 4190,
  [4340] = 2998,
  [4341] = 3109,
  [4342] = 2988,
  [4343] = 3006,
  [4344] = 4191,
  [4345] = 2987,
  [4346] = 3018,
  [4347] = 3133,
  [4348] = 4190,
  [4349] = 3021,
  [4350] = 2968,
  [4351] = 3049,
  [4352] = 3208,
  [4353] = 3120,
  [4354] = 4191,
  [4355] = 4190,
  [4356] = 3116,
  [4357] = 3122,
  [4358] = 4193,
  [4359] = 4193,
  [4360] = 2968,
  [4361] = 4193,
  [4362] = 4190,
  [4363] = 4191,
  [4364] = 4191,
  [4365] = 3038,
  [4366] = 3040,
  [4367] = 4191,
  [4368] = 4193,
  [4369] = 4190,
  [4370] = 3129,
  [4371] = 3034,
  [4372] = 4190,
  [4373] = 3148,
  [4374] = 3047,
  [4375] = 4190,
  [4376] = 3021,
  [4377] = 3050,
  [4378] = 4193,
  [4379] = 4191,
  [4380] = 4066,
  [4381] = 4193,
  [4382] = 3132,
  [4383] = 3116,
  [4384] = 4191,
  [4385] = 4200,
  [4386] = 4191,
  [4387] = 4191,
  [4388] = 4191,
  [4389] = 4193,
  [4390] = 4190,
  [4391] = 3049,
  [4392] = 4202,
  [4393] = 4193,
  [4394] = 4191,
  [4395] = 4191,
  [4396] = 2985,
  [4397] = 4190,
  [4398] = 4193,
  [4399] = 4191,
  [4400] = 4191,
  [4401] = 3018,
  [4402] = 4193,
  [4403] = 3046,
  [4404] = 3007,
  [4405] = 4190,
  [4406] = 4191,
  [4407] = 4191,
  [4408] = 4190,
  [4409] = 3035,
  [4410] = 3111,
  [4411] = 3051,
  [4412] = 4190,
  [4413] = 3052,
  [4414] = 4191,
  [4415] = 4193,
  [4416] = 4190,
  [4417] = 2996,
  [4418] = 4191,
  [4419] = 3020,
  [4420] = 3133,
  [4421] = 4193,
  [4422] = 3208,
  [4423] = 4066,
  [4424] = 4193,
  [4425] = 2997,
  [4426] = 4190,
  [4427] = 2998,
  [4428] = 4193,
  [4429] = 3046,
  [4430] = 4191,
  [4431] = 4191,
  [4432] = 3001,
  [4433] = 4191,
  [4434] = 4193,
  [4435] = 3002,
  [4436] = 4193,
  [4437] = 4193,
  [4438] = 4190,
  [4439] = 4042,
  [4440] = 4191,
  [4441] = 3024,
  [4442] = 3042,
  [4443] = 2988,
  [4444] = 4190,
  [4445] = 4190,
  [4446] = 4193,
  [4447] = 2991,
  [4448] = 2992,
  [4449] = 4190,
  [4450] = 4191,
  [4451] = 3006,
  [4452] = 3005,
  [4453] = 3107,
  [4454] = 2972,
  [4455] = 3004,
  [4456] = 4190,
  [4457] = 4193,
  [4458] = 3129,
  [4459] = 4193,
  [4460] = 4193,
  [4461] = 2990,
  [4462] = 4193,
  [4463] = 4191,
  [4464] = 3128,
  [4465] = 3037,
  [4466] = 3123,
  [4467] = 4190,
  [4468] = 3014,
  [4469] = 2990,
  [4470] = 3108,
  [4471] = 3122,
  [4472] = 2982,
  [4473] = 4193,
  [4474] = 3205,
  [4475] = 2991,
  [4476] = 4190,
  [4477] = 4193,
  [4478] = 3037,
  [4479] = 4191,
  [4480] = 3124,
  [4481] = 4190,
  [4482] = 3007,
  [4483] = 4483,
  [4484] = 4483,
  [4485] = 4483,
  [4486] = 4483,
  [4487] = 4066,
  [4488] = 4483,
  [4489] = 4483,
  [4490] = 4490,
  [4491] = 4483,
  [4492] = 4492,
  [4493] = 4483,
  [4494] = 4483,
  [4495] = 4483,
  [4496] = 4483,
  [4497] = 4483,
  [4498] = 4483,
  [4499] = 4499,
  [4500] = 4483,
  [4501] = 4483,
  [4502] = 4483,
  [4503] = 4490,
  [4504] = 4490,
  [4505] = 4492,
  [4506] = 4042,
  [4507] = 3827,
  [4508] = 4483,
  [4509] = 4499,
  [4510] = 4483,
  [4511] = 4483,
  [4512] = 4483,
  [4513] = 4483,
  [4514] = 4483,
  [4515] = 4483,
  [4516] = 4483,
  [4517] = 4499,
  [4518] = 4483,
  [4519] = 4483,
  [4520] = 4483,
  [4521] = 4483,
  [4522] = 4490,
  [4523] = 4483,
  [4524] = 4492,
  [4525] = 4499,
  [4526] = 4483,
  [4527] = 4492,
  [4528] = 4483,
  [4529] = 4483,
  [4530] = 4490,
  [4531] = 3827,
  [4532] = 4483,
  [4533] = 4483,
  [4534] = 4483,
  [4535] = 4499,
  [4536] = 4483,
  [4537] = 4490,
  [4538] = 4483,
  [4539] = 4483,
  [4540] = 4490,
  [4541] = 4483,
  [4542] = 4066,
  [4543] = 4492,
  [4544] = 4499,
  [4545] = 4483,
  [4546] = 4042,
  [4547] = 4483,
  [4548] = 4499,
  [4549] = 4483,
  [4550] = 4483,
  [4551] = 4490,
  [4552] = 4483,
  [4553] = 4553,
  [4554] = 4066,
  [4555] = 4555,
  [4556] = 4556,
  [4557] = 4556,
  [4558] = 4558,
  [4559] = 4559,
  [4560] = 3827,
  [4561] = 4561,
  [4562] = 4553,
  [4563] = 4561,
  [4564] = 4553,
  [4565] = 4561,
  [4566] = 4558,
  [4567] = 4567,
  [4568] = 4559,
  [4569] = 4569,
  [4570] = 4570,
  [4571] = 4571,
  [4572] = 4561,
  [4573] = 4553,
  [4574] = 4555,
  [4575] = 4042,
  [4576] = 4567,
  [4577] = 4569,
  [4578] = 4570,
  [4579] = 4569,
  [4580] = 4558,
  [4581] = 4561,
  [4582] = 4553,
  [4583] = 4570,
  [4584] = 4571,
  [4585] = 4569,
  [4586] = 4555,
  [4587] = 4567,
  [4588] = 4559,
  [4589] = 4567,
  [4590] = 4553,
  [4591] = 4571,
  [4592] = 4556,
  [4593] = 4555,
  [4594] = 4571,
  [4595] = 4567,
  [4596] = 4556,
  [4597] = 4569,
  [4598] = 4570,
  [4599] = 4571,
  [4600] = 4570,
  [4601] = 4559,
  [4602] = 4066,
  [4603] = 4553,
  [4604] = 4555,
  [4605] = 4569,
  [4606] = 4555,
  [4607] = 4558,
  [4608] = 4555,
  [4609] = 4558,
  [4610] = 4559,
  [4611] = 4570,
  [4612] = 4561,
  [4613] = 4042,
  [4614] = 4569,
  [4615] = 4571,
  [4616] = 4570,
  [4617] = 3827,
  [4618] = 4561,
  [4619] = 4556,
  [4620] = 4571,
  [4621] = 4621,
  [4622] = 4622,
  [4623] = 4623,
  [4624] = 4624,
  [4625] = 4623,
  [4626] = 4624,
  [4627] = 4623,
  [4628] = 4628,
  [4629] = 2591,
  [4630] = 4630,
  [4631] = 4624,
  [4632] = 4630,
  [4633] = 4623,
  [4634] = 4623,
  [4635] = 4630,
  [4636] = 4622,
  [4637] = 4622,
  [4638] = 4042,
  [4639] = 4622,
  [4640] = 4066,
  [4641] = 4630,
  [4642] = 4642,
  [4643] = 4623,
  [4644] = 4630,
  [4645] = 4624,
  [4646] = 4621,
  [4647] = 4630,
  [4648] = 4630,
  [4649] = 4042,
  [4650] = 4621,
  [4651] = 4621,
  [4652] = 4624,
  [4653] = 4622,
  [4654] = 4623,
  [4655] = 4624,
  [4656] = 4621,
  [4657] = 4630,
  [4658] = 4066,
  [4659] = 4622,
  [4660] = 4624,
  [4661] = 4623,
  [4662] = 4622,
  [4663] = 4624,
  [4664] = 4628,
  [4665] = 4622,
  [4666] = 4666,
  [4667] = 4667,
  [4668] = 4668,
  [4669] = 4668,
  [4670] = 4667,
  [4671] = 4668,
  [4672] = 4668,
  [4673] = 4667,
  [4674] = 4668,
  [4675] = 4668,
  [4676] = 4668,
  [4677] = 4668,
  [4678] = 4668,
  [4679] = 4667,
  [4680] = 4667,
  [4681] = 2933,
  [4682] = 4668,
  [4683] = 2929,
  [4684] = 4668,
  [4685] = 4667,
  [4686] = 4667,
  [4687] = 4668,
  [4688] = 4667,
  [4689] = 2932,
  [4690] = 2926,
  [4691] = 4667,
  [4692] = 2931,
  [4693] = 4667,
  [4694] = 4667,
  [4695] = 4668,
  [4696] = 4667,
  [4697] = 4668,
  [4698] = 2930,
  [4699] = 4667,
  [4700] = 4667,
  [4701] = 4668,
  [4702] = 4667,
  [4703] = 2956,
  [4704] = 4668,
  [4705] = 4668,
  [4706] = 4667,
  [4707] = 4668,
  [4708] = 2927,
  [4709] = 4709,
  [4710] = 4667,
  [4711] = 4667,
  [4712] = 4668,
  [4713] = 4668,
  [4714] = 4667,
  [4715] = 4668,
  [4716] = 4668,
  [4717] = 4668,
  [4718] = 4667,
  [4719] = 4667,
  [4720] = 4667,
  [4721] = 2957,
  [4722] = 4667,
  [4723] = 4668,
  [4724] = 4668,
  [4725] = 4667,
  [4726] = 4667,
  [4727] = 4727,
  [4728] = 4667,
  [4729] = 4667,
  [4730] = 4668,
  [4731] = 4668,
  [4732] = 4668,
  [4733] = 4668,
  [4734] = 4667,
  [4735] = 4667,
  [4736] = 4668,
  [4737] = 4668,
  [4738] = 4667,
  [4739] = 4667,
  [4740] = 4667,
  [4741] = 4667,
  [4742] = 4668,
  [4743] = 4667,
  [4744] = 4668,
  [4745] = 4667,
  [4746] = 4668,
  [4747] = 4667,
  [4748] = 4668,
  [4749] = 4667,
  [4750] = 4668,
  [4751] = 4668,
  [4752] = 2924,
  [4753] = 4667,
  [4754] = 4667,
  [4755] = 4668,
  [4756] = 4668,
  [4757] = 4668,
  [4758] = 4667,
  [4759] = 4667,
  [4760] = 4668,
  [4761] = 4668,
  [4762] = 4668,
  [4763] = 4667,
  [4764] = 4668,
  [4765] = 4668,
  [4766] = 4668,
  [4767] = 4667,
  [4768] = 4667,
  [4769] = 2925,
  [4770] = 4667,
  [4771] = 4667,
  [4772] = 4772,
  [4773] = 2926,
  [4774] = 3049,
  [4775] = 3154,
  [4776] = 3148,
  [4777] = 3133,
  [4778] = 4778,
  [4779] = 3132,
  [4780] = 4778,
  [4781] = 3131,
  [4782] = 3129,
  [4783] = 3128,
  [4784] = 3125,
  [4785] = 4778,
  [4786] = 3124,
  [4787] = 3123,
  [4788] = 3122,
  [4789] = 3121,
  [4790] = 3120,
  [4791] = 4778,
  [4792] = 3116,
  [4793] = 4778,
  [4794] = 3038,
  [4795] = 4778,
  [4796] = 4778,
  [4797] = 4778,
  [4798] = 4778,
  [4799] = 4778,
  [4800] = 4778,
  [4801] = 3023,
  [4802] = 3111,
  [4803] = 3110,
  [4804] = 4778,
  [4805] = 4778,
  [4806] = 3109,
  [4807] = 3040,
  [4808] = 3108,
  [4809] = 4778,
  [4810] = 2968,
  [4811] = 3011,
  [4812] = 2983,
  [4813] = 2982,
  [4814] = 4778,
  [4815] = 4778,
  [4816] = 3107,
  [4817] = 2972,
  [4818] = 4778,
  [4819] = 4778,
  [4820] = 4778,
  [4821] = 2985,
  [4822] = 3024,
  [4823] = 3037,
  [4824] = 2987,
  [4825] = 3035,
  [4826] = 2925,
  [4827] = 4778,
  [4828] = 4778,
  [4829] = 2956,
  [4830] = 3031,
  [4831] = 4778,
  [4832] = 4778,
  [4833] = 4778,
  [4834] = 2990,
  [4835] = 2986,
  [4836] = 2957,
  [4837] = 3033,
  [4838] = 3034,
  [4839] = 4778,
  [4840] = 4778,
  [4841] = 2957,
  [4842] = 4778,
  [4843] = 4778,
  [4844] = 2988,
  [4845] = 4778,
  [4846] = 4778,
  [4847] = 2991,
  [4848] = 2992,
  [4849] = 3042,
  [4850] = 4778,
  [4851] = 2996,
  [4852] = 2927,
  [4853] = 4778,
  [4854] = 2998,
  [4855] = 4778,
  [4856] = 3025,
  [4857] = 3001,
  [4858] = 2999,
  [4859] = 4778,
  [4860] = 4778,
  [4861] = 4778,
  [4862] = 3014,
  [4863] = 3002,
  [4864] = 4778,
  [4865] = 3052,
  [4866] = 4778,
  [4867] = 3003,
  [4868] = 3208,
  [4869] = 2930,
  [4870] = 3004,
  [4871] = 2931,
  [4872] = 4778,
  [4873] = 2932,
  [4874] = 3207,
  [4875] = 3005,
  [4876] = 3006,
  [4877] = 3046,
  [4878] = 4778,
  [4879] = 3007,
  [4880] = 4778,
  [4881] = 3206,
  [4882] = 3008,
  [4883] = 4778,
  [4884] = 3009,
  [4885] = 3012,
  [4886] = 4778,
  [4887] = 3047,
  [4888] = 3018,
  [4889] = 3205,
  [4890] = 3019,
  [4891] = 2933,
  [4892] = 2924,
  [4893] = 4778,
  [4894] = 2929,
  [4895] = 3020,
  [4896] = 4778,
  [4897] = 3021,
  [4898] = 4778,
  [4899] = 2997,
  [4900] = 3051,
  [4901] = 3050,
  [4902] = 3048,
  [4903] = 4903,
  [4904] = 3004,
  [4905] = 2986,
  [4906] = 2927,
  [4907] = 3003,
  [4908] = 3116,
  [4909] = 3205,
  [4910] = 3005,
  [4911] = 3006,
  [4912] = 3046,
  [4913] = 3120,
  [4914] = 3121,
  [4915] = 3122,
  [4916] = 3007,
  [4917] = 3008,
  [4918] = 3009,
  [4919] = 2997,
  [4920] = 3012,
  [4921] = 2998,
  [4922] = 3123,
  [4923] = 3014,
  [4924] = 3124,
  [4925] = 3125,
  [4926] = 4926,
  [4927] = 3206,
  [4928] = 3207,
  [4929] = 3002,
  [4930] = 3148,
  [4931] = 3018,
  [4932] = 3019,
  [4933] = 3020,
  [4934] = 3208,
  [4935] = 2983,
  [4936] = 2925,
  [4937] = 3033,
  [4938] = 3021,
  [4939] = 3031,
  [4940] = 3024,
  [4941] = 4926,
  [4942] = 3128,
  [4943] = 3001,
  [4944] = 4926,
  [4945] = 3023,
  [4946] = 3025,
  [4947] = 3011,
  [4948] = 4926,
  [4949] = 2924,
  [4950] = 2987,
  [4951] = 3129,
  [4952] = 2996,
  [4953] = 3034,
  [4954] = 2957,
  [4955] = 3035,
  [4956] = 3037,
  [4957] = 3131,
  [4958] = 2926,
  [4959] = 2972,
  [4960] = 2992,
  [4961] = 3154,
  [4962] = 2968,
  [4963] = 3038,
  [4964] = 2956,
  [4965] = 2999,
  [4966] = 2991,
  [4967] = 2929,
  [4968] = 2982,
  [4969] = 3040,
  [4970] = 3107,
  [4971] = 3042,
  [4972] = 3111,
  [4973] = 3110,
  [4974] = 3109,
  [4975] = 2990,
  [4976] = 4926,
  [4977] = 2933,
  [4978] = 3108,
  [4979] = 3132,
  [4980] = 3133,
  [4981] = 4926,
  [4982] = 2930,
  [4983] = 3050,
  [4984] = 3052,
  [4985] = 2985,
  [4986] = 2988,
  [4987] = 2932,
  [4988] = 3051,
  [4989] = 3047,
  [4990] = 3048,
  [4991] = 3049,
  [4992] = 4926,
  [4993] = 2931,
  [4994] = 2957,
  [4995] = 3132,
  [4996] = 4996,
  [4997] = 2996,
  [4998] = 4996,
  [4999] = 2992,
  [5000] = 2991,
  [5001] = 3148,
  [5002] = 4996,
  [5003] = 3052,
  [5004] = 4996,
  [5005] = 2988,
  [5006] = 4996,
  [5007] = 3011,
  [5008] = 5008,
  [5009] = 3051,
  [5010] = 5008,
  [5011] = 2956,
  [5012] = 4996,
  [5013] = 2999,
  [5014] = 3050,
  [5015] = 2925,
  [5016] = 4996,
  [5017] = 3006,
  [5018] = 3007,
  [5019] = 2924,
  [5020] = 3008,
  [5021] = 3049,
  [5022] = 3154,
  [5023] = 2997,
  [5024] = 3009,
  [5025] = 4996,
  [5026] = 3048,
  [5027] = 4996,
  [5028] = 4996,
  [5029] = 4996,
  [5030] = 3046,
  [5031] = 4996,
  [5032] = 4996,
  [5033] = 3012,
  [5034] = 3014,
  [5035] = 5008,
  [5036] = 4996,
  [5037] = 4996,
  [5038] = 3004,
  [5039] = 4996,
  [5040] = 2925,
  [5041] = 4996,
  [5042] = 3047,
  [5043] = 3107,
  [5044] = 2983,
  [5045] = 2982,
  [5046] = 2990,
  [5047] = 4996,
  [5048] = 2927,
  [5049] = 4996,
  [5050] = 5050,
  [5051] = 4996,
  [5052] = 5052,
  [5053] = 4996,
  [5054] = 4996,
  [5055] = 4996,
  [5056] = 4996,
  [5057] = 3002,
  [5058] = 4996,
  [5059] = 3018,
  [5060] = 4996,
  [5061] = 2986,
  [5062] = 4996,
  [5063] = 3108,
  [5064] = 3024,
  [5065] = 3125,
  [5066] = 4996,
  [5067] = 3001,
  [5068] = 3019,
  [5069] = 4996,
  [5070] = 3020,
  [5071] = 4996,
  [5072] = 3124,
  [5073] = 4996,
  [5074] = 3021,
  [5075] = 3128,
  [5076] = 2998,
  [5077] = 3133,
  [5078] = 4996,
  [5079] = 2927,
  [5080] = 4996,
  [5081] = 3129,
  [5082] = 2924,
  [5083] = 2930,
  [5084] = 3031,
  [5085] = 5050,
  [5086] = 2931,
  [5087] = 4996,
  [5088] = 2926,
  [5089] = 2929,
  [5090] = 5052,
  [5091] = 2933,
  [5092] = 4996,
  [5093] = 2956,
  [5094] = 4996,
  [5095] = 2932,
  [5096] = 3123,
  [5097] = 5052,
  [5098] = 4996,
  [5099] = 5008,
  [5100] = 2933,
  [5101] = 3122,
  [5102] = 2929,
  [5103] = 3042,
  [5104] = 2926,
  [5105] = 3005,
  [5106] = 2932,
  [5107] = 2931,
  [5108] = 5008,
  [5109] = 2930,
  [5110] = 2987,
  [5111] = 2985,
  [5112] = 4996,
  [5113] = 3040,
  [5114] = 5008,
  [5115] = 3121,
  [5116] = 3120,
  [5117] = 2968,
  [5118] = 4996,
  [5119] = 3023,
  [5120] = 5008,
  [5121] = 3116,
  [5122] = 3111,
  [5123] = 3025,
  [5124] = 2972,
  [5125] = 3033,
  [5126] = 3109,
  [5127] = 3038,
  [5128] = 3131,
  [5129] = 3003,
  [5130] = 3037,
  [5131] = 3035,
  [5132] = 3208,
  [5133] = 4996,
  [5134] = 4996,
  [5135] = 4996,
  [5136] = 3034,
  [5137] = 3207,
  [5138] = 4996,
  [5139] = 3206,
  [5140] = 4996,
  [5141] = 3205,
  [5142] = 3827,
  [5143] = 4996,
  [5144] = 4996,
  [5145] = 3110,
  [5146] = 3006,
  [5147] = 3049,
  [5148] = 2924,
  [5149] = 3001,
  [5150] = 3012,
  [5151] = 3132,
  [5152] = 3121,
  [5153] = 3033,
  [5154] = 3051,
  [5155] = 3122,
  [5156] = 2986,
  [5157] = 2985,
  [5158] = 3009,
  [5159] = 3133,
  [5160] = 2957,
  [5161] = 3008,
  [5162] = 3007,
  [5163] = 2925,
  [5164] = 3131,
  [5165] = 3006,
  [5166] = 2987,
  [5167] = 3005,
  [5168] = 3133,
  [5169] = 3004,
  [5170] = 3003,
  [5171] = 3206,
  [5172] = 3207,
  [5173] = 3014,
  [5174] = 3116,
  [5175] = 3018,
  [5176] = 3148,
  [5177] = 3019,
  [5178] = 3020,
  [5179] = 3050,
  [5180] = 3021,
  [5181] = 3023,
  [5182] = 3002,
  [5183] = 2990,
  [5184] = 3827,
  [5185] = 3024,
  [5186] = 2988,
  [5187] = 3132,
  [5188] = 2991,
  [5189] = 2996,
  [5190] = 2992,
  [5191] = 2991,
  [5192] = 2988,
  [5193] = 3125,
  [5194] = 2992,
  [5195] = 3025,
  [5196] = 2996,
  [5197] = 2957,
  [5198] = 2998,
  [5199] = 3046,
  [5200] = 3107,
  [5201] = 3001,
  [5202] = 2986,
  [5203] = 2983,
  [5204] = 2982,
  [5205] = 3002,
  [5206] = 3011,
  [5207] = 3122,
  [5208] = 3205,
  [5209] = 3154,
  [5210] = 2972,
  [5211] = 3003,
  [5212] = 3108,
  [5213] = 3109,
  [5214] = 3004,
  [5215] = 3005,
  [5216] = 3052,
  [5217] = 3206,
  [5218] = 3110,
  [5219] = 3007,
  [5220] = 3034,
  [5221] = 3035,
  [5222] = 3111,
  [5223] = 3008,
  [5224] = 3009,
  [5225] = 3120,
  [5226] = 3025,
  [5227] = 3124,
  [5228] = 2968,
  [5229] = 3031,
  [5230] = 3132,
  [5231] = 3123,
  [5232] = 3042,
  [5233] = 3123,
  [5234] = 3207,
  [5235] = 3012,
  [5236] = 3125,
  [5237] = 3148,
  [5238] = 3116,
  [5239] = 3128,
  [5240] = 3048,
  [5241] = 3128,
  [5242] = 5242,
  [5243] = 3040,
  [5244] = 3046,
  [5245] = 3014,
  [5246] = 3208,
  [5247] = 3038,
  [5248] = 3124,
  [5249] = 3122,
  [5250] = 2985,
  [5251] = 2987,
  [5252] = 3037,
  [5253] = 2990,
  [5254] = 2997,
  [5255] = 3018,
  [5256] = 2999,
  [5257] = 3019,
  [5258] = 3020,
  [5259] = 3011,
  [5260] = 3154,
  [5261] = 3024,
  [5262] = 3131,
  [5263] = 3038,
  [5264] = 2968,
  [5265] = 3031,
  [5266] = 3040,
  [5267] = 3121,
  [5268] = 3033,
  [5269] = 2972,
  [5270] = 3021,
  [5271] = 2997,
  [5272] = 2982,
  [5273] = 5242,
  [5274] = 3111,
  [5275] = 3047,
  [5276] = 4066,
  [5277] = 3023,
  [5278] = 3110,
  [5279] = 3042,
  [5280] = 2927,
  [5281] = 3120,
  [5282] = 2998,
  [5283] = 3109,
  [5284] = 2926,
  [5285] = 2929,
  [5286] = 2933,
  [5287] = 3132,
  [5288] = 3047,
  [5289] = 3048,
  [5290] = 3107,
  [5291] = 3129,
  [5292] = 2983,
  [5293] = 3049,
  [5294] = 4042,
  [5295] = 3050,
  [5296] = 3108,
  [5297] = 3034,
  [5298] = 3035,
  [5299] = 3052,
  [5300] = 3205,
  [5301] = 3122,
  [5302] = 2999,
  [5303] = 3129,
  [5304] = 3051,
  [5305] = 2932,
  [5306] = 3208,
  [5307] = 2956,
  [5308] = 2931,
  [5309] = 3037,
  [5310] = 2930,
  [5311] = 3008,
  [5312] = 3005,
  [5313] = 3129,
  [5314] = 3131,
  [5315] = 5315,
  [5316] = 4066,
  [5317] = 3108,
  [5318] = 3109,
  [5319] = 3014,
  [5320] = 3018,
  [5321] = 3128,
  [5322] = 3007,
  [5323] = 3110,
  [5324] = 3111,
  [5325] = 5325,
  [5326] = 3009,
  [5327] = 3148,
  [5328] = 3012,
  [5329] = 3154,
  [5330] = 3019,
  [5331] = 3020,
  [5332] = 2986,
  [5333] = 3121,
  [5334] = 3123,
  [5335] = 3122,
  [5336] = 3205,
  [5337] = 3021,
  [5338] = 3125,
  [5339] = 3206,
  [5340] = 3004,
  [5341] = 3207,
  [5342] = 2957,
  [5343] = 3120,
  [5344] = 4042,
  [5345] = 3128,
  [5346] = 3133,
  [5347] = 3003,
  [5348] = 3002,
  [5349] = 3023,
  [5350] = 3025,
  [5351] = 3001,
  [5352] = 3006,
  [5353] = 3132,
  [5354] = 2996,
  [5355] = 3208,
  [5356] = 5356,
  [5357] = 3124,
  [5358] = 3122,
  [5359] = 2998,
  [5360] = 3128,
  [5361] = 3116,
  [5362] = 2992,
  [5363] = 5315,
  [5364] = 3124,
  [5365] = 3120,
  [5366] = 3034,
  [5367] = 3123,
  [5368] = 2991,
  [5369] = 3125,
  [5370] = 3035,
  [5371] = 3046,
  [5372] = 3148,
  [5373] = 3116,
  [5374] = 2988,
  [5375] = 3037,
  [5376] = 3124,
  [5377] = 3038,
  [5378] = 3040,
  [5379] = 3042,
  [5380] = 2999,
  [5381] = 3133,
  [5382] = 2972,
  [5383] = 3047,
  [5384] = 2968,
  [5385] = 3132,
  [5386] = 5386,
  [5387] = 3048,
  [5388] = 3121,
  [5389] = 3049,
  [5390] = 5390,
  [5391] = 3050,
  [5392] = 2983,
  [5393] = 3051,
  [5394] = 5325,
  [5395] = 3827,
  [5396] = 2982,
  [5397] = 2985,
  [5398] = 2987,
  [5399] = 2990,
  [5400] = 3154,
  [5401] = 3131,
  [5402] = 3129,
  [5403] = 3129,
  [5404] = 3131,
  [5405] = 3122,
  [5406] = 3154,
  [5407] = 2997,
  [5408] = 5356,
  [5409] = 3033,
  [5410] = 3107,
  [5411] = 3052,
  [5412] = 3031,
  [5413] = 3024,
  [5414] = 3133,
  [5415] = 3120,
  [5416] = 3116,
  [5417] = 3148,
  [5418] = 3132,
  [5419] = 5419,
  [5420] = 3125,
  [5421] = 3121,
  [5422] = 3011,
  [5423] = 3123,
  [5424] = 5424,
  [5425] = 3116,
  [5426] = 3131,
  [5427] = 3128,
  [5428] = 5428,
  [5429] = 2930,
  [5430] = 5430,
  [5431] = 3133,
  [5432] = 3111,
  [5433] = 3208,
  [5434] = 5434,
  [5435] = 2931,
  [5436] = 3109,
  [5437] = 2932,
  [5438] = 3125,
  [5439] = 3110,
  [5440] = 5440,
  [5441] = 3108,
  [5442] = 3206,
  [5443] = 5315,
  [5444] = 3124,
  [5445] = 3123,
  [5446] = 5428,
  [5447] = 2956,
  [5448] = 5448,
  [5449] = 3121,
  [5450] = 5450,
  [5451] = 3120,
  [5452] = 5452,
  [5453] = 5453,
  [5454] = 3205,
  [5455] = 5455,
  [5456] = 5456,
  [5457] = 5457,
  [5458] = 5458,
  [5459] = 5459,
  [5460] = 3148,
  [5461] = 5453,
  [5462] = 5456,
  [5463] = 4042,
  [5464] = 5464,
  [5465] = 5464,
  [5466] = 3107,
  [5467] = 5467,
  [5468] = 5468,
  [5469] = 2933,
  [5470] = 3154,
  [5471] = 5448,
  [5472] = 2929,
  [5473] = 2926,
  [5474] = 5474,
  [5475] = 5475,
  [5476] = 5476,
  [5477] = 5477,
  [5478] = 3116,
  [5479] = 4066,
  [5480] = 3133,
  [5481] = 5457,
  [5482] = 5315,
  [5483] = 5483,
  [5484] = 5484,
  [5485] = 5485,
  [5486] = 5486,
  [5487] = 5455,
  [5488] = 5485,
  [5489] = 5486,
  [5490] = 3111,
  [5491] = 3154,
  [5492] = 3131,
  [5493] = 3110,
  [5494] = 3207,
  [5495] = 3129,
  [5496] = 5496,
  [5497] = 3129,
  [5498] = 2983,
  [5499] = 2982,
  [5500] = 5430,
  [5501] = 5325,
  [5502] = 3109,
  [5503] = 2957,
  [5504] = 5459,
  [5505] = 5484,
  [5506] = 5475,
  [5507] = 3827,
  [5508] = 5474,
  [5509] = 5509,
  [5510] = 5325,
  [5511] = 5458,
  [5512] = 5467,
  [5513] = 5440,
  [5514] = 5514,
  [5515] = 5515,
  [5516] = 2925,
  [5517] = 5517,
  [5518] = 5518,
  [5519] = 5483,
  [5520] = 5452,
  [5521] = 5521,
  [5522] = 5356,
  [5523] = 5356,
  [5524] = 5450,
  [5525] = 3128,
  [5526] = 2982,
  [5527] = 5527,
  [5528] = 3827,
  [5529] = 3108,
  [5530] = 5434,
  [5531] = 5424,
  [5532] = 3208,
  [5533] = 5521,
  [5534] = 2983,
  [5535] = 5535,
  [5536] = 3107,
  [5537] = 5527,
  [5538] = 5515,
  [5539] = 5518,
  [5540] = 3205,
  [5541] = 5541,
  [5542] = 5542,
  [5543] = 5496,
  [5544] = 3120,
  [5545] = 5477,
  [5546] = 3121,
  [5547] = 2927,
  [5548] = 5468,
  [5549] = 5509,
  [5550] = 3207,
  [5551] = 3123,
  [5552] = 3206,
  [5553] = 5514,
  [5554] = 3124,
  [5555] = 5541,
  [5556] = 3125,
  [5557] = 5542,
  [5558] = 5476,
  [5559] = 5559,
  [5560] = 5535,
  [5561] = 5561,
  [5562] = 2924,
  [5563] = 5561,
  [5564] = 3148,
  [5565] = 5517,
  [5566] = 5559,
  [5567] = 3109,
  [5568] = 3111,
  [5569] = 3208,
  [5570] = 3207,
  [5571] = 3206,
  [5572] = 3205,
  [5573] = 4042,
  [5574] = 5452,
  [5575] = 5455,
  [5576] = 3110,
  [5577] = 5521,
  [5578] = 2990,
  [5579] = 3205,
  [5580] = 5496,
  [5581] = 5434,
  [5582] = 4042,
  [5583] = 5440,
  [5584] = 2987,
  [5585] = 3206,
  [5586] = 3207,
  [5587] = 3208,
  [5588] = 3208,
  [5589] = 3207,
  [5590] = 3206,
  [5591] = 5457,
  [5592] = 2985,
  [5593] = 3108,
  [5594] = 5476,
  [5595] = 5452,
  [5596] = 3154,
  [5597] = 5476,
  [5598] = 2957,
  [5599] = 5521,
  [5600] = 4066,
  [5601] = 3205,
  [5602] = 2956,
  [5603] = 3148,
  [5604] = 5509,
  [5605] = 3133,
  [5606] = 5430,
  [5607] = 5467,
  [5608] = 3132,
  [5609] = 2924,
  [5610] = 5459,
  [5611] = 3131,
  [5612] = 5458,
  [5613] = 3129,
  [5614] = 3128,
  [5615] = 3125,
  [5616] = 3124,
  [5617] = 3123,
  [5618] = 3122,
  [5619] = 3121,
  [5620] = 5474,
  [5621] = 3120,
  [5622] = 5496,
  [5623] = 2997,
  [5624] = 5485,
  [5625] = 3116,
  [5626] = 5514,
  [5627] = 5486,
  [5628] = 5440,
  [5629] = 5450,
  [5630] = 5434,
  [5631] = 5457,
  [5632] = 5477,
  [5633] = 2999,
  [5634] = 5424,
  [5635] = 5484,
  [5636] = 5535,
  [5637] = 5518,
  [5638] = 5468,
  [5639] = 5561,
  [5640] = 5527,
  [5641] = 5517,
  [5642] = 3111,
  [5643] = 3110,
  [5644] = 3109,
  [5645] = 3108,
  [5646] = 3107,
  [5647] = 5559,
  [5648] = 3024,
  [5649] = 3011,
  [5650] = 5542,
  [5651] = 5541,
  [5652] = 5428,
  [5653] = 5448,
  [5654] = 5453,
  [5655] = 2968,
  [5656] = 5456,
  [5657] = 2982,
  [5658] = 5464,
  [5659] = 3107,
  [5660] = 3827,
  [5661] = 3021,
  [5662] = 2957,
  [5663] = 5515,
  [5664] = 5475,
  [5665] = 2926,
  [5666] = 2929,
  [5667] = 2933,
  [5668] = 5483,
  [5669] = 2972,
  [5670] = 5509,
  [5671] = 2925,
  [5672] = 5430,
  [5673] = 2982,
  [5674] = 2983,
  [5675] = 4066,
  [5676] = 5467,
  [5677] = 3107,
  [5678] = 5459,
  [5679] = 5458,
  [5680] = 5474,
  [5681] = 2932,
  [5682] = 2931,
  [5683] = 2930,
  [5684] = 3031,
  [5685] = 5464,
  [5686] = 5485,
  [5687] = 5455,
  [5688] = 3108,
  [5689] = 2927,
  [5690] = 3033,
  [5691] = 5486,
  [5692] = 5450,
  [5693] = 5477,
  [5694] = 2986,
  [5695] = 5424,
  [5696] = 5484,
  [5697] = 5535,
  [5698] = 3109,
  [5699] = 5518,
  [5700] = 3052,
  [5701] = 5468,
  [5702] = 5561,
  [5703] = 5527,
  [5704] = 5517,
  [5705] = 2988,
  [5706] = 2991,
  [5707] = 3110,
  [5708] = 2992,
  [5709] = 5559,
  [5710] = 3111,
  [5711] = 5542,
  [5712] = 2996,
  [5713] = 2983,
  [5714] = 5541,
  [5715] = 5428,
  [5716] = 5448,
  [5717] = 5453,
  [5718] = 2982,
  [5719] = 5456,
  [5720] = 3051,
  [5721] = 5514,
  [5722] = 3050,
  [5723] = 5515,
  [5724] = 3049,
  [5725] = 2983,
  [5726] = 3048,
  [5727] = 3001,
  [5728] = 3002,
  [5729] = 5475,
  [5730] = 3003,
  [5731] = 5483,
  [5732] = 3004,
  [5733] = 3047,
  [5734] = 3046,
  [5735] = 3005,
  [5736] = 2998,
  [5737] = 3020,
  [5738] = 3019,
  [5739] = 3042,
  [5740] = 3040,
  [5741] = 3038,
  [5742] = 3018,
  [5743] = 3007,
  [5744] = 3014,
  [5745] = 3006,
  [5746] = 3037,
  [5747] = 3035,
  [5748] = 3034,
  [5749] = 3012,
  [5750] = 3009,
  [5751] = 3008,
  [5752] = 3025,
  [5753] = 3023,
  [5754] = 2990,
  [5755] = 2986,
  [5756] = 2925,
  [5757] = 2927,
  [5758] = 5758,
  [5759] = 5759,
  [5760] = 5758,
  [5761] = 5758,
  [5762] = 5758,
  [5763] = 5758,
  [5764] = 3107,
  [5765] = 2968,
  [5766] = 4042,
  [5767] = 5759,
  [5768] = 2982,
  [5769] = 4066,
  [5770] = 3108,
  [5771] = 3109,
  [5772] = 3110,
  [5773] = 3111,
  [5774] = 5758,
  [5775] = 5759,
  [5776] = 2957,
  [5777] = 2956,
  [5778] = 3052,
  [5779] = 3051,
  [5780] = 2930,
  [5781] = 3050,
  [5782] = 3049,
  [5783] = 3048,
  [5784] = 3047,
  [5785] = 2931,
  [5786] = 2983,
  [5787] = 2932,
  [5788] = 2957,
  [5789] = 3042,
  [5790] = 3040,
  [5791] = 2933,
  [5792] = 3038,
  [5793] = 2929,
  [5794] = 3037,
  [5795] = 3035,
  [5796] = 3034,
  [5797] = 3025,
  [5798] = 3023,
  [5799] = 2926,
  [5800] = 3021,
  [5801] = 3033,
  [5802] = 3031,
  [5803] = 3208,
  [5804] = 3207,
  [5805] = 3206,
  [5806] = 3133,
  [5807] = 3020,
  [5808] = 3024,
  [5809] = 3132,
  [5810] = 3019,
  [5811] = 3205,
  [5812] = 3011,
  [5813] = 3116,
  [5814] = 3018,
  [5815] = 2999,
  [5816] = 2997,
  [5817] = 3014,
  [5818] = 3012,
  [5819] = 3009,
  [5820] = 3008,
  [5821] = 3007,
  [5822] = 3131,
  [5823] = 3006,
  [5824] = 3005,
  [5825] = 3004,
  [5826] = 2987,
  [5827] = 2985,
  [5828] = 3148,
  [5829] = 3003,
  [5830] = 3002,
  [5831] = 3001,
  [5832] = 2972,
  [5833] = 2996,
  [5834] = 2992,
  [5835] = 2991,
  [5836] = 2998,
  [5837] = 2924,
  [5838] = 3120,
  [5839] = 3121,
  [5840] = 3122,
  [5841] = 3129,
  [5842] = 3123,
  [5843] = 3154,
  [5844] = 3124,
  [5845] = 3125,
  [5846] = 3046,
  [5847] = 2988,
  [5848] = 3128,
  [5849] = 3206,
  [5850] = 2997,
  [5851] = 3154,
  [5852] = 3047,
  [5853] = 2925,
  [5854] = 3046,
  [5855] = 2999,
  [5856] = 2990,
  [5857] = 2983,
  [5858] = 2997,
  [5859] = 2927,
  [5860] = 2982,
  [5861] = 3111,
  [5862] = 3042,
  [5863] = 3040,
  [5864] = 3042,
  [5865] = 2931,
  [5866] = 2925,
  [5867] = 2932,
  [5868] = 3038,
  [5869] = 3040,
  [5870] = 2927,
  [5871] = 3037,
  [5872] = 3035,
  [5873] = 3034,
  [5874] = 3038,
  [5875] = 3110,
  [5876] = 3148,
  [5877] = 2924,
  [5878] = 3025,
  [5879] = 3023,
  [5880] = 3109,
  [5881] = 3037,
  [5882] = 3021,
  [5883] = 3035,
  [5884] = 3011,
  [5885] = 3034,
  [5886] = 3020,
  [5887] = 3019,
  [5888] = 3018,
  [5889] = 2987,
  [5890] = 2985,
  [5891] = 3049,
  [5892] = 2956,
  [5893] = 3050,
  [5894] = 3014,
  [5895] = 2956,
  [5896] = 3012,
  [5897] = 3827,
  [5898] = 3009,
  [5899] = 3008,
  [5900] = 3007,
  [5901] = 3051,
  [5902] = 3012,
  [5903] = 3006,
  [5904] = 3005,
  [5905] = 3004,
  [5906] = 3024,
  [5907] = 2956,
  [5908] = 2985,
  [5909] = 2968,
  [5910] = 3111,
  [5911] = 3003,
  [5912] = 3110,
  [5913] = 3002,
  [5914] = 3001,
  [5915] = 3046,
  [5916] = 2926,
  [5917] = 2929,
  [5918] = 2933,
  [5919] = 2996,
  [5920] = 2956,
  [5921] = 2992,
  [5922] = 2991,
  [5923] = 3116,
  [5924] = 3109,
  [5925] = 3025,
  [5926] = 3133,
  [5927] = 3148,
  [5928] = 3132,
  [5929] = 2988,
  [5930] = 3154,
  [5931] = 3046,
  [5932] = 2932,
  [5933] = 2931,
  [5934] = 2930,
  [5935] = 2987,
  [5936] = 3108,
  [5937] = 3031,
  [5938] = 3023,
  [5939] = 2986,
  [5940] = 3131,
  [5941] = 3033,
  [5942] = 3108,
  [5943] = 3047,
  [5944] = 3107,
  [5945] = 2933,
  [5946] = 3108,
  [5947] = 3109,
  [5948] = 2929,
  [5949] = 3110,
  [5950] = 2972,
  [5951] = 3111,
  [5952] = 2926,
  [5953] = 3021,
  [5954] = 2990,
  [5955] = 2972,
  [5956] = 2930,
  [5957] = 2986,
  [5958] = 2930,
  [5959] = 2931,
  [5960] = 2932,
  [5961] = 3052,
  [5962] = 2988,
  [5963] = 3048,
  [5964] = 2991,
  [5965] = 2992,
  [5966] = 2996,
  [5967] = 2933,
  [5968] = 2929,
  [5969] = 2926,
  [5970] = 3001,
  [5971] = 3002,
  [5972] = 3116,
  [5973] = 3003,
  [5974] = 3004,
  [5975] = 3005,
  [5976] = 3006,
  [5977] = 2925,
  [5978] = 3007,
  [5979] = 3008,
  [5980] = 3009,
  [5981] = 3012,
  [5982] = 3014,
  [5983] = 3049,
  [5984] = 3018,
  [5985] = 3019,
  [5986] = 3020,
  [5987] = 3020,
  [5988] = 2930,
  [5989] = 3021,
  [5990] = 2931,
  [5991] = 3023,
  [5992] = 3129,
  [5993] = 3025,
  [5994] = 3019,
  [5995] = 2924,
  [5996] = 2924,
  [5997] = 2932,
  [5998] = 2924,
  [5999] = 3018,
  [6000] = 3034,
  [6001] = 2968,
  [6002] = 3120,
  [6003] = 3121,
  [6004] = 3122,
  [6005] = 3035,
  [6006] = 3037,
  [6007] = 3038,
  [6008] = 3123,
  [6009] = 2957,
  [6010] = 3014,
  [6011] = 3124,
  [6012] = 2956,
  [6013] = 3040,
  [6014] = 3042,
  [6015] = 2927,
  [6016] = 2925,
  [6017] = 3048,
  [6018] = 2933,
  [6019] = 2929,
  [6020] = 3125,
  [6021] = 2926,
  [6022] = 2999,
  [6023] = 3047,
  [6024] = 3048,
  [6025] = 2956,
  [6026] = 3049,
  [6027] = 3050,
  [6028] = 3128,
  [6029] = 3051,
  [6030] = 3052,
  [6031] = 3133,
  [6032] = 2968,
  [6033] = 3132,
  [6034] = 3128,
  [6035] = 2926,
  [6036] = 2929,
  [6037] = 2933,
  [6038] = 3011,
  [6039] = 2925,
  [6040] = 3131,
  [6041] = 2924,
  [6042] = 3129,
  [6043] = 3131,
  [6044] = 3024,
  [6045] = 3132,
  [6046] = 3125,
  [6047] = 3133,
  [6048] = 3129,
  [6049] = 3124,
  [6050] = 2957,
  [6051] = 2932,
  [6052] = 2931,
  [6053] = 2930,
  [6054] = 3123,
  [6055] = 3031,
  [6056] = 3033,
  [6057] = 3009,
  [6058] = 2927,
  [6059] = 3122,
  [6060] = 2983,
  [6061] = 2927,
  [6062] = 3121,
  [6063] = 3128,
  [6064] = 3008,
  [6065] = 3148,
  [6066] = 3007,
  [6067] = 2998,
  [6068] = 2983,
  [6069] = 3154,
  [6070] = 2930,
  [6071] = 3006,
  [6072] = 3005,
  [6073] = 3004,
  [6074] = 2931,
  [6075] = 3003,
  [6076] = 2932,
  [6077] = 3002,
  [6078] = 2933,
  [6079] = 3001,
  [6080] = 2929,
  [6081] = 3205,
  [6082] = 2926,
  [6083] = 2925,
  [6084] = 2998,
  [6085] = 3125,
  [6086] = 3120,
  [6087] = 3050,
  [6088] = 3124,
  [6089] = 2972,
  [6090] = 3206,
  [6091] = 3207,
  [6092] = 3208,
  [6093] = 3051,
  [6094] = 3123,
  [6095] = 3122,
  [6096] = 2927,
  [6097] = 2924,
  [6098] = 3121,
  [6099] = 2998,
  [6100] = 2927,
  [6101] = 3116,
  [6102] = 3120,
  [6103] = 2982,
  [6104] = 2957,
  [6105] = 3107,
  [6106] = 2996,
  [6107] = 2986,
  [6108] = 2992,
  [6109] = 2924,
  [6110] = 3208,
  [6111] = 3207,
  [6112] = 2991,
  [6113] = 3206,
  [6114] = 3205,
  [6115] = 3033,
  [6116] = 3031,
  [6117] = 2957,
  [6118] = 2957,
  [6119] = 2930,
  [6120] = 2931,
  [6121] = 2932,
  [6122] = 3024,
  [6123] = 2957,
  [6124] = 2933,
  [6125] = 2929,
  [6126] = 2926,
  [6127] = 3208,
  [6128] = 3011,
  [6129] = 2925,
  [6130] = 2925,
  [6131] = 3207,
  [6132] = 2999,
  [6133] = 2997,
  [6134] = 3205,
  [6135] = 2924,
  [6136] = 2990,
  [6137] = 2927,
  [6138] = 3052,
  [6139] = 2988,
  [6140] = 2926,
  [6141] = 2929,
  [6142] = 2933,
  [6143] = 3107,
  [6144] = 2987,
  [6145] = 2985,
  [6146] = 2957,
  [6147] = 2982,
  [6148] = 2930,
  [6149] = 2931,
  [6150] = 2932,
  [6151] = 2931,
  [6152] = 2997,
  [6153] = 3154,
  [6154] = 2986,
  [6155] = 3047,
  [6156] = 3205,
  [6157] = 3131,
  [6158] = 3051,
  [6159] = 2988,
  [6160] = 3008,
  [6161] = 3206,
  [6162] = 3052,
  [6163] = 3207,
  [6164] = 3208,
  [6165] = 3050,
  [6166] = 3129,
  [6167] = 3049,
  [6168] = 3048,
  [6169] = 2972,
  [6170] = 3038,
  [6171] = 2991,
  [6172] = 3128,
  [6173] = 3051,
  [6174] = 2992,
  [6175] = 3050,
  [6176] = 2957,
  [6177] = 3049,
  [6178] = 3048,
  [6179] = 3205,
  [6180] = 3047,
  [6181] = 2996,
  [6182] = 3007,
  [6183] = 2956,
  [6184] = 3129,
  [6185] = 3207,
  [6186] = 3208,
  [6187] = 3001,
  [6188] = 3111,
  [6189] = 2987,
  [6190] = 2924,
  [6191] = 3002,
  [6192] = 3042,
  [6193] = 3040,
  [6194] = 3038,
  [6195] = 3006,
  [6196] = 3208,
  [6197] = 3037,
  [6198] = 3035,
  [6199] = 3034,
  [6200] = 3109,
  [6201] = 3205,
  [6202] = 3131,
  [6203] = 3003,
  [6204] = 3025,
  [6205] = 3023,
  [6206] = 3206,
  [6207] = 3207,
  [6208] = 3021,
  [6209] = 2968,
  [6210] = 3208,
  [6211] = 3207,
  [6212] = 3109,
  [6213] = 3020,
  [6214] = 3019,
  [6215] = 3018,
  [6216] = 3014,
  [6217] = 3004,
  [6218] = 3012,
  [6219] = 3005,
  [6220] = 3009,
  [6221] = 3008,
  [6222] = 3007,
  [6223] = 3006,
  [6224] = 2972,
  [6225] = 3006,
  [6226] = 3005,
  [6227] = 3004,
  [6228] = 3003,
  [6229] = 3007,
  [6230] = 3002,
  [6231] = 3001,
  [6232] = 3008,
  [6233] = 3009,
  [6234] = 3206,
  [6235] = 3012,
  [6236] = 2996,
  [6237] = 3205,
  [6238] = 2992,
  [6239] = 2991,
  [6240] = 2988,
  [6241] = 3014,
  [6242] = 3206,
  [6243] = 3018,
  [6244] = 3019,
  [6245] = 3020,
  [6246] = 3207,
  [6247] = 2986,
  [6248] = 3012,
  [6249] = 3208,
  [6250] = 2968,
  [6251] = 3021,
  [6252] = 3128,
  [6253] = 3023,
  [6254] = 3025,
  [6255] = 3052,
  [6256] = 3108,
  [6257] = 2957,
  [6258] = 3052,
  [6259] = 3034,
  [6260] = 3035,
  [6261] = 3004,
  [6262] = 2972,
  [6263] = 3110,
  [6264] = 3037,
  [6265] = 3051,
  [6266] = 2985,
  [6267] = 3050,
  [6268] = 2987,
  [6269] = 3049,
  [6270] = 3048,
  [6271] = 3042,
  [6272] = 3047,
  [6273] = 3033,
  [6274] = 3046,
  [6275] = 6275,
  [6276] = 3040,
  [6277] = 6275,
  [6278] = 3116,
  [6279] = 3111,
  [6280] = 2987,
  [6281] = 3148,
  [6282] = 3148,
  [6283] = 3038,
  [6284] = 3042,
  [6285] = 3040,
  [6286] = 3038,
  [6287] = 3018,
  [6288] = 2990,
  [6289] = 3037,
  [6290] = 3035,
  [6291] = 3034,
  [6292] = 3031,
  [6293] = 3040,
  [6294] = 3024,
  [6295] = 3042,
  [6296] = 3025,
  [6297] = 3023,
  [6298] = 6298,
  [6299] = 3154,
  [6300] = 3021,
  [6301] = 2968,
  [6302] = 3014,
  [6303] = 3052,
  [6304] = 3148,
  [6305] = 3020,
  [6306] = 3019,
  [6307] = 3018,
  [6308] = 3014,
  [6309] = 2997,
  [6310] = 3012,
  [6311] = 2999,
  [6312] = 3009,
  [6313] = 3008,
  [6314] = 3007,
  [6315] = 3047,
  [6316] = 3048,
  [6317] = 3006,
  [6318] = 3005,
  [6319] = 3004,
  [6320] = 3003,
  [6321] = 3011,
  [6322] = 3002,
  [6323] = 3001,
  [6324] = 2998,
  [6325] = 3049,
  [6326] = 3050,
  [6327] = 3051,
  [6328] = 2996,
  [6329] = 2957,
  [6330] = 2992,
  [6331] = 2991,
  [6332] = 2988,
  [6333] = 3024,
  [6334] = 3011,
  [6335] = 3132,
  [6336] = 2972,
  [6337] = 3133,
  [6338] = 2925,
  [6339] = 2986,
  [6340] = 3031,
  [6341] = 2985,
  [6342] = 3033,
  [6343] = 2999,
  [6344] = 3037,
  [6345] = 3018,
  [6346] = 2987,
  [6347] = 3035,
  [6348] = 2930,
  [6349] = 3110,
  [6350] = 3116,
  [6351] = 3025,
  [6352] = 3132,
  [6353] = 2990,
  [6354] = 2972,
  [6355] = 3023,
  [6356] = 3005,
  [6357] = 3052,
  [6358] = 2985,
  [6359] = 3125,
  [6360] = 2987,
  [6361] = 3107,
  [6362] = 2927,
  [6363] = 3205,
  [6364] = 2985,
  [6365] = 2924,
  [6366] = 3046,
  [6367] = 3124,
  [6368] = 2986,
  [6369] = 2930,
  [6370] = 3107,
  [6371] = 2931,
  [6372] = 2932,
  [6373] = 3123,
  [6374] = 2982,
  [6375] = 2982,
  [6376] = 2933,
  [6377] = 2929,
  [6378] = 2926,
  [6379] = 3133,
  [6380] = 2990,
  [6381] = 2986,
  [6382] = 2957,
  [6383] = 3122,
  [6384] = 3019,
  [6385] = 2957,
  [6386] = 3020,
  [6387] = 3021,
  [6388] = 3121,
  [6389] = 3120,
  [6390] = 2999,
  [6391] = 2998,
  [6392] = 2988,
  [6393] = 2968,
  [6394] = 2990,
  [6395] = 3154,
  [6396] = 3003,
  [6397] = 6298,
  [6398] = 2983,
  [6399] = 2982,
  [6400] = 3021,
  [6401] = 2997,
  [6402] = 2991,
  [6403] = 3125,
  [6404] = 2956,
  [6405] = 2992,
  [6406] = 3019,
  [6407] = 3034,
  [6408] = 4066,
  [6409] = 3206,
  [6410] = 2927,
  [6411] = 2933,
  [6412] = 3116,
  [6413] = 3011,
  [6414] = 3002,
  [6415] = 3014,
  [6416] = 2998,
  [6417] = 2957,
  [6418] = 3012,
  [6419] = 3009,
  [6420] = 3008,
  [6421] = 3108,
  [6422] = 2927,
  [6423] = 2929,
  [6424] = 2926,
  [6425] = 3024,
  [6426] = 2996,
  [6427] = 3007,
  [6428] = 3001,
  [6429] = 3006,
  [6430] = 3109,
  [6431] = 3002,
  [6432] = 3031,
  [6433] = 3110,
  [6434] = 3033,
  [6435] = 3111,
  [6436] = 3001,
  [6437] = 2983,
  [6438] = 3124,
  [6439] = 3003,
  [6440] = 3005,
  [6441] = 3004,
  [6442] = 3003,
  [6443] = 2957,
  [6444] = 2925,
  [6445] = 2997,
  [6446] = 6275,
  [6447] = 3002,
  [6448] = 2999,
  [6449] = 3123,
  [6450] = 2985,
  [6451] = 3154,
  [6452] = 2987,
  [6453] = 2930,
  [6454] = 3004,
  [6455] = 3001,
  [6456] = 3005,
  [6457] = 3006,
  [6458] = 3046,
  [6459] = 3148,
  [6460] = 3007,
  [6461] = 3008,
  [6462] = 2996,
  [6463] = 3009,
  [6464] = 2992,
  [6465] = 3023,
  [6466] = 2991,
  [6467] = 3012,
  [6468] = 3009,
  [6469] = 3014,
  [6470] = 3018,
  [6471] = 2988,
  [6472] = 2990,
  [6473] = 3019,
  [6474] = 3020,
  [6475] = 3021,
  [6476] = 6298,
  [6477] = 2924,
  [6478] = 3023,
  [6479] = 3025,
  [6480] = 2931,
  [6481] = 3034,
  [6482] = 3035,
  [6483] = 3011,
  [6484] = 3037,
  [6485] = 2932,
  [6486] = 2986,
  [6487] = 2972,
  [6488] = 3154,
  [6489] = 3038,
  [6490] = 2999,
  [6491] = 3122,
  [6492] = 3133,
  [6493] = 2997,
  [6494] = 3132,
  [6495] = 2999,
  [6496] = 3040,
  [6497] = 3042,
  [6498] = 3131,
  [6499] = 3133,
  [6500] = 3129,
  [6501] = 3128,
  [6502] = 3034,
  [6503] = 3121,
  [6504] = 3035,
  [6505] = 3011,
  [6506] = 3037,
  [6507] = 2933,
  [6508] = 2998,
  [6509] = 3125,
  [6510] = 3124,
  [6511] = 3047,
  [6512] = 2929,
  [6513] = 3132,
  [6514] = 3048,
  [6515] = 3049,
  [6516] = 3050,
  [6517] = 3024,
  [6518] = 3046,
  [6519] = 3123,
  [6520] = 3051,
  [6521] = 3122,
  [6522] = 3108,
  [6523] = 3121,
  [6524] = 3031,
  [6525] = 2927,
  [6526] = 3033,
  [6527] = 3154,
  [6528] = 3120,
  [6529] = 2983,
  [6530] = 2968,
  [6531] = 3131,
  [6532] = 3020,
  [6533] = 3128,
  [6534] = 3116,
  [6535] = 3024,
  [6536] = 2968,
  [6537] = 3148,
  [6538] = 2926,
  [6539] = 3052,
  [6540] = 2926,
  [6541] = 3133,
  [6542] = 2985,
  [6543] = 3109,
  [6544] = 2987,
  [6545] = 3125,
  [6546] = 2956,
  [6547] = 3124,
  [6548] = 3123,
  [6549] = 3116,
  [6550] = 3046,
  [6551] = 2982,
  [6552] = 2930,
  [6553] = 2931,
  [6554] = 2932,
  [6555] = 3031,
  [6556] = 3110,
  [6557] = 3033,
  [6558] = 2925,
  [6559] = 3122,
  [6560] = 2933,
  [6561] = 2929,
  [6562] = 3121,
  [6563] = 3120,
  [6564] = 2990,
  [6565] = 3111,
  [6566] = 2998,
  [6567] = 3110,
  [6568] = 3148,
  [6569] = 3110,
  [6570] = 2925,
  [6571] = 3109,
  [6572] = 6275,
  [6573] = 3109,
  [6574] = 3111,
  [6575] = 3108,
  [6576] = 3107,
  [6577] = 2982,
  [6578] = 3111,
  [6579] = 2996,
  [6580] = 3120,
  [6581] = 3121,
  [6582] = 2957,
  [6583] = 3122,
  [6584] = 3123,
  [6585] = 2997,
  [6586] = 3108,
  [6587] = 2999,
  [6588] = 2957,
  [6589] = 2924,
  [6590] = 6298,
  [6591] = 3038,
  [6592] = 3124,
  [6593] = 4042,
  [6594] = 3129,
  [6595] = 3125,
  [6596] = 3033,
  [6597] = 3011,
  [6598] = 2927,
  [6599] = 3025,
  [6600] = 2998,
  [6601] = 3031,
  [6602] = 2957,
  [6603] = 3051,
  [6604] = 3050,
  [6605] = 2956,
  [6606] = 3024,
  [6607] = 3827,
  [6608] = 3116,
  [6609] = 3024,
  [6610] = 2985,
  [6611] = 3107,
  [6612] = 2930,
  [6613] = 2931,
  [6614] = 2932,
  [6615] = 3108,
  [6616] = 3031,
  [6617] = 2956,
  [6618] = 3033,
  [6619] = 3206,
  [6620] = 3207,
  [6621] = 2983,
  [6622] = 3120,
  [6623] = 3128,
  [6624] = 3121,
  [6625] = 2933,
  [6626] = 3122,
  [6627] = 2929,
  [6628] = 2926,
  [6629] = 3123,
  [6630] = 2992,
  [6631] = 3124,
  [6632] = 3125,
  [6633] = 3049,
  [6634] = 2925,
  [6635] = 2991,
  [6636] = 3205,
  [6637] = 3011,
  [6638] = 3205,
  [6639] = 2988,
  [6640] = 3048,
  [6641] = 3208,
  [6642] = 3047,
  [6643] = 3208,
  [6644] = 3046,
  [6645] = 2990,
  [6646] = 3129,
  [6647] = 2983,
  [6648] = 3128,
  [6649] = 2982,
  [6650] = 3107,
  [6651] = 3129,
  [6652] = 2997,
  [6653] = 3131,
  [6654] = 3107,
  [6655] = 2983,
  [6656] = 3132,
  [6657] = 3131,
  [6658] = 3133,
  [6659] = 2924,
  [6660] = 3120,
  [6661] = 3042,
  [6662] = 3207,
  [6663] = 2932,
  [6664] = 3206,
  [6665] = 3040,
  [6666] = 3132,
  [6667] = 2924,
  [6668] = 3001,
  [6669] = 3037,
  [6670] = 3035,
  [6671] = 3021,
  [6672] = 6672,
  [6673] = 3020,
  [6674] = 3019,
  [6675] = 3018,
  [6676] = 3014,
  [6677] = 3034,
  [6678] = 3012,
  [6679] = 3040,
  [6680] = 3009,
  [6681] = 3008,
  [6682] = 3007,
  [6683] = 3206,
  [6684] = 3154,
  [6685] = 3006,
  [6686] = 3005,
  [6687] = 3004,
  [6688] = 3003,
  [6689] = 3038,
  [6690] = 3002,
  [6691] = 3001,
  [6692] = 2924,
  [6693] = 2926,
  [6694] = 2929,
  [6695] = 2933,
  [6696] = 2996,
  [6697] = 3207,
  [6698] = 2992,
  [6699] = 2991,
  [6700] = 2988,
  [6701] = 3025,
  [6702] = 3023,
  [6703] = 2932,
  [6704] = 2931,
  [6705] = 2930,
  [6706] = 3020,
  [6707] = 2986,
  [6708] = 2999,
  [6709] = 3009,
  [6710] = 3042,
  [6711] = 3008,
  [6712] = 3120,
  [6713] = 3007,
  [6714] = 3208,
  [6715] = 3052,
  [6716] = 3207,
  [6717] = 3047,
  [6718] = 3148,
  [6719] = 3048,
  [6720] = 3049,
  [6721] = 3050,
  [6722] = 2972,
  [6723] = 3051,
  [6724] = 3052,
  [6725] = 3051,
  [6726] = 2982,
  [6727] = 3050,
  [6728] = 3133,
  [6729] = 3049,
  [6730] = 3048,
  [6731] = 3132,
  [6732] = 3047,
  [6733] = 3131,
  [6734] = 3129,
  [6735] = 3206,
  [6736] = 3128,
  [6737] = 3205,
  [6738] = 3125,
  [6739] = 3208,
  [6740] = 3124,
  [6741] = 3011,
  [6742] = 3006,
  [6743] = 3123,
  [6744] = 3042,
  [6745] = 3040,
  [6746] = 3038,
  [6747] = 3122,
  [6748] = 3121,
  [6749] = 3037,
  [6750] = 3035,
  [6751] = 3034,
  [6752] = 3005,
  [6753] = 3019,
  [6754] = 3014,
  [6755] = 2924,
  [6756] = 3025,
  [6757] = 3023,
  [6758] = 3004,
  [6759] = 3012,
  [6760] = 3021,
  [6761] = 2968,
  [6762] = 3018,
  [6763] = 3133,
  [6764] = 3023,
  [6765] = 3020,
  [6766] = 3019,
  [6767] = 3018,
  [6768] = 3014,
  [6769] = 3003,
  [6770] = 3012,
  [6771] = 3002,
  [6772] = 3009,
  [6773] = 3008,
  [6774] = 3007,
  [6775] = 3001,
  [6776] = 3116,
  [6777] = 3006,
  [6778] = 3005,
  [6779] = 3004,
  [6780] = 3003,
  [6781] = 2926,
  [6782] = 3002,
  [6783] = 3001,
  [6784] = 2929,
  [6785] = 2926,
  [6786] = 2929,
  [6787] = 2933,
  [6788] = 2996,
  [6789] = 3025,
  [6790] = 2992,
  [6791] = 2991,
  [6792] = 2988,
  [6793] = 2933,
  [6794] = 3154,
  [6795] = 2932,
  [6796] = 2931,
  [6797] = 2930,
  [6798] = 2996,
  [6799] = 2986,
  [6800] = 3108,
  [6801] = 3003,
  [6802] = 3131,
  [6803] = 3034,
  [6804] = 2992,
  [6805] = 2991,
  [6806] = 3035,
  [6807] = 3037,
  [6808] = 3002,
  [6809] = 3129,
  [6810] = 3038,
  [6811] = 2957,
  [6812] = 3003,
  [6813] = 3001,
  [6814] = 2972,
  [6815] = 3040,
  [6816] = 3042,
  [6817] = 2996,
  [6818] = 2982,
  [6819] = 3111,
  [6820] = 3110,
  [6821] = 3109,
  [6822] = 2988,
  [6823] = 3108,
  [6824] = 2932,
  [6825] = 2931,
  [6826] = 2930,
  [6827] = 3109,
  [6828] = 2992,
  [6829] = 2991,
  [6830] = 3004,
  [6831] = 3205,
  [6832] = 3128,
  [6833] = 3107,
  [6834] = 3005,
  [6835] = 2927,
  [6836] = 3006,
  [6837] = 2988,
  [6838] = 3107,
  [6839] = 3116,
  [6840] = 2986,
  [6841] = 2983,
  [6842] = 2986,
  [6843] = 3047,
  [6844] = 3148,
  [6845] = 3048,
  [6846] = 2972,
  [6847] = 3049,
  [6848] = 3110,
  [6849] = 2998,
  [6850] = 2987,
  [6851] = 3050,
  [6852] = 3111,
  [6853] = 2968,
  [6854] = 3007,
  [6855] = 2987,
  [6856] = 3008,
  [6857] = 3154,
  [6858] = 2982,
  [6859] = 3046,
  [6860] = 3009,
  [6861] = 3051,
  [6862] = 3046,
  [6863] = 3012,
  [6864] = 3148,
  [6865] = 2997,
  [6866] = 3125,
  [6867] = 3014,
  [6868] = 2925,
  [6869] = 3122,
  [6870] = 3124,
  [6871] = 3123,
  [6872] = 3001,
  [6873] = 2982,
  [6874] = 3133,
  [6875] = 3132,
  [6876] = 2998,
  [6877] = 2996,
  [6878] = 3131,
  [6879] = 3129,
  [6880] = 3018,
  [6881] = 3046,
  [6882] = 3128,
  [6883] = 3019,
  [6884] = 2972,
  [6885] = 3124,
  [6886] = 3122,
  [6887] = 3121,
  [6888] = 3125,
  [6889] = 3116,
  [6890] = 3124,
  [6891] = 3123,
  [6892] = 3122,
  [6893] = 3121,
  [6894] = 3120,
  [6895] = 3004,
  [6896] = 3052,
  [6897] = 3107,
  [6898] = 3120,
  [6899] = 3128,
  [6900] = 2982,
  [6901] = 2983,
  [6902] = 3111,
  [6903] = 3110,
  [6904] = 6672,
  [6905] = 3109,
  [6906] = 3205,
  [6907] = 3108,
  [6908] = 2999,
  [6909] = 3107,
  [6910] = 2985,
  [6911] = 3020,
  [6912] = 2987,
  [6913] = 3005,
  [6914] = 3133,
  [6915] = 3132,
  [6916] = 3006,
  [6917] = 6917,
  [6918] = 3007,
  [6919] = 3008,
  [6920] = 3154,
  [6921] = 3131,
  [6922] = 3132,
  [6923] = 2968,
  [6924] = 3133,
  [6925] = 3129,
  [6926] = 3206,
  [6927] = 2927,
  [6928] = 3207,
  [6929] = 3109,
  [6930] = 3116,
  [6931] = 3009,
  [6932] = 2990,
  [6933] = 3012,
  [6934] = 3148,
  [6935] = 2987,
  [6936] = 3125,
  [6937] = 3108,
  [6938] = 3827,
  [6939] = 3124,
  [6940] = 3123,
  [6941] = 3122,
  [6942] = 3121,
  [6943] = 3208,
  [6944] = 3120,
  [6945] = 2983,
  [6946] = 3109,
  [6947] = 2982,
  [6948] = 3111,
  [6949] = 3033,
  [6950] = 3110,
  [6951] = 2968,
  [6952] = 3111,
  [6953] = 2997,
  [6954] = 3120,
  [6955] = 2999,
  [6956] = 3121,
  [6957] = 3116,
  [6958] = 3122,
  [6959] = 3021,
  [6960] = 2925,
  [6961] = 3123,
  [6962] = 3014,
  [6963] = 3124,
  [6964] = 3125,
  [6965] = 3011,
  [6966] = 3110,
  [6967] = 3031,
  [6968] = 2986,
  [6969] = 3033,
  [6970] = 2992,
  [6971] = 3031,
  [6972] = 2991,
  [6973] = 2988,
  [6974] = 3024,
  [6975] = 4066,
  [6976] = 3024,
  [6977] = 3024,
  [6978] = 3018,
  [6979] = 3148,
  [6980] = 3116,
  [6981] = 3128,
  [6982] = 3019,
  [6983] = 3024,
  [6984] = 3031,
  [6985] = 3023,
  [6986] = 3033,
  [6987] = 3011,
  [6988] = 3025,
  [6989] = 2988,
  [6990] = 3205,
  [6991] = 2927,
  [6992] = 3020,
  [6993] = 3021,
  [6994] = 2997,
  [6995] = 2991,
  [6996] = 2992,
  [6997] = 3021,
  [6998] = 2986,
  [6999] = 3034,
  [7000] = 3108,
  [7001] = 2996,
  [7002] = 2998,
  [7003] = 2990,
  [7004] = 3031,
  [7005] = 2999,
  [7006] = 3035,
  [7007] = 3001,
  [7008] = 3129,
  [7009] = 3002,
  [7010] = 3131,
  [7011] = 3154,
  [7012] = 3011,
  [7013] = 3003,
  [7014] = 3004,
  [7015] = 3033,
  [7016] = 4042,
  [7017] = 3208,
  [7018] = 3005,
  [7019] = 2985,
  [7020] = 6672,
  [7021] = 3006,
  [7022] = 2982,
  [7023] = 3111,
  [7024] = 3023,
  [7025] = 3207,
  [7026] = 3110,
  [7027] = 3037,
  [7028] = 3206,
  [7029] = 3154,
  [7030] = 3109,
  [7031] = 2990,
  [7032] = 3007,
  [7033] = 3008,
  [7034] = 3205,
  [7035] = 3009,
  [7036] = 3132,
  [7037] = 3148,
  [7038] = 2999,
  [7039] = 3133,
  [7040] = 3108,
  [7041] = 2998,
  [7042] = 3012,
  [7043] = 3206,
  [7044] = 3207,
  [7045] = 2997,
  [7046] = 3014,
  [7047] = 3018,
  [7048] = 3025,
  [7049] = 2998,
  [7050] = 3019,
  [7051] = 3038,
  [7052] = 3020,
  [7053] = 3034,
  [7054] = 3133,
  [7055] = 3035,
  [7056] = 3037,
  [7057] = 3132,
  [7058] = 3154,
  [7059] = 3131,
  [7060] = 3040,
  [7061] = 3129,
  [7062] = 3038,
  [7063] = 2998,
  [7064] = 3042,
  [7065] = 2983,
  [7066] = 3128,
  [7067] = 3052,
  [7068] = 3122,
  [7069] = 2968,
  [7070] = 3148,
  [7071] = 2957,
  [7072] = 3132,
  [7073] = 3125,
  [7074] = 3124,
  [7075] = 3123,
  [7076] = 3122,
  [7077] = 2983,
  [7078] = 3040,
  [7079] = 3042,
  [7080] = 3121,
  [7081] = 2972,
  [7082] = 3120,
  [7083] = 3021,
  [7084] = 3023,
  [7085] = 3025,
  [7086] = 3154,
  [7087] = 3107,
  [7088] = 3131,
  [7089] = 3046,
  [7090] = 2985,
  [7091] = 3047,
  [7092] = 3034,
  [7093] = 3035,
  [7094] = 3037,
  [7095] = 2990,
  [7096] = 3048,
  [7097] = 3129,
  [7098] = 2968,
  [7099] = 3038,
  [7100] = 3049,
  [7101] = 3050,
  [7102] = 3040,
  [7103] = 3046,
  [7104] = 3047,
  [7105] = 3042,
  [7106] = 3124,
  [7107] = 3048,
  [7108] = 2990,
  [7109] = 3049,
  [7110] = 6917,
  [7111] = 2988,
  [7112] = 3051,
  [7113] = 3052,
  [7114] = 3107,
  [7115] = 3046,
  [7116] = 3050,
  [7117] = 2982,
  [7118] = 2985,
  [7119] = 3047,
  [7120] = 3148,
  [7121] = 3048,
  [7122] = 3049,
  [7123] = 3051,
  [7124] = 2987,
  [7125] = 3051,
  [7126] = 3050,
  [7127] = 2985,
  [7128] = 3052,
  [7129] = 3051,
  [7130] = 2957,
  [7131] = 2972,
  [7132] = 3125,
  [7133] = 3133,
  [7134] = 3132,
  [7135] = 2972,
  [7136] = 3123,
  [7137] = 3121,
  [7138] = 3052,
  [7139] = 3131,
  [7140] = 3051,
  [7141] = 2985,
  [7142] = 3050,
  [7143] = 2985,
  [7144] = 3120,
  [7145] = 3050,
  [7146] = 6917,
  [7147] = 2983,
  [7148] = 3048,
  [7149] = 2982,
  [7150] = 3047,
  [7151] = 3046,
  [7152] = 3129,
  [7153] = 3033,
  [7154] = 3031,
  [7155] = 2986,
  [7156] = 2987,
  [7157] = 3049,
  [7158] = 3128,
  [7159] = 3208,
  [7160] = 2983,
  [7161] = 3116,
  [7162] = 3024,
  [7163] = 2983,
  [7164] = 3006,
  [7165] = 2925,
  [7166] = 2991,
  [7167] = 3125,
  [7168] = 3124,
  [7169] = 3123,
  [7170] = 3049,
  [7171] = 3042,
  [7172] = 3040,
  [7173] = 3122,
  [7174] = 3038,
  [7175] = 2990,
  [7176] = 3037,
  [7177] = 3035,
  [7178] = 3034,
  [7179] = 3121,
  [7180] = 2992,
  [7181] = 3120,
  [7182] = 3025,
  [7183] = 3048,
  [7184] = 3023,
  [7185] = 3047,
  [7186] = 3205,
  [7187] = 2997,
  [7188] = 3116,
  [7189] = 2972,
  [7190] = 3011,
  [7191] = 2957,
  [7192] = 2996,
  [7193] = 3052,
  [7194] = 2998,
  [7195] = 3001,
  [7196] = 3116,
  [7197] = 3021,
  [7198] = 2968,
  [7199] = 3107,
  [7200] = 2983,
  [7201] = 2999,
  [7202] = 3002,
  [7203] = 3011,
  [7204] = 3003,
  [7205] = 3004,
  [7206] = 3005,
  [7207] = 3206,
  [7208] = 3207,
  [7209] = 3111,
  [7210] = 3110,
  [7211] = 3109,
  [7212] = 3020,
  [7213] = 3108,
  [7214] = 3019,
  [7215] = 3018,
  [7216] = 3007,
  [7217] = 3008,
  [7218] = 3014,
  [7219] = 3208,
  [7220] = 2997,
  [7221] = 3012,
  [7222] = 3046,
  [7223] = 3009,
  [7224] = 3009,
  [7225] = 2999,
  [7226] = 3008,
  [7227] = 3012,
  [7228] = 2997,
  [7229] = 3007,
  [7230] = 3014,
  [7231] = 3018,
  [7232] = 3019,
  [7233] = 3827,
  [7234] = 3128,
  [7235] = 3020,
  [7236] = 3205,
  [7237] = 3024,
  [7238] = 3133,
  [7239] = 6672,
  [7240] = 2968,
  [7241] = 3021,
  [7242] = 3132,
  [7243] = 3827,
  [7244] = 3107,
  [7245] = 3023,
  [7246] = 3025,
  [7247] = 3206,
  [7248] = 3031,
  [7249] = 3207,
  [7250] = 3034,
  [7251] = 3006,
  [7252] = 2987,
  [7253] = 3005,
  [7254] = 3035,
  [7255] = 3033,
  [7256] = 3033,
  [7257] = 3004,
  [7258] = 3037,
  [7259] = 3031,
  [7260] = 2990,
  [7261] = 3003,
  [7262] = 3011,
  [7263] = 3002,
  [7264] = 3038,
  [7265] = 3002,
  [7266] = 2998,
  [7267] = 2996,
  [7268] = 2986,
  [7269] = 3208,
  [7270] = 3040,
  [7271] = 3111,
  [7272] = 3042,
  [7273] = 3110,
  [7274] = 6917,
  [7275] = 3024,
  [7276] = 3109,
  [7277] = 2988,
  [7278] = 2992,
  [7279] = 2991,
  [7280] = 3108,
  [7281] = 2932,
  [7282] = 2988,
  [7283] = 2991,
  [7284] = 2992,
  [7285] = 3132,
  [7286] = 2931,
  [7287] = 2996,
  [7288] = 2933,
  [7289] = 2929,
  [7290] = 2926,
  [7291] = 2930,
  [7292] = 2986,
  [7293] = 3001,
  [7294] = 7294,
  [7295] = 3002,
  [7296] = 7296,
  [7297] = 3003,
  [7298] = 3004,
  [7299] = 3005,
  [7300] = 3006,
  [7301] = 3208,
  [7302] = 7302,
  [7303] = 3007,
  [7304] = 3008,
  [7305] = 3009,
  [7306] = 3012,
  [7307] = 7307,
  [7308] = 3014,
  [7309] = 3018,
  [7310] = 3019,
  [7311] = 3020,
  [7312] = 3207,
  [7313] = 3206,
  [7314] = 3021,
  [7315] = 3122,
  [7316] = 3023,
  [7317] = 3025,
  [7318] = 2924,
  [7319] = 4042,
  [7320] = 2972,
  [7321] = 3034,
  [7322] = 4042,
  [7323] = 3035,
  [7324] = 3037,
  [7325] = 3038,
  [7326] = 3040,
  [7327] = 2968,
  [7328] = 3042,
  [7329] = 2999,
  [7330] = 2985,
  [7331] = 3205,
  [7332] = 2987,
  [7333] = 2990,
  [7334] = 2997,
  [7335] = 2999,
  [7336] = 7336,
  [7337] = 3011,
  [7338] = 3047,
  [7339] = 3048,
  [7340] = 3049,
  [7341] = 3050,
  [7342] = 3024,
  [7343] = 3051,
  [7344] = 4066,
  [7345] = 3031,
  [7346] = 3033,
  [7347] = 4066,
  [7348] = 3052,
  [7349] = 2985,
  [7350] = 2990,
  [7351] = 2987,
  [7352] = 2997,
  [7353] = 3033,
  [7354] = 3031,
  [7355] = 3011,
  [7356] = 2986,
  [7357] = 3128,
  [7358] = 7294,
  [7359] = 2930,
  [7360] = 2931,
  [7361] = 3827,
  [7362] = 3154,
  [7363] = 3131,
  [7364] = 3024,
  [7365] = 3129,
  [7366] = 3205,
  [7367] = 2932,
  [7368] = 3024,
  [7369] = 3031,
  [7370] = 2985,
  [7371] = 2988,
  [7372] = 2987,
  [7373] = 3033,
  [7374] = 2999,
  [7375] = 3122,
  [7376] = 2991,
  [7377] = 3148,
  [7378] = 2992,
  [7379] = 3003,
  [7380] = 3125,
  [7381] = 7296,
  [7382] = 7302,
  [7383] = 3123,
  [7384] = 2996,
  [7385] = 3121,
  [7386] = 3120,
  [7387] = 2933,
  [7388] = 2929,
  [7389] = 3206,
  [7390] = 2926,
  [7391] = 3001,
  [7392] = 3132,
  [7393] = 2990,
  [7394] = 3002,
  [7395] = 3011,
  [7396] = 3207,
  [7397] = 3004,
  [7398] = 3005,
  [7399] = 3006,
  [7400] = 3208,
  [7401] = 7307,
  [7402] = 3007,
  [7403] = 3008,
  [7404] = 3009,
  [7405] = 3012,
  [7406] = 2997,
  [7407] = 3014,
  [7408] = 3018,
  [7409] = 3019,
  [7410] = 3020,
  [7411] = 2982,
  [7412] = 2983,
  [7413] = 2968,
  [7414] = 3021,
  [7415] = 3025,
  [7416] = 4066,
  [7417] = 2924,
  [7418] = 2987,
  [7419] = 3034,
  [7420] = 3035,
  [7421] = 3037,
  [7422] = 2990,
  [7423] = 3038,
  [7424] = 2997,
  [7425] = 3040,
  [7426] = 2999,
  [7427] = 3042,
  [7428] = 4042,
  [7429] = 7429,
  [7430] = 3051,
  [7431] = 7429,
  [7432] = 7336,
  [7433] = 3107,
  [7434] = 3108,
  [7435] = 3109,
  [7436] = 3110,
  [7437] = 3827,
  [7438] = 3111,
  [7439] = 3208,
  [7440] = 3047,
  [7441] = 3116,
  [7442] = 3048,
  [7443] = 3049,
  [7444] = 3207,
  [7445] = 3206,
  [7446] = 3827,
  [7447] = 3827,
  [7448] = 3122,
  [7449] = 3033,
  [7450] = 3031,
  [7451] = 3050,
  [7452] = 3024,
  [7453] = 2985,
  [7454] = 3124,
  [7455] = 3205,
  [7456] = 3132,
  [7457] = 3133,
  [7458] = 3827,
  [7459] = 2927,
  [7460] = 2972,
  [7461] = 3128,
  [7462] = 3052,
  [7463] = 3011,
  [7464] = 3827,
  [7465] = 2925,
  [7466] = 3827,
  [7467] = 3051,
  [7468] = 7468,
  [7469] = 3110,
  [7470] = 3133,
  [7471] = 3132,
  [7472] = 3128,
  [7473] = 7473,
  [7474] = 7474,
  [7475] = 3109,
  [7476] = 7476,
  [7477] = 7477,
  [7478] = 7478,
  [7479] = 7479,
  [7480] = 3124,
  [7481] = 3122,
  [7482] = 5419,
  [7483] = 7483,
  [7484] = 5496,
  [7485] = 3116,
  [7486] = 3111,
  [7487] = 3108,
  [7488] = 3110,
  [7489] = 3109,
  [7490] = 3108,
  [7491] = 3205,
  [7492] = 7492,
  [7493] = 3111,
  [7494] = 3206,
  [7495] = 3207,
  [7496] = 3154,
  [7497] = 3208,
  [7498] = 3107,
  [7499] = 4066,
  [7500] = 3148,
  [7501] = 3827,
  [7502] = 4042,
  [7503] = 7503,
  [7504] = 7504,
  [7505] = 5457,
  [7506] = 7506,
  [7507] = 7507,
  [7508] = 7508,
  [7509] = 7509,
  [7510] = 7510,
  [7511] = 7511,
  [7512] = 5440,
  [7513] = 7513,
  [7514] = 7514,
  [7515] = 7515,
  [7516] = 3208,
  [7517] = 3125,
  [7518] = 4042,
  [7519] = 7307,
  [7520] = 3131,
  [7521] = 3129,
  [7522] = 7522,
  [7523] = 5325,
  [7524] = 3125,
  [7525] = 3123,
  [7526] = 5476,
  [7527] = 3827,
  [7528] = 3121,
  [7529] = 3120,
  [7530] = 7530,
  [7531] = 7531,
  [7532] = 4066,
  [7533] = 4042,
  [7534] = 3132,
  [7535] = 5434,
  [7536] = 7536,
  [7537] = 5452,
  [7538] = 7538,
  [7539] = 4066,
  [7540] = 4066,
  [7541] = 3208,
  [7542] = 3207,
  [7543] = 3206,
  [7544] = 3205,
  [7545] = 4042,
  [7546] = 3120,
  [7547] = 5390,
  [7548] = 3121,
  [7549] = 5356,
  [7550] = 3123,
  [7551] = 7551,
  [7552] = 7552,
  [7553] = 4042,
  [7554] = 7554,
  [7555] = 4066,
  [7556] = 3125,
  [7557] = 7557,
  [7558] = 7558,
  [7559] = 7559,
  [7560] = 3148,
  [7561] = 5452,
  [7562] = 3205,
  [7563] = 7563,
  [7564] = 3107,
  [7565] = 7563,
  [7566] = 3129,
  [7567] = 3131,
  [7568] = 3116,
  [7569] = 4042,
  [7570] = 3154,
  [7571] = 7429,
  [7572] = 3111,
  [7573] = 3110,
  [7574] = 3109,
  [7575] = 3108,
  [7576] = 7557,
  [7577] = 7558,
  [7578] = 3107,
  [7579] = 7538,
  [7580] = 2983,
  [7581] = 2982,
  [7582] = 5521,
  [7583] = 7522,
  [7584] = 7336,
  [7585] = 5386,
  [7586] = 3827,
  [7587] = 3122,
  [7588] = 3023,
  [7589] = 5434,
  [7590] = 4066,
  [7591] = 7591,
  [7592] = 5440,
  [7593] = 7593,
  [7594] = 5457,
  [7595] = 3154,
  [7596] = 7552,
  [7597] = 7551,
  [7598] = 3148,
  [7599] = 7478,
  [7600] = 7476,
  [7601] = 2925,
  [7602] = 5496,
  [7603] = 3133,
  [7604] = 3033,
  [7605] = 3031,
  [7606] = 3024,
  [7607] = 3011,
  [7608] = 7608,
  [7609] = 3208,
  [7610] = 2999,
  [7611] = 2997,
  [7612] = 3827,
  [7613] = 3206,
  [7614] = 4066,
  [7615] = 2990,
  [7616] = 2987,
  [7617] = 2985,
  [7618] = 3131,
  [7619] = 3129,
  [7620] = 7468,
  [7621] = 3205,
  [7622] = 3128,
  [7623] = 3827,
  [7624] = 3120,
  [7625] = 3207,
  [7626] = 3121,
  [7627] = 3124,
  [7628] = 3123,
  [7629] = 3123,
  [7630] = 7536,
  [7631] = 3121,
  [7632] = 3129,
  [7633] = 3120,
  [7634] = 3148,
  [7635] = 5325,
  [7636] = 3107,
  [7637] = 5476,
  [7638] = 3128,
  [7639] = 2927,
  [7640] = 7483,
  [7641] = 4042,
  [7642] = 7492,
  [7643] = 7503,
  [7644] = 7530,
  [7645] = 7504,
  [7646] = 3131,
  [7647] = 3154,
  [7648] = 7608,
  [7649] = 2968,
  [7650] = 5356,
  [7651] = 3124,
  [7652] = 7593,
  [7653] = 7302,
  [7654] = 7296,
  [7655] = 3116,
  [7656] = 3133,
  [7657] = 7559,
  [7658] = 7554,
  [7659] = 2972,
  [7660] = 3827,
  [7661] = 3125,
  [7662] = 2986,
  [7663] = 7515,
  [7664] = 7514,
  [7665] = 7513,
  [7666] = 2930,
  [7667] = 7509,
  [7668] = 3108,
  [7669] = 2931,
  [7670] = 2932,
  [7671] = 3109,
  [7672] = 2988,
  [7673] = 3110,
  [7674] = 3111,
  [7675] = 2991,
  [7676] = 2992,
  [7677] = 2996,
  [7678] = 2933,
  [7679] = 7479,
  [7680] = 7477,
  [7681] = 2929,
  [7682] = 2926,
  [7683] = 3001,
  [7684] = 3002,
  [7685] = 3827,
  [7686] = 7531,
  [7687] = 7474,
  [7688] = 7473,
  [7689] = 3003,
  [7690] = 3004,
  [7691] = 3005,
  [7692] = 3006,
  [7693] = 2925,
  [7694] = 3007,
  [7695] = 3008,
  [7696] = 3009,
  [7697] = 3012,
  [7698] = 3014,
  [7699] = 3018,
  [7700] = 3019,
  [7701] = 3020,
  [7702] = 3021,
  [7703] = 3023,
  [7704] = 3025,
  [7705] = 5521,
  [7706] = 2924,
  [7707] = 3034,
  [7708] = 3035,
  [7709] = 3037,
  [7710] = 3038,
  [7711] = 3040,
  [7712] = 3042,
  [7713] = 3207,
  [7714] = 2927,
  [7715] = 7294,
  [7716] = 7591,
  [7717] = 3206,
  [7718] = 3047,
  [7719] = 3048,
  [7720] = 3049,
  [7721] = 7511,
  [7722] = 3050,
  [7723] = 7510,
  [7724] = 7506,
  [7725] = 3052,
  [7726] = 7507,
  [7727] = 7508,
  [7728] = 5325,
  [7729] = 5440,
  [7730] = 7307,
  [7731] = 4042,
  [7732] = 7732,
  [7733] = 7733,
  [7734] = 7336,
  [7735] = 7732,
  [7736] = 7302,
  [7737] = 7296,
  [7738] = 7732,
  [7739] = 7478,
  [7740] = 4066,
  [7741] = 7294,
  [7742] = 3133,
  [7743] = 7476,
  [7744] = 5496,
  [7745] = 7473,
  [7746] = 7474,
  [7747] = 7531,
  [7748] = 4066,
  [7749] = 3154,
  [7750] = 7477,
  [7751] = 4042,
  [7752] = 7732,
  [7753] = 7732,
  [7754] = 7479,
  [7755] = 7732,
  [7756] = 7732,
  [7757] = 3129,
  [7758] = 3107,
  [7759] = 3128,
  [7760] = 3205,
  [7761] = 3116,
  [7762] = 4042,
  [7763] = 7563,
  [7764] = 7733,
  [7765] = 3148,
  [7766] = 7559,
  [7767] = 7732,
  [7768] = 3125,
  [7769] = 3131,
  [7770] = 5476,
  [7771] = 7554,
  [7772] = 7732,
  [7773] = 7732,
  [7774] = 3124,
  [7775] = 3123,
  [7776] = 3132,
  [7777] = 3121,
  [7778] = 3120,
  [7779] = 7732,
  [7780] = 3122,
  [7781] = 3206,
  [7782] = 3207,
  [7783] = 7732,
  [7784] = 7733,
  [7785] = 3208,
  [7786] = 4066,
  [7787] = 7608,
  [7788] = 7732,
  [7789] = 7732,
  [7790] = 7732,
  [7791] = 4042,
  [7792] = 7733,
  [7793] = 7732,
  [7794] = 5356,
  [7795] = 5434,
  [7796] = 7593,
  [7797] = 3108,
  [7798] = 7732,
  [7799] = 7538,
  [7800] = 7591,
  [7801] = 7522,
  [7802] = 7511,
  [7803] = 7510,
  [7804] = 4042,
  [7805] = 4066,
  [7806] = 3109,
  [7807] = 7530,
  [7808] = 3110,
  [7809] = 7508,
  [7810] = 5452,
  [7811] = 7507,
  [7812] = 7732,
  [7813] = 7506,
  [7814] = 3111,
  [7815] = 7483,
  [7816] = 7515,
  [7817] = 7514,
  [7818] = 7513,
  [7819] = 5521,
  [7820] = 4066,
  [7821] = 7732,
  [7822] = 7732,
  [7823] = 7536,
  [7824] = 7503,
  [7825] = 7468,
  [7826] = 4042,
  [7827] = 4066,
  [7828] = 7504,
  [7829] = 5457,
  [7830] = 7732,
  [7831] = 7509,
  [7832] = 7429,
  [7833] = 7732,
  [7834] = 7492,
  [7835] = 3042,
  [7836] = 3033,
  [7837] = 7837,
  [7838] = 7514,
  [7839] = 7837,
  [7840] = 7515,
  [7841] = 3004,
  [7842] = 3005,
  [7843] = 7843,
  [7844] = 7844,
  [7845] = 7845,
  [7846] = 7837,
  [7847] = 3006,
  [7848] = 7845,
  [7849] = 2986,
  [7850] = 7850,
  [7851] = 5496,
  [7852] = 7850,
  [7853] = 7844,
  [7854] = 7563,
  [7855] = 7530,
  [7856] = 7536,
  [7857] = 3107,
  [7858] = 7858,
  [7859] = 7837,
  [7860] = 7860,
  [7861] = 7850,
  [7862] = 7862,
  [7863] = 7863,
  [7864] = 7837,
  [7865] = 7513,
  [7866] = 7837,
  [7867] = 7468,
  [7868] = 7538,
  [7869] = 7522,
  [7870] = 7483,
  [7871] = 7837,
  [7872] = 2997,
  [7873] = 7862,
  [7874] = 7837,
  [7875] = 7837,
  [7876] = 7509,
  [7877] = 3007,
  [7878] = 7837,
  [7879] = 7844,
  [7880] = 2968,
  [7881] = 7845,
  [7882] = 3008,
  [7883] = 3108,
  [7884] = 7862,
  [7885] = 3205,
  [7886] = 3206,
  [7887] = 3009,
  [7888] = 3207,
  [7889] = 5452,
  [7890] = 3208,
  [7891] = 3109,
  [7892] = 7892,
  [7893] = 3110,
  [7894] = 3111,
  [7895] = 7554,
  [7896] = 7492,
  [7897] = 7850,
  [7898] = 2982,
  [7899] = 7473,
  [7900] = 3011,
  [7901] = 7901,
  [7902] = 3012,
  [7903] = 2926,
  [7904] = 7844,
  [7905] = 3014,
  [7906] = 3208,
  [7907] = 7844,
  [7908] = 2983,
  [7909] = 7843,
  [7910] = 7845,
  [7911] = 7837,
  [7912] = 7559,
  [7913] = 7845,
  [7914] = 7901,
  [7915] = 2925,
  [7916] = 7850,
  [7917] = 7503,
  [7918] = 7504,
  [7919] = 7850,
  [7920] = 7920,
  [7921] = 7862,
  [7922] = 7476,
  [7923] = 7860,
  [7924] = 7474,
  [7925] = 3207,
  [7926] = 7478,
  [7927] = 3206,
  [7928] = 7928,
  [7929] = 7929,
  [7930] = 7843,
  [7931] = 3154,
  [7932] = 7845,
  [7933] = 7837,
  [7934] = 7892,
  [7935] = 7850,
  [7936] = 7845,
  [7937] = 7937,
  [7938] = 5434,
  [7939] = 7850,
  [7940] = 3034,
  [7941] = 7591,
  [7942] = 7845,
  [7943] = 7531,
  [7944] = 3018,
  [7945] = 7837,
  [7946] = 3019,
  [7947] = 7947,
  [7948] = 7948,
  [7949] = 3020,
  [7950] = 7837,
  [7951] = 7951,
  [7952] = 7952,
  [7953] = 3003,
  [7954] = 3021,
  [7955] = 7955,
  [7956] = 7850,
  [7957] = 7957,
  [7958] = 7958,
  [7959] = 7850,
  [7960] = 7845,
  [7961] = 3205,
  [7962] = 7850,
  [7963] = 7845,
  [7964] = 2990,
  [7965] = 7965,
  [7966] = 3002,
  [7967] = 3148,
  [7968] = 7845,
  [7969] = 7477,
  [7970] = 2930,
  [7971] = 7892,
  [7972] = 7844,
  [7973] = 7901,
  [7974] = 3116,
  [7975] = 7845,
  [7976] = 7976,
  [7977] = 3001,
  [7978] = 7850,
  [7979] = 3133,
  [7980] = 3024,
  [7981] = 3132,
  [7982] = 3131,
  [7983] = 7983,
  [7984] = 3023,
  [7985] = 3025,
  [7986] = 2924,
  [7987] = 7987,
  [7988] = 7988,
  [7989] = 3129,
  [7990] = 3035,
  [7991] = 3037,
  [7992] = 3205,
  [7993] = 2931,
  [7994] = 3038,
  [7995] = 7995,
  [7996] = 7837,
  [7997] = 7850,
  [7998] = 2932,
  [7999] = 3206,
  [8000] = 7845,
  [8001] = 7479,
  [8002] = 3207,
  [8003] = 7843,
  [8004] = 7901,
  [8005] = 3040,
  [8006] = 3128,
  [8007] = 5325,
  [8008] = 7511,
  [8009] = 3208,
  [8010] = 5476,
  [8011] = 7892,
  [8012] = 3125,
  [8013] = 3124,
  [8014] = 7508,
  [8015] = 3123,
  [8016] = 3031,
  [8017] = 8017,
  [8018] = 3122,
  [8019] = 3121,
  [8020] = 7862,
  [8021] = 7845,
  [8022] = 3047,
  [8023] = 8023,
  [8024] = 3048,
  [8025] = 3049,
  [8026] = 3120,
  [8027] = 7850,
  [8028] = 7845,
  [8029] = 2988,
  [8030] = 3050,
  [8031] = 7837,
  [8032] = 3120,
  [8033] = 3121,
  [8034] = 7843,
  [8035] = 3051,
  [8036] = 7892,
  [8037] = 5356,
  [8038] = 7850,
  [8039] = 3123,
  [8040] = 3124,
  [8041] = 3125,
  [8042] = 2929,
  [8043] = 3052,
  [8044] = 3107,
  [8045] = 8045,
  [8046] = 2985,
  [8047] = 7845,
  [8048] = 3128,
  [8049] = 7837,
  [8050] = 3116,
  [8051] = 4772,
  [8052] = 7510,
  [8053] = 7507,
  [8054] = 7850,
  [8055] = 8055,
  [8056] = 4709,
  [8057] = 7837,
  [8058] = 3109,
  [8059] = 3154,
  [8060] = 2972,
  [8061] = 3148,
  [8062] = 3129,
  [8063] = 3131,
  [8064] = 2927,
  [8065] = 2991,
  [8066] = 3111,
  [8067] = 7845,
  [8068] = 7850,
  [8069] = 3133,
  [8070] = 2992,
  [8071] = 2933,
  [8072] = 7901,
  [8073] = 7506,
  [8074] = 3046,
  [8075] = 4727,
  [8076] = 3110,
  [8077] = 5521,
  [8078] = 7837,
  [8079] = 2987,
  [8080] = 2999,
  [8081] = 7845,
  [8082] = 7850,
  [8083] = 7850,
  [8084] = 2998,
  [8085] = 7837,
  [8086] = 7837,
  [8087] = 7850,
  [8088] = 3108,
  [8089] = 7593,
  [8090] = 2996,
  [8091] = 7850,
  [8092] = 8092,
  [8093] = 5440,
  [8094] = 7608,
  [8095] = 7850,
  [8096] = 8055,
  [8097] = 7845,
  [8098] = 7837,
  [8099] = 7845,
  [8100] = 5457,
  [8101] = 7845,
  [8102] = 7845,
  [8103] = 8103,
  [8104] = 8104,
  [8105] = 8105,
  [8106] = 8106,
  [8107] = 8105,
  [8108] = 8108,
  [8109] = 3128,
  [8110] = 7863,
  [8111] = 8111,
  [8112] = 8112,
  [8113] = 8105,
  [8114] = 8108,
  [8115] = 8111,
  [8116] = 7951,
  [8117] = 7858,
  [8118] = 8111,
  [8119] = 8105,
  [8120] = 8120,
  [8121] = 8121,
  [8122] = 4903,
  [8123] = 7952,
  [8124] = 8124,
  [8125] = 3124,
  [8126] = 7955,
  [8127] = 7948,
  [8128] = 8111,
  [8129] = 8129,
  [8130] = 8130,
  [8131] = 7863,
  [8132] = 8120,
  [8133] = 8133,
  [8134] = 7920,
  [8135] = 3122,
  [8136] = 8136,
  [8137] = 8137,
  [8138] = 8138,
  [8139] = 8108,
  [8140] = 8023,
  [8141] = 8105,
  [8142] = 8105,
  [8143] = 7920,
  [8144] = 7957,
  [8145] = 8145,
  [8146] = 7958,
  [8147] = 8108,
  [8148] = 8148,
  [8149] = 8108,
  [8150] = 8105,
  [8151] = 8105,
  [8152] = 8108,
  [8153] = 8111,
  [8154] = 8111,
  [8155] = 8155,
  [8156] = 3132,
  [8157] = 8045,
  [8158] = 8111,
  [8159] = 8159,
  [8160] = 8111,
  [8161] = 3133,
  [8162] = 7929,
  [8163] = 8163,
  [8164] = 8164,
  [8165] = 8165,
  [8166] = 8108,
  [8167] = 8130,
  [8168] = 8105,
  [8169] = 8108,
  [8170] = 8170,
  [8171] = 8137,
  [8172] = 8138,
  [8173] = 8111,
  [8174] = 8111,
  [8175] = 8108,
  [8176] = 8176,
  [8177] = 5390,
  [8178] = 8178,
  [8179] = 8105,
  [8180] = 8180,
  [8181] = 8105,
  [8182] = 8108,
  [8183] = 8108,
  [8184] = 7965,
  [8185] = 8017,
  [8186] = 8186,
  [8187] = 8145,
  [8188] = 7976,
  [8189] = 8105,
  [8190] = 8190,
  [8191] = 8108,
  [8192] = 8108,
  [8193] = 8111,
  [8194] = 8194,
  [8195] = 8195,
  [8196] = 8108,
  [8197] = 8105,
  [8198] = 8111,
  [8199] = 3116,
  [8200] = 7928,
  [8201] = 8108,
  [8202] = 7987,
  [8203] = 7929,
  [8204] = 8105,
  [8205] = 8108,
  [8206] = 8105,
  [8207] = 5419,
  [8208] = 8105,
  [8209] = 8111,
  [8210] = 8210,
  [8211] = 7937,
  [8212] = 7988,
  [8213] = 5386,
  [8214] = 8214,
  [8215] = 8104,
  [8216] = 7995,
  [8217] = 8176,
  [8218] = 8170,
  [8219] = 7947,
  [8220] = 7948,
  [8221] = 8163,
  [8222] = 8111,
  [8223] = 8111,
  [8224] = 8111,
  [8225] = 8225,
  [8226] = 8178,
  [8227] = 8159,
  [8228] = 7928,
  [8229] = 8111,
  [8230] = 7858,
  [8231] = 8105,
  [8232] = 8108,
  [8233] = 8108,
  [8234] = 8111,
  [8235] = 8105,
  [8236] = 8105,
  [8237] = 7983,
  [8238] = 8186,
  [8239] = 8239,
  [8240] = 8108,
  [8241] = 8225,
  [8242] = 8210,
  [8243] = 7947,
  [8244] = 7937,
  [8245] = 8155,
  [8246] = 8180,
  [8247] = 8164,
  [8248] = 8136,
  [8249] = 8105,
  [8250] = 8111,
  [8251] = 8108,
  [8252] = 8023,
  [8253] = 8111,
  [8254] = 8121,
  [8255] = 8121,
  [8256] = 8124,
  [8257] = 7951,
  [8258] = 8120,
  [8259] = 7952,
  [8260] = 8111,
  [8261] = 8133,
  [8262] = 7955,
  [8263] = 7957,
  [8264] = 8239,
  [8265] = 8108,
  [8266] = 7958,
  [8267] = 8108,
  [8268] = 8111,
  [8269] = 7965,
  [8270] = 8045,
  [8271] = 8017,
  [8272] = 8106,
  [8273] = 8195,
  [8274] = 8112,
  [8275] = 8129,
  [8276] = 8121,
  [8277] = 7976,
  [8278] = 7983,
  [8279] = 8105,
  [8280] = 8120,
  [8281] = 7987,
  [8282] = 7988,
  [8283] = 7995,
  [8284] = 8105,
  [8285] = 8133,
  [8286] = 8195,
  [8287] = 8287,
  [8288] = 8195,
  [8289] = 8112,
  [8290] = 8129,
  [8291] = 8291,
  [8292] = 8159,
  [8293] = 8239,
  [8294] = 8121,
  [8295] = 8225,
  [8296] = 8106,
  [8297] = 8186,
  [8298] = 8133,
  [8299] = 8239,
  [8300] = 8155,
  [8301] = 8124,
  [8302] = 8136,
  [8303] = 8121,
  [8304] = 8164,
  [8305] = 8180,
  [8306] = 8239,
  [8307] = 8210,
  [8308] = 8225,
  [8309] = 8159,
  [8310] = 8178,
  [8311] = 3827,
  [8312] = 8155,
  [8313] = 8210,
  [8314] = 8120,
  [8315] = 8129,
  [8316] = 8316,
  [8317] = 8112,
  [8318] = 8195,
  [8319] = 8180,
  [8320] = 8130,
  [8321] = 8106,
  [8322] = 8124,
  [8323] = 8137,
  [8324] = 8136,
  [8325] = 8121,
  [8326] = 8164,
  [8327] = 8180,
  [8328] = 8210,
  [8329] = 8225,
  [8330] = 8159,
  [8331] = 8145,
  [8332] = 8316,
  [8333] = 8239,
  [8334] = 8138,
  [8335] = 8164,
  [8336] = 8136,
  [8337] = 8133,
  [8338] = 8124,
  [8339] = 8121,
  [8340] = 8106,
  [8341] = 8178,
  [8342] = 8120,
  [8343] = 8138,
  [8344] = 8137,
  [8345] = 8138,
  [8346] = 8195,
  [8347] = 8137,
  [8348] = 8348,
  [8349] = 8145,
  [8350] = 8130,
  [8351] = 8210,
  [8352] = 8178,
  [8353] = 8130,
  [8354] = 8316,
  [8355] = 8137,
  [8356] = 8155,
  [8357] = 8138,
  [8358] = 8112,
  [8359] = 8130,
  [8360] = 8129,
  [8361] = 8112,
  [8362] = 8120,
  [8363] = 8186,
  [8364] = 8106,
  [8365] = 8155,
  [8366] = 8124,
  [8367] = 8186,
  [8368] = 8129,
  [8369] = 8186,
  [8370] = 8136,
  [8371] = 8164,
  [8372] = 8180,
  [8373] = 8225,
  [8374] = 8178,
  [8375] = 8159,
  [8376] = 8120,
  [8377] = 8316,
  [8378] = 8133,
  [8379] = 8379,
  [8380] = 8186,
  [8381] = 8133,
  [8382] = 8379,
  [8383] = 8239,
  [8384] = 7336,
  [8385] = 8385,
  [8386] = 8386,
  [8387] = 8239,
  [8388] = 8138,
  [8389] = 8239,
  [8390] = 7307,
  [8391] = 8186,
  [8392] = 8155,
  [8393] = 8178,
  [8394] = 8129,
  [8395] = 8112,
  [8396] = 8195,
  [8397] = 8106,
  [8398] = 8124,
  [8399] = 8136,
  [8400] = 8164,
  [8401] = 8180,
  [8402] = 8210,
  [8403] = 8225,
  [8404] = 8159,
  [8405] = 8405,
  [8406] = 3132,
  [8407] = 7302,
  [8408] = 8386,
  [8409] = 8409,
  [8410] = 8239,
  [8411] = 7296,
  [8412] = 4066,
  [8413] = 8137,
  [8414] = 4042,
  [8415] = 8130,
  [8416] = 8129,
  [8417] = 7294,
  [8418] = 8178,
  [8419] = 3132,
  [8420] = 3122,
  [8421] = 8405,
  [8422] = 8130,
  [8423] = 8133,
  [8424] = 8137,
  [8425] = 8138,
  [8426] = 8155,
  [8427] = 8385,
  [8428] = 8159,
  [8429] = 8225,
  [8430] = 8210,
  [8431] = 8180,
  [8432] = 8164,
  [8433] = 8136,
  [8434] = 8124,
  [8435] = 8106,
  [8436] = 8195,
  [8437] = 8112,
  [8438] = 8409,
  [8439] = 3122,
  [8440] = 3124,
  [8441] = 8441,
  [8442] = 3124,
  [8443] = 8443,
  [8444] = 3116,
  [8445] = 3116,
  [8446] = 8443,
  [8447] = 8447,
  [8448] = 3122,
  [8449] = 3133,
  [8450] = 8441,
  [8451] = 8441,
  [8452] = 8239,
  [8453] = 8447,
  [8454] = 8447,
  [8455] = 3133,
  [8456] = 8447,
  [8457] = 8443,
  [8458] = 8447,
  [8459] = 8443,
  [8460] = 8441,
  [8461] = 8178,
  [8462] = 8155,
  [8463] = 8441,
  [8464] = 8447,
  [8465] = 8138,
  [8466] = 8443,
  [8467] = 8441,
  [8468] = 8239,
  [8469] = 8441,
  [8470] = 8443,
  [8471] = 8447,
  [8472] = 8137,
  [8473] = 8178,
  [8474] = 8159,
  [8475] = 3132,
  [8476] = 8225,
  [8477] = 8210,
  [8478] = 8133,
  [8479] = 8443,
  [8480] = 8441,
  [8481] = 8121,
  [8482] = 8186,
  [8483] = 8130,
  [8484] = 8443,
  [8485] = 8121,
  [8486] = 8441,
  [8487] = 8443,
  [8488] = 8186,
  [8489] = 8120,
  [8490] = 8441,
  [8491] = 8443,
  [8492] = 8441,
  [8493] = 8441,
  [8494] = 8494,
  [8495] = 8443,
  [8496] = 8443,
  [8497] = 8441,
  [8498] = 8180,
  [8499] = 8164,
  [8500] = 8136,
  [8501] = 8124,
  [8502] = 8106,
  [8503] = 8195,
  [8504] = 3128,
  [8505] = 8239,
  [8506] = 8145,
  [8507] = 8443,
  [8508] = 8441,
  [8509] = 8130,
  [8510] = 8112,
  [8511] = 8129,
  [8512] = 8443,
  [8513] = 3132,
  [8514] = 8441,
  [8515] = 8443,
  [8516] = 8441,
  [8517] = 8443,
  [8518] = 8145,
  [8519] = 8155,
  [8520] = 8120,
  [8521] = 3128,
  [8522] = 8120,
  [8523] = 8441,
  [8524] = 8137,
  [8525] = 8121,
  [8526] = 8138,
  [8527] = 8443,
  [8528] = 7429,
  [8529] = 8443,
  [8530] = 3122,
  [8531] = 8441,
  [8532] = 8443,
  [8533] = 8159,
  [8534] = 8239,
  [8535] = 8447,
  [8536] = 8133,
  [8537] = 8447,
  [8538] = 8225,
  [8539] = 8441,
  [8540] = 8210,
  [8541] = 8441,
  [8542] = 8180,
  [8543] = 8441,
  [8544] = 8164,
  [8545] = 8136,
  [8546] = 8124,
  [8547] = 8441,
  [8548] = 8106,
  [8549] = 8443,
  [8550] = 8195,
  [8551] = 8121,
  [8552] = 8112,
  [8553] = 8447,
  [8554] = 8129,
  [8555] = 8443,
  [8556] = 8443,
  [8557] = 8120,
  [8558] = 8558,
  [8559] = 8559,
  [8560] = 7478,
  [8561] = 7476,
  [8562] = 8562,
  [8563] = 8563,
  [8564] = 7468,
  [8565] = 3120,
  [8566] = 3121,
  [8567] = 3123,
  [8568] = 3125,
  [8569] = 3148,
  [8570] = 8570,
  [8571] = 3116,
  [8572] = 8559,
  [8573] = 8558,
  [8574] = 8239,
  [8575] = 8575,
  [8576] = 8576,
  [8577] = 8577,
  [8578] = 8576,
  [8579] = 7483,
  [8580] = 8575,
  [8581] = 3129,
  [8582] = 3154,
  [8583] = 8576,
  [8584] = 8584,
  [8585] = 8585,
  [8586] = 8586,
  [8587] = 8587,
  [8588] = 8558,
  [8589] = 8575,
  [8590] = 8590,
  [8591] = 8130,
  [8592] = 3131,
  [8593] = 8593,
  [8594] = 8558,
  [8595] = 7492,
  [8596] = 8563,
  [8597] = 8575,
  [8598] = 8558,
  [8599] = 8577,
  [8600] = 8576,
  [8601] = 7503,
  [8602] = 8575,
  [8603] = 8585,
  [8604] = 8584,
  [8605] = 7504,
  [8606] = 5457,
  [8607] = 8607,
  [8608] = 8558,
  [8609] = 8575,
  [8610] = 8138,
  [8611] = 3124,
  [8612] = 8576,
  [8613] = 7563,
  [8614] = 8559,
  [8615] = 8586,
  [8616] = 8607,
  [8617] = 8576,
  [8618] = 8137,
  [8619] = 3128,
  [8620] = 8620,
  [8621] = 8558,
  [8622] = 3148,
  [8623] = 8607,
  [8624] = 8558,
  [8625] = 8625,
  [8626] = 8577,
  [8627] = 8576,
  [8628] = 8628,
  [8629] = 8629,
  [8630] = 8607,
  [8631] = 8586,
  [8632] = 8632,
  [8633] = 8633,
  [8634] = 8577,
  [8635] = 8635,
  [8636] = 8155,
  [8637] = 5356,
  [8638] = 8558,
  [8639] = 3133,
  [8640] = 8155,
  [8641] = 7538,
  [8642] = 8576,
  [8643] = 8576,
  [8644] = 5434,
  [8645] = 7522,
  [8646] = 8558,
  [8647] = 8647,
  [8648] = 8558,
  [8649] = 5440,
  [8650] = 8650,
  [8651] = 8575,
  [8652] = 8652,
  [8653] = 8653,
  [8654] = 8576,
  [8655] = 8558,
  [8656] = 8576,
  [8657] = 8576,
  [8658] = 3154,
  [8659] = 8558,
  [8660] = 8660,
  [8661] = 8625,
  [8662] = 8558,
  [8663] = 8576,
  [8664] = 5496,
  [8665] = 8585,
  [8666] = 8584,
  [8667] = 5325,
  [8668] = 8607,
  [8669] = 8607,
  [8670] = 8576,
  [8671] = 8577,
  [8672] = 8575,
  [8673] = 8635,
  [8674] = 8178,
  [8675] = 8558,
  [8676] = 8563,
  [8677] = 8576,
  [8678] = 3132,
  [8679] = 8137,
  [8680] = 8138,
  [8681] = 8681,
  [8682] = 8178,
  [8683] = 8625,
  [8684] = 8558,
  [8685] = 8559,
  [8686] = 8576,
  [8687] = 8558,
  [8688] = 8607,
  [8689] = 8559,
  [8690] = 8575,
  [8691] = 8577,
  [8692] = 8576,
  [8693] = 3133,
  [8694] = 8577,
  [8695] = 8590,
  [8696] = 8696,
  [8697] = 8697,
  [8698] = 8698,
  [8699] = 7591,
  [8700] = 8558,
  [8701] = 5325,
  [8702] = 5476,
  [8703] = 8576,
  [8704] = 8576,
  [8705] = 8590,
  [8706] = 8576,
  [8707] = 5356,
  [8708] = 3122,
  [8709] = 8625,
  [8710] = 8558,
  [8711] = 8133,
  [8712] = 8239,
  [8713] = 8713,
  [8714] = 8186,
  [8715] = 3131,
  [8716] = 8577,
  [8717] = 8558,
  [8718] = 3129,
  [8719] = 8577,
  [8720] = 8720,
  [8721] = 3128,
  [8722] = 8575,
  [8723] = 8590,
  [8724] = 8576,
  [8725] = 8590,
  [8726] = 3205,
  [8727] = 3125,
  [8728] = 8563,
  [8729] = 8558,
  [8730] = 8576,
  [8731] = 8586,
  [8732] = 8558,
  [8733] = 8563,
  [8734] = 8576,
  [8735] = 8558,
  [8736] = 8576,
  [8737] = 8586,
  [8738] = 8738,
  [8739] = 8558,
  [8740] = 8558,
  [8741] = 8562,
  [8742] = 8576,
  [8743] = 8697,
  [8744] = 8575,
  [8745] = 8576,
  [8746] = 8607,
  [8747] = 8558,
  [8748] = 3124,
  [8749] = 8625,
  [8750] = 8576,
  [8751] = 8576,
  [8752] = 8558,
  [8753] = 8607,
  [8754] = 8563,
  [8755] = 8576,
  [8756] = 3123,
  [8757] = 5419,
  [8758] = 7608,
  [8759] = 3206,
  [8760] = 3107,
  [8761] = 8558,
  [8762] = 7593,
  [8763] = 8558,
  [8764] = 3207,
  [8765] = 8576,
  [8766] = 3121,
  [8767] = 8558,
  [8768] = 8576,
  [8769] = 5386,
  [8770] = 3120,
  [8771] = 8133,
  [8772] = 8558,
  [8773] = 8587,
  [8774] = 8575,
  [8775] = 8576,
  [8776] = 8563,
  [8777] = 7536,
  [8778] = 5315,
  [8779] = 7559,
  [8780] = 8576,
  [8781] = 8558,
  [8782] = 7554,
  [8783] = 8576,
  [8784] = 8575,
  [8785] = 8785,
  [8786] = 8558,
  [8787] = 3128,
  [8788] = 8558,
  [8789] = 8576,
  [8790] = 3208,
  [8791] = 8575,
  [8792] = 8607,
  [8793] = 7530,
  [8794] = 8124,
  [8795] = 8562,
  [8796] = 8576,
  [8797] = 8584,
  [8798] = 8585,
  [8799] = 3116,
  [8800] = 8585,
  [8801] = 8584,
  [8802] = 8576,
  [8803] = 8558,
  [8804] = 8563,
  [8805] = 3111,
  [8806] = 3110,
  [8807] = 8129,
  [8808] = 8576,
  [8809] = 8576,
  [8810] = 8112,
  [8811] = 3109,
  [8812] = 8195,
  [8813] = 7511,
  [8814] = 7510,
  [8815] = 7508,
  [8816] = 8558,
  [8817] = 7507,
  [8818] = 8558,
  [8819] = 7506,
  [8820] = 3108,
  [8821] = 8584,
  [8822] = 8558,
  [8823] = 5521,
  [8824] = 8576,
  [8825] = 8563,
  [8826] = 8106,
  [8827] = 8585,
  [8828] = 8558,
  [8829] = 8129,
  [8830] = 8112,
  [8831] = 8195,
  [8832] = 8106,
  [8833] = 8136,
  [8834] = 8124,
  [8835] = 8576,
  [8836] = 8164,
  [8837] = 8136,
  [8838] = 7515,
  [8839] = 7514,
  [8840] = 7513,
  [8841] = 7509,
  [8842] = 8164,
  [8843] = 8180,
  [8844] = 8180,
  [8845] = 8210,
  [8846] = 8225,
  [8847] = 8210,
  [8848] = 8576,
  [8849] = 8225,
  [8850] = 8575,
  [8851] = 5390,
  [8852] = 8159,
  [8853] = 8159,
  [8854] = 8558,
  [8855] = 8558,
  [8856] = 5452,
  [8857] = 8563,
  [8858] = 8558,
  [8859] = 8586,
  [8860] = 8562,
  [8861] = 8186,
  [8862] = 8130,
  [8863] = 8558,
  [8864] = 8577,
  [8865] = 8575,
  [8866] = 7531,
  [8867] = 7474,
  [8868] = 7473,
  [8869] = 8576,
  [8870] = 7479,
  [8871] = 7477,
  [8872] = 5474,
  [8873] = 5496,
  [8874] = 5434,
  [8875] = 7551,
  [8876] = 7552,
  [8877] = 8239,
  [8878] = 5428,
  [8879] = 8239,
  [8880] = 8880,
  [8881] = 5448,
  [8882] = 5453,
  [8883] = 8883,
  [8884] = 5456,
  [8885] = 5464,
  [8886] = 8886,
  [8887] = 8887,
  [8888] = 3205,
  [8889] = 5452,
  [8890] = 5440,
  [8891] = 5457,
  [8892] = 5514,
  [8893] = 8893,
  [8894] = 5515,
  [8895] = 5475,
  [8896] = 5521,
  [8897] = 5483,
  [8898] = 5430,
  [8899] = 8899,
  [8900] = 8883,
  [8901] = 5541,
  [8902] = 7558,
  [8903] = 7557,
  [8904] = 8904,
  [8905] = 3111,
  [8906] = 5542,
  [8907] = 3110,
  [8908] = 8908,
  [8909] = 8909,
  [8910] = 5559,
  [8911] = 3109,
  [8912] = 5517,
  [8913] = 5527,
  [8914] = 2983,
  [8915] = 8915,
  [8916] = 2982,
  [8917] = 5561,
  [8918] = 8918,
  [8919] = 8919,
  [8920] = 5509,
  [8921] = 3108,
  [8922] = 8922,
  [8923] = 3124,
  [8924] = 3206,
  [8925] = 8925,
  [8926] = 8926,
  [8927] = 3207,
  [8928] = 5476,
  [8929] = 5468,
  [8930] = 5467,
  [8931] = 5518,
  [8932] = 5459,
  [8933] = 8933,
  [8934] = 5458,
  [8935] = 5535,
  [8936] = 3133,
  [8937] = 5484,
  [8938] = 5424,
  [8939] = 3208,
  [8940] = 3107,
  [8941] = 5485,
  [8942] = 5455,
  [8943] = 5486,
  [8944] = 5450,
  [8945] = 5477,
  [8946] = 8946,
  [8947] = 8947,
  [8948] = 8948,
  [8949] = 8949,
  [8950] = 8949,
  [8951] = 8951,
  [8952] = 5452,
  [8953] = 8951,
  [8954] = 8946,
  [8955] = 8949,
  [8956] = 8947,
  [8957] = 8951,
  [8958] = 8948,
  [8959] = 8959,
  [8960] = 8960,
  [8961] = 8961,
  [8962] = 8959,
  [8963] = 8963,
  [8964] = 8963,
  [8965] = 8965,
  [8966] = 8960,
  [8967] = 8948,
  [8968] = 8959,
  [8969] = 8969,
  [8970] = 8970,
  [8971] = 8971,
  [8972] = 8972,
  [8973] = 8960,
  [8974] = 8960,
  [8975] = 8960,
  [8976] = 8976,
  [8977] = 8959,
  [8978] = 8961,
  [8979] = 8963,
  [8980] = 8963,
  [8981] = 8959,
  [8982] = 8970,
  [8983] = 8959,
  [8984] = 8984,
  [8985] = 8963,
  [8986] = 8963,
  [8987] = 8960,
  [8988] = 8946,
  [8989] = 8976,
  [8990] = 8948,
  [8991] = 8963,
  [8992] = 8948,
  [8993] = 8961,
  [8994] = 8963,
  [8995] = 8963,
  [8996] = 8959,
  [8997] = 8963,
  [8998] = 8960,
  [8999] = 8960,
  [9000] = 8959,
  [9001] = 8959,
  [9002] = 8960,
  [9003] = 8976,
  [9004] = 9004,
  [9005] = 8963,
  [9006] = 8963,
  [9007] = 9007,
  [9008] = 8959,
  [9009] = 8959,
  [9010] = 8960,
  [9011] = 9011,
  [9012] = 8647,
  [9013] = 8647,
  [9014] = 8947,
  [9015] = 8963,
  [9016] = 8959,
  [9017] = 8959,
  [9018] = 8960,
  [9019] = 8960,
  [9020] = 8960,
  [9021] = 9021,
  [9022] = 9022,
  [9023] = 9023,
  [9024] = 9024,
  [9025] = 8946,
  [9026] = 9026,
  [9027] = 9022,
  [9028] = 9028,
  [9029] = 9028,
  [9030] = 9021,
  [9031] = 9028,
  [9032] = 2972,
  [9033] = 3003,
  [9034] = 9034,
  [9035] = 8647,
  [9036] = 9028,
  [9037] = 9037,
  [9038] = 9038,
  [9039] = 3131,
  [9040] = 2930,
  [9041] = 9022,
  [9042] = 9023,
  [9043] = 2931,
  [9044] = 9037,
  [9045] = 9045,
  [9046] = 2987,
  [9047] = 9047,
  [9048] = 3122,
  [9049] = 9049,
  [9050] = 9050,
  [9051] = 9037,
  [9052] = 9052,
  [9053] = 5452,
  [9054] = 9054,
  [9055] = 9024,
  [9056] = 9056,
  [9057] = 9057,
  [9058] = 2988,
  [9059] = 9059,
  [9060] = 9060,
  [9061] = 9023,
  [9062] = 3123,
  [9063] = 9028,
  [9064] = 9024,
  [9065] = 9024,
  [9066] = 3154,
  [9067] = 9023,
  [9068] = 9068,
  [9069] = 9056,
  [9070] = 2991,
  [9071] = 9034,
  [9072] = 2983,
  [9073] = 9073,
  [9074] = 2992,
  [9075] = 9026,
  [9076] = 9076,
  [9077] = 2996,
  [9078] = 2933,
  [9079] = 9028,
  [9080] = 2929,
  [9081] = 2932,
  [9082] = 9082,
  [9083] = 3108,
  [9084] = 3001,
  [9085] = 8647,
  [9086] = 2998,
  [9087] = 3002,
  [9088] = 9076,
  [9089] = 9056,
  [9090] = 9022,
  [9091] = 9037,
  [9092] = 9024,
  [9093] = 9021,
  [9094] = 9022,
  [9095] = 9028,
  [9096] = 9024,
  [9097] = 9026,
  [9098] = 9021,
  [9099] = 9099,
  [9100] = 9100,
  [9101] = 3129,
  [9102] = 9024,
  [9103] = 3004,
  [9104] = 9028,
  [9105] = 3005,
  [9106] = 3006,
  [9107] = 9023,
  [9108] = 9108,
  [9109] = 9024,
  [9110] = 9056,
  [9111] = 9052,
  [9112] = 9056,
  [9113] = 3011,
  [9114] = 9114,
  [9115] = 3109,
  [9116] = 9037,
  [9117] = 9021,
  [9118] = 9076,
  [9119] = 9026,
  [9120] = 9073,
  [9121] = 9022,
  [9122] = 8946,
  [9123] = 9056,
  [9124] = 9024,
  [9125] = 9125,
  [9126] = 9022,
  [9127] = 8970,
  [9128] = 9037,
  [9129] = 3110,
  [9130] = 3007,
  [9131] = 9023,
  [9132] = 3008,
  [9133] = 9028,
  [9134] = 3111,
  [9135] = 5521,
  [9136] = 9021,
  [9137] = 9137,
  [9138] = 9037,
  [9139] = 9076,
  [9140] = 9140,
  [9141] = 3132,
  [9142] = 3009,
  [9143] = 9022,
  [9144] = 9144,
  [9145] = 9037,
  [9146] = 3024,
  [9147] = 3012,
  [9148] = 3014,
  [9149] = 9037,
  [9150] = 9076,
  [9151] = 9023,
  [9152] = 9125,
  [9153] = 9024,
  [9154] = 9076,
  [9155] = 9155,
  [9156] = 9100,
  [9157] = 9157,
  [9158] = 9028,
  [9159] = 2926,
  [9160] = 3031,
  [9161] = 9137,
  [9162] = 9021,
  [9163] = 3018,
  [9164] = 2927,
  [9165] = 3121,
  [9166] = 9021,
  [9167] = 8948,
  [9168] = 9023,
  [9169] = 9026,
  [9170] = 5521,
  [9171] = 9171,
  [9172] = 7558,
  [9173] = 5452,
  [9174] = 9174,
  [9175] = 9175,
  [9176] = 3033,
  [9177] = 2925,
  [9178] = 2968,
  [9179] = 2985,
  [9180] = 7557,
  [9181] = 9028,
  [9182] = 7552,
  [9183] = 8946,
  [9184] = 2997,
  [9185] = 9026,
  [9186] = 9056,
  [9187] = 8948,
  [9188] = 2986,
  [9189] = 9056,
  [9190] = 9028,
  [9191] = 7551,
  [9192] = 9026,
  [9193] = 9028,
  [9194] = 9024,
  [9195] = 9028,
  [9196] = 2990,
  [9197] = 3019,
  [9198] = 9024,
  [9199] = 9028,
  [9200] = 3020,
  [9201] = 9045,
  [9202] = 8647,
  [9203] = 9026,
  [9204] = 9068,
  [9205] = 9021,
  [9206] = 9022,
  [9207] = 3021,
  [9208] = 9054,
  [9209] = 9076,
  [9210] = 9099,
  [9211] = 8947,
  [9212] = 9174,
  [9213] = 9213,
  [9214] = 9060,
  [9215] = 8947,
  [9216] = 9026,
  [9217] = 9217,
  [9218] = 9037,
  [9219] = 2999,
  [9220] = 9028,
  [9221] = 3023,
  [9222] = 9050,
  [9223] = 3107,
  [9224] = 3025,
  [9225] = 2924,
  [9226] = 3034,
  [9227] = 3035,
  [9228] = 3046,
  [9229] = 3037,
  [9230] = 9024,
  [9231] = 3038,
  [9232] = 9049,
  [9233] = 3120,
  [9234] = 9056,
  [9235] = 9059,
  [9236] = 9236,
  [9237] = 3040,
  [9238] = 3042,
  [9239] = 9026,
  [9240] = 3148,
  [9241] = 9144,
  [9242] = 9242,
  [9243] = 3047,
  [9244] = 9028,
  [9245] = 3048,
  [9246] = 3049,
  [9247] = 9037,
  [9248] = 9248,
  [9249] = 9024,
  [9250] = 9028,
  [9251] = 9028,
  [9252] = 8947,
  [9253] = 9021,
  [9254] = 9023,
  [9255] = 9255,
  [9256] = 9213,
  [9257] = 3208,
  [9258] = 9213,
  [9259] = 9024,
  [9260] = 3125,
  [9261] = 9021,
  [9262] = 9076,
  [9263] = 9026,
  [9264] = 9021,
  [9265] = 3050,
  [9266] = 3206,
  [9267] = 9056,
  [9268] = 3207,
  [9269] = 9037,
  [9270] = 3051,
  [9271] = 9023,
  [9272] = 9272,
  [9273] = 9037,
  [9274] = 9076,
  [9275] = 9037,
  [9276] = 9047,
  [9277] = 9026,
  [9278] = 3052,
  [9279] = 9024,
  [9280] = 9242,
  [9281] = 9023,
  [9282] = 9175,
  [9283] = 9022,
  [9284] = 9056,
  [9285] = 9024,
  [9286] = 9056,
  [9287] = 9037,
  [9288] = 9140,
  [9289] = 9082,
  [9290] = 3205,
  [9291] = 9076,
  [9292] = 9076,
  [9293] = 9022,
  [9294] = 9171,
  [9295] = 3206,
  [9296] = 9037,
  [9297] = 9297,
  [9298] = 9248,
  [9299] = 9108,
  [9300] = 3207,
  [9301] = 9023,
  [9302] = 3205,
  [9303] = 9028,
  [9304] = 9028,
  [9305] = 9305,
  [9306] = 9076,
  [9307] = 9037,
  [9308] = 9038,
  [9309] = 9022,
  [9310] = 9297,
  [9311] = 9037,
  [9312] = 9037,
  [9313] = 9313,
  [9314] = 9217,
  [9315] = 9315,
  [9316] = 3208,
  [9317] = 3205,
  [9318] = 3206,
  [9319] = 9037,
  [9320] = 9057,
  [9321] = 9024,
  [9322] = 9056,
  [9323] = 9023,
  [9324] = 9024,
  [9325] = 9037,
  [9326] = 9315,
  [9327] = 9028,
  [9328] = 9255,
  [9329] = 9037,
  [9330] = 9024,
  [9331] = 9024,
  [9332] = 9024,
  [9333] = 3207,
  [9334] = 9022,
  [9335] = 3208,
  [9336] = 2982,
  [9337] = 9026,
  [9338] = 9338,
  [9339] = 9114,
  [9340] = 9076,
  [9341] = 9021,
  [9342] = 9342,
  [9343] = 9140,
  [9344] = 9057,
  [9345] = 9082,
  [9346] = 9242,
  [9347] = 8225,
  [9348] = 9144,
  [9349] = 9349,
  [9350] = 9315,
  [9351] = 9047,
  [9352] = 9057,
  [9353] = 9082,
  [9354] = 9140,
  [9355] = 9355,
  [9356] = 9038,
  [9357] = 3108,
  [9358] = 9038,
  [9359] = 9242,
  [9360] = 9047,
  [9361] = 9049,
  [9362] = 9362,
  [9363] = 9108,
  [9364] = 9171,
  [9365] = 9108,
  [9366] = 9366,
  [9367] = 9171,
  [9368] = 9175,
  [9369] = 9050,
  [9370] = 9217,
  [9371] = 9125,
  [9372] = 8647,
  [9373] = 9100,
  [9374] = 9060,
  [9375] = 9355,
  [9376] = 5452,
  [9377] = 9114,
  [9378] = 9099,
  [9379] = 9174,
  [9380] = 9059,
  [9381] = 9315,
  [9382] = 9049,
  [9383] = 8138,
  [9384] = 9248,
  [9385] = 9034,
  [9386] = 9175,
  [9387] = 9255,
  [9388] = 9068,
  [9389] = 8137,
  [9390] = 8130,
  [9391] = 9297,
  [9392] = 9392,
  [9393] = 9054,
  [9394] = 8186,
  [9395] = 8178,
  [9396] = 9052,
  [9397] = 9054,
  [9398] = 8647,
  [9399] = 9366,
  [9400] = 9125,
  [9401] = 3107,
  [9402] = 9366,
  [9403] = 9403,
  [9404] = 9362,
  [9405] = 9054,
  [9406] = 3206,
  [9407] = 9342,
  [9408] = 8210,
  [9409] = 8180,
  [9410] = 9349,
  [9411] = 3116,
  [9412] = 5521,
  [9413] = 9413,
  [9414] = 5521,
  [9415] = 9174,
  [9416] = 9050,
  [9417] = 9099,
  [9418] = 9034,
  [9419] = 9100,
  [9420] = 9420,
  [9421] = 8164,
  [9422] = 9125,
  [9423] = 9248,
  [9424] = 9144,
  [9425] = 8145,
  [9426] = 9052,
  [9427] = 9045,
  [9428] = 3208,
  [9429] = 9059,
  [9430] = 9217,
  [9431] = 8136,
  [9432] = 9073,
  [9433] = 8159,
  [9434] = 8239,
  [9435] = 3207,
  [9436] = 9068,
  [9437] = 9114,
  [9438] = 3206,
  [9439] = 9114,
  [9440] = 9034,
  [9441] = 9248,
  [9442] = 9442,
  [9443] = 9137,
  [9444] = 9342,
  [9445] = 9144,
  [9446] = 3109,
  [9447] = 9059,
  [9448] = 9137,
  [9449] = 9052,
  [9450] = 8970,
  [9451] = 9060,
  [9452] = 9073,
  [9453] = 9073,
  [9454] = 9454,
  [9455] = 8124,
  [9456] = 8121,
  [9457] = 3133,
  [9458] = 8106,
  [9459] = 3205,
  [9460] = 9137,
  [9461] = 3208,
  [9462] = 9342,
  [9463] = 9045,
  [9464] = 9464,
  [9465] = 8112,
  [9466] = 9175,
  [9467] = 9140,
  [9468] = 9174,
  [9469] = 9099,
  [9470] = 9171,
  [9471] = 9108,
  [9472] = 9038,
  [9473] = 8129,
  [9474] = 8970,
  [9475] = 5452,
  [9476] = 8947,
  [9477] = 9477,
  [9478] = 3205,
  [9479] = 9479,
  [9480] = 8120,
  [9481] = 9366,
  [9482] = 8946,
  [9483] = 9100,
  [9484] = 8155,
  [9485] = 9485,
  [9486] = 9315,
  [9487] = 9057,
  [9488] = 9082,
  [9489] = 9242,
  [9490] = 9047,
  [9491] = 9049,
  [9492] = 3110,
  [9493] = 9255,
  [9494] = 9050,
  [9495] = 9217,
  [9496] = 9496,
  [9497] = 9060,
  [9498] = 9366,
  [9499] = 3208,
  [9500] = 3128,
  [9501] = 5521,
  [9502] = 3205,
  [9503] = 9068,
  [9504] = 9045,
  [9505] = 9297,
  [9506] = 8948,
  [9507] = 8195,
  [9508] = 3207,
  [9509] = 9255,
  [9510] = 3124,
  [9511] = 9511,
  [9512] = 9342,
  [9513] = 9513,
  [9514] = 9454,
  [9515] = 3111,
  [9516] = 8120,
  [9517] = 3206,
  [9518] = 3207,
  [9519] = 9420,
  [9520] = 9403,
  [9521] = 5452,
  [9522] = 8121,
  [9523] = 8970,
  [9524] = 9297,
  [9525] = 8133,
  [9526] = 3005,
  [9527] = 9527,
  [9528] = 9082,
  [9529] = 9057,
  [9530] = 3208,
  [9531] = 9315,
  [9532] = 8155,
  [9533] = 9047,
  [9534] = 8120,
  [9535] = 9038,
  [9536] = 8129,
  [9537] = 9242,
  [9538] = 3107,
  [9539] = 8112,
  [9540] = 9082,
  [9541] = 9057,
  [9542] = 9315,
  [9543] = 8195,
  [9544] = 8106,
  [9545] = 8124,
  [9546] = 8136,
  [9547] = 9140,
  [9548] = 8164,
  [9549] = 8180,
  [9550] = 8210,
  [9551] = 8225,
  [9552] = 8159,
  [9553] = 9108,
  [9554] = 9171,
  [9555] = 9175,
  [9556] = 9047,
  [9557] = 9059,
  [9558] = 9144,
  [9559] = 9248,
  [9560] = 9049,
  [9561] = 9049,
  [9562] = 9050,
  [9563] = 2986,
  [9564] = 8178,
  [9565] = 9217,
  [9566] = 2931,
  [9567] = 2932,
  [9568] = 9568,
  [9569] = 9569,
  [9570] = 9570,
  [9571] = 2988,
  [9572] = 2991,
  [9573] = 2992,
  [9574] = 9114,
  [9575] = 8647,
  [9576] = 2972,
  [9577] = 2996,
  [9578] = 8970,
  [9579] = 2933,
  [9580] = 2929,
  [9581] = 9581,
  [9582] = 3129,
  [9583] = 2926,
  [9584] = 9584,
  [9585] = 9585,
  [9586] = 3001,
  [9587] = 3002,
  [9588] = 3003,
  [9589] = 8948,
  [9590] = 8159,
  [9591] = 9591,
  [9592] = 3207,
  [9593] = 9527,
  [9594] = 9594,
  [9595] = 8225,
  [9596] = 8186,
  [9597] = 2927,
  [9598] = 8947,
  [9599] = 8210,
  [9600] = 3206,
  [9601] = 8180,
  [9602] = 8164,
  [9603] = 8136,
  [9604] = 9604,
  [9605] = 8239,
  [9606] = 8124,
  [9607] = 9607,
  [9608] = 9608,
  [9609] = 3131,
  [9610] = 9610,
  [9611] = 8106,
  [9612] = 8195,
  [9613] = 8112,
  [9614] = 9614,
  [9615] = 9615,
  [9616] = 9616,
  [9617] = 8129,
  [9618] = 9618,
  [9619] = 3004,
  [9620] = 8155,
  [9621] = 9621,
  [9622] = 2968,
  [9623] = 3006,
  [9624] = 9624,
  [9625] = 9174,
  [9626] = 3108,
  [9627] = 9627,
  [9628] = 9099,
  [9629] = 3007,
  [9630] = 3008,
  [9631] = 3012,
  [9632] = 3109,
  [9633] = 9100,
  [9634] = 9634,
  [9635] = 9635,
  [9636] = 9627,
  [9637] = 9125,
  [9638] = 9420,
  [9639] = 3014,
  [9640] = 9640,
  [9641] = 3018,
  [9642] = 9634,
  [9643] = 9060,
  [9644] = 3019,
  [9645] = 3110,
  [9646] = 9635,
  [9647] = 3020,
  [9648] = 8133,
  [9649] = 3111,
  [9650] = 9640,
  [9651] = 9640,
  [9652] = 9581,
  [9653] = 9114,
  [9654] = 9635,
  [9655] = 9634,
  [9656] = 9627,
  [9657] = 3021,
  [9658] = 8948,
  [9659] = 2925,
  [9660] = 9581,
  [9661] = 3023,
  [9662] = 2930,
  [9663] = 9584,
  [9664] = 9614,
  [9665] = 9585,
  [9666] = 3148,
  [9667] = 9068,
  [9668] = 9668,
  [9669] = 2924,
  [9670] = 8647,
  [9671] = 8130,
  [9672] = 3009,
  [9673] = 3034,
  [9674] = 3116,
  [9675] = 3025,
  [9676] = 9591,
  [9677] = 9527,
  [9678] = 2985,
  [9679] = 9594,
  [9680] = 3035,
  [9681] = 3154,
  [9682] = 9621,
  [9683] = 8120,
  [9684] = 9684,
  [9685] = 9685,
  [9686] = 3037,
  [9687] = 8145,
  [9688] = 9355,
  [9689] = 9569,
  [9690] = 9690,
  [9691] = 9691,
  [9692] = 2987,
  [9693] = 9140,
  [9694] = 9584,
  [9695] = 9137,
  [9696] = 3038,
  [9697] = 9568,
  [9698] = 9698,
  [9699] = 9054,
  [9700] = 9585,
  [9701] = 9052,
  [9702] = 3040,
  [9703] = 3042,
  [9704] = 9704,
  [9705] = 9705,
  [9706] = 8121,
  [9707] = 9125,
  [9708] = 9073,
  [9709] = 9635,
  [9710] = 9640,
  [9711] = 8647,
  [9712] = 9712,
  [9713] = 9100,
  [9714] = 9045,
  [9715] = 9255,
  [9716] = 9045,
  [9717] = 2997,
  [9718] = 9569,
  [9719] = 3047,
  [9720] = 3048,
  [9721] = 9349,
  [9722] = 3049,
  [9723] = 9615,
  [9724] = 9099,
  [9725] = 9616,
  [9726] = 8239,
  [9727] = 2999,
  [9728] = 9403,
  [9729] = 3011,
  [9730] = 5452,
  [9731] = 9174,
  [9732] = 3205,
  [9733] = 3050,
  [9734] = 9734,
  [9735] = 9735,
  [9736] = 3122,
  [9737] = 3051,
  [9738] = 9668,
  [9739] = 3124,
  [9740] = 3052,
  [9741] = 3128,
  [9742] = 9362,
  [9743] = 9569,
  [9744] = 9050,
  [9745] = 9591,
  [9746] = 9217,
  [9747] = 9060,
  [9748] = 8137,
  [9749] = 9698,
  [9750] = 9527,
  [9751] = 9568,
  [9752] = 3132,
  [9753] = 8138,
  [9754] = 9691,
  [9755] = 3024,
  [9756] = 3133,
  [9757] = 9297,
  [9758] = 9038,
  [9759] = 9108,
  [9760] = 8946,
  [9761] = 9594,
  [9762] = 9255,
  [9763] = 9420,
  [9764] = 9691,
  [9765] = 9610,
  [9766] = 9766,
  [9767] = 9171,
  [9768] = 9349,
  [9769] = 9175,
  [9770] = 3031,
  [9771] = 9668,
  [9772] = 3033,
  [9773] = 2982,
  [9774] = 9668,
  [9775] = 5521,
  [9776] = 9640,
  [9777] = 9614,
  [9778] = 9635,
  [9779] = 9634,
  [9780] = 9034,
  [9781] = 9614,
  [9782] = 8133,
  [9783] = 9349,
  [9784] = 2983,
  [9785] = 9627,
  [9786] = 5521,
  [9787] = 9787,
  [9788] = 5452,
  [9789] = 8121,
  [9790] = 9054,
  [9791] = 3205,
  [9792] = 3206,
  [9793] = 9052,
  [9794] = 9454,
  [9795] = 3207,
  [9796] = 7557,
  [9797] = 7558,
  [9798] = 9668,
  [9799] = 9698,
  [9800] = 9614,
  [9801] = 9621,
  [9802] = 9568,
  [9803] = 3208,
  [9804] = 9570,
  [9805] = 9621,
  [9806] = 9627,
  [9807] = 9568,
  [9808] = 9634,
  [9809] = 9635,
  [9810] = 9569,
  [9811] = 3123,
  [9812] = 9640,
  [9813] = 3121,
  [9814] = 3120,
  [9815] = 9815,
  [9816] = 9698,
  [9817] = 9817,
  [9818] = 9818,
  [9819] = 9691,
  [9820] = 9242,
  [9821] = 9616,
  [9822] = 9568,
  [9823] = 9823,
  [9824] = 9824,
  [9825] = 9825,
  [9826] = 3827,
  [9827] = 9581,
  [9828] = 9584,
  [9829] = 9591,
  [9830] = 9137,
  [9831] = 9420,
  [9832] = 9668,
  [9833] = 9640,
  [9834] = 9585,
  [9835] = 2990,
  [9836] = 9144,
  [9837] = 9635,
  [9838] = 9059,
  [9839] = 9615,
  [9840] = 9615,
  [9841] = 9594,
  [9842] = 9691,
  [9843] = 9527,
  [9844] = 9585,
  [9845] = 9073,
  [9846] = 9584,
  [9847] = 9591,
  [9848] = 3125,
  [9849] = 9581,
  [9850] = 9616,
  [9851] = 9615,
  [9852] = 9297,
  [9853] = 9853,
  [9854] = 9608,
  [9855] = 9568,
  [9856] = 9034,
  [9857] = 7551,
  [9858] = 3205,
  [9859] = 3208,
  [9860] = 7552,
  [9861] = 9698,
  [9862] = 9621,
  [9863] = 3206,
  [9864] = 9068,
  [9865] = 9865,
  [9866] = 9248,
  [9867] = 9616,
  [9868] = 3207,
  [9869] = 9594,
  [9870] = 9870,
  [9871] = 8133,
  [9872] = 9297,
  [9873] = 9870,
  [9874] = 9073,
  [9875] = 8106,
  [9876] = 9137,
  [9877] = 9052,
  [9878] = 9878,
  [9879] = 9879,
  [9880] = 8124,
  [9881] = 9870,
  [9882] = 9882,
  [9883] = 8164,
  [9884] = 9870,
  [9885] = 8180,
  [9886] = 8210,
  [9887] = 9887,
  [9888] = 9870,
  [9889] = 9889,
  [9890] = 9890,
  [9891] = 8225,
  [9892] = 4066,
  [9893] = 8159,
  [9894] = 9894,
  [9895] = 7336,
  [9896] = 9887,
  [9897] = 9889,
  [9898] = 9898,
  [9899] = 9899,
  [9900] = 9890,
  [9901] = 9890,
  [9902] = 9889,
  [9903] = 9887,
  [9904] = 9137,
  [9905] = 3208,
  [9906] = 9870,
  [9907] = 9907,
  [9908] = 9878,
  [9909] = 9882,
  [9910] = 9910,
  [9911] = 9910,
  [9912] = 9882,
  [9913] = 9870,
  [9914] = 9878,
  [9915] = 9910,
  [9916] = 9916,
  [9917] = 8195,
  [9918] = 9910,
  [9919] = 9919,
  [9920] = 9610,
  [9921] = 9882,
  [9922] = 9878,
  [9923] = 8112,
  [9924] = 9924,
  [9925] = 9870,
  [9926] = 8129,
  [9927] = 9919,
  [9928] = 9870,
  [9929] = 9919,
  [9930] = 9045,
  [9931] = 9887,
  [9932] = 9887,
  [9933] = 9890,
  [9934] = 9889,
  [9935] = 9255,
  [9936] = 9889,
  [9937] = 9887,
  [9938] = 9882,
  [9939] = 9878,
  [9940] = 9890,
  [9941] = 9890,
  [9942] = 9878,
  [9943] = 9882,
  [9944] = 9889,
  [9945] = 9910,
  [9946] = 9887,
  [9947] = 9947,
  [9948] = 9948,
  [9949] = 9947,
  [9950] = 9919,
  [9951] = 9125,
  [9952] = 9870,
  [9953] = 9889,
  [9954] = 9910,
  [9955] = 9955,
  [9956] = 9878,
  [9957] = 9140,
  [9958] = 9882,
  [9959] = 9910,
  [9960] = 9454,
  [9961] = 9878,
  [9962] = 8948,
  [9963] = 9890,
  [9964] = 3205,
  [9965] = 9315,
  [9966] = 9910,
  [9967] = 9882,
  [9968] = 9057,
  [9969] = 9045,
  [9970] = 9878,
  [9971] = 9971,
  [9972] = 9899,
  [9973] = 9255,
  [9974] = 9882,
  [9975] = 9878,
  [9976] = 9082,
  [9977] = 9910,
  [9978] = 7296,
  [9979] = 9073,
  [9980] = 7302,
  [9981] = 9137,
  [9982] = 9297,
  [9983] = 9887,
  [9984] = 3208,
  [9985] = 9870,
  [9986] = 9100,
  [9987] = 9403,
  [9988] = 9073,
  [9989] = 9610,
  [9990] = 9059,
  [9991] = 9890,
  [9992] = 9919,
  [9993] = 9894,
  [9994] = 9887,
  [9995] = 9420,
  [9996] = 9889,
  [9997] = 9887,
  [9998] = 9998,
  [9999] = 9889,
  [10000] = 9910,
  [10001] = 9882,
  [10002] = 10002,
  [10003] = 9878,
  [10004] = 9870,
  [10005] = 9919,
  [10006] = 9889,
  [10007] = 9890,
  [10008] = 9887,
  [10009] = 9890,
  [10010] = 9898,
  [10011] = 9998,
  [10012] = 9889,
  [10013] = 9890,
  [10014] = 9140,
  [10015] = 5452,
  [10016] = 10016,
  [10017] = 3206,
  [10018] = 3207,
  [10019] = 8136,
  [10020] = 9034,
  [10021] = 9054,
  [10022] = 9242,
  [10023] = 9052,
  [10024] = 9349,
  [10025] = 9890,
  [10026] = 9099,
  [10027] = 9174,
  [10028] = 3207,
  [10029] = 10029,
  [10030] = 10016,
  [10031] = 7294,
  [10032] = 9349,
  [10033] = 9910,
  [10034] = 10034,
  [10035] = 3208,
  [10036] = 9052,
  [10037] = 9248,
  [10038] = 3207,
  [10039] = 9054,
  [10040] = 10040,
  [10041] = 9144,
  [10042] = 8239,
  [10043] = 10043,
  [10044] = 10043,
  [10045] = 9047,
  [10046] = 9879,
  [10047] = 9919,
  [10048] = 9362,
  [10049] = 8155,
  [10050] = 9049,
  [10051] = 3206,
  [10052] = 9054,
  [10053] = 9608,
  [10054] = 3206,
  [10055] = 9910,
  [10056] = 9882,
  [10057] = 9919,
  [10058] = 9355,
  [10059] = 9878,
  [10060] = 9038,
  [10061] = 3205,
  [10062] = 4042,
  [10063] = 10063,
  [10064] = 9140,
  [10065] = 9882,
  [10066] = 9971,
  [10067] = 9919,
  [10068] = 10068,
  [10069] = 9887,
  [10070] = 9108,
  [10071] = 9919,
  [10072] = 9608,
  [10073] = 9870,
  [10074] = 9608,
  [10075] = 9068,
  [10076] = 9114,
  [10077] = 9887,
  [10078] = 8647,
  [10079] = 9948,
  [10080] = 10080,
  [10081] = 7429,
  [10082] = 8970,
  [10083] = 9910,
  [10084] = 10002,
  [10085] = 9919,
  [10086] = 9889,
  [10087] = 9889,
  [10088] = 9890,
  [10089] = 9175,
  [10090] = 9171,
  [10091] = 9919,
  [10092] = 9919,
  [10093] = 5521,
  [10094] = 10080,
  [10095] = 10068,
  [10096] = 9420,
  [10097] = 3205,
  [10098] = 9050,
  [10099] = 9882,
  [10100] = 7307,
  [10101] = 9919,
  [10102] = 9919,
  [10103] = 9878,
  [10104] = 9217,
  [10105] = 9060,
  [10106] = 9610,
  [10107] = 9255,
  [10108] = 8239,
  [10109] = 9890,
  [10110] = 7559,
  [10111] = 10111,
  [10112] = 7476,
  [10113] = 9140,
  [10114] = 9125,
  [10115] = 5521,
  [10116] = 7473,
  [10117] = 10117,
  [10118] = 9100,
  [10119] = 7483,
  [10120] = 3123,
  [10121] = 10068,
  [10122] = 9045,
  [10123] = 7474,
  [10124] = 9971,
  [10125] = 9099,
  [10126] = 3120,
  [10127] = 9174,
  [10128] = 10128,
  [10129] = 10129,
  [10130] = 3109,
  [10131] = 9947,
  [10132] = 9068,
  [10133] = 9898,
  [10134] = 7531,
  [10135] = 10129,
  [10136] = 10080,
  [10137] = 8121,
  [10138] = 5440,
  [10139] = 9060,
  [10140] = 7477,
  [10141] = 10129,
  [10142] = 3110,
  [10143] = 9217,
  [10144] = 10129,
  [10145] = 9050,
  [10146] = 9049,
  [10147] = 7593,
  [10148] = 9047,
  [10149] = 10149,
  [10150] = 9899,
  [10151] = 7478,
  [10152] = 10129,
  [10153] = 7492,
  [10154] = 7479,
  [10155] = 7563,
  [10156] = 9242,
  [10157] = 9082,
  [10158] = 3111,
  [10159] = 4772,
  [10160] = 3108,
  [10161] = 9608,
  [10162] = 9057,
  [10163] = 3208,
  [10164] = 10164,
  [10165] = 3208,
  [10166] = 10068,
  [10167] = 7608,
  [10168] = 9315,
  [10169] = 10129,
  [10170] = 8647,
  [10171] = 9297,
  [10172] = 10172,
  [10173] = 10043,
  [10174] = 10174,
  [10175] = 8946,
  [10176] = 7554,
  [10177] = 4709,
  [10178] = 10129,
  [10179] = 3125,
  [10180] = 9038,
  [10181] = 9108,
  [10182] = 10182,
  [10183] = 9171,
  [10184] = 8948,
  [10185] = 9175,
  [10186] = 5521,
  [10187] = 10129,
  [10188] = 10129,
  [10189] = 9144,
  [10190] = 9248,
  [10191] = 9034,
  [10192] = 9054,
  [10193] = 10129,
  [10194] = 9349,
  [10195] = 10129,
  [10196] = 4727,
  [10197] = 9971,
  [10198] = 10111,
  [10199] = 10199,
  [10200] = 8121,
  [10201] = 5452,
  [10202] = 7515,
  [10203] = 9052,
  [10204] = 3207,
  [10205] = 3206,
  [10206] = 10182,
  [10207] = 9420,
  [10208] = 9420,
  [10209] = 5452,
  [10210] = 8948,
  [10211] = 10128,
  [10212] = 10129,
  [10213] = 10149,
  [10214] = 10129,
  [10215] = 3148,
  [10216] = 9879,
  [10217] = 10002,
  [10218] = 10129,
  [10219] = 10219,
  [10220] = 9297,
  [10221] = 9610,
  [10222] = 10129,
  [10223] = 10129,
  [10224] = 8239,
  [10225] = 10225,
  [10226] = 9349,
  [10227] = 8647,
  [10228] = 10129,
  [10229] = 9879,
  [10230] = 3205,
  [10231] = 3121,
  [10232] = 10068,
  [10233] = 5452,
  [10234] = 10234,
  [10235] = 7591,
  [10236] = 3205,
  [10237] = 7511,
  [10238] = 7510,
  [10239] = 10129,
  [10240] = 9879,
  [10241] = 9144,
  [10242] = 9894,
  [10243] = 7508,
  [10244] = 9174,
  [10245] = 8145,
  [10246] = 7507,
  [10247] = 9099,
  [10248] = 7506,
  [10249] = 10080,
  [10250] = 5356,
  [10251] = 3154,
  [10252] = 10129,
  [10253] = 9045,
  [10254] = 7468,
  [10255] = 10255,
  [10256] = 8647,
  [10257] = 3131,
  [10258] = 7514,
  [10259] = 9059,
  [10260] = 9125,
  [10261] = 7513,
  [10262] = 8138,
  [10263] = 8137,
  [10264] = 8130,
  [10265] = 10129,
  [10266] = 7522,
  [10267] = 7538,
  [10268] = 9349,
  [10269] = 7530,
  [10270] = 10080,
  [10271] = 8159,
  [10272] = 8225,
  [10273] = 8210,
  [10274] = 9114,
  [10275] = 8180,
  [10276] = 8164,
  [10277] = 4727,
  [10278] = 7509,
  [10279] = 9947,
  [10280] = 3207,
  [10281] = 8136,
  [10282] = 3206,
  [10283] = 7504,
  [10284] = 7503,
  [10285] = 5521,
  [10286] = 9114,
  [10287] = 5476,
  [10288] = 10288,
  [10289] = 9034,
  [10290] = 3107,
  [10291] = 3129,
  [10292] = 8133,
  [10293] = 9248,
  [10294] = 8120,
  [10295] = 10288,
  [10296] = 9059,
  [10297] = 8947,
  [10298] = 9608,
  [10299] = 10172,
  [10300] = 8124,
  [10301] = 8106,
  [10302] = 9349,
  [10303] = 9068,
  [10304] = 9060,
  [10305] = 8948,
  [10306] = 5457,
  [10307] = 8647,
  [10308] = 7536,
  [10309] = 9610,
  [10310] = 8195,
  [10311] = 9898,
  [10312] = 5325,
  [10313] = 9971,
  [10314] = 8112,
  [10315] = 8129,
  [10316] = 9073,
  [10317] = 4709,
  [10318] = 4772,
  [10319] = 9217,
  [10320] = 10164,
  [10321] = 9050,
  [10322] = 9137,
  [10323] = 9947,
  [10324] = 9898,
  [10325] = 9049,
  [10326] = 9047,
  [10327] = 9242,
  [10328] = 9082,
  [10329] = 9057,
  [10330] = 9315,
  [10331] = 8186,
  [10332] = 9100,
  [10333] = 8120,
  [10334] = 8155,
  [10335] = 10016,
  [10336] = 9998,
  [10337] = 10129,
  [10338] = 8178,
  [10339] = 10174,
  [10340] = 5496,
  [10341] = 9038,
  [10342] = 9948,
  [10343] = 9108,
  [10344] = 8948,
  [10345] = 10219,
  [10346] = 9420,
  [10347] = 9255,
  [10348] = 10117,
  [10349] = 5434,
  [10350] = 9171,
  [10351] = 9175,
  [10352] = 10129,
  [10353] = 10353,
  [10354] = 8023,
  [10355] = 9971,
  [10356] = 9947,
  [10357] = 9898,
  [10358] = 2983,
  [10359] = 10359,
  [10360] = 8045,
  [10361] = 2982,
  [10362] = 10362,
  [10363] = 10363,
  [10364] = 9479,
  [10365] = 10365,
  [10366] = 8178,
  [10367] = 4903,
  [10368] = 10002,
  [10369] = 7608,
  [10370] = 10363,
  [10371] = 8017,
  [10372] = 10372,
  [10373] = 10373,
  [10374] = 10363,
  [10375] = 10375,
  [10376] = 10376,
  [10377] = 10377,
  [10378] = 10172,
  [10379] = 8133,
  [10380] = 10380,
  [10381] = 4903,
  [10382] = 10382,
  [10383] = 10383,
  [10384] = 10384,
  [10385] = 10363,
  [10386] = 10386,
  [10387] = 10387,
  [10388] = 10363,
  [10389] = 10080,
  [10390] = 10390,
  [10391] = 10391,
  [10392] = 10392,
  [10393] = 8970,
  [10394] = 10394,
  [10395] = 10395,
  [10396] = 10396,
  [10397] = 10397,
  [10398] = 10164,
  [10399] = 10399,
  [10400] = 10400,
  [10401] = 9899,
  [10402] = 10363,
  [10403] = 10403,
  [10404] = 10363,
  [10405] = 10405,
  [10406] = 10406,
  [10407] = 10407,
  [10408] = 10408,
  [10409] = 10409,
  [10410] = 10410,
  [10411] = 10411,
  [10412] = 10174,
  [10413] = 10413,
  [10414] = 10414,
  [10415] = 10415,
  [10416] = 10416,
  [10417] = 10417,
  [10418] = 10068,
  [10419] = 10419,
  [10420] = 10420,
  [10421] = 9879,
  [10422] = 10422,
  [10423] = 10423,
  [10424] = 10424,
  [10425] = 10425,
  [10426] = 10426,
  [10427] = 10427,
  [10428] = 10363,
  [10429] = 10429,
  [10430] = 8121,
  [10431] = 9899,
  [10432] = 10432,
  [10433] = 10433,
  [10434] = 10434,
  [10435] = 10435,
  [10436] = 10436,
  [10437] = 9879,
  [10438] = 10219,
  [10439] = 10439,
  [10440] = 9608,
  [10441] = 9297,
  [10442] = 8186,
  [10443] = 10443,
  [10444] = 10444,
  [10445] = 10363,
  [10446] = 8130,
  [10447] = 10363,
  [10448] = 10363,
  [10449] = 10449,
  [10450] = 10363,
  [10451] = 10451,
  [10452] = 9947,
  [10453] = 10453,
  [10454] = 9971,
  [10455] = 10455,
  [10456] = 7995,
  [10457] = 10363,
  [10458] = 8104,
  [10459] = 7988,
  [10460] = 7987,
  [10461] = 10288,
  [10462] = 3205,
  [10463] = 10463,
  [10464] = 9898,
  [10465] = 10465,
  [10466] = 10466,
  [10467] = 10363,
  [10468] = 3206,
  [10469] = 3207,
  [10470] = 7983,
  [10471] = 3208,
  [10472] = 10472,
  [10473] = 10473,
  [10474] = 7976,
  [10475] = 10475,
  [10476] = 10476,
  [10477] = 8647,
  [10478] = 10478,
  [10479] = 8947,
  [10480] = 10363,
  [10481] = 10363,
  [10482] = 8133,
  [10483] = 8121,
  [10484] = 10363,
  [10485] = 10485,
  [10486] = 10486,
  [10487] = 10363,
  [10488] = 7863,
  [10489] = 9420,
  [10490] = 10490,
  [10491] = 8239,
  [10492] = 5452,
  [10493] = 7957,
  [10494] = 10363,
  [10495] = 10495,
  [10496] = 10496,
  [10497] = 10497,
  [10498] = 10394,
  [10499] = 10499,
  [10500] = 10500,
  [10501] = 10501,
  [10502] = 10502,
  [10503] = 10363,
  [10504] = 10363,
  [10505] = 9610,
  [10506] = 10506,
  [10507] = 10507,
  [10508] = 8124,
  [10509] = 10363,
  [10510] = 7858,
  [10511] = 10182,
  [10512] = 8155,
  [10513] = 10363,
  [10514] = 9948,
  [10515] = 10363,
  [10516] = 10516,
  [10517] = 10363,
  [10518] = 10518,
  [10519] = 9045,
  [10520] = 10520,
  [10521] = 10521,
  [10522] = 10363,
  [10523] = 8129,
  [10524] = 8112,
  [10525] = 10525,
  [10526] = 10526,
  [10527] = 10527,
  [10528] = 10528,
  [10529] = 10529,
  [10530] = 8195,
  [10531] = 8145,
  [10532] = 8106,
  [10533] = 10533,
  [10534] = 10534,
  [10535] = 7920,
  [10536] = 10536,
  [10537] = 10537,
  [10538] = 10538,
  [10539] = 10539,
  [10540] = 10540,
  [10541] = 8136,
  [10542] = 10542,
  [10543] = 8164,
  [10544] = 10544,
  [10545] = 8138,
  [10546] = 8180,
  [10547] = 7928,
  [10548] = 8210,
  [10549] = 4772,
  [10550] = 10550,
  [10551] = 10551,
  [10552] = 10363,
  [10553] = 8225,
  [10554] = 8159,
  [10555] = 4709,
  [10556] = 10540,
  [10557] = 10557,
  [10558] = 10558,
  [10559] = 10539,
  [10560] = 10363,
  [10561] = 10527,
  [10562] = 10537,
  [10563] = 10068,
  [10564] = 10043,
  [10565] = 7929,
  [10566] = 10016,
  [10567] = 10363,
  [10568] = 10568,
  [10569] = 10526,
  [10570] = 5521,
  [10571] = 9998,
  [10572] = 10572,
  [10573] = 8137,
  [10574] = 10529,
  [10575] = 10080,
  [10576] = 8239,
  [10577] = 10528,
  [10578] = 10578,
  [10579] = 8120,
  [10580] = 10580,
  [10581] = 10525,
  [10582] = 10363,
  [10583] = 9349,
  [10584] = 10584,
  [10585] = 9050,
  [10586] = 10363,
  [10587] = 9899,
  [10588] = 10588,
  [10589] = 8155,
  [10590] = 5386,
  [10591] = 8120,
  [10592] = 8948,
  [10593] = 10521,
  [10594] = 8946,
  [10595] = 10455,
  [10596] = 10596,
  [10597] = 10520,
  [10598] = 8129,
  [10599] = 8112,
  [10600] = 8195,
  [10601] = 10363,
  [10602] = 9610,
  [10603] = 8106,
  [10604] = 7965,
  [10605] = 8176,
  [10606] = 10363,
  [10607] = 8170,
  [10608] = 10518,
  [10609] = 10609,
  [10610] = 8124,
  [10611] = 8163,
  [10612] = 10516,
  [10613] = 9114,
  [10614] = 8136,
  [10615] = 7958,
  [10616] = 8164,
  [10617] = 10363,
  [10618] = 10363,
  [10619] = 8180,
  [10620] = 10453,
  [10621] = 8210,
  [10622] = 8225,
  [10623] = 8159,
  [10624] = 4727,
  [10625] = 10362,
  [10626] = 10363,
  [10627] = 10363,
  [10628] = 9052,
  [10629] = 9054,
  [10630] = 10630,
  [10631] = 10363,
  [10632] = 10632,
  [10633] = 10633,
  [10634] = 10634,
  [10635] = 10363,
  [10636] = 9125,
  [10637] = 10407,
  [10638] = 9100,
  [10639] = 10639,
  [10640] = 10128,
  [10641] = 10641,
  [10642] = 9099,
  [10643] = 9894,
  [10644] = 9174,
  [10645] = 10363,
  [10646] = 10363,
  [10647] = 9255,
  [10648] = 5390,
  [10649] = 9060,
  [10650] = 10408,
  [10651] = 7955,
  [10652] = 10411,
  [10653] = 9217,
  [10654] = 7952,
  [10655] = 10655,
  [10656] = 10656,
  [10657] = 10657,
  [10658] = 10363,
  [10659] = 7951,
  [10660] = 10660,
  [10661] = 10661,
  [10662] = 10662,
  [10663] = 10663,
  [10664] = 10449,
  [10665] = 9140,
  [10666] = 10666,
  [10667] = 10667,
  [10668] = 10668,
  [10669] = 9034,
  [10670] = 10149,
  [10671] = 10671,
  [10672] = 9248,
  [10673] = 10429,
  [10674] = 9144,
  [10675] = 9059,
  [10676] = 10363,
  [10677] = 10677,
  [10678] = 7948,
  [10679] = 7947,
  [10680] = 7937,
  [10681] = 9049,
  [10682] = 9047,
  [10683] = 9242,
  [10684] = 10684,
  [10685] = 9082,
  [10686] = 9057,
  [10687] = 5419,
  [10688] = 9315,
  [10689] = 10403,
  [10690] = 9068,
  [10691] = 9610,
  [10692] = 10363,
  [10693] = 9137,
  [10694] = 9073,
  [10695] = 9175,
  [10696] = 9171,
  [10697] = 9108,
  [10698] = 10698,
  [10699] = 10699,
  [10700] = 10363,
  [10701] = 10701,
  [10702] = 10702,
  [10703] = 10703,
  [10704] = 9038,
  [10705] = 10705,
  [10706] = 10706,
  [10707] = 9171,
  [10708] = 10708,
  [10709] = 9297,
  [10710] = 5452,
  [10711] = 10540,
  [10712] = 10712,
  [10713] = 9610,
  [10714] = 10714,
  [10715] = 10715,
  [10716] = 10527,
  [10717] = 10717,
  [10718] = 3205,
  [10719] = 10288,
  [10720] = 10720,
  [10721] = 10721,
  [10722] = 9045,
  [10723] = 10723,
  [10724] = 10724,
  [10725] = 10714,
  [10726] = 9947,
  [10727] = 9971,
  [10728] = 10714,
  [10729] = 10526,
  [10730] = 10730,
  [10731] = 9879,
  [10732] = 10714,
  [10733] = 10733,
  [10734] = 10734,
  [10735] = 3205,
  [10736] = 10453,
  [10737] = 3206,
  [10738] = 9898,
  [10739] = 4903,
  [10740] = 10730,
  [10741] = 10741,
  [10742] = 10539,
  [10743] = 3208,
  [10744] = 10721,
  [10745] = 10745,
  [10746] = 10714,
  [10747] = 8155,
  [10748] = 9297,
  [10749] = 10721,
  [10750] = 10720,
  [10751] = 9038,
  [10752] = 9108,
  [10753] = 9175,
  [10754] = 10714,
  [10755] = 10715,
  [10756] = 10068,
  [10757] = 10080,
  [10758] = 9315,
  [10759] = 9057,
  [10760] = 9045,
  [10761] = 10712,
  [10762] = 3206,
  [10763] = 3207,
  [10764] = 10714,
  [10765] = 10712,
  [10766] = 10720,
  [10767] = 10721,
  [10768] = 10128,
  [10769] = 9068,
  [10770] = 9420,
  [10771] = 10715,
  [10772] = 10411,
  [10773] = 10714,
  [10774] = 5521,
  [10775] = 10408,
  [10776] = 3208,
  [10777] = 9060,
  [10778] = 10174,
  [10779] = 9217,
  [10780] = 9082,
  [10781] = 5521,
  [10782] = 10730,
  [10783] = 10745,
  [10784] = 9050,
  [10785] = 9242,
  [10786] = 9047,
  [10787] = 10714,
  [10788] = 10407,
  [10789] = 10714,
  [10790] = 9049,
  [10791] = 9049,
  [10792] = 9047,
  [10793] = 9242,
  [10794] = 10429,
  [10795] = 9082,
  [10796] = 9898,
  [10797] = 9057,
  [10798] = 9315,
  [10799] = 10219,
  [10800] = 10724,
  [10801] = 10394,
  [10802] = 9171,
  [10803] = 5521,
  [10804] = 10730,
  [10805] = 8970,
  [10806] = 10714,
  [10807] = 3207,
  [10808] = 10808,
  [10809] = 10730,
  [10810] = 3205,
  [10811] = 10712,
  [10812] = 10808,
  [10813] = 10714,
  [10814] = 9971,
  [10815] = 9899,
  [10816] = 9947,
  [10817] = 8287,
  [10818] = 8287,
  [10819] = 10819,
  [10820] = 10820,
  [10821] = 9879,
  [10822] = 10822,
  [10823] = 10714,
  [10824] = 9297,
  [10825] = 9175,
  [10826] = 9108,
  [10827] = 10537,
  [10828] = 10724,
  [10829] = 3206,
  [10830] = 9068,
  [10831] = 9059,
  [10832] = 3207,
  [10833] = 9171,
  [10834] = 8133,
  [10835] = 10529,
  [10836] = 9898,
  [10837] = 10708,
  [10838] = 9050,
  [10839] = 9059,
  [10840] = 9217,
  [10841] = 9114,
  [10842] = 9060,
  [10843] = 10712,
  [10844] = 9144,
  [10845] = 10708,
  [10846] = 9248,
  [10847] = 9034,
  [10848] = 9114,
  [10849] = 10528,
  [10850] = 9144,
  [10851] = 9038,
  [10852] = 9125,
  [10853] = 10741,
  [10854] = 9248,
  [10855] = 9100,
  [10856] = 10288,
  [10857] = 9034,
  [10858] = 10174,
  [10859] = 10714,
  [10860] = 10714,
  [10861] = 9060,
  [10862] = 10714,
  [10863] = 10516,
  [10864] = 9217,
  [10865] = 10714,
  [10866] = 10866,
  [10867] = 9174,
  [10868] = 10721,
  [10869] = 9099,
  [10870] = 10149,
  [10871] = 10712,
  [10872] = 9100,
  [10873] = 9125,
  [10874] = 10874,
  [10875] = 10721,
  [10876] = 10730,
  [10877] = 9114,
  [10878] = 9175,
  [10879] = 9099,
  [10880] = 10518,
  [10881] = 9174,
  [10882] = 9971,
  [10883] = 10724,
  [10884] = 9947,
  [10885] = 9049,
  [10886] = 9114,
  [10887] = 5521,
  [10888] = 9047,
  [10889] = 10889,
  [10890] = 10723,
  [10891] = 3208,
  [10892] = 9242,
  [10893] = 9082,
  [10894] = 10708,
  [10895] = 10068,
  [10896] = 10521,
  [10897] = 10714,
  [10898] = 10898,
  [10899] = 9125,
  [10900] = 10219,
  [10901] = 9100,
  [10902] = 9099,
  [10903] = 9174,
  [10904] = 9125,
  [10905] = 9057,
  [10906] = 10174,
  [10907] = 9100,
  [10908] = 10080,
  [10909] = 10411,
  [10910] = 10172,
  [10911] = 10714,
  [10912] = 9315,
  [10913] = 10411,
  [10914] = 9050,
  [10915] = 10408,
  [10916] = 9248,
  [10917] = 9068,
  [10918] = 9144,
  [10919] = 10919,
  [10920] = 10407,
  [10921] = 9045,
  [10922] = 9297,
  [10923] = 9099,
  [10924] = 9059,
  [10925] = 10925,
  [10926] = 9174,
  [10927] = 10720,
  [10928] = 10408,
  [10929] = 10708,
  [10930] = 10449,
  [10931] = 10931,
  [10932] = 9175,
  [10933] = 10933,
  [10934] = 9171,
  [10935] = 5452,
  [10936] = 10715,
  [10937] = 10937,
  [10938] = 9108,
  [10939] = 9038,
  [10940] = 10714,
  [10941] = 10520,
  [10942] = 9315,
  [10943] = 10182,
  [10944] = 9057,
  [10945] = 9879,
  [10946] = 9082,
  [10947] = 10525,
  [10948] = 9242,
  [10949] = 10949,
  [10950] = 9047,
  [10951] = 10925,
  [10952] = 9049,
  [10953] = 9034,
  [10954] = 10954,
  [10955] = 10955,
  [10956] = 9050,
  [10957] = 5452,
  [10958] = 10455,
  [10959] = 9217,
  [10960] = 9034,
  [10961] = 9038,
  [10962] = 8159,
  [10963] = 5521,
  [10964] = 10164,
  [10965] = 8239,
  [10966] = 9248,
  [10967] = 8225,
  [10968] = 9108,
  [10969] = 9144,
  [10970] = 9060,
  [10971] = 9068,
  [10972] = 10933,
  [10973] = 10362,
  [10974] = 10288,
  [10975] = 9059,
  [10976] = 10724,
  [10977] = 10724,
  [10978] = 10866,
  [10979] = 10931,
  [10980] = 10403,
  [10981] = 10714,
  [10982] = 10708,
  [10983] = 8210,
  [10984] = 8180,
  [10985] = 8164,
  [10986] = 8136,
  [10987] = 10949,
  [10988] = 10068,
  [10989] = 8124,
  [10990] = 8106,
  [10991] = 8195,
  [10992] = 8112,
  [10993] = 10080,
  [10994] = 9045,
  [10995] = 8129,
  [10996] = 10219,
  [10997] = 10407,
  [10998] = 10714,
  [10999] = 10999,
  [11000] = 11000,
  [11001] = 11001,
  [11002] = 11002,
  [11003] = 10408,
  [11004] = 10411,
  [11005] = 11005,
  [11006] = 7591,
  [11007] = 11007,
  [11008] = 11008,
  [11009] = 10407,
  [11010] = 9217,
  [11011] = 11011,
  [11012] = 11007,
  [11013] = 9060,
  [11014] = 11007,
  [11015] = 10949,
  [11016] = 11007,
  [11017] = 9050,
  [11018] = 9114,
  [11019] = 10403,
  [11020] = 11007,
  [11021] = 11007,
  [11022] = 9049,
  [11023] = 11023,
  [11024] = 9047,
  [11025] = 10219,
  [11026] = 8647,
  [11027] = 9242,
  [11028] = 8145,
  [11029] = 10429,
  [11030] = 11007,
  [11031] = 9082,
  [11032] = 9125,
  [11033] = 10449,
  [11034] = 9100,
  [11035] = 11007,
  [11036] = 10455,
  [11037] = 9947,
  [11038] = 9099,
  [11039] = 9971,
  [11040] = 9174,
  [11041] = 9948,
  [11042] = 9057,
  [11043] = 8133,
  [11044] = 8121,
  [11045] = 11007,
  [11046] = 11007,
  [11047] = 8121,
  [11048] = 11007,
  [11049] = 10411,
  [11050] = 11007,
  [11051] = 11007,
  [11052] = 9898,
  [11053] = 11053,
  [11054] = 11007,
  [11055] = 11055,
  [11056] = 10745,
  [11057] = 10933,
  [11058] = 9315,
  [11059] = 11059,
  [11060] = 10516,
  [11061] = 11007,
  [11062] = 10518,
  [11063] = 9610,
  [11064] = 11064,
  [11065] = 11007,
  [11066] = 10933,
  [11067] = 11007,
  [11068] = 8946,
  [11069] = 11069,
  [11070] = 10520,
  [11071] = 9924,
  [11072] = 9171,
  [11073] = 10453,
  [11074] = 11074,
  [11075] = 11007,
  [11076] = 9899,
  [11077] = 8120,
  [11078] = 11007,
  [11079] = 10521,
  [11080] = 11080,
  [11081] = 10408,
  [11082] = 10174,
  [11083] = 11083,
  [11084] = 11007,
  [11085] = 11007,
  [11086] = 11007,
  [11087] = 11087,
  [11088] = 3207,
  [11089] = 3205,
  [11090] = 11007,
  [11091] = 3206,
  [11092] = 10362,
  [11093] = 9879,
  [11094] = 9038,
  [11095] = 10526,
  [11096] = 3208,
  [11097] = 8948,
  [11098] = 8947,
  [11099] = 10407,
  [11100] = 3148,
  [11101] = 4727,
  [11102] = 10527,
  [11103] = 11007,
  [11104] = 10539,
  [11105] = 11007,
  [11106] = 3154,
  [11107] = 10540,
  [11108] = 11108,
  [11109] = 11109,
  [11110] = 9108,
  [11111] = 9045,
  [11112] = 11074,
  [11113] = 11007,
  [11114] = 11007,
  [11115] = 11008,
  [11116] = 11001,
  [11117] = 8178,
  [11118] = 8186,
  [11119] = 11007,
  [11120] = 10866,
  [11121] = 11007,
  [11122] = 11007,
  [11123] = 9034,
  [11124] = 9248,
  [11125] = 10172,
  [11126] = 8130,
  [11127] = 8137,
  [11128] = 10537,
  [11129] = 11007,
  [11130] = 10529,
  [11131] = 10931,
  [11132] = 11132,
  [11133] = 8138,
  [11134] = 9144,
  [11135] = 10528,
  [11136] = 9059,
  [11137] = 11064,
  [11138] = 11109,
  [11139] = 11108,
  [11140] = 10525,
  [11141] = 8287,
  [11142] = 10063,
  [11143] = 11143,
  [11144] = 4709,
  [11145] = 11007,
  [11146] = 4772,
  [11147] = 11147,
  [11148] = 11007,
  [11149] = 10394,
  [11150] = 11143,
  [11151] = 11002,
  [11152] = 11007,
  [11153] = 11153,
  [11154] = 5452,
  [11155] = 11155,
  [11156] = 10288,
  [11157] = 11059,
  [11158] = 11007,
  [11159] = 11005,
  [11160] = 11000,
  [11161] = 8225,
  [11162] = 11147,
  [11163] = 11007,
  [11164] = 8180,
  [11165] = 9916,
  [11166] = 8164,
  [11167] = 8136,
  [11168] = 11168,
  [11169] = 11007,
  [11170] = 10931,
  [11171] = 8124,
  [11172] = 11007,
  [11173] = 11007,
  [11174] = 11174,
  [11175] = 9297,
  [11176] = 11069,
  [11177] = 11053,
  [11178] = 5521,
  [11179] = 8239,
  [11180] = 8120,
  [11181] = 11007,
  [11182] = 9948,
  [11183] = 11007,
  [11184] = 10933,
  [11185] = 8106,
  [11186] = 11080,
  [11187] = 11087,
  [11188] = 11168,
  [11189] = 11055,
  [11190] = 8195,
  [11191] = 10931,
  [11192] = 11007,
  [11193] = 11132,
  [11194] = 11174,
  [11195] = 8112,
  [11196] = 8129,
  [11197] = 9068,
  [11198] = 8159,
  [11199] = 10172,
  [11200] = 10741,
  [11201] = 11007,
  [11202] = 10068,
  [11203] = 10080,
  [11204] = 8155,
  [11205] = 11007,
  [11206] = 8210,
  [11207] = 9175,
  [11208] = 11007,
  [11209] = 11087,
  [11210] = 11210,
  [11211] = 11211,
  [11212] = 11212,
  [11213] = 11212,
  [11214] = 11214,
  [11215] = 11211,
  [11216] = 11216,
  [11217] = 11211,
  [11218] = 11214,
  [11219] = 11212,
  [11220] = 11220,
  [11221] = 11221,
  [11222] = 11216,
  [11223] = 11223,
  [11224] = 11220,
  [11225] = 11216,
  [11226] = 11223,
  [11227] = 11227,
  [11228] = 8239,
  [11229] = 11210,
  [11230] = 11223,
  [11231] = 11216,
  [11232] = 11223,
  [11233] = 11220,
  [11234] = 11214,
  [11235] = 11211,
  [11236] = 8121,
  [11237] = 11212,
  [11238] = 11221,
  [11239] = 11220,
  [11240] = 11210,
  [11241] = 11210,
  [11242] = 11216,
  [11243] = 11214,
  [11244] = 11223,
  [11245] = 11221,
  [11246] = 11227,
  [11247] = 11247,
  [11248] = 11248,
  [11249] = 11210,
  [11250] = 11220,
  [11251] = 11223,
  [11252] = 11216,
  [11253] = 11253,
  [11254] = 10741,
  [11255] = 11214,
  [11256] = 11211,
  [11257] = 11212,
  [11258] = 9349,
  [11259] = 11259,
  [11260] = 11221,
  [11261] = 11210,
  [11262] = 11227,
  [11263] = 11210,
  [11264] = 11223,
  [11265] = 11216,
  [11266] = 11227,
  [11267] = 11210,
  [11268] = 11210,
  [11269] = 11220,
  [11270] = 11223,
  [11271] = 11216,
  [11272] = 11214,
  [11273] = 11212,
  [11274] = 11211,
  [11275] = 11212,
  [11276] = 11276,
  [11277] = 11220,
  [11278] = 11211,
  [11279] = 11221,
  [11280] = 11227,
  [11281] = 11227,
  [11282] = 11214,
  [11283] = 11283,
  [11284] = 8155,
  [11285] = 8129,
  [11286] = 8112,
  [11287] = 8195,
  [11288] = 11212,
  [11289] = 8106,
  [11290] = 8124,
  [11291] = 8136,
  [11292] = 8164,
  [11293] = 8180,
  [11294] = 8210,
  [11295] = 8225,
  [11296] = 8159,
  [11297] = 11227,
  [11298] = 11210,
  [11299] = 11214,
  [11300] = 11300,
  [11301] = 11220,
  [11302] = 11220,
  [11303] = 11211,
  [11304] = 11223,
  [11305] = 11216,
  [11306] = 11214,
  [11307] = 11211,
  [11308] = 11212,
  [11309] = 11212,
  [11310] = 11220,
  [11311] = 11221,
  [11312] = 11312,
  [11313] = 11313,
  [11314] = 11221,
  [11315] = 11221,
  [11316] = 11227,
  [11317] = 11220,
  [11318] = 11221,
  [11319] = 11210,
  [11320] = 11223,
  [11321] = 11216,
  [11322] = 11211,
  [11323] = 11227,
  [11324] = 11214,
  [11325] = 11211,
  [11326] = 11212,
  [11327] = 11220,
  [11328] = 11220,
  [11329] = 11221,
  [11330] = 11214,
  [11331] = 11220,
  [11332] = 11227,
  [11333] = 11210,
  [11334] = 11212,
  [11335] = 11211,
  [11336] = 11214,
  [11337] = 11223,
  [11338] = 11216,
  [11339] = 11214,
  [11340] = 11211,
  [11341] = 11220,
  [11342] = 11342,
  [11343] = 11216,
  [11344] = 11223,
  [11345] = 11212,
  [11346] = 8133,
  [11347] = 10931,
  [11348] = 11221,
  [11349] = 10933,
  [11350] = 11220,
  [11351] = 11221,
  [11352] = 11212,
  [11353] = 11220,
  [11354] = 11227,
  [11355] = 11211,
  [11356] = 11214,
  [11357] = 11227,
  [11358] = 11210,
  [11359] = 11216,
  [11360] = 11223,
  [11361] = 11210,
  [11362] = 11223,
  [11363] = 11363,
  [11364] = 11216,
  [11365] = 11214,
  [11366] = 11211,
  [11367] = 11212,
  [11368] = 11220,
  [11369] = 11216,
  [11370] = 11223,
  [11371] = 11221,
  [11372] = 11211,
  [11373] = 11210,
  [11374] = 11220,
  [11375] = 11227,
  [11376] = 11210,
  [11377] = 11223,
  [11378] = 11216,
  [11379] = 11220,
  [11380] = 11214,
  [11381] = 11221,
  [11382] = 11211,
  [11383] = 11212,
  [11384] = 11216,
  [11385] = 11227,
  [11386] = 11227,
  [11387] = 11223,
  [11388] = 11221,
  [11389] = 11227,
  [11390] = 10174,
  [11391] = 11253,
  [11392] = 11220,
  [11393] = 11210,
  [11394] = 11223,
  [11395] = 11210,
  [11396] = 11214,
  [11397] = 11216,
  [11398] = 11214,
  [11399] = 11211,
  [11400] = 11212,
  [11401] = 11216,
  [11402] = 11248,
  [11403] = 11210,
  [11404] = 11220,
  [11405] = 11227,
  [11406] = 11221,
  [11407] = 11220,
  [11408] = 11408,
  [11409] = 11221,
  [11410] = 10407,
  [11411] = 11143,
  [11412] = 11221,
  [11413] = 11223,
  [11414] = 11220,
  [11415] = 11227,
  [11416] = 11223,
  [11417] = 10408,
  [11418] = 10411,
  [11419] = 11216,
  [11420] = 11227,
  [11421] = 11210,
  [11422] = 11214,
  [11423] = 11223,
  [11424] = 11211,
  [11425] = 11223,
  [11426] = 11216,
  [11427] = 11212,
  [11428] = 8120,
  [11429] = 11220,
  [11430] = 11214,
  [11431] = 11216,
  [11432] = 11210,
  [11433] = 11247,
  [11434] = 11227,
  [11435] = 11221,
  [11436] = 11212,
  [11437] = 11437,
  [11438] = 11214,
  [11439] = 11211,
  [11440] = 11214,
  [11441] = 11211,
  [11442] = 11212,
  [11443] = 11221,
  [11444] = 11227,
  [11445] = 11211,
  [11446] = 11221,
  [11447] = 11210,
  [11448] = 11212,
  [11449] = 11220,
  [11450] = 11450,
  [11451] = 11451,
  [11452] = 11452,
  [11453] = 10219,
  [11454] = 11221,
  [11455] = 11212,
  [11456] = 11456,
  [11457] = 11210,
  [11458] = 11211,
  [11459] = 11221,
  [11460] = 8239,
  [11461] = 11220,
  [11462] = 11227,
  [11463] = 11214,
  [11464] = 11005,
  [11465] = 11210,
  [11466] = 11223,
  [11467] = 11216,
  [11468] = 11223,
  [11469] = 11214,
  [11470] = 11211,
  [11471] = 11216,
  [11472] = 11214,
  [11473] = 11212,
  [11474] = 11174,
  [11475] = 10080,
  [11476] = 8159,
  [11477] = 8225,
  [11478] = 8210,
  [11479] = 8180,
  [11480] = 8164,
  [11481] = 8136,
  [11482] = 8124,
  [11483] = 8106,
  [11484] = 11211,
  [11485] = 8195,
  [11486] = 8112,
  [11487] = 8129,
  [11488] = 8120,
  [11489] = 10068,
  [11490] = 10288,
  [11491] = 11212,
  [11492] = 11216,
  [11493] = 8155,
  [11494] = 11223,
  [11495] = 11212,
  [11496] = 11221,
  [11497] = 11221,
  [11498] = 11210,
  [11499] = 11227,
  [11500] = 11500,
  [11501] = 11211,
  [11502] = 11220,
  [11503] = 11221,
  [11504] = 11214,
  [11505] = 11221,
  [11506] = 11227,
  [11507] = 9879,
  [11508] = 11212,
  [11509] = 11227,
  [11510] = 10172,
  [11511] = 11211,
  [11512] = 11214,
  [11513] = 11227,
  [11514] = 11080,
  [11515] = 9947,
  [11516] = 11210,
  [11517] = 9971,
  [11518] = 11216,
  [11519] = 11223,
  [11520] = 11220,
  [11521] = 11216,
  [11522] = 11223,
  [11523] = 11220,
  [11524] = 11223,
  [11525] = 11216,
  [11526] = 11214,
  [11527] = 11227,
  [11528] = 11211,
  [11529] = 11437,
  [11530] = 11211,
  [11531] = 11210,
  [11532] = 11221,
  [11533] = 11227,
  [11534] = 11223,
  [11535] = 11221,
  [11536] = 11216,
  [11537] = 10931,
  [11538] = 10933,
  [11539] = 11212,
  [11540] = 11214,
  [11541] = 11211,
  [11542] = 9898,
  [11543] = 11220,
  [11544] = 11220,
  [11545] = 11212,
  [11546] = 11221,
  [11547] = 11211,
  [11548] = 11214,
  [11549] = 11212,
  [11550] = 11216,
  [11551] = 11227,
  [11552] = 11223,
  [11553] = 10866,
  [11554] = 11212,
  [11555] = 11223,
  [11556] = 11216,
  [11557] = 9948,
  [11558] = 11220,
  [11559] = 11227,
  [11560] = 11064,
  [11561] = 11214,
  [11562] = 11210,
  [11563] = 11212,
  [11564] = 11283,
  [11565] = 11211,
  [11566] = 11221,
  [11567] = 11211,
  [11568] = 11214,
  [11569] = 11053,
  [11570] = 11408,
  [11571] = 11212,
  [11572] = 11210,
  [11573] = 11573,
  [11574] = 11276,
  [11575] = 11227,
  [11576] = 11216,
  [11577] = 11227,
  [11578] = 11132,
  [11579] = 11210,
  [11580] = 8138,
  [11581] = 11212,
  [11582] = 11221,
  [11583] = 8137,
  [11584] = 8130,
  [11585] = 11220,
  [11586] = 11210,
  [11587] = 8186,
  [11588] = 11227,
  [11589] = 10949,
  [11590] = 11210,
  [11591] = 11210,
  [11592] = 11220,
  [11593] = 11223,
  [11594] = 11216,
  [11595] = 8178,
  [11596] = 11214,
  [11597] = 11211,
  [11598] = 11212,
  [11599] = 11223,
  [11600] = 11053,
  [11601] = 11214,
  [11602] = 11220,
  [11603] = 8145,
  [11604] = 11223,
  [11605] = 11216,
  [11606] = 11210,
  [11607] = 11212,
  [11608] = 11227,
  [11609] = 11211,
  [11610] = 11214,
  [11611] = 11216,
  [11612] = 11223,
  [11613] = 11210,
  [11614] = 11210,
  [11615] = 11227,
  [11616] = 11210,
  [11617] = 11221,
  [11618] = 11221,
  [11619] = 11227,
  [11620] = 11312,
  [11621] = 11621,
  [11622] = 11220,
  [11623] = 11212,
  [11624] = 11210,
  [11625] = 11220,
  [11626] = 11211,
  [11627] = 11214,
  [11628] = 8133,
  [11629] = 11216,
  [11630] = 11223,
  [11631] = 8121,
  [11632] = 10407,
  [11633] = 11053,
  [11634] = 11313,
  [11635] = 11210,
  [11636] = 11223,
  [11637] = 11216,
  [11638] = 11214,
  [11639] = 10408,
  [11640] = 11227,
  [11641] = 10411,
  [11642] = 11223,
  [11643] = 11216,
  [11644] = 11214,
  [11645] = 11211,
  [11646] = 11212,
  [11647] = 11227,
  [11648] = 10745,
  [11649] = 11221,
  [11650] = 11227,
  [11651] = 11221,
  [11652] = 11211,
  [11653] = 11227,
  [11654] = 11221,
  [11655] = 11214,
  [11656] = 11211,
  [11657] = 11210,
  [11658] = 11064,
  [11659] = 11212,
  [11660] = 11223,
  [11661] = 11221,
  [11662] = 11216,
  [11663] = 11220,
  [11664] = 11214,
  [11665] = 11211,
  [11666] = 11212,
  [11667] = 11212,
  [11668] = 11668,
  [11669] = 11212,
  [11670] = 11211,
  [11671] = 11214,
  [11672] = 11220,
  [11673] = 10411,
  [11674] = 10408,
  [11675] = 11216,
  [11676] = 11223,
  [11677] = 8239,
  [11678] = 10407,
  [11679] = 11221,
  [11680] = 11210,
  [11681] = 11221,
  [11682] = 11220,
  [11683] = 11221,
  [11684] = 11220,
  [11685] = 11227,
  [11686] = 11216,
  [11687] = 11223,
  [11688] = 11216,
  [11689] = 11227,
  [11690] = 11221,
  [11691] = 11087,
  [11692] = 11064,
  [11693] = 11221,
  [11694] = 11221,
  [11695] = 11210,
  [11696] = 11080,
  [11697] = 11223,
  [11698] = 11227,
  [11699] = 11699,
  [11700] = 11216,
  [11701] = 11210,
  [11702] = 11214,
  [11703] = 11211,
  [11704] = 11212,
  [11705] = 8970,
  [11706] = 11168,
  [11707] = 4903,
  [11708] = 11080,
  [11709] = 11087,
  [11710] = 11132,
  [11711] = 11220,
  [11712] = 11212,
  [11713] = 11221,
  [11714] = 11211,
  [11715] = 11214,
  [11716] = 11227,
  [11717] = 11216,
  [11718] = 11223,
  [11719] = 11210,
  [11720] = 11132,
  [11721] = 11212,
  [11722] = 11223,
  [11723] = 11216,
  [11724] = 11212,
  [11725] = 11211,
  [11726] = 11210,
  [11727] = 11214,
  [11728] = 11223,
  [11729] = 11211,
  [11730] = 11214,
  [11731] = 11227,
  [11732] = 11732,
  [11733] = 11733,
  [11734] = 3205,
  [11735] = 11069,
  [11736] = 11055,
  [11737] = 11000,
  [11738] = 11002,
  [11739] = 11132,
  [11740] = 3208,
  [11741] = 3207,
  [11742] = 3206,
  [11743] = 11147,
  [11744] = 11108,
  [11745] = 11109,
  [11746] = 11074,
  [11747] = 11008,
  [11748] = 11748,
  [11749] = 11055,
  [11750] = 11001,
  [11751] = 11247,
  [11752] = 11733,
  [11753] = 11753,
  [11754] = 8946,
  [11755] = 11313,
  [11756] = 11300,
  [11757] = 11312,
  [11758] = 8138,
  [11759] = 8137,
  [11760] = 8130,
  [11761] = 8186,
  [11762] = 8178,
  [11763] = 11276,
  [11764] = 8948,
  [11765] = 8947,
  [11766] = 11001,
  [11767] = 11074,
  [11768] = 11109,
  [11769] = 11108,
  [11770] = 11147,
  [11771] = 9174,
  [11772] = 11069,
  [11773] = 9114,
  [11774] = 11055,
  [11775] = 9125,
  [11776] = 9100,
  [11777] = 9099,
  [11778] = 8120,
  [11779] = 11253,
  [11780] = 11000,
  [11781] = 11002,
  [11782] = 11782,
  [11783] = 11408,
  [11784] = 11008,
  [11785] = 9248,
  [11786] = 11248,
  [11787] = 11053,
  [11788] = 11748,
  [11789] = 9144,
  [11790] = 9059,
  [11791] = 8239,
  [11792] = 9315,
  [11793] = 11064,
  [11794] = 9175,
  [11795] = 11748,
  [11796] = 11008,
  [11797] = 9171,
  [11798] = 9108,
  [11799] = 9034,
  [11800] = 9948,
  [11801] = 8121,
  [11802] = 9050,
  [11803] = 9057,
  [11804] = 9082,
  [11805] = 9899,
  [11806] = 9242,
  [11807] = 9047,
  [11808] = 9049,
  [11809] = 9297,
  [11810] = 8239,
  [11811] = 11087,
  [11812] = 11080,
  [11813] = 9217,
  [11814] = 9060,
  [11815] = 11733,
  [11816] = 11064,
  [11817] = 10931,
  [11818] = 11069,
  [11819] = 9068,
  [11820] = 9038,
  [11821] = 11143,
  [11822] = 9045,
  [11823] = 11823,
  [11824] = 8159,
  [11825] = 10933,
  [11826] = 8225,
  [11827] = 8210,
  [11828] = 8180,
  [11829] = 8164,
  [11830] = 8136,
  [11831] = 8124,
  [11832] = 11005,
  [11833] = 8106,
  [11834] = 8195,
  [11835] = 8112,
  [11836] = 8129,
  [11837] = 11733,
  [11838] = 11132,
  [11839] = 11253,
  [11840] = 8155,
  [11841] = 11053,
  [11842] = 11842,
  [11843] = 11452,
  [11844] = 11748,
  [11845] = 11845,
  [11846] = 11733,
  [11847] = 10933,
  [11848] = 10931,
  [11849] = 11408,
  [11850] = 11748,
  [11851] = 11087,
  [11852] = 11080,
  [11853] = 11002,
  [11854] = 8647,
  [11855] = 8287,
  [11856] = 11748,
  [11857] = 10172,
  [11858] = 11147,
  [11859] = 11108,
  [11860] = 11109,
  [11861] = 11174,
  [11862] = 11074,
  [11863] = 11733,
  [11864] = 8145,
  [11865] = 5452,
  [11866] = 11845,
  [11867] = 10931,
  [11868] = 11001,
  [11869] = 10933,
  [11870] = 8159,
  [11871] = 8225,
  [11872] = 11872,
  [11873] = 11168,
  [11874] = 8210,
  [11875] = 8180,
  [11876] = 8164,
  [11877] = 11000,
  [11878] = 8136,
  [11879] = 8124,
  [11880] = 11880,
  [11881] = 11881,
  [11882] = 8106,
  [11883] = 11748,
  [11884] = 8195,
  [11885] = 8112,
  [11886] = 8129,
  [11887] = 8120,
  [11888] = 8155,
  [11889] = 11247,
  [11890] = 11313,
  [11891] = 11312,
  [11892] = 11276,
  [11893] = 5521,
  [11894] = 11248,
  [11895] = 11733,
  [11896] = 8133,
  [11897] = 8121,
  [11898] = 11748,
  [11899] = 8133,
  [11900] = 8239,
  [11901] = 11901,
  [11902] = 8239,
  [11903] = 8121,
  [11904] = 8133,
  [11905] = 8155,
  [11906] = 8120,
  [11907] = 11901,
  [11908] = 11908,
  [11909] = 8121,
  [11910] = 11901,
  [11911] = 11911,
  [11912] = 8129,
  [11913] = 11913,
  [11914] = 11901,
  [11915] = 8112,
  [11916] = 8195,
  [11917] = 11901,
  [11918] = 11918,
  [11919] = 8106,
  [11920] = 10411,
  [11921] = 10407,
  [11922] = 10408,
  [11923] = 10407,
  [11924] = 8178,
  [11925] = 8186,
  [11926] = 8130,
  [11927] = 8124,
  [11928] = 8136,
  [11929] = 8137,
  [11930] = 11930,
  [11931] = 8164,
  [11932] = 8138,
  [11933] = 11901,
  [11934] = 8180,
  [11935] = 11935,
  [11936] = 8210,
  [11937] = 8225,
  [11938] = 8159,
  [11939] = 11939,
  [11940] = 3148,
  [11941] = 11941,
  [11942] = 11901,
  [11943] = 8155,
  [11944] = 11944,
  [11945] = 11944,
  [11946] = 8120,
  [11947] = 8129,
  [11948] = 8112,
  [11949] = 8195,
  [11950] = 11901,
  [11951] = 8106,
  [11952] = 8124,
  [11953] = 8136,
  [11954] = 8164,
  [11955] = 11955,
  [11956] = 8180,
  [11957] = 11901,
  [11958] = 11958,
  [11959] = 8210,
  [11960] = 8225,
  [11961] = 8239,
  [11962] = 8159,
  [11963] = 8121,
  [11964] = 11901,
  [11965] = 8145,
  [11966] = 10411,
  [11967] = 11901,
  [11968] = 10408,
  [11969] = 8239,
  [11970] = 8133,
  [11971] = 3129,
  [11972] = 8239,
  [11973] = 3131,
  [11974] = 3154,
  [11975] = 3125,
  [11976] = 11976,
  [11977] = 8145,
  [11978] = 11978,
  [11979] = 11930,
  [11980] = 11901,
  [11981] = 9899,
  [11982] = 8138,
  [11983] = 11064,
  [11984] = 11984,
  [11985] = 8137,
  [11986] = 8130,
  [11987] = 8178,
  [11988] = 8186,
  [11989] = 11053,
  [11990] = 8121,
  [11991] = 8186,
  [11992] = 8178,
  [11993] = 8130,
  [11994] = 8137,
  [11995] = 8120,
  [11996] = 8138,
  [11997] = 11901,
  [11998] = 8138,
  [11999] = 10408,
  [12000] = 10411,
  [12001] = 8239,
  [12002] = 11901,
  [12003] = 12003,
  [12004] = 8137,
  [12005] = 8120,
  [12006] = 3123,
  [12007] = 3121,
  [12008] = 11901,
  [12009] = 3120,
  [12010] = 12010,
  [12011] = 8145,
  [12012] = 8145,
  [12013] = 11901,
  [12014] = 8239,
  [12015] = 8121,
  [12016] = 11978,
  [12017] = 11955,
  [12018] = 8121,
  [12019] = 11901,
  [12020] = 11941,
  [12021] = 11901,
  [12022] = 11935,
  [12023] = 8133,
  [12024] = 11941,
  [12025] = 8130,
  [12026] = 8186,
  [12027] = 11901,
  [12028] = 12028,
  [12029] = 8120,
  [12030] = 12030,
  [12031] = 8155,
  [12032] = 8120,
  [12033] = 8129,
  [12034] = 12034,
  [12035] = 10288,
  [12036] = 8121,
  [12037] = 8178,
  [12038] = 11901,
  [12039] = 8239,
  [12040] = 8112,
  [12041] = 8195,
  [12042] = 8106,
  [12043] = 8124,
  [12044] = 8136,
  [12045] = 11901,
  [12046] = 8164,
  [12047] = 11901,
  [12048] = 12028,
  [12049] = 12030,
  [12050] = 8180,
  [12051] = 12051,
  [12052] = 8120,
  [12053] = 8210,
  [12054] = 11901,
  [12055] = 8225,
  [12056] = 8159,
  [12057] = 8647,
  [12058] = 12058,
  [12059] = 12059,
  [12060] = 12060,
  [12061] = 11901,
  [12062] = 8948,
  [12063] = 11901,
  [12064] = 11901,
  [12065] = 11901,
  [12066] = 11080,
  [12067] = 12067,
  [12068] = 11087,
  [12069] = 11132,
  [12070] = 8120,
  [12071] = 12071,
  [12072] = 12072,
  [12073] = 12073,
  [12074] = 12074,
  [12075] = 10407,
  [12076] = 12076,
  [12077] = 12077,
  [12078] = 12071,
  [12079] = 11901,
  [12080] = 11911,
  [12081] = 12074,
  [12082] = 12073,
  [12083] = 11978,
  [12084] = 12084,
  [12085] = 12085,
  [12086] = 8178,
  [12087] = 8186,
  [12088] = 8130,
  [12089] = 12072,
  [12090] = 11901,
  [12091] = 8137,
  [12092] = 11908,
  [12093] = 12060,
  [12094] = 8138,
  [12095] = 11901,
  [12096] = 11901,
  [12097] = 8133,
  [12098] = 8121,
  [12099] = 9349,
  [12100] = 8178,
  [12101] = 8186,
  [12102] = 8130,
  [12103] = 8137,
  [12104] = 8159,
  [12105] = 8225,
  [12106] = 8210,
  [12107] = 8180,
  [12108] = 8164,
  [12109] = 8136,
  [12110] = 8124,
  [12111] = 8138,
  [12112] = 12059,
  [12113] = 8106,
  [12114] = 8195,
  [12115] = 8121,
  [12116] = 8112,
  [12117] = 11901,
  [12118] = 8129,
  [12119] = 8120,
  [12120] = 8155,
  [12121] = 8133,
  [12122] = 10933,
  [12123] = 8155,
  [12124] = 11913,
  [12125] = 10931,
  [12126] = 11939,
  [12127] = 12010,
  [12128] = 12128,
  [12129] = 8159,
  [12130] = 8225,
  [12131] = 12131,
  [12132] = 3208,
  [12133] = 12133,
  [12134] = 8210,
  [12135] = 8180,
  [12136] = 8164,
  [12137] = 11901,
  [12138] = 11901,
  [12139] = 8136,
  [12140] = 8124,
  [12141] = 8106,
  [12142] = 8121,
  [12143] = 8133,
  [12144] = 11901,
  [12145] = 8195,
  [12146] = 8112,
  [12147] = 8129,
  [12148] = 8121,
  [12149] = 8946,
  [12150] = 8120,
  [12151] = 8178,
  [12152] = 8186,
  [12153] = 8155,
  [12154] = 8130,
  [12155] = 3207,
  [12156] = 11901,
  [12157] = 8129,
  [12158] = 3206,
  [12159] = 8137,
  [12160] = 8112,
  [12161] = 8138,
  [12162] = 12162,
  [12163] = 8195,
  [12164] = 8106,
  [12165] = 11901,
  [12166] = 8124,
  [12167] = 8136,
  [12168] = 8164,
  [12169] = 8180,
  [12170] = 8155,
  [12171] = 8120,
  [12172] = 8210,
  [12173] = 12051,
  [12174] = 5452,
  [12175] = 8129,
  [12176] = 8112,
  [12177] = 11901,
  [12178] = 12128,
  [12179] = 8195,
  [12180] = 11901,
  [12181] = 12181,
  [12182] = 8225,
  [12183] = 8159,
  [12184] = 8106,
  [12185] = 11901,
  [12186] = 12076,
  [12187] = 8124,
  [12188] = 8145,
  [12189] = 11984,
  [12190] = 8136,
  [12191] = 8164,
  [12192] = 11978,
  [12193] = 8180,
  [12194] = 11901,
  [12195] = 8210,
  [12196] = 8225,
  [12197] = 8159,
  [12198] = 8970,
  [12199] = 12084,
  [12200] = 3205,
  [12201] = 11918,
  [12202] = 11976,
  [12203] = 12077,
  [12204] = 11901,
  [12205] = 8133,
  [12206] = 12058,
  [12207] = 11901,
  [12208] = 8121,
  [12209] = 8947,
  [12210] = 8145,
  [12211] = 8120,
  [12212] = 12212,
  [12213] = 8210,
  [12214] = 8155,
  [12215] = 12215,
  [12216] = 12212,
  [12217] = 12217,
  [12218] = 12215,
  [12219] = 8129,
  [12220] = 12215,
  [12221] = 12215,
  [12222] = 8138,
  [12223] = 9034,
  [12224] = 8137,
  [12225] = 8112,
  [12226] = 9248,
  [12227] = 8130,
  [12228] = 8195,
  [12229] = 8186,
  [12230] = 9144,
  [12231] = 8106,
  [12232] = 9059,
  [12233] = 12217,
  [12234] = 8178,
  [12235] = 12212,
  [12236] = 8124,
  [12237] = 12215,
  [12238] = 8136,
  [12239] = 8164,
  [12240] = 12215,
  [12241] = 12241,
  [12242] = 8180,
  [12243] = 12215,
  [12244] = 12215,
  [12245] = 12215,
  [12246] = 12212,
  [12247] = 12217,
  [12248] = 8210,
  [12249] = 9114,
  [12250] = 12217,
  [12251] = 12215,
  [12252] = 8133,
  [12253] = 8121,
  [12254] = 8225,
  [12255] = 12215,
  [12256] = 12217,
  [12257] = 8159,
  [12258] = 12215,
  [12259] = 11958,
  [12260] = 12212,
  [12261] = 12212,
  [12262] = 12212,
  [12263] = 12215,
  [12264] = 12217,
  [12265] = 12215,
  [12266] = 12215,
  [12267] = 12217,
  [12268] = 12215,
  [12269] = 12217,
  [12270] = 8145,
  [12271] = 12212,
  [12272] = 12217,
  [12273] = 12212,
  [12274] = 8186,
  [12275] = 8130,
  [12276] = 8239,
  [12277] = 8133,
  [12278] = 12217,
  [12279] = 8178,
  [12280] = 12212,
  [12281] = 8148,
  [12282] = 10288,
  [12283] = 8970,
  [12284] = 8120,
  [12285] = 12076,
  [12286] = 12215,
  [12287] = 3120,
  [12288] = 3121,
  [12289] = 3123,
  [12290] = 12215,
  [12291] = 3125,
  [12292] = 12215,
  [12293] = 8121,
  [12294] = 8225,
  [12295] = 8210,
  [12296] = 8180,
  [12297] = 8239,
  [12298] = 8164,
  [12299] = 8136,
  [12300] = 12217,
  [12301] = 8124,
  [12302] = 12215,
  [12303] = 8106,
  [12304] = 8195,
  [12305] = 3107,
  [12306] = 12212,
  [12307] = 8112,
  [12308] = 12215,
  [12309] = 8129,
  [12310] = 3129,
  [12311] = 12215,
  [12312] = 8120,
  [12313] = 8155,
  [12314] = 12215,
  [12315] = 3131,
  [12316] = 3108,
  [12317] = 12212,
  [12318] = 12215,
  [12319] = 8178,
  [12320] = 12217,
  [12321] = 8120,
  [12322] = 12215,
  [12323] = 12060,
  [12324] = 12215,
  [12325] = 8155,
  [12326] = 12215,
  [12327] = 8120,
  [12328] = 8129,
  [12329] = 8159,
  [12330] = 8112,
  [12331] = 8195,
  [12332] = 12212,
  [12333] = 8138,
  [12334] = 12215,
  [12335] = 8137,
  [12336] = 8130,
  [12337] = 8186,
  [12338] = 12217,
  [12339] = 12217,
  [12340] = 8178,
  [12341] = 12212,
  [12342] = 8106,
  [12343] = 12215,
  [12344] = 8124,
  [12345] = 12215,
  [12346] = 8239,
  [12347] = 8121,
  [12348] = 8133,
  [12349] = 8136,
  [12350] = 3110,
  [12351] = 8164,
  [12352] = 12212,
  [12353] = 12051,
  [12354] = 3111,
  [12355] = 3109,
  [12356] = 3148,
  [12357] = 8180,
  [12358] = 8164,
  [12359] = 8210,
  [12360] = 12217,
  [12361] = 3154,
  [12362] = 12362,
  [12363] = 12217,
  [12364] = 8225,
  [12365] = 12217,
  [12366] = 12028,
  [12367] = 12212,
  [12368] = 12215,
  [12369] = 5050,
  [12370] = 12217,
  [12371] = 12212,
  [12372] = 8159,
  [12373] = 12212,
  [12374] = 12374,
  [12375] = 8159,
  [12376] = 9175,
  [12377] = 12212,
  [12378] = 9171,
  [12379] = 8155,
  [12380] = 8129,
  [12381] = 8112,
  [12382] = 8225,
  [12383] = 9108,
  [12384] = 12212,
  [12385] = 8210,
  [12386] = 12215,
  [12387] = 8133,
  [12388] = 9038,
  [12389] = 12217,
  [12390] = 8180,
  [12391] = 12212,
  [12392] = 9297,
  [12393] = 8136,
  [12394] = 12071,
  [12395] = 12215,
  [12396] = 8124,
  [12397] = 12397,
  [12398] = 8106,
  [12399] = 8195,
  [12400] = 8195,
  [12401] = 8112,
  [12402] = 8129,
  [12403] = 8106,
  [12404] = 12215,
  [12405] = 8124,
  [12406] = 8120,
  [12407] = 8136,
  [12408] = 8164,
  [12409] = 8180,
  [12410] = 8155,
  [12411] = 11918,
  [12412] = 12217,
  [12413] = 8210,
  [12414] = 8225,
  [12415] = 12212,
  [12416] = 8159,
  [12417] = 12215,
  [12418] = 8239,
  [12419] = 8155,
  [12420] = 12217,
  [12421] = 12217,
  [12422] = 8129,
  [12423] = 8112,
  [12424] = 8195,
  [12425] = 8106,
  [12426] = 8124,
  [12427] = 12427,
  [12428] = 8136,
  [12429] = 12429,
  [12430] = 8178,
  [12431] = 8178,
  [12432] = 8138,
  [12433] = 8186,
  [12434] = 8130,
  [12435] = 8137,
  [12436] = 8121,
  [12437] = 8137,
  [12438] = 12217,
  [12439] = 8145,
  [12440] = 8138,
  [12441] = 8186,
  [12442] = 12212,
  [12443] = 12215,
  [12444] = 8164,
  [12445] = 8180,
  [12446] = 12215,
  [12447] = 8210,
  [12448] = 8225,
  [12449] = 12215,
  [12450] = 8159,
  [12451] = 8130,
  [12452] = 8155,
  [12453] = 8129,
  [12454] = 8159,
  [12455] = 8137,
  [12456] = 8225,
  [12457] = 8136,
  [12458] = 8138,
  [12459] = 8210,
  [12460] = 8133,
  [12461] = 8112,
  [12462] = 8180,
  [12463] = 8164,
  [12464] = 8195,
  [12465] = 12215,
  [12466] = 8239,
  [12467] = 8136,
  [12468] = 8106,
  [12469] = 8124,
  [12470] = 8239,
  [12471] = 8124,
  [12472] = 8159,
  [12473] = 8106,
  [12474] = 8195,
  [12475] = 8133,
  [12476] = 9315,
  [12477] = 9057,
  [12478] = 9082,
  [12479] = 8136,
  [12480] = 9242,
  [12481] = 8129,
  [12482] = 8225,
  [12483] = 8210,
  [12484] = 8120,
  [12485] = 8164,
  [12486] = 8155,
  [12487] = 9047,
  [12488] = 12215,
  [12489] = 9049,
  [12490] = 12217,
  [12491] = 8180,
  [12492] = 8164,
  [12493] = 8120,
  [12494] = 12215,
  [12495] = 12212,
  [12496] = 12074,
  [12497] = 12217,
  [12498] = 12215,
  [12499] = 12215,
  [12500] = 8180,
  [12501] = 8210,
  [12502] = 8124,
  [12503] = 8092,
  [12504] = 8225,
  [12505] = 8106,
  [12506] = 8195,
  [12507] = 8112,
  [12508] = 8112,
  [12509] = 12212,
  [12510] = 12212,
  [12511] = 8129,
  [12512] = 12212,
  [12513] = 12217,
  [12514] = 8137,
  [12515] = 10933,
  [12516] = 8159,
  [12517] = 8163,
  [12518] = 10931,
  [12519] = 12217,
  [12520] = 8138,
  [12521] = 12217,
  [12522] = 12215,
  [12523] = 8106,
  [12524] = 12217,
  [12525] = 8170,
  [12526] = 12212,
  [12527] = 12215,
  [12528] = 8155,
  [12529] = 12073,
  [12530] = 12215,
  [12531] = 8176,
  [12532] = 12532,
  [12533] = 12215,
  [12534] = 9050,
  [12535] = 12072,
  [12536] = 8155,
  [12537] = 8120,
  [12538] = 9217,
  [12539] = 8129,
  [12540] = 8112,
  [12541] = 12212,
  [12542] = 12212,
  [12543] = 8133,
  [12544] = 9060,
  [12545] = 8195,
  [12546] = 12217,
  [12547] = 8124,
  [12548] = 8136,
  [12549] = 8164,
  [12550] = 8180,
  [12551] = 12215,
  [12552] = 12217,
  [12553] = 12217,
  [12554] = 12030,
  [12555] = 12215,
  [12556] = 8225,
  [12557] = 8159,
  [12558] = 12212,
  [12559] = 12212,
  [12560] = 12212,
  [12561] = 12215,
  [12562] = 12217,
  [12563] = 12215,
  [12564] = 8145,
  [12565] = 12217,
  [12566] = 8133,
  [12567] = 8239,
  [12568] = 8239,
  [12569] = 12077,
  [12570] = 12429,
  [12571] = 12217,
  [12572] = 9068,
  [12573] = 12212,
  [12574] = 12084,
  [12575] = 12575,
  [12576] = 8121,
  [12577] = 12131,
  [12578] = 12133,
  [12579] = 11984,
  [12580] = 12215,
  [12581] = 8145,
  [12582] = 8121,
  [12583] = 12217,
  [12584] = 12217,
  [12585] = 12212,
  [12586] = 12212,
  [12587] = 12215,
  [12588] = 12217,
  [12589] = 12212,
  [12590] = 8104,
  [12591] = 11976,
  [12592] = 12217,
  [12593] = 9174,
  [12594] = 12212,
  [12595] = 9099,
  [12596] = 9045,
  [12597] = 9100,
  [12598] = 12215,
  [12599] = 12215,
  [12600] = 9125,
  [12601] = 2968,
  [12602] = 12217,
  [12603] = 12215,
  [12604] = 8121,
  [12605] = 2972,
  [12606] = 12217,
  [12607] = 8133,
  [12608] = 12217,
  [12609] = 12212,
  [12610] = 8130,
  [12611] = 8133,
  [12612] = 8186,
  [12613] = 12212,
  [12614] = 12217,
  [12615] = 12215,
  [12616] = 12215,
  [12617] = 12212,
  [12618] = 12212,
  [12619] = 8239,
  [12620] = 8239,
  [12621] = 8121,
  [12622] = 8239,
  [12623] = 12212,
  [12624] = 12624,
  [12625] = 12624,
  [12626] = 12624,
  [12627] = 12627,
  [12628] = 5242,
  [12629] = 9034,
  [12630] = 9099,
  [12631] = 9174,
  [12632] = 12624,
  [12633] = 3205,
  [12634] = 5521,
  [12635] = 8136,
  [12636] = 12624,
  [12637] = 3206,
  [12638] = 3207,
  [12639] = 3208,
  [12640] = 12076,
  [12641] = 12641,
  [12642] = 12624,
  [12643] = 9248,
  [12644] = 9144,
  [12645] = 8159,
  [12646] = 12624,
  [12647] = 9059,
  [12648] = 11984,
  [12649] = 12649,
  [12650] = 12650,
  [12651] = 9175,
  [12652] = 8225,
  [12653] = 5452,
  [12654] = 12654,
  [12655] = 8210,
  [12656] = 12624,
  [12657] = 12657,
  [12658] = 9171,
  [12659] = 8239,
  [12660] = 12059,
  [12661] = 12624,
  [12662] = 12058,
  [12663] = 8180,
  [12664] = 12664,
  [12665] = 9108,
  [12666] = 9038,
  [12667] = 12624,
  [12668] = 8133,
  [12669] = 8239,
  [12670] = 8133,
  [12671] = 12671,
  [12672] = 8239,
  [12673] = 8164,
  [12674] = 8239,
  [12675] = 8133,
  [12676] = 12624,
  [12677] = 12624,
  [12678] = 12678,
  [12679] = 8195,
  [12680] = 9315,
  [12681] = 12624,
  [12682] = 8239,
  [12683] = 12624,
  [12684] = 9114,
  [12685] = 8155,
  [12686] = 9057,
  [12687] = 9082,
  [12688] = 8124,
  [12689] = 12689,
  [12690] = 12690,
  [12691] = 9242,
  [12692] = 12692,
  [12693] = 12624,
  [12694] = 8106,
  [12695] = 9125,
  [12696] = 12696,
  [12697] = 9297,
  [12698] = 12624,
  [12699] = 12624,
  [12700] = 8239,
  [12701] = 12624,
  [12702] = 9047,
  [12703] = 8195,
  [12704] = 12624,
  [12705] = 12705,
  [12706] = 12624,
  [12707] = 9049,
  [12708] = 12708,
  [12709] = 12624,
  [12710] = 9899,
  [12711] = 12624,
  [12712] = 8239,
  [12713] = 12624,
  [12714] = 9050,
  [12715] = 12084,
  [12716] = 12060,
  [12717] = 9217,
  [12718] = 12689,
  [12719] = 12624,
  [12720] = 12624,
  [12721] = 12624,
  [12722] = 12624,
  [12723] = 12028,
  [12724] = 8112,
  [12725] = 9060,
  [12726] = 8159,
  [12727] = 9068,
  [12728] = 8159,
  [12729] = 12058,
  [12730] = 9045,
  [12731] = 12059,
  [12732] = 12010,
  [12733] = 12733,
  [12734] = 12734,
  [12735] = 12689,
  [12736] = 8225,
  [12737] = 12737,
  [12738] = 8210,
  [12739] = 8180,
  [12740] = 8129,
  [12741] = 8947,
  [12742] = 8164,
  [12743] = 12624,
  [12744] = 11976,
  [12745] = 11913,
  [12746] = 8155,
  [12747] = 12624,
  [12748] = 12624,
  [12749] = 12749,
  [12750] = 12072,
  [12751] = 8239,
  [12752] = 12077,
  [12753] = 12690,
  [12754] = 8225,
  [12755] = 12030,
  [12756] = 12073,
  [12757] = 8239,
  [12758] = 12624,
  [12759] = 11939,
  [12760] = 8210,
  [12761] = 12761,
  [12762] = 8948,
  [12763] = 12763,
  [12764] = 8180,
  [12765] = 8946,
  [12766] = 12624,
  [12767] = 12074,
  [12768] = 8164,
  [12769] = 12624,
  [12770] = 12624,
  [12771] = 8136,
  [12772] = 12624,
  [12773] = 11939,
  [12774] = 8124,
  [12775] = 12775,
  [12776] = 9100,
  [12777] = 12010,
  [12778] = 11913,
  [12779] = 8133,
  [12780] = 12780,
  [12781] = 12624,
  [12782] = 8106,
  [12783] = 12071,
  [12784] = 8129,
  [12785] = 12010,
  [12786] = 8159,
  [12787] = 8225,
  [12788] = 12689,
  [12789] = 12775,
  [12790] = 8136,
  [12791] = 8155,
  [12792] = 8239,
  [12793] = 12624,
  [12794] = 12624,
  [12795] = 8124,
  [12796] = 8210,
  [12797] = 8180,
  [12798] = 12058,
  [12799] = 8164,
  [12800] = 8106,
  [12801] = 12624,
  [12802] = 12059,
  [12803] = 8112,
  [12804] = 12624,
  [12805] = 8129,
  [12806] = 8136,
  [12807] = 8155,
  [12808] = 11939,
  [12809] = 12624,
  [12810] = 11913,
  [12811] = 12811,
  [12812] = 8124,
  [12813] = 8195,
  [12814] = 12624,
  [12815] = 12815,
  [12816] = 8112,
  [12817] = 8106,
  [12818] = 8195,
  [12819] = 11918,
  [12820] = 12624,
  [12821] = 8112,
  [12822] = 12051,
  [12823] = 8129,
  [12824] = 12624,
  [12825] = 12825,
  [12826] = 3116,
  [12827] = 12827,
  [12828] = 10288,
  [12829] = 8570,
  [12830] = 12830,
  [12831] = 12827,
  [12832] = 12832,
  [12833] = 12825,
  [12834] = 12832,
  [12835] = 12827,
  [12836] = 12836,
  [12837] = 12837,
  [12838] = 12832,
  [12839] = 8970,
  [12840] = 12840,
  [12841] = 12825,
  [12842] = 12827,
  [12843] = 12832,
  [12844] = 12825,
  [12845] = 12845,
  [12846] = 8720,
  [12847] = 8713,
  [12848] = 3205,
  [12849] = 12849,
  [12850] = 9099,
  [12851] = 12851,
  [12852] = 12852,
  [12853] = 9174,
  [12854] = 9034,
  [12855] = 9248,
  [12856] = 9144,
  [12857] = 9059,
  [12858] = 9108,
  [12859] = 9038,
  [12860] = 9315,
  [12861] = 9057,
  [12862] = 9082,
  [12863] = 12863,
  [12864] = 12864,
  [12865] = 9242,
  [12866] = 8948,
  [12867] = 9047,
  [12868] = 12131,
  [12869] = 12869,
  [12870] = 5521,
  [12871] = 9049,
  [12872] = 8933,
  [12873] = 12849,
  [12874] = 5452,
  [12875] = 3206,
  [12876] = 9171,
  [12877] = 12877,
  [12878] = 3207,
  [12879] = 12133,
  [12880] = 3208,
  [12881] = 8919,
  [12882] = 12882,
  [12883] = 5325,
  [12884] = 12884,
  [12885] = 12849,
  [12886] = 12849,
  [12887] = 9100,
  [12888] = 9175,
  [12889] = 9050,
  [12890] = 12849,
  [12891] = 9125,
  [12892] = 5452,
  [12893] = 12864,
  [12894] = 12864,
  [12895] = 9217,
  [12896] = 11958,
  [12897] = 12864,
  [12898] = 8946,
  [12899] = 12899,
  [12900] = 9060,
  [12901] = 12901,
  [12902] = 9068,
  [12903] = 8647,
  [12904] = 9045,
  [12905] = 9297,
  [12906] = 8103,
  [12907] = 12907,
  [12908] = 12899,
  [12909] = 12909,
  [12910] = 12899,
  [12911] = 12899,
  [12912] = 3208,
  [12913] = 3207,
  [12914] = 3206,
  [12915] = 8893,
  [12916] = 12849,
  [12917] = 3205,
  [12918] = 8947,
  [12919] = 12837,
  [12920] = 5356,
  [12921] = 9349,
  [12922] = 5521,
  [12923] = 12923,
  [12924] = 9114,
  [12925] = 12925,
  [12926] = 12926,
  [12927] = 12927,
  [12928] = 7508,
  [12929] = 7593,
  [12930] = 12925,
  [12931] = 4772,
  [12932] = 12932,
  [12933] = 3128,
  [12934] = 12934,
  [12935] = 7510,
  [12936] = 12932,
  [12937] = 12937,
  [12938] = 12938,
  [12939] = 12939,
  [12940] = 12932,
  [12941] = 12925,
  [12942] = 12925,
  [12943] = 12943,
  [12944] = 9899,
  [12945] = 12932,
  [12946] = 12925,
  [12947] = 7511,
  [12948] = 12932,
  [12949] = 12949,
  [12950] = 12950,
  [12951] = 12932,
  [12952] = 12925,
  [12953] = 12953,
  [12954] = 4709,
  [12955] = 12937,
  [12956] = 8194,
  [12957] = 12932,
  [12958] = 12958,
  [12959] = 12932,
  [12960] = 7559,
  [12961] = 12925,
  [12962] = 12932,
  [12963] = 12925,
  [12964] = 12925,
  [12965] = 12932,
  [12966] = 12932,
  [12967] = 12967,
  [12968] = 9362,
  [12969] = 5440,
  [12970] = 12970,
  [12971] = 12925,
  [12972] = 12932,
  [12973] = 12925,
  [12974] = 12925,
  [12975] = 12925,
  [12976] = 12925,
  [12977] = 5434,
  [12978] = 12978,
  [12979] = 7536,
  [12980] = 12932,
  [12981] = 12981,
  [12982] = 12925,
  [12983] = 5457,
  [12984] = 12984,
  [12985] = 12985,
  [12986] = 12925,
  [12987] = 12932,
  [12988] = 12988,
  [12989] = 12989,
  [12990] = 12925,
  [12991] = 12991,
  [12992] = 12932,
  [12993] = 12993,
  [12994] = 12932,
  [12995] = 12925,
  [12996] = 12932,
  [12997] = 12997,
  [12998] = 12998,
  [12999] = 12999,
  [13000] = 13000,
  [13001] = 13001,
  [13002] = 13002,
  [13003] = 13003,
  [13004] = 13004,
  [13005] = 13005,
  [13006] = 13006,
  [13007] = 12925,
  [13008] = 13008,
  [13009] = 13009,
  [13010] = 13010,
  [13011] = 13011,
  [13012] = 13012,
  [13013] = 12932,
  [13014] = 13014,
  [13015] = 13015,
  [13016] = 7530,
  [13017] = 13017,
  [13018] = 12932,
  [13019] = 13019,
  [13020] = 7479,
  [13021] = 13021,
  [13022] = 13022,
  [13023] = 13023,
  [13024] = 13024,
  [13025] = 13025,
  [13026] = 13026,
  [13027] = 13027,
  [13028] = 7477,
  [13029] = 13029,
  [13030] = 13030,
  [13031] = 12932,
  [13032] = 12925,
  [13033] = 13033,
  [13034] = 12932,
  [13035] = 12932,
  [13036] = 13036,
  [13037] = 12937,
  [13038] = 13038,
  [13039] = 4727,
  [13040] = 12932,
  [13041] = 12925,
  [13042] = 12932,
  [13043] = 8970,
  [13044] = 13044,
  [13045] = 13045,
  [13046] = 13046,
  [13047] = 13047,
  [13048] = 5484,
  [13049] = 12932,
  [13050] = 13050,
  [13051] = 12932,
  [13052] = 7509,
  [13053] = 13022,
  [13054] = 13054,
  [13055] = 8092,
  [13056] = 13056,
  [13057] = 13008,
  [13058] = 12925,
  [13059] = 12932,
  [13060] = 13060,
  [13061] = 13061,
  [13062] = 13062,
  [13063] = 12925,
  [13064] = 13064,
  [13065] = 12925,
  [13066] = 7507,
  [13067] = 12925,
  [13068] = 12932,
  [13069] = 12925,
  [13070] = 13070,
  [13071] = 13071,
  [13072] = 13072,
  [13073] = 13073,
  [13074] = 8190,
  [13075] = 12925,
  [13076] = 12937,
  [13077] = 7531,
  [13078] = 13078,
  [13079] = 7506,
  [13080] = 7513,
  [13081] = 12932,
  [13082] = 13082,
  [13083] = 7514,
  [13084] = 13084,
  [13085] = 12932,
  [13086] = 7515,
  [13087] = 13087,
  [13088] = 12925,
  [13089] = 13089,
  [13090] = 12932,
  [13091] = 12932,
  [13092] = 13092,
  [13093] = 13008,
  [13094] = 12925,
  [13095] = 12925,
  [13096] = 5476,
  [13097] = 12932,
  [13098] = 12925,
  [13099] = 12932,
  [13100] = 13100,
  [13101] = 13101,
  [13102] = 13102,
  [13103] = 12925,
  [13104] = 12932,
  [13105] = 13105,
  [13106] = 12925,
  [13107] = 13008,
  [13108] = 5496,
  [13109] = 12932,
  [13110] = 13110,
  [13111] = 13111,
  [13112] = 7554,
  [13113] = 13113,
  [13114] = 12932,
  [13115] = 12932,
  [13116] = 12932,
  [13117] = 12932,
  [13118] = 12925,
  [13119] = 12925,
  [13120] = 12925,
  [13121] = 12925,
  [13122] = 12925,
  [13123] = 12925,
  [13124] = 13124,
  [13125] = 13125,
  [13126] = 7474,
  [13127] = 12932,
  [13128] = 12925,
  [13129] = 12925,
  [13130] = 12925,
  [13131] = 9355,
  [13132] = 12932,
  [13133] = 13133,
  [13134] = 12932,
  [13135] = 13135,
  [13136] = 7473,
  [13137] = 12925,
  [13138] = 8632,
  [13139] = 8653,
  [13140] = 8633,
  [13141] = 4709,
  [13142] = 9174,
  [13143] = 13143,
  [13144] = 11958,
  [13145] = 12830,
  [13146] = 10288,
  [13147] = 13147,
  [13148] = 13148,
  [13149] = 13149,
  [13150] = 13150,
  [13151] = 4772,
  [13152] = 13152,
  [13153] = 13153,
  [13154] = 13154,
  [13155] = 9899,
  [13156] = 9114,
  [13157] = 9125,
  [13158] = 4727,
  [13159] = 9100,
  [13160] = 9099,
  [13161] = 12131,
  [13162] = 9034,
  [13163] = 9248,
  [13164] = 9144,
  [13165] = 12133,
  [13166] = 4903,
  [13167] = 9059,
  [13168] = 9175,
  [13169] = 9171,
  [13170] = 9108,
  [13171] = 9038,
  [13172] = 9315,
  [13173] = 9057,
  [13174] = 9082,
  [13175] = 9242,
  [13176] = 9047,
  [13177] = 9049,
  [13178] = 13178,
  [13179] = 9050,
  [13180] = 9217,
  [13181] = 9060,
  [13182] = 9068,
  [13183] = 8647,
  [13184] = 9045,
  [13185] = 5521,
  [13186] = 9297,
  [13187] = 5452,
  [13188] = 3208,
  [13189] = 13189,
  [13190] = 3207,
  [13191] = 3206,
  [13192] = 3205,
  [13193] = 13193,
  [13194] = 9140,
  [13195] = 13195,
  [13196] = 8899,
  [13197] = 8887,
  [13198] = 10016,
  [13199] = 13199,
  [13200] = 9073,
  [13201] = 9137,
  [13202] = 10043,
  [13203] = 3205,
  [13204] = 3206,
  [13205] = 13195,
  [13206] = 3207,
  [13207] = 3208,
  [13208] = 13195,
  [13209] = 10288,
  [13210] = 8922,
  [13211] = 8908,
  [13212] = 13195,
  [13213] = 8886,
  [13214] = 9998,
  [13215] = 8926,
  [13216] = 13199,
  [13217] = 13217,
  [13218] = 13218,
  [13219] = 5315,
  [13220] = 9255,
  [13221] = 3122,
  [13222] = 9894,
  [13223] = 8915,
  [13224] = 9899,
  [13225] = 13225,
  [13226] = 8880,
  [13227] = 9948,
  [13228] = 4903,
  [13229] = 13199,
  [13230] = 13230,
  [13231] = 8925,
  [13232] = 13199,
  [13233] = 8918,
  [13234] = 9052,
  [13235] = 9054,
  [13236] = 8287,
  [13237] = 3132,
  [13238] = 8909,
  [13239] = 8904,
  [13240] = 10174,
  [13241] = 13241,
  [13242] = 13242,
  [13243] = 13241,
  [13244] = 9004,
  [13245] = 13242,
  [13246] = 13242,
  [13247] = 13241,
  [13248] = 13248,
  [13249] = 13249,
  [13250] = 13250,
  [13251] = 13241,
  [13252] = 5541,
  [13253] = 13241,
  [13254] = 13241,
  [13255] = 13242,
  [13256] = 13241,
  [13257] = 13242,
  [13258] = 3133,
  [13259] = 13242,
  [13260] = 5559,
  [13261] = 13261,
  [13262] = 9420,
  [13263] = 5517,
  [13264] = 13241,
  [13265] = 5527,
  [13266] = 13241,
  [13267] = 13250,
  [13268] = 13268,
  [13269] = 13241,
  [13270] = 13241,
  [13271] = 13250,
  [13272] = 13250,
  [13273] = 13241,
  [13274] = 13241,
  [13275] = 13242,
  [13276] = 13242,
  [13277] = 13242,
  [13278] = 13241,
  [13279] = 5518,
  [13280] = 13242,
  [13281] = 13242,
  [13282] = 5467,
  [13283] = 13250,
  [13284] = 13242,
  [13285] = 13241,
  [13286] = 5477,
  [13287] = 13248,
  [13288] = 13242,
  [13289] = 13242,
  [13290] = 13248,
  [13291] = 13242,
  [13292] = 13241,
  [13293] = 5424,
  [13294] = 5450,
  [13295] = 13241,
  [13296] = 13241,
  [13297] = 5486,
  [13298] = 13250,
  [13299] = 8647,
  [13300] = 13241,
  [13301] = 13249,
  [13302] = 5455,
  [13303] = 13261,
  [13304] = 13241,
  [13305] = 13242,
  [13306] = 10219,
  [13307] = 13250,
  [13308] = 5485,
  [13309] = 8969,
  [13310] = 5428,
  [13311] = 8984,
  [13312] = 5448,
  [13313] = 13242,
  [13314] = 5453,
  [13315] = 5456,
  [13316] = 5464,
  [13317] = 13241,
  [13318] = 13241,
  [13319] = 13241,
  [13320] = 13241,
  [13321] = 13242,
  [13322] = 13241,
  [13323] = 13241,
  [13324] = 13241,
  [13325] = 10172,
  [13326] = 13241,
  [13327] = 9011,
  [13328] = 13241,
  [13329] = 9272,
  [13330] = 5459,
  [13331] = 13242,
  [13332] = 5458,
  [13333] = 9349,
  [13334] = 13241,
  [13335] = 13248,
  [13336] = 13241,
  [13337] = 13241,
  [13338] = 13248,
  [13339] = 3124,
  [13340] = 13241,
  [13341] = 13241,
  [13342] = 13242,
  [13343] = 13241,
  [13344] = 13242,
  [13345] = 13250,
  [13346] = 13242,
  [13347] = 13242,
  [13348] = 13242,
  [13349] = 5430,
  [13350] = 13241,
  [13351] = 8948,
  [13352] = 13241,
  [13353] = 13242,
  [13354] = 5474,
  [13355] = 5483,
  [13356] = 13250,
  [13357] = 5475,
  [13358] = 5515,
  [13359] = 13242,
  [13360] = 13242,
  [13361] = 5514,
  [13362] = 13241,
  [13363] = 8287,
  [13364] = 13242,
  [13365] = 13241,
  [13366] = 13241,
  [13367] = 13248,
  [13368] = 10288,
  [13369] = 13241,
  [13370] = 13261,
  [13371] = 13241,
  [13372] = 13261,
  [13373] = 13241,
  [13374] = 13242,
  [13375] = 13242,
  [13376] = 13241,
  [13377] = 13250,
  [13378] = 13241,
  [13379] = 13261,
  [13380] = 13380,
  [13381] = 13242,
  [13382] = 13242,
  [13383] = 13249,
  [13384] = 13242,
  [13385] = 13241,
  [13386] = 13242,
  [13387] = 13241,
  [13388] = 13241,
  [13389] = 13241,
  [13390] = 13241,
  [13391] = 13249,
  [13392] = 13241,
  [13393] = 13241,
  [13394] = 13248,
  [13395] = 13242,
  [13396] = 13241,
  [13397] = 13242,
  [13398] = 8647,
  [13399] = 9007,
  [13400] = 13241,
  [13401] = 13261,
  [13402] = 8972,
  [13403] = 13403,
  [13404] = 13242,
  [13405] = 13405,
  [13406] = 13242,
  [13407] = 13380,
  [13408] = 13380,
  [13409] = 5509,
  [13410] = 13250,
  [13411] = 13380,
  [13412] = 13241,
  [13413] = 13241,
  [13414] = 13242,
  [13415] = 13242,
  [13416] = 13242,
  [13417] = 13242,
  [13418] = 5542,
  [13419] = 13241,
  [13420] = 13242,
  [13421] = 13242,
  [13422] = 13422,
  [13423] = 13423,
  [13424] = 13423,
  [13425] = 13425,
  [13426] = 9894,
  [13427] = 13422,
  [13428] = 13423,
  [13429] = 10362,
  [13430] = 13423,
  [13431] = 13425,
  [13432] = 13422,
  [13433] = 13422,
  [13434] = 9998,
  [13435] = 13425,
  [13436] = 13425,
  [13437] = 13437,
  [13438] = 13422,
  [13439] = 10394,
  [13440] = 13425,
  [13441] = 13441,
  [13442] = 13422,
  [13443] = 13425,
  [13444] = 13422,
  [13445] = 13425,
  [13446] = 10016,
  [13447] = 13423,
  [13448] = 13422,
  [13449] = 13449,
  [13450] = 13423,
  [13451] = 13451,
  [13452] = 13422,
  [13453] = 13425,
  [13454] = 13425,
  [13455] = 13449,
  [13456] = 13422,
  [13457] = 10043,
  [13458] = 13458,
  [13459] = 13449,
  [13460] = 13422,
  [13461] = 13422,
  [13462] = 13422,
  [13463] = 13425,
  [13464] = 9899,
  [13465] = 13422,
  [13466] = 13449,
  [13467] = 13425,
  [13468] = 13422,
  [13469] = 13425,
  [13470] = 13425,
  [13471] = 13471,
  [13472] = 13425,
  [13473] = 13425,
  [13474] = 13449,
  [13475] = 13422,
  [13476] = 13425,
  [13477] = 13477,
  [13478] = 13425,
  [13479] = 13422,
  [13480] = 13422,
  [13481] = 2927,
  [13482] = 2925,
  [13483] = 13422,
  [13484] = 9948,
  [13485] = 13422,
  [13486] = 13422,
  [13487] = 10453,
  [13488] = 13425,
  [13489] = 9155,
  [13490] = 13425,
  [13491] = 9610,
  [13492] = 13422,
  [13493] = 13425,
  [13494] = 13425,
  [13495] = 13425,
  [13496] = 13496,
  [13497] = 10219,
  [13498] = 13498,
  [13499] = 13499,
  [13500] = 9513,
  [13501] = 10741,
  [13502] = 13502,
  [13503] = 13498,
  [13504] = 13504,
  [13505] = 13505,
  [13506] = 9217,
  [13507] = 13504,
  [13508] = 3122,
  [13509] = 9624,
  [13510] = 13502,
  [13511] = 13511,
  [13512] = 13512,
  [13513] = 13513,
  [13514] = 13514,
  [13515] = 13504,
  [13516] = 10040,
  [13517] = 3132,
  [13518] = 13511,
  [13519] = 13519,
  [13520] = 13498,
  [13521] = 13498,
  [13522] = 9485,
  [13523] = 10288,
  [13524] = 13524,
  [13525] = 13525,
  [13526] = 13514,
  [13527] = 13505,
  [13528] = 13528,
  [13529] = 13496,
  [13530] = 13514,
  [13531] = 13513,
  [13532] = 13514,
  [13533] = 13525,
  [13534] = 13528,
  [13535] = 13535,
  [13536] = 13536,
  [13537] = 13537,
  [13538] = 13504,
  [13539] = 13502,
  [13540] = 9392,
  [13541] = 13536,
  [13542] = 13542,
  [13543] = 13524,
  [13544] = 13498,
  [13545] = 13514,
  [13546] = 13514,
  [13547] = 13504,
  [13548] = 13498,
  [13549] = 9766,
  [13550] = 13504,
  [13551] = 13551,
  [13552] = 13498,
  [13553] = 13553,
  [13554] = 13524,
  [13555] = 13504,
  [13556] = 13504,
  [13557] = 13502,
  [13558] = 13551,
  [13559] = 13498,
  [13560] = 13498,
  [13561] = 13514,
  [13562] = 9787,
  [13563] = 13514,
  [13564] = 9114,
  [13565] = 13553,
  [13566] = 13566,
  [13567] = 13514,
  [13568] = 13499,
  [13569] = 13504,
  [13570] = 13514,
  [13571] = 5535,
  [13572] = 10080,
  [13573] = 13498,
  [13574] = 5468,
  [13575] = 10068,
  [13576] = 13498,
  [13577] = 9125,
  [13578] = 10172,
  [13579] = 13512,
  [13580] = 9100,
  [13581] = 13581,
  [13582] = 10174,
  [13583] = 9610,
  [13584] = 13512,
  [13585] = 5561,
  [13586] = 13513,
  [13587] = 13498,
  [13588] = 13498,
  [13589] = 13504,
  [13590] = 9879,
  [13591] = 13498,
  [13592] = 13504,
  [13593] = 13551,
  [13594] = 9477,
  [13595] = 13514,
  [13596] = 13596,
  [13597] = 13514,
  [13598] = 9496,
  [13599] = 13566,
  [13600] = 13514,
  [13601] = 10002,
  [13602] = 9947,
  [13603] = 13498,
  [13604] = 5356,
  [13605] = 9099,
  [13606] = 13514,
  [13607] = 12882,
  [13608] = 13504,
  [13609] = 9971,
  [13610] = 9898,
  [13611] = 13513,
  [13612] = 13513,
  [13613] = 13511,
  [13614] = 13499,
  [13615] = 13504,
  [13616] = 13502,
  [13617] = 13596,
  [13618] = 13504,
  [13619] = 13581,
  [13620] = 9174,
  [13621] = 13528,
  [13622] = 13504,
  [13623] = 13566,
  [13624] = 13535,
  [13625] = 13536,
  [13626] = 13511,
  [13627] = 13524,
  [13628] = 13498,
  [13629] = 13524,
  [13630] = 13499,
  [13631] = 13504,
  [13632] = 13504,
  [13633] = 13633,
  [13634] = 13514,
  [13635] = 13504,
  [13636] = 13504,
  [13637] = 13230,
  [13638] = 13225,
  [13639] = 13218,
  [13640] = 13498,
  [13641] = 13514,
  [13642] = 13504,
  [13643] = 13498,
  [13644] = 13535,
  [13645] = 13551,
  [13646] = 13524,
  [13647] = 13498,
  [13648] = 13498,
  [13649] = 13498,
  [13650] = 13514,
  [13651] = 13504,
  [13652] = 13504,
  [13653] = 13504,
  [13654] = 13553,
  [13655] = 13498,
  [13656] = 13514,
  [13657] = 9899,
  [13658] = 13504,
  [13659] = 13502,
  [13660] = 13498,
  [13661] = 10866,
  [13662] = 13596,
  [13663] = 13504,
  [13664] = 13581,
  [13665] = 13514,
  [13666] = 13504,
  [13667] = 13504,
  [13668] = 13566,
  [13669] = 13498,
  [13670] = 9442,
  [13671] = 13504,
  [13672] = 13581,
  [13673] = 13498,
  [13674] = 9034,
  [13675] = 13502,
  [13676] = 9248,
  [13677] = 13217,
  [13678] = 13536,
  [13679] = 9144,
  [13680] = 13553,
  [13681] = 13535,
  [13682] = 13514,
  [13683] = 13528,
  [13684] = 13684,
  [13685] = 13498,
  [13686] = 13498,
  [13687] = 13525,
  [13688] = 13498,
  [13689] = 13498,
  [13690] = 13551,
  [13691] = 13496,
  [13692] = 10949,
  [13693] = 13496,
  [13694] = 9059,
  [13695] = 13551,
  [13696] = 13505,
  [13697] = 13498,
  [13698] = 13514,
  [13699] = 13498,
  [13700] = 9175,
  [13701] = 9171,
  [13702] = 13504,
  [13703] = 9108,
  [13704] = 13504,
  [13705] = 13566,
  [13706] = 13504,
  [13707] = 13596,
  [13708] = 13498,
  [13709] = 13709,
  [13710] = 13193,
  [13711] = 9038,
  [13712] = 13504,
  [13713] = 13498,
  [13714] = 13714,
  [13715] = 13553,
  [13716] = 13514,
  [13717] = 9315,
  [13718] = 9057,
  [13719] = 13498,
  [13720] = 13720,
  [13721] = 13505,
  [13722] = 13504,
  [13723] = 13504,
  [13724] = 3154,
  [13725] = 9082,
  [13726] = 9047,
  [13727] = 3131,
  [13728] = 13496,
  [13729] = 9049,
  [13730] = 3148,
  [13731] = 13525,
  [13732] = 13596,
  [13733] = 13581,
  [13734] = 9413,
  [13735] = 3125,
  [13736] = 13528,
  [13737] = 3123,
  [13738] = 13512,
  [13739] = 13502,
  [13740] = 9050,
  [13741] = 13504,
  [13742] = 13742,
  [13743] = 13514,
  [13744] = 13536,
  [13745] = 13524,
  [13746] = 13535,
  [13747] = 13514,
  [13748] = 13535,
  [13749] = 3121,
  [13750] = 13504,
  [13751] = 13536,
  [13752] = 9060,
  [13753] = 13504,
  [13754] = 3120,
  [13755] = 9068,
  [13756] = 13498,
  [13757] = 13566,
  [13758] = 13498,
  [13759] = 13505,
  [13760] = 13504,
  [13761] = 13761,
  [13762] = 13762,
  [13763] = 13519,
  [13764] = 3129,
  [13765] = 13496,
  [13766] = 13498,
  [13767] = 13498,
  [13768] = 13498,
  [13769] = 13504,
  [13770] = 13504,
  [13771] = 13519,
  [13772] = 13511,
  [13773] = 13504,
  [13774] = 13512,
  [13775] = 13498,
  [13776] = 13525,
  [13777] = 13513,
  [13778] = 13528,
  [13779] = 13514,
  [13780] = 5315,
  [13781] = 13596,
  [13782] = 13498,
  [13783] = 13519,
  [13784] = 13535,
  [13785] = 13528,
  [13786] = 13566,
  [13787] = 13514,
  [13788] = 13514,
  [13789] = 13504,
  [13790] = 13498,
  [13791] = 13514,
  [13792] = 13581,
  [13793] = 13536,
  [13794] = 13519,
  [13795] = 9297,
  [13796] = 9045,
  [13797] = 5325,
  [13798] = 9955,
  [13799] = 2982,
  [13800] = 13505,
  [13801] = 13514,
  [13802] = 13514,
  [13803] = 13514,
  [13804] = 13504,
  [13805] = 13511,
  [13806] = 13536,
  [13807] = 13505,
  [13808] = 13581,
  [13809] = 2983,
  [13810] = 13498,
  [13811] = 13596,
  [13812] = 13513,
  [13813] = 10745,
  [13814] = 13514,
  [13815] = 13513,
  [13816] = 13525,
  [13817] = 13498,
  [13818] = 13525,
  [13819] = 13504,
  [13820] = 13511,
  [13821] = 13596,
  [13822] = 13528,
  [13823] = 13504,
  [13824] = 13535,
  [13825] = 9464,
  [13826] = 13826,
  [13827] = 13498,
  [13828] = 13496,
  [13829] = 13566,
  [13830] = 9242,
  [13831] = 13831,
  [13832] = 7531,
  [13833] = 13833,
  [13834] = 13834,
  [13835] = 13835,
  [13836] = 5428,
  [13837] = 10128,
  [13838] = 13838,
  [13839] = 13838,
  [13840] = 10365,
  [13841] = 10399,
  [13842] = 13835,
  [13843] = 5527,
  [13844] = 13835,
  [13845] = 13834,
  [13846] = 3116,
  [13847] = 3124,
  [13848] = 13838,
  [13849] = 13831,
  [13850] = 13834,
  [13851] = 2983,
  [13852] = 13834,
  [13853] = 2982,
  [13854] = 5455,
  [13855] = 13834,
  [13856] = 13856,
  [13857] = 5486,
  [13858] = 10425,
  [13859] = 13856,
  [13860] = 13838,
  [13861] = 10426,
  [13862] = 13831,
  [13863] = 13863,
  [13864] = 13834,
  [13865] = 13838,
  [13866] = 13834,
  [13867] = 13838,
  [13868] = 9479,
  [13869] = 13838,
  [13870] = 13125,
  [13871] = 13871,
  [13872] = 13835,
  [13873] = 7530,
  [13874] = 13838,
  [13875] = 13856,
  [13876] = 13834,
  [13877] = 13838,
  [13878] = 13834,
  [13879] = 5430,
  [13880] = 13856,
  [13881] = 13856,
  [13882] = 13856,
  [13883] = 3133,
  [13884] = 13831,
  [13885] = 13856,
  [13886] = 13856,
  [13887] = 7514,
  [13888] = 13831,
  [13889] = 13835,
  [13890] = 13835,
  [13891] = 5450,
  [13892] = 13892,
  [13893] = 13831,
  [13894] = 10394,
  [13895] = 13895,
  [13896] = 13838,
  [13897] = 13838,
  [13898] = 13856,
  [13899] = 13834,
  [13900] = 5476,
  [13901] = 5448,
  [13902] = 13831,
  [13903] = 13835,
  [13904] = 5509,
  [13905] = 13831,
  [13906] = 13831,
  [13907] = 7515,
  [13908] = 5514,
  [13909] = 5515,
  [13910] = 13856,
  [13911] = 5475,
  [13912] = 10288,
  [13913] = 13834,
  [13914] = 13856,
  [13915] = 13835,
  [13916] = 13856,
  [13917] = 13831,
  [13918] = 13918,
  [13919] = 7511,
  [13920] = 5483,
  [13921] = 13838,
  [13922] = 13922,
  [13923] = 13835,
  [13924] = 13838,
  [13925] = 5477,
  [13926] = 7593,
  [13927] = 7510,
  [13928] = 13856,
  [13929] = 7508,
  [13930] = 7507,
  [13931] = 13831,
  [13932] = 13835,
  [13933] = 13835,
  [13934] = 13892,
  [13935] = 13834,
  [13936] = 13856,
  [13937] = 13838,
  [13938] = 13831,
  [13939] = 13834,
  [13940] = 7608,
  [13941] = 13941,
  [13942] = 7506,
  [13943] = 5541,
  [13944] = 13831,
  [13945] = 13834,
  [13946] = 13835,
  [13947] = 13834,
  [13948] = 13834,
  [13949] = 13835,
  [13950] = 13835,
  [13951] = 13838,
  [13952] = 13835,
  [13953] = 13856,
  [13954] = 5542,
  [13955] = 13218,
  [13956] = 13856,
  [13957] = 5559,
  [13958] = 13835,
  [13959] = 13831,
  [13960] = 13834,
  [13961] = 13838,
  [13962] = 13838,
  [13963] = 13838,
  [13964] = 13838,
  [13965] = 13831,
  [13966] = 13834,
  [13967] = 13834,
  [13968] = 13834,
  [13969] = 5517,
  [13970] = 13831,
  [13971] = 13834,
  [13972] = 13838,
  [13973] = 10451,
  [13974] = 7559,
  [13975] = 7479,
  [13976] = 13834,
  [13977] = 13834,
  [13978] = 13834,
  [13979] = 13835,
  [13980] = 13856,
  [13981] = 13831,
  [13982] = 13124,
  [13983] = 5496,
  [13984] = 13895,
  [13985] = 13831,
  [13986] = 13986,
  [13987] = 5453,
  [13988] = 13835,
  [13989] = 13834,
  [13990] = 13838,
  [13991] = 13856,
  [13992] = 13835,
  [13993] = 7477,
  [13994] = 10500,
  [13995] = 13230,
  [13996] = 13856,
  [13997] = 13997,
  [13998] = 13225,
  [13999] = 13835,
  [14000] = 13835,
  [14001] = 13105,
  [14002] = 13217,
  [14003] = 13834,
  [14004] = 13856,
  [14005] = 13834,
  [14006] = 13831,
  [14007] = 14007,
  [14008] = 13838,
  [14009] = 13838,
  [14010] = 5561,
  [14011] = 5456,
  [14012] = 3111,
  [14013] = 13856,
  [14014] = 13856,
  [14015] = 13838,
  [14016] = 13835,
  [14017] = 13856,
  [14018] = 13831,
  [14019] = 5464,
  [14020] = 5468,
  [14021] = 13835,
  [14022] = 13838,
  [14023] = 13838,
  [14024] = 5457,
  [14025] = 5440,
  [14026] = 3110,
  [14027] = 5518,
  [14028] = 13834,
  [14029] = 13856,
  [14030] = 5535,
  [14031] = 3109,
  [14032] = 3108,
  [14033] = 13835,
  [14034] = 7474,
  [14035] = 14035,
  [14036] = 13838,
  [14037] = 13835,
  [14038] = 13831,
  [14039] = 13835,
  [14040] = 7536,
  [14041] = 13856,
  [14042] = 13856,
  [14043] = 13831,
  [14044] = 13831,
  [14045] = 5484,
  [14046] = 7473,
  [14047] = 13892,
  [14048] = 13834,
  [14049] = 5424,
  [14050] = 13856,
  [14051] = 10551,
  [14052] = 13831,
  [14053] = 13838,
  [14054] = 13835,
  [14055] = 5474,
  [14056] = 13831,
  [14057] = 13856,
  [14058] = 13831,
  [14059] = 13856,
  [14060] = 13835,
  [14061] = 13835,
  [14062] = 13834,
  [14063] = 13856,
  [14064] = 5434,
  [14065] = 7509,
  [14066] = 13835,
  [14067] = 13835,
  [14068] = 13838,
  [14069] = 10380,
  [14070] = 13831,
  [14071] = 13835,
  [14072] = 13838,
  [14073] = 13835,
  [14074] = 13834,
  [14075] = 13856,
  [14076] = 3128,
  [14077] = 13831,
  [14078] = 10362,
  [14079] = 13835,
  [14080] = 13838,
  [14081] = 13831,
  [14082] = 13834,
  [14083] = 13834,
  [14084] = 13834,
  [14085] = 5561,
  [14086] = 13835,
  [14087] = 5485,
  [14088] = 13834,
  [14089] = 13835,
  [14090] = 13834,
  [14091] = 13838,
  [14092] = 5468,
  [14093] = 12978,
  [14094] = 7554,
  [14095] = 13835,
  [14096] = 5458,
  [14097] = 13834,
  [14098] = 13831,
  [14099] = 13838,
  [14100] = 13835,
  [14101] = 13856,
  [14102] = 5467,
  [14103] = 13110,
  [14104] = 5535,
  [14105] = 13856,
  [14106] = 13838,
  [14107] = 13831,
  [14108] = 13033,
  [14109] = 13838,
  [14110] = 13135,
  [14111] = 13892,
  [14112] = 13831,
  [14113] = 13834,
  [14114] = 13831,
  [14115] = 13834,
  [14116] = 13871,
  [14117] = 10149,
  [14118] = 13831,
  [14119] = 13835,
  [14120] = 13838,
  [14121] = 13856,
  [14122] = 13831,
  [14123] = 13831,
  [14124] = 14124,
  [14125] = 13831,
  [14126] = 13835,
  [14127] = 13835,
  [14128] = 13863,
  [14129] = 13834,
  [14130] = 13856,
  [14131] = 3107,
  [14132] = 13856,
  [14133] = 13834,
  [14134] = 13838,
  [14135] = 13856,
  [14136] = 13856,
  [14137] = 13113,
  [14138] = 13838,
  [14139] = 13834,
  [14140] = 13835,
  [14141] = 12993,
  [14142] = 10630,
  [14143] = 14143,
  [14144] = 13831,
  [14145] = 10632,
  [14146] = 13838,
  [14147] = 13193,
  [14148] = 13831,
  [14149] = 7513,
  [14150] = 13918,
  [14151] = 13838,
  [14152] = 14152,
  [14153] = 13834,
  [14154] = 13838,
  [14155] = 13838,
  [14156] = 13831,
  [14157] = 10453,
  [14158] = 13856,
  [14159] = 13856,
  [14160] = 13856,
  [14161] = 13856,
  [14162] = 10609,
  [14163] = 13831,
  [14164] = 13856,
  [14165] = 5459,
  [14166] = 13838,
  [14167] = 13831,
  [14168] = 13835,
  [14169] = 13831,
  [14170] = 10741,
  [14171] = 14171,
  [14172] = 14172,
  [14173] = 14173,
  [14174] = 14174,
  [14175] = 14174,
  [14176] = 14176,
  [14177] = 14172,
  [14178] = 14172,
  [14179] = 14179,
  [14180] = 14180,
  [14181] = 14181,
  [14182] = 14176,
  [14183] = 14171,
  [14184] = 14176,
  [14185] = 14185,
  [14186] = 14174,
  [14187] = 14187,
  [14188] = 14188,
  [14189] = 14189,
  [14190] = 14174,
  [14191] = 14191,
  [14192] = 14187,
  [14193] = 14176,
  [14194] = 14194,
  [14195] = 14191,
  [14196] = 14172,
  [14197] = 14172,
  [14198] = 14198,
  [14199] = 14174,
  [14200] = 14172,
  [14201] = 14189,
  [14202] = 14176,
  [14203] = 14203,
  [14204] = 14204,
  [14205] = 14198,
  [14206] = 14172,
  [14207] = 14207,
  [14208] = 14173,
  [14209] = 14174,
  [14210] = 14191,
  [14211] = 14176,
  [14212] = 14176,
  [14213] = 14180,
  [14214] = 14189,
  [14215] = 14215,
  [14216] = 14216,
  [14217] = 14176,
  [14218] = 14176,
  [14219] = 14173,
  [14220] = 14185,
  [14221] = 10684,
  [14222] = 14174,
  [14223] = 14176,
  [14224] = 14180,
  [14225] = 10557,
  [14226] = 14191,
  [14227] = 14176,
  [14228] = 14176,
  [14229] = 14229,
  [14230] = 14187,
  [14231] = 14191,
  [14232] = 14174,
  [14233] = 14198,
  [14234] = 14176,
  [14235] = 14174,
  [14236] = 14174,
  [14237] = 14174,
  [14238] = 14172,
  [14239] = 14174,
  [14240] = 14179,
  [14241] = 14174,
  [14242] = 14174,
  [14243] = 14191,
  [14244] = 14216,
  [14245] = 14191,
  [14246] = 14174,
  [14247] = 14185,
  [14248] = 14176,
  [14249] = 14215,
  [14250] = 14176,
  [14251] = 14176,
  [14252] = 14171,
  [14253] = 14176,
  [14254] = 14191,
  [14255] = 14216,
  [14256] = 14176,
  [14257] = 14257,
  [14258] = 14172,
  [14259] = 14172,
  [14260] = 14176,
  [14261] = 14180,
  [14262] = 9479,
  [14263] = 14263,
  [14264] = 14191,
  [14265] = 14265,
  [14266] = 14191,
  [14267] = 14176,
  [14268] = 14174,
  [14269] = 14172,
  [14270] = 14172,
  [14271] = 14176,
  [14272] = 14172,
  [14273] = 14185,
  [14274] = 14176,
  [14275] = 14191,
  [14276] = 9705,
  [14277] = 14174,
  [14278] = 14278,
  [14279] = 14189,
  [14280] = 14176,
  [14281] = 14281,
  [14282] = 14174,
  [14283] = 14174,
  [14284] = 14176,
  [14285] = 14189,
  [14286] = 10411,
  [14287] = 10472,
  [14288] = 14191,
  [14289] = 10478,
  [14290] = 14172,
  [14291] = 14185,
  [14292] = 12830,
  [14293] = 14172,
  [14294] = 14174,
  [14295] = 14295,
  [14296] = 14174,
  [14297] = 14297,
  [14298] = 14176,
  [14299] = 14172,
  [14300] = 14180,
  [14301] = 10949,
  [14302] = 14179,
  [14303] = 14174,
  [14304] = 14174,
  [14305] = 10408,
  [14306] = 14191,
  [14307] = 14173,
  [14308] = 14176,
  [14309] = 14173,
  [14310] = 14174,
  [14311] = 14174,
  [14312] = 14198,
  [14313] = 14174,
  [14314] = 12133,
  [14315] = 14176,
  [14316] = 14189,
  [14317] = 14317,
  [14318] = 14176,
  [14319] = 14191,
  [14320] = 14176,
  [14321] = 14189,
  [14322] = 14176,
  [14323] = 14173,
  [14324] = 14324,
  [14325] = 14325,
  [14326] = 14176,
  [14327] = 14191,
  [14328] = 14174,
  [14329] = 11958,
  [14330] = 14176,
  [14331] = 14174,
  [14332] = 14174,
  [14333] = 14174,
  [14334] = 12830,
  [14335] = 14335,
  [14336] = 14336,
  [14337] = 14180,
  [14338] = 14338,
  [14339] = 14339,
  [14340] = 14176,
  [14341] = 14198,
  [14342] = 14191,
  [14343] = 14343,
  [14344] = 14191,
  [14345] = 14198,
  [14346] = 14191,
  [14347] = 14185,
  [14348] = 14174,
  [14349] = 14349,
  [14350] = 14191,
  [14351] = 14173,
  [14352] = 14174,
  [14353] = 14176,
  [14354] = 14187,
  [14355] = 14187,
  [14356] = 14191,
  [14357] = 14215,
  [14358] = 14172,
  [14359] = 14359,
  [14360] = 10407,
  [14361] = 14172,
  [14362] = 14176,
  [14363] = 14191,
  [14364] = 14171,
  [14365] = 14176,
  [14366] = 14176,
  [14367] = 14176,
  [14368] = 14172,
  [14369] = 14172,
  [14370] = 14176,
  [14371] = 14174,
  [14372] = 10395,
  [14373] = 14191,
  [14374] = 10866,
  [14375] = 14176,
  [14376] = 14174,
  [14377] = 14174,
  [14378] = 10596,
  [14379] = 14176,
  [14380] = 14174,
  [14381] = 14171,
  [14382] = 14187,
  [14383] = 14172,
  [14384] = 14171,
  [14385] = 14173,
  [14386] = 14174,
  [14387] = 14387,
  [14388] = 14174,
  [14389] = 14187,
  [14390] = 14174,
  [14391] = 14391,
  [14392] = 14176,
  [14393] = 14171,
  [14394] = 14187,
  [14395] = 14172,
  [14396] = 14174,
  [14397] = 14174,
  [14398] = 14174,
  [14399] = 14339,
  [14400] = 14176,
  [14401] = 12131,
  [14402] = 14174,
  [14403] = 14403,
  [14404] = 14404,
  [14405] = 14405,
  [14406] = 14406,
  [14407] = 14407,
  [14408] = 14408,
  [14409] = 14409,
  [14410] = 14406,
  [14411] = 10733,
  [14412] = 14412,
  [14413] = 14413,
  [14414] = 14406,
  [14415] = 14415,
  [14416] = 14412,
  [14417] = 14417,
  [14418] = 14418,
  [14419] = 14413,
  [14420] = 14417,
  [14421] = 14421,
  [14422] = 14422,
  [14423] = 14423,
  [14424] = 14424,
  [14425] = 10822,
  [14426] = 14417,
  [14427] = 14427,
  [14428] = 14403,
  [14429] = 14429,
  [14430] = 14405,
  [14431] = 14407,
  [14432] = 14432,
  [14433] = 14408,
  [14434] = 14434,
  [14435] = 14435,
  [14436] = 14409,
  [14437] = 14437,
  [14438] = 4709,
  [14439] = 14439,
  [14440] = 14403,
  [14441] = 14441,
  [14442] = 14404,
  [14443] = 14407,
  [14444] = 14404,
  [14445] = 14417,
  [14446] = 14415,
  [14447] = 14415,
  [14448] = 14448,
  [14449] = 14449,
  [14450] = 14449,
  [14451] = 14449,
  [14452] = 14452,
  [14453] = 14449,
  [14454] = 14454,
  [14455] = 14409,
  [14456] = 14421,
  [14457] = 14403,
  [14458] = 14408,
  [14459] = 14454,
  [14460] = 14452,
  [14461] = 14461,
  [14462] = 14421,
  [14463] = 14463,
  [14464] = 14403,
  [14465] = 14465,
  [14466] = 14404,
  [14467] = 14467,
  [14468] = 14465,
  [14469] = 14421,
  [14470] = 10931,
  [14471] = 14471,
  [14472] = 14441,
  [14473] = 14415,
  [14474] = 14404,
  [14475] = 14422,
  [14476] = 14412,
  [14477] = 14461,
  [14478] = 14478,
  [14479] = 14441,
  [14480] = 10898,
  [14481] = 14412,
  [14482] = 14467,
  [14483] = 14406,
  [14484] = 14484,
  [14485] = 4772,
  [14486] = 14413,
  [14487] = 14422,
  [14488] = 14463,
  [14489] = 14403,
  [14490] = 14405,
  [14491] = 14417,
  [14492] = 14418,
  [14493] = 14407,
  [14494] = 14494,
  [14495] = 14439,
  [14496] = 14408,
  [14497] = 14497,
  [14498] = 14427,
  [14499] = 14422,
  [14500] = 4727,
  [14501] = 14413,
  [14502] = 14413,
  [14503] = 14503,
  [14504] = 14424,
  [14505] = 14418,
  [14506] = 14506,
  [14507] = 14404,
  [14508] = 14409,
  [14509] = 14424,
  [14510] = 14418,
  [14511] = 14427,
  [14512] = 11408,
  [14513] = 14513,
  [14514] = 14417,
  [14515] = 14404,
  [14516] = 14409,
  [14517] = 14409,
  [14518] = 14454,
  [14519] = 14452,
  [14520] = 14422,
  [14521] = 14432,
  [14522] = 14403,
  [14523] = 14413,
  [14524] = 14413,
  [14525] = 14427,
  [14526] = 14424,
  [14527] = 14403,
  [14528] = 14467,
  [14529] = 13125,
  [14530] = 14452,
  [14531] = 14454,
  [14532] = 14532,
  [14533] = 13105,
  [14534] = 14403,
  [14535] = 14484,
  [14536] = 14478,
  [14537] = 14467,
  [14538] = 14471,
  [14539] = 14437,
  [14540] = 14404,
  [14541] = 14421,
  [14542] = 14415,
  [14543] = 14454,
  [14544] = 14449,
  [14545] = 14452,
  [14546] = 14449,
  [14547] = 14513,
  [14548] = 14513,
  [14549] = 14461,
  [14550] = 14412,
  [14551] = 14406,
  [14552] = 14422,
  [14553] = 14405,
  [14554] = 14417,
  [14555] = 14407,
  [14556] = 14408,
  [14557] = 14452,
  [14558] = 14454,
  [14559] = 14418,
  [14560] = 14463,
  [14561] = 14418,
  [14562] = 14403,
  [14563] = 14441,
  [14564] = 14461,
  [14565] = 14452,
  [14566] = 14413,
  [14567] = 14417,
  [14568] = 14403,
  [14569] = 14404,
  [14570] = 14413,
  [14571] = 14454,
  [14572] = 14506,
  [14573] = 14404,
  [14574] = 14403,
  [14575] = 14418,
  [14576] = 14471,
  [14577] = 14422,
  [14578] = 11276,
  [14579] = 14404,
  [14580] = 14413,
  [14581] = 14409,
  [14582] = 14452,
  [14583] = 14409,
  [14584] = 14403,
  [14585] = 14454,
  [14586] = 14417,
  [14587] = 14513,
  [14588] = 14452,
  [14589] = 14454,
  [14590] = 14407,
  [14591] = 14404,
  [14592] = 14452,
  [14593] = 14421,
  [14594] = 14454,
  [14595] = 14461,
  [14596] = 14463,
  [14597] = 14415,
  [14598] = 14403,
  [14599] = 14437,
  [14600] = 14404,
  [14601] = 14421,
  [14602] = 14415,
  [14603] = 14422,
  [14604] = 14461,
  [14605] = 14417,
  [14606] = 14406,
  [14607] = 14417,
  [14608] = 14463,
  [14609] = 14412,
  [14610] = 10820,
  [14611] = 14406,
  [14612] = 14494,
  [14613] = 14422,
  [14614] = 14412,
  [14615] = 14422,
  [14616] = 14471,
  [14617] = 14406,
  [14618] = 14404,
  [14619] = 14405,
  [14620] = 14503,
  [14621] = 14407,
  [14622] = 14408,
  [14623] = 14432,
  [14624] = 14439,
  [14625] = 14461,
  [14626] = 14626,
  [14627] = 14413,
  [14628] = 14413,
  [14629] = 14532,
  [14630] = 14418,
  [14631] = 14532,
  [14632] = 14407,
  [14633] = 11312,
  [14634] = 14417,
  [14635] = 14408,
  [14636] = 14417,
  [14637] = 14427,
  [14638] = 14424,
  [14639] = 14409,
  [14640] = 14506,
  [14641] = 14503,
  [14642] = 14408,
  [14643] = 11248,
  [14644] = 9924,
  [14645] = 14409,
  [14646] = 14646,
  [14647] = 14422,
  [14648] = 14405,
  [14649] = 14413,
  [14650] = 14405,
  [14651] = 14452,
  [14652] = 14407,
  [14653] = 14403,
  [14654] = 14423,
  [14655] = 14655,
  [14656] = 10933,
  [14657] = 14452,
  [14658] = 14454,
  [14659] = 14408,
  [14660] = 14422,
  [14661] = 14407,
  [14662] = 14422,
  [14663] = 14405,
  [14664] = 9916,
  [14665] = 14403,
  [14666] = 14422,
  [14667] = 14418,
  [14668] = 14406,
  [14669] = 14669,
  [14670] = 14408,
  [14671] = 14418,
  [14672] = 14422,
  [14673] = 14404,
  [14674] = 14674,
  [14675] = 14413,
  [14676] = 14676,
  [14677] = 14417,
  [14678] = 14484,
  [14679] = 14421,
  [14680] = 14415,
  [14681] = 11313,
  [14682] = 14404,
  [14683] = 14413,
  [14684] = 14412,
  [14685] = 12978,
  [14686] = 14471,
  [14687] = 14413,
  [14688] = 14415,
  [14689] = 14418,
  [14690] = 14421,
  [14691] = 14404,
  [14692] = 14437,
  [14693] = 14421,
  [14694] = 14415,
  [14695] = 14478,
  [14696] = 14406,
  [14697] = 14471,
  [14698] = 14423,
  [14699] = 14471,
  [14700] = 14403,
  [14701] = 14412,
  [14702] = 14412,
  [14703] = 14405,
  [14704] = 14404,
  [14705] = 14417,
  [14706] = 14422,
  [14707] = 14707,
  [14708] = 14406,
  [14709] = 14417,
  [14710] = 10954,
  [14711] = 14422,
  [14712] = 14405,
  [14713] = 14713,
  [14714] = 14407,
  [14715] = 14403,
  [14716] = 14465,
  [14717] = 14421,
  [14718] = 14408,
  [14719] = 14415,
  [14720] = 14408,
  [14721] = 14424,
  [14722] = 14427,
  [14723] = 14723,
  [14724] = 14415,
  [14725] = 14413,
  [14726] = 14407,
  [14727] = 14421,
  [14728] = 14463,
  [14729] = 14423,
  [14730] = 14418,
  [14731] = 14413,
  [14732] = 14412,
  [14733] = 14409,
  [14734] = 14409,
  [14735] = 10889,
  [14736] = 14403,
  [14737] = 14737,
  [14738] = 14404,
  [14739] = 14408,
  [14740] = 14407,
  [14741] = 14741,
  [14742] = 13135,
  [14743] = 12993,
  [14744] = 14463,
  [14745] = 14452,
  [14746] = 14454,
  [14747] = 14408,
  [14748] = 14403,
  [14749] = 14429,
  [14750] = 14407,
  [14751] = 14417,
  [14752] = 14429,
  [14753] = 14404,
  [14754] = 14404,
  [14755] = 14454,
  [14756] = 14452,
  [14757] = 14405,
  [14758] = 14417,
  [14759] = 14413,
  [14760] = 14422,
  [14761] = 14406,
  [14762] = 14454,
  [14763] = 14452,
  [14764] = 14421,
  [14765] = 14403,
  [14766] = 14415,
  [14767] = 14412,
  [14768] = 14404,
  [14769] = 14412,
  [14770] = 14454,
  [14771] = 14452,
  [14772] = 14497,
  [14773] = 14439,
  [14774] = 14626,
  [14775] = 14412,
  [14776] = 14412,
  [14777] = 14417,
  [14778] = 14406,
  [14779] = 14422,
  [14780] = 14421,
  [14781] = 14415,
  [14782] = 14404,
  [14783] = 14418,
  [14784] = 14408,
  [14785] = 14417,
  [14786] = 14532,
  [14787] = 14417,
  [14788] = 14461,
  [14789] = 14789,
  [14790] = 14407,
  [14791] = 14412,
  [14792] = 14406,
  [14793] = 14405,
  [14794] = 14406,
  [14795] = 14406,
  [14796] = 14422,
  [14797] = 14417,
  [14798] = 14403,
  [14799] = 14413,
  [14800] = 14413,
  [14801] = 14513,
  [14802] = 14415,
  [14803] = 14404,
  [14804] = 14421,
  [14805] = 14513,
  [14806] = 14422,
  [14807] = 14422,
  [14808] = 14418,
  [14809] = 14408,
  [14810] = 14429,
  [14811] = 14461,
  [14812] = 14407,
  [14813] = 14406,
  [14814] = 14404,
  [14815] = 14461,
  [14816] = 14405,
  [14817] = 14409,
  [14818] = 14403,
  [14819] = 14403,
  [14820] = 14407,
  [14821] = 14408,
  [14822] = 14403,
  [14823] = 14409,
  [14824] = 14404,
  [14825] = 14422,
  [14826] = 14417,
  [14827] = 14484,
  [14828] = 14626,
  [14829] = 14422,
  [14830] = 14413,
  [14831] = 14454,
  [14832] = 14478,
  [14833] = 14403,
  [14834] = 14422,
  [14835] = 14405,
  [14836] = 14427,
  [14837] = 14415,
  [14838] = 14424,
  [14839] = 14404,
  [14840] = 14413,
  [14841] = 14408,
  [14842] = 14465,
  [14843] = 14407,
  [14844] = 14844,
  [14845] = 12133,
  [14846] = 12131,
  [14847] = 14412,
  [14848] = 14463,
  [14849] = 14452,
  [14850] = 14454,
  [14851] = 14422,
  [14852] = 14423,
  [14853] = 14409,
  [14854] = 14417,
  [14855] = 14429,
  [14856] = 14404,
  [14857] = 14404,
  [14858] = 14404,
  [14859] = 14422,
  [14860] = 14421,
  [14861] = 14415,
  [14862] = 14403,
  [14863] = 14405,
  [14864] = 14403,
  [14865] = 14412,
  [14866] = 14415,
  [14867] = 14471,
  [14868] = 14626,
  [14869] = 14421,
  [14870] = 14412,
  [14871] = 14406,
  [14872] = 14422,
  [14873] = 14873,
  [14874] = 14432,
  [14875] = 14418,
  [14876] = 14405,
  [14877] = 14413,
  [14878] = 14878,
  [14879] = 14413,
  [14880] = 14417,
  [14881] = 14404,
  [14882] = 14418,
  [14883] = 14403,
  [14884] = 14407,
  [14885] = 14454,
  [14886] = 14789,
  [14887] = 14422,
  [14888] = 14888,
  [14889] = 14503,
  [14890] = 14452,
  [14891] = 14405,
  [14892] = 11958,
  [14893] = 14413,
  [14894] = 14408,
  [14895] = 14463,
  [14896] = 14404,
  [14897] = 14418,
  [14898] = 14406,
  [14899] = 10955,
  [14900] = 14418,
  [14901] = 14506,
  [14902] = 14424,
  [14903] = 14417,
  [14904] = 14413,
  [14905] = 14422,
  [14906] = 14427,
  [14907] = 14409,
  [14908] = 14441,
  [14909] = 14454,
  [14910] = 14413,
  [14911] = 14452,
  [14912] = 14478,
  [14913] = 14422,
  [14914] = 14405,
  [14915] = 14484,
  [14916] = 14407,
  [14917] = 14408,
  [14918] = 14403,
  [14919] = 14532,
  [14920] = 14413,
  [14921] = 14422,
  [14922] = 14409,
  [14923] = 14424,
  [14924] = 14452,
  [14925] = 14454,
  [14926] = 14417,
  [14927] = 14409,
  [14928] = 14404,
  [14929] = 14413,
  [14930] = 11253,
  [14931] = 14404,
  [14932] = 14422,
  [14933] = 11247,
  [14934] = 14471,
  [14935] = 14494,
  [14936] = 14403,
  [14937] = 14421,
  [14938] = 14417,
  [14939] = 14415,
  [14940] = 14484,
  [14941] = 14405,
  [14942] = 14422,
  [14943] = 14532,
  [14944] = 14403,
  [14945] = 14417,
  [14946] = 14432,
  [14947] = 14478,
  [14948] = 14406,
  [14949] = 14471,
  [14950] = 14417,
  [14951] = 14421,
  [14952] = 14403,
  [14953] = 14413,
  [14954] = 14413,
  [14955] = 14424,
  [14956] = 14418,
  [14957] = 14463,
  [14958] = 14439,
  [14959] = 14412,
  [14960] = 14465,
  [14961] = 14961,
  [14962] = 14962,
  [14963] = 14403,
  [14964] = 14406,
  [14965] = 14461,
  [14966] = 14427,
  [14967] = 14409,
  [14968] = 14422,
  [14969] = 14422,
  [14970] = 14415,
  [14971] = 14417,
  [14972] = 14471,
  [14973] = 14405,
  [14974] = 14404,
  [14975] = 14404,
  [14976] = 14452,
  [14977] = 14454,
  [14978] = 14506,
  [14979] = 14417,
  [14980] = 14404,
  [14981] = 14427,
  [14982] = 14403,
  [14983] = 14424,
  [14984] = 14427,
  [14985] = 14413,
  [14986] = 14404,
  [14987] = 14987,
  [14988] = 14417,
  [14989] = 14461,
  [14990] = 14417,
  [14991] = 14408,
  [14992] = 14413,
  [14993] = 14403,
  [14994] = 14412,
  [14995] = 14432,
  [14996] = 14996,
  [14997] = 14409,
  [14998] = 14413,
  [14999] = 14421,
  [15000] = 14409,
  [15001] = 15001,
  [15002] = 10063,
  [15003] = 14422,
  [15004] = 14422,
  [15005] = 14418,
  [15006] = 14417,
  [15007] = 14403,
  [15008] = 14417,
  [15009] = 14429,
  [15010] = 14403,
  [15011] = 14421,
  [15012] = 14404,
  [15013] = 14403,
  [15014] = 14888,
  [15015] = 15015,
  [15016] = 14415,
  [15017] = 14417,
  [15018] = 14461,
  [15019] = 14403,
  [15020] = 15020,
  [15021] = 14404,
  [15022] = 14407,
  [15023] = 14441,
  [15024] = 14413,
  [15025] = 14413,
  [15026] = 14413,
  [15027] = 14463,
  [15028] = 14471,
  [15029] = 14471,
  [15030] = 14405,
  [15031] = 14413,
  [15032] = 14503,
  [15033] = 14412,
  [15034] = 14427,
  [15035] = 14422,
  [15036] = 14463,
  [15037] = 14417,
  [15038] = 14415,
  [15039] = 14422,
  [15040] = 14463,
  [15041] = 14424,
  [15042] = 14406,
  [15043] = 14506,
  [15044] = 14996,
  [15045] = 14421,
  [15046] = 10745,
  [15047] = 14417,
  [15048] = 14418,
  [15049] = 14404,
  [15050] = 14413,
  [15051] = 14409,
  [15052] = 14452,
  [15053] = 14424,
  [15054] = 14454,
  [15055] = 14422,
  [15056] = 14403,
  [15057] = 14413,
  [15058] = 14471,
  [15059] = 14432,
  [15060] = 14403,
  [15061] = 14417,
  [15062] = 14432,
  [15063] = 14404,
  [15064] = 3023,
  [15065] = 14655,
  [15066] = 14417,
  [15067] = 14427,
  [15068] = 14413,
  [15069] = 14844,
  [15070] = 14422,
  [15071] = 14417,
  [15072] = 14403,
  [15073] = 14417,
  [15074] = 14413,
  [15075] = 14405,
  [15076] = 14503,
  [15077] = 14404,
  [15078] = 14422,
  [15079] = 14407,
  [15080] = 14408,
  [15081] = 14418,
  [15082] = 15082,
  [15083] = 15083,
  [15084] = 15084,
  [15085] = 15085,
  [15086] = 15086,
  [15087] = 15087,
  [15088] = 15088,
  [15089] = 15089,
  [15090] = 15090,
  [15091] = 15091,
  [15092] = 15092,
  [15093] = 15093,
  [15094] = 15094,
  [15095] = 15095,
  [15096] = 15096,
  [15097] = 15097,
  [15098] = 15098,
  [15099] = 15099,
  [15100] = 15097,
  [15101] = 15088,
  [15102] = 15085,
  [15103] = 15084,
  [15104] = 15104,
  [15105] = 15105,
  [15106] = 15090,
  [15107] = 15107,
  [15108] = 15094,
  [15109] = 15109,
  [15110] = 15097,
  [15111] = 15111,
  [15112] = 15112,
  [15113] = 15113,
  [15114] = 15098,
  [15115] = 15111,
  [15116] = 15116,
  [15117] = 15117,
  [15118] = 15118,
  [15119] = 15119,
  [15120] = 15083,
  [15121] = 15121,
  [15122] = 15096,
  [15123] = 15098,
  [15124] = 15124,
  [15125] = 15125,
  [15126] = 15125,
  [15127] = 15127,
  [15128] = 15128,
  [15129] = 15129,
  [15130] = 15097,
  [15131] = 15111,
  [15132] = 15086,
  [15133] = 15089,
  [15134] = 15098,
  [15135] = 15093,
  [15136] = 15091,
  [15137] = 15105,
  [15138] = 15088,
  [15139] = 15105,
  [15140] = 15109,
  [15141] = 15109,
  [15142] = 15089,
  [15143] = 15143,
  [15144] = 15116,
  [15145] = 15125,
  [15146] = 15129,
  [15147] = 15129,
  [15148] = 15127,
  [15149] = 15098,
  [15150] = 15125,
  [15151] = 15119,
  [15152] = 15096,
  [15153] = 15083,
  [15154] = 15094,
  [15155] = 15105,
  [15156] = 15156,
  [15157] = 15157,
  [15158] = 15116,
  [15159] = 15121,
  [15160] = 15107,
  [15161] = 15094,
  [15162] = 15083,
  [15163] = 15163,
  [15164] = 15164,
  [15165] = 15128,
  [15166] = 15166,
  [15167] = 15096,
  [15168] = 15168,
  [15169] = 15127,
  [15170] = 15170,
  [15171] = 15109,
  [15172] = 15121,
  [15173] = 15173,
  [15174] = 15109,
  [15175] = 15175,
  [15176] = 15128,
  [15177] = 15129,
  [15178] = 15086,
  [15179] = 15179,
  [15180] = 15121,
  [15181] = 15089,
  [15182] = 15088,
  [15183] = 15127,
  [15184] = 15090,
  [15185] = 15117,
  [15186] = 15105,
  [15187] = 15109,
  [15188] = 15097,
  [15189] = 15084,
  [15190] = 15190,
  [15191] = 15107,
  [15192] = 15083,
  [15193] = 15094,
  [15194] = 15194,
  [15195] = 15089,
  [15196] = 15119,
  [15197] = 15194,
  [15198] = 15089,
  [15199] = 15199,
  [15200] = 15200,
  [15201] = 15201,
  [15202] = 15202,
  [15203] = 15105,
  [15204] = 15204,
  [15205] = 15090,
  [15206] = 15097,
  [15207] = 15109,
  [15208] = 15208,
  [15209] = 15088,
  [15210] = 15094,
  [15211] = 15109,
  [15212] = 15125,
  [15213] = 15091,
  [15214] = 15214,
  [15215] = 15215,
  [15216] = 15093,
  [15217] = 15090,
  [15218] = 15088,
  [15219] = 15125,
  [15220] = 15098,
  [15221] = 15125,
  [15222] = 15105,
  [15223] = 15223,
  [15224] = 15094,
  [15225] = 15089,
  [15226] = 15094,
  [15227] = 15227,
  [15228] = 15215,
  [15229] = 15089,
  [15230] = 15143,
  [15231] = 15086,
  [15232] = 15097,
  [15233] = 15097,
  [15234] = 15112,
  [15235] = 15097,
  [15236] = 15105,
  [15237] = 15098,
  [15238] = 15097,
  [15239] = 15129,
  [15240] = 15240,
  [15241] = 15241,
  [15242] = 15129,
  [15243] = 15096,
  [15244] = 15127,
  [15245] = 15090,
  [15246] = 15105,
  [15247] = 15109,
  [15248] = 15248,
  [15249] = 15083,
  [15250] = 15250,
  [15251] = 15251,
  [15252] = 15094,
  [15253] = 15098,
  [15254] = 15116,
  [15255] = 15199,
  [15256] = 15125,
  [15257] = 15109,
  [15258] = 15128,
  [15259] = 15097,
  [15260] = 15128,
  [15261] = 15128,
  [15262] = 15262,
  [15263] = 15096,
  [15264] = 15098,
  [15265] = 15109,
  [15266] = 15129,
  [15267] = 15105,
  [15268] = 15116,
  [15269] = 15157,
  [15270] = 15094,
  [15271] = 15271,
  [15272] = 15099,
  [15273] = 15273,
  [15274] = 15086,
  [15275] = 15251,
  [15276] = 15157,
  [15277] = 15129,
  [15278] = 15088,
  [15279] = 15099,
  [15280] = 15090,
  [15281] = 15116,
  [15282] = 15143,
  [15283] = 15083,
  [15284] = 15088,
  [15285] = 15116,
  [15286] = 15127,
  [15287] = 15098,
  [15288] = 15104,
  [15289] = 15084,
  [15290] = 15097,
  [15291] = 15098,
  [15292] = 15094,
  [15293] = 15179,
  [15294] = 15127,
  [15295] = 15295,
  [15296] = 15296,
  [15297] = 15121,
  [15298] = 15093,
  [15299] = 15091,
  [15300] = 15083,
  [15301] = 15104,
  [15302] = 15083,
  [15303] = 15105,
  [15304] = 15094,
  [15305] = 15129,
  [15306] = 15109,
  [15307] = 15109,
  [15308] = 15119,
  [15309] = 15127,
  [15310] = 15097,
  [15311] = 15094,
  [15312] = 15200,
  [15313] = 15086,
  [15314] = 15129,
  [15315] = 15091,
  [15316] = 15116,
  [15317] = 15125,
  [15318] = 15111,
  [15319] = 15090,
  [15320] = 15097,
  [15321] = 15227,
  [15322] = 15094,
  [15323] = 15109,
  [15324] = 15089,
  [15325] = 15089,
  [15326] = 15107,
  [15327] = 15093,
  [15328] = 15109,
  [15329] = 15223,
  [15330] = 15091,
  [15331] = 15214,
  [15332] = 15179,
  [15333] = 15204,
  [15334] = 15334,
  [15335] = 15335,
  [15336] = 15088,
  [15337] = 15129,
  [15338] = 15125,
  [15339] = 15127,
  [15340] = 15125,
  [15341] = 15098,
  [15342] = 15091,
  [15343] = 15093,
  [15344] = 15083,
  [15345] = 15086,
  [15346] = 15121,
  [15347] = 15127,
  [15348] = 15250,
  [15349] = 15116,
  [15350] = 15199,
  [15351] = 15096,
  [15352] = 15128,
  [15353] = 15096,
  [15354] = 15119,
  [15355] = 15109,
  [15356] = 15128,
  [15357] = 15156,
  [15358] = 15096,
  [15359] = 15119,
  [15360] = 15094,
  [15361] = 15109,
  [15362] = 15095,
  [15363] = 15104,
  [15364] = 15364,
  [15365] = 15097,
  [15366] = 15121,
  [15367] = 15166,
  [15368] = 15170,
  [15369] = 15086,
  [15370] = 15090,
  [15371] = 15091,
  [15372] = 15173,
  [15373] = 15088,
  [15374] = 15109,
  [15375] = 15090,
  [15376] = 15119,
  [15377] = 15128,
  [15378] = 15093,
  [15379] = 15096,
  [15380] = 15089,
  [15381] = 15083,
  [15382] = 15128,
  [15383] = 15109,
  [15384] = 15094,
  [15385] = 15208,
  [15386] = 15223,
  [15387] = 15094,
  [15388] = 15086,
  [15389] = 15097,
  [15390] = 15390,
  [15391] = 15098,
  [15392] = 15392,
  [15393] = 15094,
  [15394] = 15116,
  [15395] = 15098,
  [15396] = 15094,
  [15397] = 15179,
  [15398] = 15105,
  [15399] = 15125,
  [15400] = 15083,
  [15401] = 15109,
  [15402] = 15097,
  [15403] = 15097,
  [15404] = 15194,
  [15405] = 15109,
  [15406] = 15105,
  [15407] = 15116,
  [15408] = 15088,
  [15409] = 15127,
  [15410] = 15090,
  [15411] = 15125,
  [15412] = 15200,
  [15413] = 15097,
  [15414] = 15094,
  [15415] = 15129,
  [15416] = 15089,
  [15417] = 15098,
  [15418] = 15392,
  [15419] = 15089,
  [15420] = 15098,
  [15421] = 15105,
  [15422] = 15097,
  [15423] = 15109,
  [15424] = 15116,
  [15425] = 15090,
  [15426] = 15109,
  [15427] = 15105,
  [15428] = 15199,
  [15429] = 15109,
  [15430] = 15094,
  [15431] = 15129,
  [15432] = 15202,
  [15433] = 15127,
  [15434] = 15113,
  [15435] = 15435,
  [15436] = 15089,
  [15437] = 15109,
  [15438] = 15083,
  [15439] = 15094,
  [15440] = 15099,
  [15441] = 15157,
  [15442] = 15129,
  [15443] = 15116,
  [15444] = 15097,
  [15445] = 15164,
  [15446] = 15143,
  [15447] = 15088,
  [15448] = 15201,
  [15449] = 15086,
  [15450] = 15128,
  [15451] = 15098,
  [15452] = 15096,
  [15453] = 15105,
  [15454] = 15104,
  [15455] = 15455,
  [15456] = 15364,
  [15457] = 15457,
  [15458] = 15125,
  [15459] = 15094,
  [15460] = 15096,
  [15461] = 15156,
  [15462] = 15097,
  [15463] = 15086,
  [15464] = 15094,
  [15465] = 15097,
  [15466] = 10933,
  [15467] = 15088,
  [15468] = 15097,
  [15469] = 15090,
  [15470] = 15127,
  [15471] = 15166,
  [15472] = 15097,
  [15473] = 15179,
  [15474] = 15170,
  [15475] = 15094,
  [15476] = 15173,
  [15477] = 15179,
  [15478] = 15104,
  [15479] = 15128,
  [15480] = 15097,
  [15481] = 15098,
  [15482] = 12076,
  [15483] = 15127,
  [15484] = 15097,
  [15485] = 15109,
  [15486] = 15128,
  [15487] = 15173,
  [15488] = 15116,
  [15489] = 15125,
  [15490] = 15129,
  [15491] = 15170,
  [15492] = 15105,
  [15493] = 15128,
  [15494] = 15494,
  [15495] = 15094,
  [15496] = 15496,
  [15497] = 15109,
  [15498] = 15164,
  [15499] = 15166,
  [15500] = 15194,
  [15501] = 15109,
  [15502] = 15127,
  [15503] = 15089,
  [15504] = 15097,
  [15505] = 15125,
  [15506] = 15083,
  [15507] = 15094,
  [15508] = 15098,
  [15509] = 15127,
  [15510] = 15097,
  [15511] = 15094,
  [15512] = 15179,
  [15513] = 15089,
  [15514] = 15096,
  [15515] = 15515,
  [15516] = 15516,
  [15517] = 15104,
  [15518] = 15121,
  [15519] = 15129,
  [15520] = 15109,
  [15521] = 15119,
  [15522] = 15156,
  [15523] = 15109,
  [15524] = 15109,
  [15525] = 15129,
  [15526] = 15109,
  [15527] = 15127,
  [15528] = 15093,
  [15529] = 15091,
  [15530] = 15089,
  [15531] = 15093,
  [15532] = 15083,
  [15533] = 15533,
  [15534] = 15534,
  [15535] = 15097,
  [15536] = 15109,
  [15537] = 15116,
  [15538] = 15091,
  [15539] = 15539,
  [15540] = 15109,
  [15541] = 15094,
  [15542] = 15109,
  [15543] = 15173,
  [15544] = 15128,
  [15545] = 15086,
  [15546] = 15096,
  [15547] = 15094,
  [15548] = 15125,
  [15549] = 15109,
  [15550] = 15550,
  [15551] = 15129,
  [15552] = 15127,
  [15553] = 15083,
  [15554] = 15097,
  [15555] = 15170,
  [15556] = 15166,
  [15557] = 15086,
  [15558] = 15094,
  [15559] = 15097,
  [15560] = 15094,
  [15561] = 15088,
  [15562] = 15194,
  [15563] = 15090,
  [15564] = 15097,
  [15565] = 15089,
  [15566] = 15094,
  [15567] = 15107,
  [15568] = 15109,
  [15569] = 15125,
  [15570] = 15109,
  [15571] = 15105,
  [15572] = 15097,
  [15573] = 15109,
  [15574] = 15098,
  [15575] = 15097,
  [15576] = 15094,
  [15577] = 15090,
  [15578] = 15119,
  [15579] = 15579,
  [15580] = 15084,
  [15581] = 15088,
  [15582] = 15094,
  [15583] = 15125,
  [15584] = 15097,
  [15585] = 15094,
  [15586] = 15093,
  [15587] = 15118,
  [15588] = 15098,
  [15589] = 15086,
  [15590] = 15590,
  [15591] = 15091,
  [15592] = 15116,
  [15593] = 15111,
  [15594] = 15121,
  [15595] = 15088,
  [15596] = 15596,
  [15597] = 15097,
  [15598] = 15125,
  [15599] = 15599,
  [15600] = 15143,
  [15601] = 15157,
  [15602] = 9924,
  [15603] = 15121,
  [15604] = 15096,
  [15605] = 15204,
  [15606] = 15089,
  [15607] = 15094,
  [15608] = 15112,
  [15609] = 15097,
  [15610] = 15157,
  [15611] = 15094,
  [15612] = 15099,
  [15613] = 15097,
  [15614] = 15156,
  [15615] = 15143,
  [15616] = 15128,
  [15617] = 15096,
  [15618] = 15129,
  [15619] = 15097,
  [15620] = 15127,
  [15621] = 15094,
  [15622] = 15096,
  [15623] = 15119,
  [15624] = 15200,
  [15625] = 15083,
  [15626] = 15089,
  [15627] = 15094,
  [15628] = 15200,
  [15629] = 15116,
  [15630] = 15116,
  [15631] = 15121,
  [15632] = 15199,
  [15633] = 15109,
  [15634] = 15090,
  [15635] = 15199,
  [15636] = 15090,
  [15637] = 15128,
  [15638] = 15083,
  [15639] = 15096,
  [15640] = 15097,
  [15641] = 15099,
  [15642] = 15157,
  [15643] = 15143,
  [15644] = 15097,
  [15645] = 15094,
  [15646] = 15083,
  [15647] = 15088,
  [15648] = 15109,
  [15649] = 15094,
  [15650] = 15086,
  [15651] = 15241,
  [15652] = 15129,
  [15653] = 15653,
  [15654] = 15088,
  [15655] = 15105,
  [15656] = 15090,
  [15657] = 15097,
  [15658] = 15086,
  [15659] = 15089,
  [15660] = 15119,
  [15661] = 15098,
  [15662] = 15086,
  [15663] = 15094,
  [15664] = 15127,
  [15665] = 15104,
  [15666] = 15088,
  [15667] = 15109,
  [15668] = 15105,
  [15669] = 15096,
  [15670] = 15129,
  [15671] = 15094,
  [15672] = 15179,
  [15673] = 15271,
  [15674] = 15156,
  [15675] = 15090,
  [15676] = 15200,
  [15677] = 15121,
  [15678] = 15097,
  [15679] = 15166,
  [15680] = 15170,
  [15681] = 15173,
  [15682] = 15090,
  [15683] = 15127,
  [15684] = 15119,
  [15685] = 15199,
  [15686] = 15128,
  [15687] = 15091,
  [15688] = 15688,
  [15689] = 15083,
  [15690] = 15125,
  [15691] = 15194,
  [15692] = 15089,
  [15693] = 15091,
  [15694] = 15128,
  [15695] = 15093,
  [15696] = 15116,
  [15697] = 15097,
  [15698] = 15089,
  [15699] = 15109,
  [15700] = 15093,
  [15701] = 15125,
  [15702] = 15094,
  [15703] = 15099,
  [15704] = 15109,
  [15705] = 15098,
  [15706] = 15083,
  [15707] = 15707,
  [15708] = 15129,
  [15709] = 15129,
  [15710] = 15098,
  [15711] = 15127,
  [15712] = 15104,
  [15713] = 15116,
  [15714] = 15127,
  [15715] = 15105,
  [15716] = 15083,
  [15717] = 15179,
  [15718] = 15094,
  [15719] = 15157,
  [15720] = 15179,
  [15721] = 15116,
  [15722] = 15116,
  [15723] = 15104,
  [15724] = 15086,
  [15725] = 15109,
  [15726] = 15129,
  [15727] = 15097,
  [15728] = 15128,
  [15729] = 15089,
  [15730] = 15096,
  [15731] = 15088,
  [15732] = 15097,
  [15733] = 15097,
  [15734] = 15105,
  [15735] = 15143,
  [15736] = 15127,
  [15737] = 15086,
  [15738] = 15091,
  [15739] = 15125,
  [15740] = 15099,
  [15741] = 15086,
  [15742] = 15109,
  [15743] = 15128,
  [15744] = 15579,
  [15745] = 15088,
  [15746] = 15094,
  [15747] = 15090,
  [15748] = 15094,
  [15749] = 15749,
  [15750] = 15094,
  [15751] = 15223,
  [15752] = 15083,
  [15753] = 15214,
  [15754] = 15754,
  [15755] = 15093,
  [15756] = 15215,
  [15757] = 15125,
  [15758] = 15095,
  [15759] = 15109,
  [15760] = 15088,
  [15761] = 15116,
  [15762] = 15094,
  [15763] = 15208,
  [15764] = 15109,
  [15765] = 15097,
  [15766] = 15202,
  [15767] = 15199,
  [15768] = 15105,
  [15769] = 15094,
  [15770] = 15109,
  [15771] = 15097,
  [15772] = 15094,
  [15773] = 15599,
  [15774] = 15094,
  [15775] = 15090,
  [15776] = 15200,
  [15777] = 15097,
  [15778] = 15094,
  [15779] = 15779,
  [15780] = 15097,
  [15781] = 15094,
  [15782] = 15098,
  [15783] = 15097,
  [15784] = 15125,
  [15785] = 15090,
  [15786] = 15088,
  [15787] = 15090,
  [15788] = 15199,
  [15789] = 15086,
  [15790] = 15086,
  [15791] = 15109,
  [15792] = 15223,
  [15793] = 15097,
  [15794] = 15086,
  [15795] = 15099,
  [15796] = 15157,
  [15797] = 15086,
  [15798] = 15098,
  [15799] = 15143,
  [15800] = 15088,
  [15801] = 15109,
  [15802] = 15084,
  [15803] = 15128,
  [15804] = 15097,
  [15805] = 15109,
  [15806] = 15105,
  [15807] = 15086,
  [15808] = 15173,
  [15809] = 15170,
  [15810] = 15200,
  [15811] = 15098,
  [15812] = 15200,
  [15813] = 15096,
  [15814] = 15166,
  [15815] = 15128,
  [15816] = 15200,
  [15817] = 15089,
  [15818] = 15090,
  [15819] = 15128,
  [15820] = 15173,
  [15821] = 15199,
  [15822] = 15156,
  [15823] = 15116,
  [15824] = 15099,
  [15825] = 15170,
  [15826] = 15157,
  [15827] = 15143,
  [15828] = 15096,
  [15829] = 15166,
  [15830] = 15156,
  [15831] = 15098,
  [15832] = 15088,
  [15833] = 15200,
  [15834] = 15096,
  [15835] = 15086,
  [15836] = 15083,
  [15837] = 15105,
  [15838] = 15119,
  [15839] = 15109,
  [15840] = 15166,
  [15841] = 15170,
  [15842] = 15173,
  [15843] = 15127,
  [15844] = 15128,
  [15845] = 15121,
  [15846] = 15109,
  [15847] = 15223,
  [15848] = 15098,
  [15849] = 15156,
  [15850] = 15096,
  [15851] = 15129,
  [15852] = 15156,
  [15853] = 15116,
  [15854] = 15129,
  [15855] = 15127,
  [15856] = 15856,
  [15857] = 15086,
  [15858] = 15166,
  [15859] = 15194,
  [15860] = 15170,
  [15861] = 15093,
  [15862] = 15390,
  [15863] = 15096,
  [15864] = 15173,
  [15865] = 15392,
  [15866] = 15083,
  [15867] = 15088,
  [15868] = 15098,
  [15869] = 15091,
  [15870] = 15117,
  [15871] = 15094,
  [15872] = 15390,
  [15873] = 15204,
  [15874] = 15127,
  [15875] = 15112,
  [15876] = 15089,
  [15877] = 15877,
  [15878] = 15179,
  [15879] = 15116,
  [15880] = 15097,
  [15881] = 15084,
  [15882] = 15200,
  [15883] = 15119,
  [15884] = 15090,
  [15885] = 15121,
  [15886] = 15083,
  [15887] = 15097,
  [15888] = 15190,
  [15889] = 11984,
  [15890] = 15127,
  [15891] = 15179,
  [15892] = 15104,
  [15893] = 12084,
  [15894] = 15457,
  [15895] = 15241,
  [15896] = 15088,
  [15897] = 15104,
  [15898] = 15098,
  [15899] = 15125,
  [15900] = 15129,
  [15901] = 15093,
  [15902] = 15098,
  [15903] = 15109,
  [15904] = 15129,
  [15905] = 15086,
  [15906] = 15089,
  [15907] = 15164,
  [15908] = 15105,
  [15909] = 15125,
  [15910] = 15143,
  [15911] = 15098,
  [15912] = 12077,
  [15913] = 15083,
  [15914] = 15157,
  [15915] = 15099,
  [15916] = 15199,
  [15917] = 15250,
  [15918] = 15251,
  [15919] = 15094,
  [15920] = 15097,
  [15921] = 15194,
  [15922] = 15097,
  [15923] = 15098,
  [15924] = 15084,
  [15925] = 15199,
  [15926] = 15926,
  [15927] = 15090,
  [15928] = 15094,
  [15929] = 15083,
  [15930] = 15099,
  [15931] = 15109,
  [15932] = 15157,
  [15933] = 15094,
  [15934] = 15128,
  [15935] = 15096,
  [15936] = 15143,
  [15937] = 15121,
  [15938] = 15089,
  [15939] = 15164,
  [15940] = 15200,
  [15941] = 15088,
  [15942] = 15200,
  [15943] = 15098,
  [15944] = 15092,
  [15945] = 15097,
  [15946] = 15392,
  [15947] = 15088,
  [15948] = 15109,
  [15949] = 15090,
  [15950] = 15950,
  [15951] = 15199,
  [15952] = 15119,
  [15953] = 15109,
  [15954] = 15086,
  [15955] = 15109,
  [15956] = 15116,
  [15957] = 15143,
  [15958] = 15098,
  [15959] = 15094,
  [15960] = 15090,
  [15961] = 15157,
  [15962] = 15099,
  [15963] = 15090,
  [15964] = 15099,
  [15965] = 15125,
  [15966] = 15090,
  [15967] = 15157,
  [15968] = 15088,
  [15969] = 15262,
  [15970] = 15143,
  [15971] = 15091,
  [15972] = 15201,
  [15973] = 15088,
  [15974] = 15090,
  [15975] = 15098,
  [15976] = 15105,
  [15977] = 15093,
  [15978] = 15086,
  [15979] = 15109,
  [15980] = 15098,
  [15981] = 15199,
  [15982] = 15086,
  [15983] = 15200,
  [15984] = 15105,
  [15985] = 15097,
  [15986] = 15199,
  [15987] = 15094,
  [15988] = 15099,
  [15989] = 15157,
  [15990] = 15096,
  [15991] = 15128,
  [15992] = 15143,
  [15993] = 15125,
  [15994] = 15179,
  [15995] = 15096,
  [15996] = 15093,
  [15997] = 15997,
  [15998] = 15156,
  [15999] = 15096,
  [16000] = 15116,
  [16001] = 11621,
  [16002] = 15392,
  [16003] = 15094,
  [16004] = 15119,
  [16005] = 15083,
  [16006] = 15091,
  [16007] = 15166,
  [16008] = 10063,
  [16009] = 15170,
  [16010] = 15156,
  [16011] = 15173,
  [16012] = 15128,
  [16013] = 15097,
  [16014] = 15089,
  [16015] = 15109,
  [16016] = 15116,
  [16017] = 15125,
  [16018] = 15116,
  [16019] = 15127,
  [16020] = 15105,
  [16021] = 15157,
  [16022] = 15098,
  [16023] = 15170,
  [16024] = 15098,
  [16025] = 15129,
  [16026] = 15092,
  [16027] = 15083,
  [16028] = 15127,
  [16029] = 15084,
  [16030] = 15166,
  [16031] = 15125,
  [16032] = 15094,
  [16033] = 15119,
  [16034] = 15579,
  [16035] = 15227,
  [16036] = 15104,
  [16037] = 15089,
  [16038] = 15129,
  [16039] = 15093,
  [16040] = 15390,
  [16041] = 15096,
  [16042] = 15105,
  [16043] = 15173,
  [16044] = 15089,
  [16045] = 15107,
  [16046] = 15084,
  [16047] = 15091,
  [16048] = 15117,
  [16049] = 15094,
  [16050] = 15098,
  [16051] = 15125,
  [16052] = 15204,
  [16053] = 15121,
  [16054] = 15599,
  [16055] = 15112,
  [16056] = 15111,
  [16057] = 15125,
  [16058] = 15089,
  [16059] = 15435,
  [16060] = 15109,
  [16061] = 15109,
  [16062] = 15098,
  [16063] = 15119,
  [16064] = 15097,
  [16065] = 15121,
  [16066] = 15097,
  [16067] = 10698,
  [16068] = 15109,
  [16069] = 15190,
  [16070] = 15089,
  [16071] = 15248,
  [16072] = 15109,
  [16073] = 15098,
  [16074] = 15086,
  [16075] = 15105,
  [16076] = 15457,
  [16077] = 15241,
  [16078] = 15109,
  [16079] = 15128,
  [16080] = 10931,
  [16081] = 15097,
  [16082] = 15129,
  [16083] = 15105,
  [16084] = 15127,
  [16085] = 15223,
  [16086] = 15164,
  [16087] = 15200,
  [16088] = 15200,
  [16089] = 15156,
  [16090] = 10568,
  [16091] = 15083,
  [16092] = 15129,
  [16093] = 15109,
  [16094] = 15200,
  [16095] = 15109,
  [16096] = 16096,
  [16097] = 15090,
  [16098] = 15599,
  [16099] = 15105,
  [16100] = 15199,
  [16101] = 15109,
  [16102] = 15090,
  [16103] = 15250,
  [16104] = 15251,
  [16105] = 15096,
  [16106] = 15579,
  [16107] = 15199,
  [16108] = 15194,
  [16109] = 15086,
  [16110] = 15098,
  [16111] = 15099,
  [16112] = 15156,
  [16113] = 15157,
  [16114] = 15143,
  [16115] = 15170,
  [16116] = 15088,
  [16117] = 15116,
  [16118] = 15099,
  [16119] = 16119,
  [16120] = 15094,
  [16121] = 15094,
  [16122] = 15128,
  [16123] = 16123,
  [16124] = 15086,
  [16125] = 15097,
  [16126] = 15090,
  [16127] = 15097,
  [16128] = 15455,
  [16129] = 15143,
  [16130] = 15096,
  [16131] = 15156,
  [16132] = 15950,
  [16133] = 15166,
  [16134] = 15088,
  [16135] = 15090,
  [16136] = 15166,
  [16137] = 15084,
  [16138] = 15088,
  [16139] = 15097,
  [16140] = 15170,
  [16141] = 15092,
  [16142] = 15173,
  [16143] = 15105,
  [16144] = 15097,
  [16145] = 15179,
  [16146] = 15104,
  [16147] = 15116,
  [16148] = 15088,
  [16149] = 15083,
  [16150] = 15127,
  [16151] = 15179,
  [16152] = 15096,
  [16153] = 15104,
  [16154] = 15086,
  [16155] = 15129,
  [16156] = 15127,
  [16157] = 15109,
  [16158] = 15179,
  [16159] = 15094,
  [16160] = 15089,
  [16161] = 15098,
  [16162] = 15127,
  [16163] = 15098,
  [16164] = 15166,
  [16165] = 15083,
  [16166] = 15083,
  [16167] = 15096,
  [16168] = 15125,
  [16169] = 15086,
  [16170] = 15097,
  [16171] = 15392,
  [16172] = 15098,
  [16173] = 15170,
  [16174] = 15156,
  [16175] = 16175,
  [16176] = 15096,
  [16177] = 15116,
  [16178] = 15516,
  [16179] = 15194,
  [16180] = 15128,
  [16181] = 15173,
  [16182] = 15092,
  [16183] = 15097,
  [16184] = 15116,
  [16185] = 15295,
  [16186] = 15251,
  [16187] = 15250,
  [16188] = 15109,
  [16189] = 15105,
  [16190] = 15094,
  [16191] = 15227,
  [16192] = 15121,
  [16193] = 15223,
  [16194] = 15116,
  [16195] = 15098,
  [16196] = 15214,
  [16197] = 15215,
  [16198] = 15096,
  [16199] = 15125,
  [16200] = 15156,
  [16201] = 15950,
  [16202] = 15095,
  [16203] = 15119,
  [16204] = 15125,
  [16205] = 15109,
  [16206] = 15109,
  [16207] = 15166,
  [16208] = 15170,
  [16209] = 15173,
  [16210] = 15208,
  [16211] = 15128,
  [16212] = 15166,
  [16213] = 15083,
  [16214] = 15223,
  [16215] = 15173,
  [16216] = 15128,
  [16217] = 15129,
  [16218] = 15515,
  [16219] = 15104,
  [16220] = 15128,
  [16221] = 15094,
  [16222] = 15950,
  [16223] = 15202,
  [16224] = 15173,
  [16225] = 15170,
  [16226] = 15201,
  [16227] = 15094,
  [16228] = 15127,
  [16229] = 15086,
  [16230] = 15200,
  [16231] = 15129,
  [16232] = 15241,
  [16233] = 15097,
  [16234] = 15166,
  [16235] = 16235,
  [16236] = 15457,
  [16237] = 15094,
  [16238] = 15170,
  [16239] = 15241,
  [16240] = 15089,
  [16241] = 15090,
  [16242] = 15199,
  [16243] = 15190,
  [16244] = 15088,
  [16245] = 15240,
  [16246] = 15099,
  [16247] = 15157,
  [16248] = 15143,
  [16249] = 15088,
  [16250] = 15086,
  [16251] = 15156,
  [16252] = 15121,
  [16253] = 15143,
  [16254] = 15119,
  [16255] = 15121,
  [16256] = 15091,
  [16257] = 15096,
  [16258] = 15096,
  [16259] = 15093,
  [16260] = 15097,
  [16261] = 15156,
  [16262] = 15128,
  [16263] = 15112,
  [16264] = 15104,
  [16265] = 15089,
  [16266] = 15116,
  [16267] = 15204,
  [16268] = 15083,
  [16269] = 15163,
  [16270] = 15094,
  [16271] = 15168,
  [16272] = 15117,
  [16273] = 15128,
  [16274] = 15089,
  [16275] = 15091,
  [16276] = 15166,
  [16277] = 15170,
  [16278] = 15496,
  [16279] = 15116,
  [16280] = 15093,
  [16281] = 15091,
  [16282] = 15173,
  [16283] = 15128,
  [16284] = 15173,
  [16285] = 15125,
  [16286] = 15390,
  [16287] = 15093,
  [16288] = 15116,
  [16289] = 15094,
  [16290] = 15107,
  [16291] = 15083,
  [16292] = 15173,
  [16293] = 15170,
  [16294] = 16294,
  [16295] = 15166,
  [16296] = 15127,
  [16297] = 15083,
  [16298] = 16298,
  [16299] = 16175,
  [16300] = 15179,
  [16301] = 15127,
  [16302] = 15179,
  [16303] = 15156,
  [16304] = 15109,
  [16305] = 15496,
  [16306] = 15104,
  [16307] = 15083,
  [16308] = 15104,
  [16309] = 15098,
  [16310] = 15129,
  [16311] = 15096,
  [16312] = 15129,
  [16313] = 15094,
  [16314] = 15129,
  [16315] = 15105,
  [16316] = 15128,
  [16317] = 15097,
  [16318] = 15089,
  [16319] = 15098,
  [16320] = 15086,
  [16321] = 15128,
  [16322] = 15094,
  [16323] = 16323,
  [16324] = 15109,
  [16325] = 15125,
  [16326] = 15098,
  [16327] = 15201,
  [16328] = 15457,
  [16329] = 15202,
  [16330] = 15119,
  [16331] = 15179,
  [16332] = 15121,
  [16333] = 15105,
  [16334] = 15208,
  [16335] = 15127,
  [16336] = 15089,
  [16337] = 15084,
  [16338] = 15098,
  [16339] = 15105,
  [16340] = 15227,
  [16341] = 15088,
  [16342] = 15083,
  [16343] = 15125,
  [16344] = 15143,
  [16345] = 15127,
  [16346] = 15125,
  [16347] = 15202,
  [16348] = 15089,
  [16349] = 15125,
  [16350] = 15095,
  [16351] = 15215,
  [16352] = 15097,
  [16353] = 15208,
  [16354] = 15129,
  [16355] = 15116,
  [16356] = 15127,
  [16357] = 15496,
  [16358] = 15086,
  [16359] = 4903,
  [16360] = 15179,
  [16361] = 15090,
  [16362] = 15214,
  [16363] = 15094,
  [16364] = 15088,
  [16365] = 9916,
  [16366] = 15088,
  [16367] = 15200,
  [16368] = 15098,
  [16369] = 15190,
  [16370] = 15097,
  [16371] = 15157,
  [16372] = 15157,
  [16373] = 15086,
  [16374] = 15090,
  [16375] = 16119,
  [16376] = 15199,
  [16377] = 15223,
  [16378] = 15214,
  [16379] = 15107,
  [16380] = 15223,
  [16381] = 15098,
  [16382] = 15223,
  [16383] = 15214,
  [16384] = 15227,
  [16385] = 15215,
  [16386] = 15109,
  [16387] = 15095,
  [16388] = 16388,
  [16389] = 15099,
  [16390] = 15157,
  [16391] = 15143,
  [16392] = 15088,
  [16393] = 15109,
  [16394] = 15094,
  [16395] = 16119,
  [16396] = 15099,
  [16397] = 15105,
  [16398] = 15105,
  [16399] = 15099,
  [16400] = 15086,
  [16401] = 15248,
  [16402] = 15496,
  [16403] = 15128,
  [16404] = 15096,
  [16405] = 12030,
  [16406] = 15214,
  [16407] = 15128,
  [16408] = 15096,
  [16409] = 15173,
  [16410] = 15170,
  [16411] = 15166,
  [16412] = 15116,
  [16413] = 15201,
  [16414] = 15156,
  [16415] = 15156,
  [16416] = 15111,
  [16417] = 15096,
  [16418] = 15116,
  [16419] = 15109,
  [16420] = 15128,
  [16421] = 15201,
  [16422] = 15166,
  [16423] = 15170,
  [16424] = 15096,
  [16425] = 15083,
  [16426] = 15173,
  [16427] = 15104,
  [16428] = 15128,
  [16429] = 15089,
  [16430] = 15097,
  [16431] = 15127,
  [16432] = 16432,
  [16433] = 15129,
  [16434] = 15116,
  [16435] = 15202,
  [16436] = 15208,
  [16437] = 15086,
  [16438] = 15086,
  [16439] = 15083,
  [16440] = 15084,
  [16441] = 15129,
  [16442] = 15199,
  [16443] = 15295,
  [16444] = 15127,
  [16445] = 15179,
  [16446] = 15094,
  [16447] = 15094,
  [16448] = 15088,
  [16449] = 15104,
  [16450] = 15090,
  [16451] = 15199,
  [16452] = 15295,
  [16453] = 15129,
  [16454] = 15095,
  [16455] = 15097,
  [16456] = 15090,
  [16457] = 15088,
  [16458] = 15143,
  [16459] = 15109,
  [16460] = 15105,
  [16461] = 15090,
  [16462] = 15223,
  [16463] = 15105,
  [16464] = 15089,
  [16465] = 15089,
  [16466] = 15164,
  [16467] = 15157,
  [16468] = 15121,
  [16469] = 15116,
  [16470] = 15215,
  [16471] = 15083,
  [16472] = 15099,
  [16473] = 15097,
  [16474] = 15098,
  [16475] = 15125,
  [16476] = 15119,
  [16477] = 15090,
  [16478] = 12028,
  [16479] = 15199,
  [16480] = 15098,
  [16481] = 15125,
  [16482] = 15109,
  [16483] = 15215,
  [16484] = 15129,
  [16485] = 16485,
  [16486] = 15095,
  [16487] = 15097,
  [16488] = 15200,
  [16489] = 15105,
  [16490] = 15579,
  [16491] = 12051,
  [16492] = 15295,
  [16493] = 15295,
  [16494] = 16494,
  [16495] = 16495,
  [16496] = 16496,
  [16497] = 15599,
  [16498] = 15094,
  [16499] = 15200,
  [16500] = 15091,
  [16501] = 15093,
  [16502] = 15104,
  [16503] = 15179,
  [16504] = 15098,
  [16505] = 15127,
  [16506] = 16506,
  [16507] = 16507,
  [16508] = 16508,
  [16509] = 16509,
  [16510] = 16510,
  [16511] = 16511,
  [16512] = 16512,
  [16513] = 16513,
  [16514] = 16514,
  [16515] = 16515,
  [16516] = 16513,
  [16517] = 16515,
  [16518] = 16514,
  [16519] = 16514,
  [16520] = 16514,
  [16521] = 16521,
  [16522] = 16522,
  [16523] = 16523,
  [16524] = 16524,
  [16525] = 16525,
  [16526] = 16515,
  [16527] = 16521,
  [16528] = 16513,
  [16529] = 16529,
  [16530] = 16530,
  [16531] = 16515,
  [16532] = 16513,
  [16533] = 16514,
  [16534] = 16521,
  [16535] = 16535,
  [16536] = 16536,
  [16537] = 16537,
  [16538] = 16538,
  [16539] = 16521,
  [16540] = 16511,
  [16541] = 16541,
  [16542] = 16542,
  [16543] = 16543,
  [16544] = 16544,
  [16545] = 16545,
  [16546] = 16546,
  [16547] = 16547,
  [16548] = 16548,
  [16549] = 16549,
  [16550] = 16550,
  [16551] = 16551,
  [16552] = 16552,
  [16553] = 16553,
  [16554] = 16554,
  [16555] = 16555,
  [16556] = 16556,
  [16557] = 16514,
  [16558] = 16507,
  [16559] = 16559,
  [16560] = 16560,
  [16561] = 16561,
  [16562] = 16560,
  [16563] = 16563,
  [16564] = 16507,
  [16565] = 16565,
  [16566] = 16556,
  [16567] = 16514,
  [16568] = 16568,
  [16569] = 16555,
  [16570] = 16549,
  [16571] = 16514,
  [16572] = 16572,
  [16573] = 16543,
  [16574] = 16554,
  [16575] = 16536,
  [16576] = 16553,
  [16577] = 16577,
  [16578] = 16578,
  [16579] = 16524,
  [16580] = 16560,
  [16581] = 16522,
  [16582] = 16550,
  [16583] = 16511,
  [16584] = 16584,
  [16585] = 16513,
  [16586] = 16586,
  [16587] = 16587,
  [16588] = 16507,
  [16589] = 16545,
  [16590] = 16544,
  [16591] = 16591,
  [16592] = 16592,
  [16593] = 16593,
  [16594] = 16556,
  [16595] = 16595,
  [16596] = 16554,
  [16597] = 16542,
  [16598] = 16546,
  [16599] = 16553,
  [16600] = 16541,
  [16601] = 16601,
  [16602] = 16602,
  [16603] = 16603,
  [16604] = 16604,
  [16605] = 16605,
  [16606] = 16606,
  [16607] = 16550,
  [16608] = 16608,
  [16609] = 16609,
  [16610] = 16537,
  [16611] = 16611,
  [16612] = 16612,
  [16613] = 16613,
  [16614] = 16515,
  [16615] = 16615,
  [16616] = 16616,
  [16617] = 16546,
  [16618] = 16545,
  [16619] = 16544,
  [16620] = 16620,
  [16621] = 16621,
  [16622] = 16622,
  [16623] = 16623,
  [16624] = 16624,
  [16625] = 16523,
  [16626] = 16626,
  [16627] = 16542,
  [16628] = 16628,
  [16629] = 16629,
  [16630] = 16541,
  [16631] = 16631,
  [16632] = 16632,
  [16633] = 16633,
  [16634] = 16634,
  [16635] = 16635,
  [16636] = 16636,
  [16637] = 16637,
  [16638] = 16638,
  [16639] = 16537,
  [16640] = 16640,
  [16641] = 16506,
  [16642] = 16642,
  [16643] = 16643,
  [16644] = 16644,
  [16645] = 16645,
  [16646] = 10225,
  [16647] = 10496,
  [16648] = 11451,
  [16649] = 16513,
  [16650] = 10353,
  [16651] = 10473,
  [16652] = 16615,
  [16653] = 10255,
  [16654] = 10199,
  [16655] = 16644,
  [16656] = 10234,
  [16657] = 16512,
  [16658] = 16523,
  [16659] = 16525,
  [16660] = 16529,
  [16661] = 16530,
  [16662] = 16538,
  [16663] = 16509,
  [16664] = 16547,
  [16665] = 16552,
  [16666] = 16514,
  [16667] = 16559,
  [16668] = 16565,
  [16669] = 16572,
  [16670] = 16553,
  [16671] = 16577,
  [16672] = 16578,
  [16673] = 16584,
  [16674] = 16513,
  [16675] = 16586,
  [16676] = 16587,
  [16677] = 16595,
  [16678] = 16541,
  [16679] = 16530,
  [16680] = 16603,
  [16681] = 16643,
  [16682] = 16611,
  [16683] = 16611,
  [16684] = 16515,
  [16685] = 16620,
  [16686] = 16621,
  [16687] = 16622,
  [16688] = 16636,
  [16689] = 16640,
  [16690] = 16506,
  [16691] = 16642,
  [16692] = 16530,
  [16693] = 16643,
  [16694] = 16643,
  [16695] = 16645,
  [16696] = 16611,
  [16697] = 16513,
  [16698] = 16644,
  [16699] = 16624,
  [16700] = 16509,
  [16701] = 16525,
  [16702] = 16530,
  [16703] = 16538,
  [16704] = 16552,
  [16705] = 16530,
  [16706] = 16514,
  [16707] = 16643,
  [16708] = 16559,
  [16709] = 16611,
  [16710] = 16565,
  [16711] = 16523,
  [16712] = 16572,
  [16713] = 16577,
  [16714] = 16578,
  [16715] = 16584,
  [16716] = 16513,
  [16717] = 16586,
  [16718] = 16530,
  [16719] = 16587,
  [16720] = 16643,
  [16721] = 16603,
  [16722] = 16611,
  [16723] = 16611,
  [16724] = 16511,
  [16725] = 16620,
  [16726] = 16621,
  [16727] = 16622,
  [16728] = 16624,
  [16729] = 16636,
  [16730] = 16640,
  [16731] = 16506,
  [16732] = 16530,
  [16733] = 16642,
  [16734] = 16643,
  [16735] = 16643,
  [16736] = 16645,
  [16737] = 16611,
  [16738] = 16513,
  [16739] = 16509,
  [16740] = 16523,
  [16741] = 16525,
  [16742] = 16530,
  [16743] = 16538,
  [16744] = 16644,
  [16745] = 16552,
  [16746] = 16514,
  [16747] = 16559,
  [16748] = 16530,
  [16749] = 16565,
  [16750] = 16643,
  [16751] = 16572,
  [16752] = 16611,
  [16753] = 16577,
  [16754] = 16514,
  [16755] = 16578,
  [16756] = 16584,
  [16757] = 16513,
  [16758] = 16586,
  [16759] = 16587,
  [16760] = 16603,
  [16761] = 16611,
  [16762] = 16620,
  [16763] = 16560,
  [16764] = 16621,
  [16765] = 16622,
  [16766] = 16530,
  [16767] = 16624,
  [16768] = 16643,
  [16769] = 16636,
  [16770] = 16507,
  [16771] = 16611,
  [16772] = 16640,
  [16773] = 16506,
  [16774] = 16642,
  [16775] = 16643,
  [16776] = 16556,
  [16777] = 16645,
  [16778] = 16554,
  [16779] = 16513,
  [16780] = 16644,
  [16781] = 16553,
  [16782] = 16525,
  [16783] = 16530,
  [16784] = 16530,
  [16785] = 16538,
  [16786] = 16643,
  [16787] = 16552,
  [16788] = 16550,
  [16789] = 16611,
  [16790] = 16514,
  [16791] = 16565,
  [16792] = 16572,
  [16793] = 16577,
  [16794] = 16578,
  [16795] = 16509,
  [16796] = 16587,
  [16797] = 16512,
  [16798] = 16546,
  [16799] = 16545,
  [16800] = 16544,
  [16801] = 16603,
  [16802] = 16611,
  [16803] = 16620,
  [16804] = 16530,
  [16805] = 16512,
  [16806] = 16621,
  [16807] = 16643,
  [16808] = 16542,
  [16809] = 16622,
  [16810] = 16611,
  [16811] = 16541,
  [16812] = 16624,
  [16813] = 16512,
  [16814] = 16636,
  [16815] = 16640,
  [16816] = 16513,
  [16817] = 16643,
  [16818] = 16512,
  [16819] = 16513,
  [16820] = 16537,
  [16821] = 16644,
  [16822] = 16530,
  [16823] = 16509,
  [16824] = 16643,
  [16825] = 16525,
  [16826] = 16611,
  [16827] = 16538,
  [16828] = 16512,
  [16829] = 16552,
  [16830] = 16514,
  [16831] = 16565,
  [16832] = 16577,
  [16833] = 16578,
  [16834] = 16512,
  [16835] = 16513,
  [16836] = 16587,
  [16837] = 16530,
  [16838] = 16603,
  [16839] = 16530,
  [16840] = 16611,
  [16841] = 16643,
  [16842] = 16512,
  [16843] = 16611,
  [16844] = 16620,
  [16845] = 16622,
  [16846] = 16624,
  [16847] = 16640,
  [16848] = 16506,
  [16849] = 16643,
  [16850] = 16512,
  [16851] = 16513,
  [16852] = 16530,
  [16853] = 16525,
  [16854] = 16643,
  [16855] = 16530,
  [16856] = 16611,
  [16857] = 16538,
  [16858] = 16509,
  [16859] = 16552,
  [16860] = 16514,
  [16861] = 16512,
  [16862] = 16565,
  [16863] = 16633,
  [16864] = 16577,
  [16865] = 16530,
  [16866] = 16578,
  [16867] = 16643,
  [16868] = 16513,
  [16869] = 16611,
  [16870] = 16587,
  [16871] = 16587,
  [16872] = 16608,
  [16873] = 16611,
  [16874] = 16622,
  [16875] = 16624,
  [16876] = 16640,
  [16877] = 16506,
  [16878] = 16643,
  [16879] = 16530,
  [16880] = 16513,
  [16881] = 16643,
  [16882] = 16509,
  [16883] = 16611,
  [16884] = 16525,
  [16885] = 16603,
  [16886] = 16587,
  [16887] = 16538,
  [16888] = 16512,
  [16889] = 16552,
  [16890] = 16514,
  [16891] = 16633,
  [16892] = 16565,
  [16893] = 16608,
  [16894] = 16577,
  [16895] = 16578,
  [16896] = 16513,
  [16897] = 16587,
  [16898] = 16530,
  [16899] = 16530,
  [16900] = 16577,
  [16901] = 16643,
  [16902] = 16511,
  [16903] = 16603,
  [16904] = 16622,
  [16905] = 16640,
  [16906] = 16643,
  [16907] = 16513,
  [16908] = 16611,
  [16909] = 16509,
  [16910] = 16525,
  [16911] = 16611,
  [16912] = 16538,
  [16913] = 16512,
  [16914] = 16552,
  [16915] = 16514,
  [16916] = 16565,
  [16917] = 16577,
  [16918] = 16578,
  [16919] = 16513,
  [16920] = 16587,
  [16921] = 16587,
  [16922] = 16633,
  [16923] = 16603,
  [16924] = 16608,
  [16925] = 16514,
  [16926] = 16611,
  [16927] = 16530,
  [16928] = 16643,
  [16929] = 16513,
  [16930] = 16509,
  [16931] = 16530,
  [16932] = 16538,
  [16933] = 16560,
  [16934] = 16552,
  [16935] = 16507,
  [16936] = 16565,
  [16937] = 16577,
  [16938] = 16578,
  [16939] = 16556,
  [16940] = 16513,
  [16941] = 16554,
  [16942] = 16514,
  [16943] = 16603,
  [16944] = 16611,
  [16945] = 16512,
  [16946] = 16530,
  [16947] = 16507,
  [16948] = 16550,
  [16949] = 16643,
  [16950] = 16507,
  [16951] = 16507,
  [16952] = 16643,
  [16953] = 16507,
  [16954] = 16587,
  [16955] = 16507,
  [16956] = 16509,
  [16957] = 16530,
  [16958] = 16546,
  [16959] = 16545,
  [16960] = 16544,
  [16961] = 16611,
  [16962] = 16507,
  [16963] = 16507,
  [16964] = 16538,
  [16965] = 16507,
  [16966] = 16542,
  [16967] = 16507,
  [16968] = 16507,
  [16969] = 16507,
  [16970] = 16552,
  [16971] = 16507,
  [16972] = 16587,
  [16973] = 16514,
  [16974] = 16507,
  [16975] = 16577,
  [16976] = 16537,
  [16977] = 16507,
  [16978] = 16507,
  [16979] = 16565,
  [16980] = 16507,
  [16981] = 16507,
  [16982] = 16507,
  [16983] = 16577,
  [16984] = 16578,
  [16985] = 16507,
  [16986] = 16513,
  [16987] = 16507,
  [16988] = 16513,
  [16989] = 16507,
  [16990] = 16587,
  [16991] = 16507,
  [16992] = 16507,
  [16993] = 16603,
  [16994] = 16544,
  [16995] = 16545,
  [16996] = 16530,
  [16997] = 16546,
  [16998] = 16643,
  [16999] = 16507,
  [17000] = 16544,
  [17001] = 16545,
  [17002] = 16546,
  [17003] = 16507,
  [17004] = 16611,
  [17005] = 16611,
  [17006] = 16544,
  [17007] = 16545,
  [17008] = 16546,
  [17009] = 16507,
  [17010] = 16544,
  [17011] = 16545,
  [17012] = 16546,
  [17013] = 16587,
  [17014] = 16507,
  [17015] = 16577,
  [17016] = 16544,
  [17017] = 16545,
  [17018] = 16546,
  [17019] = 16507,
  [17020] = 16544,
  [17021] = 16545,
  [17022] = 16546,
  [17023] = 16587,
  [17024] = 16507,
  [17025] = 16544,
  [17026] = 16545,
  [17027] = 16546,
  [17028] = 16507,
  [17029] = 16643,
  [17030] = 16544,
  [17031] = 16530,
  [17032] = 16545,
  [17033] = 16643,
  [17034] = 16546,
  [17035] = 16507,
  [17036] = 16513,
  [17037] = 16511,
  [17038] = 16530,
  [17039] = 16544,
  [17040] = 16611,
  [17041] = 16545,
  [17042] = 16546,
  [17043] = 16507,
  [17044] = 16538,
  [17045] = 16544,
  [17046] = 16545,
  [17047] = 16546,
  [17048] = 16507,
  [17049] = 16544,
  [17050] = 16545,
  [17051] = 16546,
  [17052] = 16507,
  [17053] = 16544,
  [17054] = 16577,
  [17055] = 16545,
  [17056] = 16546,
  [17057] = 16507,
  [17058] = 16552,
  [17059] = 16514,
  [17060] = 16514,
  [17061] = 16544,
  [17062] = 16545,
  [17063] = 16546,
  [17064] = 16507,
  [17065] = 16565,
  [17066] = 16544,
  [17067] = 16560,
  [17068] = 16545,
  [17069] = 16507,
  [17070] = 16546,
  [17071] = 16507,
  [17072] = 16556,
  [17073] = 16577,
  [17074] = 16578,
  [17075] = 16513,
  [17076] = 16509,
  [17077] = 16587,
  [17078] = 16530,
  [17079] = 16550,
  [17080] = 16544,
  [17081] = 16643,
  [17082] = 16545,
  [17083] = 16546,
  [17084] = 16603,
  [17085] = 16611,
  [17086] = 16507,
  [17087] = 16643,
  [17088] = 16544,
  [17089] = 16546,
  [17090] = 16545,
  [17091] = 16544,
  [17092] = 16545,
  [17093] = 16546,
  [17094] = 16611,
  [17095] = 16542,
  [17096] = 16513,
  [17097] = 16509,
  [17098] = 16530,
  [17099] = 16538,
  [17100] = 16507,
  [17101] = 16552,
  [17102] = 16544,
  [17103] = 16545,
  [17104] = 16537,
  [17105] = 16546,
  [17106] = 16587,
  [17107] = 16565,
  [17108] = 16577,
  [17109] = 16507,
  [17110] = 16577,
  [17111] = 16578,
  [17112] = 16587,
  [17113] = 16603,
  [17114] = 16544,
  [17115] = 16545,
  [17116] = 16546,
  [17117] = 16611,
  [17118] = 16514,
  [17119] = 16507,
  [17120] = 16643,
  [17121] = 16513,
  [17122] = 16530,
  [17123] = 16544,
  [17124] = 16545,
  [17125] = 16546,
  [17126] = 16538,
  [17127] = 16507,
  [17128] = 16530,
  [17129] = 16552,
  [17130] = 16643,
  [17131] = 16514,
  [17132] = 16565,
  [17133] = 16537,
  [17134] = 16544,
  [17135] = 16545,
  [17136] = 16546,
  [17137] = 16611,
  [17138] = 16577,
  [17139] = 16578,
  [17140] = 16587,
  [17141] = 16507,
  [17142] = 16603,
  [17143] = 16511,
  [17144] = 16509,
  [17145] = 16611,
  [17146] = 16537,
  [17147] = 16587,
  [17148] = 16643,
  [17149] = 16577,
  [17150] = 16544,
  [17151] = 16545,
  [17152] = 16546,
  [17153] = 16643,
  [17154] = 16565,
  [17155] = 16513,
  [17156] = 16509,
  [17157] = 16507,
  [17158] = 16530,
  [17159] = 16538,
  [17160] = 16552,
  [17161] = 16537,
  [17162] = 16514,
  [17163] = 16544,
  [17164] = 16545,
  [17165] = 16514,
  [17166] = 16546,
  [17167] = 16565,
  [17168] = 16507,
  [17169] = 16577,
  [17170] = 16578,
  [17171] = 16603,
  [17172] = 16537,
  [17173] = 16560,
  [17174] = 16530,
  [17175] = 16507,
  [17176] = 16544,
  [17177] = 16545,
  [17178] = 16546,
  [17179] = 16611,
  [17180] = 16507,
  [17181] = 16643,
  [17182] = 16513,
  [17183] = 16550,
  [17184] = 16509,
  [17185] = 16530,
  [17186] = 16538,
  [17187] = 16611,
  [17188] = 16537,
  [17189] = 16544,
  [17190] = 16545,
  [17191] = 16546,
  [17192] = 16552,
  [17193] = 16546,
  [17194] = 16545,
  [17195] = 16544,
  [17196] = 16514,
  [17197] = 16507,
  [17198] = 16542,
  [17199] = 16565,
  [17200] = 16587,
  [17201] = 16578,
  [17202] = 16587,
  [17203] = 16587,
  [17204] = 16537,
  [17205] = 16577,
  [17206] = 16577,
  [17207] = 16537,
  [17208] = 16544,
  [17209] = 16545,
  [17210] = 16546,
  [17211] = 16565,
  [17212] = 16611,
  [17213] = 16507,
  [17214] = 16643,
  [17215] = 16511,
  [17216] = 16513,
  [17217] = 16509,
  [17218] = 16530,
  [17219] = 16537,
  [17220] = 16538,
  [17221] = 16544,
  [17222] = 16545,
  [17223] = 16546,
  [17224] = 16552,
  [17225] = 16507,
  [17226] = 16603,
  [17227] = 16565,
  [17228] = 16530,
  [17229] = 16511,
  [17230] = 16511,
  [17231] = 16643,
  [17232] = 16577,
  [17233] = 16578,
  [17234] = 16537,
  [17235] = 16587,
  [17236] = 16544,
  [17237] = 16545,
  [17238] = 16546,
  [17239] = 16611,
  [17240] = 16603,
  [17241] = 16507,
  [17242] = 16611,
  [17243] = 16511,
  [17244] = 16643,
  [17245] = 16537,
  [17246] = 16513,
  [17247] = 16509,
  [17248] = 16544,
  [17249] = 16514,
  [17250] = 16587,
  [17251] = 16545,
  [17252] = 16546,
  [17253] = 16577,
  [17254] = 16530,
  [17255] = 16514,
  [17256] = 16538,
  [17257] = 16560,
  [17258] = 16507,
  [17259] = 16507,
  [17260] = 16552,
  [17261] = 16565,
  [17262] = 16514,
  [17263] = 16511,
  [17264] = 16565,
  [17265] = 16537,
  [17266] = 16550,
  [17267] = 16577,
  [17268] = 16578,
  [17269] = 16544,
  [17270] = 16545,
  [17271] = 16546,
  [17272] = 16587,
  [17273] = 16507,
  [17274] = 16603,
  [17275] = 16611,
  [17276] = 16546,
  [17277] = 16545,
  [17278] = 16544,
  [17279] = 16542,
  [17280] = 16511,
  [17281] = 16537,
  [17282] = 16530,
  [17283] = 16544,
  [17284] = 16643,
  [17285] = 16545,
  [17286] = 16546,
  [17287] = 16643,
  [17288] = 16537,
  [17289] = 16513,
  [17290] = 16530,
  [17291] = 16587,
  [17292] = 16507,
  [17293] = 16538,
  [17294] = 16552,
  [17295] = 16514,
  [17296] = 16511,
  [17297] = 16611,
  [17298] = 16537,
  [17299] = 16565,
  [17300] = 16544,
  [17301] = 16545,
  [17302] = 16546,
  [17303] = 16577,
  [17304] = 16578,
  [17305] = 16507,
  [17306] = 16587,
  [17307] = 16509,
  [17308] = 16577,
  [17309] = 16511,
  [17310] = 16603,
  [17311] = 16511,
  [17312] = 16611,
  [17313] = 16565,
  [17314] = 16537,
  [17315] = 16587,
  [17316] = 16544,
  [17317] = 16545,
  [17318] = 16546,
  [17319] = 16643,
  [17320] = 16513,
  [17321] = 16507,
  [17322] = 16509,
  [17323] = 16530,
  [17324] = 16538,
  [17325] = 16511,
  [17326] = 16552,
  [17327] = 16514,
  [17328] = 16514,
  [17329] = 16530,
  [17330] = 16537,
  [17331] = 16544,
  [17332] = 16643,
  [17333] = 16545,
  [17334] = 16546,
  [17335] = 16565,
  [17336] = 16577,
  [17337] = 16507,
  [17338] = 16507,
  [17339] = 16578,
  [17340] = 16587,
  [17341] = 16603,
  [17342] = 16611,
  [17343] = 16511,
  [17344] = 16550,
  [17345] = 16537,
  [17346] = 16611,
  [17347] = 16544,
  [17348] = 16545,
  [17349] = 16546,
  [17350] = 16507,
  [17351] = 16643,
  [17352] = 16513,
  [17353] = 16509,
  [17354] = 16546,
  [17355] = 16545,
  [17356] = 16544,
  [17357] = 16542,
  [17358] = 16538,
  [17359] = 16511,
  [17360] = 16537,
  [17361] = 16577,
  [17362] = 16552,
  [17363] = 16544,
  [17364] = 16545,
  [17365] = 16546,
  [17366] = 16537,
  [17367] = 16565,
  [17368] = 16514,
  [17369] = 16550,
  [17370] = 16565,
  [17371] = 16507,
  [17372] = 16577,
  [17373] = 16578,
  [17374] = 16587,
  [17375] = 16511,
  [17376] = 16530,
  [17377] = 16537,
  [17378] = 16611,
  [17379] = 16544,
  [17380] = 16545,
  [17381] = 16546,
  [17382] = 16550,
  [17383] = 16643,
  [17384] = 16530,
  [17385] = 16513,
  [17386] = 16643,
  [17387] = 16511,
  [17388] = 16509,
  [17389] = 16507,
  [17390] = 16530,
  [17391] = 16538,
  [17392] = 16552,
  [17393] = 16514,
  [17394] = 16611,
  [17395] = 16511,
  [17396] = 16565,
  [17397] = 16537,
  [17398] = 16577,
  [17399] = 16578,
  [17400] = 16544,
  [17401] = 16545,
  [17402] = 16546,
  [17403] = 16587,
  [17404] = 16603,
  [17405] = 16587,
  [17406] = 16514,
  [17407] = 16550,
  [17408] = 16507,
  [17409] = 16577,
  [17410] = 16611,
  [17411] = 16643,
  [17412] = 16513,
  [17413] = 16511,
  [17414] = 16509,
  [17415] = 16507,
  [17416] = 16565,
  [17417] = 16530,
  [17418] = 16538,
  [17419] = 16537,
  [17420] = 16514,
  [17421] = 16544,
  [17422] = 16550,
  [17423] = 16545,
  [17424] = 16546,
  [17425] = 16565,
  [17426] = 16550,
  [17427] = 16577,
  [17428] = 16507,
  [17429] = 16587,
  [17430] = 16538,
  [17431] = 16603,
  [17432] = 16546,
  [17433] = 16545,
  [17434] = 16544,
  [17435] = 16542,
  [17436] = 16530,
  [17437] = 16603,
  [17438] = 16530,
  [17439] = 16611,
  [17440] = 16643,
  [17441] = 16511,
  [17442] = 16643,
  [17443] = 16537,
  [17444] = 16537,
  [17445] = 16513,
  [17446] = 16509,
  [17447] = 16530,
  [17448] = 16538,
  [17449] = 16544,
  [17450] = 16545,
  [17451] = 16546,
  [17452] = 16550,
  [17453] = 16611,
  [17454] = 16514,
  [17455] = 16507,
  [17456] = 16565,
  [17457] = 16577,
  [17458] = 16511,
  [17459] = 16587,
  [17460] = 16611,
  [17461] = 16537,
  [17462] = 16587,
  [17463] = 16643,
  [17464] = 16544,
  [17465] = 16511,
  [17466] = 16577,
  [17467] = 16545,
  [17468] = 16546,
  [17469] = 16513,
  [17470] = 16565,
  [17471] = 16530,
  [17472] = 16550,
  [17473] = 16538,
  [17474] = 16507,
  [17475] = 16514,
  [17476] = 16565,
  [17477] = 16577,
  [17478] = 16511,
  [17479] = 16587,
  [17480] = 16537,
  [17481] = 16611,
  [17482] = 16544,
  [17483] = 16538,
  [17484] = 16514,
  [17485] = 16545,
  [17486] = 16546,
  [17487] = 16550,
  [17488] = 16643,
  [17489] = 16513,
  [17490] = 16530,
  [17491] = 16507,
  [17492] = 16507,
  [17493] = 16643,
  [17494] = 16538,
  [17495] = 16514,
  [17496] = 16511,
  [17497] = 16565,
  [17498] = 16577,
  [17499] = 16550,
  [17500] = 16537,
  [17501] = 16611,
  [17502] = 16587,
  [17503] = 16544,
  [17504] = 16545,
  [17505] = 16546,
  [17506] = 16565,
  [17507] = 16611,
  [17508] = 16550,
  [17509] = 16546,
  [17510] = 16545,
  [17511] = 16544,
  [17512] = 16542,
  [17513] = 16507,
  [17514] = 16643,
  [17515] = 16513,
  [17516] = 16530,
  [17517] = 16587,
  [17518] = 16538,
  [17519] = 16511,
  [17520] = 16514,
  [17521] = 16537,
  [17522] = 16577,
  [17523] = 16537,
  [17524] = 16565,
  [17525] = 16577,
  [17526] = 16544,
  [17527] = 16545,
  [17528] = 16546,
  [17529] = 16587,
  [17530] = 16565,
  [17531] = 16550,
  [17532] = 16507,
  [17533] = 16611,
  [17534] = 16643,
  [17535] = 16513,
  [17536] = 16530,
  [17537] = 16511,
  [17538] = 16538,
  [17539] = 16511,
  [17540] = 16537,
  [17541] = 16514,
  [17542] = 16538,
  [17543] = 16544,
  [17544] = 16545,
  [17545] = 16530,
  [17546] = 16513,
  [17547] = 16546,
  [17548] = 16577,
  [17549] = 16643,
  [17550] = 16550,
  [17551] = 16587,
  [17552] = 16565,
  [17553] = 16507,
  [17554] = 16611,
  [17555] = 16511,
  [17556] = 16611,
  [17557] = 16514,
  [17558] = 16643,
  [17559] = 16513,
  [17560] = 16530,
  [17561] = 16537,
  [17562] = 16514,
  [17563] = 16643,
  [17564] = 16577,
  [17565] = 16507,
  [17566] = 16546,
  [17567] = 16537,
  [17568] = 16511,
  [17569] = 16545,
  [17570] = 16587,
  [17571] = 16544,
  [17572] = 16550,
  [17573] = 16587,
  [17574] = 16577,
  [17575] = 16565,
  [17576] = 16611,
  [17577] = 16514,
  [17578] = 16550,
  [17579] = 16538,
  [17580] = 16565,
  [17581] = 16542,
  [17582] = 16546,
  [17583] = 16545,
  [17584] = 16544,
  [17585] = 16542,
  [17586] = 16538,
  [17587] = 16530,
  [17588] = 16513,
  [17589] = 17589,
  [17590] = 17590,
  [17591] = 17591,
  [17592] = 17592,
  [17593] = 17593,
  [17594] = 17594,
  [17595] = 17595,
  [17596] = 17592,
  [17597] = 17597,
  [17598] = 17598,
  [17599] = 17599,
  [17600] = 17600,
  [17601] = 17601,
  [17602] = 17602,
  [17603] = 17603,
  [17604] = 17604,
  [17605] = 17605,
  [17606] = 17606,
  [17607] = 17607,
  [17608] = 17608,
  [17609] = 17609,
  [17610] = 17610,
  [17611] = 17611,
  [17612] = 17612,
  [17613] = 17613,
  [17614] = 17614,
  [17615] = 17615,
  [17616] = 17616,
  [17617] = 17617,
  [17618] = 17618,
  [17619] = 17619,
  [17620] = 17620,
  [17621] = 17590,
  [17622] = 17622,
  [17623] = 17623,
  [17624] = 17624,
  [17625] = 17625,
  [17626] = 17626,
  [17627] = 17627,
  [17628] = 17628,
  [17629] = 17629,
  [17630] = 17630,
  [17631] = 17631,
  [17632] = 17589,
  [17633] = 17633,
  [17634] = 17593,
  [17635] = 17594,
  [17636] = 17595,
  [17637] = 17595,
  [17638] = 17597,
  [17639] = 17639,
  [17640] = 17640,
  [17641] = 17591,
  [17642] = 17598,
  [17643] = 17600,
  [17644] = 17602,
  [17645] = 17603,
  [17646] = 17605,
  [17647] = 17606,
  [17648] = 17607,
  [17649] = 17599,
  [17650] = 17601,
  [17651] = 17608,
  [17652] = 17609,
  [17653] = 17604,
  [17654] = 17611,
  [17655] = 17612,
  [17656] = 17613,
  [17657] = 17614,
  [17658] = 17615,
  [17659] = 17610,
  [17660] = 17620,
  [17661] = 17627,
  [17662] = 17590,
  [17663] = 17589,
  [17664] = 17630,
  [17665] = 17622,
  [17666] = 17616,
  [17667] = 17617,
  [17668] = 17618,
  [17669] = 17619,
  [17670] = 17639,
  [17671] = 17623,
  [17672] = 17633,
  [17673] = 17624,
  [17674] = 17625,
  [17675] = 17626,
  [17676] = 17627,
  [17677] = 17628,
  [17678] = 17631,
  [17679] = 17628,
  [17680] = 17629,
  [17681] = 17630,
  [17682] = 17589,
  [17683] = 17633,
  [17684] = 17593,
  [17685] = 17639,
  [17686] = 17640,
  [17687] = 17591,
  [17688] = 17594,
  [17689] = 17606,
  [17690] = 17626,
  [17691] = 17592,
  [17692] = 17625,
  [17693] = 17597,
  [17694] = 17598,
  [17695] = 17624,
  [17696] = 17623,
  [17697] = 17600,
  [17698] = 17599,
  [17699] = 17601,
  [17700] = 17602,
  [17701] = 17603,
  [17702] = 17612,
  [17703] = 17604,
  [17704] = 17631,
  [17705] = 17622,
  [17706] = 17590,
  [17707] = 17605,
  [17708] = 17606,
  [17709] = 17607,
  [17710] = 17608,
  [17711] = 17620,
  [17712] = 17609,
  [17713] = 17610,
  [17714] = 17611,
  [17715] = 17615,
  [17716] = 17612,
  [17717] = 17613,
  [17718] = 17614,
  [17719] = 17615,
  [17720] = 17616,
  [17721] = 17617,
  [17722] = 17618,
  [17723] = 17619,
  [17724] = 17614,
  [17725] = 17620,
  [17726] = 17613,
  [17727] = 17590,
  [17728] = 17612,
  [17729] = 17611,
  [17730] = 17622,
  [17731] = 17609,
  [17732] = 17631,
  [17733] = 17623,
  [17734] = 17624,
  [17735] = 17625,
  [17736] = 17626,
  [17737] = 17627,
  [17738] = 17628,
  [17739] = 17639,
  [17740] = 17640,
  [17741] = 17591,
  [17742] = 17608,
  [17743] = 17607,
  [17744] = 17629,
  [17745] = 17630,
  [17746] = 17589,
  [17747] = 17633,
  [17748] = 17593,
  [17749] = 17629,
  [17750] = 17594,
  [17751] = 17595,
  [17752] = 17599,
  [17753] = 17601,
  [17754] = 17592,
  [17755] = 17605,
  [17756] = 17597,
  [17757] = 17604,
  [17758] = 17619,
  [17759] = 17618,
  [17760] = 17617,
  [17761] = 17598,
  [17762] = 17616,
  [17763] = 17600,
  [17764] = 17602,
  [17765] = 17603,
  [17766] = 17603,
  [17767] = 17610,
  [17768] = 17605,
  [17769] = 17602,
  [17770] = 17606,
  [17771] = 17607,
  [17772] = 17608,
  [17773] = 17600,
  [17774] = 17616,
  [17775] = 17617,
  [17776] = 17618,
  [17777] = 17619,
  [17778] = 17609,
  [17779] = 17611,
  [17780] = 17598,
  [17781] = 17592,
  [17782] = 17613,
  [17783] = 17614,
  [17784] = 17615,
  [17785] = 17610,
  [17786] = 17631,
  [17787] = 17620,
  [17788] = 17590,
  [17789] = 17597,
  [17790] = 17592,
  [17791] = 17622,
  [17792] = 17595,
  [17793] = 17639,
  [17794] = 17640,
  [17795] = 17591,
  [17796] = 17623,
  [17797] = 17594,
  [17798] = 17624,
  [17799] = 17625,
  [17800] = 17626,
  [17801] = 17627,
  [17802] = 17628,
  [17803] = 17593,
  [17804] = 17604,
  [17805] = 17629,
  [17806] = 17599,
  [17807] = 17601,
  [17808] = 17630,
  [17809] = 17589,
  [17810] = 17633,
  [17811] = 17604,
  [17812] = 17633,
  [17813] = 17630,
  [17814] = 17601,
  [17815] = 17593,
  [17816] = 17594,
  [17817] = 17595,
  [17818] = 17622,
  [17819] = 17593,
  [17820] = 17597,
  [17821] = 17610,
  [17822] = 17598,
  [17823] = 17599,
  [17824] = 17628,
  [17825] = 17600,
  [17826] = 17602,
  [17827] = 17603,
  [17828] = 17616,
  [17829] = 17617,
  [17830] = 17618,
  [17831] = 17619,
  [17832] = 17627,
  [17833] = 17605,
  [17834] = 17626,
  [17835] = 17606,
  [17836] = 17607,
  [17837] = 17608,
  [17838] = 17625,
  [17839] = 17609,
  [17840] = 17631,
  [17841] = 17611,
  [17842] = 17612,
  [17843] = 17613,
  [17844] = 17614,
  [17845] = 17615,
  [17846] = 17624,
  [17847] = 17639,
  [17848] = 17640,
  [17849] = 17591,
  [17850] = 17620,
  [17851] = 17623,
  [17852] = 17590,
  [17853] = 17622,
  [17854] = 17591,
  [17855] = 17589,
  [17856] = 17640,
  [17857] = 17629,
  [17858] = 17623,
  [17859] = 17624,
  [17860] = 17599,
  [17861] = 17601,
  [17862] = 17625,
  [17863] = 17626,
  [17864] = 17627,
  [17865] = 17604,
  [17866] = 17590,
  [17867] = 17639,
  [17868] = 17620,
  [17869] = 17628,
  [17870] = 17615,
  [17871] = 17629,
  [17872] = 17630,
  [17873] = 17589,
  [17874] = 17633,
  [17875] = 17610,
  [17876] = 17593,
  [17877] = 17614,
  [17878] = 17594,
  [17879] = 17595,
  [17880] = 17592,
  [17881] = 17613,
  [17882] = 17616,
  [17883] = 17617,
  [17884] = 17618,
  [17885] = 17619,
  [17886] = 17597,
  [17887] = 17598,
  [17888] = 17612,
  [17889] = 17611,
  [17890] = 17600,
  [17891] = 17602,
  [17892] = 17603,
  [17893] = 17893,
  [17894] = 17631,
  [17895] = 17605,
  [17896] = 17606,
  [17897] = 17607,
  [17898] = 17608,
  [17899] = 17609,
  [17900] = 17609,
  [17901] = 17639,
  [17902] = 17640,
  [17903] = 17591,
  [17904] = 17611,
  [17905] = 17608,
  [17906] = 17612,
  [17907] = 17613,
  [17908] = 17614,
  [17909] = 17615,
  [17910] = 17631,
  [17911] = 17607,
  [17912] = 17620,
  [17913] = 17590,
  [17914] = 17599,
  [17915] = 17601,
  [17916] = 17606,
  [17917] = 17605,
  [17918] = 17622,
  [17919] = 17604,
  [17920] = 17603,
  [17921] = 17602,
  [17922] = 17600,
  [17923] = 17598,
  [17924] = 17623,
  [17925] = 17624,
  [17926] = 17625,
  [17927] = 17626,
  [17928] = 17627,
  [17929] = 17610,
  [17930] = 17628,
  [17931] = 17597,
  [17932] = 17592,
  [17933] = 17629,
  [17934] = 17630,
  [17935] = 17595,
  [17936] = 17616,
  [17937] = 17617,
  [17938] = 17618,
  [17939] = 17619,
  [17940] = 17633,
  [17941] = 17593,
  [17942] = 17594,
  [17943] = 17594,
  [17944] = 17595,
  [17945] = 17592,
  [17946] = 17592,
  [17947] = 17597,
  [17948] = 17631,
  [17949] = 17598,
  [17950] = 17639,
  [17951] = 17600,
  [17952] = 17602,
  [17953] = 17603,
  [17954] = 17633,
  [17955] = 17639,
  [17956] = 17640,
  [17957] = 17591,
  [17958] = 17605,
  [17959] = 17589,
  [17960] = 17606,
  [17961] = 17607,
  [17962] = 17608,
  [17963] = 17630,
  [17964] = 17609,
  [17965] = 17629,
  [17966] = 17611,
  [17967] = 17612,
  [17968] = 17599,
  [17969] = 17601,
  [17970] = 17613,
  [17971] = 17614,
  [17972] = 17615,
  [17973] = 17604,
  [17974] = 17619,
  [17975] = 17618,
  [17976] = 17617,
  [17977] = 17616,
  [17978] = 17620,
  [17979] = 17590,
  [17980] = 17628,
  [17981] = 17627,
  [17982] = 17626,
  [17983] = 17610,
  [17984] = 17622,
  [17985] = 17625,
  [17986] = 17624,
  [17987] = 17623,
  [17988] = 17624,
  [17989] = 17625,
  [17990] = 17616,
  [17991] = 17617,
  [17992] = 17618,
  [17993] = 17619,
  [17994] = 17626,
  [17995] = 17627,
  [17996] = 17610,
  [17997] = 17628,
  [17998] = 17623,
  [17999] = 17629,
  [18000] = 17630,
  [18001] = 17589,
  [18002] = 17631,
  [18003] = 17633,
  [18004] = 17593,
  [18005] = 17622,
  [18006] = 17594,
  [18007] = 17595,
  [18008] = 17590,
  [18009] = 17639,
  [18010] = 17640,
  [18011] = 17591,
  [18012] = 17604,
  [18013] = 17615,
  [18014] = 17597,
  [18015] = 17598,
  [18016] = 17614,
  [18017] = 17600,
  [18018] = 17602,
  [18019] = 17601,
  [18020] = 17603,
  [18021] = 17613,
  [18022] = 17599,
  [18023] = 17601,
  [18024] = 17605,
  [18025] = 17606,
  [18026] = 17607,
  [18027] = 17604,
  [18028] = 17599,
  [18029] = 17612,
  [18030] = 17611,
  [18031] = 17608,
  [18032] = 17609,
  [18033] = 17609,
  [18034] = 17611,
  [18035] = 17612,
  [18036] = 17613,
  [18037] = 17610,
  [18038] = 17614,
  [18039] = 17620,
  [18040] = 17615,
  [18041] = 17607,
  [18042] = 17620,
  [18043] = 17590,
  [18044] = 17616,
  [18045] = 17617,
  [18046] = 17618,
  [18047] = 17619,
  [18048] = 17606,
  [18049] = 17605,
  [18050] = 17603,
  [18051] = 17602,
  [18052] = 17622,
  [18053] = 17591,
  [18054] = 18054,
  [18055] = 17623,
  [18056] = 17631,
  [18057] = 17624,
  [18058] = 17625,
  [18059] = 17626,
  [18060] = 17627,
  [18061] = 18061,
  [18062] = 17628,
  [18063] = 17639,
  [18064] = 17640,
  [18065] = 17591,
  [18066] = 17640,
  [18067] = 17600,
  [18068] = 17629,
  [18069] = 17630,
  [18070] = 17589,
  [18071] = 17633,
  [18072] = 17593,
  [18073] = 17592,
  [18074] = 17592,
  [18075] = 17594,
  [18076] = 17599,
  [18077] = 17601,
  [18078] = 17595,
  [18079] = 17598,
  [18080] = 17592,
  [18081] = 17604,
  [18082] = 17595,
  [18083] = 17594,
  [18084] = 17593,
  [18085] = 17597,
  [18086] = 17598,
  [18087] = 18087,
  [18088] = 17633,
  [18089] = 17893,
  [18090] = 17600,
  [18091] = 17610,
  [18092] = 17602,
  [18093] = 17589,
  [18094] = 17603,
  [18095] = 17630,
  [18096] = 17605,
  [18097] = 17606,
  [18098] = 17616,
  [18099] = 17617,
  [18100] = 17618,
  [18101] = 17619,
  [18102] = 17607,
  [18103] = 17608,
  [18104] = 17631,
  [18105] = 17629,
  [18106] = 17609,
  [18107] = 17628,
  [18108] = 17611,
  [18109] = 17612,
  [18110] = 17631,
  [18111] = 17613,
  [18112] = 17614,
  [18113] = 17615,
  [18114] = 17627,
  [18115] = 17620,
  [18116] = 17590,
  [18117] = 17639,
  [18118] = 17640,
  [18119] = 17591,
  [18120] = 17626,
  [18121] = 17625,
  [18122] = 17624,
  [18123] = 17623,
  [18124] = 17622,
  [18125] = 17622,
  [18126] = 18054,
  [18127] = 17590,
  [18128] = 17623,
  [18129] = 17624,
  [18130] = 17599,
  [18131] = 17601,
  [18132] = 17625,
  [18133] = 17626,
  [18134] = 17627,
  [18135] = 17604,
  [18136] = 17620,
  [18137] = 17615,
  [18138] = 17614,
  [18139] = 18061,
  [18140] = 17628,
  [18141] = 17613,
  [18142] = 17629,
  [18143] = 17630,
  [18144] = 17610,
  [18145] = 17589,
  [18146] = 17612,
  [18147] = 17633,
  [18148] = 17593,
  [18149] = 17611,
  [18150] = 17594,
  [18151] = 17616,
  [18152] = 17617,
  [18153] = 17618,
  [18154] = 17619,
  [18155] = 17595,
  [18156] = 17592,
  [18157] = 17609,
  [18158] = 17608,
  [18159] = 17597,
  [18160] = 17598,
  [18161] = 18087,
  [18162] = 17619,
  [18163] = 17631,
  [18164] = 17618,
  [18165] = 17600,
  [18166] = 17602,
  [18167] = 17639,
  [18168] = 17640,
  [18169] = 17591,
  [18170] = 17603,
  [18171] = 17617,
  [18172] = 17616,
  [18173] = 17605,
  [18174] = 17607,
  [18175] = 17606,
  [18176] = 17607,
  [18177] = 17599,
  [18178] = 17601,
  [18179] = 17608,
  [18180] = 17606,
  [18181] = 17609,
  [18182] = 17604,
  [18183] = 17605,
  [18184] = 17603,
  [18185] = 17610,
  [18186] = 17602,
  [18187] = 17610,
  [18188] = 17611,
  [18189] = 17600,
  [18190] = 17612,
  [18191] = 17613,
  [18192] = 17614,
  [18193] = 17616,
  [18194] = 17617,
  [18195] = 17618,
  [18196] = 17619,
  [18197] = 17615,
  [18198] = 17598,
  [18199] = 17608,
  [18200] = 17620,
  [18201] = 17590,
  [18202] = 17630,
  [18203] = 17600,
  [18204] = 17631,
  [18205] = 17604,
  [18206] = 17622,
  [18207] = 17595,
  [18208] = 17639,
  [18209] = 17640,
  [18210] = 17591,
  [18211] = 18054,
  [18212] = 17594,
  [18213] = 17623,
  [18214] = 17624,
  [18215] = 17625,
  [18216] = 17626,
  [18217] = 17599,
  [18218] = 17601,
  [18219] = 17627,
  [18220] = 18061,
  [18221] = 17628,
  [18222] = 17604,
  [18223] = 17593,
  [18224] = 17601,
  [18225] = 17633,
  [18226] = 17599,
  [18227] = 17610,
  [18228] = 17629,
  [18229] = 17589,
  [18230] = 17627,
  [18231] = 17589,
  [18232] = 17633,
  [18233] = 17616,
  [18234] = 17617,
  [18235] = 17618,
  [18236] = 17619,
  [18237] = 17593,
  [18238] = 17630,
  [18239] = 17629,
  [18240] = 17594,
  [18241] = 17595,
  [18242] = 17592,
  [18243] = 17628,
  [18244] = 17631,
  [18245] = 17597,
  [18246] = 17598,
  [18247] = 18087,
  [18248] = 17639,
  [18249] = 17640,
  [18250] = 17591,
  [18251] = 17627,
  [18252] = 17626,
  [18253] = 17625,
  [18254] = 17600,
  [18255] = 17602,
  [18256] = 17603,
  [18257] = 17599,
  [18258] = 17601,
  [18259] = 17624,
  [18260] = 17605,
  [18261] = 17606,
  [18262] = 17604,
  [18263] = 17623,
  [18264] = 17591,
  [18265] = 17640,
  [18266] = 17607,
  [18267] = 17610,
  [18268] = 17608,
  [18269] = 17622,
  [18270] = 17639,
  [18271] = 17609,
  [18272] = 17590,
  [18273] = 17616,
  [18274] = 17617,
  [18275] = 17618,
  [18276] = 17619,
  [18277] = 17611,
  [18278] = 17620,
  [18279] = 17612,
  [18280] = 17613,
  [18281] = 17614,
  [18282] = 17615,
  [18283] = 17615,
  [18284] = 17631,
  [18285] = 17620,
  [18286] = 17590,
  [18287] = 17614,
  [18288] = 17639,
  [18289] = 17640,
  [18290] = 17591,
  [18291] = 17613,
  [18292] = 17612,
  [18293] = 17893,
  [18294] = 17622,
  [18295] = 17611,
  [18296] = 18054,
  [18297] = 17599,
  [18298] = 17601,
  [18299] = 17623,
  [18300] = 17624,
  [18301] = 17625,
  [18302] = 17604,
  [18303] = 17609,
  [18304] = 17631,
  [18305] = 17608,
  [18306] = 17626,
  [18307] = 17610,
  [18308] = 17607,
  [18309] = 17606,
  [18310] = 18061,
  [18311] = 17628,
  [18312] = 17605,
  [18313] = 17616,
  [18314] = 17617,
  [18315] = 17618,
  [18316] = 17619,
  [18317] = 17629,
  [18318] = 17603,
  [18319] = 17630,
  [18320] = 17589,
  [18321] = 17633,
  [18322] = 17593,
  [18323] = 17602,
  [18324] = 17631,
  [18325] = 17594,
  [18326] = 17595,
  [18327] = 17592,
  [18328] = 17639,
  [18329] = 17640,
  [18330] = 17591,
  [18331] = 17620,
  [18332] = 17598,
  [18333] = 17597,
  [18334] = 17598,
  [18335] = 18087,
  [18336] = 17592,
  [18337] = 17599,
  [18338] = 17601,
  [18339] = 17595,
  [18340] = 17600,
  [18341] = 17602,
  [18342] = 17604,
  [18343] = 17594,
  [18344] = 17593,
  [18345] = 17633,
  [18346] = 17603,
  [18347] = 17610,
  [18348] = 17589,
  [18349] = 17630,
  [18350] = 17605,
  [18351] = 17606,
  [18352] = 17607,
  [18353] = 17616,
  [18354] = 17617,
  [18355] = 17618,
  [18356] = 17619,
  [18357] = 17608,
  [18358] = 17629,
  [18359] = 17619,
  [18360] = 17609,
  [18361] = 17618,
  [18362] = 17611,
  [18363] = 17612,
  [18364] = 17631,
  [18365] = 17613,
  [18366] = 17614,
  [18367] = 17615,
  [18368] = 17639,
  [18369] = 17640,
  [18370] = 17591,
  [18371] = 17617,
  [18372] = 17616,
  [18373] = 17620,
  [18374] = 17590,
  [18375] = 17628,
  [18376] = 17620,
  [18377] = 17599,
  [18378] = 17601,
  [18379] = 17626,
  [18380] = 17622,
  [18381] = 17625,
  [18382] = 17604,
  [18383] = 17624,
  [18384] = 17610,
  [18385] = 17623,
  [18386] = 18054,
  [18387] = 17610,
  [18388] = 17623,
  [18389] = 17622,
  [18390] = 17624,
  [18391] = 17625,
  [18392] = 17626,
  [18393] = 17616,
  [18394] = 17617,
  [18395] = 17618,
  [18396] = 17619,
  [18397] = 17627,
  [18398] = 17590,
  [18399] = 18061,
  [18400] = 17628,
  [18401] = 17600,
  [18402] = 17629,
  [18403] = 17630,
  [18404] = 17631,
  [18405] = 17589,
  [18406] = 17633,
  [18407] = 17593,
  [18408] = 17639,
  [18409] = 17640,
  [18410] = 17591,
  [18411] = 17604,
  [18412] = 17615,
  [18413] = 17594,
  [18414] = 17595,
  [18415] = 17592,
  [18416] = 17614,
  [18417] = 17599,
  [18418] = 17601,
  [18419] = 17597,
  [18420] = 17598,
  [18421] = 18087,
  [18422] = 17604,
  [18423] = 17613,
  [18424] = 17601,
  [18425] = 17612,
  [18426] = 17599,
  [18427] = 17610,
  [18428] = 17611,
  [18429] = 17609,
  [18430] = 17600,
  [18431] = 17602,
  [18432] = 17603,
  [18433] = 17616,
  [18434] = 17617,
  [18435] = 17618,
  [18436] = 17619,
  [18437] = 17608,
  [18438] = 17607,
  [18439] = 17605,
  [18440] = 17606,
  [18441] = 17607,
  [18442] = 17608,
  [18443] = 17606,
  [18444] = 17631,
  [18445] = 17609,
  [18446] = 17605,
  [18447] = 17611,
  [18448] = 17639,
  [18449] = 17640,
  [18450] = 17591,
  [18451] = 17612,
  [18452] = 17603,
  [18453] = 17613,
  [18454] = 17614,
  [18455] = 17615,
  [18456] = 17602,
  [18457] = 17599,
  [18458] = 17601,
  [18459] = 17590,
  [18460] = 17602,
  [18461] = 17591,
  [18462] = 17604,
  [18463] = 17640,
  [18464] = 17598,
  [18465] = 17639,
  [18466] = 17592,
  [18467] = 17610,
  [18468] = 17595,
  [18469] = 17594,
  [18470] = 17622,
  [18471] = 17593,
  [18472] = 18054,
  [18473] = 17616,
  [18474] = 17617,
  [18475] = 17618,
  [18476] = 17619,
  [18477] = 17623,
  [18478] = 17633,
  [18479] = 17624,
  [18480] = 17625,
  [18481] = 17626,
  [18482] = 17627,
  [18483] = 18061,
  [18484] = 17631,
  [18485] = 17628,
  [18486] = 17589,
  [18487] = 17629,
  [18488] = 17639,
  [18489] = 17640,
  [18490] = 17591,
  [18491] = 17630,
  [18492] = 17893,
  [18493] = 17589,
  [18494] = 17633,
  [18495] = 17593,
  [18496] = 17630,
  [18497] = 17599,
  [18498] = 17601,
  [18499] = 17594,
  [18500] = 17595,
  [18501] = 17592,
  [18502] = 17604,
  [18503] = 17629,
  [18504] = 17631,
  [18505] = 17628,
  [18506] = 17627,
  [18507] = 17610,
  [18508] = 17597,
  [18509] = 17626,
  [18510] = 17598,
  [18511] = 18087,
  [18512] = 17625,
  [18513] = 17616,
  [18514] = 17617,
  [18515] = 17618,
  [18516] = 17619,
  [18517] = 17624,
  [18518] = 17623,
  [18519] = 17600,
  [18520] = 17602,
  [18521] = 17603,
  [18522] = 17622,
  [18523] = 17605,
  [18524] = 17631,
  [18525] = 17606,
  [18526] = 17607,
  [18527] = 17608,
  [18528] = 17639,
  [18529] = 17640,
  [18530] = 17591,
  [18531] = 17590,
  [18532] = 17620,
  [18533] = 17609,
  [18534] = 17615,
  [18535] = 17611,
  [18536] = 17612,
  [18537] = 17599,
  [18538] = 17601,
  [18539] = 17613,
  [18540] = 17614,
  [18541] = 17615,
  [18542] = 17604,
  [18543] = 17614,
  [18544] = 17613,
  [18545] = 17612,
  [18546] = 17627,
  [18547] = 17610,
  [18548] = 17620,
  [18549] = 17609,
  [18550] = 17590,
  [18551] = 17608,
  [18552] = 17607,
  [18553] = 17616,
  [18554] = 17617,
  [18555] = 17618,
  [18556] = 17619,
  [18557] = 17606,
  [18558] = 17605,
  [18559] = 17622,
  [18560] = 17619,
  [18561] = 18054,
  [18562] = 17623,
  [18563] = 17624,
  [18564] = 17631,
  [18565] = 17625,
  [18566] = 17626,
  [18567] = 17627,
  [18568] = 17639,
  [18569] = 17640,
  [18570] = 17591,
  [18571] = 18061,
  [18572] = 17618,
  [18573] = 17628,
  [18574] = 17617,
  [18575] = 17629,
  [18576] = 17630,
  [18577] = 17599,
  [18578] = 17601,
  [18579] = 17589,
  [18580] = 17633,
  [18581] = 17593,
  [18582] = 17604,
  [18583] = 17616,
  [18584] = 17603,
  [18585] = 17608,
  [18586] = 17600,
  [18587] = 17610,
  [18588] = 17594,
  [18589] = 17610,
  [18590] = 17595,
  [18591] = 17592,
  [18592] = 17598,
  [18593] = 17616,
  [18594] = 17617,
  [18595] = 17618,
  [18596] = 17619,
  [18597] = 17597,
  [18598] = 17598,
  [18599] = 18087,
  [18600] = 17592,
  [18601] = 17595,
  [18602] = 17600,
  [18603] = 17631,
  [18604] = 17602,
  [18605] = 17603,
  [18606] = 17594,
  [18607] = 17639,
  [18608] = 17640,
  [18609] = 17591,
  [18610] = 17605,
  [18611] = 17593,
  [18612] = 17606,
  [18613] = 17607,
  [18614] = 17608,
  [18615] = 17633,
  [18616] = 17599,
  [18617] = 17601,
  [18618] = 17609,
  [18619] = 18619,
  [18620] = 17611,
  [18621] = 17604,
  [18622] = 17604,
  [18623] = 17589,
  [18624] = 17630,
  [18625] = 17612,
  [18626] = 17610,
  [18627] = 17613,
  [18628] = 17629,
  [18629] = 17614,
  [18630] = 17615,
  [18631] = 17601,
  [18632] = 17616,
  [18633] = 17617,
  [18634] = 17618,
  [18635] = 17619,
  [18636] = 17620,
  [18637] = 17590,
  [18638] = 17599,
  [18639] = 17628,
  [18640] = 17627,
  [18641] = 17622,
  [18642] = 17631,
  [18643] = 17626,
  [18644] = 18054,
  [18645] = 17623,
  [18646] = 17639,
  [18647] = 17640,
  [18648] = 17591,
  [18649] = 17624,
  [18650] = 17625,
  [18651] = 17625,
  [18652] = 17626,
  [18653] = 17627,
  [18654] = 18061,
  [18655] = 17599,
  [18656] = 17601,
  [18657] = 17628,
  [18658] = 17624,
  [18659] = 17629,
  [18660] = 17604,
  [18661] = 17623,
  [18662] = 17611,
  [18663] = 17622,
  [18664] = 17630,
  [18665] = 17610,
  [18666] = 17589,
  [18667] = 18667,
  [18668] = 17633,
  [18669] = 17593,
  [18670] = 17590,
  [18671] = 17616,
  [18672] = 17617,
  [18673] = 17618,
  [18674] = 17619,
  [18675] = 17594,
  [18676] = 17595,
  [18677] = 17592,
  [18678] = 17612,
  [18679] = 17597,
  [18680] = 17631,
  [18681] = 17598,
  [18682] = 18087,
  [18683] = 17591,
  [18684] = 17639,
  [18685] = 17640,
  [18686] = 17591,
  [18687] = 17640,
  [18688] = 17620,
  [18689] = 17600,
  [18690] = 17602,
  [18691] = 17603,
  [18692] = 17615,
  [18693] = 17599,
  [18694] = 17601,
  [18695] = 17605,
  [18696] = 17606,
  [18697] = 17607,
  [18698] = 17604,
  [18699] = 17639,
  [18700] = 17614,
  [18701] = 17613,
  [18702] = 17608,
  [18703] = 17610,
  [18704] = 17612,
  [18705] = 17611,
  [18706] = 17609,
  [18707] = 17609,
  [18708] = 18708,
  [18709] = 17616,
  [18710] = 17617,
  [18711] = 17618,
  [18712] = 17619,
  [18713] = 17611,
  [18714] = 17589,
  [18715] = 17613,
  [18716] = 17614,
  [18717] = 17615,
  [18718] = 17631,
  [18719] = 17600,
  [18720] = 17620,
  [18721] = 17590,
  [18722] = 17639,
  [18723] = 17640,
  [18724] = 17591,
  [18725] = 17607,
  [18726] = 18726,
  [18727] = 17606,
  [18728] = 17893,
  [18729] = 17622,
  [18730] = 17605,
  [18731] = 17599,
  [18732] = 17601,
  [18733] = 18054,
  [18734] = 17623,
  [18735] = 17624,
  [18736] = 17604,
  [18737] = 17603,
  [18738] = 17631,
  [18739] = 17602,
  [18740] = 17625,
  [18741] = 17610,
  [18742] = 17626,
  [18743] = 17608,
  [18744] = 17627,
  [18745] = 18061,
  [18746] = 17628,
  [18747] = 17616,
  [18748] = 17617,
  [18749] = 17618,
  [18750] = 17619,
  [18751] = 17592,
  [18752] = 17629,
  [18753] = 17630,
  [18754] = 17595,
  [18755] = 17633,
  [18756] = 17631,
  [18757] = 17593,
  [18758] = 17594,
  [18759] = 17594,
  [18760] = 17639,
  [18761] = 17640,
  [18762] = 17591,
  [18763] = 17595,
  [18764] = 17593,
  [18765] = 17592,
  [18766] = 17633,
  [18767] = 17597,
  [18768] = 17598,
  [18769] = 17599,
  [18770] = 17601,
  [18771] = 18087,
  [18772] = 17589,
  [18773] = 17630,
  [18774] = 17604,
  [18775] = 17629,
  [18776] = 17628,
  [18777] = 17627,
  [18778] = 17600,
  [18779] = 17610,
  [18780] = 17602,
  [18781] = 17626,
  [18782] = 17603,
  [18783] = 17625,
  [18784] = 17605,
  [18785] = 17616,
  [18786] = 17617,
  [18787] = 17618,
  [18788] = 17619,
  [18789] = 17606,
  [18790] = 17607,
  [18791] = 17608,
  [18792] = 17624,
  [18793] = 17609,
  [18794] = 17631,
  [18795] = 17623,
  [18796] = 18708,
  [18797] = 17611,
  [18798] = 17639,
  [18799] = 17640,
  [18800] = 17591,
  [18801] = 17612,
  [18802] = 17622,
  [18803] = 17613,
  [18804] = 17614,
  [18805] = 18805,
  [18806] = 17615,
  [18807] = 17599,
  [18808] = 17601,
  [18809] = 17590,
  [18810] = 17620,
  [18811] = 17590,
  [18812] = 17604,
  [18813] = 17620,
  [18814] = 17615,
  [18815] = 17614,
  [18816] = 17613,
  [18817] = 17610,
  [18818] = 18818,
  [18819] = 17612,
  [18820] = 17622,
  [18821] = 17611,
  [18822] = 17616,
  [18823] = 17617,
  [18824] = 17618,
  [18825] = 17619,
  [18826] = 18054,
  [18827] = 18827,
  [18828] = 18828,
  [18829] = 17623,
  [18830] = 17624,
  [18831] = 17631,
  [18832] = 17625,
  [18833] = 17626,
  [18834] = 17627,
  [18835] = 17639,
  [18836] = 17640,
  [18837] = 17591,
  [18838] = 18061,
  [18839] = 17609,
  [18840] = 17628,
  [18841] = 18841,
  [18842] = 17590,
  [18843] = 18843,
  [18844] = 17599,
  [18845] = 17601,
  [18846] = 17607,
  [18847] = 17629,
  [18848] = 17630,
  [18849] = 17604,
  [18850] = 17606,
  [18851] = 17605,
  [18852] = 17603,
  [18853] = 17589,
  [18854] = 17610,
  [18855] = 17633,
  [18856] = 17593,
  [18857] = 17619,
  [18858] = 17594,
  [18859] = 17616,
  [18860] = 17617,
  [18861] = 17618,
  [18862] = 17619,
  [18863] = 17595,
  [18864] = 18864,
  [18865] = 17592,
  [18866] = 17618,
  [18867] = 17597,
  [18868] = 17631,
  [18869] = 17598,
  [18870] = 18087,
  [18871] = 17617,
  [18872] = 17639,
  [18873] = 17640,
  [18874] = 17591,
  [18875] = 17616,
  [18876] = 17602,
  [18877] = 17600,
  [18878] = 17602,
  [18879] = 18879,
  [18880] = 18880,
  [18881] = 17599,
  [18882] = 17601,
  [18883] = 17603,
  [18884] = 17600,
  [18885] = 17605,
  [18886] = 17604,
  [18887] = 17598,
  [18888] = 17592,
  [18889] = 17595,
  [18890] = 17606,
  [18891] = 17610,
  [18892] = 17607,
  [18893] = 17608,
  [18894] = 17629,
  [18895] = 17609,
  [18896] = 17616,
  [18897] = 17617,
  [18898] = 17618,
  [18899] = 17619,
  [18900] = 17610,
  [18901] = 18708,
  [18902] = 17611,
  [18903] = 17612,
  [18904] = 17613,
  [18905] = 17631,
  [18906] = 17614,
  [18907] = 18907,
  [18908] = 18805,
  [18909] = 17639,
  [18910] = 17640,
  [18911] = 17591,
  [18912] = 17615,
  [18913] = 17594,
  [18914] = 17593,
  [18915] = 17620,
  [18916] = 17590,
  [18917] = 17633,
  [18918] = 17599,
  [18919] = 17601,
  [18920] = 17589,
  [18921] = 17630,
  [18922] = 17622,
  [18923] = 17604,
  [18924] = 17629,
  [18925] = 17628,
  [18926] = 18619,
  [18927] = 17604,
  [18928] = 17610,
  [18929] = 18054,
  [18930] = 18827,
  [18931] = 18828,
  [18932] = 17623,
  [18933] = 17616,
  [18934] = 17617,
  [18935] = 17618,
  [18936] = 17619,
  [18937] = 17624,
  [18938] = 17625,
  [18939] = 17626,
  [18940] = 17627,
  [18941] = 18061,
  [18942] = 17628,
  [18943] = 18841,
  [18944] = 18818,
  [18945] = 17639,
  [18946] = 17640,
  [18947] = 17591,
  [18948] = 18843,
  [18949] = 17598,
  [18950] = 17625,
  [18951] = 17597,
  [18952] = 17630,
  [18953] = 17589,
  [18954] = 17599,
  [18955] = 17601,
  [18956] = 17633,
  [18957] = 17593,
  [18958] = 17624,
  [18959] = 17604,
  [18960] = 17601,
  [18961] = 17623,
  [18962] = 17599,
  [18963] = 17594,
  [18964] = 17610,
  [18965] = 17595,
  [18966] = 18864,
  [18967] = 17592,
  [18968] = 17622,
  [18969] = 17616,
  [18970] = 17617,
  [18971] = 17618,
  [18972] = 17619,
  [18973] = 17606,
  [18974] = 17620,
  [18975] = 17598,
  [18976] = 18087,
  [18977] = 17615,
  [18978] = 17614,
  [18979] = 17600,
  [18980] = 17639,
  [18981] = 17640,
  [18982] = 17591,
  [18983] = 17613,
  [18984] = 17602,
  [18985] = 17599,
  [18986] = 17601,
  [18987] = 17604,
  [18988] = 18667,
  [18989] = 17612,
  [18990] = 17611,
  [18991] = 17610,
  [18992] = 18879,
  [18993] = 17616,
  [18994] = 17617,
  [18995] = 17618,
  [18996] = 17619,
  [18997] = 18880,
  [18998] = 17603,
  [18999] = 17609,
  [19000] = 17605,
  [19001] = 17606,
  [19002] = 17591,
  [19003] = 17591,
  [19004] = 17607,
  [19005] = 17640,
  [19006] = 17608,
  [19007] = 17607,
  [19008] = 17610,
  [19009] = 17608,
  [19010] = 17616,
  [19011] = 17617,
  [19012] = 17618,
  [19013] = 17619,
  [19014] = 17639,
  [19015] = 17609,
  [19016] = 17606,
  [19017] = 18708,
  [19018] = 17611,
  [19019] = 17605,
  [19020] = 17603,
  [19021] = 17602,
  [19022] = 17600,
  [19023] = 17617,
  [19024] = 17618,
  [19025] = 17619,
  [19026] = 17612,
  [19027] = 17613,
  [19028] = 17614,
  [19029] = 17598,
  [19030] = 18726,
  [19031] = 17626,
  [19032] = 17893,
  [19033] = 17617,
  [19034] = 17618,
  [19035] = 17619,
  [19036] = 18907,
  [19037] = 18805,
  [19038] = 17615,
  [19039] = 17592,
  [19040] = 17595,
  [19041] = 17594,
  [19042] = 17631,
  [19043] = 17617,
  [19044] = 17618,
  [19045] = 17619,
  [19046] = 17593,
  [19047] = 17620,
  [19048] = 17640,
  [19049] = 17633,
  [19050] = 17589,
  [19051] = 17630,
  [19052] = 17629,
  [19053] = 17617,
  [19054] = 17618,
  [19055] = 17619,
  [19056] = 17628,
  [19057] = 17628,
  [19058] = 17626,
  [19059] = 17625,
  [19060] = 17624,
  [19061] = 17623,
  [19062] = 17622,
  [19063] = 17617,
  [19064] = 17618,
  [19065] = 17619,
  [19066] = 17622,
  [19067] = 17590,
  [19068] = 18054,
  [19069] = 17620,
  [19070] = 17615,
  [19071] = 17614,
  [19072] = 17613,
  [19073] = 17617,
  [19074] = 17618,
  [19075] = 17619,
  [19076] = 18827,
  [19077] = 18828,
  [19078] = 17623,
  [19079] = 17612,
  [19080] = 17611,
  [19081] = 17608,
  [19082] = 17607,
  [19083] = 17617,
  [19084] = 17618,
  [19085] = 17619,
  [19086] = 17624,
  [19087] = 17625,
  [19088] = 17626,
  [19089] = 17600,
  [19090] = 17605,
  [19091] = 17603,
  [19092] = 17602,
  [19093] = 17617,
  [19094] = 17618,
  [19095] = 17619,
  [19096] = 17627,
  [19097] = 18061,
  [19098] = 17598,
  [19099] = 17614,
  [19100] = 17598,
  [19101] = 17592,
  [19102] = 17595,
  [19103] = 17617,
  [19104] = 17618,
  [19105] = 17619,
  [19106] = 18841,
  [19107] = 18818,
  [19108] = 18843,
  [19109] = 17594,
  [19110] = 17593,
  [19111] = 17633,
  [19112] = 17589,
  [19113] = 17617,
  [19114] = 17618,
  [19115] = 17619,
  [19116] = 17630,
  [19117] = 17629,
  [19118] = 17630,
  [19119] = 17629,
  [19120] = 17628,
  [19121] = 17626,
  [19122] = 17625,
  [19123] = 17617,
  [19124] = 17618,
  [19125] = 17619,
  [19126] = 17589,
  [19127] = 17633,
  [19128] = 17593,
  [19129] = 17624,
  [19130] = 17623,
  [19131] = 17622,
  [19132] = 17590,
  [19133] = 17617,
  [19134] = 17618,
  [19135] = 17619,
  [19136] = 17620,
  [19137] = 17594,
  [19138] = 17615,
  [19139] = 17595,
  [19140] = 18864,
  [19141] = 17614,
  [19142] = 17592,
  [19143] = 17613,
  [19144] = 17612,
  [19145] = 17597,
  [19146] = 17619,
  [19147] = 17618,
  [19148] = 17617,
  [19149] = 18087,
  [19150] = 17616,
  [19151] = 17611,
  [19152] = 17609,
  [19153] = 17608,
  [19154] = 17600,
  [19155] = 17602,
  [19156] = 17607,
  [19157] = 18879,
  [19158] = 18880,
  [19159] = 17606,
  [19160] = 17603,
  [19161] = 17605,
  [19162] = 17603,
  [19163] = 17605,
  [19164] = 17606,
  [19165] = 17602,
  [19166] = 17607,
  [19167] = 17608,
  [19168] = 17600,
  [19169] = 17610,
  [19170] = 17609,
  [19171] = 17598,
  [19172] = 17609,
  [19173] = 18708,
  [19174] = 17595,
  [19175] = 17611,
  [19176] = 17612,
  [19177] = 17594,
  [19178] = 17613,
  [19179] = 17614,
  [19180] = 17593,
  [19181] = 18907,
  [19182] = 18805,
  [19183] = 17633,
  [19184] = 17615,
  [19185] = 17589,
  [19186] = 17630,
  [19187] = 17620,
  [19188] = 17590,
  [19189] = 18619,
  [19190] = 17629,
  [19191] = 17604,
  [19192] = 17628,
  [19193] = 17626,
  [19194] = 17622,
  [19195] = 17625,
  [19196] = 17601,
  [19197] = 18054,
  [19198] = 17624,
  [19199] = 18827,
  [19200] = 18828,
  [19201] = 17599,
  [19202] = 17623,
  [19203] = 17624,
  [19204] = 17623,
  [19205] = 17625,
  [19206] = 17626,
  [19207] = 17627,
  [19208] = 18061,
  [19209] = 17628,
  [19210] = 18841,
  [19211] = 18818,
  [19212] = 17622,
  [19213] = 19213,
  [19214] = 18843,
  [19215] = 17620,
  [19216] = 17629,
  [19217] = 17630,
  [19218] = 17589,
  [19219] = 17633,
  [19220] = 17593,
  [19221] = 17615,
  [19222] = 17594,
  [19223] = 17595,
  [19224] = 18864,
  [19225] = 17592,
  [19226] = 17624,
  [19227] = 17597,
  [19228] = 17613,
  [19229] = 17598,
  [19230] = 18087,
  [19231] = 17612,
  [19232] = 18667,
  [19233] = 17600,
  [19234] = 17602,
  [19235] = 18879,
  [19236] = 18880,
  [19237] = 17611,
  [19238] = 17603,
  [19239] = 17611,
  [19240] = 17605,
  [19241] = 17606,
  [19242] = 17607,
  [19243] = 17608,
  [19244] = 18843,
  [19245] = 17609,
  [19246] = 17609,
  [19247] = 18708,
  [19248] = 17611,
  [19249] = 17612,
  [19250] = 17613,
  [19251] = 17614,
  [19252] = 18907,
  [19253] = 18805,
  [19254] = 19254,
  [19255] = 17615,
  [19256] = 17608,
  [19257] = 17620,
  [19258] = 17590,
  [19259] = 17607,
  [19260] = 17591,
  [19261] = 17640,
  [19262] = 19262,
  [19263] = 17622,
  [19264] = 19264,
  [19265] = 17606,
  [19266] = 18054,
  [19267] = 18827,
  [19268] = 18828,
  [19269] = 17623,
  [19270] = 17624,
  [19271] = 17625,
  [19272] = 17626,
  [19273] = 17627,
  [19274] = 18061,
  [19275] = 17628,
  [19276] = 18841,
  [19277] = 18818,
  [19278] = 19278,
  [19279] = 19279,
  [19280] = 17605,
  [19281] = 17639,
  [19282] = 17629,
  [19283] = 17603,
  [19284] = 19284,
  [19285] = 19285,
  [19286] = 19286,
  [19287] = 17630,
  [19288] = 17589,
  [19289] = 17633,
  [19290] = 17593,
  [19291] = 17602,
  [19292] = 17594,
  [19293] = 17595,
  [19294] = 18864,
  [19295] = 19295,
  [19296] = 17592,
  [19297] = 17600,
  [19298] = 17592,
  [19299] = 17597,
  [19300] = 17598,
  [19301] = 17598,
  [19302] = 18087,
  [19303] = 17592,
  [19304] = 18726,
  [19305] = 17600,
  [19306] = 17602,
  [19307] = 18879,
  [19308] = 18880,
  [19309] = 17603,
  [19310] = 17595,
  [19311] = 17605,
  [19312] = 17606,
  [19313] = 17607,
  [19314] = 17608,
  [19315] = 17893,
  [19316] = 17609,
  [19317] = 17594,
  [19318] = 18708,
  [19319] = 17611,
  [19320] = 17612,
  [19321] = 17613,
  [19322] = 17614,
  [19323] = 18907,
  [19324] = 18805,
  [19325] = 17593,
  [19326] = 19213,
  [19327] = 17615,
  [19328] = 17633,
  [19329] = 17620,
  [19330] = 17590,
  [19331] = 17589,
  [19332] = 17631,
  [19333] = 17630,
  [19334] = 17629,
  [19335] = 17622,
  [19336] = 19336,
  [19337] = 17628,
  [19338] = 18054,
  [19339] = 17626,
  [19340] = 19340,
  [19341] = 18827,
  [19342] = 18828,
  [19343] = 17623,
  [19344] = 17624,
  [19345] = 17625,
  [19346] = 17626,
  [19347] = 17627,
  [19348] = 18061,
  [19349] = 17628,
  [19350] = 17625,
  [19351] = 18841,
  [19352] = 18818,
  [19353] = 18843,
  [19354] = 17609,
  [19355] = 17629,
  [19356] = 17630,
  [19357] = 17589,
  [19358] = 17633,
  [19359] = 19262,
  [19360] = 17593,
  [19361] = 19264,
  [19362] = 17623,
  [19363] = 17594,
  [19364] = 19364,
  [19365] = 17595,
  [19366] = 18864,
  [19367] = 17592,
  [19368] = 17620,
  [19369] = 17597,
  [19370] = 17615,
  [19371] = 17598,
  [19372] = 18087,
  [19373] = 17614,
  [19374] = 17613,
  [19375] = 19279,
  [19376] = 17600,
  [19377] = 17612,
  [19378] = 19284,
  [19379] = 19285,
  [19380] = 19286,
  [19381] = 17602,
  [19382] = 18879,
  [19383] = 18880,
  [19384] = 17603,
  [19385] = 17611,
  [19386] = 17605,
  [19387] = 17606,
  [19388] = 17607,
  [19389] = 17608,
  [19390] = 17602,
  [19391] = 17606,
  [19392] = 17609,
  [19393] = 17605,
  [19394] = 18708,
  [19395] = 17611,
  [19396] = 17612,
  [19397] = 17613,
  [19398] = 17614,
  [19399] = 18907,
  [19400] = 17602,
  [19401] = 19213,
  [19402] = 18805,
  [19403] = 17615,
  [19404] = 17600,
  [19405] = 17620,
  [19406] = 17590,
  [19407] = 17598,
  [19408] = 17595,
  [19409] = 17593,
  [19410] = 17623,
  [19411] = 17622,
  [19412] = 19412,
  [19413] = 19336,
  [19414] = 17622,
  [19415] = 18054,
  [19416] = 17620,
  [19417] = 19417,
  [19418] = 17615,
  [19419] = 19340,
  [19420] = 18827,
  [19421] = 18828,
  [19422] = 17623,
  [19423] = 17624,
  [19424] = 17625,
  [19425] = 17626,
  [19426] = 17627,
  [19427] = 18061,
  [19428] = 17628,
  [19429] = 17609,
  [19430] = 17606,
  [19431] = 18841,
  [19432] = 18818,
  [19433] = 19262,
  [19434] = 18843,
  [19435] = 19264,
  [19436] = 17605,
  [19437] = 17629,
  [19438] = 17630,
  [19439] = 17589,
  [19440] = 17633,
  [19441] = 17593,
  [19442] = 17612,
  [19443] = 17594,
  [19444] = 19444,
  [19445] = 19445,
  [19446] = 19364,
  [19447] = 17595,
  [19448] = 18864,
  [19449] = 19279,
  [19450] = 17592,
  [19451] = 17602,
  [19452] = 19284,
  [19453] = 19285,
  [19454] = 19286,
  [19455] = 17600,
  [19456] = 17597,
  [19457] = 17595,
  [19458] = 17598,
  [19459] = 18087,
  [19460] = 17623,
  [19461] = 17622,
  [19462] = 19462,
  [19463] = 17600,
  [19464] = 17620,
  [19465] = 17602,
  [19466] = 18879,
  [19467] = 18880,
  [19468] = 17603,
  [19469] = 17615,
  [19470] = 17609,
  [19471] = 19213,
  [19472] = 17605,
  [19473] = 17606,
  [19474] = 17607,
  [19475] = 17608,
  [19476] = 17606,
  [19477] = 17609,
  [19478] = 17605,
  [19479] = 18708,
  [19480] = 17611,
  [19481] = 17613,
  [19482] = 17615,
  [19483] = 17614,
  [19484] = 18907,
  [19485] = 18805,
  [19486] = 17615,
  [19487] = 17600,
  [19488] = 17620,
  [19489] = 19262,
  [19490] = 17590,
  [19491] = 19264,
  [19492] = 17595,
  [19493] = 17623,
  [19494] = 18864,
  [19495] = 17622,
  [19496] = 19496,
  [19497] = 19497,
  [19498] = 19279,
  [19499] = 19284,
  [19500] = 19285,
  [19501] = 19286,
  [19502] = 17622,
  [19503] = 19412,
  [19504] = 19336,
  [19505] = 17620,
  [19506] = 19213,
  [19507] = 19507,
  [19508] = 17615,
  [19509] = 18054,
  [19510] = 17609,
  [19511] = 19417,
  [19512] = 17606,
  [19513] = 19340,
  [19514] = 18827,
  [19515] = 19515,
  [19516] = 18828,
  [19517] = 17623,
  [19518] = 17624,
  [19519] = 17625,
  [19520] = 17626,
  [19521] = 17627,
  [19522] = 18061,
  [19523] = 19262,
  [19524] = 17628,
  [19525] = 19264,
  [19526] = 17605,
  [19527] = 17602,
  [19528] = 18841,
  [19529] = 19284,
  [19530] = 19285,
  [19531] = 19286,
  [19532] = 17600,
  [19533] = 19533,
  [19534] = 17595,
  [19535] = 19213,
  [19536] = 18818,
  [19537] = 18843,
  [19538] = 17623,
  [19539] = 17629,
  [19540] = 17630,
  [19541] = 17589,
  [19542] = 17633,
  [19543] = 17593,
  [19544] = 17622,
  [19545] = 17594,
  [19546] = 19444,
  [19547] = 19445,
  [19548] = 19364,
  [19549] = 17595,
  [19550] = 17620,
  [19551] = 19262,
  [19552] = 17592,
  [19553] = 19264,
  [19554] = 17615,
  [19555] = 17597,
  [19556] = 17609,
  [19557] = 19284,
  [19558] = 19285,
  [19559] = 19286,
  [19560] = 17598,
  [19561] = 18087,
  [19562] = 17619,
  [19563] = 19213,
  [19564] = 17618,
  [19565] = 17617,
  [19566] = 19462,
  [19567] = 17600,
  [19568] = 17602,
  [19569] = 18879,
  [19570] = 18880,
  [19571] = 17603,
  [19572] = 17606,
  [19573] = 17605,
  [19574] = 17606,
  [19575] = 17607,
  [19576] = 17608,
  [19577] = 19262,
  [19578] = 17616,
  [19579] = 19264,
  [19580] = 17609,
  [19581] = 17605,
  [19582] = 18708,
  [19583] = 19284,
  [19584] = 19285,
  [19585] = 19286,
  [19586] = 17611,
  [19587] = 17612,
  [19588] = 17602,
  [19589] = 19213,
  [19590] = 17613,
  [19591] = 17614,
  [19592] = 18907,
  [19593] = 18805,
  [19594] = 17615,
  [19595] = 17600,
  [19596] = 17620,
  [19597] = 17590,
  [19598] = 19497,
  [19599] = 17595,
  [19600] = 17623,
  [19601] = 17622,
  [19602] = 19262,
  [19603] = 17620,
  [19604] = 19264,
  [19605] = 19496,
  [19606] = 19284,
  [19607] = 19285,
  [19608] = 19286,
  [19609] = 17606,
  [19610] = 19213,
  [19611] = 18054,
  [19612] = 17622,
  [19613] = 19412,
  [19614] = 19336,
  [19615] = 19507,
  [19616] = 17610,
  [19617] = 17609,
  [19618] = 19417,
  [19619] = 17606,
  [19620] = 19340,
  [19621] = 17605,
  [19622] = 19262,
  [19623] = 18827,
  [19624] = 19264,
  [19625] = 19515,
  [19626] = 19284,
  [19627] = 19285,
  [19628] = 19286,
  [19629] = 17602,
  [19630] = 19213,
  [19631] = 18828,
  [19632] = 17623,
  [19633] = 17624,
  [19634] = 17625,
  [19635] = 17626,
  [19636] = 17627,
  [19637] = 18061,
  [19638] = 17628,
  [19639] = 17622,
  [19640] = 17595,
  [19641] = 19262,
  [19642] = 17623,
  [19643] = 19264,
  [19644] = 18841,
  [19645] = 19284,
  [19646] = 19285,
  [19647] = 19286,
  [19648] = 17622,
  [19649] = 19213,
  [19650] = 18619,
  [19651] = 19533,
  [19652] = 18818,
  [19653] = 18843,
  [19654] = 17620,
  [19655] = 17629,
  [19656] = 17630,
  [19657] = 17589,
  [19658] = 17633,
  [19659] = 17593,
  [19660] = 19262,
  [19661] = 17615,
  [19662] = 19264,
  [19663] = 17594,
  [19664] = 19284,
  [19665] = 19285,
  [19666] = 19286,
  [19667] = 17609,
  [19668] = 19213,
  [19669] = 19444,
  [19670] = 19445,
  [19671] = 19364,
  [19672] = 17595,
  [19673] = 18864,
  [19674] = 17592,
  [19675] = 17604,
  [19676] = 17597,
  [19677] = 17606,
  [19678] = 19262,
  [19679] = 17598,
  [19680] = 19264,
  [19681] = 18087,
  [19682] = 19284,
  [19683] = 19285,
  [19684] = 19286,
  [19685] = 17605,
  [19686] = 17600,
  [19687] = 17601,
  [19688] = 19462,
  [19689] = 17600,
  [19690] = 17602,
  [19691] = 18879,
  [19692] = 18880,
  [19693] = 19693,
  [19694] = 19262,
  [19695] = 17603,
  [19696] = 19264,
  [19697] = 17600,
  [19698] = 19284,
  [19699] = 19285,
  [19700] = 19286,
  [19701] = 17605,
  [19702] = 17606,
  [19703] = 17607,
  [19704] = 17608,
  [19705] = 17599,
  [19706] = 17609,
  [19707] = 17595,
  [19708] = 18708,
  [19709] = 17611,
  [19710] = 19262,
  [19711] = 17612,
  [19712] = 19264,
  [19713] = 17613,
  [19714] = 19284,
  [19715] = 19285,
  [19716] = 19286,
  [19717] = 17614,
  [19718] = 18907,
  [19719] = 18805,
  [19720] = 17615,
  [19721] = 17623,
  [19722] = 17620,
  [19723] = 17590,
  [19724] = 17622,
  [19725] = 17620,
  [19726] = 19262,
  [19727] = 19412,
  [19728] = 19264,
  [19729] = 17615,
  [19730] = 19284,
  [19731] = 19285,
  [19732] = 19286,
  [19733] = 17609,
  [19734] = 19496,
  [19735] = 19497,
  [19736] = 17622,
  [19737] = 17615,
  [19738] = 19507,
  [19739] = 19336,
  [19740] = 19740,
  [19741] = 17605,
  [19742] = 19262,
  [19743] = 18667,
  [19744] = 19264,
  [19745] = 18054,
  [19746] = 19284,
  [19747] = 19285,
  [19748] = 19286,
  [19749] = 17602,
  [19750] = 19417,
  [19751] = 17600,
  [19752] = 19340,
  [19753] = 17595,
  [19754] = 18827,
  [19755] = 19515,
  [19756] = 18828,
  [19757] = 17623,
  [19758] = 19262,
  [19759] = 17624,
  [19760] = 19264,
  [19761] = 17625,
  [19762] = 19284,
  [19763] = 19285,
  [19764] = 19286,
  [19765] = 17626,
  [19766] = 17627,
  [19767] = 18061,
  [19768] = 17628,
  [19769] = 17623,
  [19770] = 17622,
  [19771] = 17620,
  [19772] = 18841,
  [19773] = 17600,
  [19774] = 19262,
  [19775] = 19533,
  [19776] = 19264,
  [19777] = 19295,
  [19778] = 19284,
  [19779] = 19285,
  [19780] = 19286,
  [19781] = 18818,
  [19782] = 18843,
  [19783] = 17609,
  [19784] = 17629,
  [19785] = 17630,
  [19786] = 17589,
  [19787] = 17633,
  [19788] = 19788,
  [19789] = 17593,
  [19790] = 19262,
  [19791] = 17591,
  [19792] = 19264,
  [19793] = 17594,
  [19794] = 19284,
  [19795] = 19285,
  [19796] = 19286,
  [19797] = 19444,
  [19798] = 19445,
  [19799] = 19364,
  [19800] = 19278,
  [19801] = 17595,
  [19802] = 18864,
  [19803] = 18805,
  [19804] = 17592,
  [19805] = 17640,
  [19806] = 19262,
  [19807] = 17597,
  [19808] = 19264,
  [19809] = 17606,
  [19810] = 19284,
  [19811] = 19285,
  [19812] = 19286,
  [19813] = 17605,
  [19814] = 17598,
  [19815] = 17639,
  [19816] = 18087,
  [19817] = 17602,
  [19818] = 17600,
  [19819] = 17595,
  [19820] = 19462,
  [19821] = 19254,
  [19822] = 19262,
  [19823] = 17600,
  [19824] = 19264,
  [19825] = 17602,
  [19826] = 19284,
  [19827] = 19285,
  [19828] = 19286,
  [19829] = 18879,
  [19830] = 18880,
  [19831] = 19693,
  [19832] = 17603,
  [19833] = 17623,
  [19834] = 17605,
  [19835] = 17606,
  [19836] = 17607,
  [19837] = 17608,
  [19838] = 17622,
  [19839] = 19264,
  [19840] = 18726,
  [19841] = 19284,
  [19842] = 19285,
  [19843] = 19286,
  [19844] = 17609,
  [19845] = 17620,
  [19846] = 18708,
  [19847] = 17611,
  [19848] = 17612,
  [19849] = 17613,
  [19850] = 17614,
  [19851] = 18907,
  [19852] = 17615,
  [19853] = 17615,
  [19854] = 19264,
  [19855] = 17893,
  [19856] = 19284,
  [19857] = 19285,
  [19858] = 19286,
  [19859] = 17620,
  [19860] = 17590,
  [19861] = 17609,
  [19862] = 17606,
  [19863] = 17605,
  [19864] = 17602,
  [19865] = 17606,
  [19866] = 17593,
  [19867] = 19496,
  [19868] = 19497,
  [19869] = 19264,
  [19870] = 17622,
  [19871] = 19284,
  [19872] = 19285,
  [19873] = 19286,
  [19874] = 17595,
  [19875] = 19412,
  [19876] = 19336,
  [19877] = 19507,
  [19878] = 17623,
  [19879] = 17631,
  [19880] = 18054,
  [19881] = 17622,
  [19882] = 19417,
  [19883] = 17620,
  [19884] = 19264,
  [19885] = 19340,
  [19886] = 19284,
  [19887] = 19285,
  [19888] = 19286,
  [19889] = 17615,
  [19890] = 18827,
  [19891] = 19515,
  [19892] = 18828,
  [19893] = 17623,
  [19894] = 17624,
  [19895] = 17625,
  [19896] = 17626,
  [19897] = 17627,
  [19898] = 18061,
  [19899] = 19264,
  [19900] = 17628,
  [19901] = 19284,
  [19902] = 19285,
  [19903] = 19286,
  [19904] = 17609,
  [19905] = 17606,
  [19906] = 17605,
  [19907] = 18841,
  [19908] = 17602,
  [19909] = 19533,
  [19910] = 19295,
  [19911] = 18818,
  [19912] = 18843,
  [19913] = 17600,
  [19914] = 19264,
  [19915] = 17629,
  [19916] = 19284,
  [19917] = 19285,
  [19918] = 19286,
  [19919] = 17630,
  [19920] = 17589,
  [19921] = 17633,
  [19922] = 19788,
  [19923] = 18880,
  [19924] = 17595,
  [19925] = 17594,
  [19926] = 19444,
  [19927] = 19445,
  [19928] = 19364,
  [19929] = 19264,
  [19930] = 19278,
  [19931] = 19284,
  [19932] = 19285,
  [19933] = 19286,
  [19934] = 17595,
  [19935] = 18864,
  [19936] = 19740,
  [19937] = 17592,
  [19938] = 17623,
  [19939] = 17597,
  [19940] = 17622,
  [19941] = 17620,
  [19942] = 17598,
  [19943] = 17615,
  [19944] = 19264,
  [19945] = 18087,
  [19946] = 19284,
  [19947] = 19285,
  [19948] = 19286,
  [19949] = 17609,
  [19950] = 17606,
  [19951] = 17605,
  [19952] = 19462,
  [19953] = 19254,
  [19954] = 17600,
  [19955] = 17602,
  [19956] = 18879,
  [19957] = 17602,
  [19958] = 19693,
  [19959] = 19264,
  [19960] = 17603,
  [19961] = 19284,
  [19962] = 19285,
  [19963] = 19286,
  [19964] = 17600,
  [19965] = 17605,
  [19966] = 17606,
  [19967] = 17607,
  [19968] = 17608,
  [19969] = 17595,
  [19970] = 17623,
  [19971] = 17609,
  [19972] = 17622,
  [19973] = 18708,
  [19974] = 19264,
  [19975] = 17611,
  [19976] = 19284,
  [19977] = 19285,
  [19978] = 19286,
  [19979] = 17612,
  [19980] = 17613,
  [19981] = 17614,
  [19982] = 18907,
  [19983] = 18805,
  [19984] = 17615,
  [19985] = 17620,
  [19986] = 17620,
  [19987] = 17590,
  [19988] = 17615,
  [19989] = 19264,
  [19990] = 17609,
  [19991] = 19284,
  [19992] = 19285,
  [19993] = 19286,
  [19994] = 17595,
  [19995] = 17605,
  [19996] = 17602,
  [19997] = 17600,
  [19998] = 19496,
  [19999] = 19497,
  [20000] = 17622,
  [20001] = 17595,
  [20002] = 19412,
  [20003] = 19336,
  [20004] = 19264,
  [20005] = 19507,
  [20006] = 19284,
  [20007] = 19285,
  [20008] = 19286,
  [20009] = 17623,
  [20010] = 17622,
  [20011] = 18054,
  [20012] = 17620,
  [20013] = 19417,
  [20014] = 17615,
  [20015] = 19340,
  [20016] = 17609,
  [20017] = 18827,
  [20018] = 19515,
  [20019] = 19264,
  [20020] = 18828,
  [20021] = 19284,
  [20022] = 19285,
  [20023] = 19286,
  [20024] = 17623,
  [20025] = 17624,
  [20026] = 17625,
  [20027] = 17626,
  [20028] = 17627,
  [20029] = 18061,
  [20030] = 17628,
  [20031] = 17597,
  [20032] = 17606,
  [20033] = 17605,
  [20034] = 19264,
  [20035] = 18841,
  [20036] = 19284,
  [20037] = 19285,
  [20038] = 19286,
  [20039] = 17602,
  [20040] = 19533,
  [20041] = 19295,
  [20042] = 17600,
  [20043] = 18818,
  [20044] = 18843,
  [20045] = 17595,
  [20046] = 17629,
  [20047] = 17630,
  [20048] = 17589,
  [20049] = 19264,
  [20050] = 17633,
  [20051] = 19284,
  [20052] = 19285,
  [20053] = 19286,
  [20054] = 19788,
  [20055] = 17593,
  [20056] = 17623,
  [20057] = 17594,
  [20058] = 19444,
  [20059] = 17622,
  [20060] = 19445,
  [20061] = 20061,
  [20062] = 19364,
  [20063] = 19278,
  [20064] = 19264,
  [20065] = 17595,
  [20066] = 19284,
  [20067] = 19285,
  [20068] = 19286,
  [20069] = 17602,
  [20070] = 18864,
  [20071] = 19740,
  [20072] = 17592,
  [20073] = 17605,
  [20074] = 17611,
  [20075] = 17602,
  [20076] = 17600,
  [20077] = 17598,
  [20078] = 17595,
  [20079] = 18087,
  [20080] = 19284,
  [20081] = 19285,
  [20082] = 19286,
  [20083] = 17615,
  [20084] = 17602,
  [20085] = 17600,
  [20086] = 17595,
  [20087] = 19462,
  [20088] = 19254,
  [20089] = 20089,
  [20090] = 17600,
  [20091] = 17602,
  [20092] = 20092,
  [20093] = 18879,
  [20094] = 19284,
  [20095] = 19285,
  [20096] = 19286,
  [20097] = 18880,
  [20098] = 20098,
  [20099] = 19693,
  [20100] = 17603,
  [20101] = 17602,
  [20102] = 17605,
  [20103] = 17606,
  [20104] = 17607,
  [20105] = 17608,
  [20106] = 17600,
  [20107] = 17595,
  [20108] = 19284,
  [20109] = 19285,
  [20110] = 19286,
  [20111] = 17609,
  [20112] = 17615,
  [20113] = 18708,
  [20114] = 20114,
  [20115] = 17612,
  [20116] = 17613,
  [20117] = 17614,
  [20118] = 18907,
  [20119] = 18805,
  [20120] = 17600,
  [20121] = 20121,
  [20122] = 19284,
  [20123] = 19285,
  [20124] = 19286,
  [20125] = 17602,
  [20126] = 20126,
  [20127] = 20127,
  [20128] = 17615,
  [20129] = 17602,
  [20130] = 17620,
  [20131] = 17590,
  [20132] = 17631,
  [20133] = 17600,
  [20134] = 17595,
  [20135] = 17602,
  [20136] = 19284,
  [20137] = 19285,
  [20138] = 19286,
  [20139] = 17600,
  [20140] = 19213,
  [20141] = 17595,
  [20142] = 5390,
  [20143] = 5419,
  [20144] = 5386,
  [20145] = 17602,
  [20146] = 17600,
  [20147] = 17595,
  [20148] = 19284,
  [20149] = 19285,
  [20150] = 19286,
  [20151] = 17619,
  [20152] = 17618,
  [20153] = 17617,
  [20154] = 17602,
  [20155] = 19284,
  [20156] = 19285,
  [20157] = 19286,
  [20158] = 20158,
  [20159] = 17616,
  [20160] = 19284,
  [20161] = 19285,
  [20162] = 19286,
  [20163] = 17600,
  [20164] = 17595,
  [20165] = 19284,
  [20166] = 19285,
  [20167] = 19286,
  [20168] = 17602,
  [20169] = 17600,
  [20170] = 19284,
  [20171] = 19285,
  [20172] = 19286,
  [20173] = 19496,
  [20174] = 19497,
  [20175] = 19284,
  [20176] = 19285,
  [20177] = 19286,
  [20178] = 17622,
  [20179] = 18054,
  [20180] = 19284,
  [20181] = 19285,
  [20182] = 19286,
  [20183] = 19412,
  [20184] = 19336,
  [20185] = 19284,
  [20186] = 19285,
  [20187] = 19286,
  [20188] = 17595,
  [20189] = 19507,
  [20190] = 19284,
  [20191] = 19285,
  [20192] = 19286,
  [20193] = 20193,
  [20194] = 17602,
  [20195] = 19284,
  [20196] = 19285,
  [20197] = 19286,
  [20198] = 17600,
  [20199] = 17616,
  [20200] = 19284,
  [20201] = 19285,
  [20202] = 19286,
  [20203] = 17595,
  [20204] = 19417,
  [20205] = 19284,
  [20206] = 19285,
  [20207] = 19286,
  [20208] = 17602,
  [20209] = 19340,
  [20210] = 19284,
  [20211] = 19285,
  [20212] = 19286,
  [20213] = 17600,
  [20214] = 17595,
  [20215] = 19284,
  [20216] = 19285,
  [20217] = 19286,
  [20218] = 17610,
  [20219] = 18827,
  [20220] = 19515,
  [20221] = 20221,
  [20222] = 20222,
  [20223] = 18828,
  [20224] = 17595,
  [20225] = 17600,
  [20226] = 17619,
  [20227] = 17618,
  [20228] = 17617,
  [20229] = 17623,
  [20230] = 17624,
  [20231] = 17625,
  [20232] = 17626,
  [20233] = 17627,
  [20234] = 17595,
  [20235] = 17602,
  [20236] = 17600,
  [20237] = 18061,
  [20238] = 17595,
  [20239] = 17602,
  [20240] = 17628,
  [20241] = 17600,
  [20242] = 20242,
  [20243] = 17595,
  [20244] = 17602,
  [20245] = 20245,
  [20246] = 20246,
  [20247] = 18619,
  [20248] = 17600,
  [20249] = 20249,
  [20250] = 17602,
  [20251] = 17600,
  [20252] = 18841,
  [20253] = 17593,
  [20254] = 19533,
  [20255] = 19295,
  [20256] = 20256,
  [20257] = 20257,
  [20258] = 20258,
  [20259] = 17604,
  [20260] = 17595,
  [20261] = 18818,
  [20262] = 18843,
  [20263] = 17602,
  [20264] = 17600,
  [20265] = 19286,
  [20266] = 19285,
  [20267] = 19284,
  [20268] = 17601,
  [20269] = 17629,
  [20270] = 17630,
  [20271] = 17589,
  [20272] = 20242,
  [20273] = 20245,
  [20274] = 20246,
  [20275] = 17633,
  [20276] = 17595,
  [20277] = 17599,
  [20278] = 17602,
  [20279] = 19788,
  [20280] = 20256,
  [20281] = 17600,
  [20282] = 17610,
  [20283] = 17595,
  [20284] = 17602,
  [20285] = 17600,
  [20286] = 17595,
  [20287] = 17594,
  [20288] = 17602,
  [20289] = 20242,
  [20290] = 20245,
  [20291] = 20246,
  [20292] = 19444,
  [20293] = 20293,
  [20294] = 19445,
  [20295] = 20295,
  [20296] = 17600,
  [20297] = 20256,
  [20298] = 19279,
  [20299] = 20061,
  [20300] = 19364,
  [20301] = 17595,
  [20302] = 18619,
  [20303] = 19278,
  [20304] = 20304,
  [20305] = 17595,
  [20306] = 20245,
  [20307] = 17602,
  [20308] = 18864,
  [20309] = 20158,
  [20310] = 19740,
  [20311] = 20256,
  [20312] = 17600,
  [20313] = 20313,
  [20314] = 18667,
  [20315] = 17595,
  [20316] = 17602,
  [20317] = 17600,
  [20318] = 20245,
  [20319] = 20319,
  [20320] = 17604,
  [20321] = 20245,
  [20322] = 19264,
  [20323] = 17592,
  [20324] = 20245,
  [20325] = 17595,
  [20326] = 17601,
  [20327] = 20245,
  [20328] = 20245,
  [20329] = 20245,
  [20330] = 20245,
  [20331] = 20245,
  [20332] = 20245,
  [20333] = 20245,
  [20334] = 20245,
  [20335] = 20245,
  [20336] = 20245,
  [20337] = 20245,
  [20338] = 20245,
  [20339] = 20245,
  [20340] = 20245,
  [20341] = 20245,
  [20342] = 20245,
  [20343] = 20245,
  [20344] = 20245,
  [20345] = 20245,
  [20346] = 20245,
  [20347] = 20245,
  [20348] = 20245,
  [20349] = 20245,
  [20350] = 20245,
  [20351] = 20245,
  [20352] = 20245,
  [20353] = 20245,
  [20354] = 20245,
  [20355] = 20245,
  [20356] = 20245,
  [20357] = 20245,
  [20358] = 20245,
  [20359] = 20245,
  [20360] = 20245,
  [20361] = 20245,
  [20362] = 20245,
  [20363] = 20245,
  [20364] = 20245,
  [20365] = 20245,
  [20366] = 20245,
  [20367] = 20245,
  [20368] = 20245,
  [20369] = 20245,
  [20370] = 20245,
  [20371] = 20245,
  [20372] = 20245,
  [20373] = 20245,
  [20374] = 20245,
  [20375] = 20245,
  [20376] = 17597,
  [20377] = 17599,
  [20378] = 19262,
  [20379] = 17593,
  [20380] = 17602,
  [20381] = 17598,
  [20382] = 17600,
  [20383] = 17595,
  [20384] = 20384,
  [20385] = 18087,
  [20386] = 20386,
  [20387] = 20319,
  [20388] = 20388,
  [20389] = 20389,
  [20390] = 17591,
  [20391] = 20391,
  [20392] = 20293,
  [20393] = 17640,
  [20394] = 20394,
  [20395] = 20384,
  [20396] = 20396,
  [20397] = 20397,
  [20398] = 20319,
  [20399] = 20399,
  [20400] = 17631,
  [20401] = 17639,
  [20402] = 20256,
  [20403] = 17602,
  [20404] = 19462,
  [20405] = 20384,
  [20406] = 18726,
  [20407] = 18708,
  [20408] = 20319,
  [20409] = 18667,
  [20410] = 19254,
  [20411] = 17639,
  [20412] = 20089,
  [20413] = 17600,
  [20414] = 17640,
  [20415] = 17602,
  [20416] = 20092,
  [20417] = 18879,
  [20418] = 18880,
  [20419] = 20249,
  [20420] = 20098,
  [20421] = 18726,
  [20422] = 19693,
  [20423] = 17591,
  [20424] = 20424,
  [20425] = 17893,
  [20426] = 20426,
  [20427] = 17603,
  [20428] = 20428,
  [20429] = 17605,
  [20430] = 17606,
  [20431] = 12909,
  [20432] = 20432,
  [20433] = 17607,
  [20434] = 17608,
  [20435] = 17591,
  [20436] = 17640,
  [20437] = 17639,
  [20438] = 20384,
  [20439] = 19693,
  [20440] = 20249,
  [20441] = 20441,
  [20442] = 17609,
  [20443] = 18667,
  [20444] = 18708,
  [20445] = 20445,
  [20446] = 20446,
  [20447] = 17611,
  [20448] = 18726,
  [20449] = 17612,
  [20450] = 17613,
  [20451] = 17614,
  [20452] = 20452,
  [20453] = 20293,
  [20454] = 20454,
  [20455] = 20455,
  [20456] = 17631,
  [20457] = 17893,
  [20458] = 18907,
  [20459] = 18805,
  [20460] = 20460,
  [20461] = 17599,
  [20462] = 17601,
  [20463] = 20121,
  [20464] = 20114,
  [20465] = 17604,
  [20466] = 20126,
  [20467] = 20127,
  [20468] = 18619,
  [20469] = 17615,
  [20470] = 17610,
  [20471] = 17893,
  [20472] = 20246,
  [20473] = 20473,
  [20474] = 17617,
  [20475] = 20475,
  [20476] = 17620,
  [20477] = 8291,
  [20478] = 20245,
  [20479] = 17590,
  [20480] = 17631,
  [20481] = 17590,
  [20482] = 17618,
  [20483] = 20483,
  [20484] = 20484,
  [20485] = 17593,
  [20486] = 17598,
  [20487] = 17590,
  [20488] = 17619,
  [20489] = 17611,
  [20490] = 17612,
  [20491] = 17613,
  [20492] = 17614,
  [20493] = 17590,
  [20494] = 20386,
  [20495] = 17590,
  [20496] = 17616,
  [20497] = 17631,
  [20498] = 19213,
  [20499] = 17612,
  [20500] = 20242,
  [20501] = 17613,
  [20502] = 17598,
  [20503] = 17614,
  [20504] = 20504,
  [20505] = 20505,
};

static TSCharacterRange sym_conversion_specification_character_set_6[] = {
  {'!', '!'}, {'%', '%'}, {',', ','}, {'@', '@'}, {'B', 'C'}, {'E', 'H'}, {'L', 'L'}, {'N', 'N'},
  {'S', 'S'}, {'X', 'X'}, {'a', 'i'}, {'l', 'l'}, {'n', 'o'}, {'s', 'u'}, {'x', 'x'},
};

static TSCharacterRange sym_conversion_specification_character_set_7[] = {
  {'!', '!'}, {'%', '%'}, {',', ','}, {'0', '9'}, {'@', '@'}, {'B', 'C'}, {'E', 'H'}, {'L', 'L'},
  {'N', 'N'}, {'S', 'S'}, {'X', 'X'}, {'a', 'i'}, {'l', 'l'}, {'n', 'o'}, {'s', 'u'}, {'x', 'x'},
};

static TSCharacterRange sym_prefix_operator_character_set_1[] = {
  {'!', '!'}, {'#', '&'}, {'*', '+'}, {'-', '/'}, {':', ':'}, {'<', '@'}, {'^', '^'}, {'|', '|'},
  {'~', '~'},
};

static TSCharacterRange sym_pow_operator_character_set_1[] = {
  {'!', '!'}, {'$', '&'}, {'*', '+'}, {'-', '/'}, {':', ':'}, {'<', '@'}, {'^', '^'}, {'|', '|'},
  {'~', '~'},
};

static TSCharacterRange sym_indexing_operator_character_set_1[] = {
  {'!', '!'}, {'$', '&'}, {'*', '+'}, {'-', '-'}, {'/', '/'}, {':', ':'}, {'=', '@'}, {'^', '^'},
  {'|', '|'},
};

static TSCharacterRange sym_let_operator_character_set_1[] = {
  {'$', '$'}, {'&', '&'}, {'*', '+'}, {'-', '-'}, {'/', '/'}, {'<', '>'}, {'@', '@'}, {'^', '^'},
  {'|', '|'},
};

static TSCharacterRange sym__lowercase_identifier_character_set_2[] = {
  {'\'', '\''}, {'0', '9'}, {'A', 'Z'}, {'_', '_'}, {'a', 'z'}, {0xaa, 0xaa}, {0xb5, 0xb5}, {0xb7, 0xb7},
  {0xba, 0xba}, {0xc0, 0xd6}, {0xd8, 0xf6}, {0xf8, 0x2c1}, {0x2c6, 0x2d1}, {0x2e0, 0x2e4}, {0x2ec, 0x2ec}, {0x2ee, 0x2ee},
  {0x300, 0x374}, {0x376, 0x377}, {0x37b, 0x37d}, {0x37f, 0x37f}, {0x386, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x3a1}, {0x3a3, 0x3f5},
  {0x3f7, 0x481}, {0x483, 0x487}, {0x48a, 0x52f}, {0x531, 0x556}, {0x559, 0x559}, {0x560, 0x588}, {0x591, 0x5bd}, {0x5bf, 0x5bf},
  {0x5c1, 0x5c2}, {0x5c4, 0x5c5}, {0x5c7, 0x5c7}, {0x5d0, 0x5ea}, {0x5ef, 0x5f2}, {0x610, 0x61a}, {0x620, 0x669}, {0x66e, 0x6d3},
  {0x6d5, 0x6dc}, {0x6df, 0x6e8}, {0x6ea, 0x6fc}, {0x6ff, 0x6ff}, {0x710, 0x74a}, {0x74d, 0x7b1}, {0x7c0, 0x7f5}, {0x7fa, 0x7fa},
  {0x7fd, 0x7fd}, {0x800, 0x82d}, {0x840, 0x85b}, {0x860, 0x86a}, {0x870, 0x887}, {0x889, 0x88e}, {0x898, 0x8e1}, {0x8e3, 0x963},
  {0x966, 0x96f}, {0x971, 0x983}, {0x985, 0x98c}, {0x98f, 0x990}, {0x993, 0x9a8}, {0x9aa, 0x9b0}, {0x9b2, 0x9b2}, {0x9b6, 0x9b9},
  {0x9bc, 0x9c4}, {0x9c7, 0x9c8}, {0x9cb, 0x9ce}, {0x9d7, 0x9d7}, {0x9dc, 0x9dd}, {0x9df, 0x9e3}, {0x9e6, 0x9f1}, {0x9fc, 0x9fc},
  {0x9fe, 0x9fe}, {0xa01, 0xa03}, {0xa05, 0xa0a}, {0xa0f, 0xa10}, {0xa13, 0xa28}, {0xa2a, 0xa30}, {0xa32, 0xa33}, {0xa35, 0xa36},
  {0xa38, 0xa39}, {0xa3c, 0xa3c}, {0xa3e, 0xa42}, {0xa47, 0xa48}, {0xa4b, 0xa4d}, {0xa51, 0xa51}, {0xa59, 0xa5c}, {0xa5e, 0xa5e},
  {0xa66, 0xa75}, {0xa81, 0xa83}, {0xa85, 0xa8d}, {0xa8f, 0xa91}, {0xa93, 0xaa8}, {0xaaa, 0xab0}, {0xab2, 0xab3}, {0xab5, 0xab9},
  {0xabc, 0xac5}, {0xac7, 0xac9}, {0xacb, 0xacd}, {0xad0, 0xad0}, {0xae0, 0xae3}, {0xae6, 0xaef}, {0xaf9, 0xaff}, {0xb01, 0xb03},
  {0xb05, 0xb0c}, {0xb0f, 0xb10}, {0xb13, 0xb28}, {0xb2a, 0xb30}, {0xb32, 0xb33}, {0xb35, 0xb39}, {0xb3c, 0xb44}, {0xb47, 0xb48},
  {0xb4b, 0xb4d}, {0xb55, 0xb57}, {0xb5c, 0xb5d}, {0xb5f, 0xb63}, {0xb66, 0xb6f}, {0xb71, 0xb71}, {0xb82, 0xb83}, {0xb85, 0xb8a},
  {0xb8e, 0xb90}, {0xb92, 0xb95}, {0xb99, 0xb9a}, {0xb9c, 0xb9c}, {0xb9e, 0xb9f}, {0xba3, 0xba4}, {0xba8, 0xbaa}, {0xbae, 0xbb9},
  {0xbbe, 0xbc2}, {0xbc6, 0xbc8}, {0xbca, 0xbcd}, {0xbd0, 0xbd0}, {0xbd7, 0xbd7}, {0xbe6, 0xbef}, {0xc00, 0xc0c}, {0xc0e, 0xc10},
  {0xc12, 0xc28}, {0xc2a, 0xc39}, {0xc3c, 0xc44}, {0xc46, 0xc48}, {0xc4a, 0xc4d}, {0xc55, 0xc56}, {0xc58, 0xc5a}, {0xc5d, 0xc5d},
  {0xc60, 0xc63}, {0xc66, 0xc6f}, {0xc80, 0xc83}, {0xc85, 0xc8c}, {0xc8e, 0xc90}, {0xc92, 0xca8}, {0xcaa, 0xcb3}, {0xcb5, 0xcb9},
  {0xcbc, 0xcc4}, {0xcc6, 0xcc8}, {0xcca, 0xccd}, {0xcd5, 0xcd6}, {0xcdd, 0xcde}, {0xce0, 0xce3}, {0xce6, 0xcef}, {0xcf1, 0xcf3},
  {0xd00, 0xd0c}, {0xd0e, 0xd10}, {0xd12, 0xd44}, {0xd46, 0xd48}, {0xd4a, 0xd4e}, {0xd54, 0xd57}, {0xd5f, 0xd63}, {0xd66, 0xd6f},
  {0xd7a, 0xd7f}, {0xd81, 0xd83}, {0xd85, 0xd96}, {0xd9a, 0xdb1}, {0xdb3, 0xdbb}, {0xdbd, 0xdbd}, {0xdc0, 0xdc6}, {0xdca, 0xdca},
  {0xdcf, 0xdd4}, {0xdd6, 0xdd6}, {0xdd8, 0xddf}, {0xde6, 0xdef}, {0xdf2, 0xdf3}, {0xe01, 0xe3a}, {0xe40, 0xe4e}, {0xe50, 0xe59},
  {0xe81, 0xe82}, {0xe84, 0xe84}, {0xe86, 0xe8a}, {0xe8c, 0xea3}, {0xea5, 0xea5}, {0xea7, 0xebd}, {0xec0, 0xec4}, {0xec6, 0xec6},
  {0xec8, 0xece}, {0xed0, 0xed9}, {0xedc, 0xedf}, {0xf00, 0xf00}, {0xf18, 0xf19}, {0xf20, 0xf29}, {0xf35, 0xf35}, {0xf37, 0xf37},
  {0xf39, 0xf39}, {0xf3e, 0xf47}, {0xf49, 0xf6c}, {0xf71, 0xf84}, {0xf86, 0xf97}, {0xf99, 0xfbc}, {0xfc6, 0xfc6}, {0x1000, 0x1049},
  {0x1050, 0x109d}, {0x10a0, 0x10c5}, {0x10c7, 0x10c7}, {0x10cd, 0x10cd}, {0x10d0, 0x10fa}, {0x10fc, 0x1248}, {0x124a, 0x124d}, {0x1250, 0x1256},
  {0x1258, 0x1258}, {0x125a, 0x125d}, {0x1260, 0x1288}, {0x128a, 0x128d}, {0x1290, 0x12b0}, {0x12b2, 0x12b5}, {0x12b8, 0x12be}, {0x12c0, 0x12c0},
  {0x12c2, 0x12c5}, {0x12c8, 0x12d6}, {0x12d8, 0x1310}, {0x1312, 0x1315}, {0x1318, 0x135a}, {0x135d, 0x135f}, {0x1369, 0x1371}, {0x1380, 0x138f},
  {0x13a0, 0x13f5}, {0x13f8, 0x13fd}, {0x1401, 0x166c}, {0x166f, 0x167f}, {0x1681, 0x169a}, {0x16a0, 0x16ea}, {0x16ee, 0x16f8}, {0x1700, 0x1715},
  {0x171f, 0x1734}, {0x1740, 0x1753}, {0x1760, 0x176c}, {0x176e, 0x1770}, {0x1772, 0x1773}, {0x1780, 0x17d3}, {0x17d7, 0x17d7}, {0x17dc, 0x17dd},
  {0x17e0, 0x17e9}, {0x180b, 0x180d}, {0x180f, 0x1819}, {0x1820, 0x1878}, {0x1880, 0x18aa}, {0x18b0, 0x18f5}, {0x1900, 0x191e}, {0x1920, 0x192b},
  {0x1930, 0x193b}, {0x1946, 0x196d}, {0x1970, 0x1974}, {0x1980, 0x19ab}, {0x19b0, 0x19c9}, {0x19d0, 0x19da}, {0x1a00, 0x1a1b}, {0x1a20, 0x1a5e},
  {0x1a60, 0x1a7c}, {0x1a7f, 0x1a89}, {0x1a90, 0x1a99}, {0x1aa7, 0x1aa7}, {0x1ab0, 0x1abd}, {0x1abf, 0x1ace}, {0x1b00, 0x1b4c}, {0x1b50, 0x1b59},
  {0x1b6b, 0x1b73}, {0x1b80, 0x1bf3}, {0x1c00, 0x1c37}, {0x1c40, 0x1c49}, {0x1c4d, 0x1c7d}, {0x1c80, 0x1c88}, {0x1c90, 0x1cba}, {0x1cbd, 0x1cbf},
  {0x1cd0, 0x1cd2}, {0x1cd4, 0x1cfa}, {0x1d00, 0x1f15}, {0x1f18, 0x1f1d}, {0x1f20, 0x1f45}, {0x1f48, 0x1f4d}, {0x1f50, 0x1f57}, {0x1f59, 0x1f59},
  {0x1f5b, 0x1f5b}, {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f7d}, {0x1f80, 0x1fb4}, {0x1fb6, 0x1fbc}, {0x1fbe, 0x1fbe}, {0x1fc2, 0x1fc4}, {0x1fc6, 0x1fcc},
  {0x1fd0, 0x1fd3}, {0x1fd6, 0x1fdb}, {0x1fe0, 0x1fec}, {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ffc}, {0x200c, 0x200d}, {0x203f, 0x2040}, {0x2054, 0x2054},
  {0x2071, 0x2071}, {0x207f, 0x207f}, {0x2090, 0x209c}, {0x20d0, 0x20dc}, {0x20e1, 0x20e1}, {0x20e5, 0x20f0}, {0x2102, 0x2102}, {0x2107, 0x2107},
  {0x210a, 0x2113}, {0x2115, 0x2115}, {0x2118, 0x211d}, {0x2124, 0x2124}, {0x2126, 0x2126}, {0x2128, 0x2128}, {0x212a, 0x2139}, {0x213c, 0x213f},
  {0x2145, 0x2149}, {0x214e, 0x214e}, {0x2160, 0x2188}, {0x2c00, 0x2ce4}, {0x2ceb, 0x2cf3}, {0x2d00, 0x2d25}, {0x2d27, 0x2d27}, {0x2d2d, 0x2d2d},
  {0x2d30, 0x2d67}, {0x2d6f, 0x2d6f}, {0x2d7f, 0x2d96}, {0x2da0, 0x2da6}, {0x2da8, 0x2dae}, {0x2db0, 0x2db6}, {0x2db8, 0x2dbe}, {0x2dc0, 0x2dc6},
  {0x2dc8, 0x2dce}, {0x2dd0, 0x2dd6}, {0x2dd8, 0x2dde}, {0x2de0, 0x2dff}, {0x3005, 0x3007}, {0x3021, 0x302f}, {0x3031, 0x3035}, {0x3038, 0x303c},
  {0x3041, 0x3096}, {0x3099, 0x309a}, {0x309d, 0x309f}, {0x30a1, 0x30ff}, {0x3105, 0x312f}, {0x3131, 0x318e}, {0x31a0, 0x31bf}, {0x31f0, 0x31ff},
  {0x3400, 0x4dbf}, {0x4e00, 0xa48c}, {0xa4d0, 0xa4fd}, {0xa500, 0xa60c}, {0xa610, 0xa62b}, {0xa640, 0xa66f}, {0xa674, 0xa67d}, {0xa67f, 0xa6f1},
  {0xa717, 0xa71f}, {0xa722, 0xa788}, {0xa78b, 0xa7ca}, {0xa7d0, 0xa7d1}, {0xa7d3, 0xa7d3}, {0xa7d5, 0xa7d9}, {0xa7f2, 0xa827}, {0xa82c, 0xa82c},
  {0xa840, 0xa873}, {0xa880, 0xa8c5}, {0xa8d0, 0xa8d9}, {0xa8e0, 0xa8f7}, {0xa8fb, 0xa8fb}, {0xa8fd, 0xa92d}, {0xa930, 0xa953}, {0xa960, 0xa97c},
  {0xa980, 0xa9c0}, {0xa9cf, 0xa9d9}, {0xa9e0, 0xa9fe}, {0xaa00, 0xaa36}, {0xaa40, 0xaa4d}, {0xaa50, 0xaa59}, {0xaa60, 0xaa76}, {0xaa7a, 0xaac2},
  {0xaadb, 0xaadd}, {0xaae0, 0xaaef}, {0xaaf2, 0xaaf6}, {0xab01, 0xab06}, {0xab09, 0xab0e}, {0xab11, 0xab16}, {0xab20, 0xab26}, {0xab28, 0xab2e},
  {0xab30, 0xab5a}, {0xab5c, 0xab69}, {0xab70, 0xabea}, {0xabec, 0xabed}, {0xabf0, 0xabf9}, {0xac00, 0xd7a3}, {0xd7b0, 0xd7c6}, {0xd7cb, 0xd7fb},
  {0xf900, 0xfa6d}, {0xfa70, 0xfad9}, {0xfb00, 0xfb06}, {0xfb13, 0xfb17}, {0xfb1d, 0xfb28}, {0xfb2a, 0xfb36}, {0xfb38, 0xfb3c}, {0xfb3e, 0xfb3e},
  {0xfb40, 0xfb41}, {0xfb43, 0xfb44}, {0xfb46, 0xfbb1}, {0xfbd3, 0xfc5d}, {0xfc64, 0xfd3d}, {0xfd50, 0xfd8f}, {0xfd92, 0xfdc7}, {0xfdf0, 0xfdf9},
  {0xfe00, 0xfe0f}, {0xfe20, 0xfe2f}, {0xfe33, 0xfe34}, {0xfe4d, 0xfe4f}, {0xfe71, 0xfe71}, {0xfe73, 0xfe73}, {0xfe77, 0xfe77}, {0xfe79, 0xfe79},
  {0xfe7b, 0xfe7b}, {0xfe7d, 0xfe7d}, {0xfe7f, 0xfefc}, {0xff10, 0xff19}, {0xff21, 0xff3a}, {0xff3f, 0xff3f}, {0xff41, 0xff5a}, {0xff65, 0xffbe},
  {0xffc2, 0xffc7}, {0xffca, 0xffcf}, {0xffd2, 0xffd7}, {0xffda, 0xffdc}, {0x10000, 0x1000b}, {0x1000d, 0x10026}, {0x10028, 0x1003a}, {0x1003c, 0x1003d},
  {0x1003f, 0x1004d}, {0x10050, 0x1005d}, {0x10080, 0x100fa}, {0x10140, 0x10174}, {0x101fd, 0x101fd}, {0x10280, 0x1029c}, {0x102a0, 0x102d0}, {0x102e0, 0x102e0},
  {0x10300, 0x1031f}, {0x1032d, 0x1034a}, {0x10350, 0x1037a}, {0x10380, 0x1039d}, {0x103a0, 0x103c3}, {0x103c8, 0x103cf}, {0x103d1, 0x103d5}, {0x10400, 0x1049d},
  {0x104a0, 0x104a9}, {0x104b0, 0x104d3}, {0x104d8, 0x104fb}, {0x10500, 0x10527}, {0x10530, 0x10563}, {0x10570, 0x1057a}, {0x1057c, 0x1058a}, {0x1058c, 0x10592},
  {0x10594, 0x10595}, {0x10597, 0x105a1}, {0x105a3, 0x105b1}, {0x105b3, 0x105b9}, {0x105bb, 0x105bc}, {0x10600, 0x10736}, {0x10740, 0x10755}, {0x10760, 0x10767},
  {0x10780, 0x10785}, {0x10787, 0x107b0}, {0x107b2, 0x107ba}, {0x10800, 0x10805}, {0x10808, 0x10808}, {0x1080a, 0x10835}, {0x10837, 0x10838}, {0x1083c, 0x1083c},
  {0x1083f, 0x10855}, {0x10860, 0x10876}, {0x10880, 0x1089e}, {0x108e0, 0x108f2}, {0x108f4, 0x108f5}, {0x10900, 0x10915}, {0x10920, 0x10939}, {0x10980, 0x109b7},
  {0x109be, 0x109bf}, {0x10a00, 0x10a03}, {0x10a05, 0x10a06}, {0x10a0c, 0x10a13}, {0x10a15, 0x10a17}, {0x10a19, 0x10a35}, {0x10a38, 0x10a3a}, {0x10a3f, 0x10a3f},
  {0x10a60, 0x10a7c}, {0x10a80, 0x10a9c}, {0x10ac0, 0x10ac7}, {0x10ac9, 0x10ae6}, {0x10b00, 0x10b35}, {0x10b40, 0x10b55}, {0x10b60, 0x10b72}, {0x10b80, 0x10b91},
  {0x10c00, 0x10c48}, {0x10c80, 0x10cb2}, {0x10cc0, 0x10cf2}, {0x10d00, 0x10d27}, {0x10d30, 0x10d39}, {0x10e80, 0x10ea9}, {0x10eab, 0x10eac}, {0x10eb0, 0x10eb1},
  {0x10efd, 0x10f1c}, {0x10f27, 0x10f27}, {0x10f30, 0x10f50}, {0x10f70, 0x10f85}, {0x10fb0, 0x10fc4}, {0x10fe0, 0x10ff6}, {0x11000, 0x11046}, {0x11066, 0x11075},
  {0x1107f, 0x110ba}, {0x110c2, 0x110c2}, {0x110d0, 0x110e8}, {0x110f0, 0x110f9}, {0x11100, 0x11134}, {0x11136, 0x1113f}, {0x11144, 0x11147}, {0x11150, 0x11173},
  {0x11176, 0x11176}, {0x11180, 0x111c4}, {0x111c9, 0x111cc}, {0x111ce, 0x111da}, {0x111dc, 0x111dc}, {0x11200, 0x11211}, {0x11213, 0x11237}, {0x1123e, 0x11241},
  {0x11280, 0x11286}, {0x11288, 0x11288}, {0x1128a, 0x1128d}, {0x1128f, 0x1129d}, {0x1129f, 0x112a8}, {0x112b0, 0x112ea}, {0x112f0, 0x112f9}, {0x11300, 0x11303},
  {0x11305, 0x1130c}, {0x1130f, 0x11310}, {0x11313, 0x11328}, {0x1132a, 0x11330}, {0x11332, 0x11333}, {0x11335, 0x11339}, {0x1133b, 0x11344}, {0x11347, 0x11348},
  {0x1134b, 0x1134d}, {0x11350, 0x11350}, {0x11357, 0x11357}, {0x1135d, 0x11363}, {0x11366, 0x1136c}, {0x11370, 0x11374}, {0x11400, 0x1144a}, {0x11450, 0x11459},
  {0x1145e, 0x11461}, {0x11480, 0x114c5}, {0x114c7, 0x114c7}, {0x114d0, 0x114d9}, {0x11580, 0x115b5}, {0x115b8, 0x115c0}, {0x115d8, 0x115dd}, {0x11600, 0x11640},
  {0x11644, 0x11644}, {0x11650, 0x11659}, {0x11680, 0x116b8}, {0x116c0, 0x116c9}, {0x11700, 0x1171a}, {0x1171d, 0x1172b}, {0x11730, 0x11739}, {0x11740, 0x11746},
  {0x11800, 0x1183a}, {0x118a0, 0x118e9}, {0x118ff, 0x11906}, {0x11909, 0x11909}, {0x1190c, 0x11913}, {0x11915, 0x11916}, {0x11918, 0x11935}, {0x11937, 0x11938},
  {0x1193b, 0x11943}, {0x11950, 0x11959}, {0x119a0, 0x119a7}, {0x119aa, 0x119d7}, {0x119da, 0x119e1}, {0x119e3, 0x119e4}, {0x11a00, 0x11a3e}, {0x11a47, 0x11a47},
  {0x11a50, 0x11a99}, {0x11a9d, 0x11a9d}, {0x11ab0, 0x11af8}, {0x11c00, 0x11c08}, {0x11c0a, 0x11c36}, {0x11c38, 0x11c40}, {0x11c50, 0x11c59}, {0x11c72, 0x11c8f},
  {0x11c92, 0x11ca7}, {0x11ca9, 0x11cb6}, {0x11d00, 0x11d06}, {0x11d08, 0x11d09}, {0x11d0b, 0x11d36}, {0x11d3a, 0x11d3a}, {0x11d3c, 0x11d3d}, {0x11d3f, 0x11d47},
  {0x11d50, 0x11d59}, {0x11d60, 0x11d65}, {0x11d67, 0x11d68}, {0x11d6a, 0x11d8e}, {0x11d90, 0x11d91}, {0x11d93, 0x11d98}, {0x11da0, 0x11da9}, {0x11ee0, 0x11ef6},
  {0x11f00, 0x11f10}, {0x11f12, 0x11f3a}, {0x11f3e, 0x11f42}, {0x11f50, 0x11f59}, {0x11fb0, 0x11fb0}, {0x12000, 0x12399}, {0x12400, 0x1246e}, {0x12480, 0x12543},
  {0x12f90, 0x12ff0}, {0x13000, 0x1342f}, {0x13440, 0x13455}, {0x14400, 0x14646}, {0x16800, 0x16a38}, {0x16a40, 0x16a5e}, {0x16a60, 0x16a69}, {0x16a70, 0x16abe},
  {0x16ac0, 0x16ac9}, {0x16ad0, 0x16aed}, {0x16af0, 0x16af4}, {0x16b00, 0x16b36}, {0x16b40, 0x16b43}, {0x16b50, 0x16b59}, {0x16b63, 0x16b77}, {0x16b7d, 0x16b8f},
  {0x16e40, 0x16e7f}, {0x16f00, 0x16f4a}, {0x16f4f, 0x16f87}, {0x16f8f, 0x16f9f}, {0x16fe0, 0x16fe1}, {0x16fe3, 0x16fe4}, {0x16ff0, 0x16ff1}, {0x17000, 0x187f7},
  {0x18800, 0x18cd5}, {0x18d00, 0x18d08}, {0x1aff0, 0x1aff3}, {0x1aff5, 0x1affb}, {0x1affd, 0x1affe}, {0x1b000, 0x1b122}, {0x1b132, 0x1b132}, {0x1b150, 0x1b152},
  {0x1b155, 0x1b155}, {0x1b164, 0x1b167}, {0x1b170, 0x1b2fb}, {0x1bc00, 0x1bc6a}, {0x1bc70, 0x1bc7c}, {0x1bc80, 0x1bc88}, {0x1bc90, 0x1bc99}, {0x1bc9d, 0x1bc9e},
  {0x1cf00, 0x1cf2d}, {0x1cf30, 0x1cf46}, {0x1d165, 0x1d169}, {0x1d16d, 0x1d172}, {0x1d17b, 0x1d182}, {0x1d185, 0x1d18b}, {0x1d1aa, 0x1d1ad}, {0x1d242, 0x1d244},
  {0x1d400, 0x1d454}, {0x1d456, 0x1d49c}, {0x1d49e, 0x1d49f}, {0x1d4a2, 0x1d4a2}, {0x1d4a5, 0x1d4a6}, {0x1d4a9, 0x1d4ac}, {0x1d4ae, 0x1d4b9}, {0x1d4bb, 0x1d4bb},
  {0x1d4bd, 0x1d4c3}, {0x1d4c5, 0x1d505}, {0x1d507, 0x1d50a}, {0x1d50d, 0x1d514}, {0x1d516, 0x1d51c}, {0x1d51e, 0x1d539}, {0x1d53b, 0x1d53e}, {0x1d540, 0x1d544},
  {0x1d546, 0x1d546}, {0x1d54a, 0x1d550}, {0x1d552, 0x1d6a5}, {0x1d6a8, 0x1d6c0}, {0x1d6c2, 0x1d6da}, {0x1d6dc, 0x1d6fa}, {0x1d6fc, 0x1d714}, {0x1d716, 0x1d734},
  {0x1d736, 0x1d74e}, {0x1d750, 0x1d76e}, {0x1d770, 0x1d788}, {0x1d78a, 0x1d7a8}, {0x1d7aa, 0x1d7c2}, {0x1d7c4, 0x1d7cb}, {0x1d7ce, 0x1d7ff}, {0x1da00, 0x1da36},
  {0x1da3b, 0x1da6c}, {0x1da75, 0x1da75}, {0x1da84, 0x1da84}, {0x1da9b, 0x1da9f}, {0x1daa1, 0x1daaf}, {0x1df00, 0x1df1e}, {0x1df25, 0x1df2a}, {0x1e000, 0x1e006},
  {0x1e008, 0x1e018}, {0x1e01b, 0x1e021}, {0x1e023, 0x1e024}, {0x1e026, 0x1e02a}, {0x1e030, 0x1e06d}, {0x1e08f, 0x1e08f}, {0x1e100, 0x1e12c}, {0x1e130, 0x1e13d},
  {0x1e140, 0x1e149}, {0x1e14e, 0x1e14e}, {0x1e290, 0x1e2ae}, {0x1e2c0, 0x1e2f9}, {0x1e4d0, 0x1e4f9}, {0x1e7e0, 0x1e7e6}, {0x1e7e8, 0x1e7eb}, {0x1e7ed, 0x1e7ee},
  {0x1e7f0, 0x1e7fe}, {0x1e800, 0x1e8c4}, {0x1e8d0, 0x1e8d6}, {0x1e900, 0x1e94b}, {0x1e950, 0x1e959}, {0x1ee00, 0x1ee03}, {0x1ee05, 0x1ee1f}, {0x1ee21, 0x1ee22},
  {0x1ee24, 0x1ee24}, {0x1ee27, 0x1ee27}, {0x1ee29, 0x1ee32}, {0x1ee34, 0x1ee37}, {0x1ee39, 0x1ee39}, {0x1ee3b, 0x1ee3b}, {0x1ee42, 0x1ee42}, {0x1ee47, 0x1ee47},
  {0x1ee49, 0x1ee49}, {0x1ee4b, 0x1ee4b}, {0x1ee4d, 0x1ee4f}, {0x1ee51, 0x1ee52}, {0x1ee54, 0x1ee54}, {0x1ee57, 0x1ee57}, {0x1ee59, 0x1ee59}, {0x1ee5b, 0x1ee5b},
  {0x1ee5d, 0x1ee5d}, {0x1ee5f, 0x1ee5f}, {0x1ee61, 0x1ee62}, {0x1ee64, 0x1ee64}, {0x1ee67, 0x1ee6a}, {0x1ee6c, 0x1ee72}, {0x1ee74, 0x1ee77}, {0x1ee79, 0x1ee7c},
  {0x1ee7e, 0x1ee7e}, {0x1ee80, 0x1ee89}, {0x1ee8b, 0x1ee9b}, {0x1eea1, 0x1eea3}, {0x1eea5, 0x1eea9}, {0x1eeab, 0x1eebb}, {0x1fbf0, 0x1fbf9}, {0x20000, 0x2a6df},
  {0x2a700, 0x2b739}, {0x2b740, 0x2b81d}, {0x2b820, 0x2cea1}, {0x2ceb0, 0x2ebe0}, {0x2ebf0, 0x2ee5d}, {0x2f800, 0x2fa1d}, {0x30000, 0x3134a}, {0x31350, 0x323af},
  {0xe0100, 0xe01ef},
};

static TSCharacterRange sym__lowercase_identifier_character_set_3[] = {
  {'_', '_'}, {'a', 'z'}, {0xb5, 0xb5}, {0xdf, 0xf6}, {0xf8, 0xff}, {0x101, 0x101}, {0x103, 0x103}, {0x105, 0x105},
  {0x107, 0x107}, {0x109, 0x109}, {0x10b, 0x10b}, {0x10d, 0x10d}, {0x10f, 0x10f}, {0x111, 0x111}, {0x113, 0x113}, {0x115, 0x115},
  {0x117, 0x117}, {0x119, 0x119}, {0x11b, 0x11b}, {0x11d, 0x11d}, {0x11f, 0x11f}, {0x121, 0x121}, {0x123, 0x123}, {0x125, 0x125},
  {0x127, 0x127}, {0x129, 0x129}, {0x12b, 0x12b}, {0x12d, 0x12d}, {0x12f, 0x12f}, {0x131, 0x131}, {0x133, 0x133}, {0x135, 0x135},
  {0x137, 0x138}, {0x13a, 0x13a}, {0x13c, 0x13c}, {0x13e, 0x13e}, {0x140, 0x140}, {0x142, 0x142}, {0x144, 0x144}, {0x146, 0x146},
  {0x148, 0x149}, {0x14b, 0x14b}, {0x14d, 0x14d}, {0x14f, 0x14f}, {0x151, 0x151}, {0x153, 0x153}, {0x155, 0x155}, {0x157, 0x157},
  {0x159, 0x159}, {0x15b, 0x15b}, {0x15d, 0x15d}, {0x15f, 0x15f}, {0x161, 0x161}, {0x163, 0x163}, {0x165, 0x165}, {0x167, 0x167},
  {0x169, 0x169}, {0x16b, 0x16b}, {0x16d, 0x16d}, {0x16f, 0x16f}, {0x171, 0x171}, {0x173, 0x173}, {0x175, 0x175}, {0x177, 0x177},
  {0x17a, 0x17a}, {0x17c, 0x17c}, {0x17e, 0x180}, {0x183, 0x183}, {0x185, 0x185}, {0x188, 0x188}, {0x18c, 0x18d}, {0x192, 0x192},
  {0x195, 0x195}, {0x199, 0x19b}, {0x19e, 0x19e}, {0x1a1, 0x1a1}, {0x1a3, 0x1a3}, {0x1a5, 0x1a5}, {0x1a8, 0x1a8}, {0x1aa, 0x1ab},
  {0x1ad, 0x1ad}, {0x1b0, 0x1b0}, {0x1b4, 0x1b4}, {0x1b6, 0x1b6}, {0x1b9, 0x1ba}, {0x1bd, 0x1bf}, {0x1c6, 0x1c6}, {0x1c9, 0x1c9},
  {0x1cc, 0x1cc}, {0x1ce, 0x1ce}, {0x1d0, 0x1d0}, {0x1d2, 0x1d2}, {0x1d4, 0x1d4}, {0x1d6, 0x1d6}, {0x1d8, 0x1d8}, {0x1da, 0x1da},
  {0x1dc, 0x1dd}, {0x1df, 0x1df}, {0x1e1, 0x1e1}, {0x1e3, 0x1e3}, {0x1e5, 0x1e5}, {0x1e7, 0x1e7}, {0x1e9, 0x1e9}, {0x1eb, 0x1eb},
  {0x1ed, 0x1ed}, {0x1ef, 0x1f0}, {0x1f3, 0x1f3}, {0x1f5, 0x1f5}, {0x1f9, 0x1f9}, {0x1fb, 0x1fb}, {0x1fd, 0x1fd}, {0x1ff, 0x1ff},
  {0x201, 0x201}, {0x203, 0x203}, {0x205, 0x205}, {0x207, 0x207}, {0x209, 0x209}, {0x20b, 0x20b}, {0x20d, 0x20d}, {0x20f, 0x20f},
  {0x211, 0x211}, {0x213, 0x213}, {0x215, 0x215}, {0x217, 0x217}, {0x219, 0x219}, {0x21b, 0x21b}, {0x21d, 0x21d}, {0x21f, 0x21f},
  {0x221, 0x221}, {0x223, 0x223}, {0x225, 0x225}, {0x227, 0x227}, {0x229, 0x229}, {0x22b, 0x22b}, {0x22d, 0x22d}, {0x22f, 0x22f},
  {0x231, 0x231}, {0x233, 0x239}, {0x23c, 0x23c}, {0x23f, 0x240}, {0x242, 0x242}, {0x247, 0x247}, {0x249, 0x249}, {0x24b, 0x24b},
  {0x24d, 0x24d}, {0x24f, 0x293}, {0x295, 0x2af}, {0x371, 0x371}, {0x373, 0x373}, {0x377, 0x377}, {0x37b, 0x37d}, {0x390, 0x390},
  {0x3ac, 0x3ce}, {0x3d0, 0x3d1}, {0x3d5, 0x3d7}, {0x3d9, 0x3d9}, {0x3db, 0x3db}, {0x3dd, 0x3dd}, {0x3df, 0x3df}, {0x3e1, 0x3e1},
  {0x3e3, 0x3e3}, {0x3e5, 0x3e5}, {0x3e7, 0x3e7}, {0x3e9, 0x3e9}, {0x3eb, 0x3eb}, {0x3ed, 0x3ed}, {0x3ef, 0x3f3}, {0x3f5, 0x3f5},
  {0x3f8, 0x3f8}, {0x3fb, 0x3fc}, {0x430, 0x45f}, {0x461, 0x461}, {0x463, 0x463}, {0x465, 0x465}, {0x467, 0x467}, {0x469, 0x469},
  {0x46b, 0x46b}, {0x46d, 0x46d}, {0x46f, 0x46f}, {0x471, 0x471}, {0x473, 0x473}, {0x475, 0x475}, {0x477, 0x477}, {0x479, 0x479},
  {0x47b, 0x47b}, {0x47d, 0x47d}, {0x47f, 0x47f}, {0x481, 0x481}, {0x48b, 0x48b}, {0x48d, 0x48d}, {0x48f, 0x48f}, {0x491, 0x491},
  {0x493, 0x493}, {0x495, 0x495}, {0x497, 0x497}, {0x499, 0x499}, {0x49b, 0x49b}, {0x49d, 0x49d}, {0x49f, 0x49f}, {0x4a1, 0x4a1},
  {0x4a3, 0x4a3}, {0x4a5, 0x4a5}, {0x4a7, 0x4a7}, {0x4a9, 0x4a9}, {0x4ab, 0x4ab}, {0x4ad, 0x4ad}, {0x4af, 0x4af}, {0x4b1, 0x4b1},
  {0x4b3, 0x4b3}, {0x4b5, 0x4b5}, {0x4b7, 0x4b7}, {0x4b9, 0x4b9}, {0x4bb, 0x4bb}, {0x4bd, 0x4bd}, {0x4bf, 0x4bf}, {0x4c2, 0x4c2},
  {0x4c4, 0x4c4}, {0x4c6, 0x4c6}, {0x4c8, 0x4c8}, {0x4ca, 0x4ca}, {0x4cc, 0x4cc}, {0x4ce, 0x4cf}, {0x4d1, 0x4d1}, {0x4d3, 0x4d3},
  {0x4d5, 0x4d5}, {0x4d7, 0x4d7}, {0x4d9, 0x4d9}, {0x4db, 0x4db}, {0x4dd, 0x4dd}, {0x4df, 0x4df}, {0x4e1, 0x4e1}, {0x4e3, 0x4e3},
  {0x4e5, 0x4e5}, {0x4e7, 0x4e7}, {0x4e9, 0x4e9}, {0x4eb, 0x4eb}, {0x4ed, 0x4ed}, {0x4ef, 0x4ef}, {0x4f1, 0x4f1}, {0x4f3, 0x4f3},
  {0x4f5, 0x4f5}, {0x4f7, 0x4f7}, {0x4f9, 0x4f9}, {0x4fb, 0x4fb}, {0x4fd, 0x4fd}, {0x4ff, 0x4ff}, {0x501, 0x501}, {0x503, 0x503},
  {0x505, 0x505}, {0x507, 0x507}, {0x509, 0x509}, {0x50b, 0x50b}, {0x50d, 0x50d}, {0x50f, 0x50f}, {0x511, 0x511}, {0x513, 0x513},
  {0x515, 0x515}, {0x517, 0x517}, {0x519, 0x519}, {0x51b, 0x51b}, {0x51d, 0x51d}, {0x51f, 0x51f}, {0x521, 0x521}, {0x523, 0x523},
  {0x525, 0x525}, {0x527, 0x527}, {0x529, 0x529}, {0x52b, 0x52b}, {0x52d, 0x52d}, {0x52f, 0x52f}, {0x560, 0x588}, {0x10d0, 0x10fa},
  {0x10fd, 0x10ff}, {0x13f8, 0x13fd}, {0x1c80, 0x1c88}, {0x1d00, 0x1d2b}, {0x1d6b, 0x1d77}, {0x1d79, 0x1d9a}, {0x1e01, 0x1e01}, {0x1e03, 0x1e03},
  {0x1e05, 0x1e05}, {0x1e07, 0x1e07}, {0x1e09, 0x1e09}, {0x1e0b, 0x1e0b}, {0x1e0d, 0x1e0d}, {0x1e0f, 0x1e0f}, {0x1e11, 0x1e11}, {0x1e13, 0x1e13},
  {0x1e15, 0x1e15}, {0x1e17, 0x1e17}, {0x1e19, 0x1e19}, {0x1e1b, 0x1e1b}, {0x1e1d, 0x1e1d}, {0x1e1f, 0x1e1f}, {0x1e21, 0x1e21}, {0x1e23, 0x1e23},
  {0x1e25, 0x1e25}, {0x1e27, 0x1e27}, {0x1e29, 0x1e29}, {0x1e2b, 0x1e2b}, {0x1e2d, 0x1e2d}, {0x1e2f, 0x1e2f}, {0x1e31, 0x1e31}, {0x1e33, 0x1e33},
  {0x1e35, 0x1e35}, {0x1e37, 0x1e37}, {0x1e39, 0x1e39}, {0x1e3b, 0x1e3b}, {0x1e3d, 0x1e3d}, {0x1e3f, 0x1e3f}, {0x1e41, 0x1e41}, {0x1e43, 0x1e43},
  {0x1e45, 0x1e45}, {0x1e47, 0x1e47}, {0x1e49, 0x1e49}, {0x1e4b, 0x1e4b}, {0x1e4d, 0x1e4d}, {0x1e4f, 0x1e4f}, {0x1e51, 0x1e51}, {0x1e53, 0x1e53},
  {0x1e55, 0x1e55}, {0x1e57, 0x1e57}, {0x1e59, 0x1e59}, {0x1e5b, 0x1e5b}, {0x1e5d, 0x1e5d}, {0x1e5f, 0x1e5f}, {0x1e61, 0x1e61}, {0x1e63, 0x1e63},
  {0x1e65, 0x1e65}, {0x1e67, 0x1e67}, {0x1e69, 0x1e69}, {0x1e6b, 0x1e6b}, {0x1e6d, 0x1e6d}, {0x1e6f, 0x1e6f}, {0x1e71, 0x1e71}, {0x1e73, 0x1e73},
  {0x1e75, 0x1e75}, {0x1e77, 0x1e77}, {0x1e79, 0x1e79}, {0x1e7b, 0x1e7b}, {0x1e7d, 0x1e7d}, {0x1e7f, 0x1e7f}, {0x1e81, 0x1e81}, {0x1e83, 0x1e83},
  {0x1e85, 0x1e85}, {0x1e87, 0x1e87}, {0x1e89, 0x1e89}, {0x1e8b, 0x1e8b}, {0x1e8d, 0x1e8d}, {0x1e8f, 0x1e8f}, {0x1e91, 0x1e91}, {0x1e93, 0x1e93},
  {0x1e95, 0x1e9d}, {0x1e9f, 0x1e9f}, {0x1ea1, 0x1ea1}, {0x1ea3, 0x1ea3}, {0x1ea5, 0x1ea5}, {0x1ea7, 0x1ea7}, {0x1ea9, 0x1ea9}, {0x1eab, 0x1eab},
  {0x1ead, 0x1ead}, {0x1eaf, 0x1eaf}, {0x1eb1, 0x1eb1}, {0x1eb3, 0x1eb3}, {0x1eb5, 0x1eb5}, {0x1eb7, 0x1eb7}, {0x1eb9, 0x1eb9}, {0x1ebb, 0x1ebb},
  {0x1ebd, 0x1ebd}, {0x1ebf, 0x1ebf}, {0x1ec1, 0x1ec1}, {0x1ec3, 0x1ec3}, {0x1ec5, 0x1ec5}, {0x1ec7, 0x1ec7}, {0x1ec9, 0x1ec9}, {0x1ecb, 0x1ecb},
  {0x1ecd, 0x1ecd}, {0x1ecf, 0x1ecf}, {0x1ed1, 0x1ed1}, {0x1ed3, 0x1ed3}, {0x1ed5, 0x1ed5}, {0x1ed7, 0x1ed7}, {0x1ed9, 0x1ed9}, {0x1edb, 0x1edb},
  {0x1edd, 0x1edd}, {0x1edf, 0x1edf}, {0x1ee1, 0x1ee1}, {0x1ee3, 0x1ee3}, {0x1ee5, 0x1ee5}, {0x1ee7, 0x1ee7}, {0x1ee9, 0x1ee9}, {0x1eeb, 0x1eeb},
  {0x1eed, 0x1eed}, {0x1eef, 0x1eef}, {0x1ef1, 0x1ef1}, {0x1ef3, 0x1ef3}, {0x1ef5, 0x1ef5}, {0x1ef7, 0x1ef7}, {0x1ef9, 0x1ef9}, {0x1efb, 0x1efb},
  {0x1efd, 0x1efd}, {0x1eff, 0x1f07}, {0x1f10, 0x1f15}, {0x1f20, 0x1f27}, {0x1f30, 0x1f37}, {0x1f40, 0x1f45}, {0x1f50, 0x1f57}, {0x1f60, 0x1f67},
  {0x1f70, 0x1f7d}, {0x1f80, 0x1f87}, {0x1f90, 0x1f97}, {0x1fa0, 0x1fa7}, {0x1fb0, 0x1fb4}, {0x1fb6, 0x1fb7}, {0x1fbe, 0x1fbe}, {0x1fc2, 0x1fc4},
  {0x1fc6, 0x1fc7}, {0x1fd0, 0x1fd3}, {0x1fd6, 0x1fd7}, {0x1fe0, 0x1fe7}, {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ff7}, {0x210a, 0x210a}, {0x210e, 0x210f},
  {0x2113, 0x2113}, {0x212f, 0x212f}, {0x2134, 0x2134}, {0x2139, 0x2139}, {0x213c, 0x213d}, {0x2146, 0x2149}, {0x214e, 0x214e}, {0x2184, 0x2184},
  {0x2c30, 0x2c5f}, {0x2c61, 0x2c61}, {0x2c65, 0x2c66}, {0x2c68, 0x2c68}, {0x2c6a, 0x2c6a}, {0x2c6c, 0x2c6c}, {0x2c71, 0x2c71}, {0x2c73, 0x2c74},
  {0x2c76, 0x2c7b}, {0x2c81, 0x2c81}, {0x2c83, 0x2c83}, {0x2c85, 0x2c85}, {0x2c87, 0x2c87}, {0x2c89, 0x2c89}, {0x2c8b, 0x2c8b}, {0x2c8d, 0x2c8d},
  {0x2c8f, 0x2c8f}, {0x2c91, 0x2c91}, {0x2c93, 0x2c93}, {0x2c95, 0x2c95}, {0x2c97, 0x2c97}, {0x2c99, 0x2c99}, {0x2c9b, 0x2c9b}, {0x2c9d, 0x2c9d},
  {0x2c9f, 0x2c9f}, {0x2ca1, 0x2ca1}, {0x2ca3, 0x2ca3}, {0x2ca5, 0x2ca5}, {0x2ca7, 0x2ca7}, {0x2ca9, 0x2ca9}, {0x2cab, 0x2cab}, {0x2cad, 0x2cad},
  {0x2caf, 0x2caf}, {0x2cb1, 0x2cb1}, {0x2cb3, 0x2cb3}, {0x2cb5, 0x2cb5}, {0x2cb7, 0x2cb7}, {0x2cb9, 0x2cb9}, {0x2cbb, 0x2cbb}, {0x2cbd, 0x2cbd},
  {0x2cbf, 0x2cbf}, {0x2cc1, 0x2cc1}, {0x2cc3, 0x2cc3}, {0x2cc5, 0x2cc5}, {0x2cc7, 0x2cc7}, {0x2cc9, 0x2cc9}, {0x2ccb, 0x2ccb}, {0x2ccd, 0x2ccd},
  {0x2ccf, 0x2ccf}, {0x2cd1, 0x2cd1}, {0x2cd3, 0x2cd3}, {0x2cd5, 0x2cd5}, {0x2cd7, 0x2cd7}, {0x2cd9, 0x2cd9}, {0x2cdb, 0x2cdb}, {0x2cdd, 0x2cdd},
  {0x2cdf, 0x2cdf}, {0x2ce1, 0x2ce1}, {0x2ce3, 0x2ce4}, {0x2cec, 0x2cec}, {0x2cee, 0x2cee}, {0x2cf3, 0x2cf3}, {0x2d00, 0x2d25}, {0x2d27, 0x2d27},
  {0x2d2d, 0x2d2d}, {0xa641, 0xa641}, {0xa643, 0xa643}, {0xa645, 0xa645}, {0xa647, 0xa647}, {0xa649, 0xa649}, {0xa64b, 0xa64b}, {0xa64d, 0xa64d},
  {0xa64f, 0xa64f}, {0xa651, 0xa651}, {0xa653, 0xa653}, {0xa655, 0xa655}, {0xa657, 0xa657}, {0xa659, 0xa659}, {0xa65b, 0xa65b}, {0xa65d, 0xa65d},
  {0xa65f, 0xa65f}, {0xa661, 0xa661}, {0xa663, 0xa663}, {0xa665, 0xa665}, {0xa667, 0xa667}, {0xa669, 0xa669}, {0xa66b, 0xa66b}, {0xa66d, 0xa66d},
  {0xa681, 0xa681}, {0xa683, 0xa683}, {0xa685, 0xa685}, {0xa687, 0xa687}, {0xa689, 0xa689}, {0xa68b, 0xa68b}, {0xa68d, 0xa68d}, {0xa68f, 0xa68f},
  {0xa691, 0xa691}, {0xa693, 0xa693}, {0xa695, 0xa695}, {0xa697, 0xa697}, {0xa699, 0xa699}, {0xa69b, 0xa69b}, {0xa723, 0xa723}, {0xa725, 0xa725},
  {0xa727, 0xa727}, {0xa729, 0xa729}, {0xa72b, 0xa72b}, {0xa72d, 0xa72d}, {0xa72f, 0xa731}, {0xa733, 0xa733}, {0xa735, 0xa735}, {0xa737, 0xa737},
  {0xa739, 0xa739}, {0xa73b, 0xa73b}, {0xa73d, 0xa73d}, {0xa73f, 0xa73f}, {0xa741, 0xa741}, {0xa743, 0xa743}, {0xa745, 0xa745}, {0xa747, 0xa747},
  {0xa749, 0xa749}, {0xa74b, 0xa74b}, {0xa74d, 0xa74d}, {0xa74f, 0xa74f}, {0xa751, 0xa751}, {0xa753, 0xa753}, {0xa755, 0xa755}, {0xa757, 0xa757},
  {0xa759, 0xa759}, {0xa75b, 0xa75b}, {0xa75d, 0xa75d}, {0xa75f, 0xa75f}, {0xa761, 0xa761}, {0xa763, 0xa763}, {0xa765, 0xa765}, {0xa767, 0xa767},
  {0xa769, 0xa769}, {0xa76b, 0xa76b}, {0xa76d, 0xa76d}, {0xa76f, 0xa76f}, {0xa771, 0xa778}, {0xa77a, 0xa77a}, {0xa77c, 0xa77c}, {0xa77f, 0xa77f},
  {0xa781, 0xa781}, {0xa783, 0xa783}, {0xa785, 0xa785}, {0xa787, 0xa787}, {0xa78c, 0xa78c}, {0xa78e, 0xa78e}, {0xa791, 0xa791}, {0xa793, 0xa795},
  {0xa797, 0xa797}, {0xa799, 0xa799}, {0xa79b, 0xa79b}, {0xa79d, 0xa79d}, {0xa79f, 0xa79f}, {0xa7a1, 0xa7a1}, {0xa7a3, 0xa7a3}, {0xa7a5, 0xa7a5},
  {0xa7a7, 0xa7a7}, {0xa7a9, 0xa7a9}, {0xa7af, 0xa7af}, {0xa7b5, 0xa7b5}, {0xa7b7, 0xa7b7}, {0xa7b9, 0xa7b9}, {0xa7bb, 0xa7bb}, {0xa7bd, 0xa7bd},
  {0xa7bf, 0xa7bf}, {0xa7c1, 0xa7c1}, {0xa7c3, 0xa7c3}, {0xa7c8, 0xa7c8}, {0xa7ca, 0xa7ca}, {0xa7d1, 0xa7d1}, {0xa7d3, 0xa7d3}, {0xa7d5, 0xa7d5},
  {0xa7d7, 0xa7d7}, {0xa7d9, 0xa7d9}, {0xa7f6, 0xa7f6}, {0xa7fa, 0xa7fa}, {0xab30, 0xab5a}, {0xab60, 0xab68}, {0xab70, 0xabbf}, {0xfb00, 0xfb06},
  {0xfb13, 0xfb17}, {0xff41, 0xff5a}, {0x10428, 0x1044f}, {0x104d8, 0x104fb}, {0x10597, 0x105a1}, {0x105a3, 0x105b1}, {0x105b3, 0x105b9}, {0x105bb, 0x105bc},
};

static TSCharacterRange sym__uppercase_identifier_character_set_1[] = {
  {'A', 'Z'}, {0xc0, 0xd6}, {0xd8, 0xde}, {0x100, 0x100}, {0x102, 0x102}, {0x104, 0x104}, {0x106, 0x106}, {0x108, 0x108},
  {0x10a, 0x10a}, {0x10c, 0x10c}, {0x10e, 0x10e}, {0x110, 0x110}, {0x112, 0x112}, {0x114, 0x114}, {0x116, 0x116}, {0x118, 0x118},
  {0x11a, 0x11a}, {0x11c, 0x11c}, {0x11e, 0x11e}, {0x120, 0x120}, {0x122, 0x122}, {0x124, 0x124}, {0x126, 0x126}, {0x128, 0x128},
  {0x12a, 0x12a}, {0x12c, 0x12c}, {0x12e, 0x12e}, {0x130, 0x130}, {0x132, 0x132}, {0x134, 0x134}, {0x136, 0x136}, {0x139, 0x139},
  {0x13b, 0x13b}, {0x13d, 0x13d}, {0x13f, 0x13f}, {0x141, 0x141}, {0x143, 0x143}, {0x145, 0x145}, {0x147, 0x147}, {0x14a, 0x14a},
  {0x14c, 0x14c}, {0x14e, 0x14e}, {0x150, 0x150}, {0x152, 0x152}, {0x154, 0x154}, {0x156, 0x156}, {0x158, 0x158}, {0x15a, 0x15a},
  {0x15c, 0x15c}, {0x15e, 0x15e}, {0x160, 0x160}, {0x162, 0x162}, {0x164, 0x164}, {0x166, 0x166}, {0x168, 0x168}, {0x16a, 0x16a},
  {0x16c, 0x16c}, {0x16e, 0x16e}, {0x170, 0x170}, {0x172, 0x172}, {0x174, 0x174}, {0x176, 0x176}, {0x178, 0x179}, {0x17b, 0x17b},
  {0x17d, 0x17d}, {0x181, 0x182}, {0x184, 0x184}, {0x186, 0x187}, {0x189, 0x18b}, {0x18e, 0x191}, {0x193, 0x194}, {0x196, 0x198},
  {0x19c, 0x19d}, {0x19f, 0x1a0}, {0x1a2, 0x1a2}, {0x1a4, 0x1a4}, {0x1a6, 0x1a7}, {0x1a9, 0x1a9}, {0x1ac, 0x1ac}, {0x1ae, 0x1af},
  {0x1b1, 0x1b3}, {0x1b5, 0x1b5}, {0x1b7, 0x1b8}, {0x1bc, 0x1bc}, {0x1c4, 0x1c4}, {0x1c7, 0x1c7}, {0x1ca, 0x1ca}, {0x1cd, 0x1cd},
  {0x1cf, 0x1cf}, {0x1d1, 0x1d1}, {0x1d3, 0x1d3}, {0x1d5, 0x1d5}, {0x1d7, 0x1d7}, {0x1d9, 0x1d9}, {0x1db, 0x1db}, {0x1de, 0x1de},
  {0x1e0, 0x1e0}, {0x1e2, 0x1e2}, {0x1e4, 0x1e4}, {0x1e6, 0x1e6}, {0x1e8, 0x1e8}, {0x1ea, 0x1ea}, {0x1ec, 0x1ec}, {0x1ee, 0x1ee},
  {0x1f1, 0x1f1}, {0x1f4, 0x1f4}, {0x1f6, 0x1f8}, {0x1fa, 0x1fa}, {0x1fc, 0x1fc}, {0x1fe, 0x1fe}, {0x200, 0x200}, {0x202, 0x202},
  {0x204, 0x204}, {0x206, 0x206}, {0x208, 0x208}, {0x20a, 0x20a}, {0x20c, 0x20c}, {0x20e, 0x20e}, {0x210, 0x210}, {0x212, 0x212},
  {0x214, 0x214}, {0x216, 0x216}, {0x218, 0x218}, {0x21a, 0x21a}, {0x21c, 0x21c}, {0x21e, 0x21e}, {0x220, 0x220}, {0x222, 0x222},
  {0x224, 0x224}, {0x226, 0x226}, {0x228, 0x228}, {0x22a, 0x22a}, {0x22c, 0x22c}, {0x22e, 0x22e}, {0x230, 0x230}, {0x232, 0x232},
  {0x23a, 0x23b}, {0x23d, 0x23e}, {0x241, 0x241}, {0x243, 0x246}, {0x248, 0x248}, {0x24a, 0x24a}, {0x24c, 0x24c}, {0x24e, 0x24e},
  {0x370, 0x370}, {0x372, 0x372}, {0x376, 0x376}, {0x37f, 0x37f}, {0x386, 0x386}, {0x388, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x38f},
  {0x391, 0x3a1}, {0x3a3, 0x3ab}, {0x3cf, 0x3cf}, {0x3d2, 0x3d4}, {0x3d8, 0x3d8}, {0x3da, 0x3da}, {0x3dc, 0x3dc}, {0x3de, 0x3de},
  {0x3e0, 0x3e0}, {0x3e2, 0x3e2}, {0x3e4, 0x3e4}, {0x3e6, 0x3e6}, {0x3e8, 0x3e8}, {0x3ea, 0x3ea}, {0x3ec, 0x3ec}, {0x3ee, 0x3ee},
  {0x3f4, 0x3f4}, {0x3f7, 0x3f7}, {0x3f9, 0x3fa}, {0x3fd, 0x42f}, {0x460, 0x460}, {0x462, 0x462}, {0x464, 0x464}, {0x466, 0x466},
  {0x468, 0x468}, {0x46a, 0x46a}, {0x46c, 0x46c}, {0x46e, 0x46e}, {0x470, 0x470}, {0x472, 0x472}, {0x474, 0x474}, {0x476, 0x476},
  {0x478, 0x478}, {0x47a, 0x47a}, {0x47c, 0x47c}, {0x47e, 0x47e}, {0x480, 0x480}, {0x48a, 0x48a}, {0x48c, 0x48c}, {0x48e, 0x48e},
  {0x490, 0x490}, {0x492, 0x492}, {0x494, 0x494}, {0x496, 0x496}, {0x498, 0x498}, {0x49a, 0x49a}, {0x49c, 0x49c}, {0x49e, 0x49e},
  {0x4a0, 0x4a0}, {0x4a2, 0x4a2}, {0x4a4, 0x4a4}, {0x4a6, 0x4a6}, {0x4a8, 0x4a8}, {0x4aa, 0x4aa}, {0x4ac, 0x4ac}, {0x4ae, 0x4ae},
  {0x4b0, 0x4b0}, {0x4b2, 0x4b2}, {0x4b4, 0x4b4}, {0x4b6, 0x4b6}, {0x4b8, 0x4b8}, {0x4ba, 0x4ba}, {0x4bc, 0x4bc}, {0x4be, 0x4be},
  {0x4c0, 0x4c1}, {0x4c3, 0x4c3}, {0x4c5, 0x4c5}, {0x4c7, 0x4c7}, {0x4c9, 0x4c9}, {0x4cb, 0x4cb}, {0x4cd, 0x4cd}, {0x4d0, 0x4d0},
  {0x4d2, 0x4d2}, {0x4d4, 0x4d4}, {0x4d6, 0x4d6}, {0x4d8, 0x4d8}, {0x4da, 0x4da}, {0x4dc, 0x4dc}, {0x4de, 0x4de}, {0x4e0, 0x4e0},
  {0x4e2, 0x4e2}, {0x4e4, 0x4e4}, {0x4e6, 0x4e6}, {0x4e8, 0x4e8}, {0x4ea, 0x4ea}, {0x4ec, 0x4ec}, {0x4ee, 0x4ee}, {0x4f0, 0x4f0},
  {0x4f2, 0x4f2}, {0x4f4, 0x4f4}, {0x4f6, 0x4f6}, {0x4f8, 0x4f8}, {0x4fa, 0x4fa}, {0x4fc, 0x4fc}, {0x4fe, 0x4fe}, {0x500, 0x500},
  {0x502, 0x502}, {0x504, 0x504}, {0x506, 0x506}, {0x508, 0x508}, {0x50a, 0x50a}, {0x50c, 0x50c}, {0x50e, 0x50e}, {0x510, 0x510},
  {0x512, 0x512}, {0x514, 0x514}, {0x516, 0x516}, {0x518, 0x518}, {0x51a, 0x51a}, {0x51c, 0x51c}, {0x51e, 0x51e}, {0x520, 0x520},
  {0x522, 0x522}, {0x524, 0x524}, {0x526, 0x526}, {0x528, 0x528}, {0x52a, 0x52a}, {0x52c, 0x52c}, {0x52e, 0x52e}, {0x531, 0x556},
  {0x10a0, 0x10c5}, {0x10c7, 0x10c7}, {0x10cd, 0x10cd}, {0x13a0, 0x13f5}, {0x1c90, 0x1cba}, {0x1cbd, 0x1cbf}, {0x1e00, 0x1e00}, {0x1e02, 0x1e02},
  {0x1e04, 0x1e04}, {0x1e06, 0x1e06}, {0x1e08, 0x1e08}, {0x1e0a, 0x1e0a}, {0x1e0c, 0x1e0c}, {0x1e0e, 0x1e0e}, {0x1e10, 0x1e10}, {0x1e12, 0x1e12},
  {0x1e14, 0x1e14}, {0x1e16, 0x1e16}, {0x1e18, 0x1e18}, {0x1e1a, 0x1e1a}, {0x1e1c, 0x1e1c}, {0x1e1e, 0x1e1e}, {0x1e20, 0x1e20}, {0x1e22, 0x1e22},
  {0x1e24, 0x1e24}, {0x1e26, 0x1e26}, {0x1e28, 0x1e28}, {0x1e2a, 0x1e2a}, {0x1e2c, 0x1e2c}, {0x1e2e, 0x1e2e}, {0x1e30, 0x1e30}, {0x1e32, 0x1e32},
  {0x1e34, 0x1e34}, {0x1e36, 0x1e36}, {0x1e38, 0x1e38}, {0x1e3a, 0x1e3a}, {0x1e3c, 0x1e3c}, {0x1e3e, 0x1e3e}, {0x1e40, 0x1e40}, {0x1e42, 0x1e42},
  {0x1e44, 0x1e44}, {0x1e46, 0x1e46}, {0x1e48, 0x1e48}, {0x1e4a, 0x1e4a}, {0x1e4c, 0x1e4c}, {0x1e4e, 0x1e4e}, {0x1e50, 0x1e50}, {0x1e52, 0x1e52},
  {0x1e54, 0x1e54}, {0x1e56, 0x1e56}, {0x1e58, 0x1e58}, {0x1e5a, 0x1e5a}, {0x1e5c, 0x1e5c}, {0x1e5e, 0x1e5e}, {0x1e60, 0x1e60}, {0x1e62, 0x1e62},
  {0x1e64, 0x1e64}, {0x1e66, 0x1e66}, {0x1e68, 0x1e68}, {0x1e6a, 0x1e6a}, {0x1e6c, 0x1e6c}, {0x1e6e, 0x1e6e}, {0x1e70, 0x1e70}, {0x1e72, 0x1e72},
  {0x1e74, 0x1e74}, {0x1e76, 0x1e76}, {0x1e78, 0x1e78}, {0x1e7a, 0x1e7a}, {0x1e7c, 0x1e7c}, {0x1e7e, 0x1e7e}, {0x1e80, 0x1e80}, {0x1e82, 0x1e82},
  {0x1e84, 0x1e84}, {0x1e86, 0x1e86}, {0x1e88, 0x1e88}, {0x1e8a, 0x1e8a}, {0x1e8c, 0x1e8c}, {0x1e8e, 0x1e8e}, {0x1e90, 0x1e90}, {0x1e92, 0x1e92},
  {0x1e94, 0x1e94}, {0x1e9e, 0x1e9e}, {0x1ea0, 0x1ea0}, {0x1ea2, 0x1ea2}, {0x1ea4, 0x1ea4}, {0x1ea6, 0x1ea6}, {0x1ea8, 0x1ea8}, {0x1eaa, 0x1eaa},
  {0x1eac, 0x1eac}, {0x1eae, 0x1eae}, {0x1eb0, 0x1eb0}, {0x1eb2, 0x1eb2}, {0x1eb4, 0x1eb4}, {0x1eb6, 0x1eb6}, {0x1eb8, 0x1eb8}, {0x1eba, 0x1eba},
  {0x1ebc, 0x1ebc}, {0x1ebe, 0x1ebe}, {0x1ec0, 0x1ec0}, {0x1ec2, 0x1ec2}, {0x1ec4, 0x1ec4}, {0x1ec6, 0x1ec6}, {0x1ec8, 0x1ec8}, {0x1eca, 0x1eca},
  {0x1ecc, 0x1ecc}, {0x1ece, 0x1ece}, {0x1ed0, 0x1ed0}, {0x1ed2, 0x1ed2}, {0x1ed4, 0x1ed4}, {0x1ed6, 0x1ed6}, {0x1ed8, 0x1ed8}, {0x1eda, 0x1eda},
  {0x1edc, 0x1edc}, {0x1ede, 0x1ede}, {0x1ee0, 0x1ee0}, {0x1ee2, 0x1ee2}, {0x1ee4, 0x1ee4}, {0x1ee6, 0x1ee6}, {0x1ee8, 0x1ee8}, {0x1eea, 0x1eea},
  {0x1eec, 0x1eec}, {0x1eee, 0x1eee}, {0x1ef0, 0x1ef0}, {0x1ef2, 0x1ef2}, {0x1ef4, 0x1ef4}, {0x1ef6, 0x1ef6}, {0x1ef8, 0x1ef8}, {0x1efa, 0x1efa},
  {0x1efc, 0x1efc}, {0x1efe, 0x1efe}, {0x1f08, 0x1f0f}, {0x1f18, 0x1f1d}, {0x1f28, 0x1f2f}, {0x1f38, 0x1f3f}, {0x1f48, 0x1f4d}, {0x1f59, 0x1f59},
  {0x1f5b, 0x1f5b}, {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f5f}, {0x1f68, 0x1f6f}, {0x1fb8, 0x1fbb}, {0x1fc8, 0x1fcb}, {0x1fd8, 0x1fdb}, {0x1fe8, 0x1fec},
  {0x1ff8, 0x1ffb}, {0x2102, 0x2102}, {0x2107, 0x2107}, {0x210b, 0x210d}, {0x2110, 0x2112}, {0x2115, 0x2115}, {0x2119, 0x211d}, {0x2124, 0x2124},
  {0x2126, 0x2126}, {0x2128, 0x2128}, {0x212a, 0x212d}, {0x2130, 0x2133}, {0x213e, 0x213f}, {0x2145, 0x2145}, {0x2183, 0x2183}, {0x2c00, 0x2c2f},
  {0x2c60, 0x2c60}, {0x2c62, 0x2c64}, {0x2c67, 0x2c67}, {0x2c69, 0x2c69}, {0x2c6b, 0x2c6b}, {0x2c6d, 0x2c70}, {0x2c72, 0x2c72}, {0x2c75, 0x2c75},
  {0x2c7e, 0x2c80}, {0x2c82, 0x2c82}, {0x2c84, 0x2c84}, {0x2c86, 0x2c86}, {0x2c88, 0x2c88}, {0x2c8a, 0x2c8a}, {0x2c8c, 0x2c8c}, {0x2c8e, 0x2c8e},
  {0x2c90, 0x2c90}, {0x2c92, 0x2c92}, {0x2c94, 0x2c94}, {0x2c96, 0x2c96}, {0x2c98, 0x2c98}, {0x2c9a, 0x2c9a}, {0x2c9c, 0x2c9c}, {0x2c9e, 0x2c9e},
  {0x2ca0, 0x2ca0}, {0x2ca2, 0x2ca2}, {0x2ca4, 0x2ca4}, {0x2ca6, 0x2ca6}, {0x2ca8, 0x2ca8}, {0x2caa, 0x2caa}, {0x2cac, 0x2cac}, {0x2cae, 0x2cae},
  {0x2cb0, 0x2cb0}, {0x2cb2, 0x2cb2}, {0x2cb4, 0x2cb4}, {0x2cb6, 0x2cb6}, {0x2cb8, 0x2cb8}, {0x2cba, 0x2cba}, {0x2cbc, 0x2cbc}, {0x2cbe, 0x2cbe},
  {0x2cc0, 0x2cc0}, {0x2cc2, 0x2cc2}, {0x2cc4, 0x2cc4}, {0x2cc6, 0x2cc6}, {0x2cc8, 0x2cc8}, {0x2cca, 0x2cca}, {0x2ccc, 0x2ccc}, {0x2cce, 0x2cce},
  {0x2cd0, 0x2cd0}, {0x2cd2, 0x2cd2}, {0x2cd4, 0x2cd4}, {0x2cd6, 0x2cd6}, {0x2cd8, 0x2cd8}, {0x2cda, 0x2cda}, {0x2cdc, 0x2cdc}, {0x2cde, 0x2cde},
  {0x2ce0, 0x2ce0}, {0x2ce2, 0x2ce2}, {0x2ceb, 0x2ceb}, {0x2ced, 0x2ced}, {0x2cf2, 0x2cf2}, {0xa640, 0xa640}, {0xa642, 0xa642}, {0xa644, 0xa644},
  {0xa646, 0xa646}, {0xa648, 0xa648}, {0xa64a, 0xa64a}, {0xa64c, 0xa64c}, {0xa64e, 0xa64e}, {0xa650, 0xa650}, {0xa652, 0xa652}, {0xa654, 0xa654},
  {0xa656, 0xa656}, {0xa658, 0xa658}, {0xa65a, 0xa65a}, {0xa65c, 0xa65c}, {0xa65e, 0xa65e}, {0xa660, 0xa660}, {0xa662, 0xa662}, {0xa664, 0xa664},
  {0xa666, 0xa666}, {0xa668, 0xa668}, {0xa66a, 0xa66a}, {0xa66c, 0xa66c}, {0xa680, 0xa680}, {0xa682, 0xa682}, {0xa684, 0xa684}, {0xa686, 0xa686},
  {0xa688, 0xa688}, {0xa68a, 0xa68a}, {0xa68c, 0xa68c}, {0xa68e, 0xa68e}, {0xa690, 0xa690}, {0xa692, 0xa692}, {0xa694, 0xa694}, {0xa696, 0xa696},
  {0xa698, 0xa698}, {0xa69a, 0xa69a}, {0xa722, 0xa722}, {0xa724, 0xa724}, {0xa726, 0xa726}, {0xa728, 0xa728}, {0xa72a, 0xa72a}, {0xa72c, 0xa72c},
  {0xa72e, 0xa72e}, {0xa732, 0xa732}, {0xa734, 0xa734}, {0xa736, 0xa736}, {0xa738, 0xa738}, {0xa73a, 0xa73a}, {0xa73c, 0xa73c}, {0xa73e, 0xa73e},
  {0xa740, 0xa740}, {0xa742, 0xa742}, {0xa744, 0xa744}, {0xa746, 0xa746}, {0xa748, 0xa748}, {0xa74a, 0xa74a}, {0xa74c, 0xa74c}, {0xa74e, 0xa74e},
  {0xa750, 0xa750}, {0xa752, 0xa752}, {0xa754, 0xa754}, {0xa756, 0xa756}, {0xa758, 0xa758}, {0xa75a, 0xa75a}, {0xa75c, 0xa75c}, {0xa75e, 0xa75e},
  {0xa760, 0xa760}, {0xa762, 0xa762}, {0xa764, 0xa764}, {0xa766, 0xa766}, {0xa768, 0xa768}, {0xa76a, 0xa76a}, {0xa76c, 0xa76c}, {0xa76e, 0xa76e},
  {0xa779, 0xa779}, {0xa77b, 0xa77b}, {0xa77d, 0xa77e}, {0xa780, 0xa780}, {0xa782, 0xa782}, {0xa784, 0xa784}, {0xa786, 0xa786}, {0xa78b, 0xa78b},
  {0xa78d, 0xa78d}, {0xa790, 0xa790}, {0xa792, 0xa792}, {0xa796, 0xa796}, {0xa798, 0xa798}, {0xa79a, 0xa79a}, {0xa79c, 0xa79c}, {0xa79e, 0xa79e},
  {0xa7a0, 0xa7a0}, {0xa7a2, 0xa7a2}, {0xa7a4, 0xa7a4}, {0xa7a6, 0xa7a6}, {0xa7a8, 0xa7a8}, {0xa7aa, 0xa7ae}, {0xa7b0, 0xa7b4}, {0xa7b6, 0xa7b6},
  {0xa7b8, 0xa7b8}, {0xa7ba, 0xa7ba}, {0xa7bc, 0xa7bc}, {0xa7be, 0xa7be}, {0xa7c0, 0xa7c0}, {0xa7c2, 0xa7c2}, {0xa7c4, 0xa7c7}, {0xa7c9, 0xa7c9},
  {0xa7d0, 0xa7d0}, {0xa7d6, 0xa7d6}, {0xa7d8, 0xa7d8}, {0xa7f5, 0xa7f5}, {0xff21, 0xff3a}, {0x10400, 0x10427}, {0x104b0, 0x104d3}, {0x10570, 0x1057a},
  {0x1057c, 0x1058a}, {0x1058c, 0x10592}, {0x10594, 0x10595},
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(435);
      ADVANCE_MAP(
        '!', 469,
        '"', 610,
        '#', 549,
        '$', 403,
        '%', 584,
        '&', 545,
        '\'', 606,
        '(', 458,
        ')', 459,
        '*', 503,
        '+', 468,
        ',', 466,
        '-', 471,
        '.', 500,
        '0', 587,
        ':', 453,
        ';', 511,
        '<', 547,
        '=', 447,
        '>', 543,
        '?', 450,
        '@', 650,
        '[', 478,
        '\\', 2,
        ']', 488,
        '^', 652,
        '`', 818,
        'a', 742,
        'c', 736,
        'd', 763,
        'e', 730,
        'i', 743,
        'l', 701,
        'm', 673,
        'o', 775,
        't', 722,
        'v', 671,
        'w', 726,
        '{', 506,
        '|', 475,
        '}', 512,
        '~', 448,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(419);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 1:
      if (lookahead == '\n') ADVANCE(618);
      if (lookahead == '\r') ADVANCE(1);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '\n', 618,
        '\r', 1,
        '#', 418,
        'o', 400,
        'u', 391,
        'x', 417,
        ' ', 624,
        '"', 624,
        '\'', 624,
        '\\', 624,
        'b', 624,
        'n', 624,
        'r', 624,
        't', 624,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(407);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '\n', 618,
        '\r', 1,
        'o', 400,
        'u', 391,
        'x', 417,
        ' ', 624,
        '"', 624,
        '\'', 624,
        '\\', 624,
        'b', 624,
        'n', 624,
        'r', 624,
        't', 624,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(407);
      END_STATE();
    case 4:
      if (lookahead == '\n') ADVANCE(607);
      if (lookahead == '\r') ADVANCE(5);
      if (lookahead == '[') ADVANCE(609);
      if (lookahead == '\\') ADVANCE(348);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(608);
      if (lookahead != 0 &&
          lookahead != '\'') ADVANCE(608);
      END_STATE();
    case 5:
      if (lookahead == '\n') ADVANCE(607);
      if (lookahead == '\r') ADVANCE(5);
      if (lookahead == '[') ADVANCE(263);
      if (lookahead == '\\') ADVANCE(348);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(266);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '!', 469,
        '"', 610,
        '#', 548,
        '%', 584,
        '\'', 605,
        '(', 458,
        '+', 598,
        ',', 466,
        '-', 604,
        '.', 819,
        '0', 587,
        ':', 495,
        ';', 510,
        '=', 447,
        '>', 394,
        '?', 450,
        '[', 484,
        '\\', 198,
        '`', 818,
        '{', 507,
        '|', 474,
        '~', 448,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(6);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '!', 469,
        '#', 548,
        '&', 544,
        '\'', 817,
        '(', 458,
        ')', 459,
        '*', 503,
        '+', 255,
        ',', 466,
        '-', 260,
        '.', 248,
        ':', 492,
        ';', 510,
        '<', 546,
        '=', 447,
        '>', 543,
        '?', 450,
        '[', 482,
        '\\', 198,
        ']', 488,
        '`', 818,
        '{', 507,
        '|', 473,
        '}', 512,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(7);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 8:
      ADVANCE_MAP(
        '!', 469,
        '%', 584,
        '\'', 817,
        '(', 458,
        '+', 467,
        '-', 470,
        '.', 819,
        '[', 483,
        '\\', 198,
        '{', 236,
        '|', 473,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(8);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 9:
      if (lookahead == '!') ADVANCE(469);
      if (lookahead == '(') ADVANCE(458);
      if (lookahead == '[') ADVANCE(483);
      if (lookahead == '\\') ADVANCE(198);
      if (lookahead == 'l') ADVANCE(701);
      if (lookahead == '{') ADVANCE(236);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(9);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 10:
      ADVANCE_MAP(
        '!', 258,
        '#', 816,
        '&', 661,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        ':', 253,
        ';', 511,
        '<', 655,
        '[', 238,
        ']', 488,
        'a', 329,
        'c', 324,
        'd', 350,
        'e', 320,
        'i', 334,
        'l', 271,
        'm', 356,
        'o', 361,
        't', 352,
        '{', 239,
        '|', 477,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '$', 658,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(10);
      END_STATE();
    case 11:
      ADVANCE_MAP(
        '!', 258,
        '#', 550,
        '&', 661,
        '\'', 606,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        ':', 493,
        ';', 511,
        '<', 655,
        '[', 486,
        ']', 488,
        '`', 818,
        'a', 329,
        'c', 324,
        'd', 350,
        'e', 320,
        'i', 334,
        'l', 271,
        'm', 356,
        'o', 361,
        't', 352,
        'v', 269,
        'w', 313,
        '{', 509,
        '|', 477,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '$', 658,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(13);
      END_STATE();
    case 12:
      ADVANCE_MAP(
        '!', 258,
        '#', 550,
        '&', 661,
        '(', 458,
        ')', 459,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 603,
        '.', 499,
        ':', 494,
        ';', 510,
        '<', 655,
        '>', 656,
        '[', 235,
        ']', 488,
        'a', 342,
        'd', 349,
        'e', 319,
        'i', 336,
        'l', 273,
        'm', 357,
        'o', 364,
        't', 310,
        'w', 313,
        '{', 236,
        '|', 476,
        '}', 512,
        '$', 658,
        '=', 658,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(12);
      END_STATE();
    case 13:
      ADVANCE_MAP(
        '!', 258,
        '#', 550,
        '&', 661,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        ':', 493,
        ';', 511,
        '<', 655,
        '[', 486,
        ']', 488,
        '`', 818,
        'a', 329,
        'c', 324,
        'd', 350,
        'e', 320,
        'i', 334,
        'l', 271,
        'm', 356,
        'o', 361,
        't', 352,
        'v', 269,
        'w', 313,
        '{', 509,
        '|', 477,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '$', 658,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(13);
      END_STATE();
    case 14:
      ADVANCE_MAP(
        '!', 258,
        '#', 550,
        '&', 661,
        ')', 459,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 603,
        '.', 499,
        ':', 494,
        ';', 510,
        '<', 655,
        '>', 656,
        '[', 238,
        ']', 488,
        'a', 371,
        'c', 355,
        'd', 349,
        'e', 319,
        'i', 335,
        'l', 273,
        'm', 298,
        'o', 364,
        't', 310,
        'v', 269,
        'w', 313,
        '{', 239,
        '|', 477,
        '}', 512,
        '$', 658,
        '=', 658,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(14);
      END_STATE();
    case 15:
      ADVANCE_MAP(
        '!', 258,
        '#', 550,
        '&', 661,
        ')', 459,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 603,
        '.', 499,
        ':', 494,
        ';', 510,
        '<', 655,
        '>', 656,
        '[', 238,
        ']', 488,
        'a', 371,
        'c', 355,
        'd', 349,
        'e', 319,
        'i', 335,
        'l', 273,
        'm', 298,
        'o', 364,
        't', 310,
        'v', 269,
        'w', 313,
        '{', 239,
        '|', 476,
        '}', 512,
        '$', 658,
        '=', 658,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(15);
      END_STATE();
    case 16:
      ADVANCE_MAP(
        '!', 258,
        '#', 550,
        '&', 661,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        ':', 253,
        ';', 510,
        '<', 655,
        '[', 264,
        'a', 329,
        'd', 350,
        'e', 318,
        'i', 336,
        'l', 273,
        'm', 357,
        'o', 364,
        't', 351,
        '|', 477,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '$', 658,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(16);
      END_STATE();
    case 17:
      ADVANCE_MAP(
        '!', 258,
        '&', 661,
        ')', 459,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 603,
        ':', 494,
        ';', 510,
        '<', 655,
        '>', 656,
        '[', 264,
        ']', 488,
        'a', 329,
        'd', 349,
        'e', 319,
        'i', 336,
        'l', 273,
        'm', 357,
        'o', 364,
        't', 310,
        'w', 313,
        '|', 476,
        '}', 512,
        '$', 658,
        '=', 658,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(17);
      END_STATE();
    case 18:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '#', 816,
        '$', 403,
        '%', 584,
        '&', 544,
        '\'', 605,
        '(', 458,
        ')', 459,
        '*', 503,
        '+', 599,
        '-', 600,
        '.', 819,
        '0', 587,
        ':', 497,
        ';', 254,
        '<', 247,
        '=', 447,
        '>', 543,
        '?', 451,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'c', 737,
        'e', 806,
        'i', 753,
        'l', 701,
        'm', 676,
        'o', 776,
        't', 808,
        '{', 506,
        '|', 473,
        '~', 414,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(18);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 19:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '#', 816,
        '$', 403,
        '%', 584,
        '\'', 605,
        '(', 458,
        '.', 499,
        '0', 587,
        ':', 256,
        ';', 254,
        '=', 447,
        '[', 481,
        '\\', 198,
        '`', 818,
        'c', 737,
        'e', 751,
        'i', 753,
        'l', 701,
        'm', 676,
        'o', 776,
        't', 808,
        '{', 506,
        '+', 599,
        '-', 599,
        '?', 414,
        '~', 414,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(19);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 20:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '#', 816,
        '$', 403,
        '%', 584,
        '\'', 605,
        '(', 458,
        '0', 587,
        ';', 254,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 742,
        'c', 737,
        'e', 806,
        'i', 743,
        'l', 701,
        'm', 676,
        'o', 776,
        't', 808,
        '{', 506,
        '+', 599,
        '-', 599,
        '?', 414,
        '~', 414,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(20);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 21:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '#', 816,
        '$', 403,
        '%', 584,
        '\'', 605,
        '(', 458,
        '0', 587,
        ';', 254,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 742,
        'c', 737,
        'e', 806,
        'i', 753,
        'l', 701,
        'm', 676,
        'o', 776,
        't', 808,
        '{', 506,
        '+', 599,
        '-', 599,
        '?', 414,
        '~', 414,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(21);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 22:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '#', 816,
        '$', 403,
        '%', 584,
        '\'', 605,
        '(', 458,
        '0', 587,
        ';', 254,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 742,
        'c', 737,
        'e', 751,
        'i', 743,
        'l', 701,
        'm', 676,
        'o', 776,
        't', 808,
        '{', 506,
        '+', 599,
        '-', 599,
        '?', 414,
        '~', 414,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(22);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 23:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '#', 816,
        '$', 403,
        '%', 584,
        '\'', 605,
        '(', 458,
        '0', 587,
        ';', 254,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 742,
        'c', 737,
        'e', 751,
        'i', 753,
        'l', 701,
        'm', 676,
        'o', 776,
        't', 808,
        '{', 506,
        '+', 599,
        '-', 599,
        '?', 414,
        '~', 414,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(23);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 24:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '#', 816,
        '$', 403,
        '\'', 605,
        '(', 458,
        '+', 255,
        '0', 587,
        ':', 452,
        ';', 254,
        '?', 451,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 759,
        'c', 737,
        'e', 806,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 506,
        '~', 449,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(25);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 25:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '#', 816,
        '$', 403,
        '\'', 605,
        '(', 458,
        '+', 255,
        '0', 587,
        ';', 254,
        '?', 451,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 759,
        'c', 737,
        'e', 806,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 506,
        '~', 449,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(25);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 26:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '#', 816,
        '$', 403,
        '\'', 605,
        '(', 458,
        '0', 587,
        ':', 452,
        ';', 254,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 759,
        'c', 737,
        'e', 751,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 506,
        '~', 449,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(27);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 27:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '#', 816,
        '$', 403,
        '\'', 605,
        '(', 458,
        '0', 587,
        ';', 254,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 759,
        'c', 737,
        'e', 751,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 506,
        '~', 449,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(27);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 28:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '#', 550,
        '$', 403,
        '%', 584,
        '&', 544,
        '\'', 605,
        '(', 458,
        ')', 459,
        '*', 503,
        '+', 598,
        ',', 466,
        '-', 604,
        '.', 499,
        '0', 587,
        ':', 495,
        ';', 510,
        '=', 447,
        '>', 543,
        '?', 451,
        '[', 484,
        '\\', 198,
        ']', 488,
        '`', 818,
        '{', 508,
        '|', 473,
        '}', 512,
        '~', 449,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(28);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 29:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '#', 550,
        '$', 403,
        '\'', 605,
        '(', 458,
        ')', 459,
        ',', 466,
        '.', 499,
        '0', 587,
        ':', 490,
        ';', 510,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        '{', 508,
        '|', 474,
        '~', 449,
        '+', 598,
        '-', 598,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(29);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 30:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '#', 550,
        '$', 403,
        '\'', 605,
        '(', 458,
        '*', 503,
        '-', 260,
        '.', 499,
        '0', 587,
        ':', 452,
        ';', 254,
        '=', 447,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 759,
        'c', 737,
        'e', 751,
        'i', 753,
        'm', 768,
        'o', 776,
        't', 808,
        'v', 671,
        '{', 506,
        '|', 473,
        '~', 449,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(33);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 31:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '#', 550,
        '$', 403,
        '\'', 605,
        '(', 458,
        '*', 503,
        '-', 260,
        '.', 499,
        '0', 587,
        ':', 457,
        '=', 447,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'c', 767,
        'e', 752,
        'i', 747,
        'm', 711,
        'v', 671,
        '{', 506,
        '~', 449,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(32);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 32:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '#', 550,
        '$', 403,
        '\'', 605,
        '(', 458,
        '*', 503,
        '-', 260,
        '.', 499,
        '0', 587,
        ':', 261,
        '=', 447,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'c', 767,
        'e', 752,
        'i', 747,
        'm', 711,
        'v', 671,
        '{', 506,
        '~', 449,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(32);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 33:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '#', 550,
        '$', 403,
        '\'', 605,
        '(', 458,
        '*', 503,
        '-', 260,
        '.', 499,
        '0', 587,
        ';', 254,
        '=', 447,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 759,
        'c', 737,
        'e', 751,
        'i', 753,
        'm', 768,
        'o', 776,
        't', 808,
        'v', 671,
        '{', 506,
        '|', 473,
        '~', 449,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(33);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 34:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '#', 550,
        '$', 403,
        '\'', 605,
        '(', 458,
        '.', 499,
        '0', 587,
        ';', 254,
        '?', 451,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 759,
        'c', 737,
        'e', 806,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 506,
        '~', 449,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(34);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 35:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '#', 550,
        '$', 403,
        '\'', 605,
        '(', 458,
        '.', 499,
        '0', 587,
        ';', 254,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 759,
        'c', 737,
        'e', 751,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 506,
        '~', 449,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(35);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 36:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '$', 403,
        '%', 584,
        '\'', 605,
        '(', 458,
        ')', 459,
        '+', 599,
        '-', 600,
        '.', 499,
        '0', 587,
        ':', 498,
        ';', 510,
        '=', 447,
        '>', 394,
        '[', 484,
        '\\', 198,
        ']', 488,
        '`', 818,
        'l', 701,
        'm', 679,
        '{', 508,
        '|', 267,
        '}', 512,
        '?', 414,
        '~', 414,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(36);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 37:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '$', 403,
        '%', 584,
        '\'', 605,
        '(', 458,
        '0', 587,
        ':', 489,
        ';', 510,
        '=', 447,
        '>', 543,
        '[', 481,
        '\\', 198,
        '`', 818,
        'c', 767,
        'e', 752,
        'i', 747,
        'l', 701,
        'm', 675,
        'v', 671,
        '{', 506,
        '}', 512,
        '+', 599,
        '-', 599,
        '?', 414,
        '~', 414,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(37);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 38:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '$', 403,
        '%', 584,
        '\'', 605,
        '(', 458,
        '0', 587,
        '[', 484,
        '\\', 198,
        '`', 818,
        'd', 763,
        'l', 701,
        'm', 679,
        '{', 508,
        '+', 599,
        '-', 599,
        '?', 414,
        '~', 414,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(38);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 39:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '$', 403,
        '%', 584,
        '\'', 605,
        '(', 458,
        '0', 587,
        '[', 484,
        '\\', 198,
        '`', 818,
        'd', 765,
        'l', 701,
        'm', 679,
        't', 764,
        '{', 508,
        '+', 599,
        '-', 599,
        '?', 414,
        '~', 414,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(39);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 40:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '$', 403,
        '%', 584,
        '\'', 605,
        '(', 458,
        '0', 587,
        '[', 484,
        '\\', 198,
        '`', 818,
        'd', 774,
        'l', 701,
        'm', 679,
        '{', 508,
        '+', 599,
        '-', 599,
        '?', 414,
        '~', 414,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(40);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 41:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '$', 403,
        '%', 584,
        '\'', 605,
        '(', 458,
        '0', 587,
        '[', 484,
        '\\', 198,
        '`', 818,
        'e', 752,
        'l', 701,
        'm', 679,
        '{', 508,
        '+', 599,
        '-', 599,
        '?', 414,
        '~', 414,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(41);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 42:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '$', 403,
        '%', 584,
        '\'', 605,
        '(', 458,
        '0', 587,
        '[', 484,
        '\\', 198,
        '`', 818,
        'l', 701,
        'm', 679,
        't', 723,
        '{', 508,
        '+', 599,
        '-', 599,
        '?', 414,
        '~', 414,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(42);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 43:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '$', 403,
        '%', 584,
        '\'', 605,
        '(', 458,
        '0', 587,
        '[', 484,
        '\\', 198,
        '`', 818,
        'l', 701,
        'm', 679,
        'w', 726,
        '{', 508,
        '+', 599,
        '-', 599,
        '?', 414,
        '~', 414,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(43);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 44:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '$', 403,
        '%', 584,
        '\'', 605,
        '(', 458,
        '0', 587,
        '[', 485,
        '\\', 198,
        '`', 818,
        'a', 742,
        'i', 748,
        'l', 701,
        'm', 679,
        '{', 508,
        '+', 599,
        '-', 599,
        '?', 414,
        '~', 414,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(44);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 45:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '$', 403,
        '\'', 605,
        '(', 458,
        ')', 459,
        '.', 819,
        '0', 587,
        ':', 489,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        '{', 508,
        '~', 449,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(45);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 46:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '$', 403,
        '\'', 605,
        '(', 458,
        ')', 459,
        '.', 819,
        '0', 587,
        ':', 452,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        '{', 508,
        '~', 449,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(45);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 47:
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '$', 403,
        '\'', 605,
        '(', 458,
        '.', 819,
        '0', 587,
        '[', 484,
        '\\', 198,
        '`', 818,
        'l', 701,
        'm', 679,
        '{', 508,
        '+', 599,
        '-', 599,
        '?', 414,
        '~', 414,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(47);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 48:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 248,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 655,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 730,
        'i', 743,
        'l', 683,
        'm', 677,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(48);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 49:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 655,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 806,
        'i', 743,
        'l', 683,
        'm', 677,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(49);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 50:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 655,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 806,
        'i', 753,
        'l', 683,
        'm', 677,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(50);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 51:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 655,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 732,
        'i', 743,
        'l', 683,
        'm', 677,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(51);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 52:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 655,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 732,
        'i', 753,
        'l', 683,
        'm', 677,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(52);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 53:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 655,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 788,
        'c', 737,
        'e', 806,
        'i', 753,
        'l', 683,
        'm', 677,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(53);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 54:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 655,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 788,
        'c', 737,
        'e', 732,
        'i', 753,
        'l', 683,
        'm', 677,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(54);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 55:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 655,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 730,
        'i', 753,
        'l', 683,
        'm', 677,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(55);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 56:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 655,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 751,
        'i', 743,
        'l', 683,
        'm', 677,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(56);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 57:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 655,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 751,
        'i', 753,
        'l', 683,
        'm', 677,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(57);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 58:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 655,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 788,
        'c', 737,
        'e', 730,
        'i', 753,
        'l', 683,
        'm', 677,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(58);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 59:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 655,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 788,
        'c', 737,
        'e', 751,
        'i', 753,
        'l', 683,
        'm', 677,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(59);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 60:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 655,
        '?', 451,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 806,
        'i', 743,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(60);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 61:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 655,
        '?', 451,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 806,
        'i', 753,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(61);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 62:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 655,
        '?', 451,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 732,
        'i', 743,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(62);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 63:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 655,
        '?', 451,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 732,
        'i', 753,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(63);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 64:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 655,
        '?', 451,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 788,
        'c', 737,
        'e', 806,
        'i', 753,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(64);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 65:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 655,
        '?', 451,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 788,
        'c', 737,
        'e', 732,
        'i', 753,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(65);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 66:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 655,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 730,
        'i', 743,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(66);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 67:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 655,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 730,
        'i', 753,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(67);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 68:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 655,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 751,
        'i', 743,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(68);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 69:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 655,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 751,
        'i', 753,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(69);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 70:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 655,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 788,
        'c', 737,
        'e', 730,
        'i', 753,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(70);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 71:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 655,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 788,
        'c', 737,
        'e', 751,
        'i', 753,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(71);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 72:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '0', 587,
        ':', 454,
        ';', 511,
        '<', 655,
        '?', 451,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 806,
        'i', 743,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(60);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 73:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '0', 587,
        ':', 454,
        ';', 511,
        '<', 655,
        '?', 451,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 806,
        'i', 753,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(61);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 74:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '0', 587,
        ':', 454,
        ';', 511,
        '<', 655,
        '?', 451,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 732,
        'i', 743,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(62);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 75:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '0', 587,
        ':', 454,
        ';', 511,
        '<', 655,
        '?', 451,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 732,
        'i', 753,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(63);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 76:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '0', 587,
        ':', 454,
        ';', 511,
        '<', 655,
        '?', 451,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 788,
        'c', 737,
        'e', 806,
        'i', 753,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(64);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 77:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '0', 587,
        ':', 454,
        ';', 511,
        '<', 655,
        '?', 451,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 788,
        'c', 737,
        'e', 732,
        'i', 753,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(65);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 78:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '0', 587,
        ':', 454,
        ';', 511,
        '<', 655,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 730,
        'i', 743,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(66);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 79:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '0', 587,
        ':', 454,
        ';', 511,
        '<', 655,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 730,
        'i', 753,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(67);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 80:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '0', 587,
        ':', 454,
        ';', 511,
        '<', 655,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 751,
        'i', 743,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(68);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 81:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '0', 587,
        ':', 454,
        ';', 511,
        '<', 655,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 751,
        'i', 753,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(69);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 82:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '0', 587,
        ':', 454,
        ';', 511,
        '<', 655,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 788,
        'c', 737,
        'e', 730,
        'i', 753,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(70);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 83:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 816,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '0', 587,
        ':', 454,
        ';', 511,
        '<', 655,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 788,
        'c', 737,
        'e', 751,
        'i', 753,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(71);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 84:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        ')', 459,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 603,
        '.', 499,
        '0', 587,
        ':', 494,
        ';', 510,
        '<', 654,
        '=', 658,
        '>', 656,
        '?', 451,
        '[', 484,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 788,
        'e', 733,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 477,
        '}', 512,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(84);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 85:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        ')', 459,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 603,
        '.', 499,
        '0', 587,
        ':', 494,
        ';', 510,
        '<', 654,
        '=', 658,
        '>', 656,
        '?', 451,
        '[', 484,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 788,
        'e', 733,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 476,
        '}', 512,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(85);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 86:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        ')', 459,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 603,
        '.', 499,
        '0', 587,
        ':', 494,
        ';', 510,
        '<', 654,
        '=', 658,
        '>', 656,
        '?', 451,
        '[', 484,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 788,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 477,
        '}', 512,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(86);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 87:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        ')', 459,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 603,
        '.', 499,
        '0', 587,
        ':', 494,
        ';', 510,
        '<', 654,
        '=', 658,
        '>', 656,
        '?', 451,
        '[', 484,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 788,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 476,
        '}', 512,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(87);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 88:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 654,
        '?', 451,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 806,
        'i', 743,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(88);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 89:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 654,
        '?', 451,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 806,
        'i', 753,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(89);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 90:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 654,
        '?', 451,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 732,
        'i', 743,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(90);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 91:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 654,
        '?', 451,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 732,
        'i', 753,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(91);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 92:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 654,
        '?', 451,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 788,
        'c', 737,
        'e', 806,
        'i', 753,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(92);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 93:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 654,
        '?', 451,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 788,
        'c', 737,
        'e', 732,
        'i', 753,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(93);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 94:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 654,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 730,
        'i', 743,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(94);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 95:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 654,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 730,
        'i', 753,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(95);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 96:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 654,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 751,
        'i', 743,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(96);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 97:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 654,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 741,
        'c', 737,
        'e', 751,
        'i', 753,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(97);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 98:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 654,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 788,
        'c', 737,
        'e', 730,
        'i', 753,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(98);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 99:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 511,
        '<', 654,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 788,
        'c', 737,
        'e', 751,
        'i', 753,
        'l', 683,
        'm', 771,
        'o', 775,
        't', 808,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(99);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 100:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 788,
        'c', 767,
        'e', 731,
        'i', 747,
        'l', 685,
        'm', 710,
        'o', 779,
        'v', 671,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(100);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 101:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 788,
        'c', 767,
        'e', 752,
        'i', 747,
        'l', 685,
        'm', 710,
        'o', 779,
        'v', 671,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(101);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 102:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'd', 763,
        'e', 733,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(102);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 103:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'd', 763,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(103);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 104:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'd', 765,
        'e', 733,
        'l', 685,
        'm', 772,
        'o', 779,
        't', 764,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(104);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 105:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'd', 765,
        'l', 685,
        'm', 772,
        'o', 779,
        't', 764,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(105);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 106:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'd', 774,
        'e', 733,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(106);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 107:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'd', 774,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(107);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 108:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'e', 731,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(108);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 109:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'e', 733,
        'l', 685,
        'm', 772,
        'o', 779,
        't', 723,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(109);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 110:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'e', 733,
        'l', 685,
        'm', 772,
        'o', 779,
        'w', 726,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(110);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 111:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'e', 752,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(111);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 112:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'l', 685,
        'm', 772,
        'o', 779,
        't', 723,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(112);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 113:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'l', 685,
        'm', 772,
        'o', 779,
        'w', 726,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(113);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 114:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 485,
        '\\', 198,
        '`', 818,
        'a', 741,
        'e', 733,
        'i', 748,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(114);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 115:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 485,
        '\\', 198,
        '`', 818,
        'a', 741,
        'i', 748,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(115);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 116:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 454,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 788,
        'c', 767,
        'e', 731,
        'i', 747,
        'l', 685,
        'm', 710,
        'o', 779,
        'v', 671,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(100);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 117:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 454,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 788,
        'c', 767,
        'e', 752,
        'i', 747,
        'l', 685,
        'm', 710,
        'o', 779,
        'v', 671,
        '{', 506,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(101);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 118:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 454,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'd', 763,
        'e', 733,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(102);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 119:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 454,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'd', 763,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(103);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 120:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 454,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'd', 765,
        'e', 733,
        'l', 685,
        'm', 772,
        'o', 779,
        't', 764,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(104);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 121:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 454,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'd', 765,
        'l', 685,
        'm', 772,
        'o', 779,
        't', 764,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(105);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 122:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 454,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'd', 774,
        'e', 733,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(106);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 123:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 454,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'd', 774,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(107);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 124:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 454,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'e', 731,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(108);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 125:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 454,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'e', 733,
        'l', 685,
        'm', 772,
        'o', 779,
        't', 723,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(109);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 126:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 454,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'e', 733,
        'l', 685,
        'm', 772,
        'o', 779,
        'w', 726,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(110);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 127:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 454,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'e', 752,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(111);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 128:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 454,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'l', 685,
        'm', 772,
        'o', 779,
        't', 723,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(112);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 129:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 454,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'l', 685,
        'm', 772,
        'o', 779,
        'w', 726,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(113);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 130:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 454,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 485,
        '\\', 198,
        '`', 818,
        'a', 741,
        'e', 733,
        'i', 748,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(114);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 131:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 454,
        ';', 510,
        '<', 654,
        '?', 451,
        '[', 485,
        '\\', 198,
        '`', 818,
        'a', 741,
        'i', 748,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 477,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(115);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 132:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '&', 661,
        '\'', 605,
        '(', 458,
        ')', 459,
        '*', 643,
        '+', 601,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        '<', 655,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 758,
        'e', 807,
        'l', 684,
        'm', 677,
        'o', 779,
        't', 808,
        '{', 507,
        '|', 392,
        '%', 646,
        '/', 646,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '$', 658,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(132);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 133:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '&', 661,
        '\'', 605,
        '(', 458,
        ')', 459,
        '*', 643,
        '+', 601,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        '<', 655,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 758,
        'e', 807,
        'l', 684,
        'm', 677,
        'o', 779,
        '{', 507,
        '|', 392,
        '%', 646,
        '/', 646,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '$', 658,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(133);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 134:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 550,
        '&', 661,
        '\'', 605,
        '(', 458,
        ')', 459,
        '*', 643,
        '+', 601,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        '<', 655,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 758,
        'l', 684,
        'm', 677,
        'o', 779,
        '{', 507,
        '|', 392,
        '%', 646,
        '/', 646,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '$', 658,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(134);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 135:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '#', 413,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        ')', 459,
        '*', 643,
        '+', 601,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 655,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 758,
        'l', 683,
        'm', 677,
        'o', 779,
        '{', 508,
        '|', 268,
        '%', 646,
        '/', 646,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(135);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 136:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        ')', 459,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 655,
        '=', 658,
        '>', 656,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 788,
        'c', 767,
        'e', 731,
        'i', 747,
        'l', 683,
        'm', 674,
        'o', 779,
        'v', 671,
        '{', 506,
        '|', 477,
        '}', 512,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(136);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 137:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        ')', 459,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 603,
        '/', 646,
        '0', 587,
        ':', 494,
        ';', 510,
        '<', 655,
        '=', 658,
        '>', 656,
        '[', 484,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 788,
        'e', 733,
        'l', 683,
        'm', 678,
        'o', 779,
        '{', 508,
        '|', 477,
        '}', 512,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(137);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 138:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        ')', 459,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 603,
        '/', 646,
        '0', 587,
        ':', 494,
        ';', 510,
        '<', 655,
        '=', 658,
        '>', 656,
        '[', 484,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 788,
        'l', 683,
        'm', 678,
        'o', 779,
        '{', 508,
        '|', 477,
        '}', 512,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(138);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 139:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 655,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 788,
        'c', 767,
        'e', 752,
        'i', 747,
        'l', 683,
        'm', 674,
        'o', 779,
        'v', 671,
        '{', 506,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(139);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 140:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 655,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'd', 763,
        'e', 733,
        'l', 683,
        'm', 678,
        'o', 779,
        '{', 508,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(140);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 141:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 655,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'd', 763,
        'l', 683,
        'm', 678,
        'o', 779,
        '{', 508,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(141);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 142:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 655,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'd', 765,
        'e', 733,
        'l', 683,
        'm', 678,
        'o', 779,
        't', 764,
        '{', 508,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(142);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 143:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 655,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'd', 765,
        'l', 683,
        'm', 678,
        'o', 779,
        't', 764,
        '{', 508,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(143);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 144:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 655,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'd', 774,
        'e', 733,
        'l', 683,
        'm', 678,
        'o', 779,
        '{', 508,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(144);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 145:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 655,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'd', 774,
        'l', 683,
        'm', 678,
        'o', 779,
        '{', 508,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(145);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 146:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 655,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'e', 731,
        'l', 683,
        'm', 678,
        'o', 779,
        '{', 508,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(146);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 147:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 655,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'e', 733,
        'l', 683,
        'm', 678,
        'o', 779,
        't', 723,
        '{', 508,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(147);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 148:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 655,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'e', 733,
        'l', 683,
        'm', 678,
        'o', 779,
        'w', 726,
        '{', 508,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(148);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 149:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 655,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'e', 733,
        'l', 683,
        'm', 678,
        'o', 779,
        '{', 508,
        '|', 476,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(149);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 150:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 655,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'e', 752,
        'l', 683,
        'm', 678,
        'o', 779,
        '{', 508,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(150);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 151:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 655,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'l', 683,
        'm', 678,
        'o', 779,
        't', 723,
        '{', 508,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(151);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 152:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 655,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'l', 683,
        'm', 678,
        'o', 779,
        'w', 726,
        '{', 508,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(152);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 153:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 655,
        '[', 484,
        '\\', 198,
        '`', 818,
        'a', 788,
        'l', 683,
        'm', 678,
        'o', 779,
        '{', 508,
        '|', 476,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(153);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 154:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 655,
        '[', 485,
        '\\', 198,
        '`', 818,
        'a', 741,
        'e', 733,
        'i', 748,
        'l', 683,
        'm', 678,
        'o', 779,
        '{', 508,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(154);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 155:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '%', 585,
        '&', 661,
        '\'', 605,
        '(', 458,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '/', 646,
        '0', 587,
        ':', 253,
        ';', 510,
        '<', 655,
        '[', 485,
        '\\', 198,
        '`', 818,
        'a', 741,
        'i', 748,
        'l', 683,
        'm', 678,
        'o', 779,
        '{', 508,
        '|', 477,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(155);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 156:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        ')', 459,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 603,
        '0', 587,
        ':', 455,
        ';', 510,
        '<', 655,
        '=', 658,
        '>', 656,
        '?', 451,
        '[', 484,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 788,
        'e', 733,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 477,
        '}', 512,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(160);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 157:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        ')', 459,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 603,
        '0', 587,
        ':', 455,
        ';', 510,
        '<', 655,
        '=', 658,
        '>', 656,
        '?', 451,
        '[', 484,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 788,
        'e', 733,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 476,
        '}', 512,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(161);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 158:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        ')', 459,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 603,
        '0', 587,
        ':', 455,
        ';', 510,
        '<', 655,
        '=', 658,
        '>', 656,
        '?', 451,
        '[', 484,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 788,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 477,
        '}', 512,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(162);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 159:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        ')', 459,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 603,
        '0', 587,
        ':', 455,
        ';', 510,
        '<', 655,
        '=', 658,
        '>', 656,
        '?', 451,
        '[', 484,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 788,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 476,
        '}', 512,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(163);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 160:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        ')', 459,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 603,
        '0', 587,
        ':', 494,
        ';', 510,
        '<', 655,
        '=', 658,
        '>', 656,
        '?', 451,
        '[', 484,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 788,
        'e', 733,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 477,
        '}', 512,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(160);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 161:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        ')', 459,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 603,
        '0', 587,
        ':', 494,
        ';', 510,
        '<', 655,
        '=', 658,
        '>', 656,
        '?', 451,
        '[', 484,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 788,
        'e', 733,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 476,
        '}', 512,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(161);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 162:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        ')', 459,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 603,
        '0', 587,
        ':', 494,
        ';', 510,
        '<', 655,
        '=', 658,
        '>', 656,
        '?', 451,
        '[', 484,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 788,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 477,
        '}', 512,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(162);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 163:
      ADVANCE_MAP(
        '!', 633,
        '"', 610,
        '$', 657,
        '&', 661,
        '\'', 605,
        '(', 458,
        ')', 459,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 603,
        '0', 587,
        ':', 494,
        ';', 510,
        '<', 655,
        '=', 658,
        '>', 656,
        '?', 451,
        '[', 484,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 788,
        'l', 685,
        'm', 772,
        'o', 779,
        '{', 508,
        '|', 476,
        '}', 512,
        '~', 449,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(163);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 164:
      ADVANCE_MAP(
        '!', 633,
        '#', 413,
        '&', 661,
        ')', 459,
        '*', 643,
        '+', 601,
        '-', 602,
        '.', 499,
        ':', 259,
        '<', 655,
        '[', 263,
        'a', 344,
        'l', 272,
        'm', 277,
        'o', 364,
        '|', 392,
        '%', 646,
        '/', 646,
        '?', 414,
        '~', 414,
        '@', 652,
        '^', 652,
        '$', 658,
        '=', 658,
        '>', 658,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(164);
      END_STATE();
    case 165:
      ADVANCE_MAP(
        '"', 610,
        '#', 816,
        '\'', 605,
        '(', 458,
        ')', 459,
        ',', 466,
        '0', 587,
        ':', 490,
        ';', 254,
        '=', 447,
        '[', 238,
        '\\', 198,
        ']', 488,
        'c', 737,
        'e', 751,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 509,
        '|', 473,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(165);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 166:
      ADVANCE_MAP(
        '"', 610,
        '#', 816,
        '\'', 605,
        '(', 458,
        '0', 587,
        ':', 489,
        ';', 254,
        '=', 447,
        '[', 238,
        '\\', 198,
        ']', 488,
        'c', 737,
        'e', 806,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 509,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(166);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 167:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '%', 584,
        '\'', 605,
        '(', 458,
        ')', 459,
        '+', 598,
        ',', 466,
        '-', 604,
        '.', 499,
        '0', 587,
        ':', 490,
        ';', 510,
        '=', 447,
        '[', 484,
        '\\', 198,
        ']', 488,
        '`', 818,
        'e', 807,
        '{', 507,
        '|', 473,
        '}', 512,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(167);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 168:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '%', 584,
        '\'', 605,
        '(', 458,
        '0', 587,
        '[', 484,
        '\\', 198,
        '`', 818,
        'e', 807,
        'm', 768,
        'o', 776,
        '{', 507,
        '+', 598,
        '-', 598,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(168);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 169:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '%', 584,
        '\'', 605,
        '(', 458,
        '0', 587,
        '[', 484,
        '\\', 198,
        '`', 818,
        'o', 776,
        '{', 507,
        '+', 598,
        '-', 598,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(169);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 170:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        ')', 459,
        '*', 503,
        '+', 598,
        ',', 466,
        '-', 604,
        '.', 499,
        '0', 587,
        ':', 495,
        ';', 510,
        '=', 447,
        '?', 450,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'c', 767,
        'e', 752,
        'i', 747,
        'm', 711,
        'v', 671,
        '{', 505,
        '|', 473,
        '}', 512,
        '~', 448,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(170);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 171:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        ')', 459,
        '+', 598,
        ',', 466,
        '-', 604,
        '.', 499,
        '0', 587,
        ':', 495,
        ';', 510,
        '=', 447,
        '?', 450,
        '[', 484,
        '\\', 198,
        ']', 488,
        '`', 818,
        '{', 507,
        '|', 473,
        '}', 512,
        '~', 448,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(171);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 172:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        '*', 503,
        '+', 598,
        '-', 604,
        '.', 499,
        '0', 587,
        ':', 489,
        ';', 254,
        '=', 447,
        '?', 450,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 759,
        'c', 737,
        'e', 806,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 505,
        '|', 473,
        '~', 448,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(172);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 173:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        '*', 503,
        '+', 598,
        '-', 604,
        '.', 499,
        '0', 587,
        ':', 489,
        ';', 254,
        '=', 447,
        '?', 450,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 759,
        'c', 737,
        'e', 751,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 505,
        '|', 473,
        '~', 448,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(173);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 174:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        '*', 503,
        '+', 598,
        '-', 604,
        '.', 499,
        '0', 587,
        ':', 489,
        ';', 254,
        '=', 447,
        '?', 450,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 759,
        'c', 737,
        'e', 751,
        'i', 753,
        'm', 768,
        'o', 776,
        't', 808,
        'v', 671,
        '{', 505,
        '|', 473,
        '~', 448,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(174);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 175:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        '+', 598,
        ',', 466,
        '-', 604,
        '.', 248,
        '0', 587,
        ':', 495,
        ';', 510,
        '=', 447,
        '?', 450,
        '[', 484,
        '\\', 198,
        '`', 818,
        '{', 507,
        '|', 474,
        '~', 448,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(175);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 176:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        '+', 598,
        ',', 466,
        '-', 604,
        '.', 248,
        '0', 587,
        ':', 456,
        ';', 510,
        '=', 447,
        '?', 450,
        '[', 484,
        '\\', 198,
        '`', 818,
        '{', 507,
        '|', 474,
        '~', 448,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(175);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 177:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        ',', 466,
        '.', 499,
        '0', 587,
        ':', 495,
        ';', 254,
        '=', 447,
        '?', 450,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 742,
        'c', 737,
        'e', 806,
        'i', 743,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 505,
        '|', 473,
        '~', 448,
        '+', 598,
        '-', 598,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(177);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 178:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        ',', 466,
        '.', 499,
        '0', 587,
        ':', 495,
        ';', 254,
        '=', 447,
        '?', 450,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 742,
        'c', 737,
        'e', 806,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 505,
        '|', 473,
        '~', 448,
        '+', 598,
        '-', 598,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(178);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 179:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        ',', 466,
        '.', 499,
        '0', 587,
        ':', 495,
        ';', 254,
        '=', 447,
        '?', 450,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 742,
        'c', 737,
        'e', 751,
        'i', 743,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 505,
        '|', 473,
        '~', 448,
        '+', 598,
        '-', 598,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(179);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 180:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        ',', 466,
        '.', 499,
        '0', 587,
        ':', 495,
        ';', 254,
        '=', 447,
        '?', 450,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 742,
        'c', 737,
        'e', 751,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 505,
        '|', 473,
        '~', 448,
        '+', 598,
        '-', 598,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(180);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 181:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        ',', 466,
        '.', 499,
        '0', 587,
        ':', 495,
        '=', 447,
        '?', 450,
        '[', 485,
        '\\', 198,
        '`', 818,
        'a', 742,
        'i', 748,
        '{', 507,
        '|', 473,
        '~', 448,
        '+', 598,
        '-', 598,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(181);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 182:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        ',', 466,
        '.', 499,
        '0', 587,
        ':', 252,
        ';', 510,
        '[', 484,
        '\\', 198,
        '`', 818,
        'e', 807,
        '{', 507,
        '|', 474,
        '+', 598,
        '-', 598,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(182);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 183:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        ',', 466,
        '.', 248,
        '0', 587,
        ':', 495,
        ';', 254,
        '=', 447,
        '?', 450,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 742,
        'c', 737,
        'e', 806,
        'i', 743,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 505,
        '|', 473,
        '~', 448,
        '+', 598,
        '-', 598,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(183);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 184:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        ',', 466,
        '.', 248,
        '0', 587,
        ':', 495,
        ';', 254,
        '=', 447,
        '?', 450,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 742,
        'c', 737,
        'e', 806,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 505,
        '|', 473,
        '~', 448,
        '+', 598,
        '-', 598,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(184);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 185:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        ',', 466,
        '.', 248,
        '0', 587,
        ':', 495,
        ';', 254,
        '=', 447,
        '?', 450,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 742,
        'c', 737,
        'e', 751,
        'i', 743,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 505,
        '|', 473,
        '~', 448,
        '+', 598,
        '-', 598,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(185);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 186:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        ',', 466,
        '.', 248,
        '0', 587,
        ':', 495,
        ';', 254,
        '=', 447,
        '?', 450,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 742,
        'c', 737,
        'e', 751,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 505,
        '|', 473,
        '~', 448,
        '+', 598,
        '-', 598,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(186);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 187:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        ',', 466,
        '.', 248,
        '0', 587,
        ':', 495,
        '=', 447,
        '?', 450,
        '[', 485,
        '\\', 198,
        '`', 818,
        'a', 742,
        'i', 748,
        '{', 507,
        '|', 473,
        '~', 448,
        '+', 598,
        '-', 598,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(187);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 188:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        '.', 819,
        '0', 587,
        '[', 484,
        '\\', 198,
        '`', 818,
        'e', 807,
        '{', 507,
        '|', 473,
        '+', 598,
        '-', 598,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(188);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 189:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        '0', 587,
        ':', 489,
        ';', 254,
        '=', 447,
        '?', 450,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 759,
        'c', 737,
        'e', 806,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 505,
        '~', 448,
        '+', 598,
        '-', 598,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(189);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 190:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        '0', 587,
        ':', 489,
        ';', 254,
        '=', 447,
        '?', 450,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 759,
        'c', 737,
        'e', 751,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 505,
        '~', 448,
        '+', 598,
        '-', 598,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(190);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 191:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        '0', 587,
        ':', 489,
        ';', 254,
        '=', 447,
        '?', 450,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 759,
        'c', 737,
        'e', 751,
        'i', 753,
        'm', 768,
        'o', 776,
        't', 808,
        'v', 671,
        '{', 505,
        '~', 448,
        '+', 598,
        '-', 598,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(191);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 192:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        '0', 587,
        ':', 489,
        '=', 447,
        '?', 450,
        '[', 481,
        '\\', 198,
        '`', 818,
        'c', 767,
        'e', 752,
        'i', 747,
        'm', 711,
        'v', 671,
        '{', 505,
        '~', 448,
        '+', 598,
        '-', 598,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(192);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 193:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        '0', 587,
        ':', 452,
        ';', 254,
        '=', 447,
        '?', 450,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 759,
        'c', 737,
        'e', 806,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 505,
        '~', 448,
        '+', 598,
        '-', 598,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(189);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 194:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        '0', 587,
        ':', 452,
        ';', 254,
        '=', 447,
        '?', 450,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 759,
        'c', 737,
        'e', 751,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 505,
        '~', 448,
        '+', 598,
        '-', 598,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(190);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 195:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        '0', 587,
        ':', 452,
        ';', 254,
        '=', 447,
        '?', 450,
        '[', 481,
        '\\', 198,
        '`', 818,
        'a', 759,
        'c', 737,
        'e', 751,
        'i', 753,
        'm', 768,
        'o', 776,
        't', 808,
        'v', 671,
        '{', 505,
        '~', 448,
        '+', 598,
        '-', 598,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(191);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 196:
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        '0', 587,
        ':', 452,
        '=', 447,
        '?', 450,
        '[', 481,
        '\\', 198,
        '`', 818,
        'c', 767,
        'e', 752,
        'i', 747,
        'm', 711,
        'v', 671,
        '{', 505,
        '~', 448,
        '+', 598,
        '-', 598,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(192);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 197:
      if (lookahead == '"') ADVANCE(610);
      if (lookahead == '%') ADVANCE(613);
      if (lookahead == '@') ADVANCE(614);
      if (lookahead == '[') ADVANCE(615);
      if (lookahead == '\\') ADVANCE(3);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(611);
      if (lookahead != 0) ADVANCE(616);
      END_STATE();
    case 198:
      if (lookahead == '#') ADVANCE(418);
      END_STATE();
    case 199:
      ADVANCE_MAP(
        '#', 816,
        '(', 458,
        '*', 503,
        '-', 260,
        ':', 489,
        ';', 254,
        '=', 447,
        '[', 486,
        '\\', 198,
        ']', 488,
        'a', 759,
        'c', 736,
        'e', 806,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 239,
        '|', 473,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(199);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 200:
      ADVANCE_MAP(
        '#', 816,
        '(', 458,
        '*', 503,
        '-', 260,
        ':', 489,
        ';', 254,
        '=', 447,
        '[', 486,
        '\\', 198,
        'a', 759,
        'c', 736,
        'e', 751,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 239,
        '|', 473,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(200);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 201:
      ADVANCE_MAP(
        '#', 816,
        '(', 458,
        ':', 489,
        ';', 254,
        '=', 447,
        '[', 486,
        '\\', 198,
        ']', 488,
        'a', 759,
        'c', 737,
        'e', 806,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 239,
        '|', 473,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(201);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 202:
      ADVANCE_MAP(
        '#', 816,
        '(', 458,
        ':', 489,
        ';', 254,
        '=', 447,
        '[', 486,
        '\\', 198,
        'a', 759,
        'c', 737,
        'e', 751,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 239,
        '|', 473,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(202);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 203:
      ADVANCE_MAP(
        '#', 816,
        '*', 503,
        '-', 260,
        ':', 256,
        ';', 254,
        '=', 447,
        '[', 238,
        '\\', 198,
        ']', 488,
        'a', 759,
        'c', 736,
        'e', 806,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        'w', 726,
        '{', 239,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(203);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 204:
      ADVANCE_MAP(
        '#', 816,
        '*', 503,
        '-', 260,
        ':', 256,
        ';', 254,
        '=', 447,
        '[', 238,
        '\\', 198,
        'a', 759,
        'c', 736,
        'e', 751,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        'w', 726,
        '{', 239,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(204);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 205:
      ADVANCE_MAP(
        '#', 550,
        '(', 458,
        '*', 503,
        '-', 260,
        '.', 499,
        ':', 496,
        ';', 510,
        '=', 447,
        '[', 235,
        'a', 341,
        'c', 355,
        'i', 336,
        'w', 313,
        '{', 236,
        '}', 512,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(205);
      END_STATE();
    case 206:
      ADVANCE_MAP(
        '#', 550,
        ')', 459,
        ',', 466,
        '-', 260,
        '.', 500,
        ':', 490,
        ';', 510,
        '=', 447,
        '[', 263,
        '\\', 198,
        ']', 488,
        'w', 726,
        '|', 473,
        '}', 512,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(206);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 207:
      ADVANCE_MAP(
        '#', 550,
        ')', 459,
        ',', 466,
        '-', 260,
        '.', 499,
        ':', 490,
        ';', 510,
        '=', 447,
        '[', 238,
        '\\', 198,
        ']', 488,
        'c', 767,
        'e', 752,
        'i', 747,
        'm', 711,
        'v', 671,
        'w', 726,
        '{', 239,
        '|', 473,
        '}', 512,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(207);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 208:
      ADVANCE_MAP(
        '#', 548,
        '%', 584,
        '\'', 817,
        '(', 458,
        ')', 459,
        '-', 260,
        '.', 819,
        ':', 252,
        '<', 546,
        '?', 450,
        '[', 482,
        '\\', 198,
        'm', 768,
        '{', 236,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(208);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 209:
      ADVANCE_MAP(
        '#', 548,
        '%', 584,
        '\'', 817,
        '(', 458,
        '<', 546,
        '?', 450,
        '[', 482,
        '\\', 198,
        't', 808,
        '{', 236,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(209);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 210:
      ADVANCE_MAP(
        '#', 548,
        '&', 544,
        '\'', 817,
        ')', 459,
        '*', 503,
        ',', 466,
        '-', 260,
        '.', 499,
        ':', 261,
        ';', 510,
        '=', 447,
        '>', 543,
        '[', 263,
        '\\', 198,
        ']', 488,
        '|', 473,
        '}', 512,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(210);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 211:
      ADVANCE_MAP(
        '#', 548,
        '\'', 817,
        '(', 458,
        '*', 503,
        '-', 260,
        '.', 499,
        ':', 489,
        ';', 254,
        '=', 447,
        '[', 486,
        '\\', 198,
        'a', 759,
        'c', 736,
        'e', 751,
        'i', 753,
        'm', 768,
        'o', 776,
        't', 808,
        'v', 671,
        '{', 239,
        '|', 473,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(211);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 212:
      ADVANCE_MAP(
        '#', 548,
        '\'', 817,
        '(', 458,
        '*', 503,
        '-', 260,
        '.', 499,
        ';', 254,
        '[', 486,
        '\\', 198,
        'a', 759,
        'c', 737,
        'e', 751,
        'i', 753,
        'm', 768,
        'o', 776,
        't', 808,
        'v', 671,
        '{', 239,
        '|', 473,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(212);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 213:
      ADVANCE_MAP(
        '#', 548,
        '\'', 817,
        '(', 458,
        '<', 546,
        '?', 450,
        '[', 482,
        '\\', 198,
        'l', 716,
        '{', 236,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(213);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 214:
      ADVANCE_MAP(
        '#', 548,
        '\'', 817,
        '*', 503,
        ',', 466,
        '-', 260,
        '.', 499,
        ':', 490,
        ';', 510,
        '=', 447,
        '[', 264,
        '\\', 198,
        'i', 748,
        '|', 474,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(214);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 215:
      ADVANCE_MAP(
        '#', 548,
        '\'', 817,
        '*', 503,
        '-', 260,
        '.', 499,
        ':', 489,
        ';', 254,
        '=', 447,
        '[', 238,
        '\\', 198,
        ']', 488,
        'a', 759,
        'c', 736,
        'e', 806,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 239,
        '|', 473,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(215);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 216:
      ADVANCE_MAP(
        '#', 548,
        '\'', 817,
        '*', 503,
        '-', 260,
        '.', 499,
        ':', 489,
        ';', 254,
        '=', 447,
        '[', 238,
        '\\', 198,
        'a', 759,
        'c', 736,
        'e', 751,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 239,
        '|', 473,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(216);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 217:
      ADVANCE_MAP(
        '#', 548,
        '\'', 817,
        '*', 503,
        '-', 260,
        '.', 499,
        ':', 489,
        ';', 254,
        '=', 447,
        '[', 238,
        '\\', 198,
        'c', 737,
        'e', 751,
        'i', 753,
        'm', 768,
        'o', 776,
        't', 808,
        'v', 671,
        '{', 239,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(217);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 218:
      ADVANCE_MAP(
        '#', 548,
        '\'', 817,
        '*', 503,
        '-', 260,
        '.', 499,
        ':', 489,
        '[', 238,
        '\\', 198,
        'c', 767,
        'e', 752,
        'i', 755,
        'm', 711,
        'v', 671,
        '{', 239,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(218);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 219:
      ADVANCE_MAP(
        '#', 548,
        '\'', 817,
        '*', 503,
        '-', 260,
        '.', 499,
        ':', 261,
        '=', 447,
        '[', 238,
        '\\', 198,
        'c', 767,
        'e', 752,
        'i', 747,
        'm', 711,
        'v', 671,
        '{', 239,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(219);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 220:
      ADVANCE_MAP(
        '#', 548,
        '\'', 817,
        '*', 503,
        '-', 260,
        '.', 499,
        ';', 254,
        '[', 238,
        '\\', 198,
        ']', 488,
        'a', 759,
        'c', 737,
        'e', 806,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 239,
        '|', 473,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(220);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 221:
      ADVANCE_MAP(
        '#', 548,
        '\'', 817,
        '*', 503,
        '-', 260,
        '.', 499,
        ';', 254,
        '[', 238,
        '\\', 198,
        ']', 488,
        'c', 737,
        'e', 806,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 239,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(221);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 222:
      ADVANCE_MAP(
        '#', 548,
        '\'', 817,
        '*', 503,
        '-', 260,
        '.', 499,
        ';', 254,
        '[', 238,
        '\\', 198,
        'a', 759,
        'c', 737,
        'e', 751,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 239,
        '|', 473,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(222);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 223:
      ADVANCE_MAP(
        '#', 548,
        '\'', 817,
        '*', 503,
        '-', 260,
        '.', 499,
        ';', 254,
        '[', 238,
        '\\', 198,
        'c', 737,
        'e', 751,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        '{', 239,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(223);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 224:
      ADVANCE_MAP(
        '#', 548,
        ')', 459,
        '*', 503,
        '-', 260,
        ':', 498,
        '[', 263,
        '\\', 198,
        'a', 759,
        'c', 767,
        'w', 726,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(224);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 225:
      ADVANCE_MAP(
        '#', 548,
        '*', 503,
        '-', 260,
        ':', 496,
        ';', 254,
        '=', 447,
        '[', 238,
        '\\', 198,
        ']', 488,
        'a', 759,
        'c', 736,
        'e', 806,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        'w', 726,
        '{', 239,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(225);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 226:
      ADVANCE_MAP(
        '#', 548,
        '*', 503,
        '-', 260,
        ':', 496,
        ';', 254,
        '=', 447,
        '[', 238,
        '\\', 198,
        'a', 759,
        'c', 736,
        'e', 751,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        'w', 726,
        '{', 239,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(226);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 227:
      ADVANCE_MAP(
        '#', 548,
        '*', 503,
        '-', 260,
        ':', 496,
        ';', 254,
        '=', 447,
        '[', 238,
        '\\', 198,
        'a', 759,
        'c', 736,
        'e', 751,
        'i', 753,
        'm', 768,
        'o', 776,
        't', 808,
        'v', 671,
        'w', 726,
        '{', 239,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(227);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 228:
      ADVANCE_MAP(
        '#', 548,
        '*', 503,
        '-', 260,
        ':', 496,
        ';', 510,
        '=', 447,
        '>', 543,
        '[', 264,
        '\\', 198,
        'a', 759,
        'c', 767,
        'i', 748,
        'w', 726,
        '}', 512,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(228);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 229:
      if (lookahead == '%') ADVANCE(584);
      if (lookahead == '[') ADVANCE(487);
      if (lookahead == '\\') ADVANCE(198);
      if (lookahead == 't') ADVANCE(808);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(229);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 230:
      if (lookahead == '%') ADVANCE(578);
      if (lookahead == '@') ADVANCE(572);
      END_STATE();
    case 231:
      if (lookahead == '%') ADVANCE(580);
      END_STATE();
    case 232:
      if (lookahead == '%') ADVANCE(582);
      END_STATE();
    case 233:
      if (lookahead == '%') ADVANCE(583);
      END_STATE();
    case 234:
      if (lookahead == '%') ADVANCE(577);
      if (lookahead == '@') ADVANCE(571);
      END_STATE();
    case 235:
      if (lookahead == '%') ADVANCE(577);
      if (lookahead == '@') ADVANCE(573);
      END_STATE();
    case 236:
      if (lookahead == '%') ADVANCE(579);
      END_STATE();
    case 237:
      if (lookahead == '%') ADVANCE(620);
      if (lookahead == '@') ADVANCE(621);
      if (lookahead == '[') ADVANCE(622);
      if (lookahead == '|') ADVANCE(619);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(611);
      if (lookahead != 0) ADVANCE(623);
      END_STATE();
    case 238:
      if (lookahead == '%') ADVANCE(232);
      if (lookahead == '@') ADVANCE(572);
      END_STATE();
    case 239:
      if (lookahead == '%') ADVANCE(233);
      END_STATE();
    case 240:
      if (lookahead == '(') ADVANCE(458);
      if (lookahead == ')') ADVANCE(459);
      if (lookahead == '[') ADVANCE(234);
      if (lookahead == '\\') ADVANCE(198);
      if (lookahead == 'v') ADVANCE(671);
      if (lookahead == '{') ADVANCE(236);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(240);
      if (set_contains(sym_indexing_operator_character_set_1, 9, lookahead)) ADVANCE(667);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 241:
      ADVANCE_MAP(
        '(', 458,
        '.', 819,
        ':', 498,
        ';', 510,
        '=', 447,
        '>', 394,
        '[', 238,
        'c', 355,
        'e', 337,
        'i', 335,
        'm', 296,
        'v', 269,
        '{', 239,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(241);
      END_STATE();
    case 242:
      if (lookahead == '(') ADVANCE(458);
      if (lookahead == '.') ADVANCE(248);
      if (lookahead == '[') ADVANCE(487);
      if (lookahead == '\\') ADVANCE(198);
      if (lookahead == '{') ADVANCE(504);
      if (lookahead == '|') ADVANCE(473);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(242);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 243:
      if (lookahead == '(') ADVANCE(458);
      if (lookahead == '[') ADVANCE(487);
      if (lookahead == '\\') ADVANCE(198);
      if (lookahead == '{') ADVANCE(504);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(243);
      if (set_contains(sym_indexing_operator_character_set_1, 9, lookahead)) ADVANCE(667);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 244:
      if (lookahead == '*') ADVANCE(251);
      if (lookahead == '.') ADVANCE(245);
      if (lookahead == 'L' ||
          lookahead == 'l' ||
          lookahead == 'n') ADVANCE(629);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(250);
      if (set_contains(sym_conversion_specification_character_set_6, 15, lookahead)) ADVANCE(628);
      END_STATE();
    case 245:
      if (lookahead == '*') ADVANCE(399);
      if (lookahead == 'L' ||
          lookahead == 'l' ||
          lookahead == 'n') ADVANCE(629);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(398);
      if (set_contains(sym_conversion_specification_character_set_7, 16, lookahead)) ADVANCE(628);
      END_STATE();
    case 246:
      ADVANCE_MAP(
        ',', 466,
        '.', 499,
        ':', 490,
        ';', 510,
        '=', 447,
        '[', 264,
        '\\', 198,
        ']', 488,
        'i', 748,
        '|', 473,
        '}', 512,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(246);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 247:
      if (lookahead == '-') ADVANCE(554);
      END_STATE();
    case 248:
      if (lookahead == '.') ADVANCE(464);
      END_STATE();
    case 249:
      if (lookahead == '.') ADVANCE(819);
      if (lookahead == '[') ADVANCE(263);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(581);
      END_STATE();
    case 250:
      if (lookahead == '.') ADVANCE(245);
      if (lookahead == 'L' ||
          lookahead == 'l' ||
          lookahead == 'n') ADVANCE(629);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(250);
      if (set_contains(sym_conversion_specification_character_set_7, 16, lookahead)) ADVANCE(628);
      END_STATE();
    case 251:
      if (lookahead == '.') ADVANCE(245);
      if (lookahead == 'L' ||
          lookahead == 'l' ||
          lookahead == 'n') ADVANCE(629);
      if (set_contains(sym_conversion_specification_character_set_6, 15, lookahead)) ADVANCE(628);
      END_STATE();
    case 252:
      if (lookahead == ':') ADVANCE(551);
      END_STATE();
    case 253:
      if (lookahead == ':') ADVANCE(551);
      if (lookahead == '=') ADVANCE(666);
      END_STATE();
    case 254:
      if (lookahead == ';') ADVANCE(438);
      END_STATE();
    case 255:
      if (lookahead == '=') ADVANCE(465);
      END_STATE();
    case 256:
      if (lookahead == '=') ADVANCE(472);
      END_STATE();
    case 257:
      if (lookahead == '=') ADVANCE(472);
      if (lookahead == '>') ADVANCE(446);
      END_STATE();
    case 258:
      if (lookahead == '=') ADVANCE(653);
      END_STATE();
    case 259:
      if (lookahead == '=') ADVANCE(666);
      END_STATE();
    case 260:
      if (lookahead == '>') ADVANCE(501);
      END_STATE();
    case 261:
      if (lookahead == '>') ADVANCE(446);
      END_STATE();
    case 262:
      if (lookahead == '>') ADVANCE(630);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(262);
      END_STATE();
    case 263:
      if (lookahead == '@') ADVANCE(571);
      END_STATE();
    case 264:
      if (lookahead == '@') ADVANCE(573);
      END_STATE();
    case 265:
      if (lookahead == '[') ADVANCE(483);
      if (lookahead == '\\') ADVANCE(198);
      if (lookahead == 'l') ADVANCE(716);
      if (lookahead == '{') ADVANCE(236);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(265);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 266:
      if (lookahead == '[') ADVANCE(263);
      if (lookahead == '\\') ADVANCE(348);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(266);
      END_STATE();
    case 267:
      if (lookahead == ']') ADVANCE(553);
      END_STATE();
    case 268:
      if (lookahead == ']') ADVANCE(553);
      if (lookahead == '|') ADVANCE(664);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(658);
      END_STATE();
    case 269:
      if (lookahead == 'a') ADVANCE(321);
      END_STATE();
    case 270:
      if (lookahead == 'a') ADVANCE(374);
      END_STATE();
    case 271:
      if (lookahead == 'a') ADVANCE(340);
      if (lookahead == 'e') ADVANCE(376);
      if (lookahead == 'o') ADVANCE(366);
      if (lookahead == 's') ADVANCE(396);
      if (lookahead == 'x') ADVANCE(354);
      END_STATE();
    case 272:
      if (lookahead == 'a') ADVANCE(340);
      if (lookahead == 'e') ADVANCE(383);
      if (lookahead == 'o') ADVANCE(366);
      if (lookahead == 's') ADVANCE(396);
      if (lookahead == 'x') ADVANCE(354);
      END_STATE();
    case 273:
      if (lookahead == 'a') ADVANCE(340);
      if (lookahead == 'o') ADVANCE(366);
      if (lookahead == 's') ADVANCE(396);
      if (lookahead == 'x') ADVANCE(354);
      END_STATE();
    case 274:
      if (lookahead == 'a') ADVANCE(316);
      END_STATE();
    case 275:
      if (lookahead == 'a') ADVANCE(326);
      END_STATE();
    case 276:
      if (lookahead == 'a') ADVANCE(323);
      END_STATE();
    case 277:
      if (lookahead == 'a') ADVANCE(380);
      if (lookahead == 'o') ADVANCE(283);
      END_STATE();
    case 278:
      if (lookahead == 'c') ADVANCE(322);
      if (lookahead == 'h') ADVANCE(302);
      if (lookahead == 'i') ADVANCE(381);
      END_STATE();
    case 279:
      if (lookahead == 'c') ADVANCE(300);
      if (lookahead == 't') ADVANCE(301);
      END_STATE();
    case 280:
      if (lookahead == 'c') ADVANCE(308);
      END_STATE();
    case 281:
      if (lookahead == 'd') ADVANCE(443);
      END_STATE();
    case 282:
      if (lookahead == 'd') ADVANCE(527);
      END_STATE();
    case 283:
      if (lookahead == 'd') ADVANCE(642);
      END_STATE();
    case 284:
      if (lookahead == 'd') ADVANCE(645);
      END_STATE();
    case 285:
      if (lookahead == 'd') ADVANCE(533);
      END_STATE();
    case 286:
      if (lookahead == 'd') ADVANCE(442);
      END_STATE();
    case 287:
      if (lookahead == 'd') ADVANCE(408);
      END_STATE();
    case 288:
      if (lookahead == 'd') ADVANCE(387);
      END_STATE();
    case 289:
      if (lookahead == 'd') ADVANCE(294);
      END_STATE();
    case 290:
      if (lookahead == 'e') ADVANCE(376);
      END_STATE();
    case 291:
      if (lookahead == 'e') ADVANCE(558);
      END_STATE();
    case 292:
      if (lookahead == 'e') ADVANCE(462);
      END_STATE();
    case 293:
      if (lookahead == 'e') ADVANCE(517);
      END_STATE();
    case 294:
      if (lookahead == 'e') ADVANCE(521);
      END_STATE();
    case 295:
      if (lookahead == 'e') ADVANCE(562);
      END_STATE();
    case 296:
      if (lookahead == 'e') ADVANCE(377);
      END_STATE();
    case 297:
      if (lookahead == 'e') ADVANCE(377);
      if (lookahead == 'o') ADVANCE(284);
      END_STATE();
    case 298:
      if (lookahead == 'e') ADVANCE(377);
      if (lookahead == 'o') ADVANCE(283);
      END_STATE();
    case 299:
      if (lookahead == 'e') ADVANCE(377);
      if (lookahead == 'o') ADVANCE(288);
      END_STATE();
    case 300:
      if (lookahead == 'e') ADVANCE(362);
      END_STATE();
    case 301:
      if (lookahead == 'e') ADVANCE(369);
      END_STATE();
    case 302:
      if (lookahead == 'e') ADVANCE(370);
      END_STATE();
    case 303:
      if (lookahead == 'e') ADVANCE(331);
      END_STATE();
    case 304:
      if (lookahead == 'e') ADVANCE(332);
      END_STATE();
    case 305:
      if (lookahead == 'e') ADVANCE(367);
      END_STATE();
    case 306:
      if (lookahead == 'h') ADVANCE(529);
      END_STATE();
    case 307:
      if (lookahead == 'h') ADVANCE(358);
      END_STATE();
    case 308:
      if (lookahead == 'h') ADVANCE(410);
      END_STATE();
    case 309:
      if (lookahead == 'h') ADVANCE(302);
      if (lookahead == 'i') ADVANCE(381);
      END_STATE();
    case 310:
      if (lookahead == 'h') ADVANCE(304);
      END_STATE();
    case 311:
      if (lookahead == 'h') ADVANCE(304);
      if (lookahead == 'y') ADVANCE(363);
      END_STATE();
    case 312:
      if (lookahead == 'i') ADVANCE(390);
      END_STATE();
    case 313:
      if (lookahead == 'i') ADVANCE(382);
      END_STATE();
    case 314:
      if (lookahead == 'i') ADVANCE(359);
      END_STATE();
    case 315:
      if (lookahead == 'i') ADVANCE(378);
      END_STATE();
    case 316:
      if (lookahead == 'i') ADVANCE(343);
      END_STATE();
    case 317:
      if (lookahead == 'i') ADVANCE(275);
      END_STATE();
    case 318:
      if (lookahead == 'l') ADVANCE(373);
      END_STATE();
    case 319:
      if (lookahead == 'l') ADVANCE(373);
      if (lookahead == 'n') ADVANCE(282);
      END_STATE();
    case 320:
      if (lookahead == 'l') ADVANCE(373);
      if (lookahead == 'n') ADVANCE(282);
      if (lookahead == 'x') ADVANCE(279);
      END_STATE();
    case 321:
      if (lookahead == 'l') ADVANCE(525);
      END_STATE();
    case 322:
      if (lookahead == 'l') ADVANCE(388);
      END_STATE();
    case 323:
      if (lookahead == 'l') ADVANCE(460);
      END_STATE();
    case 324:
      if (lookahead == 'l') ADVANCE(270);
      END_STATE();
    case 325:
      if (lookahead == 'l') ADVANCE(270);
      if (lookahead == 'o') ADVANCE(339);
      END_STATE();
    case 326:
      if (lookahead == 'l') ADVANCE(312);
      END_STATE();
    case 327:
      if (lookahead == 'l') ADVANCE(293);
      END_STATE();
    case 328:
      if (lookahead == 'n') ADVANCE(630);
      END_STATE();
    case 329:
      if (lookahead == 'n') ADVANCE(281);
      if (lookahead == 's') ADVANCE(365);
      END_STATE();
    case 330:
      if (lookahead == 'n') ADVANCE(278);
      END_STATE();
    case 331:
      if (lookahead == 'n') ADVANCE(519);
      END_STATE();
    case 332:
      if (lookahead == 'n') ADVANCE(556);
      END_STATE();
    case 333:
      if (lookahead == 'n') ADVANCE(515);
      END_STATE();
    case 334:
      if (lookahead == 'n') ADVANCE(537);
      END_STATE();
    case 335:
      if (lookahead == 'n') ADVANCE(309);
      END_STATE();
    case 336:
      if (lookahead == 'n') ADVANCE(535);
      END_STATE();
    case 337:
      if (lookahead == 'n') ADVANCE(282);
      END_STATE();
    case 338:
      if (lookahead == 'n') ADVANCE(282);
      if (lookahead == 'x') ADVANCE(279);
      END_STATE();
    case 339:
      if (lookahead == 'n') ADVANCE(375);
      END_STATE();
    case 340:
      if (lookahead == 'n') ADVANCE(283);
      END_STATE();
    case 341:
      if (lookahead == 'n') ADVANCE(286);
      END_STATE();
    case 342:
      if (lookahead == 'n') ADVANCE(286);
      if (lookahead == 's') ADVANCE(365);
      END_STATE();
    case 343:
      if (lookahead == 'n') ADVANCE(379);
      END_STATE();
    case 344:
      if (lookahead == 'n') ADVANCE(287);
      if (lookahead == 's') ADVANCE(365);
      END_STATE();
    case 345:
      if (lookahead == 'n') ADVANCE(386);
      END_STATE();
    case 346:
      if (lookahead == 'n') ADVANCE(295);
      if (lookahead == 'w') ADVANCE(345);
      END_STATE();
    case 347:
      if (lookahead == 'n') ADVANCE(276);
      END_STATE();
    case 348:
      ADVANCE_MAP(
        'o', 400,
        'x', 417,
        ' ', 624,
        '"', 624,
        '\'', 624,
        '\\', 624,
        'b', 624,
        'n', 624,
        'r', 624,
        't', 624,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(407);
      END_STATE();
    case 349:
      if (lookahead == 'o') ADVANCE(560);
      END_STATE();
    case 350:
      if (lookahead == 'o') ADVANCE(346);
      END_STATE();
    case 351:
      if (lookahead == 'o') ADVANCE(564);
      END_STATE();
    case 352:
      if (lookahead == 'o') ADVANCE(564);
      if (lookahead == 'y') ADVANCE(363);
      END_STATE();
    case 353:
      if (lookahead == 'o') ADVANCE(566);
      END_STATE();
    case 354:
      if (lookahead == 'o') ADVANCE(366);
      END_STATE();
    case 355:
      if (lookahead == 'o') ADVANCE(339);
      END_STATE();
    case 356:
      if (lookahead == 'o') ADVANCE(284);
      END_STATE();
    case 357:
      if (lookahead == 'o') ADVANCE(283);
      END_STATE();
    case 358:
      if (lookahead == 'o') ADVANCE(285);
      END_STATE();
    case 359:
      if (lookahead == 'o') ADVANCE(333);
      END_STATE();
    case 360:
      if (lookahead == 'p') ADVANCE(303);
      END_STATE();
    case 361:
      if (lookahead == 'p') ADVANCE(303);
      if (lookahead == 'r') ADVANCE(663);
      END_STATE();
    case 362:
      if (lookahead == 'p') ADVANCE(384);
      END_STATE();
    case 363:
      if (lookahead == 'p') ADVANCE(292);
      END_STATE();
    case 364:
      if (lookahead == 'r') ADVANCE(663);
      END_STATE();
    case 365:
      if (lookahead == 'r') ADVANCE(639);
      END_STATE();
    case 366:
      if (lookahead == 'r') ADVANCE(642);
      END_STATE();
    case 367:
      if (lookahead == 'r') ADVANCE(539);
      END_STATE();
    case 368:
      if (lookahead == 'r') ADVANCE(274);
      END_STATE();
    case 369:
      if (lookahead == 'r') ADVANCE(347);
      END_STATE();
    case 370:
      if (lookahead == 'r') ADVANCE(315);
      END_STATE();
    case 371:
      if (lookahead == 's') ADVANCE(365);
      END_STATE();
    case 372:
      if (lookahead == 's') ADVANCE(523);
      END_STATE();
    case 373:
      if (lookahead == 's') ADVANCE(291);
      END_STATE();
    case 374:
      if (lookahead == 's') ADVANCE(372);
      END_STATE();
    case 375:
      if (lookahead == 's') ADVANCE(385);
      END_STATE();
    case 376:
      if (lookahead == 't') ADVANCE(439);
      END_STATE();
    case 377:
      if (lookahead == 't') ADVANCE(307);
      END_STATE();
    case 378:
      if (lookahead == 't') ADVANCE(531);
      END_STATE();
    case 379:
      if (lookahead == 't') ADVANCE(513);
      END_STATE();
    case 380:
      if (lookahead == 't') ADVANCE(280);
      END_STATE();
    case 381:
      if (lookahead == 't') ADVANCE(317);
      END_STATE();
    case 382:
      if (lookahead == 't') ADVANCE(306);
      END_STATE();
    case 383:
      if (lookahead == 't') ADVANCE(409);
      END_STATE();
    case 384:
      if (lookahead == 't') ADVANCE(314);
      END_STATE();
    case 385:
      if (lookahead == 't') ADVANCE(368);
      END_STATE();
    case 386:
      if (lookahead == 't') ADVANCE(353);
      END_STATE();
    case 387:
      if (lookahead == 'u') ADVANCE(327);
      END_STATE();
    case 388:
      if (lookahead == 'u') ADVANCE(289);
      END_STATE();
    case 389:
      if (lookahead == 'y') ADVANCE(363);
      END_STATE();
    case 390:
      if (lookahead == 'z') ADVANCE(305);
      END_STATE();
    case 391:
      if (lookahead == '{') ADVANCE(415);
      END_STATE();
    case 392:
      if (lookahead == '|') ADVANCE(664);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(658);
      END_STATE();
    case 393:
      if (lookahead == '}') ADVANCE(617);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(393);
      END_STATE();
    case 394:
      if (lookahead == '}') ADVANCE(569);
      END_STATE();
    case 395:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(404);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(596);
      END_STATE();
    case 396:
      if (lookahead == 'l' ||
          lookahead == 'r') ADVANCE(639);
      END_STATE();
    case 397:
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(593);
      END_STATE();
    case 398:
      if (lookahead == 'L' ||
          lookahead == 'l' ||
          lookahead == 'n') ADVANCE(629);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(398);
      if (set_contains(sym_conversion_specification_character_set_7, 16, lookahead)) ADVANCE(628);
      END_STATE();
    case 399:
      if (lookahead == 'L' ||
          lookahead == 'l' ||
          lookahead == 'n') ADVANCE(629);
      if (set_contains(sym_conversion_specification_character_set_6, 15, lookahead)) ADVANCE(628);
      END_STATE();
    case 400:
      if (('0' <= lookahead && lookahead <= '3')) ADVANCE(402);
      END_STATE();
    case 401:
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(627);
      END_STATE();
    case 402:
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(401);
      END_STATE();
    case 403:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(570);
      END_STATE();
    case 404:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(596);
      END_STATE();
    case 405:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(262);
      END_STATE();
    case 406:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(625);
      END_STATE();
    case 407:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(406);
      END_STATE();
    case 408:
      if (set_contains(sym_let_operator_character_set_1, 9, lookahead)) ADVANCE(669);
      END_STATE();
    case 409:
      if (set_contains(sym_let_operator_character_set_1, 9, lookahead)) ADVANCE(668);
      END_STATE();
    case 410:
      if (set_contains(sym_let_operator_character_set_1, 9, lookahead)) ADVANCE(670);
      END_STATE();
    case 411:
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(658);
      END_STATE();
    case 412:
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(649);
      END_STATE();
    case 413:
      if (set_contains(sym_prefix_operator_character_set_1, 9, lookahead)) ADVANCE(638);
      END_STATE();
    case 414:
      if (set_contains(sym_prefix_operator_character_set_1, 9, lookahead)) ADVANCE(634);
      END_STATE();
    case 415:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(393);
      END_STATE();
    case 416:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(626);
      END_STATE();
    case 417:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(416);
      END_STATE();
    case 418:
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 419:
      if (eof) ADVANCE(435);
      ADVANCE_MAP(
        '!', 469,
        '"', 610,
        '#', 549,
        '$', 403,
        '%', 584,
        '&', 545,
        '\'', 605,
        '(', 458,
        ')', 459,
        '*', 503,
        '+', 468,
        ',', 466,
        '-', 471,
        '.', 500,
        '0', 587,
        ':', 492,
        ';', 511,
        '<', 547,
        '=', 447,
        '>', 543,
        '?', 450,
        '@', 650,
        '[', 479,
        '\\', 2,
        ']', 488,
        '^', 652,
        '`', 818,
        'a', 742,
        'c', 736,
        'd', 763,
        'e', 730,
        'i', 743,
        'l', 701,
        'm', 673,
        'o', 775,
        't', 722,
        'v', 671,
        'w', 726,
        '{', 506,
        '|', 475,
        '}', 512,
        '~', 448,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(419);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 420:
      if (eof) ADVANCE(435);
      ADVANCE_MAP(
        '!', 258,
        '"', 610,
        '#', 816,
        '&', 661,
        '\'', 817,
        '(', 458,
        ')', 459,
        '*', 643,
        '+', 601,
        ',', 466,
        '-', 602,
        '.', 499,
        '0', 587,
        ':', 494,
        ';', 511,
        '<', 655,
        '>', 656,
        '[', 481,
        ']', 488,
        '`', 818,
        'a', 329,
        'c', 325,
        'd', 349,
        'e', 320,
        'i', 330,
        'l', 271,
        'm', 297,
        'o', 361,
        't', 311,
        'v', 269,
        'w', 313,
        '{', 505,
        '|', 477,
        '}', 512,
        '$', 658,
        '=', 658,
        '%', 646,
        '/', 646,
        '@', 652,
        '^', 652,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(420);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      END_STATE();
    case 421:
      if (eof) ADVANCE(435);
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '#', 550,
        '$', 403,
        '\'', 605,
        '(', 458,
        '*', 503,
        '-', 260,
        '.', 499,
        '0', 587,
        ':', 452,
        ';', 254,
        '=', 447,
        '?', 451,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 759,
        'c', 737,
        'e', 806,
        'i', 753,
        'm', 768,
        'o', 776,
        't', 808,
        'v', 671,
        '{', 506,
        '|', 473,
        '~', 449,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(422);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 422:
      if (eof) ADVANCE(435);
      ADVANCE_MAP(
        '!', 632,
        '"', 610,
        '#', 550,
        '$', 403,
        '\'', 605,
        '(', 458,
        '*', 503,
        '-', 260,
        '.', 499,
        '0', 587,
        ';', 254,
        '=', 447,
        '?', 451,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 759,
        'c', 737,
        'e', 806,
        'i', 753,
        'm', 768,
        'o', 776,
        't', 808,
        'v', 671,
        '{', 506,
        '|', 473,
        '~', 449,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(422);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 423:
      if (eof) ADVANCE(435);
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        '*', 503,
        '+', 598,
        '-', 604,
        '.', 499,
        '0', 587,
        ':', 489,
        ';', 254,
        '=', 447,
        '?', 450,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 759,
        'c', 737,
        'e', 806,
        'i', 753,
        'm', 768,
        'o', 776,
        't', 808,
        'v', 671,
        '{', 505,
        '|', 473,
        '~', 448,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(423);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 424:
      if (eof) ADVANCE(435);
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        '0', 587,
        ':', 489,
        ';', 254,
        '=', 447,
        '?', 450,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 759,
        'c', 737,
        'e', 806,
        'i', 753,
        'm', 768,
        'o', 776,
        't', 808,
        'v', 671,
        '{', 505,
        '~', 448,
        '+', 598,
        '-', 598,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(424);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 425:
      if (eof) ADVANCE(435);
      ADVANCE_MAP(
        '"', 610,
        '#', 548,
        '\'', 605,
        '(', 458,
        '0', 587,
        ':', 452,
        ';', 254,
        '=', 447,
        '?', 450,
        '[', 481,
        '\\', 198,
        ']', 488,
        '`', 818,
        'a', 759,
        'c', 737,
        'e', 806,
        'i', 753,
        'm', 768,
        'o', 776,
        't', 808,
        'v', 671,
        '{', 505,
        '~', 448,
        '+', 598,
        '-', 598,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(424);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 426:
      if (eof) ADVANCE(435);
      ADVANCE_MAP(
        '#', 816,
        '%', 584,
        '(', 458,
        ')', 459,
        '*', 503,
        '+', 255,
        '-', 260,
        '.', 499,
        ':', 497,
        ';', 254,
        '=', 447,
        '[', 230,
        ']', 488,
        'a', 341,
        'c', 325,
        'e', 338,
        'i', 330,
        'l', 290,
        'm', 299,
        'o', 360,
        't', 389,
        'v', 269,
        'w', 313,
        '{', 231,
        '|', 473,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(426);
      END_STATE();
    case 427:
      if (eof) ADVANCE(435);
      ADVANCE_MAP(
        '#', 816,
        '&', 544,
        ')', 459,
        '*', 503,
        ',', 466,
        '-', 260,
        ':', 257,
        ';', 254,
        '=', 447,
        '>', 543,
        '[', 238,
        '\\', 198,
        ']', 488,
        'a', 759,
        'c', 736,
        'e', 751,
        'i', 750,
        'l', 701,
        'm', 709,
        'o', 776,
        't', 808,
        'v', 671,
        'w', 726,
        '{', 239,
        '|', 473,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(427);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 428:
      if (eof) ADVANCE(435);
      ADVANCE_MAP(
        '#', 816,
        '(', 458,
        ')', 459,
        ',', 466,
        '-', 260,
        '.', 499,
        ':', 490,
        ';', 254,
        '=', 447,
        '[', 238,
        '\\', 198,
        ']', 488,
        'a', 759,
        'c', 736,
        'e', 751,
        'i', 753,
        'l', 701,
        'm', 768,
        'o', 776,
        't', 808,
        'v', 671,
        '{', 239,
        '|', 473,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(428);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 429:
      if (eof) ADVANCE(435);
      ADVANCE_MAP(
        '#', 816,
        '(', 458,
        ')', 459,
        ',', 466,
        '-', 260,
        ':', 492,
        ';', 254,
        '=', 447,
        '[', 230,
        '\\', 198,
        ']', 488,
        'a', 759,
        'c', 736,
        'e', 751,
        'i', 749,
        'l', 701,
        'm', 709,
        'o', 776,
        't', 808,
        'v', 671,
        'w', 726,
        '{', 231,
        '|', 473,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(429);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 430:
      if (eof) ADVANCE(435);
      ADVANCE_MAP(
        '#', 816,
        ')', 459,
        ':', 489,
        ';', 254,
        '[', 238,
        '\\', 198,
        ']', 488,
        'a', 759,
        'c', 736,
        'e', 751,
        'i', 750,
        'l', 701,
        'm', 709,
        'o', 776,
        't', 808,
        'v', 671,
        '{', 239,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(430);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 431:
      if (eof) ADVANCE(435);
      ADVANCE_MAP(
        '#', 548,
        '\'', 817,
        '(', 458,
        ')', 459,
        '*', 503,
        ',', 466,
        '-', 260,
        '.', 499,
        ':', 491,
        ';', 254,
        '<', 546,
        '=', 447,
        '?', 450,
        '[', 480,
        '\\', 198,
        ']', 488,
        'c', 737,
        'e', 806,
        'i', 753,
        'm', 768,
        'o', 776,
        't', 808,
        'v', 671,
        '{', 231,
        '|', 473,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(431);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 432:
      if (eof) ADVANCE(435);
      ADVANCE_MAP(
        '#', 548,
        '\'', 817,
        '(', 458,
        '*', 503,
        '-', 260,
        '.', 499,
        ':', 489,
        ';', 254,
        '=', 447,
        '[', 486,
        '\\', 198,
        ']', 488,
        'a', 759,
        'c', 736,
        'e', 806,
        'i', 753,
        'm', 768,
        'o', 776,
        't', 808,
        'v', 671,
        '{', 239,
        '|', 473,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(432);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 433:
      if (eof) ADVANCE(435);
      ADVANCE_MAP(
        '#', 548,
        '\'', 817,
        '(', 458,
        '*', 503,
        '-', 260,
        '.', 499,
        ';', 254,
        '[', 486,
        '\\', 198,
        ']', 488,
        'a', 759,
        'c', 737,
        'e', 806,
        'i', 753,
        'm', 768,
        'o', 776,
        't', 808,
        'v', 671,
        '{', 239,
        '|', 473,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(433);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 434:
      if (eof) ADVANCE(435);
      ADVANCE_MAP(
        '#', 548,
        '*', 503,
        '-', 260,
        ':', 496,
        ';', 254,
        '=', 447,
        '[', 238,
        '\\', 198,
        ']', 488,
        'a', 759,
        'c', 736,
        'e', 806,
        'i', 753,
        'm', 768,
        'o', 776,
        't', 808,
        'v', 671,
        'w', 726,
        '{', 239,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(434);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(814);
      END_STATE();
    case 435:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 436:
      ACCEPT_TOKEN(sym_shebang);
      if (set_contains(sym_prefix_operator_character_set_1, 9, lookahead)) ADVANCE(436);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(437);
      END_STATE();
    case 437:
      ACCEPT_TOKEN(sym_shebang);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(437);
      END_STATE();
    case 438:
      ACCEPT_TOKEN(anon_sym_SEMI_SEMI);
      END_STATE();
    case 439:
      ACCEPT_TOKEN(anon_sym_let);
      if (set_contains(sym_let_operator_character_set_1, 9, lookahead)) ADVANCE(668);
      END_STATE();
    case 440:
      ACCEPT_TOKEN(anon_sym_let);
      if (set_contains(sym_let_operator_character_set_1, 9, lookahead)) ADVANCE(668);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 441:
      ACCEPT_TOKEN(anon_sym_let);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 442:
      ACCEPT_TOKEN(anon_sym_and);
      END_STATE();
    case 443:
      ACCEPT_TOKEN(anon_sym_and);
      if (set_contains(sym_let_operator_character_set_1, 9, lookahead)) ADVANCE(669);
      END_STATE();
    case 444:
      ACCEPT_TOKEN(anon_sym_and);
      if (set_contains(sym_let_operator_character_set_1, 9, lookahead)) ADVANCE(669);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 445:
      ACCEPT_TOKEN(anon_sym_and);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 446:
      ACCEPT_TOKEN(anon_sym_COLON_GT);
      END_STATE();
    case 447:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 448:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 449:
      ACCEPT_TOKEN(anon_sym_TILDE);
      if (set_contains(sym_prefix_operator_character_set_1, 9, lookahead)) ADVANCE(634);
      END_STATE();
    case 450:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 451:
      ACCEPT_TOKEN(anon_sym_QMARK);
      if (set_contains(sym_prefix_operator_character_set_1, 9, lookahead)) ADVANCE(634);
      END_STATE();
    case 452:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 453:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(551);
      if (lookahead == '=') ADVANCE(472);
      if (lookahead == '>') ADVANCE(446);
      END_STATE();
    case 454:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(551);
      if (lookahead == '=') ADVANCE(666);
      END_STATE();
    case 455:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(551);
      if (lookahead == '=') ADVANCE(666);
      if (lookahead == '>') ADVANCE(446);
      END_STATE();
    case 456:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(551);
      if (lookahead == '>') ADVANCE(446);
      END_STATE();
    case 457:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == '>') ADVANCE(446);
      END_STATE();
    case 458:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 459:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 460:
      ACCEPT_TOKEN(anon_sym_external);
      END_STATE();
    case 461:
      ACCEPT_TOKEN(anon_sym_external);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 462:
      ACCEPT_TOKEN(anon_sym_type);
      END_STATE();
    case 463:
      ACCEPT_TOKEN(anon_sym_type);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 464:
      ACCEPT_TOKEN(anon_sym_DOT_DOT);
      END_STATE();
    case 465:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 466:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 467:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 468:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '.') ADVANCE(635);
      if (lookahead == '=') ADVANCE(465);
      END_STATE();
    case 469:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 470:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 471:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '.') ADVANCE(635);
      if (lookahead == '>') ADVANCE(501);
      END_STATE();
    case 472:
      ACCEPT_TOKEN(anon_sym_COLON_EQ);
      END_STATE();
    case 473:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 474:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == ']') ADVANCE(553);
      END_STATE();
    case 475:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == ']') ADVANCE(553);
      if (lookahead == '|') ADVANCE(663);
      END_STATE();
    case 476:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == ']') ADVANCE(553);
      if (lookahead == '|') ADVANCE(664);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(658);
      END_STATE();
    case 477:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(664);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(658);
      END_STATE();
    case 478:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '%') ADVANCE(578);
      if (lookahead == '<') ADVANCE(542);
      if (lookahead == '>') ADVANCE(541);
      if (lookahead == '@') ADVANCE(612);
      if (lookahead == '|') ADVANCE(552);
      END_STATE();
    case 479:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '%') ADVANCE(578);
      if (lookahead == '<') ADVANCE(542);
      if (lookahead == '>') ADVANCE(541);
      if (lookahead == '@') ADVANCE(571);
      if (lookahead == '|') ADVANCE(552);
      END_STATE();
    case 480:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '%') ADVANCE(578);
      if (lookahead == '<') ADVANCE(542);
      if (lookahead == '>') ADVANCE(541);
      if (lookahead == '@') ADVANCE(572);
      END_STATE();
    case 481:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '%') ADVANCE(578);
      if (lookahead == '@') ADVANCE(572);
      if (lookahead == '|') ADVANCE(552);
      END_STATE();
    case 482:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '%') ADVANCE(577);
      if (lookahead == '<') ADVANCE(542);
      if (lookahead == '>') ADVANCE(541);
      if (lookahead == '@') ADVANCE(571);
      END_STATE();
    case 483:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '%') ADVANCE(577);
      if (lookahead == '@') ADVANCE(571);
      END_STATE();
    case 484:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '%') ADVANCE(577);
      if (lookahead == '@') ADVANCE(571);
      if (lookahead == '|') ADVANCE(552);
      END_STATE();
    case 485:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '%') ADVANCE(577);
      if (lookahead == '@') ADVANCE(573);
      if (lookahead == '|') ADVANCE(552);
      END_STATE();
    case 486:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '%') ADVANCE(232);
      if (lookahead == '@') ADVANCE(572);
      END_STATE();
    case 487:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '@') ADVANCE(571);
      END_STATE();
    case 488:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 489:
      ACCEPT_TOKEN(anon_sym_COLON2);
      END_STATE();
    case 490:
      ACCEPT_TOKEN(anon_sym_COLON2);
      if (lookahead == ':') ADVANCE(551);
      END_STATE();
    case 491:
      ACCEPT_TOKEN(anon_sym_COLON2);
      if (lookahead == ':') ADVANCE(551);
      if (lookahead == '=') ADVANCE(472);
      END_STATE();
    case 492:
      ACCEPT_TOKEN(anon_sym_COLON2);
      if (lookahead == ':') ADVANCE(551);
      if (lookahead == '=') ADVANCE(472);
      if (lookahead == '>') ADVANCE(446);
      END_STATE();
    case 493:
      ACCEPT_TOKEN(anon_sym_COLON2);
      if (lookahead == ':') ADVANCE(551);
      if (lookahead == '=') ADVANCE(666);
      END_STATE();
    case 494:
      ACCEPT_TOKEN(anon_sym_COLON2);
      if (lookahead == ':') ADVANCE(551);
      if (lookahead == '=') ADVANCE(666);
      if (lookahead == '>') ADVANCE(446);
      END_STATE();
    case 495:
      ACCEPT_TOKEN(anon_sym_COLON2);
      if (lookahead == ':') ADVANCE(551);
      if (lookahead == '>') ADVANCE(446);
      END_STATE();
    case 496:
      ACCEPT_TOKEN(anon_sym_COLON2);
      if (lookahead == '=') ADVANCE(472);
      END_STATE();
    case 497:
      ACCEPT_TOKEN(anon_sym_COLON2);
      if (lookahead == '=') ADVANCE(472);
      if (lookahead == '>') ADVANCE(446);
      END_STATE();
    case 498:
      ACCEPT_TOKEN(anon_sym_COLON2);
      if (lookahead == '>') ADVANCE(446);
      END_STATE();
    case 499:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 500:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(464);
      END_STATE();
    case 501:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      END_STATE();
    case 502:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(649);
      END_STATE();
    case 503:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 504:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 505:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      if (lookahead == '%') ADVANCE(580);
      END_STATE();
    case 506:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      if (lookahead == '%') ADVANCE(580);
      if (lookahead == '<') ADVANCE(568);
      END_STATE();
    case 507:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      if (lookahead == '%') ADVANCE(579);
      END_STATE();
    case 508:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      if (lookahead == '%') ADVANCE(579);
      if (lookahead == '<') ADVANCE(568);
      END_STATE();
    case 509:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      if (lookahead == '%') ADVANCE(233);
      END_STATE();
    case 510:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 511:
      ACCEPT_TOKEN(anon_sym_SEMI);
      if (lookahead == ';') ADVANCE(438);
      END_STATE();
    case 512:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 513:
      ACCEPT_TOKEN(anon_sym_constraint);
      END_STATE();
    case 514:
      ACCEPT_TOKEN(anon_sym_constraint);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 515:
      ACCEPT_TOKEN(anon_sym_exception);
      END_STATE();
    case 516:
      ACCEPT_TOKEN(anon_sym_exception);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 517:
      ACCEPT_TOKEN(anon_sym_module);
      END_STATE();
    case 518:
      ACCEPT_TOKEN(anon_sym_module);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 519:
      ACCEPT_TOKEN(anon_sym_open);
      END_STATE();
    case 520:
      ACCEPT_TOKEN(anon_sym_open);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 521:
      ACCEPT_TOKEN(anon_sym_include);
      END_STATE();
    case 522:
      ACCEPT_TOKEN(anon_sym_include);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 523:
      ACCEPT_TOKEN(anon_sym_class);
      END_STATE();
    case 524:
      ACCEPT_TOKEN(anon_sym_class);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 525:
      ACCEPT_TOKEN(anon_sym_val);
      END_STATE();
    case 526:
      ACCEPT_TOKEN(anon_sym_val);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 527:
      ACCEPT_TOKEN(anon_sym_end);
      END_STATE();
    case 528:
      ACCEPT_TOKEN(anon_sym_end);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 529:
      ACCEPT_TOKEN(anon_sym_with);
      END_STATE();
    case 530:
      ACCEPT_TOKEN(anon_sym_with);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 531:
      ACCEPT_TOKEN(anon_sym_inherit);
      END_STATE();
    case 532:
      ACCEPT_TOKEN(anon_sym_inherit);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 533:
      ACCEPT_TOKEN(anon_sym_method);
      END_STATE();
    case 534:
      ACCEPT_TOKEN(anon_sym_method);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 535:
      ACCEPT_TOKEN(anon_sym_in);
      END_STATE();
    case 536:
      ACCEPT_TOKEN(anon_sym_in);
      if (lookahead == 'c') ADVANCE(738);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 537:
      ACCEPT_TOKEN(anon_sym_in);
      if (lookahead == 'c') ADVANCE(322);
      END_STATE();
    case 538:
      ACCEPT_TOKEN(anon_sym_in);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 539:
      ACCEPT_TOKEN(anon_sym_initializer);
      END_STATE();
    case 540:
      ACCEPT_TOKEN(anon_sym_initializer);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 541:
      ACCEPT_TOKEN(anon_sym_LBRACK_GT);
      END_STATE();
    case 542:
      ACCEPT_TOKEN(anon_sym_LBRACK_LT);
      END_STATE();
    case 543:
      ACCEPT_TOKEN(anon_sym_GT);
      END_STATE();
    case 544:
      ACCEPT_TOKEN(anon_sym_AMP);
      END_STATE();
    case 545:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(660);
      END_STATE();
    case 546:
      ACCEPT_TOKEN(anon_sym_LT);
      END_STATE();
    case 547:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '-') ADVANCE(554);
      END_STATE();
    case 548:
      ACCEPT_TOKEN(anon_sym_POUND);
      END_STATE();
    case 549:
      ACCEPT_TOKEN(anon_sym_POUND);
      if (lookahead == '!') ADVANCE(436);
      if (set_contains(sym_prefix_operator_character_set_1, 9, lookahead)) ADVANCE(638);
      END_STATE();
    case 550:
      ACCEPT_TOKEN(anon_sym_POUND);
      if (set_contains(sym_prefix_operator_character_set_1, 9, lookahead)) ADVANCE(638);
      END_STATE();
    case 551:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      END_STATE();
    case 552:
      ACCEPT_TOKEN(anon_sym_LBRACK_PIPE);
      END_STATE();
    case 553:
      ACCEPT_TOKEN(anon_sym_PIPE_RBRACK);
      END_STATE();
    case 554:
      ACCEPT_TOKEN(anon_sym_LT_DASH);
      END_STATE();
    case 555:
      ACCEPT_TOKEN(anon_sym_LT_DASH);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(658);
      END_STATE();
    case 556:
      ACCEPT_TOKEN(anon_sym_then);
      END_STATE();
    case 557:
      ACCEPT_TOKEN(anon_sym_then);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 558:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 559:
      ACCEPT_TOKEN(anon_sym_else);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 560:
      ACCEPT_TOKEN(anon_sym_do);
      END_STATE();
    case 561:
      ACCEPT_TOKEN(anon_sym_do);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 562:
      ACCEPT_TOKEN(anon_sym_done);
      END_STATE();
    case 563:
      ACCEPT_TOKEN(anon_sym_done);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 564:
      ACCEPT_TOKEN(anon_sym_to);
      END_STATE();
    case 565:
      ACCEPT_TOKEN(anon_sym_to);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 566:
      ACCEPT_TOKEN(anon_sym_downto);
      END_STATE();
    case 567:
      ACCEPT_TOKEN(anon_sym_downto);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 568:
      ACCEPT_TOKEN(anon_sym_LBRACE_LT);
      END_STATE();
    case 569:
      ACCEPT_TOKEN(anon_sym_GT_RBRACE);
      END_STATE();
    case 570:
      ACCEPT_TOKEN(sym_ocamlyacc_value);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(570);
      END_STATE();
    case 571:
      ACCEPT_TOKEN(aux_sym_attribute_token1);
      END_STATE();
    case 572:
      ACCEPT_TOKEN(aux_sym_attribute_token1);
      if (lookahead == '@') ADVANCE(575);
      END_STATE();
    case 573:
      ACCEPT_TOKEN(aux_sym_attribute_token1);
      if (lookahead == '@') ADVANCE(574);
      END_STATE();
    case 574:
      ACCEPT_TOKEN(anon_sym_LBRACK_AT_AT);
      END_STATE();
    case 575:
      ACCEPT_TOKEN(anon_sym_LBRACK_AT_AT);
      if (lookahead == '@') ADVANCE(576);
      END_STATE();
    case 576:
      ACCEPT_TOKEN(anon_sym_LBRACK_AT_AT_AT);
      END_STATE();
    case 577:
      ACCEPT_TOKEN(anon_sym_LBRACK_PERCENT);
      END_STATE();
    case 578:
      ACCEPT_TOKEN(anon_sym_LBRACK_PERCENT);
      if (lookahead == '%') ADVANCE(582);
      END_STATE();
    case 579:
      ACCEPT_TOKEN(anon_sym_LBRACE_PERCENT);
      END_STATE();
    case 580:
      ACCEPT_TOKEN(anon_sym_LBRACE_PERCENT);
      if (lookahead == '%') ADVANCE(583);
      END_STATE();
    case 581:
      ACCEPT_TOKEN(aux_sym_quoted_extension_token1);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(581);
      END_STATE();
    case 582:
      ACCEPT_TOKEN(anon_sym_LBRACK_PERCENT_PERCENT);
      END_STATE();
    case 583:
      ACCEPT_TOKEN(anon_sym_LBRACE_PERCENT_PERCENT);
      END_STATE();
    case 584:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 585:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(646);
      END_STATE();
    case 586:
      ACCEPT_TOKEN(aux_sym_number_token1);
      END_STATE();
    case 587:
      ACCEPT_TOKEN(aux_sym_number_token1);
      ADVANCE_MAP(
        '.', 591,
        'B', 397,
        'b', 397,
        'E', 395,
        'e', 395,
        'O', 594,
        'o', 594,
        'X', 597,
        'x', 597,
      );
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(588);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(586);
      END_STATE();
    case 588:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == '.') ADVANCE(591);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(395);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(588);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(586);
      END_STATE();
    case 589:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == '.') ADVANCE(592);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(590);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(589);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(586);
      END_STATE();
    case 590:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(404);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(596);
      END_STATE();
    case 591:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(395);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(591);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(586);
      END_STATE();
    case 592:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(590);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(592);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(586);
      END_STATE();
    case 593:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == '0' ||
          lookahead == '1' ||
          lookahead == '_') ADVANCE(593);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(586);
      END_STATE();
    case 594:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(595);
      END_STATE();
    case 595:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (('0' <= lookahead && lookahead <= '7') ||
          lookahead == '_') ADVANCE(595);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(586);
      END_STATE();
    case 596:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(596);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(586);
      END_STATE();
    case 597:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(589);
      END_STATE();
    case 598:
      ACCEPT_TOKEN(aux_sym_signed_number_token1);
      END_STATE();
    case 599:
      ACCEPT_TOKEN(aux_sym_signed_number_token1);
      if (lookahead == '.') ADVANCE(635);
      END_STATE();
    case 600:
      ACCEPT_TOKEN(aux_sym_signed_number_token1);
      if (lookahead == '.') ADVANCE(635);
      if (lookahead == '>') ADVANCE(501);
      END_STATE();
    case 601:
      ACCEPT_TOKEN(aux_sym_signed_number_token1);
      if (lookahead == '.') ADVANCE(637);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(649);
      END_STATE();
    case 602:
      ACCEPT_TOKEN(aux_sym_signed_number_token1);
      if (lookahead == '.') ADVANCE(636);
      if (lookahead == '>') ADVANCE(412);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(648);
      END_STATE();
    case 603:
      ACCEPT_TOKEN(aux_sym_signed_number_token1);
      if (lookahead == '.') ADVANCE(636);
      if (lookahead == '>') ADVANCE(502);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(648);
      END_STATE();
    case 604:
      ACCEPT_TOKEN(aux_sym_signed_number_token1);
      if (lookahead == '>') ADVANCE(501);
      END_STATE();
    case 605:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 606:
      ACCEPT_TOKEN(anon_sym_SQUOTE2);
      END_STATE();
    case 607:
      ACCEPT_TOKEN(aux_sym_character_content_token1);
      END_STATE();
    case 608:
      ACCEPT_TOKEN(aux_sym_character_content_token2);
      END_STATE();
    case 609:
      ACCEPT_TOKEN(aux_sym_character_content_token2);
      if (lookahead == '@') ADVANCE(571);
      END_STATE();
    case 610:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 611:
      ACCEPT_TOKEN(aux_sym_string_content_token1);
      END_STATE();
    case 612:
      ACCEPT_TOKEN(aux_sym_string_content_token2);
      END_STATE();
    case 613:
      ACCEPT_TOKEN(aux_sym_string_content_token3);
      ADVANCE_MAP(
        '*', 251,
        '.', 245,
        'L', 629,
        'l', 629,
        'n', 629,
        ' ', 244,
        '#', 244,
        '+', 244,
        '-', 244,
        '0', 244,
      );
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(250);
      if (set_contains(sym_conversion_specification_character_set_7, 16, lookahead)) ADVANCE(628);
      END_STATE();
    case 614:
      ACCEPT_TOKEN(aux_sym_string_content_token3);
      ADVANCE_MAP(
        '<', 405,
        '\\', 328,
        ' ', 630,
        ',', 630,
        '.', 630,
        ';', 630,
        '?', 630,
        '[', 630,
        ']', 630,
        '{', 630,
        '}', 630,
      );
      END_STATE();
    case 615:
      ACCEPT_TOKEN(aux_sym_string_content_token3);
      if (lookahead == '@') ADVANCE(612);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '%' &&
          lookahead != '\\') ADVANCE(616);
      END_STATE();
    case 616:
      ACCEPT_TOKEN(aux_sym_string_content_token3);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '%' &&
          lookahead != '@' &&
          lookahead != '\\') ADVANCE(616);
      END_STATE();
    case 617:
      ACCEPT_TOKEN(aux_sym_string_content_token4);
      END_STATE();
    case 618:
      ACCEPT_TOKEN(aux_sym_string_content_token5);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(618);
      END_STATE();
    case 619:
      ACCEPT_TOKEN(aux_sym_quoted_string_content_token1);
      END_STATE();
    case 620:
      ACCEPT_TOKEN(aux_sym_quoted_string_content_token1);
      ADVANCE_MAP(
        '*', 251,
        '.', 245,
        'L', 629,
        'l', 629,
        'n', 629,
        ' ', 244,
        '#', 244,
        '+', 244,
        '-', 244,
        '0', 244,
      );
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(250);
      if (set_contains(sym_conversion_specification_character_set_7, 16, lookahead)) ADVANCE(628);
      END_STATE();
    case 621:
      ACCEPT_TOKEN(aux_sym_quoted_string_content_token1);
      ADVANCE_MAP(
        '<', 405,
        '\\', 328,
        ' ', 630,
        ',', 630,
        '.', 630,
        ';', 630,
        '?', 630,
        '[', 630,
        ']', 630,
        '{', 630,
        '}', 630,
      );
      END_STATE();
    case 622:
      ACCEPT_TOKEN(aux_sym_quoted_string_content_token1);
      if (lookahead == '@') ADVANCE(612);
      if (lookahead != 0 &&
          lookahead != '%' &&
          lookahead != '|') ADVANCE(623);
      END_STATE();
    case 623:
      ACCEPT_TOKEN(aux_sym_quoted_string_content_token1);
      if (lookahead != 0 &&
          lookahead != '%' &&
          lookahead != '@' &&
          lookahead != '|') ADVANCE(623);
      END_STATE();
    case 624:
      ACCEPT_TOKEN(aux_sym_escape_sequence_token1);
      END_STATE();
    case 625:
      ACCEPT_TOKEN(aux_sym_escape_sequence_token2);
      END_STATE();
    case 626:
      ACCEPT_TOKEN(aux_sym_escape_sequence_token3);
      END_STATE();
    case 627:
      ACCEPT_TOKEN(aux_sym_escape_sequence_token4);
      END_STATE();
    case 628:
      ACCEPT_TOKEN(sym_conversion_specification);
      END_STATE();
    case 629:
      ACCEPT_TOKEN(sym_conversion_specification);
      if (lookahead == 'X' ||
          lookahead == 'd' ||
          lookahead == 'i' ||
          lookahead == 'o' ||
          lookahead == 'u' ||
          lookahead == 'x') ADVANCE(628);
      END_STATE();
    case 630:
      ACCEPT_TOKEN(sym_pretty_printing_indication);
      END_STATE();
    case 631:
      ACCEPT_TOKEN(sym_pretty_printing_indication);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(652);
      END_STATE();
    case 632:
      ACCEPT_TOKEN(sym_prefix_operator);
      if (lookahead == '=') ADVANCE(414);
      if (set_contains(sym_prefix_operator_character_set_1, 9, lookahead)) ADVANCE(634);
      END_STATE();
    case 633:
      ACCEPT_TOKEN(sym_prefix_operator);
      if (lookahead == '=') ADVANCE(659);
      if (set_contains(sym_prefix_operator_character_set_1, 9, lookahead)) ADVANCE(634);
      END_STATE();
    case 634:
      ACCEPT_TOKEN(sym_prefix_operator);
      if (set_contains(sym_prefix_operator_character_set_1, 9, lookahead)) ADVANCE(634);
      END_STATE();
    case 635:
      ACCEPT_TOKEN(aux_sym_sign_operator_token1);
      END_STATE();
    case 636:
      ACCEPT_TOKEN(aux_sym_sign_operator_token1);
      if (lookahead == '>') ADVANCE(649);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(648);
      END_STATE();
    case 637:
      ACCEPT_TOKEN(aux_sym_sign_operator_token1);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(649);
      END_STATE();
    case 638:
      ACCEPT_TOKEN(sym_hash_operator);
      if (set_contains(sym_prefix_operator_character_set_1, 9, lookahead)) ADVANCE(638);
      END_STATE();
    case 639:
      ACCEPT_TOKEN(sym_pow_operator);
      END_STATE();
    case 640:
      ACCEPT_TOKEN(sym_pow_operator);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(640);
      END_STATE();
    case 641:
      ACCEPT_TOKEN(sym_pow_operator);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 642:
      ACCEPT_TOKEN(sym_mult_operator);
      END_STATE();
    case 643:
      ACCEPT_TOKEN(sym_mult_operator);
      if (lookahead == '*') ADVANCE(640);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(646);
      END_STATE();
    case 644:
      ACCEPT_TOKEN(sym_mult_operator);
      if (lookahead == 'u') ADVANCE(740);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 645:
      ACCEPT_TOKEN(sym_mult_operator);
      if (lookahead == 'u') ADVANCE(327);
      END_STATE();
    case 646:
      ACCEPT_TOKEN(sym_mult_operator);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(646);
      END_STATE();
    case 647:
      ACCEPT_TOKEN(sym_mult_operator);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 648:
      ACCEPT_TOKEN(aux_sym_add_operator_token1);
      if (lookahead == '>') ADVANCE(649);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(648);
      END_STATE();
    case 649:
      ACCEPT_TOKEN(aux_sym_add_operator_token1);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(649);
      END_STATE();
    case 650:
      ACCEPT_TOKEN(sym_concat_operator);
      ADVANCE_MAP(
        '<', 651,
        '\\', 328,
        '.', 631,
        '?', 631,
        ' ', 630,
        ',', 630,
        ';', 630,
        '[', 630,
        ']', 630,
        '{', 630,
        '}', 630,
      );
      if (lookahead == '!' ||
          ('$' <= lookahead && lookahead <= '&') ||
          ('*' <= lookahead && lookahead <= '/') ||
          (':' <= lookahead && lookahead <= '@') ||
          lookahead == '^' ||
          ('|' <= lookahead && lookahead <= '~')) ADVANCE(652);
      END_STATE();
    case 651:
      ACCEPT_TOKEN(sym_concat_operator);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(262);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(652);
      END_STATE();
    case 652:
      ACCEPT_TOKEN(sym_concat_operator);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(652);
      END_STATE();
    case 653:
      ACCEPT_TOKEN(sym_rel_operator);
      END_STATE();
    case 654:
      ACCEPT_TOKEN(sym_rel_operator);
      if (lookahead == '-') ADVANCE(555);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(658);
      END_STATE();
    case 655:
      ACCEPT_TOKEN(sym_rel_operator);
      if (lookahead == '-') ADVANCE(411);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(658);
      END_STATE();
    case 656:
      ACCEPT_TOKEN(sym_rel_operator);
      if (lookahead == '}') ADVANCE(569);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(658);
      END_STATE();
    case 657:
      ACCEPT_TOKEN(sym_rel_operator);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(570);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(658);
      END_STATE();
    case 658:
      ACCEPT_TOKEN(sym_rel_operator);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(658);
      END_STATE();
    case 659:
      ACCEPT_TOKEN(sym_rel_operator);
      if (set_contains(sym_prefix_operator_character_set_1, 9, lookahead)) ADVANCE(634);
      END_STATE();
    case 660:
      ACCEPT_TOKEN(sym_and_operator);
      END_STATE();
    case 661:
      ACCEPT_TOKEN(sym_and_operator);
      if (lookahead == '&') ADVANCE(662);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(658);
      END_STATE();
    case 662:
      ACCEPT_TOKEN(sym_and_operator);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(658);
      END_STATE();
    case 663:
      ACCEPT_TOKEN(sym_or_operator);
      END_STATE();
    case 664:
      ACCEPT_TOKEN(sym_or_operator);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(658);
      END_STATE();
    case 665:
      ACCEPT_TOKEN(sym_or_operator);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 666:
      ACCEPT_TOKEN(sym_assign_operator);
      END_STATE();
    case 667:
      ACCEPT_TOKEN(sym_indexing_operator);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(667);
      END_STATE();
    case 668:
      ACCEPT_TOKEN(sym_let_operator);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(668);
      END_STATE();
    case 669:
      ACCEPT_TOKEN(sym_let_and_operator);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(669);
      END_STATE();
    case 670:
      ACCEPT_TOKEN(sym_match_operator);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(670);
      END_STATE();
    case 671:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(734);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 672:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(789);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 673:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(792);
      if (lookahead == 'e') ADVANCE(793);
      if (lookahead == 'o') ADVANCE(694);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 674:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(792);
      if (lookahead == 'e') ADVANCE(793);
      if (lookahead == 'o') ADVANCE(696);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 675:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(792);
      if (lookahead == 'e') ADVANCE(793);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 676:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(792);
      if (lookahead == 'o') ADVANCE(694);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 677:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(792);
      if (lookahead == 'o') ADVANCE(697);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 678:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(792);
      if (lookahead == 'o') ADVANCE(696);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 679:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(792);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 680:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(727);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 681:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(735);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 682:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(739);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 683:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(756);
      if (lookahead == 'e') ADVANCE(791);
      if (lookahead == 'o') ADVANCE(781);
      if (lookahead == 's') ADVANCE(810);
      if (lookahead == 'x') ADVANCE(769);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 684:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(756);
      if (lookahead == 'e') ADVANCE(800);
      if (lookahead == 'o') ADVANCE(781);
      if (lookahead == 's') ADVANCE(810);
      if (lookahead == 'x') ADVANCE(769);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 685:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(756);
      if (lookahead == 'o') ADVANCE(781);
      if (lookahead == 's') ADVANCE(810);
      if (lookahead == 'x') ADVANCE(769);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 686:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'c') ADVANCE(738);
      if (lookahead == 'h') ADVANCE(714);
      if (lookahead == 'i') ADVANCE(801);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 687:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'c') ADVANCE(738);
      if (lookahead == 'h') ADVANCE(714);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 688:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'c') ADVANCE(738);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 689:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'c') ADVANCE(718);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 690:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'c') ADVANCE(708);
      if (lookahead == 't') ADVANCE(703);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 691:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'c') ADVANCE(708);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 692:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'd') ADVANCE(444);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 693:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'd') ADVANCE(528);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 694:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'd') ADVANCE(803);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 695:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'd') ADVANCE(534);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 696:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'd') ADVANCE(647);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 697:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'd') ADVANCE(644);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 698:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'd') ADVANCE(445);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 699:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'd') ADVANCE(811);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 700:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'd') ADVANCE(706);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 701:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(791);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 702:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(559);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 703:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(784);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 704:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(463);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 705:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(518);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 706:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(522);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 707:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(563);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 708:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(778);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 709:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(793);
      if (lookahead == 'o') ADVANCE(694);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 710:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(793);
      if (lookahead == 'o') ADVANCE(696);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 711:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(793);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 712:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(744);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 713:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(745);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 714:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(785);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 715:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(782);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 716:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(796);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 717:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'h') ADVANCE(530);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 718:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'h') ADVANCE(813);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 719:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'h') ADVANCE(770);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 720:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'h') ADVANCE(714);
      if (lookahead == 'i') ADVANCE(801);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 721:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'h') ADVANCE(714);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 722:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'h') ADVANCE(713);
      if (lookahead == 'o') ADVANCE(565);
      if (lookahead == 'y') ADVANCE(777);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 723:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'h') ADVANCE(713);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 724:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'i') ADVANCE(809);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 725:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'i') ADVANCE(773);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 726:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'i') ADVANCE(798);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 727:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'i') ADVANCE(757);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 728:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'i') ADVANCE(795);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 729:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'i') ADVANCE(682);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 730:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'l') ADVANCE(787);
      if (lookahead == 'n') ADVANCE(693);
      if (lookahead == 'x') ADVANCE(690);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 731:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'l') ADVANCE(787);
      if (lookahead == 'n') ADVANCE(693);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 732:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'l') ADVANCE(787);
      if (lookahead == 'x') ADVANCE(690);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 733:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'l') ADVANCE(787);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 734:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'l') ADVANCE(526);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 735:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'l') ADVANCE(461);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 736:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'l') ADVANCE(672);
      if (lookahead == 'o') ADVANCE(754);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 737:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'l') ADVANCE(672);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 738:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'l') ADVANCE(804);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 739:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'l') ADVANCE(724);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 740:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'l') ADVANCE(705);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 741:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(692);
      if (lookahead == 's') ADVANCE(780);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 742:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(692);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 743:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(536);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 744:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(520);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 745:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(557);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 746:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(516);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 747:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(720);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 748:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(538);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 749:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(687);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 750:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(686);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 751:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(693);
      if (lookahead == 'x') ADVANCE(690);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 752:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(693);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 753:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(688);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 754:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(790);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 755:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(721);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 756:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(696);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 757:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(794);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 758:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(699);
      if (lookahead == 's') ADVANCE(780);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 759:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(698);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 760:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(802);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 761:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(707);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 762:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(681);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 763:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'o') ADVANCE(561);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 764:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'o') ADVANCE(565);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 765:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'o') ADVANCE(805);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 766:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'o') ADVANCE(567);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 767:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'o') ADVANCE(754);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 768:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'o') ADVANCE(694);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 769:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'o') ADVANCE(781);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 770:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'o') ADVANCE(695);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 771:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'o') ADVANCE(697);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 772:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'o') ADVANCE(696);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 773:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'o') ADVANCE(746);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 774:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'o') ADVANCE(761);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 775:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'p') ADVANCE(712);
      if (lookahead == 'r') ADVANCE(665);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 776:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'p') ADVANCE(712);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 777:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'p') ADVANCE(704);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 778:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'p') ADVANCE(797);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 779:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'r') ADVANCE(665);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 780:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'r') ADVANCE(641);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 781:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'r') ADVANCE(647);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 782:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'r') ADVANCE(540);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 783:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'r') ADVANCE(680);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 784:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'r') ADVANCE(762);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 785:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'r') ADVANCE(728);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 786:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 's') ADVANCE(524);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 787:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 's') ADVANCE(702);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 788:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 's') ADVANCE(780);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 789:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 's') ADVANCE(786);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 790:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 's') ADVANCE(799);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 791:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 't') ADVANCE(440);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 792:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 't') ADVANCE(689);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 793:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 't') ADVANCE(719);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 794:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 't') ADVANCE(514);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 795:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 't') ADVANCE(532);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 796:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 't') ADVANCE(441);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 797:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 't') ADVANCE(725);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 798:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 't') ADVANCE(717);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 799:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 't') ADVANCE(783);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 800:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 't') ADVANCE(812);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 801:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 't') ADVANCE(729);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 802:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 't') ADVANCE(766);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 803:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'u') ADVANCE(740);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 804:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'u') ADVANCE(700);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 805:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'w') ADVANCE(760);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 806:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'x') ADVANCE(690);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 807:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'x') ADVANCE(691);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 808:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'y') ADVANCE(777);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 809:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'z') ADVANCE(715);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 810:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'l' ||
          lookahead == 'r') ADVANCE(641);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 811:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (set_contains(sym_let_operator_character_set_1, 9, lookahead)) ADVANCE(669);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 812:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (set_contains(sym_let_operator_character_set_1, 9, lookahead)) ADVANCE(668);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 813:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (set_contains(sym_let_operator_character_set_1, 9, lookahead)) ADVANCE(670);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 814:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(814);
      END_STATE();
    case 815:
      ACCEPT_TOKEN(sym__uppercase_identifier);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(815);
      END_STATE();
    case 816:
      ACCEPT_TOKEN(aux_sym_directive_token1);
      END_STATE();
    case 817:
      ACCEPT_TOKEN(aux_sym_type_variable_token1);
      END_STATE();
    case 818:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      END_STATE();
    case 819:
      ACCEPT_TOKEN(aux_sym_attribute_id_token1);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      ADVANCE_MAP(
        '_', 1,
        'a', 2,
        'b', 3,
        'e', 4,
        'f', 5,
        'i', 6,
        'l', 7,
        'm', 8,
        'n', 9,
        'o', 10,
        'p', 11,
        'r', 12,
        's', 13,
        't', 14,
        'v', 15,
        'w', 16,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      END_STATE();
    case 1:
      ACCEPT_TOKEN(anon_sym__);
      END_STATE();
    case 2:
      if (lookahead == 's') ADVANCE(17);
      END_STATE();
    case 3:
      if (lookahead == 'e') ADVANCE(18);
      END_STATE();
    case 4:
      if (lookahead == 'f') ADVANCE(19);
      END_STATE();
    case 5:
      if (lookahead == 'a') ADVANCE(20);
      if (lookahead == 'o') ADVANCE(21);
      if (lookahead == 'u') ADVANCE(22);
      END_STATE();
    case 6:
      if (lookahead == 'f') ADVANCE(23);
      END_STATE();
    case 7:
      if (lookahead == 'a') ADVANCE(24);
      END_STATE();
    case 8:
      if (lookahead == 'a') ADVANCE(25);
      if (lookahead == 'u') ADVANCE(26);
      END_STATE();
    case 9:
      if (lookahead == 'e') ADVANCE(27);
      if (lookahead == 'o') ADVANCE(28);
      END_STATE();
    case 10:
      if (lookahead == 'b') ADVANCE(29);
      if (lookahead == 'f') ADVANCE(30);
      END_STATE();
    case 11:
      if (lookahead == 'r') ADVANCE(31);
      END_STATE();
    case 12:
      if (lookahead == 'e') ADVANCE(32);
      END_STATE();
    case 13:
      if (lookahead == 'i') ADVANCE(33);
      if (lookahead == 't') ADVANCE(34);
      END_STATE();
    case 14:
      if (lookahead == 'r') ADVANCE(35);
      END_STATE();
    case 15:
      if (lookahead == 'i') ADVANCE(36);
      END_STATE();
    case 16:
      if (lookahead == 'h') ADVANCE(37);
      END_STATE();
    case 17:
      ACCEPT_TOKEN(anon_sym_as);
      if (lookahead == 's') ADVANCE(38);
      END_STATE();
    case 18:
      if (lookahead == 'g') ADVANCE(39);
      END_STATE();
    case 19:
      if (lookahead == 'f') ADVANCE(40);
      END_STATE();
    case 20:
      if (lookahead == 'l') ADVANCE(41);
      END_STATE();
    case 21:
      if (lookahead == 'r') ADVANCE(42);
      END_STATE();
    case 22:
      if (lookahead == 'n') ADVANCE(43);
      END_STATE();
    case 23:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 24:
      if (lookahead == 'z') ADVANCE(44);
      END_STATE();
    case 25:
      if (lookahead == 't') ADVANCE(45);
      END_STATE();
    case 26:
      if (lookahead == 't') ADVANCE(46);
      END_STATE();
    case 27:
      if (lookahead == 'w') ADVANCE(47);
      END_STATE();
    case 28:
      if (lookahead == 'n') ADVANCE(48);
      END_STATE();
    case 29:
      if (lookahead == 'j') ADVANCE(49);
      END_STATE();
    case 30:
      ACCEPT_TOKEN(anon_sym_of);
      END_STATE();
    case 31:
      if (lookahead == 'i') ADVANCE(50);
      END_STATE();
    case 32:
      if (lookahead == 'c') ADVANCE(51);
      END_STATE();
    case 33:
      if (lookahead == 'g') ADVANCE(52);
      END_STATE();
    case 34:
      if (lookahead == 'r') ADVANCE(53);
      END_STATE();
    case 35:
      if (lookahead == 'u') ADVANCE(54);
      if (lookahead == 'y') ADVANCE(55);
      END_STATE();
    case 36:
      if (lookahead == 'r') ADVANCE(56);
      END_STATE();
    case 37:
      if (lookahead == 'e') ADVANCE(57);
      if (lookahead == 'i') ADVANCE(58);
      END_STATE();
    case 38:
      if (lookahead == 'e') ADVANCE(59);
      END_STATE();
    case 39:
      if (lookahead == 'i') ADVANCE(60);
      END_STATE();
    case 40:
      if (lookahead == 'e') ADVANCE(61);
      END_STATE();
    case 41:
      if (lookahead == 's') ADVANCE(62);
      END_STATE();
    case 42:
      ACCEPT_TOKEN(anon_sym_for);
      END_STATE();
    case 43:
      ACCEPT_TOKEN(anon_sym_fun);
      if (lookahead == 'c') ADVANCE(63);
      END_STATE();
    case 44:
      if (lookahead == 'y') ADVANCE(64);
      END_STATE();
    case 45:
      if (lookahead == 'c') ADVANCE(65);
      END_STATE();
    case 46:
      if (lookahead == 'a') ADVANCE(66);
      END_STATE();
    case 47:
      ACCEPT_TOKEN(anon_sym_new);
      END_STATE();
    case 48:
      if (lookahead == 'r') ADVANCE(67);
      END_STATE();
    case 49:
      if (lookahead == 'e') ADVANCE(68);
      END_STATE();
    case 50:
      if (lookahead == 'v') ADVANCE(69);
      END_STATE();
    case 51:
      ACCEPT_TOKEN(anon_sym_rec);
      END_STATE();
    case 52:
      ACCEPT_TOKEN(anon_sym_sig);
      END_STATE();
    case 53:
      if (lookahead == 'u') ADVANCE(70);
      END_STATE();
    case 54:
      if (lookahead == 'e') ADVANCE(71);
      END_STATE();
    case 55:
      ACCEPT_TOKEN(anon_sym_try);
      END_STATE();
    case 56:
      if (lookahead == 't') ADVANCE(72);
      END_STATE();
    case 57:
      if (lookahead == 'n') ADVANCE(73);
      END_STATE();
    case 58:
      if (lookahead == 'l') ADVANCE(74);
      END_STATE();
    case 59:
      if (lookahead == 'r') ADVANCE(75);
      END_STATE();
    case 60:
      if (lookahead == 'n') ADVANCE(76);
      END_STATE();
    case 61:
      if (lookahead == 'c') ADVANCE(77);
      END_STATE();
    case 62:
      if (lookahead == 'e') ADVANCE(78);
      END_STATE();
    case 63:
      if (lookahead == 't') ADVANCE(79);
      END_STATE();
    case 64:
      ACCEPT_TOKEN(anon_sym_lazy);
      END_STATE();
    case 65:
      if (lookahead == 'h') ADVANCE(80);
      END_STATE();
    case 66:
      if (lookahead == 'b') ADVANCE(81);
      END_STATE();
    case 67:
      if (lookahead == 'e') ADVANCE(82);
      END_STATE();
    case 68:
      if (lookahead == 'c') ADVANCE(83);
      END_STATE();
    case 69:
      if (lookahead == 'a') ADVANCE(84);
      END_STATE();
    case 70:
      if (lookahead == 'c') ADVANCE(85);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(anon_sym_true);
      END_STATE();
    case 72:
      if (lookahead == 'u') ADVANCE(86);
      END_STATE();
    case 73:
      ACCEPT_TOKEN(anon_sym_when);
      END_STATE();
    case 74:
      if (lookahead == 'e') ADVANCE(87);
      END_STATE();
    case 75:
      if (lookahead == 't') ADVANCE(88);
      END_STATE();
    case 76:
      ACCEPT_TOKEN(anon_sym_begin);
      END_STATE();
    case 77:
      if (lookahead == 't') ADVANCE(89);
      END_STATE();
    case 78:
      ACCEPT_TOKEN(anon_sym_false);
      END_STATE();
    case 79:
      if (lookahead == 'i') ADVANCE(90);
      if (lookahead == 'o') ADVANCE(91);
      END_STATE();
    case 80:
      ACCEPT_TOKEN(anon_sym_match);
      END_STATE();
    case 81:
      if (lookahead == 'l') ADVANCE(92);
      END_STATE();
    case 82:
      if (lookahead == 'c') ADVANCE(93);
      END_STATE();
    case 83:
      if (lookahead == 't') ADVANCE(94);
      END_STATE();
    case 84:
      if (lookahead == 't') ADVANCE(95);
      END_STATE();
    case 85:
      if (lookahead == 't') ADVANCE(96);
      END_STATE();
    case 86:
      if (lookahead == 'a') ADVANCE(97);
      END_STATE();
    case 87:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 88:
      ACCEPT_TOKEN(anon_sym_assert);
      END_STATE();
    case 89:
      ACCEPT_TOKEN(anon_sym_effect);
      END_STATE();
    case 90:
      if (lookahead == 'o') ADVANCE(98);
      END_STATE();
    case 91:
      if (lookahead == 'r') ADVANCE(99);
      END_STATE();
    case 92:
      if (lookahead == 'e') ADVANCE(100);
      END_STATE();
    case 93:
      ACCEPT_TOKEN(anon_sym_nonrec);
      END_STATE();
    case 94:
      ACCEPT_TOKEN(anon_sym_object);
      END_STATE();
    case 95:
      if (lookahead == 'e') ADVANCE(101);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(anon_sym_struct);
      END_STATE();
    case 97:
      if (lookahead == 'l') ADVANCE(102);
      END_STATE();
    case 98:
      if (lookahead == 'n') ADVANCE(103);
      END_STATE();
    case 99:
      ACCEPT_TOKEN(anon_sym_functor);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(anon_sym_mutable);
      END_STATE();
    case 101:
      ACCEPT_TOKEN(anon_sym_private);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(anon_sym_virtual);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(anon_sym_function);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 420, .external_lex_state = 2},
  [2] = {.lex_state = 18, .external_lex_state = 3},
  [3] = {.lex_state = 18, .external_lex_state = 3},
  [4] = {.lex_state = 18, .external_lex_state = 3},
  [5] = {.lex_state = 18, .external_lex_state = 3},
  [6] = {.lex_state = 18, .external_lex_state = 3},
  [7] = {.lex_state = 18, .external_lex_state = 3},
  [8] = {.lex_state = 18, .external_lex_state = 3},
  [9] = {.lex_state = 18, .external_lex_state = 3},
  [10] = {.lex_state = 18, .external_lex_state = 3},
  [11] = {.lex_state = 18, .external_lex_state = 3},
  [12] = {.lex_state = 18, .external_lex_state = 3},
  [13] = {.lex_state = 18, .external_lex_state = 3},
  [14] = {.lex_state = 18, .external_lex_state = 3},
  [15] = {.lex_state = 18, .external_lex_state = 3},
  [16] = {.lex_state = 18, .external_lex_state = 3},
  [17] = {.lex_state = 18, .external_lex_state = 3},
  [18] = {.lex_state = 18, .external_lex_state = 3},
  [19] = {.lex_state = 18, .external_lex_state = 3},
  [20] = {.lex_state = 18, .external_lex_state = 3},
  [21] = {.lex_state = 18, .external_lex_state = 3},
  [22] = {.lex_state = 18, .external_lex_state = 3},
  [23] = {.lex_state = 18, .external_lex_state = 3},
  [24] = {.lex_state = 18, .external_lex_state = 3},
  [25] = {.lex_state = 18, .external_lex_state = 3},
  [26] = {.lex_state = 18, .external_lex_state = 3},
  [27] = {.lex_state = 18, .external_lex_state = 3},
  [28] = {.lex_state = 18, .external_lex_state = 3},
  [29] = {.lex_state = 18, .external_lex_state = 3},
  [30] = {.lex_state = 18, .external_lex_state = 3},
  [31] = {.lex_state = 18, .external_lex_state = 3},
  [32] = {.lex_state = 18, .external_lex_state = 3},
  [33] = {.lex_state = 18, .external_lex_state = 3},
  [34] = {.lex_state = 18, .external_lex_state = 3},
  [35] = {.lex_state = 18, .external_lex_state = 3},
  [36] = {.lex_state = 18, .external_lex_state = 3},
  [37] = {.lex_state = 18, .external_lex_state = 3},
  [38] = {.lex_state = 18, .external_lex_state = 3},
  [39] = {.lex_state = 18, .external_lex_state = 3},
  [40] = {.lex_state = 18, .external_lex_state = 3},
  [41] = {.lex_state = 18, .external_lex_state = 3},
  [42] = {.lex_state = 18, .external_lex_state = 3},
  [43] = {.lex_state = 18, .external_lex_state = 3},
  [44] = {.lex_state = 18, .external_lex_state = 3},
  [45] = {.lex_state = 18, .external_lex_state = 3},
  [46] = {.lex_state = 18, .external_lex_state = 3},
  [47] = {.lex_state = 18, .external_lex_state = 3},
  [48] = {.lex_state = 18, .external_lex_state = 3},
  [49] = {.lex_state = 18, .external_lex_state = 3},
  [50] = {.lex_state = 18, .external_lex_state = 3},
  [51] = {.lex_state = 18, .external_lex_state = 3},
  [52] = {.lex_state = 18, .external_lex_state = 3},
  [53] = {.lex_state = 18, .external_lex_state = 3},
  [54] = {.lex_state = 18, .external_lex_state = 3},
  [55] = {.lex_state = 18, .external_lex_state = 3},
  [56] = {.lex_state = 18, .external_lex_state = 3},
  [57] = {.lex_state = 18, .external_lex_state = 3},
  [58] = {.lex_state = 18, .external_lex_state = 3},
  [59] = {.lex_state = 18, .external_lex_state = 3},
  [60] = {.lex_state = 18, .external_lex_state = 3},
  [61] = {.lex_state = 18, .external_lex_state = 3},
  [62] = {.lex_state = 18, .external_lex_state = 3},
  [63] = {.lex_state = 18, .external_lex_state = 3},
  [64] = {.lex_state = 18, .external_lex_state = 3},
  [65] = {.lex_state = 18, .external_lex_state = 3},
  [66] = {.lex_state = 18, .external_lex_state = 3},
  [67] = {.lex_state = 18, .external_lex_state = 3},
  [68] = {.lex_state = 18, .external_lex_state = 3},
  [69] = {.lex_state = 18, .external_lex_state = 3},
  [70] = {.lex_state = 18, .external_lex_state = 3},
  [71] = {.lex_state = 18, .external_lex_state = 3},
  [72] = {.lex_state = 18, .external_lex_state = 3},
  [73] = {.lex_state = 18, .external_lex_state = 3},
  [74] = {.lex_state = 18, .external_lex_state = 3},
  [75] = {.lex_state = 18, .external_lex_state = 3},
  [76] = {.lex_state = 18, .external_lex_state = 3},
  [77] = {.lex_state = 18, .external_lex_state = 3},
  [78] = {.lex_state = 18, .external_lex_state = 3},
  [79] = {.lex_state = 18, .external_lex_state = 3},
  [80] = {.lex_state = 18, .external_lex_state = 3},
  [81] = {.lex_state = 18, .external_lex_state = 3},
  [82] = {.lex_state = 18, .external_lex_state = 3},
  [83] = {.lex_state = 18, .external_lex_state = 3},
  [84] = {.lex_state = 18, .external_lex_state = 3},
  [85] = {.lex_state = 18, .external_lex_state = 3},
  [86] = {.lex_state = 18, .external_lex_state = 3},
  [87] = {.lex_state = 18, .external_lex_state = 3},
  [88] = {.lex_state = 18, .external_lex_state = 3},
  [89] = {.lex_state = 48, .external_lex_state = 3},
  [90] = {.lex_state = 51, .external_lex_state = 3},
  [91] = {.lex_state = 19, .external_lex_state = 3},
  [92] = {.lex_state = 52, .external_lex_state = 3},
  [93] = {.lex_state = 55, .external_lex_state = 3},
  [94] = {.lex_state = 49, .external_lex_state = 3},
  [95] = {.lex_state = 19, .external_lex_state = 3},
  [96] = {.lex_state = 56, .external_lex_state = 3},
  [97] = {.lex_state = 18, .external_lex_state = 3},
  [98] = {.lex_state = 19, .external_lex_state = 3},
  [99] = {.lex_state = 50, .external_lex_state = 3},
  [100] = {.lex_state = 19, .external_lex_state = 3},
  [101] = {.lex_state = 19, .external_lex_state = 3},
  [102] = {.lex_state = 19, .external_lex_state = 3},
  [103] = {.lex_state = 18, .external_lex_state = 3},
  [104] = {.lex_state = 18, .external_lex_state = 3},
  [105] = {.lex_state = 18, .external_lex_state = 3},
  [106] = {.lex_state = 57, .external_lex_state = 3},
  [107] = {.lex_state = 18, .external_lex_state = 3},
  [108] = {.lex_state = 58, .external_lex_state = 3},
  [109] = {.lex_state = 54, .external_lex_state = 3},
  [110] = {.lex_state = 18, .external_lex_state = 3},
  [111] = {.lex_state = 59, .external_lex_state = 3},
  [112] = {.lex_state = 53, .external_lex_state = 3},
  [113] = {.lex_state = 136, .external_lex_state = 3},
  [114] = {.lex_state = 136, .external_lex_state = 3},
  [115] = {.lex_state = 139, .external_lex_state = 3},
  [116] = {.lex_state = 139, .external_lex_state = 3},
  [117] = {.lex_state = 137, .external_lex_state = 3},
  [118] = {.lex_state = 137, .external_lex_state = 3},
  [119] = {.lex_state = 138, .external_lex_state = 3},
  [120] = {.lex_state = 138, .external_lex_state = 3},
  [121] = {.lex_state = 22, .external_lex_state = 3},
  [122] = {.lex_state = 154, .external_lex_state = 3},
  [123] = {.lex_state = 20, .external_lex_state = 3},
  [124] = {.lex_state = 23, .external_lex_state = 3},
  [125] = {.lex_state = 21, .external_lex_state = 3},
  [126] = {.lex_state = 155, .external_lex_state = 3},
  [127] = {.lex_state = 154, .external_lex_state = 3},
  [128] = {.lex_state = 142, .external_lex_state = 3},
  [129] = {.lex_state = 155, .external_lex_state = 3},
  [130] = {.lex_state = 135, .external_lex_state = 3},
  [131] = {.lex_state = 135, .external_lex_state = 3},
  [132] = {.lex_state = 135, .external_lex_state = 3},
  [133] = {.lex_state = 135, .external_lex_state = 3},
  [134] = {.lex_state = 135, .external_lex_state = 3},
  [135] = {.lex_state = 143, .external_lex_state = 3},
  [136] = {.lex_state = 135, .external_lex_state = 3},
  [137] = {.lex_state = 19, .external_lex_state = 3},
  [138] = {.lex_state = 135, .external_lex_state = 3},
  [139] = {.lex_state = 135, .external_lex_state = 3},
  [140] = {.lex_state = 135, .external_lex_state = 3},
  [141] = {.lex_state = 135, .external_lex_state = 3},
  [142] = {.lex_state = 135, .external_lex_state = 3},
  [143] = {.lex_state = 135, .external_lex_state = 3},
  [144] = {.lex_state = 135, .external_lex_state = 3},
  [145] = {.lex_state = 135, .external_lex_state = 3},
  [146] = {.lex_state = 135, .external_lex_state = 3},
  [147] = {.lex_state = 135, .external_lex_state = 3},
  [148] = {.lex_state = 135, .external_lex_state = 3},
  [149] = {.lex_state = 135, .external_lex_state = 3},
  [150] = {.lex_state = 135, .external_lex_state = 3},
  [151] = {.lex_state = 135, .external_lex_state = 3},
  [152] = {.lex_state = 135, .external_lex_state = 3},
  [153] = {.lex_state = 135, .external_lex_state = 3},
  [154] = {.lex_state = 135, .external_lex_state = 3},
  [155] = {.lex_state = 135, .external_lex_state = 3},
  [156] = {.lex_state = 135, .external_lex_state = 3},
  [157] = {.lex_state = 135, .external_lex_state = 3},
  [158] = {.lex_state = 135, .external_lex_state = 3},
  [159] = {.lex_state = 135, .external_lex_state = 3},
  [160] = {.lex_state = 135, .external_lex_state = 3},
  [161] = {.lex_state = 135, .external_lex_state = 3},
  [162] = {.lex_state = 135, .external_lex_state = 3},
  [163] = {.lex_state = 135, .external_lex_state = 3},
  [164] = {.lex_state = 135, .external_lex_state = 3},
  [165] = {.lex_state = 135, .external_lex_state = 3},
  [166] = {.lex_state = 135, .external_lex_state = 3},
  [167] = {.lex_state = 135, .external_lex_state = 3},
  [168] = {.lex_state = 135, .external_lex_state = 3},
  [169] = {.lex_state = 135, .external_lex_state = 3},
  [170] = {.lex_state = 135, .external_lex_state = 3},
  [171] = {.lex_state = 135, .external_lex_state = 3},
  [172] = {.lex_state = 135, .external_lex_state = 3},
  [173] = {.lex_state = 135, .external_lex_state = 3},
  [174] = {.lex_state = 135, .external_lex_state = 3},
  [175] = {.lex_state = 135, .external_lex_state = 3},
  [176] = {.lex_state = 135, .external_lex_state = 3},
  [177] = {.lex_state = 135, .external_lex_state = 3},
  [178] = {.lex_state = 135, .external_lex_state = 3},
  [179] = {.lex_state = 135, .external_lex_state = 3},
  [180] = {.lex_state = 135, .external_lex_state = 3},
  [181] = {.lex_state = 135, .external_lex_state = 3},
  [182] = {.lex_state = 135, .external_lex_state = 3},
  [183] = {.lex_state = 135, .external_lex_state = 3},
  [184] = {.lex_state = 149, .external_lex_state = 3},
  [185] = {.lex_state = 135, .external_lex_state = 3},
  [186] = {.lex_state = 135, .external_lex_state = 3},
  [187] = {.lex_state = 135, .external_lex_state = 3},
  [188] = {.lex_state = 135, .external_lex_state = 3},
  [189] = {.lex_state = 135, .external_lex_state = 3},
  [190] = {.lex_state = 135, .external_lex_state = 3},
  [191] = {.lex_state = 18, .external_lex_state = 3},
  [192] = {.lex_state = 135, .external_lex_state = 3},
  [193] = {.lex_state = 135, .external_lex_state = 3},
  [194] = {.lex_state = 135, .external_lex_state = 3},
  [195] = {.lex_state = 135, .external_lex_state = 3},
  [196] = {.lex_state = 135, .external_lex_state = 3},
  [197] = {.lex_state = 135, .external_lex_state = 3},
  [198] = {.lex_state = 135, .external_lex_state = 3},
  [199] = {.lex_state = 135, .external_lex_state = 3},
  [200] = {.lex_state = 135, .external_lex_state = 3},
  [201] = {.lex_state = 135, .external_lex_state = 3},
  [202] = {.lex_state = 135, .external_lex_state = 3},
  [203] = {.lex_state = 135, .external_lex_state = 3},
  [204] = {.lex_state = 135, .external_lex_state = 3},
  [205] = {.lex_state = 135, .external_lex_state = 3},
  [206] = {.lex_state = 135, .external_lex_state = 3},
  [207] = {.lex_state = 135, .external_lex_state = 3},
  [208] = {.lex_state = 135, .external_lex_state = 3},
  [209] = {.lex_state = 135, .external_lex_state = 3},
  [210] = {.lex_state = 135, .external_lex_state = 3},
  [211] = {.lex_state = 135, .external_lex_state = 3},
  [212] = {.lex_state = 135, .external_lex_state = 3},
  [213] = {.lex_state = 135, .external_lex_state = 3},
  [214] = {.lex_state = 135, .external_lex_state = 3},
  [215] = {.lex_state = 147, .external_lex_state = 3},
  [216] = {.lex_state = 135, .external_lex_state = 3},
  [217] = {.lex_state = 140, .external_lex_state = 3},
  [218] = {.lex_state = 135, .external_lex_state = 3},
  [219] = {.lex_state = 135, .external_lex_state = 3},
  [220] = {.lex_state = 135, .external_lex_state = 3},
  [221] = {.lex_state = 135, .external_lex_state = 3},
  [222] = {.lex_state = 148, .external_lex_state = 3},
  [223] = {.lex_state = 144, .external_lex_state = 3},
  [224] = {.lex_state = 146, .external_lex_state = 3},
  [225] = {.lex_state = 135, .external_lex_state = 3},
  [226] = {.lex_state = 135, .external_lex_state = 3},
  [227] = {.lex_state = 148, .external_lex_state = 3},
  [228] = {.lex_state = 150, .external_lex_state = 3},
  [229] = {.lex_state = 145, .external_lex_state = 3},
  [230] = {.lex_state = 152, .external_lex_state = 3},
  [231] = {.lex_state = 141, .external_lex_state = 3},
  [232] = {.lex_state = 153, .external_lex_state = 3},
  [233] = {.lex_state = 151, .external_lex_state = 3},
  [234] = {.lex_state = 147, .external_lex_state = 3},
  [235] = {.lex_state = 140, .external_lex_state = 3},
  [236] = {.lex_state = 146, .external_lex_state = 3},
  [237] = {.lex_state = 150, .external_lex_state = 3},
  [238] = {.lex_state = 152, .external_lex_state = 3},
  [239] = {.lex_state = 151, .external_lex_state = 3},
  [240] = {.lex_state = 141, .external_lex_state = 3},
  [241] = {.lex_state = 37, .external_lex_state = 3},
  [242] = {.lex_state = 36, .external_lex_state = 3},
  [243] = {.lex_state = 44, .external_lex_state = 3},
  [244] = {.lex_state = 39, .external_lex_state = 3},
  [245] = {.lex_state = 41, .external_lex_state = 3},
  [246] = {.lex_state = 41, .external_lex_state = 3},
  [247] = {.lex_state = 38, .external_lex_state = 3},
  [248] = {.lex_state = 41, .external_lex_state = 3},
  [249] = {.lex_state = 41, .external_lex_state = 3},
  [250] = {.lex_state = 41, .external_lex_state = 3},
  [251] = {.lex_state = 41, .external_lex_state = 3},
  [252] = {.lex_state = 41, .external_lex_state = 3},
  [253] = {.lex_state = 40, .external_lex_state = 3},
  [254] = {.lex_state = 41, .external_lex_state = 3},
  [255] = {.lex_state = 41, .external_lex_state = 3},
  [256] = {.lex_state = 41, .external_lex_state = 3},
  [257] = {.lex_state = 41, .external_lex_state = 3},
  [258] = {.lex_state = 36, .external_lex_state = 3},
  [259] = {.lex_state = 41, .external_lex_state = 3},
  [260] = {.lex_state = 43, .external_lex_state = 3},
  [261] = {.lex_state = 41, .external_lex_state = 3},
  [262] = {.lex_state = 41, .external_lex_state = 3},
  [263] = {.lex_state = 41, .external_lex_state = 3},
  [264] = {.lex_state = 41, .external_lex_state = 3},
  [265] = {.lex_state = 41, .external_lex_state = 3},
  [266] = {.lex_state = 41, .external_lex_state = 3},
  [267] = {.lex_state = 41, .external_lex_state = 3},
  [268] = {.lex_state = 41, .external_lex_state = 3},
  [269] = {.lex_state = 41, .external_lex_state = 3},
  [270] = {.lex_state = 41, .external_lex_state = 3},
  [271] = {.lex_state = 41, .external_lex_state = 3},
  [272] = {.lex_state = 41, .external_lex_state = 3},
  [273] = {.lex_state = 41, .external_lex_state = 3},
  [274] = {.lex_state = 41, .external_lex_state = 3},
  [275] = {.lex_state = 41, .external_lex_state = 3},
  [276] = {.lex_state = 41, .external_lex_state = 3},
  [277] = {.lex_state = 41, .external_lex_state = 3},
  [278] = {.lex_state = 41, .external_lex_state = 3},
  [279] = {.lex_state = 41, .external_lex_state = 3},
  [280] = {.lex_state = 41, .external_lex_state = 3},
  [281] = {.lex_state = 41, .external_lex_state = 3},
  [282] = {.lex_state = 41, .external_lex_state = 3},
  [283] = {.lex_state = 41, .external_lex_state = 3},
  [284] = {.lex_state = 41, .external_lex_state = 3},
  [285] = {.lex_state = 41, .external_lex_state = 3},
  [286] = {.lex_state = 41, .external_lex_state = 3},
  [287] = {.lex_state = 41, .external_lex_state = 3},
  [288] = {.lex_state = 42, .external_lex_state = 3},
  [289] = {.lex_state = 41, .external_lex_state = 3},
  [290] = {.lex_state = 41, .external_lex_state = 3},
  [291] = {.lex_state = 41, .external_lex_state = 3},
  [292] = {.lex_state = 41, .external_lex_state = 3},
  [293] = {.lex_state = 41, .external_lex_state = 3},
  [294] = {.lex_state = 41, .external_lex_state = 3},
  [295] = {.lex_state = 36, .external_lex_state = 3},
  [296] = {.lex_state = 36, .external_lex_state = 3},
  [297] = {.lex_state = 36, .external_lex_state = 3},
  [298] = {.lex_state = 36, .external_lex_state = 3},
  [299] = {.lex_state = 36, .external_lex_state = 3},
  [300] = {.lex_state = 36, .external_lex_state = 3},
  [301] = {.lex_state = 94, .external_lex_state = 3},
  [302] = {.lex_state = 36, .external_lex_state = 3},
  [303] = {.lex_state = 36, .external_lex_state = 3},
  [304] = {.lex_state = 36, .external_lex_state = 3},
  [305] = {.lex_state = 36, .external_lex_state = 3},
  [306] = {.lex_state = 36, .external_lex_state = 3},
  [307] = {.lex_state = 36, .external_lex_state = 3},
  [308] = {.lex_state = 36, .external_lex_state = 3},
  [309] = {.lex_state = 36, .external_lex_state = 3},
  [310] = {.lex_state = 36, .external_lex_state = 3},
  [311] = {.lex_state = 36, .external_lex_state = 3},
  [312] = {.lex_state = 36, .external_lex_state = 3},
  [313] = {.lex_state = 36, .external_lex_state = 3},
  [314] = {.lex_state = 36, .external_lex_state = 3},
  [315] = {.lex_state = 36, .external_lex_state = 3},
  [316] = {.lex_state = 36, .external_lex_state = 3},
  [317] = {.lex_state = 36, .external_lex_state = 3},
  [318] = {.lex_state = 36, .external_lex_state = 3},
  [319] = {.lex_state = 36, .external_lex_state = 3},
  [320] = {.lex_state = 36, .external_lex_state = 3},
  [321] = {.lex_state = 36, .external_lex_state = 3},
  [322] = {.lex_state = 36, .external_lex_state = 3},
  [323] = {.lex_state = 90, .external_lex_state = 3},
  [324] = {.lex_state = 36, .external_lex_state = 3},
  [325] = {.lex_state = 36, .external_lex_state = 3},
  [326] = {.lex_state = 36, .external_lex_state = 3},
  [327] = {.lex_state = 36, .external_lex_state = 3},
  [328] = {.lex_state = 36, .external_lex_state = 3},
  [329] = {.lex_state = 36, .external_lex_state = 3},
  [330] = {.lex_state = 36, .external_lex_state = 3},
  [331] = {.lex_state = 36, .external_lex_state = 3},
  [332] = {.lex_state = 36, .external_lex_state = 3},
  [333] = {.lex_state = 36, .external_lex_state = 3},
  [334] = {.lex_state = 36, .external_lex_state = 3},
  [335] = {.lex_state = 36, .external_lex_state = 3},
  [336] = {.lex_state = 36, .external_lex_state = 3},
  [337] = {.lex_state = 36, .external_lex_state = 3},
  [338] = {.lex_state = 36, .external_lex_state = 3},
  [339] = {.lex_state = 36, .external_lex_state = 3},
  [340] = {.lex_state = 36, .external_lex_state = 3},
  [341] = {.lex_state = 36, .external_lex_state = 3},
  [342] = {.lex_state = 36, .external_lex_state = 3},
  [343] = {.lex_state = 36, .external_lex_state = 3},
  [344] = {.lex_state = 36, .external_lex_state = 3},
  [345] = {.lex_state = 36, .external_lex_state = 3},
  [346] = {.lex_state = 36, .external_lex_state = 3},
  [347] = {.lex_state = 36, .external_lex_state = 3},
  [348] = {.lex_state = 36, .external_lex_state = 3},
  [349] = {.lex_state = 36, .external_lex_state = 3},
  [350] = {.lex_state = 36, .external_lex_state = 3},
  [351] = {.lex_state = 36, .external_lex_state = 3},
  [352] = {.lex_state = 36, .external_lex_state = 3},
  [353] = {.lex_state = 36, .external_lex_state = 3},
  [354] = {.lex_state = 36, .external_lex_state = 3},
  [355] = {.lex_state = 36, .external_lex_state = 3},
  [356] = {.lex_state = 36, .external_lex_state = 3},
  [357] = {.lex_state = 36, .external_lex_state = 3},
  [358] = {.lex_state = 36, .external_lex_state = 3},
  [359] = {.lex_state = 36, .external_lex_state = 3},
  [360] = {.lex_state = 36, .external_lex_state = 3},
  [361] = {.lex_state = 36, .external_lex_state = 3},
  [362] = {.lex_state = 36, .external_lex_state = 3},
  [363] = {.lex_state = 36, .external_lex_state = 3},
  [364] = {.lex_state = 36, .external_lex_state = 3},
  [365] = {.lex_state = 36, .external_lex_state = 3},
  [366] = {.lex_state = 36, .external_lex_state = 3},
  [367] = {.lex_state = 36, .external_lex_state = 3},
  [368] = {.lex_state = 36, .external_lex_state = 3},
  [369] = {.lex_state = 36, .external_lex_state = 3},
  [370] = {.lex_state = 36, .external_lex_state = 3},
  [371] = {.lex_state = 36, .external_lex_state = 3},
  [372] = {.lex_state = 36, .external_lex_state = 3},
  [373] = {.lex_state = 36, .external_lex_state = 3},
  [374] = {.lex_state = 36, .external_lex_state = 3},
  [375] = {.lex_state = 36, .external_lex_state = 3},
  [376] = {.lex_state = 36, .external_lex_state = 3},
  [377] = {.lex_state = 36, .external_lex_state = 3},
  [378] = {.lex_state = 36, .external_lex_state = 3},
  [379] = {.lex_state = 36, .external_lex_state = 3},
  [380] = {.lex_state = 36, .external_lex_state = 3},
  [381] = {.lex_state = 36, .external_lex_state = 3},
  [382] = {.lex_state = 36, .external_lex_state = 3},
  [383] = {.lex_state = 36, .external_lex_state = 3},
  [384] = {.lex_state = 36, .external_lex_state = 3},
  [385] = {.lex_state = 36, .external_lex_state = 3},
  [386] = {.lex_state = 36, .external_lex_state = 3},
  [387] = {.lex_state = 36, .external_lex_state = 3},
  [388] = {.lex_state = 36, .external_lex_state = 3},
  [389] = {.lex_state = 36, .external_lex_state = 3},
  [390] = {.lex_state = 36, .external_lex_state = 3},
  [391] = {.lex_state = 36, .external_lex_state = 3},
  [392] = {.lex_state = 36, .external_lex_state = 3},
  [393] = {.lex_state = 36, .external_lex_state = 3},
  [394] = {.lex_state = 36, .external_lex_state = 3},
  [395] = {.lex_state = 36, .external_lex_state = 3},
  [396] = {.lex_state = 36, .external_lex_state = 3},
  [397] = {.lex_state = 36, .external_lex_state = 3},
  [398] = {.lex_state = 36, .external_lex_state = 3},
  [399] = {.lex_state = 36, .external_lex_state = 3},
  [400] = {.lex_state = 36, .external_lex_state = 3},
  [401] = {.lex_state = 36, .external_lex_state = 3},
  [402] = {.lex_state = 36, .external_lex_state = 3},
  [403] = {.lex_state = 36, .external_lex_state = 3},
  [404] = {.lex_state = 36, .external_lex_state = 3},
  [405] = {.lex_state = 36, .external_lex_state = 3},
  [406] = {.lex_state = 36, .external_lex_state = 3},
  [407] = {.lex_state = 36, .external_lex_state = 3},
  [408] = {.lex_state = 36, .external_lex_state = 3},
  [409] = {.lex_state = 36, .external_lex_state = 3},
  [410] = {.lex_state = 36, .external_lex_state = 3},
  [411] = {.lex_state = 36, .external_lex_state = 3},
  [412] = {.lex_state = 36, .external_lex_state = 3},
  [413] = {.lex_state = 36, .external_lex_state = 3},
  [414] = {.lex_state = 36, .external_lex_state = 3},
  [415] = {.lex_state = 36, .external_lex_state = 3},
  [416] = {.lex_state = 36, .external_lex_state = 3},
  [417] = {.lex_state = 36, .external_lex_state = 3},
  [418] = {.lex_state = 36, .external_lex_state = 3},
  [419] = {.lex_state = 36, .external_lex_state = 3},
  [420] = {.lex_state = 36, .external_lex_state = 3},
  [421] = {.lex_state = 36, .external_lex_state = 3},
  [422] = {.lex_state = 36, .external_lex_state = 3},
  [423] = {.lex_state = 36, .external_lex_state = 3},
  [424] = {.lex_state = 36, .external_lex_state = 3},
  [425] = {.lex_state = 36, .external_lex_state = 3},
  [426] = {.lex_state = 36, .external_lex_state = 3},
  [427] = {.lex_state = 36, .external_lex_state = 3},
  [428] = {.lex_state = 36, .external_lex_state = 3},
  [429] = {.lex_state = 36, .external_lex_state = 3},
  [430] = {.lex_state = 36, .external_lex_state = 3},
  [431] = {.lex_state = 36, .external_lex_state = 3},
  [432] = {.lex_state = 36, .external_lex_state = 3},
  [433] = {.lex_state = 36, .external_lex_state = 3},
  [434] = {.lex_state = 36, .external_lex_state = 3},
  [435] = {.lex_state = 36, .external_lex_state = 3},
  [436] = {.lex_state = 36, .external_lex_state = 3},
  [437] = {.lex_state = 36, .external_lex_state = 3},
  [438] = {.lex_state = 36, .external_lex_state = 3},
  [439] = {.lex_state = 36, .external_lex_state = 3},
  [440] = {.lex_state = 36, .external_lex_state = 3},
  [441] = {.lex_state = 36, .external_lex_state = 3},
  [442] = {.lex_state = 36, .external_lex_state = 3},
  [443] = {.lex_state = 36, .external_lex_state = 3},
  [444] = {.lex_state = 36, .external_lex_state = 3},
  [445] = {.lex_state = 36, .external_lex_state = 3},
  [446] = {.lex_state = 36, .external_lex_state = 3},
  [447] = {.lex_state = 36, .external_lex_state = 3},
  [448] = {.lex_state = 36, .external_lex_state = 3},
  [449] = {.lex_state = 36, .external_lex_state = 3},
  [450] = {.lex_state = 36, .external_lex_state = 3},
  [451] = {.lex_state = 36, .external_lex_state = 3},
  [452] = {.lex_state = 36, .external_lex_state = 3},
  [453] = {.lex_state = 36, .external_lex_state = 3},
  [454] = {.lex_state = 36, .external_lex_state = 3},
  [455] = {.lex_state = 36, .external_lex_state = 3},
  [456] = {.lex_state = 36, .external_lex_state = 3},
  [457] = {.lex_state = 36, .external_lex_state = 3},
  [458] = {.lex_state = 36, .external_lex_state = 3},
  [459] = {.lex_state = 36, .external_lex_state = 3},
  [460] = {.lex_state = 36, .external_lex_state = 3},
  [461] = {.lex_state = 36, .external_lex_state = 3},
  [462] = {.lex_state = 36, .external_lex_state = 3},
  [463] = {.lex_state = 36, .external_lex_state = 3},
  [464] = {.lex_state = 36, .external_lex_state = 3},
  [465] = {.lex_state = 36, .external_lex_state = 3},
  [466] = {.lex_state = 36, .external_lex_state = 3},
  [467] = {.lex_state = 36, .external_lex_state = 3},
  [468] = {.lex_state = 36, .external_lex_state = 3},
  [469] = {.lex_state = 36, .external_lex_state = 3},
  [470] = {.lex_state = 36, .external_lex_state = 3},
  [471] = {.lex_state = 36, .external_lex_state = 3},
  [472] = {.lex_state = 36, .external_lex_state = 3},
  [473] = {.lex_state = 36, .external_lex_state = 3},
  [474] = {.lex_state = 36, .external_lex_state = 3},
  [475] = {.lex_state = 36, .external_lex_state = 3},
  [476] = {.lex_state = 36, .external_lex_state = 3},
  [477] = {.lex_state = 36, .external_lex_state = 3},
  [478] = {.lex_state = 36, .external_lex_state = 3},
  [479] = {.lex_state = 36, .external_lex_state = 3},
  [480] = {.lex_state = 36, .external_lex_state = 3},
  [481] = {.lex_state = 36, .external_lex_state = 3},
  [482] = {.lex_state = 36, .external_lex_state = 3},
  [483] = {.lex_state = 36, .external_lex_state = 3},
  [484] = {.lex_state = 36, .external_lex_state = 3},
  [485] = {.lex_state = 36, .external_lex_state = 3},
  [486] = {.lex_state = 36, .external_lex_state = 3},
  [487] = {.lex_state = 36, .external_lex_state = 3},
  [488] = {.lex_state = 36, .external_lex_state = 3},
  [489] = {.lex_state = 36, .external_lex_state = 3},
  [490] = {.lex_state = 36, .external_lex_state = 3},
  [491] = {.lex_state = 36, .external_lex_state = 3},
  [492] = {.lex_state = 36, .external_lex_state = 3},
  [493] = {.lex_state = 36, .external_lex_state = 3},
  [494] = {.lex_state = 36, .external_lex_state = 3},
  [495] = {.lex_state = 36, .external_lex_state = 3},
  [496] = {.lex_state = 36, .external_lex_state = 3},
  [497] = {.lex_state = 36, .external_lex_state = 3},
  [498] = {.lex_state = 36, .external_lex_state = 3},
  [499] = {.lex_state = 36, .external_lex_state = 3},
  [500] = {.lex_state = 36, .external_lex_state = 3},
  [501] = {.lex_state = 36, .external_lex_state = 3},
  [502] = {.lex_state = 36, .external_lex_state = 3},
  [503] = {.lex_state = 36, .external_lex_state = 3},
  [504] = {.lex_state = 40, .external_lex_state = 3},
  [505] = {.lex_state = 96, .external_lex_state = 3},
  [506] = {.lex_state = 91, .external_lex_state = 3},
  [507] = {.lex_state = 36, .external_lex_state = 3},
  [508] = {.lex_state = 36, .external_lex_state = 3},
  [509] = {.lex_state = 36, .external_lex_state = 3},
  [510] = {.lex_state = 36, .external_lex_state = 3},
  [511] = {.lex_state = 36, .external_lex_state = 3},
  [512] = {.lex_state = 36, .external_lex_state = 3},
  [513] = {.lex_state = 36, .external_lex_state = 3},
  [514] = {.lex_state = 40, .external_lex_state = 3},
  [515] = {.lex_state = 36, .external_lex_state = 3},
  [516] = {.lex_state = 36, .external_lex_state = 3},
  [517] = {.lex_state = 36, .external_lex_state = 3},
  [518] = {.lex_state = 36, .external_lex_state = 3},
  [519] = {.lex_state = 36, .external_lex_state = 3},
  [520] = {.lex_state = 36, .external_lex_state = 3},
  [521] = {.lex_state = 36, .external_lex_state = 3},
  [522] = {.lex_state = 36, .external_lex_state = 3},
  [523] = {.lex_state = 36, .external_lex_state = 3},
  [524] = {.lex_state = 36, .external_lex_state = 3},
  [525] = {.lex_state = 36, .external_lex_state = 3},
  [526] = {.lex_state = 36, .external_lex_state = 3},
  [527] = {.lex_state = 36, .external_lex_state = 3},
  [528] = {.lex_state = 36, .external_lex_state = 3},
  [529] = {.lex_state = 36, .external_lex_state = 3},
  [530] = {.lex_state = 36, .external_lex_state = 3},
  [531] = {.lex_state = 36, .external_lex_state = 3},
  [532] = {.lex_state = 36, .external_lex_state = 3},
  [533] = {.lex_state = 36, .external_lex_state = 3},
  [534] = {.lex_state = 36, .external_lex_state = 3},
  [535] = {.lex_state = 36, .external_lex_state = 3},
  [536] = {.lex_state = 36, .external_lex_state = 3},
  [537] = {.lex_state = 40, .external_lex_state = 3},
  [538] = {.lex_state = 36, .external_lex_state = 3},
  [539] = {.lex_state = 36, .external_lex_state = 3},
  [540] = {.lex_state = 36, .external_lex_state = 3},
  [541] = {.lex_state = 36, .external_lex_state = 3},
  [542] = {.lex_state = 88, .external_lex_state = 3},
  [543] = {.lex_state = 40, .external_lex_state = 3},
  [544] = {.lex_state = 36, .external_lex_state = 3},
  [545] = {.lex_state = 36, .external_lex_state = 3},
  [546] = {.lex_state = 36, .external_lex_state = 3},
  [547] = {.lex_state = 36, .external_lex_state = 3},
  [548] = {.lex_state = 36, .external_lex_state = 3},
  [549] = {.lex_state = 95, .external_lex_state = 3},
  [550] = {.lex_state = 36, .external_lex_state = 3},
  [551] = {.lex_state = 36, .external_lex_state = 3},
  [552] = {.lex_state = 36, .external_lex_state = 3},
  [553] = {.lex_state = 36, .external_lex_state = 3},
  [554] = {.lex_state = 36, .external_lex_state = 3},
  [555] = {.lex_state = 36, .external_lex_state = 3},
  [556] = {.lex_state = 36, .external_lex_state = 3},
  [557] = {.lex_state = 36, .external_lex_state = 3},
  [558] = {.lex_state = 36, .external_lex_state = 3},
  [559] = {.lex_state = 36, .external_lex_state = 3},
  [560] = {.lex_state = 36, .external_lex_state = 3},
  [561] = {.lex_state = 36, .external_lex_state = 3},
  [562] = {.lex_state = 36, .external_lex_state = 3},
  [563] = {.lex_state = 36, .external_lex_state = 3},
  [564] = {.lex_state = 36, .external_lex_state = 3},
  [565] = {.lex_state = 36, .external_lex_state = 3},
  [566] = {.lex_state = 36, .external_lex_state = 3},
  [567] = {.lex_state = 36, .external_lex_state = 3},
  [568] = {.lex_state = 36, .external_lex_state = 3},
  [569] = {.lex_state = 36, .external_lex_state = 3},
  [570] = {.lex_state = 36, .external_lex_state = 3},
  [571] = {.lex_state = 36, .external_lex_state = 3},
  [572] = {.lex_state = 36, .external_lex_state = 3},
  [573] = {.lex_state = 36, .external_lex_state = 3},
  [574] = {.lex_state = 97, .external_lex_state = 3},
  [575] = {.lex_state = 36, .external_lex_state = 3},
  [576] = {.lex_state = 36, .external_lex_state = 3},
  [577] = {.lex_state = 36, .external_lex_state = 3},
  [578] = {.lex_state = 36, .external_lex_state = 3},
  [579] = {.lex_state = 36, .external_lex_state = 3},
  [580] = {.lex_state = 36, .external_lex_state = 3},
  [581] = {.lex_state = 36, .external_lex_state = 3},
  [582] = {.lex_state = 36, .external_lex_state = 3},
  [583] = {.lex_state = 36, .external_lex_state = 3},
  [584] = {.lex_state = 36, .external_lex_state = 3},
  [585] = {.lex_state = 36, .external_lex_state = 3},
  [586] = {.lex_state = 36, .external_lex_state = 3},
  [587] = {.lex_state = 36, .external_lex_state = 3},
  [588] = {.lex_state = 36, .external_lex_state = 3},
  [589] = {.lex_state = 36, .external_lex_state = 3},
  [590] = {.lex_state = 36, .external_lex_state = 3},
  [591] = {.lex_state = 36, .external_lex_state = 3},
  [592] = {.lex_state = 36, .external_lex_state = 3},
  [593] = {.lex_state = 89, .external_lex_state = 3},
  [594] = {.lex_state = 36, .external_lex_state = 3},
  [595] = {.lex_state = 36, .external_lex_state = 3},
  [596] = {.lex_state = 36, .external_lex_state = 3},
  [597] = {.lex_state = 36, .external_lex_state = 3},
  [598] = {.lex_state = 36, .external_lex_state = 3},
  [599] = {.lex_state = 36, .external_lex_state = 3},
  [600] = {.lex_state = 36, .external_lex_state = 3},
  [601] = {.lex_state = 36, .external_lex_state = 3},
  [602] = {.lex_state = 36, .external_lex_state = 3},
  [603] = {.lex_state = 36, .external_lex_state = 3},
  [604] = {.lex_state = 36, .external_lex_state = 3},
  [605] = {.lex_state = 36, .external_lex_state = 3},
  [606] = {.lex_state = 36, .external_lex_state = 3},
  [607] = {.lex_state = 36, .external_lex_state = 3},
  [608] = {.lex_state = 36, .external_lex_state = 3},
  [609] = {.lex_state = 36, .external_lex_state = 3},
  [610] = {.lex_state = 36, .external_lex_state = 3},
  [611] = {.lex_state = 36, .external_lex_state = 3},
  [612] = {.lex_state = 36, .external_lex_state = 3},
  [613] = {.lex_state = 36, .external_lex_state = 3},
  [614] = {.lex_state = 36, .external_lex_state = 3},
  [615] = {.lex_state = 36, .external_lex_state = 3},
  [616] = {.lex_state = 36, .external_lex_state = 3},
  [617] = {.lex_state = 36, .external_lex_state = 3},
  [618] = {.lex_state = 36, .external_lex_state = 3},
  [619] = {.lex_state = 36, .external_lex_state = 3},
  [620] = {.lex_state = 36, .external_lex_state = 3},
  [621] = {.lex_state = 36, .external_lex_state = 3},
  [622] = {.lex_state = 36, .external_lex_state = 3},
  [623] = {.lex_state = 36, .external_lex_state = 3},
  [624] = {.lex_state = 36, .external_lex_state = 3},
  [625] = {.lex_state = 36, .external_lex_state = 3},
  [626] = {.lex_state = 36, .external_lex_state = 3},
  [627] = {.lex_state = 36, .external_lex_state = 3},
  [628] = {.lex_state = 36, .external_lex_state = 3},
  [629] = {.lex_state = 36, .external_lex_state = 3},
  [630] = {.lex_state = 36, .external_lex_state = 3},
  [631] = {.lex_state = 36, .external_lex_state = 3},
  [632] = {.lex_state = 36, .external_lex_state = 3},
  [633] = {.lex_state = 36, .external_lex_state = 3},
  [634] = {.lex_state = 36, .external_lex_state = 3},
  [635] = {.lex_state = 36, .external_lex_state = 3},
  [636] = {.lex_state = 36, .external_lex_state = 3},
  [637] = {.lex_state = 36, .external_lex_state = 3},
  [638] = {.lex_state = 36, .external_lex_state = 3},
  [639] = {.lex_state = 36, .external_lex_state = 3},
  [640] = {.lex_state = 36, .external_lex_state = 3},
  [641] = {.lex_state = 36, .external_lex_state = 3},
  [642] = {.lex_state = 36, .external_lex_state = 3},
  [643] = {.lex_state = 36, .external_lex_state = 3},
  [644] = {.lex_state = 36, .external_lex_state = 3},
  [645] = {.lex_state = 36, .external_lex_state = 3},
  [646] = {.lex_state = 36, .external_lex_state = 3},
  [647] = {.lex_state = 36, .external_lex_state = 3},
  [648] = {.lex_state = 36, .external_lex_state = 3},
  [649] = {.lex_state = 36, .external_lex_state = 3},
  [650] = {.lex_state = 36, .external_lex_state = 3},
  [651] = {.lex_state = 36, .external_lex_state = 3},
  [652] = {.lex_state = 36, .external_lex_state = 3},
  [653] = {.lex_state = 36, .external_lex_state = 3},
  [654] = {.lex_state = 36, .external_lex_state = 3},
  [655] = {.lex_state = 36, .external_lex_state = 3},
  [656] = {.lex_state = 36, .external_lex_state = 3},
  [657] = {.lex_state = 36, .external_lex_state = 3},
  [658] = {.lex_state = 36, .external_lex_state = 3},
  [659] = {.lex_state = 36, .external_lex_state = 3},
  [660] = {.lex_state = 36, .external_lex_state = 3},
  [661] = {.lex_state = 36, .external_lex_state = 3},
  [662] = {.lex_state = 36, .external_lex_state = 3},
  [663] = {.lex_state = 36, .external_lex_state = 3},
  [664] = {.lex_state = 36, .external_lex_state = 3},
  [665] = {.lex_state = 36, .external_lex_state = 3},
  [666] = {.lex_state = 36, .external_lex_state = 3},
  [667] = {.lex_state = 36, .external_lex_state = 3},
  [668] = {.lex_state = 36, .external_lex_state = 3},
  [669] = {.lex_state = 36, .external_lex_state = 3},
  [670] = {.lex_state = 36, .external_lex_state = 3},
  [671] = {.lex_state = 36, .external_lex_state = 3},
  [672] = {.lex_state = 36, .external_lex_state = 3},
  [673] = {.lex_state = 36, .external_lex_state = 3},
  [674] = {.lex_state = 36, .external_lex_state = 3},
  [675] = {.lex_state = 36, .external_lex_state = 3},
  [676] = {.lex_state = 36, .external_lex_state = 3},
  [677] = {.lex_state = 36, .external_lex_state = 3},
  [678] = {.lex_state = 36, .external_lex_state = 3},
  [679] = {.lex_state = 36, .external_lex_state = 3},
  [680] = {.lex_state = 36, .external_lex_state = 3},
  [681] = {.lex_state = 36, .external_lex_state = 3},
  [682] = {.lex_state = 36, .external_lex_state = 3},
  [683] = {.lex_state = 36, .external_lex_state = 3},
  [684] = {.lex_state = 36, .external_lex_state = 3},
  [685] = {.lex_state = 36, .external_lex_state = 3},
  [686] = {.lex_state = 36, .external_lex_state = 3},
  [687] = {.lex_state = 36, .external_lex_state = 3},
  [688] = {.lex_state = 36, .external_lex_state = 3},
  [689] = {.lex_state = 36, .external_lex_state = 3},
  [690] = {.lex_state = 36, .external_lex_state = 3},
  [691] = {.lex_state = 36, .external_lex_state = 3},
  [692] = {.lex_state = 36, .external_lex_state = 3},
  [693] = {.lex_state = 36, .external_lex_state = 3},
  [694] = {.lex_state = 36, .external_lex_state = 3},
  [695] = {.lex_state = 36, .external_lex_state = 3},
  [696] = {.lex_state = 36, .external_lex_state = 3},
  [697] = {.lex_state = 36, .external_lex_state = 3},
  [698] = {.lex_state = 36, .external_lex_state = 3},
  [699] = {.lex_state = 36, .external_lex_state = 3},
  [700] = {.lex_state = 36, .external_lex_state = 3},
  [701] = {.lex_state = 36, .external_lex_state = 3},
  [702] = {.lex_state = 36, .external_lex_state = 3},
  [703] = {.lex_state = 36, .external_lex_state = 3},
  [704] = {.lex_state = 36, .external_lex_state = 3},
  [705] = {.lex_state = 36, .external_lex_state = 3},
  [706] = {.lex_state = 36, .external_lex_state = 3},
  [707] = {.lex_state = 36, .external_lex_state = 3},
  [708] = {.lex_state = 36, .external_lex_state = 3},
  [709] = {.lex_state = 36, .external_lex_state = 3},
  [710] = {.lex_state = 36, .external_lex_state = 3},
  [711] = {.lex_state = 36, .external_lex_state = 3},
  [712] = {.lex_state = 36, .external_lex_state = 3},
  [713] = {.lex_state = 36, .external_lex_state = 3},
  [714] = {.lex_state = 36, .external_lex_state = 3},
  [715] = {.lex_state = 36, .external_lex_state = 3},
  [716] = {.lex_state = 36, .external_lex_state = 3},
  [717] = {.lex_state = 36, .external_lex_state = 3},
  [718] = {.lex_state = 36, .external_lex_state = 3},
  [719] = {.lex_state = 36, .external_lex_state = 3},
  [720] = {.lex_state = 36, .external_lex_state = 3},
  [721] = {.lex_state = 36, .external_lex_state = 3},
  [722] = {.lex_state = 36, .external_lex_state = 3},
  [723] = {.lex_state = 36, .external_lex_state = 3},
  [724] = {.lex_state = 36, .external_lex_state = 3},
  [725] = {.lex_state = 36, .external_lex_state = 3},
  [726] = {.lex_state = 36, .external_lex_state = 3},
  [727] = {.lex_state = 36, .external_lex_state = 3},
  [728] = {.lex_state = 36, .external_lex_state = 3},
  [729] = {.lex_state = 36, .external_lex_state = 3},
  [730] = {.lex_state = 36, .external_lex_state = 3},
  [731] = {.lex_state = 36, .external_lex_state = 3},
  [732] = {.lex_state = 36, .external_lex_state = 3},
  [733] = {.lex_state = 36, .external_lex_state = 3},
  [734] = {.lex_state = 36, .external_lex_state = 3},
  [735] = {.lex_state = 36, .external_lex_state = 3},
  [736] = {.lex_state = 36, .external_lex_state = 3},
  [737] = {.lex_state = 36, .external_lex_state = 3},
  [738] = {.lex_state = 36, .external_lex_state = 3},
  [739] = {.lex_state = 36, .external_lex_state = 3},
  [740] = {.lex_state = 36, .external_lex_state = 3},
  [741] = {.lex_state = 36, .external_lex_state = 3},
  [742] = {.lex_state = 36, .external_lex_state = 3},
  [743] = {.lex_state = 36, .external_lex_state = 3},
  [744] = {.lex_state = 36, .external_lex_state = 3},
  [745] = {.lex_state = 36, .external_lex_state = 3},
  [746] = {.lex_state = 36, .external_lex_state = 3},
  [747] = {.lex_state = 36, .external_lex_state = 3},
  [748] = {.lex_state = 36, .external_lex_state = 3},
  [749] = {.lex_state = 36, .external_lex_state = 3},
  [750] = {.lex_state = 36, .external_lex_state = 3},
  [751] = {.lex_state = 36, .external_lex_state = 3},
  [752] = {.lex_state = 36, .external_lex_state = 3},
  [753] = {.lex_state = 36, .external_lex_state = 3},
  [754] = {.lex_state = 36, .external_lex_state = 3},
  [755] = {.lex_state = 36, .external_lex_state = 3},
  [756] = {.lex_state = 36, .external_lex_state = 3},
  [757] = {.lex_state = 36, .external_lex_state = 3},
  [758] = {.lex_state = 36, .external_lex_state = 3},
  [759] = {.lex_state = 36, .external_lex_state = 3},
  [760] = {.lex_state = 36, .external_lex_state = 3},
  [761] = {.lex_state = 36, .external_lex_state = 3},
  [762] = {.lex_state = 36, .external_lex_state = 3},
  [763] = {.lex_state = 36, .external_lex_state = 3},
  [764] = {.lex_state = 36, .external_lex_state = 3},
  [765] = {.lex_state = 36, .external_lex_state = 3},
  [766] = {.lex_state = 36, .external_lex_state = 3},
  [767] = {.lex_state = 36, .external_lex_state = 3},
  [768] = {.lex_state = 36, .external_lex_state = 3},
  [769] = {.lex_state = 36, .external_lex_state = 3},
  [770] = {.lex_state = 36, .external_lex_state = 3},
  [771] = {.lex_state = 36, .external_lex_state = 3},
  [772] = {.lex_state = 36, .external_lex_state = 3},
  [773] = {.lex_state = 36, .external_lex_state = 3},
  [774] = {.lex_state = 36, .external_lex_state = 3},
  [775] = {.lex_state = 36, .external_lex_state = 3},
  [776] = {.lex_state = 36, .external_lex_state = 3},
  [777] = {.lex_state = 36, .external_lex_state = 3},
  [778] = {.lex_state = 36, .external_lex_state = 3},
  [779] = {.lex_state = 36, .external_lex_state = 3},
  [780] = {.lex_state = 36, .external_lex_state = 3},
  [781] = {.lex_state = 36, .external_lex_state = 3},
  [782] = {.lex_state = 36, .external_lex_state = 3},
  [783] = {.lex_state = 36, .external_lex_state = 3},
  [784] = {.lex_state = 36, .external_lex_state = 3},
  [785] = {.lex_state = 36, .external_lex_state = 3},
  [786] = {.lex_state = 36, .external_lex_state = 3},
  [787] = {.lex_state = 36, .external_lex_state = 3},
  [788] = {.lex_state = 36, .external_lex_state = 3},
  [789] = {.lex_state = 36, .external_lex_state = 3},
  [790] = {.lex_state = 36, .external_lex_state = 3},
  [791] = {.lex_state = 36, .external_lex_state = 3},
  [792] = {.lex_state = 36, .external_lex_state = 3},
  [793] = {.lex_state = 36, .external_lex_state = 3},
  [794] = {.lex_state = 36, .external_lex_state = 3},
  [795] = {.lex_state = 36, .external_lex_state = 3},
  [796] = {.lex_state = 36, .external_lex_state = 3},
  [797] = {.lex_state = 36, .external_lex_state = 3},
  [798] = {.lex_state = 36, .external_lex_state = 3},
  [799] = {.lex_state = 36, .external_lex_state = 3},
  [800] = {.lex_state = 36, .external_lex_state = 3},
  [801] = {.lex_state = 36, .external_lex_state = 3},
  [802] = {.lex_state = 36, .external_lex_state = 3},
  [803] = {.lex_state = 36, .external_lex_state = 3},
  [804] = {.lex_state = 36, .external_lex_state = 3},
  [805] = {.lex_state = 36, .external_lex_state = 3},
  [806] = {.lex_state = 36, .external_lex_state = 3},
  [807] = {.lex_state = 36, .external_lex_state = 3},
  [808] = {.lex_state = 36, .external_lex_state = 3},
  [809] = {.lex_state = 36, .external_lex_state = 3},
  [810] = {.lex_state = 36, .external_lex_state = 3},
  [811] = {.lex_state = 36, .external_lex_state = 3},
  [812] = {.lex_state = 36, .external_lex_state = 3},
  [813] = {.lex_state = 36, .external_lex_state = 3},
  [814] = {.lex_state = 36, .external_lex_state = 3},
  [815] = {.lex_state = 36, .external_lex_state = 3},
  [816] = {.lex_state = 36, .external_lex_state = 3},
  [817] = {.lex_state = 36, .external_lex_state = 3},
  [818] = {.lex_state = 36, .external_lex_state = 3},
  [819] = {.lex_state = 36, .external_lex_state = 3},
  [820] = {.lex_state = 36, .external_lex_state = 3},
  [821] = {.lex_state = 36, .external_lex_state = 3},
  [822] = {.lex_state = 36, .external_lex_state = 3},
  [823] = {.lex_state = 36, .external_lex_state = 3},
  [824] = {.lex_state = 36, .external_lex_state = 3},
  [825] = {.lex_state = 36, .external_lex_state = 3},
  [826] = {.lex_state = 36, .external_lex_state = 3},
  [827] = {.lex_state = 36, .external_lex_state = 3},
  [828] = {.lex_state = 36, .external_lex_state = 3},
  [829] = {.lex_state = 36, .external_lex_state = 3},
  [830] = {.lex_state = 36, .external_lex_state = 3},
  [831] = {.lex_state = 36, .external_lex_state = 3},
  [832] = {.lex_state = 36, .external_lex_state = 3},
  [833] = {.lex_state = 36, .external_lex_state = 3},
  [834] = {.lex_state = 36, .external_lex_state = 3},
  [835] = {.lex_state = 36, .external_lex_state = 3},
  [836] = {.lex_state = 36, .external_lex_state = 3},
  [837] = {.lex_state = 36, .external_lex_state = 3},
  [838] = {.lex_state = 36, .external_lex_state = 3},
  [839] = {.lex_state = 36, .external_lex_state = 3},
  [840] = {.lex_state = 36, .external_lex_state = 3},
  [841] = {.lex_state = 36, .external_lex_state = 3},
  [842] = {.lex_state = 36, .external_lex_state = 3},
  [843] = {.lex_state = 36, .external_lex_state = 3},
  [844] = {.lex_state = 36, .external_lex_state = 3},
  [845] = {.lex_state = 36, .external_lex_state = 3},
  [846] = {.lex_state = 36, .external_lex_state = 3},
  [847] = {.lex_state = 36, .external_lex_state = 3},
  [848] = {.lex_state = 36, .external_lex_state = 3},
  [849] = {.lex_state = 36, .external_lex_state = 3},
  [850] = {.lex_state = 36, .external_lex_state = 3},
  [851] = {.lex_state = 36, .external_lex_state = 3},
  [852] = {.lex_state = 36, .external_lex_state = 3},
  [853] = {.lex_state = 36, .external_lex_state = 3},
  [854] = {.lex_state = 36, .external_lex_state = 3},
  [855] = {.lex_state = 36, .external_lex_state = 3},
  [856] = {.lex_state = 36, .external_lex_state = 3},
  [857] = {.lex_state = 36, .external_lex_state = 3},
  [858] = {.lex_state = 36, .external_lex_state = 3},
  [859] = {.lex_state = 36, .external_lex_state = 3},
  [860] = {.lex_state = 36, .external_lex_state = 3},
  [861] = {.lex_state = 36, .external_lex_state = 3},
  [862] = {.lex_state = 36, .external_lex_state = 3},
  [863] = {.lex_state = 36, .external_lex_state = 3},
  [864] = {.lex_state = 36, .external_lex_state = 3},
  [865] = {.lex_state = 36, .external_lex_state = 3},
  [866] = {.lex_state = 36, .external_lex_state = 3},
  [867] = {.lex_state = 36, .external_lex_state = 3},
  [868] = {.lex_state = 36, .external_lex_state = 3},
  [869] = {.lex_state = 36, .external_lex_state = 3},
  [870] = {.lex_state = 36, .external_lex_state = 3},
  [871] = {.lex_state = 36, .external_lex_state = 3},
  [872] = {.lex_state = 36, .external_lex_state = 3},
  [873] = {.lex_state = 36, .external_lex_state = 3},
  [874] = {.lex_state = 36, .external_lex_state = 3},
  [875] = {.lex_state = 36, .external_lex_state = 3},
  [876] = {.lex_state = 36, .external_lex_state = 3},
  [877] = {.lex_state = 36, .external_lex_state = 3},
  [878] = {.lex_state = 36, .external_lex_state = 3},
  [879] = {.lex_state = 36, .external_lex_state = 3},
  [880] = {.lex_state = 36, .external_lex_state = 3},
  [881] = {.lex_state = 36, .external_lex_state = 3},
  [882] = {.lex_state = 36, .external_lex_state = 3},
  [883] = {.lex_state = 36, .external_lex_state = 3},
  [884] = {.lex_state = 36, .external_lex_state = 3},
  [885] = {.lex_state = 36, .external_lex_state = 3},
  [886] = {.lex_state = 36, .external_lex_state = 3},
  [887] = {.lex_state = 36, .external_lex_state = 3},
  [888] = {.lex_state = 36, .external_lex_state = 3},
  [889] = {.lex_state = 36, .external_lex_state = 3},
  [890] = {.lex_state = 36, .external_lex_state = 3},
  [891] = {.lex_state = 36, .external_lex_state = 3},
  [892] = {.lex_state = 36, .external_lex_state = 3},
  [893] = {.lex_state = 36, .external_lex_state = 3},
  [894] = {.lex_state = 36, .external_lex_state = 3},
  [895] = {.lex_state = 36, .external_lex_state = 3},
  [896] = {.lex_state = 36, .external_lex_state = 3},
  [897] = {.lex_state = 36, .external_lex_state = 3},
  [898] = {.lex_state = 36, .external_lex_state = 3},
  [899] = {.lex_state = 36, .external_lex_state = 3},
  [900] = {.lex_state = 36, .external_lex_state = 3},
  [901] = {.lex_state = 36, .external_lex_state = 3},
  [902] = {.lex_state = 36, .external_lex_state = 3},
  [903] = {.lex_state = 36, .external_lex_state = 3},
  [904] = {.lex_state = 36, .external_lex_state = 3},
  [905] = {.lex_state = 36, .external_lex_state = 3},
  [906] = {.lex_state = 36, .external_lex_state = 3},
  [907] = {.lex_state = 36, .external_lex_state = 3},
  [908] = {.lex_state = 36, .external_lex_state = 3},
  [909] = {.lex_state = 36, .external_lex_state = 3},
  [910] = {.lex_state = 36, .external_lex_state = 3},
  [911] = {.lex_state = 36, .external_lex_state = 3},
  [912] = {.lex_state = 36, .external_lex_state = 3},
  [913] = {.lex_state = 36, .external_lex_state = 3},
  [914] = {.lex_state = 36, .external_lex_state = 3},
  [915] = {.lex_state = 36, .external_lex_state = 3},
  [916] = {.lex_state = 36, .external_lex_state = 3},
  [917] = {.lex_state = 36, .external_lex_state = 3},
  [918] = {.lex_state = 36, .external_lex_state = 3},
  [919] = {.lex_state = 36, .external_lex_state = 3},
  [920] = {.lex_state = 36, .external_lex_state = 3},
  [921] = {.lex_state = 36, .external_lex_state = 3},
  [922] = {.lex_state = 36, .external_lex_state = 3},
  [923] = {.lex_state = 36, .external_lex_state = 3},
  [924] = {.lex_state = 36, .external_lex_state = 3},
  [925] = {.lex_state = 36, .external_lex_state = 3},
  [926] = {.lex_state = 36, .external_lex_state = 3},
  [927] = {.lex_state = 36, .external_lex_state = 3},
  [928] = {.lex_state = 36, .external_lex_state = 3},
  [929] = {.lex_state = 36, .external_lex_state = 3},
  [930] = {.lex_state = 36, .external_lex_state = 3},
  [931] = {.lex_state = 36, .external_lex_state = 3},
  [932] = {.lex_state = 36, .external_lex_state = 3},
  [933] = {.lex_state = 36, .external_lex_state = 3},
  [934] = {.lex_state = 36, .external_lex_state = 3},
  [935] = {.lex_state = 36, .external_lex_state = 3},
  [936] = {.lex_state = 36, .external_lex_state = 3},
  [937] = {.lex_state = 36, .external_lex_state = 3},
  [938] = {.lex_state = 36, .external_lex_state = 3},
  [939] = {.lex_state = 36, .external_lex_state = 3},
  [940] = {.lex_state = 36, .external_lex_state = 3},
  [941] = {.lex_state = 36, .external_lex_state = 3},
  [942] = {.lex_state = 36, .external_lex_state = 3},
  [943] = {.lex_state = 36, .external_lex_state = 3},
  [944] = {.lex_state = 36, .external_lex_state = 3},
  [945] = {.lex_state = 36, .external_lex_state = 3},
  [946] = {.lex_state = 36, .external_lex_state = 3},
  [947] = {.lex_state = 36, .external_lex_state = 3},
  [948] = {.lex_state = 36, .external_lex_state = 3},
  [949] = {.lex_state = 36, .external_lex_state = 3},
  [950] = {.lex_state = 36, .external_lex_state = 3},
  [951] = {.lex_state = 36, .external_lex_state = 3},
  [952] = {.lex_state = 36, .external_lex_state = 3},
  [953] = {.lex_state = 36, .external_lex_state = 3},
  [954] = {.lex_state = 36, .external_lex_state = 3},
  [955] = {.lex_state = 36, .external_lex_state = 3},
  [956] = {.lex_state = 36, .external_lex_state = 3},
  [957] = {.lex_state = 36, .external_lex_state = 3},
  [958] = {.lex_state = 36, .external_lex_state = 3},
  [959] = {.lex_state = 36, .external_lex_state = 3},
  [960] = {.lex_state = 36, .external_lex_state = 3},
  [961] = {.lex_state = 36, .external_lex_state = 3},
  [962] = {.lex_state = 36, .external_lex_state = 3},
  [963] = {.lex_state = 36, .external_lex_state = 3},
  [964] = {.lex_state = 36, .external_lex_state = 3},
  [965] = {.lex_state = 36, .external_lex_state = 3},
  [966] = {.lex_state = 36, .external_lex_state = 3},
  [967] = {.lex_state = 36, .external_lex_state = 3},
  [968] = {.lex_state = 36, .external_lex_state = 3},
  [969] = {.lex_state = 36, .external_lex_state = 3},
  [970] = {.lex_state = 36, .external_lex_state = 3},
  [971] = {.lex_state = 36, .external_lex_state = 3},
  [972] = {.lex_state = 36, .external_lex_state = 3},
  [973] = {.lex_state = 36, .external_lex_state = 3},
  [974] = {.lex_state = 36, .external_lex_state = 3},
  [975] = {.lex_state = 36, .external_lex_state = 3},
  [976] = {.lex_state = 36, .external_lex_state = 3},
  [977] = {.lex_state = 36, .external_lex_state = 3},
  [978] = {.lex_state = 36, .external_lex_state = 3},
  [979] = {.lex_state = 36, .external_lex_state = 3},
  [980] = {.lex_state = 36, .external_lex_state = 3},
  [981] = {.lex_state = 36, .external_lex_state = 3},
  [982] = {.lex_state = 36, .external_lex_state = 3},
  [983] = {.lex_state = 36, .external_lex_state = 3},
  [984] = {.lex_state = 36, .external_lex_state = 3},
  [985] = {.lex_state = 36, .external_lex_state = 3},
  [986] = {.lex_state = 36, .external_lex_state = 3},
  [987] = {.lex_state = 36, .external_lex_state = 3},
  [988] = {.lex_state = 36, .external_lex_state = 3},
  [989] = {.lex_state = 36, .external_lex_state = 3},
  [990] = {.lex_state = 36, .external_lex_state = 3},
  [991] = {.lex_state = 36, .external_lex_state = 3},
  [992] = {.lex_state = 36, .external_lex_state = 3},
  [993] = {.lex_state = 36, .external_lex_state = 3},
  [994] = {.lex_state = 36, .external_lex_state = 3},
  [995] = {.lex_state = 36, .external_lex_state = 3},
  [996] = {.lex_state = 36, .external_lex_state = 3},
  [997] = {.lex_state = 36, .external_lex_state = 3},
  [998] = {.lex_state = 36, .external_lex_state = 3},
  [999] = {.lex_state = 36, .external_lex_state = 3},
  [1000] = {.lex_state = 36, .external_lex_state = 3},
  [1001] = {.lex_state = 36, .external_lex_state = 3},
  [1002] = {.lex_state = 36, .external_lex_state = 3},
  [1003] = {.lex_state = 36, .external_lex_state = 3},
  [1004] = {.lex_state = 36, .external_lex_state = 3},
  [1005] = {.lex_state = 36, .external_lex_state = 3},
  [1006] = {.lex_state = 36, .external_lex_state = 3},
  [1007] = {.lex_state = 36, .external_lex_state = 3},
  [1008] = {.lex_state = 36, .external_lex_state = 3},
  [1009] = {.lex_state = 36, .external_lex_state = 3},
  [1010] = {.lex_state = 36, .external_lex_state = 3},
  [1011] = {.lex_state = 36, .external_lex_state = 3},
  [1012] = {.lex_state = 36, .external_lex_state = 3},
  [1013] = {.lex_state = 36, .external_lex_state = 3},
  [1014] = {.lex_state = 36, .external_lex_state = 3},
  [1015] = {.lex_state = 36, .external_lex_state = 3},
  [1016] = {.lex_state = 36, .external_lex_state = 3},
  [1017] = {.lex_state = 36, .external_lex_state = 3},
  [1018] = {.lex_state = 36, .external_lex_state = 3},
  [1019] = {.lex_state = 36, .external_lex_state = 3},
  [1020] = {.lex_state = 36, .external_lex_state = 3},
  [1021] = {.lex_state = 36, .external_lex_state = 3},
  [1022] = {.lex_state = 36, .external_lex_state = 3},
  [1023] = {.lex_state = 36, .external_lex_state = 3},
  [1024] = {.lex_state = 36, .external_lex_state = 3},
  [1025] = {.lex_state = 36, .external_lex_state = 3},
  [1026] = {.lex_state = 36, .external_lex_state = 3},
  [1027] = {.lex_state = 36, .external_lex_state = 3},
  [1028] = {.lex_state = 36, .external_lex_state = 3},
  [1029] = {.lex_state = 36, .external_lex_state = 3},
  [1030] = {.lex_state = 36, .external_lex_state = 3},
  [1031] = {.lex_state = 36, .external_lex_state = 3},
  [1032] = {.lex_state = 36, .external_lex_state = 3},
  [1033] = {.lex_state = 36, .external_lex_state = 3},
  [1034] = {.lex_state = 36, .external_lex_state = 3},
  [1035] = {.lex_state = 36, .external_lex_state = 3},
  [1036] = {.lex_state = 36, .external_lex_state = 3},
  [1037] = {.lex_state = 36, .external_lex_state = 3},
  [1038] = {.lex_state = 36, .external_lex_state = 3},
  [1039] = {.lex_state = 36, .external_lex_state = 3},
  [1040] = {.lex_state = 36, .external_lex_state = 3},
  [1041] = {.lex_state = 36, .external_lex_state = 3},
  [1042] = {.lex_state = 36, .external_lex_state = 3},
  [1043] = {.lex_state = 36, .external_lex_state = 3},
  [1044] = {.lex_state = 36, .external_lex_state = 3},
  [1045] = {.lex_state = 36, .external_lex_state = 3},
  [1046] = {.lex_state = 36, .external_lex_state = 3},
  [1047] = {.lex_state = 36, .external_lex_state = 3},
  [1048] = {.lex_state = 36, .external_lex_state = 3},
  [1049] = {.lex_state = 36, .external_lex_state = 3},
  [1050] = {.lex_state = 36, .external_lex_state = 3},
  [1051] = {.lex_state = 36, .external_lex_state = 3},
  [1052] = {.lex_state = 36, .external_lex_state = 3},
  [1053] = {.lex_state = 36, .external_lex_state = 3},
  [1054] = {.lex_state = 36, .external_lex_state = 3},
  [1055] = {.lex_state = 36, .external_lex_state = 3},
  [1056] = {.lex_state = 36, .external_lex_state = 3},
  [1057] = {.lex_state = 36, .external_lex_state = 3},
  [1058] = {.lex_state = 36, .external_lex_state = 3},
  [1059] = {.lex_state = 36, .external_lex_state = 3},
  [1060] = {.lex_state = 36, .external_lex_state = 3},
  [1061] = {.lex_state = 36, .external_lex_state = 3},
  [1062] = {.lex_state = 36, .external_lex_state = 3},
  [1063] = {.lex_state = 36, .external_lex_state = 3},
  [1064] = {.lex_state = 36, .external_lex_state = 3},
  [1065] = {.lex_state = 36, .external_lex_state = 3},
  [1066] = {.lex_state = 36, .external_lex_state = 3},
  [1067] = {.lex_state = 36, .external_lex_state = 3},
  [1068] = {.lex_state = 36, .external_lex_state = 3},
  [1069] = {.lex_state = 36, .external_lex_state = 3},
  [1070] = {.lex_state = 36, .external_lex_state = 3},
  [1071] = {.lex_state = 36, .external_lex_state = 3},
  [1072] = {.lex_state = 36, .external_lex_state = 3},
  [1073] = {.lex_state = 36, .external_lex_state = 3},
  [1074] = {.lex_state = 36, .external_lex_state = 3},
  [1075] = {.lex_state = 36, .external_lex_state = 3},
  [1076] = {.lex_state = 36, .external_lex_state = 3},
  [1077] = {.lex_state = 36, .external_lex_state = 3},
  [1078] = {.lex_state = 36, .external_lex_state = 3},
  [1079] = {.lex_state = 36, .external_lex_state = 3},
  [1080] = {.lex_state = 36, .external_lex_state = 3},
  [1081] = {.lex_state = 36, .external_lex_state = 3},
  [1082] = {.lex_state = 36, .external_lex_state = 3},
  [1083] = {.lex_state = 36, .external_lex_state = 3},
  [1084] = {.lex_state = 36, .external_lex_state = 3},
  [1085] = {.lex_state = 36, .external_lex_state = 3},
  [1086] = {.lex_state = 36, .external_lex_state = 3},
  [1087] = {.lex_state = 36, .external_lex_state = 3},
  [1088] = {.lex_state = 36, .external_lex_state = 3},
  [1089] = {.lex_state = 36, .external_lex_state = 3},
  [1090] = {.lex_state = 36, .external_lex_state = 3},
  [1091] = {.lex_state = 36, .external_lex_state = 3},
  [1092] = {.lex_state = 36, .external_lex_state = 3},
  [1093] = {.lex_state = 36, .external_lex_state = 3},
  [1094] = {.lex_state = 36, .external_lex_state = 3},
  [1095] = {.lex_state = 36, .external_lex_state = 3},
  [1096] = {.lex_state = 36, .external_lex_state = 3},
  [1097] = {.lex_state = 36, .external_lex_state = 3},
  [1098] = {.lex_state = 36, .external_lex_state = 3},
  [1099] = {.lex_state = 36, .external_lex_state = 3},
  [1100] = {.lex_state = 36, .external_lex_state = 3},
  [1101] = {.lex_state = 36, .external_lex_state = 3},
  [1102] = {.lex_state = 36, .external_lex_state = 3},
  [1103] = {.lex_state = 36, .external_lex_state = 3},
  [1104] = {.lex_state = 36, .external_lex_state = 3},
  [1105] = {.lex_state = 36, .external_lex_state = 3},
  [1106] = {.lex_state = 36, .external_lex_state = 3},
  [1107] = {.lex_state = 36, .external_lex_state = 3},
  [1108] = {.lex_state = 36, .external_lex_state = 3},
  [1109] = {.lex_state = 36, .external_lex_state = 3},
  [1110] = {.lex_state = 36, .external_lex_state = 3},
  [1111] = {.lex_state = 36, .external_lex_state = 3},
  [1112] = {.lex_state = 36, .external_lex_state = 3},
  [1113] = {.lex_state = 36, .external_lex_state = 3},
  [1114] = {.lex_state = 36, .external_lex_state = 3},
  [1115] = {.lex_state = 36, .external_lex_state = 3},
  [1116] = {.lex_state = 36, .external_lex_state = 3},
  [1117] = {.lex_state = 36, .external_lex_state = 3},
  [1118] = {.lex_state = 36, .external_lex_state = 3},
  [1119] = {.lex_state = 36, .external_lex_state = 3},
  [1120] = {.lex_state = 36, .external_lex_state = 3},
  [1121] = {.lex_state = 36, .external_lex_state = 3},
  [1122] = {.lex_state = 36, .external_lex_state = 3},
  [1123] = {.lex_state = 36, .external_lex_state = 3},
  [1124] = {.lex_state = 36, .external_lex_state = 3},
  [1125] = {.lex_state = 36, .external_lex_state = 3},
  [1126] = {.lex_state = 36, .external_lex_state = 3},
  [1127] = {.lex_state = 36, .external_lex_state = 3},
  [1128] = {.lex_state = 36, .external_lex_state = 3},
  [1129] = {.lex_state = 36, .external_lex_state = 3},
  [1130] = {.lex_state = 36, .external_lex_state = 3},
  [1131] = {.lex_state = 36, .external_lex_state = 3},
  [1132] = {.lex_state = 36, .external_lex_state = 3},
  [1133] = {.lex_state = 36, .external_lex_state = 3},
  [1134] = {.lex_state = 36, .external_lex_state = 3},
  [1135] = {.lex_state = 36, .external_lex_state = 3},
  [1136] = {.lex_state = 36, .external_lex_state = 3},
  [1137] = {.lex_state = 36, .external_lex_state = 3},
  [1138] = {.lex_state = 36, .external_lex_state = 3},
  [1139] = {.lex_state = 36, .external_lex_state = 3},
  [1140] = {.lex_state = 36, .external_lex_state = 3},
  [1141] = {.lex_state = 36, .external_lex_state = 3},
  [1142] = {.lex_state = 36, .external_lex_state = 3},
  [1143] = {.lex_state = 36, .external_lex_state = 3},
  [1144] = {.lex_state = 36, .external_lex_state = 3},
  [1145] = {.lex_state = 36, .external_lex_state = 3},
  [1146] = {.lex_state = 36, .external_lex_state = 3},
  [1147] = {.lex_state = 36, .external_lex_state = 3},
  [1148] = {.lex_state = 36, .external_lex_state = 3},
  [1149] = {.lex_state = 36, .external_lex_state = 3},
  [1150] = {.lex_state = 36, .external_lex_state = 3},
  [1151] = {.lex_state = 36, .external_lex_state = 3},
  [1152] = {.lex_state = 36, .external_lex_state = 3},
  [1153] = {.lex_state = 36, .external_lex_state = 3},
  [1154] = {.lex_state = 36, .external_lex_state = 3},
  [1155] = {.lex_state = 36, .external_lex_state = 3},
  [1156] = {.lex_state = 36, .external_lex_state = 3},
  [1157] = {.lex_state = 36, .external_lex_state = 3},
  [1158] = {.lex_state = 36, .external_lex_state = 3},
  [1159] = {.lex_state = 36, .external_lex_state = 3},
  [1160] = {.lex_state = 36, .external_lex_state = 3},
  [1161] = {.lex_state = 36, .external_lex_state = 3},
  [1162] = {.lex_state = 36, .external_lex_state = 3},
  [1163] = {.lex_state = 36, .external_lex_state = 3},
  [1164] = {.lex_state = 36, .external_lex_state = 3},
  [1165] = {.lex_state = 36, .external_lex_state = 3},
  [1166] = {.lex_state = 36, .external_lex_state = 3},
  [1167] = {.lex_state = 36, .external_lex_state = 3},
  [1168] = {.lex_state = 36, .external_lex_state = 3},
  [1169] = {.lex_state = 36, .external_lex_state = 3},
  [1170] = {.lex_state = 36, .external_lex_state = 3},
  [1171] = {.lex_state = 36, .external_lex_state = 3},
  [1172] = {.lex_state = 36, .external_lex_state = 3},
  [1173] = {.lex_state = 36, .external_lex_state = 3},
  [1174] = {.lex_state = 36, .external_lex_state = 3},
  [1175] = {.lex_state = 36, .external_lex_state = 3},
  [1176] = {.lex_state = 36, .external_lex_state = 3},
  [1177] = {.lex_state = 36, .external_lex_state = 3},
  [1178] = {.lex_state = 36, .external_lex_state = 3},
  [1179] = {.lex_state = 36, .external_lex_state = 3},
  [1180] = {.lex_state = 36, .external_lex_state = 3},
  [1181] = {.lex_state = 36, .external_lex_state = 3},
  [1182] = {.lex_state = 36, .external_lex_state = 3},
  [1183] = {.lex_state = 36, .external_lex_state = 3},
  [1184] = {.lex_state = 36, .external_lex_state = 3},
  [1185] = {.lex_state = 36, .external_lex_state = 3},
  [1186] = {.lex_state = 36, .external_lex_state = 3},
  [1187] = {.lex_state = 36, .external_lex_state = 3},
  [1188] = {.lex_state = 36, .external_lex_state = 3},
  [1189] = {.lex_state = 36, .external_lex_state = 3},
  [1190] = {.lex_state = 36, .external_lex_state = 3},
  [1191] = {.lex_state = 36, .external_lex_state = 3},
  [1192] = {.lex_state = 36, .external_lex_state = 3},
  [1193] = {.lex_state = 36, .external_lex_state = 3},
  [1194] = {.lex_state = 36, .external_lex_state = 3},
  [1195] = {.lex_state = 36, .external_lex_state = 3},
  [1196] = {.lex_state = 36, .external_lex_state = 3},
  [1197] = {.lex_state = 36, .external_lex_state = 3},
  [1198] = {.lex_state = 36, .external_lex_state = 3},
  [1199] = {.lex_state = 36, .external_lex_state = 3},
  [1200] = {.lex_state = 36, .external_lex_state = 3},
  [1201] = {.lex_state = 36, .external_lex_state = 3},
  [1202] = {.lex_state = 36, .external_lex_state = 3},
  [1203] = {.lex_state = 36, .external_lex_state = 3},
  [1204] = {.lex_state = 36, .external_lex_state = 3},
  [1205] = {.lex_state = 36, .external_lex_state = 3},
  [1206] = {.lex_state = 36, .external_lex_state = 3},
  [1207] = {.lex_state = 36, .external_lex_state = 3},
  [1208] = {.lex_state = 36, .external_lex_state = 3},
  [1209] = {.lex_state = 36, .external_lex_state = 3},
  [1210] = {.lex_state = 36, .external_lex_state = 3},
  [1211] = {.lex_state = 36, .external_lex_state = 3},
  [1212] = {.lex_state = 36, .external_lex_state = 3},
  [1213] = {.lex_state = 36, .external_lex_state = 3},
  [1214] = {.lex_state = 36, .external_lex_state = 3},
  [1215] = {.lex_state = 36, .external_lex_state = 3},
  [1216] = {.lex_state = 36, .external_lex_state = 3},
  [1217] = {.lex_state = 36, .external_lex_state = 3},
  [1218] = {.lex_state = 36, .external_lex_state = 3},
  [1219] = {.lex_state = 36, .external_lex_state = 3},
  [1220] = {.lex_state = 36, .external_lex_state = 3},
  [1221] = {.lex_state = 36, .external_lex_state = 3},
  [1222] = {.lex_state = 36, .external_lex_state = 3},
  [1223] = {.lex_state = 36, .external_lex_state = 3},
  [1224] = {.lex_state = 36, .external_lex_state = 3},
  [1225] = {.lex_state = 36, .external_lex_state = 3},
  [1226] = {.lex_state = 36, .external_lex_state = 3},
  [1227] = {.lex_state = 36, .external_lex_state = 3},
  [1228] = {.lex_state = 36, .external_lex_state = 3},
  [1229] = {.lex_state = 36, .external_lex_state = 3},
  [1230] = {.lex_state = 36, .external_lex_state = 3},
  [1231] = {.lex_state = 36, .external_lex_state = 3},
  [1232] = {.lex_state = 36, .external_lex_state = 3},
  [1233] = {.lex_state = 36, .external_lex_state = 3},
  [1234] = {.lex_state = 36, .external_lex_state = 3},
  [1235] = {.lex_state = 36, .external_lex_state = 3},
  [1236] = {.lex_state = 36, .external_lex_state = 3},
  [1237] = {.lex_state = 36, .external_lex_state = 3},
  [1238] = {.lex_state = 36, .external_lex_state = 3},
  [1239] = {.lex_state = 36, .external_lex_state = 3},
  [1240] = {.lex_state = 36, .external_lex_state = 3},
  [1241] = {.lex_state = 36, .external_lex_state = 3},
  [1242] = {.lex_state = 36, .external_lex_state = 3},
  [1243] = {.lex_state = 36, .external_lex_state = 3},
  [1244] = {.lex_state = 36, .external_lex_state = 3},
  [1245] = {.lex_state = 36, .external_lex_state = 3},
  [1246] = {.lex_state = 36, .external_lex_state = 3},
  [1247] = {.lex_state = 36, .external_lex_state = 3},
  [1248] = {.lex_state = 36, .external_lex_state = 3},
  [1249] = {.lex_state = 36, .external_lex_state = 3},
  [1250] = {.lex_state = 36, .external_lex_state = 3},
  [1251] = {.lex_state = 36, .external_lex_state = 3},
  [1252] = {.lex_state = 36, .external_lex_state = 3},
  [1253] = {.lex_state = 36, .external_lex_state = 3},
  [1254] = {.lex_state = 36, .external_lex_state = 3},
  [1255] = {.lex_state = 36, .external_lex_state = 3},
  [1256] = {.lex_state = 36, .external_lex_state = 3},
  [1257] = {.lex_state = 36, .external_lex_state = 3},
  [1258] = {.lex_state = 36, .external_lex_state = 3},
  [1259] = {.lex_state = 36, .external_lex_state = 3},
  [1260] = {.lex_state = 36, .external_lex_state = 3},
  [1261] = {.lex_state = 36, .external_lex_state = 3},
  [1262] = {.lex_state = 36, .external_lex_state = 3},
  [1263] = {.lex_state = 36, .external_lex_state = 3},
  [1264] = {.lex_state = 36, .external_lex_state = 3},
  [1265] = {.lex_state = 36, .external_lex_state = 3},
  [1266] = {.lex_state = 36, .external_lex_state = 3},
  [1267] = {.lex_state = 36, .external_lex_state = 3},
  [1268] = {.lex_state = 36, .external_lex_state = 3},
  [1269] = {.lex_state = 36, .external_lex_state = 3},
  [1270] = {.lex_state = 36, .external_lex_state = 3},
  [1271] = {.lex_state = 36, .external_lex_state = 3},
  [1272] = {.lex_state = 36, .external_lex_state = 3},
  [1273] = {.lex_state = 36, .external_lex_state = 3},
  [1274] = {.lex_state = 36, .external_lex_state = 3},
  [1275] = {.lex_state = 36, .external_lex_state = 3},
  [1276] = {.lex_state = 36, .external_lex_state = 3},
  [1277] = {.lex_state = 36, .external_lex_state = 3},
  [1278] = {.lex_state = 36, .external_lex_state = 3},
  [1279] = {.lex_state = 36, .external_lex_state = 3},
  [1280] = {.lex_state = 36, .external_lex_state = 3},
  [1281] = {.lex_state = 36, .external_lex_state = 3},
  [1282] = {.lex_state = 36, .external_lex_state = 3},
  [1283] = {.lex_state = 36, .external_lex_state = 3},
  [1284] = {.lex_state = 36, .external_lex_state = 3},
  [1285] = {.lex_state = 36, .external_lex_state = 3},
  [1286] = {.lex_state = 36, .external_lex_state = 3},
  [1287] = {.lex_state = 36, .external_lex_state = 3},
  [1288] = {.lex_state = 36, .external_lex_state = 3},
  [1289] = {.lex_state = 36, .external_lex_state = 3},
  [1290] = {.lex_state = 36, .external_lex_state = 3},
  [1291] = {.lex_state = 36, .external_lex_state = 3},
  [1292] = {.lex_state = 36, .external_lex_state = 3},
  [1293] = {.lex_state = 36, .external_lex_state = 3},
  [1294] = {.lex_state = 36, .external_lex_state = 3},
  [1295] = {.lex_state = 36, .external_lex_state = 3},
  [1296] = {.lex_state = 36, .external_lex_state = 3},
  [1297] = {.lex_state = 36, .external_lex_state = 3},
  [1298] = {.lex_state = 36, .external_lex_state = 3},
  [1299] = {.lex_state = 36, .external_lex_state = 3},
  [1300] = {.lex_state = 36, .external_lex_state = 3},
  [1301] = {.lex_state = 36, .external_lex_state = 3},
  [1302] = {.lex_state = 36, .external_lex_state = 3},
  [1303] = {.lex_state = 36, .external_lex_state = 3},
  [1304] = {.lex_state = 36, .external_lex_state = 3},
  [1305] = {.lex_state = 36, .external_lex_state = 3},
  [1306] = {.lex_state = 36, .external_lex_state = 3},
  [1307] = {.lex_state = 36, .external_lex_state = 3},
  [1308] = {.lex_state = 36, .external_lex_state = 3},
  [1309] = {.lex_state = 36, .external_lex_state = 3},
  [1310] = {.lex_state = 36, .external_lex_state = 3},
  [1311] = {.lex_state = 36, .external_lex_state = 3},
  [1312] = {.lex_state = 36, .external_lex_state = 3},
  [1313] = {.lex_state = 36, .external_lex_state = 3},
  [1314] = {.lex_state = 36, .external_lex_state = 3},
  [1315] = {.lex_state = 36, .external_lex_state = 3},
  [1316] = {.lex_state = 36, .external_lex_state = 3},
  [1317] = {.lex_state = 36, .external_lex_state = 3},
  [1318] = {.lex_state = 36, .external_lex_state = 3},
  [1319] = {.lex_state = 36, .external_lex_state = 3},
  [1320] = {.lex_state = 36, .external_lex_state = 3},
  [1321] = {.lex_state = 36, .external_lex_state = 3},
  [1322] = {.lex_state = 36, .external_lex_state = 3},
  [1323] = {.lex_state = 36, .external_lex_state = 3},
  [1324] = {.lex_state = 36, .external_lex_state = 3},
  [1325] = {.lex_state = 36, .external_lex_state = 3},
  [1326] = {.lex_state = 36, .external_lex_state = 3},
  [1327] = {.lex_state = 36, .external_lex_state = 3},
  [1328] = {.lex_state = 36, .external_lex_state = 3},
  [1329] = {.lex_state = 36, .external_lex_state = 3},
  [1330] = {.lex_state = 36, .external_lex_state = 3},
  [1331] = {.lex_state = 36, .external_lex_state = 3},
  [1332] = {.lex_state = 36, .external_lex_state = 3},
  [1333] = {.lex_state = 36, .external_lex_state = 3},
  [1334] = {.lex_state = 36, .external_lex_state = 3},
  [1335] = {.lex_state = 36, .external_lex_state = 3},
  [1336] = {.lex_state = 36, .external_lex_state = 3},
  [1337] = {.lex_state = 36, .external_lex_state = 3},
  [1338] = {.lex_state = 36, .external_lex_state = 3},
  [1339] = {.lex_state = 36, .external_lex_state = 3},
  [1340] = {.lex_state = 36, .external_lex_state = 3},
  [1341] = {.lex_state = 36, .external_lex_state = 3},
  [1342] = {.lex_state = 36, .external_lex_state = 3},
  [1343] = {.lex_state = 36, .external_lex_state = 3},
  [1344] = {.lex_state = 36, .external_lex_state = 3},
  [1345] = {.lex_state = 36, .external_lex_state = 3},
  [1346] = {.lex_state = 36, .external_lex_state = 3},
  [1347] = {.lex_state = 36, .external_lex_state = 3},
  [1348] = {.lex_state = 36, .external_lex_state = 3},
  [1349] = {.lex_state = 36, .external_lex_state = 3},
  [1350] = {.lex_state = 36, .external_lex_state = 3},
  [1351] = {.lex_state = 36, .external_lex_state = 3},
  [1352] = {.lex_state = 36, .external_lex_state = 3},
  [1353] = {.lex_state = 36, .external_lex_state = 3},
  [1354] = {.lex_state = 36, .external_lex_state = 3},
  [1355] = {.lex_state = 36, .external_lex_state = 3},
  [1356] = {.lex_state = 36, .external_lex_state = 3},
  [1357] = {.lex_state = 36, .external_lex_state = 3},
  [1358] = {.lex_state = 36, .external_lex_state = 3},
  [1359] = {.lex_state = 36, .external_lex_state = 3},
  [1360] = {.lex_state = 36, .external_lex_state = 3},
  [1361] = {.lex_state = 36, .external_lex_state = 3},
  [1362] = {.lex_state = 36, .external_lex_state = 3},
  [1363] = {.lex_state = 36, .external_lex_state = 3},
  [1364] = {.lex_state = 36, .external_lex_state = 3},
  [1365] = {.lex_state = 36, .external_lex_state = 3},
  [1366] = {.lex_state = 36, .external_lex_state = 3},
  [1367] = {.lex_state = 36, .external_lex_state = 3},
  [1368] = {.lex_state = 36, .external_lex_state = 3},
  [1369] = {.lex_state = 36, .external_lex_state = 3},
  [1370] = {.lex_state = 36, .external_lex_state = 3},
  [1371] = {.lex_state = 36, .external_lex_state = 3},
  [1372] = {.lex_state = 36, .external_lex_state = 3},
  [1373] = {.lex_state = 36, .external_lex_state = 3},
  [1374] = {.lex_state = 36, .external_lex_state = 3},
  [1375] = {.lex_state = 36, .external_lex_state = 3},
  [1376] = {.lex_state = 36, .external_lex_state = 3},
  [1377] = {.lex_state = 36, .external_lex_state = 3},
  [1378] = {.lex_state = 36, .external_lex_state = 3},
  [1379] = {.lex_state = 36, .external_lex_state = 3},
  [1380] = {.lex_state = 36, .external_lex_state = 3},
  [1381] = {.lex_state = 36, .external_lex_state = 3},
  [1382] = {.lex_state = 36, .external_lex_state = 3},
  [1383] = {.lex_state = 36, .external_lex_state = 3},
  [1384] = {.lex_state = 36, .external_lex_state = 3},
  [1385] = {.lex_state = 36, .external_lex_state = 3},
  [1386] = {.lex_state = 36, .external_lex_state = 3},
  [1387] = {.lex_state = 36, .external_lex_state = 3},
  [1388] = {.lex_state = 36, .external_lex_state = 3},
  [1389] = {.lex_state = 36, .external_lex_state = 3},
  [1390] = {.lex_state = 36, .external_lex_state = 3},
  [1391] = {.lex_state = 36, .external_lex_state = 3},
  [1392] = {.lex_state = 36, .external_lex_state = 3},
  [1393] = {.lex_state = 36, .external_lex_state = 3},
  [1394] = {.lex_state = 36, .external_lex_state = 3},
  [1395] = {.lex_state = 36, .external_lex_state = 3},
  [1396] = {.lex_state = 36, .external_lex_state = 3},
  [1397] = {.lex_state = 36, .external_lex_state = 3},
  [1398] = {.lex_state = 36, .external_lex_state = 3},
  [1399] = {.lex_state = 36, .external_lex_state = 3},
  [1400] = {.lex_state = 36, .external_lex_state = 3},
  [1401] = {.lex_state = 36, .external_lex_state = 3},
  [1402] = {.lex_state = 36, .external_lex_state = 3},
  [1403] = {.lex_state = 36, .external_lex_state = 3},
  [1404] = {.lex_state = 36, .external_lex_state = 3},
  [1405] = {.lex_state = 36, .external_lex_state = 3},
  [1406] = {.lex_state = 36, .external_lex_state = 3},
  [1407] = {.lex_state = 36, .external_lex_state = 3},
  [1408] = {.lex_state = 36, .external_lex_state = 3},
  [1409] = {.lex_state = 36, .external_lex_state = 3},
  [1410] = {.lex_state = 36, .external_lex_state = 3},
  [1411] = {.lex_state = 36, .external_lex_state = 3},
  [1412] = {.lex_state = 36, .external_lex_state = 3},
  [1413] = {.lex_state = 36, .external_lex_state = 3},
  [1414] = {.lex_state = 36, .external_lex_state = 3},
  [1415] = {.lex_state = 36, .external_lex_state = 3},
  [1416] = {.lex_state = 36, .external_lex_state = 3},
  [1417] = {.lex_state = 36, .external_lex_state = 3},
  [1418] = {.lex_state = 36, .external_lex_state = 3},
  [1419] = {.lex_state = 36, .external_lex_state = 3},
  [1420] = {.lex_state = 36, .external_lex_state = 3},
  [1421] = {.lex_state = 36, .external_lex_state = 3},
  [1422] = {.lex_state = 36, .external_lex_state = 3},
  [1423] = {.lex_state = 36, .external_lex_state = 3},
  [1424] = {.lex_state = 36, .external_lex_state = 3},
  [1425] = {.lex_state = 36, .external_lex_state = 3},
  [1426] = {.lex_state = 36, .external_lex_state = 3},
  [1427] = {.lex_state = 36, .external_lex_state = 3},
  [1428] = {.lex_state = 36, .external_lex_state = 3},
  [1429] = {.lex_state = 36, .external_lex_state = 3},
  [1430] = {.lex_state = 36, .external_lex_state = 3},
  [1431] = {.lex_state = 36, .external_lex_state = 3},
  [1432] = {.lex_state = 36, .external_lex_state = 3},
  [1433] = {.lex_state = 36, .external_lex_state = 3},
  [1434] = {.lex_state = 36, .external_lex_state = 3},
  [1435] = {.lex_state = 36, .external_lex_state = 3},
  [1436] = {.lex_state = 36, .external_lex_state = 3},
  [1437] = {.lex_state = 36, .external_lex_state = 3},
  [1438] = {.lex_state = 36, .external_lex_state = 3},
  [1439] = {.lex_state = 36, .external_lex_state = 3},
  [1440] = {.lex_state = 36, .external_lex_state = 3},
  [1441] = {.lex_state = 36, .external_lex_state = 3},
  [1442] = {.lex_state = 36, .external_lex_state = 3},
  [1443] = {.lex_state = 36, .external_lex_state = 3},
  [1444] = {.lex_state = 36, .external_lex_state = 3},
  [1445] = {.lex_state = 36, .external_lex_state = 3},
  [1446] = {.lex_state = 36, .external_lex_state = 3},
  [1447] = {.lex_state = 36, .external_lex_state = 3},
  [1448] = {.lex_state = 36, .external_lex_state = 3},
  [1449] = {.lex_state = 36, .external_lex_state = 3},
  [1450] = {.lex_state = 36, .external_lex_state = 3},
  [1451] = {.lex_state = 36, .external_lex_state = 3},
  [1452] = {.lex_state = 36, .external_lex_state = 3},
  [1453] = {.lex_state = 36, .external_lex_state = 3},
  [1454] = {.lex_state = 36, .external_lex_state = 3},
  [1455] = {.lex_state = 36, .external_lex_state = 3},
  [1456] = {.lex_state = 36, .external_lex_state = 3},
  [1457] = {.lex_state = 36, .external_lex_state = 3},
  [1458] = {.lex_state = 36, .external_lex_state = 3},
  [1459] = {.lex_state = 36, .external_lex_state = 3},
  [1460] = {.lex_state = 36, .external_lex_state = 3},
  [1461] = {.lex_state = 36, .external_lex_state = 3},
  [1462] = {.lex_state = 36, .external_lex_state = 3},
  [1463] = {.lex_state = 36, .external_lex_state = 3},
  [1464] = {.lex_state = 36, .external_lex_state = 3},
  [1465] = {.lex_state = 36, .external_lex_state = 3},
  [1466] = {.lex_state = 36, .external_lex_state = 3},
  [1467] = {.lex_state = 36, .external_lex_state = 3},
  [1468] = {.lex_state = 36, .external_lex_state = 3},
  [1469] = {.lex_state = 36, .external_lex_state = 3},
  [1470] = {.lex_state = 36, .external_lex_state = 3},
  [1471] = {.lex_state = 36, .external_lex_state = 3},
  [1472] = {.lex_state = 36, .external_lex_state = 3},
  [1473] = {.lex_state = 36, .external_lex_state = 3},
  [1474] = {.lex_state = 36, .external_lex_state = 3},
  [1475] = {.lex_state = 36, .external_lex_state = 3},
  [1476] = {.lex_state = 36, .external_lex_state = 3},
  [1477] = {.lex_state = 36, .external_lex_state = 3},
  [1478] = {.lex_state = 36, .external_lex_state = 3},
  [1479] = {.lex_state = 36, .external_lex_state = 3},
  [1480] = {.lex_state = 36, .external_lex_state = 3},
  [1481] = {.lex_state = 36, .external_lex_state = 3},
  [1482] = {.lex_state = 36, .external_lex_state = 3},
  [1483] = {.lex_state = 36, .external_lex_state = 3},
  [1484] = {.lex_state = 36, .external_lex_state = 3},
  [1485] = {.lex_state = 36, .external_lex_state = 3},
  [1486] = {.lex_state = 36, .external_lex_state = 3},
  [1487] = {.lex_state = 36, .external_lex_state = 3},
  [1488] = {.lex_state = 36, .external_lex_state = 3},
  [1489] = {.lex_state = 36, .external_lex_state = 3},
  [1490] = {.lex_state = 36, .external_lex_state = 3},
  [1491] = {.lex_state = 36, .external_lex_state = 3},
  [1492] = {.lex_state = 36, .external_lex_state = 3},
  [1493] = {.lex_state = 36, .external_lex_state = 3},
  [1494] = {.lex_state = 36, .external_lex_state = 3},
  [1495] = {.lex_state = 36, .external_lex_state = 3},
  [1496] = {.lex_state = 36, .external_lex_state = 3},
  [1497] = {.lex_state = 36, .external_lex_state = 3},
  [1498] = {.lex_state = 36, .external_lex_state = 3},
  [1499] = {.lex_state = 36, .external_lex_state = 3},
  [1500] = {.lex_state = 36, .external_lex_state = 3},
  [1501] = {.lex_state = 36, .external_lex_state = 3},
  [1502] = {.lex_state = 36, .external_lex_state = 3},
  [1503] = {.lex_state = 36, .external_lex_state = 3},
  [1504] = {.lex_state = 36, .external_lex_state = 3},
  [1505] = {.lex_state = 36, .external_lex_state = 3},
  [1506] = {.lex_state = 36, .external_lex_state = 3},
  [1507] = {.lex_state = 36, .external_lex_state = 3},
  [1508] = {.lex_state = 36, .external_lex_state = 3},
  [1509] = {.lex_state = 36, .external_lex_state = 3},
  [1510] = {.lex_state = 36, .external_lex_state = 3},
  [1511] = {.lex_state = 36, .external_lex_state = 3},
  [1512] = {.lex_state = 36, .external_lex_state = 3},
  [1513] = {.lex_state = 36, .external_lex_state = 3},
  [1514] = {.lex_state = 36, .external_lex_state = 3},
  [1515] = {.lex_state = 36, .external_lex_state = 3},
  [1516] = {.lex_state = 36, .external_lex_state = 3},
  [1517] = {.lex_state = 36, .external_lex_state = 3},
  [1518] = {.lex_state = 36, .external_lex_state = 3},
  [1519] = {.lex_state = 36, .external_lex_state = 3},
  [1520] = {.lex_state = 36, .external_lex_state = 3},
  [1521] = {.lex_state = 36, .external_lex_state = 3},
  [1522] = {.lex_state = 36, .external_lex_state = 3},
  [1523] = {.lex_state = 36, .external_lex_state = 3},
  [1524] = {.lex_state = 36, .external_lex_state = 3},
  [1525] = {.lex_state = 36, .external_lex_state = 3},
  [1526] = {.lex_state = 36, .external_lex_state = 3},
  [1527] = {.lex_state = 98, .external_lex_state = 3},
  [1528] = {.lex_state = 36, .external_lex_state = 3},
  [1529] = {.lex_state = 36, .external_lex_state = 3},
  [1530] = {.lex_state = 36, .external_lex_state = 3},
  [1531] = {.lex_state = 36, .external_lex_state = 3},
  [1532] = {.lex_state = 36, .external_lex_state = 3},
  [1533] = {.lex_state = 36, .external_lex_state = 3},
  [1534] = {.lex_state = 36, .external_lex_state = 3},
  [1535] = {.lex_state = 36, .external_lex_state = 3},
  [1536] = {.lex_state = 36, .external_lex_state = 3},
  [1537] = {.lex_state = 36, .external_lex_state = 3},
  [1538] = {.lex_state = 36, .external_lex_state = 3},
  [1539] = {.lex_state = 36, .external_lex_state = 3},
  [1540] = {.lex_state = 36, .external_lex_state = 3},
  [1541] = {.lex_state = 36, .external_lex_state = 3},
  [1542] = {.lex_state = 36, .external_lex_state = 3},
  [1543] = {.lex_state = 36, .external_lex_state = 3},
  [1544] = {.lex_state = 36, .external_lex_state = 3},
  [1545] = {.lex_state = 36, .external_lex_state = 3},
  [1546] = {.lex_state = 36, .external_lex_state = 3},
  [1547] = {.lex_state = 36, .external_lex_state = 3},
  [1548] = {.lex_state = 36, .external_lex_state = 3},
  [1549] = {.lex_state = 36, .external_lex_state = 3},
  [1550] = {.lex_state = 36, .external_lex_state = 3},
  [1551] = {.lex_state = 36, .external_lex_state = 3},
  [1552] = {.lex_state = 36, .external_lex_state = 3},
  [1553] = {.lex_state = 36, .external_lex_state = 3},
  [1554] = {.lex_state = 36, .external_lex_state = 3},
  [1555] = {.lex_state = 36, .external_lex_state = 3},
  [1556] = {.lex_state = 36, .external_lex_state = 3},
  [1557] = {.lex_state = 36, .external_lex_state = 3},
  [1558] = {.lex_state = 36, .external_lex_state = 3},
  [1559] = {.lex_state = 36, .external_lex_state = 3},
  [1560] = {.lex_state = 36, .external_lex_state = 3},
  [1561] = {.lex_state = 36, .external_lex_state = 3},
  [1562] = {.lex_state = 36, .external_lex_state = 3},
  [1563] = {.lex_state = 36, .external_lex_state = 3},
  [1564] = {.lex_state = 36, .external_lex_state = 3},
  [1565] = {.lex_state = 36, .external_lex_state = 3},
  [1566] = {.lex_state = 36, .external_lex_state = 3},
  [1567] = {.lex_state = 36, .external_lex_state = 3},
  [1568] = {.lex_state = 36, .external_lex_state = 3},
  [1569] = {.lex_state = 36, .external_lex_state = 3},
  [1570] = {.lex_state = 36, .external_lex_state = 3},
  [1571] = {.lex_state = 36, .external_lex_state = 3},
  [1572] = {.lex_state = 36, .external_lex_state = 3},
  [1573] = {.lex_state = 36, .external_lex_state = 3},
  [1574] = {.lex_state = 36, .external_lex_state = 3},
  [1575] = {.lex_state = 36, .external_lex_state = 3},
  [1576] = {.lex_state = 36, .external_lex_state = 3},
  [1577] = {.lex_state = 36, .external_lex_state = 3},
  [1578] = {.lex_state = 36, .external_lex_state = 3},
  [1579] = {.lex_state = 36, .external_lex_state = 3},
  [1580] = {.lex_state = 36, .external_lex_state = 3},
  [1581] = {.lex_state = 36, .external_lex_state = 3},
  [1582] = {.lex_state = 93, .external_lex_state = 3},
  [1583] = {.lex_state = 36, .external_lex_state = 3},
  [1584] = {.lex_state = 36, .external_lex_state = 3},
  [1585] = {.lex_state = 36, .external_lex_state = 3},
  [1586] = {.lex_state = 36, .external_lex_state = 3},
  [1587] = {.lex_state = 36, .external_lex_state = 3},
  [1588] = {.lex_state = 36, .external_lex_state = 3},
  [1589] = {.lex_state = 36, .external_lex_state = 3},
  [1590] = {.lex_state = 36, .external_lex_state = 3},
  [1591] = {.lex_state = 36, .external_lex_state = 3},
  [1592] = {.lex_state = 36, .external_lex_state = 3},
  [1593] = {.lex_state = 36, .external_lex_state = 3},
  [1594] = {.lex_state = 36, .external_lex_state = 3},
  [1595] = {.lex_state = 36, .external_lex_state = 3},
  [1596] = {.lex_state = 36, .external_lex_state = 3},
  [1597] = {.lex_state = 36, .external_lex_state = 3},
  [1598] = {.lex_state = 36, .external_lex_state = 3},
  [1599] = {.lex_state = 36, .external_lex_state = 3},
  [1600] = {.lex_state = 36, .external_lex_state = 3},
  [1601] = {.lex_state = 36, .external_lex_state = 3},
  [1602] = {.lex_state = 36, .external_lex_state = 3},
  [1603] = {.lex_state = 36, .external_lex_state = 3},
  [1604] = {.lex_state = 36, .external_lex_state = 3},
  [1605] = {.lex_state = 36, .external_lex_state = 3},
  [1606] = {.lex_state = 36, .external_lex_state = 3},
  [1607] = {.lex_state = 36, .external_lex_state = 3},
  [1608] = {.lex_state = 36, .external_lex_state = 3},
  [1609] = {.lex_state = 36, .external_lex_state = 3},
  [1610] = {.lex_state = 36, .external_lex_state = 3},
  [1611] = {.lex_state = 36, .external_lex_state = 3},
  [1612] = {.lex_state = 36, .external_lex_state = 3},
  [1613] = {.lex_state = 36, .external_lex_state = 3},
  [1614] = {.lex_state = 36, .external_lex_state = 3},
  [1615] = {.lex_state = 36, .external_lex_state = 3},
  [1616] = {.lex_state = 36, .external_lex_state = 3},
  [1617] = {.lex_state = 36, .external_lex_state = 3},
  [1618] = {.lex_state = 36, .external_lex_state = 3},
  [1619] = {.lex_state = 36, .external_lex_state = 3},
  [1620] = {.lex_state = 36, .external_lex_state = 3},
  [1621] = {.lex_state = 36, .external_lex_state = 3},
  [1622] = {.lex_state = 36, .external_lex_state = 3},
  [1623] = {.lex_state = 36, .external_lex_state = 3},
  [1624] = {.lex_state = 36, .external_lex_state = 3},
  [1625] = {.lex_state = 36, .external_lex_state = 3},
  [1626] = {.lex_state = 36, .external_lex_state = 3},
  [1627] = {.lex_state = 36, .external_lex_state = 3},
  [1628] = {.lex_state = 36, .external_lex_state = 3},
  [1629] = {.lex_state = 36, .external_lex_state = 3},
  [1630] = {.lex_state = 36, .external_lex_state = 3},
  [1631] = {.lex_state = 36, .external_lex_state = 3},
  [1632] = {.lex_state = 36, .external_lex_state = 3},
  [1633] = {.lex_state = 36, .external_lex_state = 3},
  [1634] = {.lex_state = 36, .external_lex_state = 3},
  [1635] = {.lex_state = 36, .external_lex_state = 3},
  [1636] = {.lex_state = 36, .external_lex_state = 3},
  [1637] = {.lex_state = 36, .external_lex_state = 3},
  [1638] = {.lex_state = 36, .external_lex_state = 3},
  [1639] = {.lex_state = 36, .external_lex_state = 3},
  [1640] = {.lex_state = 36, .external_lex_state = 3},
  [1641] = {.lex_state = 36, .external_lex_state = 3},
  [1642] = {.lex_state = 36, .external_lex_state = 3},
  [1643] = {.lex_state = 36, .external_lex_state = 3},
  [1644] = {.lex_state = 36, .external_lex_state = 3},
  [1645] = {.lex_state = 36, .external_lex_state = 3},
  [1646] = {.lex_state = 36, .external_lex_state = 3},
  [1647] = {.lex_state = 36, .external_lex_state = 3},
  [1648] = {.lex_state = 36, .external_lex_state = 3},
  [1649] = {.lex_state = 36, .external_lex_state = 3},
  [1650] = {.lex_state = 36, .external_lex_state = 3},
  [1651] = {.lex_state = 36, .external_lex_state = 3},
  [1652] = {.lex_state = 36, .external_lex_state = 3},
  [1653] = {.lex_state = 36, .external_lex_state = 3},
  [1654] = {.lex_state = 36, .external_lex_state = 3},
  [1655] = {.lex_state = 36, .external_lex_state = 3},
  [1656] = {.lex_state = 36, .external_lex_state = 3},
  [1657] = {.lex_state = 36, .external_lex_state = 3},
  [1658] = {.lex_state = 36, .external_lex_state = 3},
  [1659] = {.lex_state = 36, .external_lex_state = 3},
  [1660] = {.lex_state = 36, .external_lex_state = 3},
  [1661] = {.lex_state = 36, .external_lex_state = 3},
  [1662] = {.lex_state = 36, .external_lex_state = 3},
  [1663] = {.lex_state = 36, .external_lex_state = 3},
  [1664] = {.lex_state = 36, .external_lex_state = 3},
  [1665] = {.lex_state = 36, .external_lex_state = 3},
  [1666] = {.lex_state = 36, .external_lex_state = 3},
  [1667] = {.lex_state = 36, .external_lex_state = 3},
  [1668] = {.lex_state = 36, .external_lex_state = 3},
  [1669] = {.lex_state = 36, .external_lex_state = 3},
  [1670] = {.lex_state = 36, .external_lex_state = 3},
  [1671] = {.lex_state = 36, .external_lex_state = 3},
  [1672] = {.lex_state = 36, .external_lex_state = 3},
  [1673] = {.lex_state = 36, .external_lex_state = 3},
  [1674] = {.lex_state = 36, .external_lex_state = 3},
  [1675] = {.lex_state = 36, .external_lex_state = 3},
  [1676] = {.lex_state = 36, .external_lex_state = 3},
  [1677] = {.lex_state = 36, .external_lex_state = 3},
  [1678] = {.lex_state = 36, .external_lex_state = 3},
  [1679] = {.lex_state = 36, .external_lex_state = 3},
  [1680] = {.lex_state = 36, .external_lex_state = 3},
  [1681] = {.lex_state = 36, .external_lex_state = 3},
  [1682] = {.lex_state = 36, .external_lex_state = 3},
  [1683] = {.lex_state = 36, .external_lex_state = 3},
  [1684] = {.lex_state = 36, .external_lex_state = 3},
  [1685] = {.lex_state = 36, .external_lex_state = 3},
  [1686] = {.lex_state = 36, .external_lex_state = 3},
  [1687] = {.lex_state = 36, .external_lex_state = 3},
  [1688] = {.lex_state = 36, .external_lex_state = 3},
  [1689] = {.lex_state = 36, .external_lex_state = 3},
  [1690] = {.lex_state = 36, .external_lex_state = 3},
  [1691] = {.lex_state = 36, .external_lex_state = 3},
  [1692] = {.lex_state = 36, .external_lex_state = 3},
  [1693] = {.lex_state = 36, .external_lex_state = 3},
  [1694] = {.lex_state = 36, .external_lex_state = 3},
  [1695] = {.lex_state = 36, .external_lex_state = 3},
  [1696] = {.lex_state = 36, .external_lex_state = 3},
  [1697] = {.lex_state = 36, .external_lex_state = 3},
  [1698] = {.lex_state = 36, .external_lex_state = 3},
  [1699] = {.lex_state = 36, .external_lex_state = 3},
  [1700] = {.lex_state = 36, .external_lex_state = 3},
  [1701] = {.lex_state = 36, .external_lex_state = 3},
  [1702] = {.lex_state = 36, .external_lex_state = 3},
  [1703] = {.lex_state = 36, .external_lex_state = 3},
  [1704] = {.lex_state = 36, .external_lex_state = 3},
  [1705] = {.lex_state = 36, .external_lex_state = 3},
  [1706] = {.lex_state = 36, .external_lex_state = 3},
  [1707] = {.lex_state = 36, .external_lex_state = 3},
  [1708] = {.lex_state = 36, .external_lex_state = 3},
  [1709] = {.lex_state = 36, .external_lex_state = 3},
  [1710] = {.lex_state = 36, .external_lex_state = 3},
  [1711] = {.lex_state = 36, .external_lex_state = 3},
  [1712] = {.lex_state = 36, .external_lex_state = 3},
  [1713] = {.lex_state = 36, .external_lex_state = 3},
  [1714] = {.lex_state = 78, .external_lex_state = 3},
  [1715] = {.lex_state = 36, .external_lex_state = 3},
  [1716] = {.lex_state = 36, .external_lex_state = 3},
  [1717] = {.lex_state = 36, .external_lex_state = 3},
  [1718] = {.lex_state = 36, .external_lex_state = 3},
  [1719] = {.lex_state = 36, .external_lex_state = 3},
  [1720] = {.lex_state = 36, .external_lex_state = 3},
  [1721] = {.lex_state = 36, .external_lex_state = 3},
  [1722] = {.lex_state = 36, .external_lex_state = 3},
  [1723] = {.lex_state = 36, .external_lex_state = 3},
  [1724] = {.lex_state = 36, .external_lex_state = 3},
  [1725] = {.lex_state = 36, .external_lex_state = 3},
  [1726] = {.lex_state = 36, .external_lex_state = 3},
  [1727] = {.lex_state = 36, .external_lex_state = 3},
  [1728] = {.lex_state = 36, .external_lex_state = 3},
  [1729] = {.lex_state = 36, .external_lex_state = 3},
  [1730] = {.lex_state = 36, .external_lex_state = 3},
  [1731] = {.lex_state = 36, .external_lex_state = 3},
  [1732] = {.lex_state = 36, .external_lex_state = 3},
  [1733] = {.lex_state = 36, .external_lex_state = 3},
  [1734] = {.lex_state = 36, .external_lex_state = 3},
  [1735] = {.lex_state = 36, .external_lex_state = 3},
  [1736] = {.lex_state = 36, .external_lex_state = 3},
  [1737] = {.lex_state = 36, .external_lex_state = 3},
  [1738] = {.lex_state = 36, .external_lex_state = 3},
  [1739] = {.lex_state = 36, .external_lex_state = 3},
  [1740] = {.lex_state = 36, .external_lex_state = 3},
  [1741] = {.lex_state = 36, .external_lex_state = 3},
  [1742] = {.lex_state = 36, .external_lex_state = 3},
  [1743] = {.lex_state = 36, .external_lex_state = 3},
  [1744] = {.lex_state = 36, .external_lex_state = 3},
  [1745] = {.lex_state = 36, .external_lex_state = 3},
  [1746] = {.lex_state = 36, .external_lex_state = 3},
  [1747] = {.lex_state = 36, .external_lex_state = 3},
  [1748] = {.lex_state = 36, .external_lex_state = 3},
  [1749] = {.lex_state = 36, .external_lex_state = 3},
  [1750] = {.lex_state = 36, .external_lex_state = 3},
  [1751] = {.lex_state = 36, .external_lex_state = 3},
  [1752] = {.lex_state = 36, .external_lex_state = 3},
  [1753] = {.lex_state = 36, .external_lex_state = 3},
  [1754] = {.lex_state = 36, .external_lex_state = 3},
  [1755] = {.lex_state = 36, .external_lex_state = 3},
  [1756] = {.lex_state = 36, .external_lex_state = 3},
  [1757] = {.lex_state = 36, .external_lex_state = 3},
  [1758] = {.lex_state = 36, .external_lex_state = 3},
  [1759] = {.lex_state = 36, .external_lex_state = 3},
  [1760] = {.lex_state = 74, .external_lex_state = 3},
  [1761] = {.lex_state = 36, .external_lex_state = 3},
  [1762] = {.lex_state = 36, .external_lex_state = 3},
  [1763] = {.lex_state = 36, .external_lex_state = 3},
  [1764] = {.lex_state = 36, .external_lex_state = 3},
  [1765] = {.lex_state = 36, .external_lex_state = 3},
  [1766] = {.lex_state = 36, .external_lex_state = 3},
  [1767] = {.lex_state = 74, .external_lex_state = 3},
  [1768] = {.lex_state = 36, .external_lex_state = 3},
  [1769] = {.lex_state = 36, .external_lex_state = 3},
  [1770] = {.lex_state = 36, .external_lex_state = 3},
  [1771] = {.lex_state = 78, .external_lex_state = 3},
  [1772] = {.lex_state = 36, .external_lex_state = 3},
  [1773] = {.lex_state = 36, .external_lex_state = 3},
  [1774] = {.lex_state = 36, .external_lex_state = 3},
  [1775] = {.lex_state = 36, .external_lex_state = 3},
  [1776] = {.lex_state = 36, .external_lex_state = 3},
  [1777] = {.lex_state = 36, .external_lex_state = 3},
  [1778] = {.lex_state = 36, .external_lex_state = 3},
  [1779] = {.lex_state = 36, .external_lex_state = 3},
  [1780] = {.lex_state = 36, .external_lex_state = 3},
  [1781] = {.lex_state = 36, .external_lex_state = 3},
  [1782] = {.lex_state = 36, .external_lex_state = 3},
  [1783] = {.lex_state = 36, .external_lex_state = 3},
  [1784] = {.lex_state = 36, .external_lex_state = 3},
  [1785] = {.lex_state = 36, .external_lex_state = 3},
  [1786] = {.lex_state = 36, .external_lex_state = 3},
  [1787] = {.lex_state = 36, .external_lex_state = 3},
  [1788] = {.lex_state = 36, .external_lex_state = 3},
  [1789] = {.lex_state = 36, .external_lex_state = 3},
  [1790] = {.lex_state = 36, .external_lex_state = 3},
  [1791] = {.lex_state = 36, .external_lex_state = 3},
  [1792] = {.lex_state = 36, .external_lex_state = 3},
  [1793] = {.lex_state = 75, .external_lex_state = 3},
  [1794] = {.lex_state = 36, .external_lex_state = 3},
  [1795] = {.lex_state = 36, .external_lex_state = 3},
  [1796] = {.lex_state = 36, .external_lex_state = 3},
  [1797] = {.lex_state = 36, .external_lex_state = 3},
  [1798] = {.lex_state = 36, .external_lex_state = 3},
  [1799] = {.lex_state = 36, .external_lex_state = 3},
  [1800] = {.lex_state = 36, .external_lex_state = 3},
  [1801] = {.lex_state = 36, .external_lex_state = 3},
  [1802] = {.lex_state = 36, .external_lex_state = 3},
  [1803] = {.lex_state = 36, .external_lex_state = 3},
  [1804] = {.lex_state = 36, .external_lex_state = 3},
  [1805] = {.lex_state = 36, .external_lex_state = 3},
  [1806] = {.lex_state = 36, .external_lex_state = 3},
  [1807] = {.lex_state = 36, .external_lex_state = 3},
  [1808] = {.lex_state = 36, .external_lex_state = 3},
  [1809] = {.lex_state = 36, .external_lex_state = 3},
  [1810] = {.lex_state = 36, .external_lex_state = 3},
  [1811] = {.lex_state = 36, .external_lex_state = 3},
  [1812] = {.lex_state = 36, .external_lex_state = 3},
  [1813] = {.lex_state = 36, .external_lex_state = 3},
  [1814] = {.lex_state = 36, .external_lex_state = 3},
  [1815] = {.lex_state = 79, .external_lex_state = 3},
  [1816] = {.lex_state = 36, .external_lex_state = 3},
  [1817] = {.lex_state = 36, .external_lex_state = 3},
  [1818] = {.lex_state = 36, .external_lex_state = 3},
  [1819] = {.lex_state = 36, .external_lex_state = 3},
  [1820] = {.lex_state = 36, .external_lex_state = 3},
  [1821] = {.lex_state = 36, .external_lex_state = 3},
  [1822] = {.lex_state = 36, .external_lex_state = 3},
  [1823] = {.lex_state = 36, .external_lex_state = 3},
  [1824] = {.lex_state = 36, .external_lex_state = 3},
  [1825] = {.lex_state = 36, .external_lex_state = 3},
  [1826] = {.lex_state = 36, .external_lex_state = 3},
  [1827] = {.lex_state = 36, .external_lex_state = 3},
  [1828] = {.lex_state = 36, .external_lex_state = 3},
  [1829] = {.lex_state = 36, .external_lex_state = 3},
  [1830] = {.lex_state = 36, .external_lex_state = 3},
  [1831] = {.lex_state = 36, .external_lex_state = 3},
  [1832] = {.lex_state = 36, .external_lex_state = 3},
  [1833] = {.lex_state = 36, .external_lex_state = 3},
  [1834] = {.lex_state = 36, .external_lex_state = 3},
  [1835] = {.lex_state = 36, .external_lex_state = 3},
  [1836] = {.lex_state = 36, .external_lex_state = 3},
  [1837] = {.lex_state = 36, .external_lex_state = 3},
  [1838] = {.lex_state = 36, .external_lex_state = 3},
  [1839] = {.lex_state = 36, .external_lex_state = 3},
  [1840] = {.lex_state = 36, .external_lex_state = 3},
  [1841] = {.lex_state = 36, .external_lex_state = 3},
  [1842] = {.lex_state = 36, .external_lex_state = 3},
  [1843] = {.lex_state = 36, .external_lex_state = 3},
  [1844] = {.lex_state = 36, .external_lex_state = 3},
  [1845] = {.lex_state = 36, .external_lex_state = 3},
  [1846] = {.lex_state = 36, .external_lex_state = 3},
  [1847] = {.lex_state = 36, .external_lex_state = 3},
  [1848] = {.lex_state = 36, .external_lex_state = 3},
  [1849] = {.lex_state = 36, .external_lex_state = 3},
  [1850] = {.lex_state = 36, .external_lex_state = 3},
  [1851] = {.lex_state = 36, .external_lex_state = 3},
  [1852] = {.lex_state = 36, .external_lex_state = 3},
  [1853] = {.lex_state = 36, .external_lex_state = 3},
  [1854] = {.lex_state = 36, .external_lex_state = 3},
  [1855] = {.lex_state = 36, .external_lex_state = 3},
  [1856] = {.lex_state = 36, .external_lex_state = 3},
  [1857] = {.lex_state = 36, .external_lex_state = 3},
  [1858] = {.lex_state = 36, .external_lex_state = 3},
  [1859] = {.lex_state = 36, .external_lex_state = 3},
  [1860] = {.lex_state = 36, .external_lex_state = 3},
  [1861] = {.lex_state = 36, .external_lex_state = 3},
  [1862] = {.lex_state = 36, .external_lex_state = 3},
  [1863] = {.lex_state = 36, .external_lex_state = 3},
  [1864] = {.lex_state = 36, .external_lex_state = 3},
  [1865] = {.lex_state = 36, .external_lex_state = 3},
  [1866] = {.lex_state = 36, .external_lex_state = 3},
  [1867] = {.lex_state = 36, .external_lex_state = 3},
  [1868] = {.lex_state = 36, .external_lex_state = 3},
  [1869] = {.lex_state = 36, .external_lex_state = 3},
  [1870] = {.lex_state = 36, .external_lex_state = 3},
  [1871] = {.lex_state = 36, .external_lex_state = 3},
  [1872] = {.lex_state = 36, .external_lex_state = 3},
  [1873] = {.lex_state = 36, .external_lex_state = 3},
  [1874] = {.lex_state = 36, .external_lex_state = 3},
  [1875] = {.lex_state = 36, .external_lex_state = 3},
  [1876] = {.lex_state = 36, .external_lex_state = 3},
  [1877] = {.lex_state = 36, .external_lex_state = 3},
  [1878] = {.lex_state = 36, .external_lex_state = 3},
  [1879] = {.lex_state = 36, .external_lex_state = 3},
  [1880] = {.lex_state = 36, .external_lex_state = 3},
  [1881] = {.lex_state = 36, .external_lex_state = 3},
  [1882] = {.lex_state = 36, .external_lex_state = 3},
  [1883] = {.lex_state = 36, .external_lex_state = 3},
  [1884] = {.lex_state = 36, .external_lex_state = 3},
  [1885] = {.lex_state = 36, .external_lex_state = 3},
  [1886] = {.lex_state = 36, .external_lex_state = 3},
  [1887] = {.lex_state = 36, .external_lex_state = 3},
  [1888] = {.lex_state = 36, .external_lex_state = 3},
  [1889] = {.lex_state = 36, .external_lex_state = 3},
  [1890] = {.lex_state = 36, .external_lex_state = 3},
  [1891] = {.lex_state = 36, .external_lex_state = 3},
  [1892] = {.lex_state = 36, .external_lex_state = 3},
  [1893] = {.lex_state = 36, .external_lex_state = 3},
  [1894] = {.lex_state = 36, .external_lex_state = 3},
  [1895] = {.lex_state = 36, .external_lex_state = 3},
  [1896] = {.lex_state = 36, .external_lex_state = 3},
  [1897] = {.lex_state = 36, .external_lex_state = 3},
  [1898] = {.lex_state = 36, .external_lex_state = 3},
  [1899] = {.lex_state = 36, .external_lex_state = 3},
  [1900] = {.lex_state = 36, .external_lex_state = 3},
  [1901] = {.lex_state = 36, .external_lex_state = 3},
  [1902] = {.lex_state = 36, .external_lex_state = 3},
  [1903] = {.lex_state = 36, .external_lex_state = 3},
  [1904] = {.lex_state = 36, .external_lex_state = 3},
  [1905] = {.lex_state = 36, .external_lex_state = 3},
  [1906] = {.lex_state = 36, .external_lex_state = 3},
  [1907] = {.lex_state = 36, .external_lex_state = 3},
  [1908] = {.lex_state = 36, .external_lex_state = 3},
  [1909] = {.lex_state = 99, .external_lex_state = 3},
  [1910] = {.lex_state = 36, .external_lex_state = 3},
  [1911] = {.lex_state = 36, .external_lex_state = 3},
  [1912] = {.lex_state = 36, .external_lex_state = 3},
  [1913] = {.lex_state = 36, .external_lex_state = 3},
  [1914] = {.lex_state = 36, .external_lex_state = 3},
  [1915] = {.lex_state = 36, .external_lex_state = 3},
  [1916] = {.lex_state = 36, .external_lex_state = 3},
  [1917] = {.lex_state = 36, .external_lex_state = 3},
  [1918] = {.lex_state = 36, .external_lex_state = 3},
  [1919] = {.lex_state = 36, .external_lex_state = 3},
  [1920] = {.lex_state = 36, .external_lex_state = 3},
  [1921] = {.lex_state = 36, .external_lex_state = 3},
  [1922] = {.lex_state = 36, .external_lex_state = 3},
  [1923] = {.lex_state = 36, .external_lex_state = 3},
  [1924] = {.lex_state = 36, .external_lex_state = 3},
  [1925] = {.lex_state = 36, .external_lex_state = 3},
  [1926] = {.lex_state = 36, .external_lex_state = 3},
  [1927] = {.lex_state = 36, .external_lex_state = 3},
  [1928] = {.lex_state = 36, .external_lex_state = 3},
  [1929] = {.lex_state = 36, .external_lex_state = 3},
  [1930] = {.lex_state = 36, .external_lex_state = 3},
  [1931] = {.lex_state = 36, .external_lex_state = 3},
  [1932] = {.lex_state = 36, .external_lex_state = 3},
  [1933] = {.lex_state = 36, .external_lex_state = 3},
  [1934] = {.lex_state = 36, .external_lex_state = 3},
  [1935] = {.lex_state = 36, .external_lex_state = 3},
  [1936] = {.lex_state = 36, .external_lex_state = 3},
  [1937] = {.lex_state = 36, .external_lex_state = 3},
  [1938] = {.lex_state = 36, .external_lex_state = 3},
  [1939] = {.lex_state = 36, .external_lex_state = 3},
  [1940] = {.lex_state = 36, .external_lex_state = 3},
  [1941] = {.lex_state = 36, .external_lex_state = 3},
  [1942] = {.lex_state = 36, .external_lex_state = 3},
  [1943] = {.lex_state = 36, .external_lex_state = 3},
  [1944] = {.lex_state = 36, .external_lex_state = 3},
  [1945] = {.lex_state = 36, .external_lex_state = 3},
  [1946] = {.lex_state = 36, .external_lex_state = 3},
  [1947] = {.lex_state = 36, .external_lex_state = 3},
  [1948] = {.lex_state = 36, .external_lex_state = 3},
  [1949] = {.lex_state = 36, .external_lex_state = 3},
  [1950] = {.lex_state = 36, .external_lex_state = 3},
  [1951] = {.lex_state = 36, .external_lex_state = 3},
  [1952] = {.lex_state = 36, .external_lex_state = 3},
  [1953] = {.lex_state = 36, .external_lex_state = 3},
  [1954] = {.lex_state = 36, .external_lex_state = 3},
  [1955] = {.lex_state = 36, .external_lex_state = 3},
  [1956] = {.lex_state = 36, .external_lex_state = 3},
  [1957] = {.lex_state = 36, .external_lex_state = 3},
  [1958] = {.lex_state = 36, .external_lex_state = 3},
  [1959] = {.lex_state = 36, .external_lex_state = 3},
  [1960] = {.lex_state = 36, .external_lex_state = 3},
  [1961] = {.lex_state = 36, .external_lex_state = 3},
  [1962] = {.lex_state = 36, .external_lex_state = 3},
  [1963] = {.lex_state = 80, .external_lex_state = 3},
  [1964] = {.lex_state = 36, .external_lex_state = 3},
  [1965] = {.lex_state = 36, .external_lex_state = 3},
  [1966] = {.lex_state = 36, .external_lex_state = 3},
  [1967] = {.lex_state = 36, .external_lex_state = 3},
  [1968] = {.lex_state = 36, .external_lex_state = 3},
  [1969] = {.lex_state = 36, .external_lex_state = 3},
  [1970] = {.lex_state = 36, .external_lex_state = 3},
  [1971] = {.lex_state = 36, .external_lex_state = 3},
  [1972] = {.lex_state = 36, .external_lex_state = 3},
  [1973] = {.lex_state = 36, .external_lex_state = 3},
  [1974] = {.lex_state = 36, .external_lex_state = 3},
  [1975] = {.lex_state = 36, .external_lex_state = 3},
  [1976] = {.lex_state = 36, .external_lex_state = 3},
  [1977] = {.lex_state = 36, .external_lex_state = 3},
  [1978] = {.lex_state = 36, .external_lex_state = 3},
  [1979] = {.lex_state = 36, .external_lex_state = 3},
  [1980] = {.lex_state = 36, .external_lex_state = 3},
  [1981] = {.lex_state = 36, .external_lex_state = 3},
  [1982] = {.lex_state = 36, .external_lex_state = 3},
  [1983] = {.lex_state = 36, .external_lex_state = 3},
  [1984] = {.lex_state = 36, .external_lex_state = 3},
  [1985] = {.lex_state = 36, .external_lex_state = 3},
  [1986] = {.lex_state = 36, .external_lex_state = 3},
  [1987] = {.lex_state = 36, .external_lex_state = 3},
  [1988] = {.lex_state = 36, .external_lex_state = 3},
  [1989] = {.lex_state = 36, .external_lex_state = 3},
  [1990] = {.lex_state = 36, .external_lex_state = 3},
  [1991] = {.lex_state = 36, .external_lex_state = 3},
  [1992] = {.lex_state = 36, .external_lex_state = 3},
  [1993] = {.lex_state = 36, .external_lex_state = 3},
  [1994] = {.lex_state = 36, .external_lex_state = 3},
  [1995] = {.lex_state = 36, .external_lex_state = 3},
  [1996] = {.lex_state = 36, .external_lex_state = 3},
  [1997] = {.lex_state = 36, .external_lex_state = 3},
  [1998] = {.lex_state = 36, .external_lex_state = 3},
  [1999] = {.lex_state = 36, .external_lex_state = 3},
  [2000] = {.lex_state = 36, .external_lex_state = 3},
  [2001] = {.lex_state = 36, .external_lex_state = 3},
  [2002] = {.lex_state = 36, .external_lex_state = 3},
  [2003] = {.lex_state = 36, .external_lex_state = 3},
  [2004] = {.lex_state = 36, .external_lex_state = 3},
  [2005] = {.lex_state = 36, .external_lex_state = 3},
  [2006] = {.lex_state = 36, .external_lex_state = 3},
  [2007] = {.lex_state = 36, .external_lex_state = 3},
  [2008] = {.lex_state = 36, .external_lex_state = 3},
  [2009] = {.lex_state = 36, .external_lex_state = 3},
  [2010] = {.lex_state = 36, .external_lex_state = 3},
  [2011] = {.lex_state = 36, .external_lex_state = 3},
  [2012] = {.lex_state = 36, .external_lex_state = 3},
  [2013] = {.lex_state = 36, .external_lex_state = 3},
  [2014] = {.lex_state = 36, .external_lex_state = 3},
  [2015] = {.lex_state = 36, .external_lex_state = 3},
  [2016] = {.lex_state = 36, .external_lex_state = 3},
  [2017] = {.lex_state = 36, .external_lex_state = 3},
  [2018] = {.lex_state = 75, .external_lex_state = 3},
  [2019] = {.lex_state = 36, .external_lex_state = 3},
  [2020] = {.lex_state = 36, .external_lex_state = 3},
  [2021] = {.lex_state = 36, .external_lex_state = 3},
  [2022] = {.lex_state = 36, .external_lex_state = 3},
  [2023] = {.lex_state = 36, .external_lex_state = 3},
  [2024] = {.lex_state = 36, .external_lex_state = 3},
  [2025] = {.lex_state = 36, .external_lex_state = 3},
  [2026] = {.lex_state = 36, .external_lex_state = 3},
  [2027] = {.lex_state = 36, .external_lex_state = 3},
  [2028] = {.lex_state = 36, .external_lex_state = 3},
  [2029] = {.lex_state = 36, .external_lex_state = 3},
  [2030] = {.lex_state = 36, .external_lex_state = 3},
  [2031] = {.lex_state = 36, .external_lex_state = 3},
  [2032] = {.lex_state = 36, .external_lex_state = 3},
  [2033] = {.lex_state = 36, .external_lex_state = 3},
  [2034] = {.lex_state = 36, .external_lex_state = 3},
  [2035] = {.lex_state = 36, .external_lex_state = 3},
  [2036] = {.lex_state = 36, .external_lex_state = 3},
  [2037] = {.lex_state = 36, .external_lex_state = 3},
  [2038] = {.lex_state = 36, .external_lex_state = 3},
  [2039] = {.lex_state = 36, .external_lex_state = 3},
  [2040] = {.lex_state = 36, .external_lex_state = 3},
  [2041] = {.lex_state = 36, .external_lex_state = 3},
  [2042] = {.lex_state = 36, .external_lex_state = 3},
  [2043] = {.lex_state = 36, .external_lex_state = 3},
  [2044] = {.lex_state = 36, .external_lex_state = 3},
  [2045] = {.lex_state = 36, .external_lex_state = 3},
  [2046] = {.lex_state = 36, .external_lex_state = 3},
  [2047] = {.lex_state = 36, .external_lex_state = 3},
  [2048] = {.lex_state = 36, .external_lex_state = 3},
  [2049] = {.lex_state = 36, .external_lex_state = 3},
  [2050] = {.lex_state = 36, .external_lex_state = 3},
  [2051] = {.lex_state = 36, .external_lex_state = 3},
  [2052] = {.lex_state = 36, .external_lex_state = 3},
  [2053] = {.lex_state = 36, .external_lex_state = 3},
  [2054] = {.lex_state = 36, .external_lex_state = 3},
  [2055] = {.lex_state = 36, .external_lex_state = 3},
  [2056] = {.lex_state = 36, .external_lex_state = 3},
  [2057] = {.lex_state = 36, .external_lex_state = 3},
  [2058] = {.lex_state = 36, .external_lex_state = 3},
  [2059] = {.lex_state = 36, .external_lex_state = 3},
  [2060] = {.lex_state = 36, .external_lex_state = 3},
  [2061] = {.lex_state = 36, .external_lex_state = 3},
  [2062] = {.lex_state = 36, .external_lex_state = 3},
  [2063] = {.lex_state = 36, .external_lex_state = 3},
  [2064] = {.lex_state = 36, .external_lex_state = 3},
  [2065] = {.lex_state = 79, .external_lex_state = 3},
  [2066] = {.lex_state = 36, .external_lex_state = 3},
  [2067] = {.lex_state = 36, .external_lex_state = 3},
  [2068] = {.lex_state = 36, .external_lex_state = 3},
  [2069] = {.lex_state = 36, .external_lex_state = 3},
  [2070] = {.lex_state = 36, .external_lex_state = 3},
  [2071] = {.lex_state = 36, .external_lex_state = 3},
  [2072] = {.lex_state = 36, .external_lex_state = 3},
  [2073] = {.lex_state = 36, .external_lex_state = 3},
  [2074] = {.lex_state = 36, .external_lex_state = 3},
  [2075] = {.lex_state = 36, .external_lex_state = 3},
  [2076] = {.lex_state = 36, .external_lex_state = 3},
  [2077] = {.lex_state = 36, .external_lex_state = 3},
  [2078] = {.lex_state = 36, .external_lex_state = 3},
  [2079] = {.lex_state = 36, .external_lex_state = 3},
  [2080] = {.lex_state = 36, .external_lex_state = 3},
  [2081] = {.lex_state = 36, .external_lex_state = 3},
  [2082] = {.lex_state = 36, .external_lex_state = 3},
  [2083] = {.lex_state = 36, .external_lex_state = 3},
  [2084] = {.lex_state = 36, .external_lex_state = 3},
  [2085] = {.lex_state = 36, .external_lex_state = 3},
  [2086] = {.lex_state = 36, .external_lex_state = 3},
  [2087] = {.lex_state = 36, .external_lex_state = 3},
  [2088] = {.lex_state = 36, .external_lex_state = 3},
  [2089] = {.lex_state = 36, .external_lex_state = 3},
  [2090] = {.lex_state = 36, .external_lex_state = 3},
  [2091] = {.lex_state = 36, .external_lex_state = 3},
  [2092] = {.lex_state = 36, .external_lex_state = 3},
  [2093] = {.lex_state = 36, .external_lex_state = 3},
  [2094] = {.lex_state = 36, .external_lex_state = 3},
  [2095] = {.lex_state = 36, .external_lex_state = 3},
  [2096] = {.lex_state = 36, .external_lex_state = 3},
  [2097] = {.lex_state = 36, .external_lex_state = 3},
  [2098] = {.lex_state = 36, .external_lex_state = 3},
  [2099] = {.lex_state = 36, .external_lex_state = 3},
  [2100] = {.lex_state = 36, .external_lex_state = 3},
  [2101] = {.lex_state = 36, .external_lex_state = 3},
  [2102] = {.lex_state = 36, .external_lex_state = 3},
  [2103] = {.lex_state = 36, .external_lex_state = 3},
  [2104] = {.lex_state = 36, .external_lex_state = 3},
  [2105] = {.lex_state = 36, .external_lex_state = 3},
  [2106] = {.lex_state = 36, .external_lex_state = 3},
  [2107] = {.lex_state = 36, .external_lex_state = 3},
  [2108] = {.lex_state = 36, .external_lex_state = 3},
  [2109] = {.lex_state = 36, .external_lex_state = 3},
  [2110] = {.lex_state = 36, .external_lex_state = 3},
  [2111] = {.lex_state = 36, .external_lex_state = 3},
  [2112] = {.lex_state = 36, .external_lex_state = 3},
  [2113] = {.lex_state = 36, .external_lex_state = 3},
  [2114] = {.lex_state = 36, .external_lex_state = 3},
  [2115] = {.lex_state = 36, .external_lex_state = 3},
  [2116] = {.lex_state = 36, .external_lex_state = 3},
  [2117] = {.lex_state = 36, .external_lex_state = 3},
  [2118] = {.lex_state = 80, .external_lex_state = 3},
  [2119] = {.lex_state = 36, .external_lex_state = 3},
  [2120] = {.lex_state = 36, .external_lex_state = 3},
  [2121] = {.lex_state = 36, .external_lex_state = 3},
  [2122] = {.lex_state = 36, .external_lex_state = 3},
  [2123] = {.lex_state = 36, .external_lex_state = 3},
  [2124] = {.lex_state = 92, .external_lex_state = 3},
  [2125] = {.lex_state = 36, .external_lex_state = 3},
  [2126] = {.lex_state = 72, .external_lex_state = 3},
  [2127] = {.lex_state = 36, .external_lex_state = 3},
  [2128] = {.lex_state = 36, .external_lex_state = 3},
  [2129] = {.lex_state = 36, .external_lex_state = 3},
  [2130] = {.lex_state = 36, .external_lex_state = 3},
  [2131] = {.lex_state = 36, .external_lex_state = 3},
  [2132] = {.lex_state = 36, .external_lex_state = 3},
  [2133] = {.lex_state = 36, .external_lex_state = 3},
  [2134] = {.lex_state = 36, .external_lex_state = 3},
  [2135] = {.lex_state = 36, .external_lex_state = 3},
  [2136] = {.lex_state = 36, .external_lex_state = 3},
  [2137] = {.lex_state = 36, .external_lex_state = 3},
  [2138] = {.lex_state = 36, .external_lex_state = 3},
  [2139] = {.lex_state = 36, .external_lex_state = 3},
  [2140] = {.lex_state = 36, .external_lex_state = 3},
  [2141] = {.lex_state = 36, .external_lex_state = 3},
  [2142] = {.lex_state = 36, .external_lex_state = 3},
  [2143] = {.lex_state = 36, .external_lex_state = 3},
  [2144] = {.lex_state = 36, .external_lex_state = 3},
  [2145] = {.lex_state = 36, .external_lex_state = 3},
  [2146] = {.lex_state = 36, .external_lex_state = 3},
  [2147] = {.lex_state = 36, .external_lex_state = 3},
  [2148] = {.lex_state = 36, .external_lex_state = 3},
  [2149] = {.lex_state = 36, .external_lex_state = 3},
  [2150] = {.lex_state = 36, .external_lex_state = 3},
  [2151] = {.lex_state = 36, .external_lex_state = 3},
  [2152] = {.lex_state = 36, .external_lex_state = 3},
  [2153] = {.lex_state = 36, .external_lex_state = 3},
  [2154] = {.lex_state = 36, .external_lex_state = 3},
  [2155] = {.lex_state = 36, .external_lex_state = 3},
  [2156] = {.lex_state = 36, .external_lex_state = 3},
  [2157] = {.lex_state = 36, .external_lex_state = 3},
  [2158] = {.lex_state = 36, .external_lex_state = 3},
  [2159] = {.lex_state = 36, .external_lex_state = 3},
  [2160] = {.lex_state = 36, .external_lex_state = 3},
  [2161] = {.lex_state = 36, .external_lex_state = 3},
  [2162] = {.lex_state = 36, .external_lex_state = 3},
  [2163] = {.lex_state = 36, .external_lex_state = 3},
  [2164] = {.lex_state = 36, .external_lex_state = 3},
  [2165] = {.lex_state = 36, .external_lex_state = 3},
  [2166] = {.lex_state = 36, .external_lex_state = 3},
  [2167] = {.lex_state = 36, .external_lex_state = 3},
  [2168] = {.lex_state = 36, .external_lex_state = 3},
  [2169] = {.lex_state = 36, .external_lex_state = 3},
  [2170] = {.lex_state = 36, .external_lex_state = 3},
  [2171] = {.lex_state = 36, .external_lex_state = 3},
  [2172] = {.lex_state = 36, .external_lex_state = 3},
  [2173] = {.lex_state = 36, .external_lex_state = 3},
  [2174] = {.lex_state = 36, .external_lex_state = 3},
  [2175] = {.lex_state = 36, .external_lex_state = 3},
  [2176] = {.lex_state = 36, .external_lex_state = 3},
  [2177] = {.lex_state = 36, .external_lex_state = 3},
  [2178] = {.lex_state = 36, .external_lex_state = 3},
  [2179] = {.lex_state = 36, .external_lex_state = 3},
  [2180] = {.lex_state = 36, .external_lex_state = 3},
  [2181] = {.lex_state = 36, .external_lex_state = 3},
  [2182] = {.lex_state = 36, .external_lex_state = 3},
  [2183] = {.lex_state = 36, .external_lex_state = 3},
  [2184] = {.lex_state = 36, .external_lex_state = 3},
  [2185] = {.lex_state = 36, .external_lex_state = 3},
  [2186] = {.lex_state = 36, .external_lex_state = 3},
  [2187] = {.lex_state = 36, .external_lex_state = 3},
  [2188] = {.lex_state = 36, .external_lex_state = 3},
  [2189] = {.lex_state = 36, .external_lex_state = 3},
  [2190] = {.lex_state = 36, .external_lex_state = 3},
  [2191] = {.lex_state = 36, .external_lex_state = 3},
  [2192] = {.lex_state = 36, .external_lex_state = 3},
  [2193] = {.lex_state = 36, .external_lex_state = 3},
  [2194] = {.lex_state = 36, .external_lex_state = 3},
  [2195] = {.lex_state = 36, .external_lex_state = 3},
  [2196] = {.lex_state = 36, .external_lex_state = 3},
  [2197] = {.lex_state = 36, .external_lex_state = 3},
  [2198] = {.lex_state = 36, .external_lex_state = 3},
  [2199] = {.lex_state = 36, .external_lex_state = 3},
  [2200] = {.lex_state = 36, .external_lex_state = 3},
  [2201] = {.lex_state = 36, .external_lex_state = 3},
  [2202] = {.lex_state = 36, .external_lex_state = 3},
  [2203] = {.lex_state = 36, .external_lex_state = 3},
  [2204] = {.lex_state = 36, .external_lex_state = 3},
  [2205] = {.lex_state = 36, .external_lex_state = 3},
  [2206] = {.lex_state = 36, .external_lex_state = 3},
  [2207] = {.lex_state = 36, .external_lex_state = 3},
  [2208] = {.lex_state = 36, .external_lex_state = 3},
  [2209] = {.lex_state = 36, .external_lex_state = 3},
  [2210] = {.lex_state = 36, .external_lex_state = 3},
  [2211] = {.lex_state = 36, .external_lex_state = 3},
  [2212] = {.lex_state = 36, .external_lex_state = 3},
  [2213] = {.lex_state = 36, .external_lex_state = 3},
  [2214] = {.lex_state = 36, .external_lex_state = 3},
  [2215] = {.lex_state = 36, .external_lex_state = 3},
  [2216] = {.lex_state = 36, .external_lex_state = 3},
  [2217] = {.lex_state = 36, .external_lex_state = 3},
  [2218] = {.lex_state = 36, .external_lex_state = 3},
  [2219] = {.lex_state = 36, .external_lex_state = 3},
  [2220] = {.lex_state = 36, .external_lex_state = 3},
  [2221] = {.lex_state = 36, .external_lex_state = 3},
  [2222] = {.lex_state = 36, .external_lex_state = 3},
  [2223] = {.lex_state = 36, .external_lex_state = 3},
  [2224] = {.lex_state = 36, .external_lex_state = 3},
  [2225] = {.lex_state = 36, .external_lex_state = 3},
  [2226] = {.lex_state = 36, .external_lex_state = 3},
  [2227] = {.lex_state = 36, .external_lex_state = 3},
  [2228] = {.lex_state = 36, .external_lex_state = 3},
  [2229] = {.lex_state = 36, .external_lex_state = 3},
  [2230] = {.lex_state = 36, .external_lex_state = 3},
  [2231] = {.lex_state = 36, .external_lex_state = 3},
  [2232] = {.lex_state = 36, .external_lex_state = 3},
  [2233] = {.lex_state = 36, .external_lex_state = 3},
  [2234] = {.lex_state = 36, .external_lex_state = 3},
  [2235] = {.lex_state = 36, .external_lex_state = 3},
  [2236] = {.lex_state = 36, .external_lex_state = 3},
  [2237] = {.lex_state = 36, .external_lex_state = 3},
  [2238] = {.lex_state = 36, .external_lex_state = 3},
  [2239] = {.lex_state = 36, .external_lex_state = 3},
  [2240] = {.lex_state = 36, .external_lex_state = 3},
  [2241] = {.lex_state = 36, .external_lex_state = 3},
  [2242] = {.lex_state = 36, .external_lex_state = 3},
  [2243] = {.lex_state = 36, .external_lex_state = 3},
  [2244] = {.lex_state = 36, .external_lex_state = 3},
  [2245] = {.lex_state = 36, .external_lex_state = 3},
  [2246] = {.lex_state = 36, .external_lex_state = 3},
  [2247] = {.lex_state = 36, .external_lex_state = 3},
  [2248] = {.lex_state = 36, .external_lex_state = 3},
  [2249] = {.lex_state = 36, .external_lex_state = 3},
  [2250] = {.lex_state = 36, .external_lex_state = 3},
  [2251] = {.lex_state = 36, .external_lex_state = 3},
  [2252] = {.lex_state = 36, .external_lex_state = 3},
  [2253] = {.lex_state = 36, .external_lex_state = 3},
  [2254] = {.lex_state = 36, .external_lex_state = 3},
  [2255] = {.lex_state = 36, .external_lex_state = 3},
  [2256] = {.lex_state = 36, .external_lex_state = 3},
  [2257] = {.lex_state = 36, .external_lex_state = 3},
  [2258] = {.lex_state = 36, .external_lex_state = 3},
  [2259] = {.lex_state = 36, .external_lex_state = 3},
  [2260] = {.lex_state = 36, .external_lex_state = 3},
  [2261] = {.lex_state = 36, .external_lex_state = 3},
  [2262] = {.lex_state = 36, .external_lex_state = 3},
  [2263] = {.lex_state = 36, .external_lex_state = 3},
  [2264] = {.lex_state = 36, .external_lex_state = 3},
  [2265] = {.lex_state = 36, .external_lex_state = 3},
  [2266] = {.lex_state = 36, .external_lex_state = 3},
  [2267] = {.lex_state = 36, .external_lex_state = 3},
  [2268] = {.lex_state = 36, .external_lex_state = 3},
  [2269] = {.lex_state = 36, .external_lex_state = 3},
  [2270] = {.lex_state = 36, .external_lex_state = 3},
  [2271] = {.lex_state = 36, .external_lex_state = 3},
  [2272] = {.lex_state = 36, .external_lex_state = 3},
  [2273] = {.lex_state = 36, .external_lex_state = 3},
  [2274] = {.lex_state = 36, .external_lex_state = 3},
  [2275] = {.lex_state = 36, .external_lex_state = 3},
  [2276] = {.lex_state = 36, .external_lex_state = 3},
  [2277] = {.lex_state = 36, .external_lex_state = 3},
  [2278] = {.lex_state = 36, .external_lex_state = 3},
  [2279] = {.lex_state = 36, .external_lex_state = 3},
  [2280] = {.lex_state = 36, .external_lex_state = 3},
  [2281] = {.lex_state = 36, .external_lex_state = 3},
  [2282] = {.lex_state = 36, .external_lex_state = 3},
  [2283] = {.lex_state = 36, .external_lex_state = 3},
  [2284] = {.lex_state = 36, .external_lex_state = 3},
  [2285] = {.lex_state = 36, .external_lex_state = 3},
  [2286] = {.lex_state = 36, .external_lex_state = 3},
  [2287] = {.lex_state = 36, .external_lex_state = 3},
  [2288] = {.lex_state = 36, .external_lex_state = 3},
  [2289] = {.lex_state = 36, .external_lex_state = 3},
  [2290] = {.lex_state = 36, .external_lex_state = 3},
  [2291] = {.lex_state = 36, .external_lex_state = 3},
  [2292] = {.lex_state = 36, .external_lex_state = 3},
  [2293] = {.lex_state = 36, .external_lex_state = 3},
  [2294] = {.lex_state = 36, .external_lex_state = 3},
  [2295] = {.lex_state = 36, .external_lex_state = 3},
  [2296] = {.lex_state = 36, .external_lex_state = 3},
  [2297] = {.lex_state = 36, .external_lex_state = 3},
  [2298] = {.lex_state = 36, .external_lex_state = 3},
  [2299] = {.lex_state = 36, .external_lex_state = 3},
  [2300] = {.lex_state = 36, .external_lex_state = 3},
  [2301] = {.lex_state = 36, .external_lex_state = 3},
  [2302] = {.lex_state = 36, .external_lex_state = 3},
  [2303] = {.lex_state = 36, .external_lex_state = 3},
  [2304] = {.lex_state = 36, .external_lex_state = 3},
  [2305] = {.lex_state = 36, .external_lex_state = 3},
  [2306] = {.lex_state = 36, .external_lex_state = 3},
  [2307] = {.lex_state = 36, .external_lex_state = 3},
  [2308] = {.lex_state = 36, .external_lex_state = 3},
  [2309] = {.lex_state = 36, .external_lex_state = 3},
  [2310] = {.lex_state = 36, .external_lex_state = 3},
  [2311] = {.lex_state = 36, .external_lex_state = 3},
  [2312] = {.lex_state = 36, .external_lex_state = 3},
  [2313] = {.lex_state = 36, .external_lex_state = 3},
  [2314] = {.lex_state = 36, .external_lex_state = 3},
  [2315] = {.lex_state = 36, .external_lex_state = 3},
  [2316] = {.lex_state = 36, .external_lex_state = 3},
  [2317] = {.lex_state = 36, .external_lex_state = 3},
  [2318] = {.lex_state = 72, .external_lex_state = 3},
  [2319] = {.lex_state = 36, .external_lex_state = 3},
  [2320] = {.lex_state = 36, .external_lex_state = 3},
  [2321] = {.lex_state = 36, .external_lex_state = 3},
  [2322] = {.lex_state = 36, .external_lex_state = 3},
  [2323] = {.lex_state = 36, .external_lex_state = 3},
  [2324] = {.lex_state = 36, .external_lex_state = 3},
  [2325] = {.lex_state = 36, .external_lex_state = 3},
  [2326] = {.lex_state = 36, .external_lex_state = 3},
  [2327] = {.lex_state = 36, .external_lex_state = 3},
  [2328] = {.lex_state = 36, .external_lex_state = 3},
  [2329] = {.lex_state = 36, .external_lex_state = 3},
  [2330] = {.lex_state = 36, .external_lex_state = 3},
  [2331] = {.lex_state = 36, .external_lex_state = 3},
  [2332] = {.lex_state = 36, .external_lex_state = 3},
  [2333] = {.lex_state = 36, .external_lex_state = 3},
  [2334] = {.lex_state = 36, .external_lex_state = 3},
  [2335] = {.lex_state = 36, .external_lex_state = 3},
  [2336] = {.lex_state = 36, .external_lex_state = 3},
  [2337] = {.lex_state = 36, .external_lex_state = 3},
  [2338] = {.lex_state = 36, .external_lex_state = 3},
  [2339] = {.lex_state = 36, .external_lex_state = 3},
  [2340] = {.lex_state = 36, .external_lex_state = 3},
  [2341] = {.lex_state = 36, .external_lex_state = 3},
  [2342] = {.lex_state = 36, .external_lex_state = 3},
  [2343] = {.lex_state = 36, .external_lex_state = 3},
  [2344] = {.lex_state = 36, .external_lex_state = 3},
  [2345] = {.lex_state = 36, .external_lex_state = 3},
  [2346] = {.lex_state = 36, .external_lex_state = 3},
  [2347] = {.lex_state = 36, .external_lex_state = 3},
  [2348] = {.lex_state = 36, .external_lex_state = 3},
  [2349] = {.lex_state = 36, .external_lex_state = 3},
  [2350] = {.lex_state = 36, .external_lex_state = 3},
  [2351] = {.lex_state = 36, .external_lex_state = 3},
  [2352] = {.lex_state = 36, .external_lex_state = 3},
  [2353] = {.lex_state = 36, .external_lex_state = 3},
  [2354] = {.lex_state = 36, .external_lex_state = 3},
  [2355] = {.lex_state = 36, .external_lex_state = 3},
  [2356] = {.lex_state = 36, .external_lex_state = 3},
  [2357] = {.lex_state = 36, .external_lex_state = 3},
  [2358] = {.lex_state = 36, .external_lex_state = 3},
  [2359] = {.lex_state = 36, .external_lex_state = 3},
  [2360] = {.lex_state = 36, .external_lex_state = 3},
  [2361] = {.lex_state = 36, .external_lex_state = 3},
  [2362] = {.lex_state = 36, .external_lex_state = 3},
  [2363] = {.lex_state = 36, .external_lex_state = 3},
  [2364] = {.lex_state = 36, .external_lex_state = 3},
  [2365] = {.lex_state = 36, .external_lex_state = 3},
  [2366] = {.lex_state = 36, .external_lex_state = 3},
  [2367] = {.lex_state = 36, .external_lex_state = 3},
  [2368] = {.lex_state = 36, .external_lex_state = 3},
  [2369] = {.lex_state = 36, .external_lex_state = 3},
  [2370] = {.lex_state = 36, .external_lex_state = 3},
  [2371] = {.lex_state = 36, .external_lex_state = 3},
  [2372] = {.lex_state = 36, .external_lex_state = 3},
  [2373] = {.lex_state = 36, .external_lex_state = 3},
  [2374] = {.lex_state = 36, .external_lex_state = 3},
  [2375] = {.lex_state = 36, .external_lex_state = 3},
  [2376] = {.lex_state = 36, .external_lex_state = 3},
  [2377] = {.lex_state = 36, .external_lex_state = 3},
  [2378] = {.lex_state = 36, .external_lex_state = 3},
  [2379] = {.lex_state = 36, .external_lex_state = 3},
  [2380] = {.lex_state = 36, .external_lex_state = 3},
  [2381] = {.lex_state = 36, .external_lex_state = 3},
  [2382] = {.lex_state = 36, .external_lex_state = 3},
  [2383] = {.lex_state = 36, .external_lex_state = 3},
  [2384] = {.lex_state = 36, .external_lex_state = 3},
  [2385] = {.lex_state = 36, .external_lex_state = 3},
  [2386] = {.lex_state = 36, .external_lex_state = 3},
  [2387] = {.lex_state = 36, .external_lex_state = 3},
  [2388] = {.lex_state = 36, .external_lex_state = 3},
  [2389] = {.lex_state = 36, .external_lex_state = 3},
  [2390] = {.lex_state = 36, .external_lex_state = 3},
  [2391] = {.lex_state = 36, .external_lex_state = 3},
  [2392] = {.lex_state = 36, .external_lex_state = 3},
  [2393] = {.lex_state = 36, .external_lex_state = 3},
  [2394] = {.lex_state = 36, .external_lex_state = 3},
  [2395] = {.lex_state = 36, .external_lex_state = 3},
  [2396] = {.lex_state = 36, .external_lex_state = 3},
  [2397] = {.lex_state = 36, .external_lex_state = 3},
  [2398] = {.lex_state = 36, .external_lex_state = 3},
  [2399] = {.lex_state = 36, .external_lex_state = 3},
  [2400] = {.lex_state = 36, .external_lex_state = 3},
  [2401] = {.lex_state = 36, .external_lex_state = 3},
  [2402] = {.lex_state = 36, .external_lex_state = 3},
  [2403] = {.lex_state = 36, .external_lex_state = 3},
  [2404] = {.lex_state = 36, .external_lex_state = 3},
  [2405] = {.lex_state = 36, .external_lex_state = 3},
  [2406] = {.lex_state = 36, .external_lex_state = 3},
  [2407] = {.lex_state = 36, .external_lex_state = 3},
  [2408] = {.lex_state = 36, .external_lex_state = 3},
  [2409] = {.lex_state = 36, .external_lex_state = 3},
  [2410] = {.lex_state = 36, .external_lex_state = 3},
  [2411] = {.lex_state = 81, .external_lex_state = 3},
  [2412] = {.lex_state = 73, .external_lex_state = 3},
  [2413] = {.lex_state = 81, .external_lex_state = 3},
  [2414] = {.lex_state = 73, .external_lex_state = 3},
  [2415] = {.lex_state = 77, .external_lex_state = 3},
  [2416] = {.lex_state = 82, .external_lex_state = 3},
  [2417] = {.lex_state = 77, .external_lex_state = 3},
  [2418] = {.lex_state = 82, .external_lex_state = 3},
  [2419] = {.lex_state = 76, .external_lex_state = 3},
  [2420] = {.lex_state = 83, .external_lex_state = 3},
  [2421] = {.lex_state = 83, .external_lex_state = 3},
  [2422] = {.lex_state = 76, .external_lex_state = 3},
  [2423] = {.lex_state = 116, .external_lex_state = 3},
  [2424] = {.lex_state = 117, .external_lex_state = 3},
  [2425] = {.lex_state = 85, .external_lex_state = 3},
  [2426] = {.lex_state = 116, .external_lex_state = 3},
  [2427] = {.lex_state = 87, .external_lex_state = 3},
  [2428] = {.lex_state = 84, .external_lex_state = 3},
  [2429] = {.lex_state = 116, .external_lex_state = 3},
  [2430] = {.lex_state = 86, .external_lex_state = 3},
  [2431] = {.lex_state = 117, .external_lex_state = 3},
  [2432] = {.lex_state = 117, .external_lex_state = 3},
  [2433] = {.lex_state = 85, .external_lex_state = 3},
  [2434] = {.lex_state = 85, .external_lex_state = 3},
  [2435] = {.lex_state = 130, .external_lex_state = 3},
  [2436] = {.lex_state = 84, .external_lex_state = 3},
  [2437] = {.lex_state = 87, .external_lex_state = 3},
  [2438] = {.lex_state = 84, .external_lex_state = 3},
  [2439] = {.lex_state = 87, .external_lex_state = 3},
  [2440] = {.lex_state = 132, .external_lex_state = 3},
  [2441] = {.lex_state = 86, .external_lex_state = 3},
  [2442] = {.lex_state = 131, .external_lex_state = 3},
  [2443] = {.lex_state = 132, .external_lex_state = 3},
  [2444] = {.lex_state = 179, .external_lex_state = 3},
  [2445] = {.lex_state = 179, .external_lex_state = 3},
  [2446] = {.lex_state = 132, .external_lex_state = 3},
  [2447] = {.lex_state = 132, .external_lex_state = 3},
  [2448] = {.lex_state = 132, .external_lex_state = 3},
  [2449] = {.lex_state = 132, .external_lex_state = 3},
  [2450] = {.lex_state = 132, .external_lex_state = 3},
  [2451] = {.lex_state = 177, .external_lex_state = 3},
  [2452] = {.lex_state = 86, .external_lex_state = 3},
  [2453] = {.lex_state = 177, .external_lex_state = 3},
  [2454] = {.lex_state = 132, .external_lex_state = 3},
  [2455] = {.lex_state = 180, .external_lex_state = 3},
  [2456] = {.lex_state = 180, .external_lex_state = 3},
  [2457] = {.lex_state = 120, .external_lex_state = 3},
  [2458] = {.lex_state = 178, .external_lex_state = 3},
  [2459] = {.lex_state = 178, .external_lex_state = 3},
  [2460] = {.lex_state = 133, .external_lex_state = 3},
  [2461] = {.lex_state = 133, .external_lex_state = 3},
  [2462] = {.lex_state = 133, .external_lex_state = 3},
  [2463] = {.lex_state = 130, .external_lex_state = 3},
  [2464] = {.lex_state = 130, .external_lex_state = 3},
  [2465] = {.lex_state = 133, .external_lex_state = 3},
  [2466] = {.lex_state = 124, .external_lex_state = 3},
  [2467] = {.lex_state = 118, .external_lex_state = 3},
  [2468] = {.lex_state = 133, .external_lex_state = 3},
  [2469] = {.lex_state = 121, .external_lex_state = 3},
  [2470] = {.lex_state = 133, .external_lex_state = 3},
  [2471] = {.lex_state = 133, .external_lex_state = 3},
  [2472] = {.lex_state = 133, .external_lex_state = 3},
  [2473] = {.lex_state = 125, .external_lex_state = 3},
  [2474] = {.lex_state = 122, .external_lex_state = 3},
  [2475] = {.lex_state = 133, .external_lex_state = 3},
  [2476] = {.lex_state = 126, .external_lex_state = 3},
  [2477] = {.lex_state = 133, .external_lex_state = 3},
  [2478] = {.lex_state = 133, .external_lex_state = 3},
  [2479] = {.lex_state = 131, .external_lex_state = 3},
  [2480] = {.lex_state = 177, .external_lex_state = 3},
  [2481] = {.lex_state = 128, .external_lex_state = 3},
  [2482] = {.lex_state = 127, .external_lex_state = 3},
  [2483] = {.lex_state = 179, .external_lex_state = 3},
  [2484] = {.lex_state = 123, .external_lex_state = 3},
  [2485] = {.lex_state = 129, .external_lex_state = 3},
  [2486] = {.lex_state = 119, .external_lex_state = 3},
  [2487] = {.lex_state = 131, .external_lex_state = 3},
  [2488] = {.lex_state = 24, .external_lex_state = 3},
  [2489] = {.lex_state = 120, .external_lex_state = 3},
  [2490] = {.lex_state = 26, .external_lex_state = 3},
  [2491] = {.lex_state = 26, .external_lex_state = 3},
  [2492] = {.lex_state = 180, .external_lex_state = 3},
  [2493] = {.lex_state = 178, .external_lex_state = 3},
  [2494] = {.lex_state = 24, .external_lex_state = 3},
  [2495] = {.lex_state = 26, .external_lex_state = 3},
  [2496] = {.lex_state = 120, .external_lex_state = 3},
  [2497] = {.lex_state = 24, .external_lex_state = 3},
  [2498] = {.lex_state = 121, .external_lex_state = 3},
  [2499] = {.lex_state = 124, .external_lex_state = 3},
  [2500] = {.lex_state = 122, .external_lex_state = 3},
  [2501] = {.lex_state = 125, .external_lex_state = 3},
  [2502] = {.lex_state = 124, .external_lex_state = 3},
  [2503] = {.lex_state = 118, .external_lex_state = 3},
  [2504] = {.lex_state = 118, .external_lex_state = 3},
  [2505] = {.lex_state = 122, .external_lex_state = 3},
  [2506] = {.lex_state = 126, .external_lex_state = 3},
  [2507] = {.lex_state = 126, .external_lex_state = 3},
  [2508] = {.lex_state = 121, .external_lex_state = 3},
  [2509] = {.lex_state = 125, .external_lex_state = 3},
  [2510] = {.lex_state = 30, .external_lex_state = 3},
  [2511] = {.lex_state = 421, .external_lex_state = 3},
  [2512] = {.lex_state = 128, .external_lex_state = 3},
  [2513] = {.lex_state = 30, .external_lex_state = 3},
  [2514] = {.lex_state = 30, .external_lex_state = 3},
  [2515] = {.lex_state = 129, .external_lex_state = 3},
  [2516] = {.lex_state = 119, .external_lex_state = 3},
  [2517] = {.lex_state = 129, .external_lex_state = 3},
  [2518] = {.lex_state = 119, .external_lex_state = 3},
  [2519] = {.lex_state = 421, .external_lex_state = 3},
  [2520] = {.lex_state = 421, .external_lex_state = 3},
  [2521] = {.lex_state = 128, .external_lex_state = 3},
  [2522] = {.lex_state = 421, .external_lex_state = 3},
  [2523] = {.lex_state = 421, .external_lex_state = 3},
  [2524] = {.lex_state = 127, .external_lex_state = 3},
  [2525] = {.lex_state = 123, .external_lex_state = 3},
  [2526] = {.lex_state = 127, .external_lex_state = 3},
  [2527] = {.lex_state = 421, .external_lex_state = 3},
  [2528] = {.lex_state = 123, .external_lex_state = 3},
  [2529] = {.lex_state = 134, .external_lex_state = 3},
  [2530] = {.lex_state = 134, .external_lex_state = 3},
  [2531] = {.lex_state = 134, .external_lex_state = 3},
  [2532] = {.lex_state = 134, .external_lex_state = 3},
  [2533] = {.lex_state = 134, .external_lex_state = 3},
  [2534] = {.lex_state = 134, .external_lex_state = 3},
  [2535] = {.lex_state = 134, .external_lex_state = 3},
  [2536] = {.lex_state = 173, .external_lex_state = 3},
  [2537] = {.lex_state = 31, .external_lex_state = 3},
  [2538] = {.lex_state = 172, .external_lex_state = 3},
  [2539] = {.lex_state = 172, .external_lex_state = 3},
  [2540] = {.lex_state = 31, .external_lex_state = 3},
  [2541] = {.lex_state = 173, .external_lex_state = 3},
  [2542] = {.lex_state = 172, .external_lex_state = 3},
  [2543] = {.lex_state = 172, .external_lex_state = 3},
  [2544] = {.lex_state = 173, .external_lex_state = 3},
  [2545] = {.lex_state = 173, .external_lex_state = 3},
  [2546] = {.lex_state = 172, .external_lex_state = 3},
  [2547] = {.lex_state = 31, .external_lex_state = 3},
  [2548] = {.lex_state = 173, .external_lex_state = 3},
  [2549] = {.lex_state = 173, .external_lex_state = 3},
  [2550] = {.lex_state = 172, .external_lex_state = 3},
  [2551] = {.lex_state = 173, .external_lex_state = 3},
  [2552] = {.lex_state = 172, .external_lex_state = 3},
  [2553] = {.lex_state = 173, .external_lex_state = 3},
  [2554] = {.lex_state = 172, .external_lex_state = 3},
  [2555] = {.lex_state = 173, .external_lex_state = 3},
  [2556] = {.lex_state = 172, .external_lex_state = 3},
  [2557] = {.lex_state = 172, .external_lex_state = 3},
  [2558] = {.lex_state = 173, .external_lex_state = 3},
  [2559] = {.lex_state = 167, .external_lex_state = 3},
  [2560] = {.lex_state = 423, .external_lex_state = 3},
  [2561] = {.lex_state = 423, .external_lex_state = 3},
  [2562] = {.lex_state = 167, .external_lex_state = 3},
  [2563] = {.lex_state = 174, .external_lex_state = 3},
  [2564] = {.lex_state = 423, .external_lex_state = 3},
  [2565] = {.lex_state = 174, .external_lex_state = 3},
  [2566] = {.lex_state = 423, .external_lex_state = 3},
  [2567] = {.lex_state = 423, .external_lex_state = 3},
  [2568] = {.lex_state = 174, .external_lex_state = 3},
  [2569] = {.lex_state = 174, .external_lex_state = 3},
  [2570] = {.lex_state = 423, .external_lex_state = 3},
  [2571] = {.lex_state = 174, .external_lex_state = 3},
  [2572] = {.lex_state = 423, .external_lex_state = 3},
  [2573] = {.lex_state = 423, .external_lex_state = 3},
  [2574] = {.lex_state = 174, .external_lex_state = 3},
  [2575] = {.lex_state = 423, .external_lex_state = 3},
  [2576] = {.lex_state = 423, .external_lex_state = 3},
  [2577] = {.lex_state = 423, .external_lex_state = 3},
  [2578] = {.lex_state = 423, .external_lex_state = 3},
  [2579] = {.lex_state = 423, .external_lex_state = 3},
  [2580] = {.lex_state = 423, .external_lex_state = 3},
  [2581] = {.lex_state = 174, .external_lex_state = 3},
  [2582] = {.lex_state = 423, .external_lex_state = 3},
  [2583] = {.lex_state = 174, .external_lex_state = 3},
  [2584] = {.lex_state = 423, .external_lex_state = 3},
  [2585] = {.lex_state = 423, .external_lex_state = 3},
  [2586] = {.lex_state = 174, .external_lex_state = 3},
  [2587] = {.lex_state = 174, .external_lex_state = 3},
  [2588] = {.lex_state = 423, .external_lex_state = 3},
  [2589] = {.lex_state = 423, .external_lex_state = 3},
  [2590] = {.lex_state = 423, .external_lex_state = 3},
  [2591] = {.lex_state = 172, .external_lex_state = 3},
  [2592] = {.lex_state = 173, .external_lex_state = 3},
  [2593] = {.lex_state = 167, .external_lex_state = 3},
  [2594] = {.lex_state = 423, .external_lex_state = 3},
  [2595] = {.lex_state = 174, .external_lex_state = 3},
  [2596] = {.lex_state = 181, .external_lex_state = 3},
  [2597] = {.lex_state = 167, .external_lex_state = 3},
  [2598] = {.lex_state = 182, .external_lex_state = 3},
  [2599] = {.lex_state = 181, .external_lex_state = 3},
  [2600] = {.lex_state = 182, .external_lex_state = 3},
  [2601] = {.lex_state = 170, .external_lex_state = 3},
  [2602] = {.lex_state = 167, .external_lex_state = 3},
  [2603] = {.lex_state = 167, .external_lex_state = 3},
  [2604] = {.lex_state = 167, .external_lex_state = 3},
  [2605] = {.lex_state = 167, .external_lex_state = 3},
  [2606] = {.lex_state = 167, .external_lex_state = 3},
  [2607] = {.lex_state = 167, .external_lex_state = 3},
  [2608] = {.lex_state = 167, .external_lex_state = 3},
  [2609] = {.lex_state = 167, .external_lex_state = 3},
  [2610] = {.lex_state = 167, .external_lex_state = 3},
  [2611] = {.lex_state = 167, .external_lex_state = 3},
  [2612] = {.lex_state = 167, .external_lex_state = 3},
  [2613] = {.lex_state = 167, .external_lex_state = 3},
  [2614] = {.lex_state = 167, .external_lex_state = 3},
  [2615] = {.lex_state = 167, .external_lex_state = 3},
  [2616] = {.lex_state = 167, .external_lex_state = 3},
  [2617] = {.lex_state = 167, .external_lex_state = 3},
  [2618] = {.lex_state = 167, .external_lex_state = 3},
  [2619] = {.lex_state = 167, .external_lex_state = 3},
  [2620] = {.lex_state = 167, .external_lex_state = 3},
  [2621] = {.lex_state = 167, .external_lex_state = 3},
  [2622] = {.lex_state = 167, .external_lex_state = 3},
  [2623] = {.lex_state = 167, .external_lex_state = 3},
  [2624] = {.lex_state = 167, .external_lex_state = 3},
  [2625] = {.lex_state = 167, .external_lex_state = 3},
  [2626] = {.lex_state = 167, .external_lex_state = 3},
  [2627] = {.lex_state = 170, .external_lex_state = 3},
  [2628] = {.lex_state = 167, .external_lex_state = 3},
  [2629] = {.lex_state = 167, .external_lex_state = 3},
  [2630] = {.lex_state = 167, .external_lex_state = 3},
  [2631] = {.lex_state = 167, .external_lex_state = 3},
  [2632] = {.lex_state = 167, .external_lex_state = 3},
  [2633] = {.lex_state = 170, .external_lex_state = 3},
  [2634] = {.lex_state = 167, .external_lex_state = 3},
  [2635] = {.lex_state = 167, .external_lex_state = 3},
  [2636] = {.lex_state = 167, .external_lex_state = 3},
  [2637] = {.lex_state = 170, .external_lex_state = 3},
  [2638] = {.lex_state = 167, .external_lex_state = 3},
  [2639] = {.lex_state = 167, .external_lex_state = 3},
  [2640] = {.lex_state = 167, .external_lex_state = 3},
  [2641] = {.lex_state = 167, .external_lex_state = 3},
  [2642] = {.lex_state = 170, .external_lex_state = 3},
  [2643] = {.lex_state = 167, .external_lex_state = 3},
  [2644] = {.lex_state = 170, .external_lex_state = 3},
  [2645] = {.lex_state = 167, .external_lex_state = 3},
  [2646] = {.lex_state = 167, .external_lex_state = 3},
  [2647] = {.lex_state = 167, .external_lex_state = 3},
  [2648] = {.lex_state = 167, .external_lex_state = 3},
  [2649] = {.lex_state = 167, .external_lex_state = 3},
  [2650] = {.lex_state = 167, .external_lex_state = 3},
  [2651] = {.lex_state = 168, .external_lex_state = 3},
  [2652] = {.lex_state = 168, .external_lex_state = 3},
  [2653] = {.lex_state = 168, .external_lex_state = 3},
  [2654] = {.lex_state = 168, .external_lex_state = 3},
  [2655] = {.lex_state = 168, .external_lex_state = 3},
  [2656] = {.lex_state = 168, .external_lex_state = 3},
  [2657] = {.lex_state = 168, .external_lex_state = 3},
  [2658] = {.lex_state = 168, .external_lex_state = 3},
  [2659] = {.lex_state = 168, .external_lex_state = 3},
  [2660] = {.lex_state = 168, .external_lex_state = 3},
  [2661] = {.lex_state = 168, .external_lex_state = 3},
  [2662] = {.lex_state = 168, .external_lex_state = 3},
  [2663] = {.lex_state = 168, .external_lex_state = 3},
  [2664] = {.lex_state = 168, .external_lex_state = 3},
  [2665] = {.lex_state = 168, .external_lex_state = 3},
  [2666] = {.lex_state = 168, .external_lex_state = 3},
  [2667] = {.lex_state = 168, .external_lex_state = 3},
  [2668] = {.lex_state = 168, .external_lex_state = 3},
  [2669] = {.lex_state = 168, .external_lex_state = 3},
  [2670] = {.lex_state = 168, .external_lex_state = 3},
  [2671] = {.lex_state = 168, .external_lex_state = 3},
  [2672] = {.lex_state = 168, .external_lex_state = 3},
  [2673] = {.lex_state = 168, .external_lex_state = 3},
  [2674] = {.lex_state = 168, .external_lex_state = 3},
  [2675] = {.lex_state = 168, .external_lex_state = 3},
  [2676] = {.lex_state = 168, .external_lex_state = 3},
  [2677] = {.lex_state = 168, .external_lex_state = 3},
  [2678] = {.lex_state = 168, .external_lex_state = 3},
  [2679] = {.lex_state = 168, .external_lex_state = 3},
  [2680] = {.lex_state = 168, .external_lex_state = 3},
  [2681] = {.lex_state = 168, .external_lex_state = 3},
  [2682] = {.lex_state = 168, .external_lex_state = 3},
  [2683] = {.lex_state = 168, .external_lex_state = 3},
  [2684] = {.lex_state = 181, .external_lex_state = 3},
  [2685] = {.lex_state = 168, .external_lex_state = 3},
  [2686] = {.lex_state = 168, .external_lex_state = 3},
  [2687] = {.lex_state = 168, .external_lex_state = 3},
  [2688] = {.lex_state = 168, .external_lex_state = 3},
  [2689] = {.lex_state = 168, .external_lex_state = 3},
  [2690] = {.lex_state = 168, .external_lex_state = 3},
  [2691] = {.lex_state = 168, .external_lex_state = 3},
  [2692] = {.lex_state = 168, .external_lex_state = 3},
  [2693] = {.lex_state = 168, .external_lex_state = 3},
  [2694] = {.lex_state = 168, .external_lex_state = 3},
  [2695] = {.lex_state = 168, .external_lex_state = 3},
  [2696] = {.lex_state = 168, .external_lex_state = 3},
  [2697] = {.lex_state = 168, .external_lex_state = 3},
  [2698] = {.lex_state = 168, .external_lex_state = 3},
  [2699] = {.lex_state = 168, .external_lex_state = 3},
  [2700] = {.lex_state = 167, .external_lex_state = 3},
  [2701] = {.lex_state = 167, .external_lex_state = 3},
  [2702] = {.lex_state = 167, .external_lex_state = 3},
  [2703] = {.lex_state = 167, .external_lex_state = 3},
  [2704] = {.lex_state = 167, .external_lex_state = 3},
  [2705] = {.lex_state = 167, .external_lex_state = 3},
  [2706] = {.lex_state = 167, .external_lex_state = 3},
  [2707] = {.lex_state = 167, .external_lex_state = 3},
  [2708] = {.lex_state = 167, .external_lex_state = 3},
  [2709] = {.lex_state = 167, .external_lex_state = 3},
  [2710] = {.lex_state = 167, .external_lex_state = 3},
  [2711] = {.lex_state = 167, .external_lex_state = 3},
  [2712] = {.lex_state = 167, .external_lex_state = 3},
  [2713] = {.lex_state = 167, .external_lex_state = 3},
  [2714] = {.lex_state = 167, .external_lex_state = 3},
  [2715] = {.lex_state = 167, .external_lex_state = 3},
  [2716] = {.lex_state = 167, .external_lex_state = 3},
  [2717] = {.lex_state = 167, .external_lex_state = 3},
  [2718] = {.lex_state = 167, .external_lex_state = 3},
  [2719] = {.lex_state = 167, .external_lex_state = 3},
  [2720] = {.lex_state = 167, .external_lex_state = 3},
  [2721] = {.lex_state = 167, .external_lex_state = 3},
  [2722] = {.lex_state = 167, .external_lex_state = 3},
  [2723] = {.lex_state = 167, .external_lex_state = 3},
  [2724] = {.lex_state = 167, .external_lex_state = 3},
  [2725] = {.lex_state = 167, .external_lex_state = 3},
  [2726] = {.lex_state = 167, .external_lex_state = 3},
  [2727] = {.lex_state = 167, .external_lex_state = 3},
  [2728] = {.lex_state = 167, .external_lex_state = 3},
  [2729] = {.lex_state = 167, .external_lex_state = 3},
  [2730] = {.lex_state = 167, .external_lex_state = 3},
  [2731] = {.lex_state = 167, .external_lex_state = 3},
  [2732] = {.lex_state = 167, .external_lex_state = 3},
  [2733] = {.lex_state = 167, .external_lex_state = 3},
  [2734] = {.lex_state = 167, .external_lex_state = 3},
  [2735] = {.lex_state = 167, .external_lex_state = 3},
  [2736] = {.lex_state = 167, .external_lex_state = 3},
  [2737] = {.lex_state = 167, .external_lex_state = 3},
  [2738] = {.lex_state = 167, .external_lex_state = 3},
  [2739] = {.lex_state = 167, .external_lex_state = 3},
  [2740] = {.lex_state = 167, .external_lex_state = 3},
  [2741] = {.lex_state = 167, .external_lex_state = 3},
  [2742] = {.lex_state = 167, .external_lex_state = 3},
  [2743] = {.lex_state = 167, .external_lex_state = 3},
  [2744] = {.lex_state = 167, .external_lex_state = 3},
  [2745] = {.lex_state = 167, .external_lex_state = 3},
  [2746] = {.lex_state = 167, .external_lex_state = 3},
  [2747] = {.lex_state = 167, .external_lex_state = 3},
  [2748] = {.lex_state = 167, .external_lex_state = 3},
  [2749] = {.lex_state = 167, .external_lex_state = 3},
  [2750] = {.lex_state = 167, .external_lex_state = 3},
  [2751] = {.lex_state = 167, .external_lex_state = 3},
  [2752] = {.lex_state = 167, .external_lex_state = 3},
  [2753] = {.lex_state = 167, .external_lex_state = 3},
  [2754] = {.lex_state = 167, .external_lex_state = 3},
  [2755] = {.lex_state = 167, .external_lex_state = 3},
  [2756] = {.lex_state = 167, .external_lex_state = 3},
  [2757] = {.lex_state = 167, .external_lex_state = 3},
  [2758] = {.lex_state = 167, .external_lex_state = 3},
  [2759] = {.lex_state = 167, .external_lex_state = 3},
  [2760] = {.lex_state = 167, .external_lex_state = 3},
  [2761] = {.lex_state = 167, .external_lex_state = 3},
  [2762] = {.lex_state = 167, .external_lex_state = 3},
  [2763] = {.lex_state = 167, .external_lex_state = 3},
  [2764] = {.lex_state = 167, .external_lex_state = 3},
  [2765] = {.lex_state = 167, .external_lex_state = 3},
  [2766] = {.lex_state = 167, .external_lex_state = 3},
  [2767] = {.lex_state = 167, .external_lex_state = 3},
  [2768] = {.lex_state = 167, .external_lex_state = 3},
  [2769] = {.lex_state = 167, .external_lex_state = 3},
  [2770] = {.lex_state = 167, .external_lex_state = 3},
  [2771] = {.lex_state = 167, .external_lex_state = 3},
  [2772] = {.lex_state = 167, .external_lex_state = 3},
  [2773] = {.lex_state = 167, .external_lex_state = 3},
  [2774] = {.lex_state = 167, .external_lex_state = 3},
  [2775] = {.lex_state = 167, .external_lex_state = 3},
  [2776] = {.lex_state = 167, .external_lex_state = 3},
  [2777] = {.lex_state = 167, .external_lex_state = 3},
  [2778] = {.lex_state = 167, .external_lex_state = 3},
  [2779] = {.lex_state = 167, .external_lex_state = 3},
  [2780] = {.lex_state = 167, .external_lex_state = 3},
  [2781] = {.lex_state = 167, .external_lex_state = 3},
  [2782] = {.lex_state = 167, .external_lex_state = 3},
  [2783] = {.lex_state = 167, .external_lex_state = 3},
  [2784] = {.lex_state = 167, .external_lex_state = 3},
  [2785] = {.lex_state = 167, .external_lex_state = 3},
  [2786] = {.lex_state = 167, .external_lex_state = 3},
  [2787] = {.lex_state = 167, .external_lex_state = 3},
  [2788] = {.lex_state = 167, .external_lex_state = 3},
  [2789] = {.lex_state = 167, .external_lex_state = 3},
  [2790] = {.lex_state = 167, .external_lex_state = 3},
  [2791] = {.lex_state = 167, .external_lex_state = 3},
  [2792] = {.lex_state = 167, .external_lex_state = 3},
  [2793] = {.lex_state = 167, .external_lex_state = 3},
  [2794] = {.lex_state = 167, .external_lex_state = 3},
  [2795] = {.lex_state = 167, .external_lex_state = 3},
  [2796] = {.lex_state = 167, .external_lex_state = 3},
  [2797] = {.lex_state = 167, .external_lex_state = 3},
  [2798] = {.lex_state = 167, .external_lex_state = 3},
  [2799] = {.lex_state = 167, .external_lex_state = 3},
  [2800] = {.lex_state = 167, .external_lex_state = 3},
  [2801] = {.lex_state = 167, .external_lex_state = 3},
  [2802] = {.lex_state = 167, .external_lex_state = 3},
  [2803] = {.lex_state = 167, .external_lex_state = 3},
  [2804] = {.lex_state = 167, .external_lex_state = 3},
  [2805] = {.lex_state = 167, .external_lex_state = 3},
  [2806] = {.lex_state = 167, .external_lex_state = 3},
  [2807] = {.lex_state = 167, .external_lex_state = 3},
  [2808] = {.lex_state = 167, .external_lex_state = 3},
  [2809] = {.lex_state = 167, .external_lex_state = 3},
  [2810] = {.lex_state = 167, .external_lex_state = 3},
  [2811] = {.lex_state = 167, .external_lex_state = 3},
  [2812] = {.lex_state = 167, .external_lex_state = 3},
  [2813] = {.lex_state = 167, .external_lex_state = 3},
  [2814] = {.lex_state = 167, .external_lex_state = 3},
  [2815] = {.lex_state = 167, .external_lex_state = 3},
  [2816] = {.lex_state = 167, .external_lex_state = 3},
  [2817] = {.lex_state = 167, .external_lex_state = 3},
  [2818] = {.lex_state = 28, .external_lex_state = 3},
  [2819] = {.lex_state = 167, .external_lex_state = 3},
  [2820] = {.lex_state = 167, .external_lex_state = 3},
  [2821] = {.lex_state = 167, .external_lex_state = 3},
  [2822] = {.lex_state = 167, .external_lex_state = 3},
  [2823] = {.lex_state = 167, .external_lex_state = 3},
  [2824] = {.lex_state = 167, .external_lex_state = 3},
  [2825] = {.lex_state = 167, .external_lex_state = 3},
  [2826] = {.lex_state = 167, .external_lex_state = 3},
  [2827] = {.lex_state = 167, .external_lex_state = 3},
  [2828] = {.lex_state = 167, .external_lex_state = 3},
  [2829] = {.lex_state = 167, .external_lex_state = 3},
  [2830] = {.lex_state = 167, .external_lex_state = 3},
  [2831] = {.lex_state = 167, .external_lex_state = 3},
  [2832] = {.lex_state = 167, .external_lex_state = 3},
  [2833] = {.lex_state = 167, .external_lex_state = 3},
  [2834] = {.lex_state = 167, .external_lex_state = 3},
  [2835] = {.lex_state = 167, .external_lex_state = 3},
  [2836] = {.lex_state = 167, .external_lex_state = 3},
  [2837] = {.lex_state = 167, .external_lex_state = 3},
  [2838] = {.lex_state = 167, .external_lex_state = 3},
  [2839] = {.lex_state = 167, .external_lex_state = 3},
  [2840] = {.lex_state = 167, .external_lex_state = 3},
  [2841] = {.lex_state = 167, .external_lex_state = 3},
  [2842] = {.lex_state = 167, .external_lex_state = 3},
  [2843] = {.lex_state = 167, .external_lex_state = 3},
  [2844] = {.lex_state = 167, .external_lex_state = 3},
  [2845] = {.lex_state = 167, .external_lex_state = 3},
  [2846] = {.lex_state = 167, .external_lex_state = 3},
  [2847] = {.lex_state = 167, .external_lex_state = 3},
  [2848] = {.lex_state = 167, .external_lex_state = 3},
  [2849] = {.lex_state = 167, .external_lex_state = 3},
  [2850] = {.lex_state = 167, .external_lex_state = 3},
  [2851] = {.lex_state = 167, .external_lex_state = 3},
  [2852] = {.lex_state = 167, .external_lex_state = 3},
  [2853] = {.lex_state = 167, .external_lex_state = 3},
  [2854] = {.lex_state = 28, .external_lex_state = 3},
  [2855] = {.lex_state = 167, .external_lex_state = 3},
  [2856] = {.lex_state = 167, .external_lex_state = 3},
  [2857] = {.lex_state = 167, .external_lex_state = 3},
  [2858] = {.lex_state = 167, .external_lex_state = 3},
  [2859] = {.lex_state = 167, .external_lex_state = 3},
  [2860] = {.lex_state = 167, .external_lex_state = 3},
  [2861] = {.lex_state = 167, .external_lex_state = 3},
  [2862] = {.lex_state = 167, .external_lex_state = 3},
  [2863] = {.lex_state = 167, .external_lex_state = 3},
  [2864] = {.lex_state = 167, .external_lex_state = 3},
  [2865] = {.lex_state = 167, .external_lex_state = 3},
  [2866] = {.lex_state = 167, .external_lex_state = 3},
  [2867] = {.lex_state = 167, .external_lex_state = 3},
  [2868] = {.lex_state = 167, .external_lex_state = 3},
  [2869] = {.lex_state = 167, .external_lex_state = 3},
  [2870] = {.lex_state = 167, .external_lex_state = 3},
  [2871] = {.lex_state = 167, .external_lex_state = 3},
  [2872] = {.lex_state = 167, .external_lex_state = 3},
  [2873] = {.lex_state = 167, .external_lex_state = 3},
  [2874] = {.lex_state = 167, .external_lex_state = 3},
  [2875] = {.lex_state = 167, .external_lex_state = 3},
  [2876] = {.lex_state = 167, .external_lex_state = 3},
  [2877] = {.lex_state = 167, .external_lex_state = 3},
  [2878] = {.lex_state = 167, .external_lex_state = 3},
  [2879] = {.lex_state = 167, .external_lex_state = 3},
  [2880] = {.lex_state = 167, .external_lex_state = 3},
  [2881] = {.lex_state = 167, .external_lex_state = 3},
  [2882] = {.lex_state = 28, .external_lex_state = 3},
  [2883] = {.lex_state = 167, .external_lex_state = 3},
  [2884] = {.lex_state = 167, .external_lex_state = 3},
  [2885] = {.lex_state = 167, .external_lex_state = 3},
  [2886] = {.lex_state = 167, .external_lex_state = 3},
  [2887] = {.lex_state = 167, .external_lex_state = 3},
  [2888] = {.lex_state = 167, .external_lex_state = 3},
  [2889] = {.lex_state = 167, .external_lex_state = 3},
  [2890] = {.lex_state = 167, .external_lex_state = 3},
  [2891] = {.lex_state = 167, .external_lex_state = 3},
  [2892] = {.lex_state = 167, .external_lex_state = 3},
  [2893] = {.lex_state = 167, .external_lex_state = 3},
  [2894] = {.lex_state = 167, .external_lex_state = 3},
  [2895] = {.lex_state = 167, .external_lex_state = 3},
  [2896] = {.lex_state = 167, .external_lex_state = 3},
  [2897] = {.lex_state = 431, .external_lex_state = 2},
  [2898] = {.lex_state = 167, .external_lex_state = 3},
  [2899] = {.lex_state = 167, .external_lex_state = 3},
  [2900] = {.lex_state = 167, .external_lex_state = 3},
  [2901] = {.lex_state = 167, .external_lex_state = 3},
  [2902] = {.lex_state = 167, .external_lex_state = 3},
  [2903] = {.lex_state = 167, .external_lex_state = 3},
  [2904] = {.lex_state = 167, .external_lex_state = 3},
  [2905] = {.lex_state = 167, .external_lex_state = 3},
  [2906] = {.lex_state = 167, .external_lex_state = 3},
  [2907] = {.lex_state = 167, .external_lex_state = 3},
  [2908] = {.lex_state = 167, .external_lex_state = 3},
  [2909] = {.lex_state = 167, .external_lex_state = 3},
  [2910] = {.lex_state = 167, .external_lex_state = 3},
  [2911] = {.lex_state = 167, .external_lex_state = 3},
  [2912] = {.lex_state = 167, .external_lex_state = 3},
  [2913] = {.lex_state = 167, .external_lex_state = 3},
  [2914] = {.lex_state = 167, .external_lex_state = 3},
  [2915] = {.lex_state = 167, .external_lex_state = 3},
  [2916] = {.lex_state = 167, .external_lex_state = 3},
  [2917] = {.lex_state = 167, .external_lex_state = 3},
  [2918] = {.lex_state = 167, .external_lex_state = 3},
  [2919] = {.lex_state = 167, .external_lex_state = 3},
  [2920] = {.lex_state = 167, .external_lex_state = 3},
  [2921] = {.lex_state = 167, .external_lex_state = 3},
  [2922] = {.lex_state = 167, .external_lex_state = 3},
  [2923] = {.lex_state = 167, .external_lex_state = 3},
  [2924] = {.lex_state = 94, .external_lex_state = 3},
  [2925] = {.lex_state = 90, .external_lex_state = 3},
  [2926] = {.lex_state = 94, .external_lex_state = 3},
  [2927] = {.lex_state = 90, .external_lex_state = 3},
  [2928] = {.lex_state = 167, .external_lex_state = 3},
  [2929] = {.lex_state = 94, .external_lex_state = 3},
  [2930] = {.lex_state = 90, .external_lex_state = 3},
  [2931] = {.lex_state = 90, .external_lex_state = 3},
  [2932] = {.lex_state = 90, .external_lex_state = 3},
  [2933] = {.lex_state = 94, .external_lex_state = 3},
  [2934] = {.lex_state = 90, .external_lex_state = 3},
  [2935] = {.lex_state = 90, .external_lex_state = 3},
  [2936] = {.lex_state = 90, .external_lex_state = 3},
  [2937] = {.lex_state = 94, .external_lex_state = 3},
  [2938] = {.lex_state = 94, .external_lex_state = 3},
  [2939] = {.lex_state = 94, .external_lex_state = 3},
  [2940] = {.lex_state = 90, .external_lex_state = 3},
  [2941] = {.lex_state = 94, .external_lex_state = 3},
  [2942] = {.lex_state = 94, .external_lex_state = 3},
  [2943] = {.lex_state = 167, .external_lex_state = 3},
  [2944] = {.lex_state = 167, .external_lex_state = 3},
  [2945] = {.lex_state = 167, .external_lex_state = 3},
  [2946] = {.lex_state = 167, .external_lex_state = 3},
  [2947] = {.lex_state = 167, .external_lex_state = 3},
  [2948] = {.lex_state = 167, .external_lex_state = 3},
  [2949] = {.lex_state = 167, .external_lex_state = 3},
  [2950] = {.lex_state = 167, .external_lex_state = 3},
  [2951] = {.lex_state = 167, .external_lex_state = 3},
  [2952] = {.lex_state = 167, .external_lex_state = 3},
  [2953] = {.lex_state = 167, .external_lex_state = 3},
  [2954] = {.lex_state = 167, .external_lex_state = 3},
  [2955] = {.lex_state = 170, .external_lex_state = 3},
  [2956] = {.lex_state = 90, .external_lex_state = 3},
  [2957] = {.lex_state = 90, .external_lex_state = 3},
  [2958] = {.lex_state = 167, .external_lex_state = 3},
  [2959] = {.lex_state = 167, .external_lex_state = 3},
  [2960] = {.lex_state = 167, .external_lex_state = 3},
  [2961] = {.lex_state = 167, .external_lex_state = 3},
  [2962] = {.lex_state = 94, .external_lex_state = 3},
  [2963] = {.lex_state = 94, .external_lex_state = 3},
  [2964] = {.lex_state = 167, .external_lex_state = 3},
  [2965] = {.lex_state = 167, .external_lex_state = 3},
  [2966] = {.lex_state = 28, .external_lex_state = 4},
  [2967] = {.lex_state = 28, .external_lex_state = 4},
  [2968] = {.lex_state = 94, .external_lex_state = 3},
  [2969] = {.lex_state = 28, .external_lex_state = 4},
  [2970] = {.lex_state = 28, .external_lex_state = 4},
  [2971] = {.lex_state = 167, .external_lex_state = 3},
  [2972] = {.lex_state = 94, .external_lex_state = 3},
  [2973] = {.lex_state = 96, .external_lex_state = 3},
  [2974] = {.lex_state = 96, .external_lex_state = 3},
  [2975] = {.lex_state = 96, .external_lex_state = 3},
  [2976] = {.lex_state = 28, .external_lex_state = 4},
  [2977] = {.lex_state = 167, .external_lex_state = 3},
  [2978] = {.lex_state = 167, .external_lex_state = 3},
  [2979] = {.lex_state = 96, .external_lex_state = 3},
  [2980] = {.lex_state = 96, .external_lex_state = 3},
  [2981] = {.lex_state = 96, .external_lex_state = 3},
  [2982] = {.lex_state = 90, .external_lex_state = 3},
  [2983] = {.lex_state = 90, .external_lex_state = 3},
  [2984] = {.lex_state = 96, .external_lex_state = 3},
  [2985] = {.lex_state = 94, .external_lex_state = 3},
  [2986] = {.lex_state = 94, .external_lex_state = 3},
  [2987] = {.lex_state = 94, .external_lex_state = 3},
  [2988] = {.lex_state = 94, .external_lex_state = 3},
  [2989] = {.lex_state = 96, .external_lex_state = 3},
  [2990] = {.lex_state = 94, .external_lex_state = 3},
  [2991] = {.lex_state = 94, .external_lex_state = 3},
  [2992] = {.lex_state = 94, .external_lex_state = 3},
  [2993] = {.lex_state = 91, .external_lex_state = 3},
  [2994] = {.lex_state = 28, .external_lex_state = 4},
  [2995] = {.lex_state = 167, .external_lex_state = 3},
  [2996] = {.lex_state = 94, .external_lex_state = 3},
  [2997] = {.lex_state = 94, .external_lex_state = 3},
  [2998] = {.lex_state = 94, .external_lex_state = 3},
  [2999] = {.lex_state = 94, .external_lex_state = 3},
  [3000] = {.lex_state = 167, .external_lex_state = 3},
  [3001] = {.lex_state = 94, .external_lex_state = 3},
  [3002] = {.lex_state = 94, .external_lex_state = 3},
  [3003] = {.lex_state = 94, .external_lex_state = 3},
  [3004] = {.lex_state = 94, .external_lex_state = 3},
  [3005] = {.lex_state = 94, .external_lex_state = 3},
  [3006] = {.lex_state = 94, .external_lex_state = 3},
  [3007] = {.lex_state = 94, .external_lex_state = 3},
  [3008] = {.lex_state = 94, .external_lex_state = 3},
  [3009] = {.lex_state = 94, .external_lex_state = 3},
  [3010] = {.lex_state = 167, .external_lex_state = 3},
  [3011] = {.lex_state = 94, .external_lex_state = 3},
  [3012] = {.lex_state = 94, .external_lex_state = 3},
  [3013] = {.lex_state = 182, .external_lex_state = 3},
  [3014] = {.lex_state = 94, .external_lex_state = 3},
  [3015] = {.lex_state = 91, .external_lex_state = 3},
  [3016] = {.lex_state = 91, .external_lex_state = 3},
  [3017] = {.lex_state = 91, .external_lex_state = 3},
  [3018] = {.lex_state = 94, .external_lex_state = 3},
  [3019] = {.lex_state = 94, .external_lex_state = 3},
  [3020] = {.lex_state = 94, .external_lex_state = 3},
  [3021] = {.lex_state = 94, .external_lex_state = 3},
  [3022] = {.lex_state = 28, .external_lex_state = 4},
  [3023] = {.lex_state = 94, .external_lex_state = 3},
  [3024] = {.lex_state = 94, .external_lex_state = 3},
  [3025] = {.lex_state = 94, .external_lex_state = 3},
  [3026] = {.lex_state = 182, .external_lex_state = 3},
  [3027] = {.lex_state = 167, .external_lex_state = 3},
  [3028] = {.lex_state = 91, .external_lex_state = 3},
  [3029] = {.lex_state = 91, .external_lex_state = 3},
  [3030] = {.lex_state = 91, .external_lex_state = 3},
  [3031] = {.lex_state = 94, .external_lex_state = 3},
  [3032] = {.lex_state = 96, .external_lex_state = 3},
  [3033] = {.lex_state = 94, .external_lex_state = 3},
  [3034] = {.lex_state = 94, .external_lex_state = 3},
  [3035] = {.lex_state = 94, .external_lex_state = 3},
  [3036] = {.lex_state = 182, .external_lex_state = 3},
  [3037] = {.lex_state = 94, .external_lex_state = 3},
  [3038] = {.lex_state = 94, .external_lex_state = 3},
  [3039] = {.lex_state = 167, .external_lex_state = 3},
  [3040] = {.lex_state = 94, .external_lex_state = 3},
  [3041] = {.lex_state = 167, .external_lex_state = 3},
  [3042] = {.lex_state = 94, .external_lex_state = 3},
  [3043] = {.lex_state = 95, .external_lex_state = 3},
  [3044] = {.lex_state = 167, .external_lex_state = 3},
  [3045] = {.lex_state = 28, .external_lex_state = 4},
  [3046] = {.lex_state = 94, .external_lex_state = 3},
  [3047] = {.lex_state = 94, .external_lex_state = 3},
  [3048] = {.lex_state = 94, .external_lex_state = 3},
  [3049] = {.lex_state = 94, .external_lex_state = 3},
  [3050] = {.lex_state = 94, .external_lex_state = 3},
  [3051] = {.lex_state = 94, .external_lex_state = 3},
  [3052] = {.lex_state = 94, .external_lex_state = 3},
  [3053] = {.lex_state = 167, .external_lex_state = 3},
  [3054] = {.lex_state = 90, .external_lex_state = 3},
  [3055] = {.lex_state = 28, .external_lex_state = 4},
  [3056] = {.lex_state = 90, .external_lex_state = 3},
  [3057] = {.lex_state = 28, .external_lex_state = 4},
  [3058] = {.lex_state = 95, .external_lex_state = 3},
  [3059] = {.lex_state = 182, .external_lex_state = 3},
  [3060] = {.lex_state = 95, .external_lex_state = 3},
  [3061] = {.lex_state = 90, .external_lex_state = 3},
  [3062] = {.lex_state = 90, .external_lex_state = 3},
  [3063] = {.lex_state = 90, .external_lex_state = 3},
  [3064] = {.lex_state = 90, .external_lex_state = 3},
  [3065] = {.lex_state = 28, .external_lex_state = 4},
  [3066] = {.lex_state = 95, .external_lex_state = 3},
  [3067] = {.lex_state = 95, .external_lex_state = 3},
  [3068] = {.lex_state = 95, .external_lex_state = 3},
  [3069] = {.lex_state = 167, .external_lex_state = 3},
  [3070] = {.lex_state = 95, .external_lex_state = 3},
  [3071] = {.lex_state = 95, .external_lex_state = 3},
  [3072] = {.lex_state = 28, .external_lex_state = 4},
  [3073] = {.lex_state = 95, .external_lex_state = 3},
  [3074] = {.lex_state = 167, .external_lex_state = 3},
  [3075] = {.lex_state = 90, .external_lex_state = 3},
  [3076] = {.lex_state = 28, .external_lex_state = 4},
  [3077] = {.lex_state = 90, .external_lex_state = 3},
  [3078] = {.lex_state = 90, .external_lex_state = 3},
  [3079] = {.lex_state = 28, .external_lex_state = 4},
  [3080] = {.lex_state = 28, .external_lex_state = 4},
  [3081] = {.lex_state = 91, .external_lex_state = 3},
  [3082] = {.lex_state = 28, .external_lex_state = 4},
  [3083] = {.lex_state = 167, .external_lex_state = 3},
  [3084] = {.lex_state = 91, .external_lex_state = 3},
  [3085] = {.lex_state = 91, .external_lex_state = 3},
  [3086] = {.lex_state = 28, .external_lex_state = 4},
  [3087] = {.lex_state = 91, .external_lex_state = 3},
  [3088] = {.lex_state = 94, .external_lex_state = 3},
  [3089] = {.lex_state = 94, .external_lex_state = 3},
  [3090] = {.lex_state = 167, .external_lex_state = 3},
  [3091] = {.lex_state = 95, .external_lex_state = 3},
  [3092] = {.lex_state = 88, .external_lex_state = 3},
  [3093] = {.lex_state = 167, .external_lex_state = 3},
  [3094] = {.lex_state = 95, .external_lex_state = 3},
  [3095] = {.lex_state = 90, .external_lex_state = 3},
  [3096] = {.lex_state = 88, .external_lex_state = 3},
  [3097] = {.lex_state = 167, .external_lex_state = 3},
  [3098] = {.lex_state = 28, .external_lex_state = 4},
  [3099] = {.lex_state = 167, .external_lex_state = 3},
  [3100] = {.lex_state = 96, .external_lex_state = 3},
  [3101] = {.lex_state = 96, .external_lex_state = 3},
  [3102] = {.lex_state = 167, .external_lex_state = 3},
  [3103] = {.lex_state = 90, .external_lex_state = 3},
  [3104] = {.lex_state = 90, .external_lex_state = 3},
  [3105] = {.lex_state = 167, .external_lex_state = 3},
  [3106] = {.lex_state = 90, .external_lex_state = 3},
  [3107] = {.lex_state = 90, .external_lex_state = 3},
  [3108] = {.lex_state = 90, .external_lex_state = 3},
  [3109] = {.lex_state = 90, .external_lex_state = 3},
  [3110] = {.lex_state = 90, .external_lex_state = 3},
  [3111] = {.lex_state = 90, .external_lex_state = 3},
  [3112] = {.lex_state = 90, .external_lex_state = 3},
  [3113] = {.lex_state = 90, .external_lex_state = 3},
  [3114] = {.lex_state = 167, .external_lex_state = 3},
  [3115] = {.lex_state = 90, .external_lex_state = 3},
  [3116] = {.lex_state = 90, .external_lex_state = 3},
  [3117] = {.lex_state = 90, .external_lex_state = 3},
  [3118] = {.lex_state = 90, .external_lex_state = 3},
  [3119] = {.lex_state = 90, .external_lex_state = 3},
  [3120] = {.lex_state = 90, .external_lex_state = 3},
  [3121] = {.lex_state = 90, .external_lex_state = 3},
  [3122] = {.lex_state = 90, .external_lex_state = 3},
  [3123] = {.lex_state = 90, .external_lex_state = 3},
  [3124] = {.lex_state = 90, .external_lex_state = 3},
  [3125] = {.lex_state = 90, .external_lex_state = 3},
  [3126] = {.lex_state = 90, .external_lex_state = 3},
  [3127] = {.lex_state = 94, .external_lex_state = 3},
  [3128] = {.lex_state = 90, .external_lex_state = 3},
  [3129] = {.lex_state = 90, .external_lex_state = 3},
  [3130] = {.lex_state = 28, .external_lex_state = 4},
  [3131] = {.lex_state = 90, .external_lex_state = 3},
  [3132] = {.lex_state = 90, .external_lex_state = 3},
  [3133] = {.lex_state = 90, .external_lex_state = 3},
  [3134] = {.lex_state = 167, .external_lex_state = 3},
  [3135] = {.lex_state = 94, .external_lex_state = 3},
  [3136] = {.lex_state = 94, .external_lex_state = 3},
  [3137] = {.lex_state = 94, .external_lex_state = 3},
  [3138] = {.lex_state = 94, .external_lex_state = 3},
  [3139] = {.lex_state = 182, .external_lex_state = 3},
  [3140] = {.lex_state = 90, .external_lex_state = 3},
  [3141] = {.lex_state = 167, .external_lex_state = 3},
  [3142] = {.lex_state = 90, .external_lex_state = 3},
  [3143] = {.lex_state = 90, .external_lex_state = 3},
  [3144] = {.lex_state = 90, .external_lex_state = 3},
  [3145] = {.lex_state = 167, .external_lex_state = 3},
  [3146] = {.lex_state = 90, .external_lex_state = 3},
  [3147] = {.lex_state = 90, .external_lex_state = 3},
  [3148] = {.lex_state = 90, .external_lex_state = 3},
  [3149] = {.lex_state = 90, .external_lex_state = 3},
  [3150] = {.lex_state = 28, .external_lex_state = 4},
  [3151] = {.lex_state = 90, .external_lex_state = 3},
  [3152] = {.lex_state = 90, .external_lex_state = 3},
  [3153] = {.lex_state = 90, .external_lex_state = 3},
  [3154] = {.lex_state = 90, .external_lex_state = 3},
  [3155] = {.lex_state = 28, .external_lex_state = 4},
  [3156] = {.lex_state = 90, .external_lex_state = 3},
  [3157] = {.lex_state = 90, .external_lex_state = 3},
  [3158] = {.lex_state = 90, .external_lex_state = 3},
  [3159] = {.lex_state = 90, .external_lex_state = 3},
  [3160] = {.lex_state = 90, .external_lex_state = 3},
  [3161] = {.lex_state = 90, .external_lex_state = 3},
  [3162] = {.lex_state = 90, .external_lex_state = 3},
  [3163] = {.lex_state = 90, .external_lex_state = 3},
  [3164] = {.lex_state = 90, .external_lex_state = 3},
  [3165] = {.lex_state = 90, .external_lex_state = 3},
  [3166] = {.lex_state = 94, .external_lex_state = 3},
  [3167] = {.lex_state = 90, .external_lex_state = 3},
  [3168] = {.lex_state = 90, .external_lex_state = 3},
  [3169] = {.lex_state = 90, .external_lex_state = 3},
  [3170] = {.lex_state = 90, .external_lex_state = 3},
  [3171] = {.lex_state = 90, .external_lex_state = 3},
  [3172] = {.lex_state = 90, .external_lex_state = 3},
  [3173] = {.lex_state = 88, .external_lex_state = 3},
  [3174] = {.lex_state = 88, .external_lex_state = 3},
  [3175] = {.lex_state = 88, .external_lex_state = 3},
  [3176] = {.lex_state = 90, .external_lex_state = 3},
  [3177] = {.lex_state = 94, .external_lex_state = 3},
  [3178] = {.lex_state = 94, .external_lex_state = 3},
  [3179] = {.lex_state = 167, .external_lex_state = 3},
  [3180] = {.lex_state = 182, .external_lex_state = 3},
  [3181] = {.lex_state = 167, .external_lex_state = 3},
  [3182] = {.lex_state = 94, .external_lex_state = 3},
  [3183] = {.lex_state = 88, .external_lex_state = 3},
  [3184] = {.lex_state = 167, .external_lex_state = 3},
  [3185] = {.lex_state = 88, .external_lex_state = 3},
  [3186] = {.lex_state = 88, .external_lex_state = 3},
  [3187] = {.lex_state = 167, .external_lex_state = 3},
  [3188] = {.lex_state = 94, .external_lex_state = 3},
  [3189] = {.lex_state = 94, .external_lex_state = 3},
  [3190] = {.lex_state = 94, .external_lex_state = 3},
  [3191] = {.lex_state = 182, .external_lex_state = 3},
  [3192] = {.lex_state = 94, .external_lex_state = 3},
  [3193] = {.lex_state = 94, .external_lex_state = 3},
  [3194] = {.lex_state = 94, .external_lex_state = 3},
  [3195] = {.lex_state = 94, .external_lex_state = 3},
  [3196] = {.lex_state = 94, .external_lex_state = 3},
  [3197] = {.lex_state = 94, .external_lex_state = 3},
  [3198] = {.lex_state = 94, .external_lex_state = 3},
  [3199] = {.lex_state = 167, .external_lex_state = 3},
  [3200] = {.lex_state = 167, .external_lex_state = 3},
  [3201] = {.lex_state = 88, .external_lex_state = 3},
  [3202] = {.lex_state = 28, .external_lex_state = 4},
  [3203] = {.lex_state = 28, .external_lex_state = 4},
  [3204] = {.lex_state = 28, .external_lex_state = 4},
  [3205] = {.lex_state = 90, .external_lex_state = 3},
  [3206] = {.lex_state = 90, .external_lex_state = 3},
  [3207] = {.lex_state = 90, .external_lex_state = 3},
  [3208] = {.lex_state = 90, .external_lex_state = 3},
  [3209] = {.lex_state = 167, .external_lex_state = 3},
  [3210] = {.lex_state = 94, .external_lex_state = 3},
  [3211] = {.lex_state = 94, .external_lex_state = 3},
  [3212] = {.lex_state = 94, .external_lex_state = 3},
  [3213] = {.lex_state = 94, .external_lex_state = 3},
  [3214] = {.lex_state = 167, .external_lex_state = 3},
  [3215] = {.lex_state = 167, .external_lex_state = 3},
  [3216] = {.lex_state = 167, .external_lex_state = 3},
  [3217] = {.lex_state = 167, .external_lex_state = 3},
  [3218] = {.lex_state = 182, .external_lex_state = 3},
  [3219] = {.lex_state = 28, .external_lex_state = 4},
  [3220] = {.lex_state = 28, .external_lex_state = 4},
  [3221] = {.lex_state = 167, .external_lex_state = 3},
  [3222] = {.lex_state = 167, .external_lex_state = 3},
  [3223] = {.lex_state = 167, .external_lex_state = 3},
  [3224] = {.lex_state = 167, .external_lex_state = 3},
  [3225] = {.lex_state = 182, .external_lex_state = 3},
  [3226] = {.lex_state = 28, .external_lex_state = 4},
  [3227] = {.lex_state = 167, .external_lex_state = 3},
  [3228] = {.lex_state = 28, .external_lex_state = 4},
  [3229] = {.lex_state = 167, .external_lex_state = 3},
  [3230] = {.lex_state = 167, .external_lex_state = 3},
  [3231] = {.lex_state = 28, .external_lex_state = 4},
  [3232] = {.lex_state = 167, .external_lex_state = 3},
  [3233] = {.lex_state = 182, .external_lex_state = 3},
  [3234] = {.lex_state = 167, .external_lex_state = 3},
  [3235] = {.lex_state = 28, .external_lex_state = 4},
  [3236] = {.lex_state = 167, .external_lex_state = 3},
  [3237] = {.lex_state = 167, .external_lex_state = 3},
  [3238] = {.lex_state = 28, .external_lex_state = 4},
  [3239] = {.lex_state = 167, .external_lex_state = 3},
  [3240] = {.lex_state = 167, .external_lex_state = 3},
  [3241] = {.lex_state = 182, .external_lex_state = 3},
  [3242] = {.lex_state = 88, .external_lex_state = 3},
  [3243] = {.lex_state = 88, .external_lex_state = 3},
  [3244] = {.lex_state = 28, .external_lex_state = 4},
  [3245] = {.lex_state = 167, .external_lex_state = 3},
  [3246] = {.lex_state = 28, .external_lex_state = 3},
  [3247] = {.lex_state = 28, .external_lex_state = 3},
  [3248] = {.lex_state = 28, .external_lex_state = 4},
  [3249] = {.lex_state = 28, .external_lex_state = 4},
  [3250] = {.lex_state = 167, .external_lex_state = 3},
  [3251] = {.lex_state = 167, .external_lex_state = 3},
  [3252] = {.lex_state = 167, .external_lex_state = 3},
  [3253] = {.lex_state = 167, .external_lex_state = 3},
  [3254] = {.lex_state = 28, .external_lex_state = 4},
  [3255] = {.lex_state = 167, .external_lex_state = 3},
  [3256] = {.lex_state = 28, .external_lex_state = 4},
  [3257] = {.lex_state = 167, .external_lex_state = 3},
  [3258] = {.lex_state = 182, .external_lex_state = 3},
  [3259] = {.lex_state = 167, .external_lex_state = 3},
  [3260] = {.lex_state = 167, .external_lex_state = 3},
  [3261] = {.lex_state = 182, .external_lex_state = 3},
  [3262] = {.lex_state = 167, .external_lex_state = 3},
  [3263] = {.lex_state = 167, .external_lex_state = 3},
  [3264] = {.lex_state = 28, .external_lex_state = 4},
  [3265] = {.lex_state = 167, .external_lex_state = 3},
  [3266] = {.lex_state = 182, .external_lex_state = 3},
  [3267] = {.lex_state = 167, .external_lex_state = 3},
  [3268] = {.lex_state = 167, .external_lex_state = 3},
  [3269] = {.lex_state = 167, .external_lex_state = 3},
  [3270] = {.lex_state = 167, .external_lex_state = 3},
  [3271] = {.lex_state = 167, .external_lex_state = 3},
  [3272] = {.lex_state = 28, .external_lex_state = 4},
  [3273] = {.lex_state = 167, .external_lex_state = 3},
  [3274] = {.lex_state = 167, .external_lex_state = 3},
  [3275] = {.lex_state = 28, .external_lex_state = 4},
  [3276] = {.lex_state = 28, .external_lex_state = 4},
  [3277] = {.lex_state = 182, .external_lex_state = 3},
  [3278] = {.lex_state = 167, .external_lex_state = 3},
  [3279] = {.lex_state = 182, .external_lex_state = 3},
  [3280] = {.lex_state = 167, .external_lex_state = 3},
  [3281] = {.lex_state = 167, .external_lex_state = 3},
  [3282] = {.lex_state = 167, .external_lex_state = 3},
  [3283] = {.lex_state = 167, .external_lex_state = 3},
  [3284] = {.lex_state = 182, .external_lex_state = 3},
  [3285] = {.lex_state = 182, .external_lex_state = 3},
  [3286] = {.lex_state = 167, .external_lex_state = 3},
  [3287] = {.lex_state = 167, .external_lex_state = 3},
  [3288] = {.lex_state = 182, .external_lex_state = 3},
  [3289] = {.lex_state = 167, .external_lex_state = 3},
  [3290] = {.lex_state = 28, .external_lex_state = 4},
  [3291] = {.lex_state = 167, .external_lex_state = 3},
  [3292] = {.lex_state = 167, .external_lex_state = 3},
  [3293] = {.lex_state = 182, .external_lex_state = 3},
  [3294] = {.lex_state = 167, .external_lex_state = 3},
  [3295] = {.lex_state = 28, .external_lex_state = 4},
  [3296] = {.lex_state = 167, .external_lex_state = 3},
  [3297] = {.lex_state = 182, .external_lex_state = 3},
  [3298] = {.lex_state = 167, .external_lex_state = 3},
  [3299] = {.lex_state = 182, .external_lex_state = 3},
  [3300] = {.lex_state = 167, .external_lex_state = 3},
  [3301] = {.lex_state = 167, .external_lex_state = 3},
  [3302] = {.lex_state = 182, .external_lex_state = 3},
  [3303] = {.lex_state = 167, .external_lex_state = 3},
  [3304] = {.lex_state = 28, .external_lex_state = 4},
  [3305] = {.lex_state = 28, .external_lex_state = 4},
  [3306] = {.lex_state = 167, .external_lex_state = 3},
  [3307] = {.lex_state = 167, .external_lex_state = 3},
  [3308] = {.lex_state = 167, .external_lex_state = 3},
  [3309] = {.lex_state = 167, .external_lex_state = 3},
  [3310] = {.lex_state = 167, .external_lex_state = 3},
  [3311] = {.lex_state = 167, .external_lex_state = 3},
  [3312] = {.lex_state = 182, .external_lex_state = 3},
  [3313] = {.lex_state = 167, .external_lex_state = 3},
  [3314] = {.lex_state = 167, .external_lex_state = 3},
  [3315] = {.lex_state = 97, .external_lex_state = 3},
  [3316] = {.lex_state = 88, .external_lex_state = 3},
  [3317] = {.lex_state = 97, .external_lex_state = 3},
  [3318] = {.lex_state = 97, .external_lex_state = 3},
  [3319] = {.lex_state = 167, .external_lex_state = 3},
  [3320] = {.lex_state = 97, .external_lex_state = 3},
  [3321] = {.lex_state = 167, .external_lex_state = 3},
  [3322] = {.lex_state = 167, .external_lex_state = 3},
  [3323] = {.lex_state = 167, .external_lex_state = 3},
  [3324] = {.lex_state = 96, .external_lex_state = 3},
  [3325] = {.lex_state = 97, .external_lex_state = 3},
  [3326] = {.lex_state = 167, .external_lex_state = 3},
  [3327] = {.lex_state = 167, .external_lex_state = 3},
  [3328] = {.lex_state = 167, .external_lex_state = 3},
  [3329] = {.lex_state = 88, .external_lex_state = 3},
  [3330] = {.lex_state = 167, .external_lex_state = 3},
  [3331] = {.lex_state = 88, .external_lex_state = 3},
  [3332] = {.lex_state = 88, .external_lex_state = 3},
  [3333] = {.lex_state = 167, .external_lex_state = 3},
  [3334] = {.lex_state = 88, .external_lex_state = 3},
  [3335] = {.lex_state = 169, .external_lex_state = 3},
  [3336] = {.lex_state = 167, .external_lex_state = 3},
  [3337] = {.lex_state = 95, .external_lex_state = 3},
  [3338] = {.lex_state = 167, .external_lex_state = 3},
  [3339] = {.lex_state = 95, .external_lex_state = 3},
  [3340] = {.lex_state = 88, .external_lex_state = 3},
  [3341] = {.lex_state = 88, .external_lex_state = 3},
  [3342] = {.lex_state = 167, .external_lex_state = 3},
  [3343] = {.lex_state = 167, .external_lex_state = 3},
  [3344] = {.lex_state = 91, .external_lex_state = 3},
  [3345] = {.lex_state = 88, .external_lex_state = 3},
  [3346] = {.lex_state = 97, .external_lex_state = 3},
  [3347] = {.lex_state = 97, .external_lex_state = 3},
  [3348] = {.lex_state = 97, .external_lex_state = 3},
  [3349] = {.lex_state = 91, .external_lex_state = 3},
  [3350] = {.lex_state = 88, .external_lex_state = 3},
  [3351] = {.lex_state = 91, .external_lex_state = 3},
  [3352] = {.lex_state = 91, .external_lex_state = 3},
  [3353] = {.lex_state = 91, .external_lex_state = 3},
  [3354] = {.lex_state = 91, .external_lex_state = 3},
  [3355] = {.lex_state = 91, .external_lex_state = 3},
  [3356] = {.lex_state = 89, .external_lex_state = 3},
  [3357] = {.lex_state = 88, .external_lex_state = 3},
  [3358] = {.lex_state = 88, .external_lex_state = 3},
  [3359] = {.lex_state = 167, .external_lex_state = 3},
  [3360] = {.lex_state = 88, .external_lex_state = 3},
  [3361] = {.lex_state = 88, .external_lex_state = 3},
  [3362] = {.lex_state = 167, .external_lex_state = 3},
  [3363] = {.lex_state = 88, .external_lex_state = 3},
  [3364] = {.lex_state = 88, .external_lex_state = 3},
  [3365] = {.lex_state = 88, .external_lex_state = 3},
  [3366] = {.lex_state = 88, .external_lex_state = 3},
  [3367] = {.lex_state = 96, .external_lex_state = 3},
  [3368] = {.lex_state = 95, .external_lex_state = 3},
  [3369] = {.lex_state = 88, .external_lex_state = 3},
  [3370] = {.lex_state = 88, .external_lex_state = 3},
  [3371] = {.lex_state = 88, .external_lex_state = 3},
  [3372] = {.lex_state = 88, .external_lex_state = 3},
  [3373] = {.lex_state = 88, .external_lex_state = 3},
  [3374] = {.lex_state = 88, .external_lex_state = 3},
  [3375] = {.lex_state = 88, .external_lex_state = 3},
  [3376] = {.lex_state = 88, .external_lex_state = 3},
  [3377] = {.lex_state = 96, .external_lex_state = 3},
  [3378] = {.lex_state = 88, .external_lex_state = 3},
  [3379] = {.lex_state = 88, .external_lex_state = 3},
  [3380] = {.lex_state = 95, .external_lex_state = 3},
  [3381] = {.lex_state = 95, .external_lex_state = 3},
  [3382] = {.lex_state = 95, .external_lex_state = 3},
  [3383] = {.lex_state = 95, .external_lex_state = 3},
  [3384] = {.lex_state = 88, .external_lex_state = 3},
  [3385] = {.lex_state = 88, .external_lex_state = 3},
  [3386] = {.lex_state = 88, .external_lex_state = 3},
  [3387] = {.lex_state = 167, .external_lex_state = 3},
  [3388] = {.lex_state = 89, .external_lex_state = 3},
  [3389] = {.lex_state = 88, .external_lex_state = 3},
  [3390] = {.lex_state = 91, .external_lex_state = 3},
  [3391] = {.lex_state = 167, .external_lex_state = 3},
  [3392] = {.lex_state = 89, .external_lex_state = 3},
  [3393] = {.lex_state = 88, .external_lex_state = 3},
  [3394] = {.lex_state = 167, .external_lex_state = 3},
  [3395] = {.lex_state = 91, .external_lex_state = 3},
  [3396] = {.lex_state = 88, .external_lex_state = 3},
  [3397] = {.lex_state = 88, .external_lex_state = 3},
  [3398] = {.lex_state = 91, .external_lex_state = 3},
  [3399] = {.lex_state = 91, .external_lex_state = 3},
  [3400] = {.lex_state = 91, .external_lex_state = 3},
  [3401] = {.lex_state = 88, .external_lex_state = 3},
  [3402] = {.lex_state = 167, .external_lex_state = 3},
  [3403] = {.lex_state = 88, .external_lex_state = 3},
  [3404] = {.lex_state = 88, .external_lex_state = 3},
  [3405] = {.lex_state = 96, .external_lex_state = 3},
  [3406] = {.lex_state = 91, .external_lex_state = 3},
  [3407] = {.lex_state = 88, .external_lex_state = 3},
  [3408] = {.lex_state = 91, .external_lex_state = 3},
  [3409] = {.lex_state = 167, .external_lex_state = 3},
  [3410] = {.lex_state = 95, .external_lex_state = 3},
  [3411] = {.lex_state = 91, .external_lex_state = 3},
  [3412] = {.lex_state = 91, .external_lex_state = 3},
  [3413] = {.lex_state = 91, .external_lex_state = 3},
  [3414] = {.lex_state = 167, .external_lex_state = 3},
  [3415] = {.lex_state = 167, .external_lex_state = 3},
  [3416] = {.lex_state = 88, .external_lex_state = 3},
  [3417] = {.lex_state = 167, .external_lex_state = 3},
  [3418] = {.lex_state = 88, .external_lex_state = 3},
  [3419] = {.lex_state = 88, .external_lex_state = 3},
  [3420] = {.lex_state = 167, .external_lex_state = 3},
  [3421] = {.lex_state = 91, .external_lex_state = 3},
  [3422] = {.lex_state = 167, .external_lex_state = 3},
  [3423] = {.lex_state = 167, .external_lex_state = 3},
  [3424] = {.lex_state = 91, .external_lex_state = 3},
  [3425] = {.lex_state = 167, .external_lex_state = 3},
  [3426] = {.lex_state = 167, .external_lex_state = 3},
  [3427] = {.lex_state = 96, .external_lex_state = 3},
  [3428] = {.lex_state = 95, .external_lex_state = 3},
  [3429] = {.lex_state = 95, .external_lex_state = 3},
  [3430] = {.lex_state = 167, .external_lex_state = 3},
  [3431] = {.lex_state = 95, .external_lex_state = 3},
  [3432] = {.lex_state = 95, .external_lex_state = 3},
  [3433] = {.lex_state = 169, .external_lex_state = 3},
  [3434] = {.lex_state = 95, .external_lex_state = 3},
  [3435] = {.lex_state = 95, .external_lex_state = 3},
  [3436] = {.lex_state = 91, .external_lex_state = 3},
  [3437] = {.lex_state = 96, .external_lex_state = 3},
  [3438] = {.lex_state = 167, .external_lex_state = 3},
  [3439] = {.lex_state = 88, .external_lex_state = 3},
  [3440] = {.lex_state = 97, .external_lex_state = 3},
  [3441] = {.lex_state = 167, .external_lex_state = 3},
  [3442] = {.lex_state = 167, .external_lex_state = 3},
  [3443] = {.lex_state = 96, .external_lex_state = 3},
  [3444] = {.lex_state = 95, .external_lex_state = 3},
  [3445] = {.lex_state = 167, .external_lex_state = 3},
  [3446] = {.lex_state = 88, .external_lex_state = 3},
  [3447] = {.lex_state = 88, .external_lex_state = 3},
  [3448] = {.lex_state = 88, .external_lex_state = 3},
  [3449] = {.lex_state = 95, .external_lex_state = 3},
  [3450] = {.lex_state = 95, .external_lex_state = 3},
  [3451] = {.lex_state = 97, .external_lex_state = 3},
  [3452] = {.lex_state = 91, .external_lex_state = 3},
  [3453] = {.lex_state = 167, .external_lex_state = 3},
  [3454] = {.lex_state = 88, .external_lex_state = 3},
  [3455] = {.lex_state = 95, .external_lex_state = 3},
  [3456] = {.lex_state = 96, .external_lex_state = 3},
  [3457] = {.lex_state = 96, .external_lex_state = 3},
  [3458] = {.lex_state = 96, .external_lex_state = 3},
  [3459] = {.lex_state = 95, .external_lex_state = 3},
  [3460] = {.lex_state = 96, .external_lex_state = 3},
  [3461] = {.lex_state = 88, .external_lex_state = 3},
  [3462] = {.lex_state = 167, .external_lex_state = 3},
  [3463] = {.lex_state = 95, .external_lex_state = 3},
  [3464] = {.lex_state = 88, .external_lex_state = 3},
  [3465] = {.lex_state = 96, .external_lex_state = 3},
  [3466] = {.lex_state = 167, .external_lex_state = 3},
  [3467] = {.lex_state = 95, .external_lex_state = 3},
  [3468] = {.lex_state = 88, .external_lex_state = 3},
  [3469] = {.lex_state = 88, .external_lex_state = 3},
  [3470] = {.lex_state = 88, .external_lex_state = 3},
  [3471] = {.lex_state = 88, .external_lex_state = 3},
  [3472] = {.lex_state = 88, .external_lex_state = 3},
  [3473] = {.lex_state = 88, .external_lex_state = 3},
  [3474] = {.lex_state = 88, .external_lex_state = 3},
  [3475] = {.lex_state = 95, .external_lex_state = 3},
  [3476] = {.lex_state = 96, .external_lex_state = 3},
  [3477] = {.lex_state = 167, .external_lex_state = 3},
  [3478] = {.lex_state = 95, .external_lex_state = 3},
  [3479] = {.lex_state = 88, .external_lex_state = 3},
  [3480] = {.lex_state = 95, .external_lex_state = 3},
  [3481] = {.lex_state = 96, .external_lex_state = 3},
  [3482] = {.lex_state = 167, .external_lex_state = 3},
  [3483] = {.lex_state = 95, .external_lex_state = 3},
  [3484] = {.lex_state = 88, .external_lex_state = 3},
  [3485] = {.lex_state = 96, .external_lex_state = 3},
  [3486] = {.lex_state = 88, .external_lex_state = 3},
  [3487] = {.lex_state = 95, .external_lex_state = 3},
  [3488] = {.lex_state = 88, .external_lex_state = 3},
  [3489] = {.lex_state = 95, .external_lex_state = 3},
  [3490] = {.lex_state = 88, .external_lex_state = 3},
  [3491] = {.lex_state = 95, .external_lex_state = 3},
  [3492] = {.lex_state = 88, .external_lex_state = 3},
  [3493] = {.lex_state = 96, .external_lex_state = 3},
  [3494] = {.lex_state = 95, .external_lex_state = 3},
  [3495] = {.lex_state = 95, .external_lex_state = 3},
  [3496] = {.lex_state = 167, .external_lex_state = 3},
  [3497] = {.lex_state = 96, .external_lex_state = 3},
  [3498] = {.lex_state = 88, .external_lex_state = 3},
  [3499] = {.lex_state = 167, .external_lex_state = 3},
  [3500] = {.lex_state = 167, .external_lex_state = 3},
  [3501] = {.lex_state = 96, .external_lex_state = 3},
  [3502] = {.lex_state = 96, .external_lex_state = 3},
  [3503] = {.lex_state = 88, .external_lex_state = 3},
  [3504] = {.lex_state = 91, .external_lex_state = 3},
  [3505] = {.lex_state = 167, .external_lex_state = 3},
  [3506] = {.lex_state = 88, .external_lex_state = 3},
  [3507] = {.lex_state = 96, .external_lex_state = 3},
  [3508] = {.lex_state = 167, .external_lex_state = 3},
  [3509] = {.lex_state = 91, .external_lex_state = 3},
  [3510] = {.lex_state = 167, .external_lex_state = 3},
  [3511] = {.lex_state = 167, .external_lex_state = 3},
  [3512] = {.lex_state = 91, .external_lex_state = 3},
  [3513] = {.lex_state = 96, .external_lex_state = 3},
  [3514] = {.lex_state = 91, .external_lex_state = 3},
  [3515] = {.lex_state = 95, .external_lex_state = 3},
  [3516] = {.lex_state = 95, .external_lex_state = 3},
  [3517] = {.lex_state = 95, .external_lex_state = 3},
  [3518] = {.lex_state = 96, .external_lex_state = 3},
  [3519] = {.lex_state = 95, .external_lex_state = 3},
  [3520] = {.lex_state = 96, .external_lex_state = 3},
  [3521] = {.lex_state = 167, .external_lex_state = 3},
  [3522] = {.lex_state = 88, .external_lex_state = 3},
  [3523] = {.lex_state = 96, .external_lex_state = 3},
  [3524] = {.lex_state = 167, .external_lex_state = 3},
  [3525] = {.lex_state = 167, .external_lex_state = 3},
  [3526] = {.lex_state = 96, .external_lex_state = 3},
  [3527] = {.lex_state = 88, .external_lex_state = 3},
  [3528] = {.lex_state = 91, .external_lex_state = 3},
  [3529] = {.lex_state = 167, .external_lex_state = 3},
  [3530] = {.lex_state = 167, .external_lex_state = 3},
  [3531] = {.lex_state = 167, .external_lex_state = 3},
  [3532] = {.lex_state = 91, .external_lex_state = 3},
  [3533] = {.lex_state = 167, .external_lex_state = 3},
  [3534] = {.lex_state = 167, .external_lex_state = 3},
  [3535] = {.lex_state = 91, .external_lex_state = 3},
  [3536] = {.lex_state = 96, .external_lex_state = 3},
  [3537] = {.lex_state = 167, .external_lex_state = 3},
  [3538] = {.lex_state = 96, .external_lex_state = 3},
  [3539] = {.lex_state = 88, .external_lex_state = 3},
  [3540] = {.lex_state = 96, .external_lex_state = 3},
  [3541] = {.lex_state = 96, .external_lex_state = 3},
  [3542] = {.lex_state = 96, .external_lex_state = 3},
  [3543] = {.lex_state = 91, .external_lex_state = 3},
  [3544] = {.lex_state = 96, .external_lex_state = 3},
  [3545] = {.lex_state = 167, .external_lex_state = 3},
  [3546] = {.lex_state = 167, .external_lex_state = 3},
  [3547] = {.lex_state = 96, .external_lex_state = 3},
  [3548] = {.lex_state = 97, .external_lex_state = 3},
  [3549] = {.lex_state = 91, .external_lex_state = 3},
  [3550] = {.lex_state = 167, .external_lex_state = 3},
  [3551] = {.lex_state = 91, .external_lex_state = 3},
  [3552] = {.lex_state = 167, .external_lex_state = 3},
  [3553] = {.lex_state = 167, .external_lex_state = 3},
  [3554] = {.lex_state = 96, .external_lex_state = 3},
  [3555] = {.lex_state = 91, .external_lex_state = 3},
  [3556] = {.lex_state = 96, .external_lex_state = 3},
  [3557] = {.lex_state = 96, .external_lex_state = 3},
  [3558] = {.lex_state = 88, .external_lex_state = 3},
  [3559] = {.lex_state = 28, .external_lex_state = 3},
  [3560] = {.lex_state = 96, .external_lex_state = 3},
  [3561] = {.lex_state = 28, .external_lex_state = 3},
  [3562] = {.lex_state = 167, .external_lex_state = 3},
  [3563] = {.lex_state = 96, .external_lex_state = 3},
  [3564] = {.lex_state = 95, .external_lex_state = 3},
  [3565] = {.lex_state = 91, .external_lex_state = 3},
  [3566] = {.lex_state = 167, .external_lex_state = 3},
  [3567] = {.lex_state = 91, .external_lex_state = 3},
  [3568] = {.lex_state = 167, .external_lex_state = 3},
  [3569] = {.lex_state = 169, .external_lex_state = 3},
  [3570] = {.lex_state = 169, .external_lex_state = 3},
  [3571] = {.lex_state = 91, .external_lex_state = 3},
  [3572] = {.lex_state = 167, .external_lex_state = 3},
  [3573] = {.lex_state = 96, .external_lex_state = 3},
  [3574] = {.lex_state = 167, .external_lex_state = 3},
  [3575] = {.lex_state = 91, .external_lex_state = 3},
  [3576] = {.lex_state = 96, .external_lex_state = 3},
  [3577] = {.lex_state = 169, .external_lex_state = 3},
  [3578] = {.lex_state = 96, .external_lex_state = 3},
  [3579] = {.lex_state = 91, .external_lex_state = 3},
  [3580] = {.lex_state = 167, .external_lex_state = 3},
  [3581] = {.lex_state = 167, .external_lex_state = 3},
  [3582] = {.lex_state = 96, .external_lex_state = 3},
  [3583] = {.lex_state = 95, .external_lex_state = 3},
  [3584] = {.lex_state = 88, .external_lex_state = 3},
  [3585] = {.lex_state = 167, .external_lex_state = 3},
  [3586] = {.lex_state = 167, .external_lex_state = 3},
  [3587] = {.lex_state = 167, .external_lex_state = 3},
  [3588] = {.lex_state = 95, .external_lex_state = 3},
  [3589] = {.lex_state = 96, .external_lex_state = 3},
  [3590] = {.lex_state = 89, .external_lex_state = 3},
  [3591] = {.lex_state = 167, .external_lex_state = 3},
  [3592] = {.lex_state = 167, .external_lex_state = 3},
  [3593] = {.lex_state = 95, .external_lex_state = 3},
  [3594] = {.lex_state = 96, .external_lex_state = 3},
  [3595] = {.lex_state = 89, .external_lex_state = 3},
  [3596] = {.lex_state = 167, .external_lex_state = 3},
  [3597] = {.lex_state = 91, .external_lex_state = 3},
  [3598] = {.lex_state = 89, .external_lex_state = 3},
  [3599] = {.lex_state = 95, .external_lex_state = 3},
  [3600] = {.lex_state = 91, .external_lex_state = 3},
  [3601] = {.lex_state = 95, .external_lex_state = 3},
  [3602] = {.lex_state = 91, .external_lex_state = 3},
  [3603] = {.lex_state = 95, .external_lex_state = 3},
  [3604] = {.lex_state = 95, .external_lex_state = 3},
  [3605] = {.lex_state = 91, .external_lex_state = 3},
  [3606] = {.lex_state = 95, .external_lex_state = 3},
  [3607] = {.lex_state = 95, .external_lex_state = 3},
  [3608] = {.lex_state = 95, .external_lex_state = 3},
  [3609] = {.lex_state = 95, .external_lex_state = 3},
  [3610] = {.lex_state = 95, .external_lex_state = 3},
  [3611] = {.lex_state = 95, .external_lex_state = 3},
  [3612] = {.lex_state = 89, .external_lex_state = 3},
  [3613] = {.lex_state = 167, .external_lex_state = 3},
  [3614] = {.lex_state = 95, .external_lex_state = 3},
  [3615] = {.lex_state = 95, .external_lex_state = 3},
  [3616] = {.lex_state = 167, .external_lex_state = 3},
  [3617] = {.lex_state = 167, .external_lex_state = 3},
  [3618] = {.lex_state = 89, .external_lex_state = 3},
  [3619] = {.lex_state = 89, .external_lex_state = 3},
  [3620] = {.lex_state = 167, .external_lex_state = 3},
  [3621] = {.lex_state = 167, .external_lex_state = 3},
  [3622] = {.lex_state = 167, .external_lex_state = 3},
  [3623] = {.lex_state = 167, .external_lex_state = 3},
  [3624] = {.lex_state = 6, .external_lex_state = 3},
  [3625] = {.lex_state = 6, .external_lex_state = 3},
  [3626] = {.lex_state = 95, .external_lex_state = 3},
  [3627] = {.lex_state = 167, .external_lex_state = 3},
  [3628] = {.lex_state = 95, .external_lex_state = 3},
  [3629] = {.lex_state = 95, .external_lex_state = 3},
  [3630] = {.lex_state = 95, .external_lex_state = 3},
  [3631] = {.lex_state = 167, .external_lex_state = 3},
  [3632] = {.lex_state = 95, .external_lex_state = 3},
  [3633] = {.lex_state = 96, .external_lex_state = 3},
  [3634] = {.lex_state = 95, .external_lex_state = 3},
  [3635] = {.lex_state = 96, .external_lex_state = 3},
  [3636] = {.lex_state = 91, .external_lex_state = 3},
  [3637] = {.lex_state = 95, .external_lex_state = 3},
  [3638] = {.lex_state = 96, .external_lex_state = 3},
  [3639] = {.lex_state = 95, .external_lex_state = 3},
  [3640] = {.lex_state = 95, .external_lex_state = 3},
  [3641] = {.lex_state = 167, .external_lex_state = 3},
  [3642] = {.lex_state = 89, .external_lex_state = 3},
  [3643] = {.lex_state = 96, .external_lex_state = 3},
  [3644] = {.lex_state = 167, .external_lex_state = 3},
  [3645] = {.lex_state = 95, .external_lex_state = 3},
  [3646] = {.lex_state = 167, .external_lex_state = 3},
  [3647] = {.lex_state = 91, .external_lex_state = 3},
  [3648] = {.lex_state = 95, .external_lex_state = 3},
  [3649] = {.lex_state = 91, .external_lex_state = 3},
  [3650] = {.lex_state = 91, .external_lex_state = 3},
  [3651] = {.lex_state = 88, .external_lex_state = 3},
  [3652] = {.lex_state = 96, .external_lex_state = 3},
  [3653] = {.lex_state = 95, .external_lex_state = 3},
  [3654] = {.lex_state = 167, .external_lex_state = 3},
  [3655] = {.lex_state = 96, .external_lex_state = 3},
  [3656] = {.lex_state = 95, .external_lex_state = 3},
  [3657] = {.lex_state = 96, .external_lex_state = 3},
  [3658] = {.lex_state = 96, .external_lex_state = 3},
  [3659] = {.lex_state = 95, .external_lex_state = 3},
  [3660] = {.lex_state = 91, .external_lex_state = 3},
  [3661] = {.lex_state = 91, .external_lex_state = 3},
  [3662] = {.lex_state = 95, .external_lex_state = 3},
  [3663] = {.lex_state = 91, .external_lex_state = 3},
  [3664] = {.lex_state = 96, .external_lex_state = 3},
  [3665] = {.lex_state = 167, .external_lex_state = 3},
  [3666] = {.lex_state = 167, .external_lex_state = 3},
  [3667] = {.lex_state = 96, .external_lex_state = 3},
  [3668] = {.lex_state = 96, .external_lex_state = 3},
  [3669] = {.lex_state = 96, .external_lex_state = 3},
  [3670] = {.lex_state = 167, .external_lex_state = 3},
  [3671] = {.lex_state = 167, .external_lex_state = 3},
  [3672] = {.lex_state = 91, .external_lex_state = 3},
  [3673] = {.lex_state = 91, .external_lex_state = 3},
  [3674] = {.lex_state = 96, .external_lex_state = 3},
  [3675] = {.lex_state = 95, .external_lex_state = 3},
  [3676] = {.lex_state = 95, .external_lex_state = 3},
  [3677] = {.lex_state = 95, .external_lex_state = 3},
  [3678] = {.lex_state = 167, .external_lex_state = 3},
  [3679] = {.lex_state = 95, .external_lex_state = 3},
  [3680] = {.lex_state = 96, .external_lex_state = 3},
  [3681] = {.lex_state = 167, .external_lex_state = 3},
  [3682] = {.lex_state = 95, .external_lex_state = 3},
  [3683] = {.lex_state = 95, .external_lex_state = 3},
  [3684] = {.lex_state = 167, .external_lex_state = 3},
  [3685] = {.lex_state = 169, .external_lex_state = 3},
  [3686] = {.lex_state = 167, .external_lex_state = 3},
  [3687] = {.lex_state = 167, .external_lex_state = 3},
  [3688] = {.lex_state = 96, .external_lex_state = 3},
  [3689] = {.lex_state = 96, .external_lex_state = 3},
  [3690] = {.lex_state = 91, .external_lex_state = 3},
  [3691] = {.lex_state = 91, .external_lex_state = 3},
  [3692] = {.lex_state = 96, .external_lex_state = 3},
  [3693] = {.lex_state = 167, .external_lex_state = 3},
  [3694] = {.lex_state = 96, .external_lex_state = 3},
  [3695] = {.lex_state = 96, .external_lex_state = 3},
  [3696] = {.lex_state = 96, .external_lex_state = 3},
  [3697] = {.lex_state = 88, .external_lex_state = 3},
  [3698] = {.lex_state = 96, .external_lex_state = 3},
  [3699] = {.lex_state = 167, .external_lex_state = 3},
  [3700] = {.lex_state = 96, .external_lex_state = 3},
  [3701] = {.lex_state = 167, .external_lex_state = 3},
  [3702] = {.lex_state = 167, .external_lex_state = 3},
  [3703] = {.lex_state = 167, .external_lex_state = 3},
  [3704] = {.lex_state = 95, .external_lex_state = 3},
  [3705] = {.lex_state = 96, .external_lex_state = 3},
  [3706] = {.lex_state = 96, .external_lex_state = 3},
  [3707] = {.lex_state = 167, .external_lex_state = 3},
  [3708] = {.lex_state = 96, .external_lex_state = 3},
  [3709] = {.lex_state = 91, .external_lex_state = 3},
  [3710] = {.lex_state = 169, .external_lex_state = 3},
  [3711] = {.lex_state = 167, .external_lex_state = 3},
  [3712] = {.lex_state = 167, .external_lex_state = 3},
  [3713] = {.lex_state = 167, .external_lex_state = 3},
  [3714] = {.lex_state = 91, .external_lex_state = 3},
  [3715] = {.lex_state = 91, .external_lex_state = 3},
  [3716] = {.lex_state = 91, .external_lex_state = 3},
  [3717] = {.lex_state = 167, .external_lex_state = 3},
  [3718] = {.lex_state = 89, .external_lex_state = 3},
  [3719] = {.lex_state = 167, .external_lex_state = 3},
  [3720] = {.lex_state = 167, .external_lex_state = 3},
  [3721] = {.lex_state = 96, .external_lex_state = 3},
  [3722] = {.lex_state = 96, .external_lex_state = 3},
  [3723] = {.lex_state = 91, .external_lex_state = 3},
  [3724] = {.lex_state = 91, .external_lex_state = 3},
  [3725] = {.lex_state = 91, .external_lex_state = 3},
  [3726] = {.lex_state = 91, .external_lex_state = 3},
  [3727] = {.lex_state = 96, .external_lex_state = 3},
  [3728] = {.lex_state = 88, .external_lex_state = 3},
  [3729] = {.lex_state = 91, .external_lex_state = 3},
  [3730] = {.lex_state = 91, .external_lex_state = 3},
  [3731] = {.lex_state = 91, .external_lex_state = 3},
  [3732] = {.lex_state = 96, .external_lex_state = 3},
  [3733] = {.lex_state = 91, .external_lex_state = 3},
  [3734] = {.lex_state = 167, .external_lex_state = 3},
  [3735] = {.lex_state = 167, .external_lex_state = 3},
  [3736] = {.lex_state = 91, .external_lex_state = 3},
  [3737] = {.lex_state = 91, .external_lex_state = 3},
  [3738] = {.lex_state = 167, .external_lex_state = 3},
  [3739] = {.lex_state = 167, .external_lex_state = 3},
  [3740] = {.lex_state = 91, .external_lex_state = 3},
  [3741] = {.lex_state = 91, .external_lex_state = 3},
  [3742] = {.lex_state = 91, .external_lex_state = 3},
  [3743] = {.lex_state = 91, .external_lex_state = 3},
  [3744] = {.lex_state = 167, .external_lex_state = 3},
  [3745] = {.lex_state = 91, .external_lex_state = 3},
  [3746] = {.lex_state = 91, .external_lex_state = 3},
  [3747] = {.lex_state = 167, .external_lex_state = 3},
  [3748] = {.lex_state = 167, .external_lex_state = 3},
  [3749] = {.lex_state = 89, .external_lex_state = 3},
  [3750] = {.lex_state = 89, .external_lex_state = 3},
  [3751] = {.lex_state = 98, .external_lex_state = 3},
  [3752] = {.lex_state = 97, .external_lex_state = 3},
  [3753] = {.lex_state = 98, .external_lex_state = 3},
  [3754] = {.lex_state = 97, .external_lex_state = 3},
  [3755] = {.lex_state = 97, .external_lex_state = 3},
  [3756] = {.lex_state = 28, .external_lex_state = 3},
  [3757] = {.lex_state = 97, .external_lex_state = 3},
  [3758] = {.lex_state = 89, .external_lex_state = 3},
  [3759] = {.lex_state = 97, .external_lex_state = 3},
  [3760] = {.lex_state = 97, .external_lex_state = 3},
  [3761] = {.lex_state = 28, .external_lex_state = 3},
  [3762] = {.lex_state = 89, .external_lex_state = 3},
  [3763] = {.lex_state = 97, .external_lex_state = 3},
  [3764] = {.lex_state = 97, .external_lex_state = 3},
  [3765] = {.lex_state = 97, .external_lex_state = 3},
  [3766] = {.lex_state = 28, .external_lex_state = 3},
  [3767] = {.lex_state = 97, .external_lex_state = 3},
  [3768] = {.lex_state = 97, .external_lex_state = 3},
  [3769] = {.lex_state = 97, .external_lex_state = 3},
  [3770] = {.lex_state = 28, .external_lex_state = 3},
  [3771] = {.lex_state = 28, .external_lex_state = 3},
  [3772] = {.lex_state = 97, .external_lex_state = 3},
  [3773] = {.lex_state = 97, .external_lex_state = 3},
  [3774] = {.lex_state = 97, .external_lex_state = 3},
  [3775] = {.lex_state = 97, .external_lex_state = 3},
  [3776] = {.lex_state = 97, .external_lex_state = 3},
  [3777] = {.lex_state = 97, .external_lex_state = 3},
  [3778] = {.lex_state = 97, .external_lex_state = 3},
  [3779] = {.lex_state = 97, .external_lex_state = 3},
  [3780] = {.lex_state = 89, .external_lex_state = 3},
  [3781] = {.lex_state = 97, .external_lex_state = 3},
  [3782] = {.lex_state = 89, .external_lex_state = 3},
  [3783] = {.lex_state = 89, .external_lex_state = 3},
  [3784] = {.lex_state = 97, .external_lex_state = 3},
  [3785] = {.lex_state = 97, .external_lex_state = 3},
  [3786] = {.lex_state = 97, .external_lex_state = 3},
  [3787] = {.lex_state = 89, .external_lex_state = 3},
  [3788] = {.lex_state = 97, .external_lex_state = 3},
  [3789] = {.lex_state = 97, .external_lex_state = 3},
  [3790] = {.lex_state = 28, .external_lex_state = 3},
  [3791] = {.lex_state = 97, .external_lex_state = 3},
  [3792] = {.lex_state = 28, .external_lex_state = 3},
  [3793] = {.lex_state = 28, .external_lex_state = 3},
  [3794] = {.lex_state = 28, .external_lex_state = 3},
  [3795] = {.lex_state = 28, .external_lex_state = 3},
  [3796] = {.lex_state = 97, .external_lex_state = 3},
  [3797] = {.lex_state = 97, .external_lex_state = 3},
  [3798] = {.lex_state = 98, .external_lex_state = 3},
  [3799] = {.lex_state = 97, .external_lex_state = 3},
  [3800] = {.lex_state = 28, .external_lex_state = 3},
  [3801] = {.lex_state = 97, .external_lex_state = 3},
  [3802] = {.lex_state = 28, .external_lex_state = 3},
  [3803] = {.lex_state = 28, .external_lex_state = 3},
  [3804] = {.lex_state = 97, .external_lex_state = 3},
  [3805] = {.lex_state = 98, .external_lex_state = 3},
  [3806] = {.lex_state = 97, .external_lex_state = 3},
  [3807] = {.lex_state = 28, .external_lex_state = 3},
  [3808] = {.lex_state = 89, .external_lex_state = 3},
  [3809] = {.lex_state = 28, .external_lex_state = 3},
  [3810] = {.lex_state = 97, .external_lex_state = 3},
  [3811] = {.lex_state = 28, .external_lex_state = 3},
  [3812] = {.lex_state = 89, .external_lex_state = 3},
  [3813] = {.lex_state = 28, .external_lex_state = 3},
  [3814] = {.lex_state = 28, .external_lex_state = 3},
  [3815] = {.lex_state = 97, .external_lex_state = 3},
  [3816] = {.lex_state = 28, .external_lex_state = 3},
  [3817] = {.lex_state = 93, .external_lex_state = 3},
  [3818] = {.lex_state = 28, .external_lex_state = 3},
  [3819] = {.lex_state = 97, .external_lex_state = 3},
  [3820] = {.lex_state = 89, .external_lex_state = 3},
  [3821] = {.lex_state = 89, .external_lex_state = 3},
  [3822] = {.lex_state = 89, .external_lex_state = 3},
  [3823] = {.lex_state = 93, .external_lex_state = 3},
  [3824] = {.lex_state = 97, .external_lex_state = 3},
  [3825] = {.lex_state = 97, .external_lex_state = 3},
  [3826] = {.lex_state = 89, .external_lex_state = 3},
  [3827] = {.lex_state = 78, .external_lex_state = 3},
  [3828] = {.lex_state = 97, .external_lex_state = 3},
  [3829] = {.lex_state = 98, .external_lex_state = 3},
  [3830] = {.lex_state = 97, .external_lex_state = 3},
  [3831] = {.lex_state = 28, .external_lex_state = 3},
  [3832] = {.lex_state = 89, .external_lex_state = 3},
  [3833] = {.lex_state = 98, .external_lex_state = 3},
  [3834] = {.lex_state = 98, .external_lex_state = 3},
  [3835] = {.lex_state = 28, .external_lex_state = 3},
  [3836] = {.lex_state = 28, .external_lex_state = 3},
  [3837] = {.lex_state = 28, .external_lex_state = 3},
  [3838] = {.lex_state = 97, .external_lex_state = 3},
  [3839] = {.lex_state = 89, .external_lex_state = 3},
  [3840] = {.lex_state = 97, .external_lex_state = 3},
  [3841] = {.lex_state = 97, .external_lex_state = 3},
  [3842] = {.lex_state = 97, .external_lex_state = 3},
  [3843] = {.lex_state = 97, .external_lex_state = 3},
  [3844] = {.lex_state = 28, .external_lex_state = 3},
  [3845] = {.lex_state = 74, .external_lex_state = 3},
  [3846] = {.lex_state = 89, .external_lex_state = 3},
  [3847] = {.lex_state = 89, .external_lex_state = 3},
  [3848] = {.lex_state = 28, .external_lex_state = 3},
  [3849] = {.lex_state = 89, .external_lex_state = 3},
  [3850] = {.lex_state = 28, .external_lex_state = 3},
  [3851] = {.lex_state = 28, .external_lex_state = 3},
  [3852] = {.lex_state = 28, .external_lex_state = 3},
  [3853] = {.lex_state = 28, .external_lex_state = 3},
  [3854] = {.lex_state = 89, .external_lex_state = 3},
  [3855] = {.lex_state = 89, .external_lex_state = 3},
  [3856] = {.lex_state = 89, .external_lex_state = 3},
  [3857] = {.lex_state = 89, .external_lex_state = 3},
  [3858] = {.lex_state = 89, .external_lex_state = 3},
  [3859] = {.lex_state = 89, .external_lex_state = 3},
  [3860] = {.lex_state = 28, .external_lex_state = 3},
  [3861] = {.lex_state = 93, .external_lex_state = 3},
  [3862] = {.lex_state = 93, .external_lex_state = 3},
  [3863] = {.lex_state = 89, .external_lex_state = 3},
  [3864] = {.lex_state = 89, .external_lex_state = 3},
  [3865] = {.lex_state = 89, .external_lex_state = 3},
  [3866] = {.lex_state = 93, .external_lex_state = 3},
  [3867] = {.lex_state = 89, .external_lex_state = 3},
  [3868] = {.lex_state = 89, .external_lex_state = 3},
  [3869] = {.lex_state = 28, .external_lex_state = 3},
  [3870] = {.lex_state = 89, .external_lex_state = 3},
  [3871] = {.lex_state = 97, .external_lex_state = 3},
  [3872] = {.lex_state = 97, .external_lex_state = 3},
  [3873] = {.lex_state = 97, .external_lex_state = 3},
  [3874] = {.lex_state = 97, .external_lex_state = 3},
  [3875] = {.lex_state = 97, .external_lex_state = 3},
  [3876] = {.lex_state = 89, .external_lex_state = 3},
  [3877] = {.lex_state = 89, .external_lex_state = 3},
  [3878] = {.lex_state = 89, .external_lex_state = 3},
  [3879] = {.lex_state = 89, .external_lex_state = 3},
  [3880] = {.lex_state = 89, .external_lex_state = 3},
  [3881] = {.lex_state = 89, .external_lex_state = 3},
  [3882] = {.lex_state = 93, .external_lex_state = 3},
  [3883] = {.lex_state = 93, .external_lex_state = 3},
  [3884] = {.lex_state = 97, .external_lex_state = 3},
  [3885] = {.lex_state = 93, .external_lex_state = 3},
  [3886] = {.lex_state = 89, .external_lex_state = 3},
  [3887] = {.lex_state = 89, .external_lex_state = 3},
  [3888] = {.lex_state = 89, .external_lex_state = 3},
  [3889] = {.lex_state = 89, .external_lex_state = 3},
  [3890] = {.lex_state = 97, .external_lex_state = 3},
  [3891] = {.lex_state = 89, .external_lex_state = 3},
  [3892] = {.lex_state = 97, .external_lex_state = 3},
  [3893] = {.lex_state = 89, .external_lex_state = 3},
  [3894] = {.lex_state = 97, .external_lex_state = 3},
  [3895] = {.lex_state = 28, .external_lex_state = 3},
  [3896] = {.lex_state = 28, .external_lex_state = 3},
  [3897] = {.lex_state = 97, .external_lex_state = 3},
  [3898] = {.lex_state = 97, .external_lex_state = 3},
  [3899] = {.lex_state = 97, .external_lex_state = 3},
  [3900] = {.lex_state = 28, .external_lex_state = 3},
  [3901] = {.lex_state = 97, .external_lex_state = 3},
  [3902] = {.lex_state = 28, .external_lex_state = 3},
  [3903] = {.lex_state = 97, .external_lex_state = 3},
  [3904] = {.lex_state = 97, .external_lex_state = 3},
  [3905] = {.lex_state = 97, .external_lex_state = 3},
  [3906] = {.lex_state = 89, .external_lex_state = 3},
  [3907] = {.lex_state = 97, .external_lex_state = 3},
  [3908] = {.lex_state = 98, .external_lex_state = 3},
  [3909] = {.lex_state = 98, .external_lex_state = 3},
  [3910] = {.lex_state = 93, .external_lex_state = 3},
  [3911] = {.lex_state = 28, .external_lex_state = 3},
  [3912] = {.lex_state = 97, .external_lex_state = 3},
  [3913] = {.lex_state = 89, .external_lex_state = 3},
  [3914] = {.lex_state = 28, .external_lex_state = 3},
  [3915] = {.lex_state = 28, .external_lex_state = 3},
  [3916] = {.lex_state = 89, .external_lex_state = 3},
  [3917] = {.lex_state = 28, .external_lex_state = 3},
  [3918] = {.lex_state = 28, .external_lex_state = 3},
  [3919] = {.lex_state = 28, .external_lex_state = 3},
  [3920] = {.lex_state = 89, .external_lex_state = 3},
  [3921] = {.lex_state = 89, .external_lex_state = 3},
  [3922] = {.lex_state = 89, .external_lex_state = 3},
  [3923] = {.lex_state = 28, .external_lex_state = 3},
  [3924] = {.lex_state = 97, .external_lex_state = 3},
  [3925] = {.lex_state = 28, .external_lex_state = 3},
  [3926] = {.lex_state = 97, .external_lex_state = 3},
  [3927] = {.lex_state = 89, .external_lex_state = 3},
  [3928] = {.lex_state = 93, .external_lex_state = 3},
  [3929] = {.lex_state = 93, .external_lex_state = 3},
  [3930] = {.lex_state = 97, .external_lex_state = 3},
  [3931] = {.lex_state = 89, .external_lex_state = 3},
  [3932] = {.lex_state = 28, .external_lex_state = 3},
  [3933] = {.lex_state = 28, .external_lex_state = 3},
  [3934] = {.lex_state = 28, .external_lex_state = 3},
  [3935] = {.lex_state = 89, .external_lex_state = 3},
  [3936] = {.lex_state = 97, .external_lex_state = 3},
  [3937] = {.lex_state = 97, .external_lex_state = 3},
  [3938] = {.lex_state = 89, .external_lex_state = 3},
  [3939] = {.lex_state = 28, .external_lex_state = 3},
  [3940] = {.lex_state = 89, .external_lex_state = 3},
  [3941] = {.lex_state = 28, .external_lex_state = 3},
  [3942] = {.lex_state = 28, .external_lex_state = 3},
  [3943] = {.lex_state = 89, .external_lex_state = 3},
  [3944] = {.lex_state = 97, .external_lex_state = 3},
  [3945] = {.lex_state = 89, .external_lex_state = 3},
  [3946] = {.lex_state = 89, .external_lex_state = 3},
  [3947] = {.lex_state = 89, .external_lex_state = 3},
  [3948] = {.lex_state = 97, .external_lex_state = 3},
  [3949] = {.lex_state = 89, .external_lex_state = 3},
  [3950] = {.lex_state = 89, .external_lex_state = 3},
  [3951] = {.lex_state = 89, .external_lex_state = 3},
  [3952] = {.lex_state = 89, .external_lex_state = 3},
  [3953] = {.lex_state = 89, .external_lex_state = 3},
  [3954] = {.lex_state = 28, .external_lex_state = 3},
  [3955] = {.lex_state = 89, .external_lex_state = 3},
  [3956] = {.lex_state = 28, .external_lex_state = 3},
  [3957] = {.lex_state = 89, .external_lex_state = 3},
  [3958] = {.lex_state = 89, .external_lex_state = 3},
  [3959] = {.lex_state = 89, .external_lex_state = 3},
  [3960] = {.lex_state = 98, .external_lex_state = 3},
  [3961] = {.lex_state = 89, .external_lex_state = 3},
  [3962] = {.lex_state = 89, .external_lex_state = 3},
  [3963] = {.lex_state = 89, .external_lex_state = 3},
  [3964] = {.lex_state = 97, .external_lex_state = 3},
  [3965] = {.lex_state = 89, .external_lex_state = 3},
  [3966] = {.lex_state = 28, .external_lex_state = 3},
  [3967] = {.lex_state = 98, .external_lex_state = 3},
  [3968] = {.lex_state = 97, .external_lex_state = 3},
  [3969] = {.lex_state = 89, .external_lex_state = 3},
  [3970] = {.lex_state = 92, .external_lex_state = 3},
  [3971] = {.lex_state = 93, .external_lex_state = 3},
  [3972] = {.lex_state = 98, .external_lex_state = 3},
  [3973] = {.lex_state = 93, .external_lex_state = 3},
  [3974] = {.lex_state = 28, .external_lex_state = 3},
  [3975] = {.lex_state = 72, .external_lex_state = 3},
  [3976] = {.lex_state = 28, .external_lex_state = 3},
  [3977] = {.lex_state = 98, .external_lex_state = 3},
  [3978] = {.lex_state = 92, .external_lex_state = 3},
  [3979] = {.lex_state = 98, .external_lex_state = 3},
  [3980] = {.lex_state = 93, .external_lex_state = 3},
  [3981] = {.lex_state = 98, .external_lex_state = 3},
  [3982] = {.lex_state = 98, .external_lex_state = 3},
  [3983] = {.lex_state = 28, .external_lex_state = 3},
  [3984] = {.lex_state = 98, .external_lex_state = 3},
  [3985] = {.lex_state = 28, .external_lex_state = 3},
  [3986] = {.lex_state = 98, .external_lex_state = 3},
  [3987] = {.lex_state = 98, .external_lex_state = 3},
  [3988] = {.lex_state = 93, .external_lex_state = 3},
  [3989] = {.lex_state = 98, .external_lex_state = 3},
  [3990] = {.lex_state = 98, .external_lex_state = 3},
  [3991] = {.lex_state = 28, .external_lex_state = 3},
  [3992] = {.lex_state = 93, .external_lex_state = 3},
  [3993] = {.lex_state = 93, .external_lex_state = 3},
  [3994] = {.lex_state = 98, .external_lex_state = 3},
  [3995] = {.lex_state = 98, .external_lex_state = 3},
  [3996] = {.lex_state = 99, .external_lex_state = 3},
  [3997] = {.lex_state = 98, .external_lex_state = 3},
  [3998] = {.lex_state = 98, .external_lex_state = 3},
  [3999] = {.lex_state = 98, .external_lex_state = 3},
  [4000] = {.lex_state = 98, .external_lex_state = 3},
  [4001] = {.lex_state = 92, .external_lex_state = 3},
  [4002] = {.lex_state = 98, .external_lex_state = 3},
  [4003] = {.lex_state = 93, .external_lex_state = 3},
  [4004] = {.lex_state = 28, .external_lex_state = 3},
  [4005] = {.lex_state = 92, .external_lex_state = 3},
  [4006] = {.lex_state = 93, .external_lex_state = 3},
  [4007] = {.lex_state = 93, .external_lex_state = 3},
  [4008] = {.lex_state = 99, .external_lex_state = 3},
  [4009] = {.lex_state = 92, .external_lex_state = 3},
  [4010] = {.lex_state = 98, .external_lex_state = 3},
  [4011] = {.lex_state = 28, .external_lex_state = 3},
  [4012] = {.lex_state = 28, .external_lex_state = 3},
  [4013] = {.lex_state = 98, .external_lex_state = 3},
  [4014] = {.lex_state = 93, .external_lex_state = 3},
  [4015] = {.lex_state = 98, .external_lex_state = 3},
  [4016] = {.lex_state = 92, .external_lex_state = 3},
  [4017] = {.lex_state = 28, .external_lex_state = 3},
  [4018] = {.lex_state = 98, .external_lex_state = 3},
  [4019] = {.lex_state = 98, .external_lex_state = 3},
  [4020] = {.lex_state = 93, .external_lex_state = 3},
  [4021] = {.lex_state = 28, .external_lex_state = 3},
  [4022] = {.lex_state = 93, .external_lex_state = 3},
  [4023] = {.lex_state = 28, .external_lex_state = 3},
  [4024] = {.lex_state = 93, .external_lex_state = 3},
  [4025] = {.lex_state = 92, .external_lex_state = 3},
  [4026] = {.lex_state = 93, .external_lex_state = 3},
  [4027] = {.lex_state = 98, .external_lex_state = 3},
  [4028] = {.lex_state = 28, .external_lex_state = 3},
  [4029] = {.lex_state = 98, .external_lex_state = 3},
  [4030] = {.lex_state = 28, .external_lex_state = 3},
  [4031] = {.lex_state = 98, .external_lex_state = 3},
  [4032] = {.lex_state = 93, .external_lex_state = 3},
  [4033] = {.lex_state = 93, .external_lex_state = 3},
  [4034] = {.lex_state = 28, .external_lex_state = 3},
  [4035] = {.lex_state = 98, .external_lex_state = 3},
  [4036] = {.lex_state = 99, .external_lex_state = 3},
  [4037] = {.lex_state = 28, .external_lex_state = 3},
  [4038] = {.lex_state = 98, .external_lex_state = 3},
  [4039] = {.lex_state = 28, .external_lex_state = 3},
  [4040] = {.lex_state = 98, .external_lex_state = 3},
  [4041] = {.lex_state = 93, .external_lex_state = 3},
  [4042] = {.lex_state = 78, .external_lex_state = 3},
  [4043] = {.lex_state = 98, .external_lex_state = 3},
  [4044] = {.lex_state = 98, .external_lex_state = 3},
  [4045] = {.lex_state = 93, .external_lex_state = 3},
  [4046] = {.lex_state = 99, .external_lex_state = 3},
  [4047] = {.lex_state = 93, .external_lex_state = 3},
  [4048] = {.lex_state = 98, .external_lex_state = 3},
  [4049] = {.lex_state = 28, .external_lex_state = 3},
  [4050] = {.lex_state = 28, .external_lex_state = 3},
  [4051] = {.lex_state = 93, .external_lex_state = 3},
  [4052] = {.lex_state = 74, .external_lex_state = 3},
  [4053] = {.lex_state = 98, .external_lex_state = 3},
  [4054] = {.lex_state = 93, .external_lex_state = 3},
  [4055] = {.lex_state = 93, .external_lex_state = 3},
  [4056] = {.lex_state = 93, .external_lex_state = 3},
  [4057] = {.lex_state = 28, .external_lex_state = 3},
  [4058] = {.lex_state = 98, .external_lex_state = 3},
  [4059] = {.lex_state = 93, .external_lex_state = 3},
  [4060] = {.lex_state = 28, .external_lex_state = 3},
  [4061] = {.lex_state = 93, .external_lex_state = 3},
  [4062] = {.lex_state = 93, .external_lex_state = 3},
  [4063] = {.lex_state = 98, .external_lex_state = 3},
  [4064] = {.lex_state = 98, .external_lex_state = 3},
  [4065] = {.lex_state = 28, .external_lex_state = 3},
  [4066] = {.lex_state = 78, .external_lex_state = 3},
  [4067] = {.lex_state = 98, .external_lex_state = 3},
  [4068] = {.lex_state = 28, .external_lex_state = 3},
  [4069] = {.lex_state = 28, .external_lex_state = 3},
  [4070] = {.lex_state = 98, .external_lex_state = 3},
  [4071] = {.lex_state = 99, .external_lex_state = 3},
  [4072] = {.lex_state = 79, .external_lex_state = 3},
  [4073] = {.lex_state = 28, .external_lex_state = 3},
  [4074] = {.lex_state = 28, .external_lex_state = 3},
  [4075] = {.lex_state = 98, .external_lex_state = 3},
  [4076] = {.lex_state = 98, .external_lex_state = 3},
  [4077] = {.lex_state = 98, .external_lex_state = 3},
  [4078] = {.lex_state = 98, .external_lex_state = 3},
  [4079] = {.lex_state = 80, .external_lex_state = 3},
  [4080] = {.lex_state = 98, .external_lex_state = 3},
  [4081] = {.lex_state = 98, .external_lex_state = 3},
  [4082] = {.lex_state = 28, .external_lex_state = 3},
  [4083] = {.lex_state = 28, .external_lex_state = 3},
  [4084] = {.lex_state = 98, .external_lex_state = 3},
  [4085] = {.lex_state = 98, .external_lex_state = 3},
  [4086] = {.lex_state = 28, .external_lex_state = 3},
  [4087] = {.lex_state = 98, .external_lex_state = 3},
  [4088] = {.lex_state = 93, .external_lex_state = 3},
  [4089] = {.lex_state = 28, .external_lex_state = 3},
  [4090] = {.lex_state = 28, .external_lex_state = 3},
  [4091] = {.lex_state = 93, .external_lex_state = 3},
  [4092] = {.lex_state = 93, .external_lex_state = 3},
  [4093] = {.lex_state = 99, .external_lex_state = 3},
  [4094] = {.lex_state = 93, .external_lex_state = 3},
  [4095] = {.lex_state = 28, .external_lex_state = 3},
  [4096] = {.lex_state = 98, .external_lex_state = 3},
  [4097] = {.lex_state = 98, .external_lex_state = 3},
  [4098] = {.lex_state = 98, .external_lex_state = 3},
  [4099] = {.lex_state = 93, .external_lex_state = 3},
  [4100] = {.lex_state = 93, .external_lex_state = 3},
  [4101] = {.lex_state = 28, .external_lex_state = 3},
  [4102] = {.lex_state = 98, .external_lex_state = 3},
  [4103] = {.lex_state = 98, .external_lex_state = 3},
  [4104] = {.lex_state = 93, .external_lex_state = 3},
  [4105] = {.lex_state = 28, .external_lex_state = 3},
  [4106] = {.lex_state = 28, .external_lex_state = 3},
  [4107] = {.lex_state = 98, .external_lex_state = 3},
  [4108] = {.lex_state = 92, .external_lex_state = 3},
  [4109] = {.lex_state = 28, .external_lex_state = 3},
  [4110] = {.lex_state = 93, .external_lex_state = 3},
  [4111] = {.lex_state = 93, .external_lex_state = 3},
  [4112] = {.lex_state = 93, .external_lex_state = 3},
  [4113] = {.lex_state = 93, .external_lex_state = 3},
  [4114] = {.lex_state = 98, .external_lex_state = 3},
  [4115] = {.lex_state = 98, .external_lex_state = 3},
  [4116] = {.lex_state = 98, .external_lex_state = 3},
  [4117] = {.lex_state = 98, .external_lex_state = 3},
  [4118] = {.lex_state = 98, .external_lex_state = 3},
  [4119] = {.lex_state = 93, .external_lex_state = 3},
  [4120] = {.lex_state = 93, .external_lex_state = 3},
  [4121] = {.lex_state = 99, .external_lex_state = 3},
  [4122] = {.lex_state = 93, .external_lex_state = 3},
  [4123] = {.lex_state = 93, .external_lex_state = 3},
  [4124] = {.lex_state = 28, .external_lex_state = 3},
  [4125] = {.lex_state = 99, .external_lex_state = 3},
  [4126] = {.lex_state = 28, .external_lex_state = 3},
  [4127] = {.lex_state = 93, .external_lex_state = 3},
  [4128] = {.lex_state = 98, .external_lex_state = 3},
  [4129] = {.lex_state = 99, .external_lex_state = 3},
  [4130] = {.lex_state = 98, .external_lex_state = 3},
  [4131] = {.lex_state = 28, .external_lex_state = 3},
  [4132] = {.lex_state = 98, .external_lex_state = 3},
  [4133] = {.lex_state = 93, .external_lex_state = 3},
  [4134] = {.lex_state = 98, .external_lex_state = 3},
  [4135] = {.lex_state = 28, .external_lex_state = 3},
  [4136] = {.lex_state = 93, .external_lex_state = 3},
  [4137] = {.lex_state = 92, .external_lex_state = 3},
  [4138] = {.lex_state = 98, .external_lex_state = 3},
  [4139] = {.lex_state = 93, .external_lex_state = 3},
  [4140] = {.lex_state = 93, .external_lex_state = 3},
  [4141] = {.lex_state = 93, .external_lex_state = 3},
  [4142] = {.lex_state = 93, .external_lex_state = 3},
  [4143] = {.lex_state = 98, .external_lex_state = 3},
  [4144] = {.lex_state = 93, .external_lex_state = 3},
  [4145] = {.lex_state = 93, .external_lex_state = 3},
  [4146] = {.lex_state = 28, .external_lex_state = 3},
  [4147] = {.lex_state = 74, .external_lex_state = 3},
  [4148] = {.lex_state = 75, .external_lex_state = 3},
  [4149] = {.lex_state = 28, .external_lex_state = 3},
  [4150] = {.lex_state = 99, .external_lex_state = 3},
  [4151] = {.lex_state = 98, .external_lex_state = 3},
  [4152] = {.lex_state = 93, .external_lex_state = 3},
  [4153] = {.lex_state = 93, .external_lex_state = 3},
  [4154] = {.lex_state = 93, .external_lex_state = 3},
  [4155] = {.lex_state = 93, .external_lex_state = 3},
  [4156] = {.lex_state = 93, .external_lex_state = 3},
  [4157] = {.lex_state = 28, .external_lex_state = 3},
  [4158] = {.lex_state = 93, .external_lex_state = 3},
  [4159] = {.lex_state = 98, .external_lex_state = 3},
  [4160] = {.lex_state = 93, .external_lex_state = 3},
  [4161] = {.lex_state = 98, .external_lex_state = 3},
  [4162] = {.lex_state = 93, .external_lex_state = 3},
  [4163] = {.lex_state = 92, .external_lex_state = 3},
  [4164] = {.lex_state = 98, .external_lex_state = 3},
  [4165] = {.lex_state = 93, .external_lex_state = 3},
  [4166] = {.lex_state = 98, .external_lex_state = 3},
  [4167] = {.lex_state = 93, .external_lex_state = 3},
  [4168] = {.lex_state = 93, .external_lex_state = 3},
  [4169] = {.lex_state = 92, .external_lex_state = 3},
  [4170] = {.lex_state = 28, .external_lex_state = 3},
  [4171] = {.lex_state = 98, .external_lex_state = 3},
  [4172] = {.lex_state = 93, .external_lex_state = 3},
  [4173] = {.lex_state = 93, .external_lex_state = 3},
  [4174] = {.lex_state = 98, .external_lex_state = 3},
  [4175] = {.lex_state = 93, .external_lex_state = 3},
  [4176] = {.lex_state = 28, .external_lex_state = 3},
  [4177] = {.lex_state = 98, .external_lex_state = 3},
  [4178] = {.lex_state = 93, .external_lex_state = 3},
  [4179] = {.lex_state = 93, .external_lex_state = 3},
  [4180] = {.lex_state = 93, .external_lex_state = 3},
  [4181] = {.lex_state = 28, .external_lex_state = 3},
  [4182] = {.lex_state = 28, .external_lex_state = 3},
  [4183] = {.lex_state = 99, .external_lex_state = 3},
  [4184] = {.lex_state = 93, .external_lex_state = 3},
  [4185] = {.lex_state = 93, .external_lex_state = 3},
  [4186] = {.lex_state = 93, .external_lex_state = 3},
  [4187] = {.lex_state = 93, .external_lex_state = 3},
  [4188] = {.lex_state = 98, .external_lex_state = 3},
  [4189] = {.lex_state = 93, .external_lex_state = 3},
  [4190] = {.lex_state = 28, .external_lex_state = 3},
  [4191] = {.lex_state = 28, .external_lex_state = 3},
  [4192] = {.lex_state = 99, .external_lex_state = 3},
  [4193] = {.lex_state = 28, .external_lex_state = 3},
  [4194] = {.lex_state = 92, .external_lex_state = 3},
  [4195] = {.lex_state = 92, .external_lex_state = 3},
  [4196] = {.lex_state = 92, .external_lex_state = 3},
  [4197] = {.lex_state = 92, .external_lex_state = 3},
  [4198] = {.lex_state = 73, .external_lex_state = 3},
  [4199] = {.lex_state = 92, .external_lex_state = 3},
  [4200] = {.lex_state = 28, .external_lex_state = 3},
  [4201] = {.lex_state = 28, .external_lex_state = 3},
  [4202] = {.lex_state = 28, .external_lex_state = 3},
  [4203] = {.lex_state = 28, .external_lex_state = 3},
  [4204] = {.lex_state = 28, .external_lex_state = 3},
  [4205] = {.lex_state = 28, .external_lex_state = 3},
  [4206] = {.lex_state = 92, .external_lex_state = 3},
  [4207] = {.lex_state = 28, .external_lex_state = 3},
  [4208] = {.lex_state = 79, .external_lex_state = 3},
  [4209] = {.lex_state = 92, .external_lex_state = 3},
  [4210] = {.lex_state = 99, .external_lex_state = 3},
  [4211] = {.lex_state = 28, .external_lex_state = 3},
  [4212] = {.lex_state = 28, .external_lex_state = 3},
  [4213] = {.lex_state = 28, .external_lex_state = 3},
  [4214] = {.lex_state = 28, .external_lex_state = 3},
  [4215] = {.lex_state = 99, .external_lex_state = 3},
  [4216] = {.lex_state = 92, .external_lex_state = 3},
  [4217] = {.lex_state = 28, .external_lex_state = 3},
  [4218] = {.lex_state = 92, .external_lex_state = 3},
  [4219] = {.lex_state = 99, .external_lex_state = 3},
  [4220] = {.lex_state = 75, .external_lex_state = 3},
  [4221] = {.lex_state = 99, .external_lex_state = 3},
  [4222] = {.lex_state = 99, .external_lex_state = 3},
  [4223] = {.lex_state = 99, .external_lex_state = 3},
  [4224] = {.lex_state = 92, .external_lex_state = 3},
  [4225] = {.lex_state = 92, .external_lex_state = 3},
  [4226] = {.lex_state = 92, .external_lex_state = 3},
  [4227] = {.lex_state = 92, .external_lex_state = 3},
  [4228] = {.lex_state = 92, .external_lex_state = 3},
  [4229] = {.lex_state = 28, .external_lex_state = 3},
  [4230] = {.lex_state = 99, .external_lex_state = 3},
  [4231] = {.lex_state = 92, .external_lex_state = 3},
  [4232] = {.lex_state = 28, .external_lex_state = 3},
  [4233] = {.lex_state = 28, .external_lex_state = 3},
  [4234] = {.lex_state = 28, .external_lex_state = 3},
  [4235] = {.lex_state = 28, .external_lex_state = 3},
  [4236] = {.lex_state = 28, .external_lex_state = 3},
  [4237] = {.lex_state = 28, .external_lex_state = 3},
  [4238] = {.lex_state = 28, .external_lex_state = 3},
  [4239] = {.lex_state = 99, .external_lex_state = 3},
  [4240] = {.lex_state = 28, .external_lex_state = 3},
  [4241] = {.lex_state = 92, .external_lex_state = 3},
  [4242] = {.lex_state = 28, .external_lex_state = 3},
  [4243] = {.lex_state = 28, .external_lex_state = 3},
  [4244] = {.lex_state = 28, .external_lex_state = 3},
  [4245] = {.lex_state = 99, .external_lex_state = 3},
  [4246] = {.lex_state = 99, .external_lex_state = 3},
  [4247] = {.lex_state = 80, .external_lex_state = 3},
  [4248] = {.lex_state = 92, .external_lex_state = 3},
  [4249] = {.lex_state = 99, .external_lex_state = 3},
  [4250] = {.lex_state = 99, .external_lex_state = 3},
  [4251] = {.lex_state = 92, .external_lex_state = 3},
  [4252] = {.lex_state = 79, .external_lex_state = 3},
  [4253] = {.lex_state = 28, .external_lex_state = 3},
  [4254] = {.lex_state = 92, .external_lex_state = 3},
  [4255] = {.lex_state = 99, .external_lex_state = 3},
  [4256] = {.lex_state = 28, .external_lex_state = 3},
  [4257] = {.lex_state = 92, .external_lex_state = 3},
  [4258] = {.lex_state = 99, .external_lex_state = 3},
  [4259] = {.lex_state = 99, .external_lex_state = 3},
  [4260] = {.lex_state = 92, .external_lex_state = 3},
  [4261] = {.lex_state = 99, .external_lex_state = 3},
  [4262] = {.lex_state = 28, .external_lex_state = 3},
  [4263] = {.lex_state = 92, .external_lex_state = 3},
  [4264] = {.lex_state = 28, .external_lex_state = 3},
  [4265] = {.lex_state = 28, .external_lex_state = 3},
  [4266] = {.lex_state = 28, .external_lex_state = 3},
  [4267] = {.lex_state = 92, .external_lex_state = 3},
  [4268] = {.lex_state = 28, .external_lex_state = 3},
  [4269] = {.lex_state = 99, .external_lex_state = 3},
  [4270] = {.lex_state = 99, .external_lex_state = 3},
  [4271] = {.lex_state = 28, .external_lex_state = 3},
  [4272] = {.lex_state = 28, .external_lex_state = 3},
  [4273] = {.lex_state = 28, .external_lex_state = 3},
  [4274] = {.lex_state = 99, .external_lex_state = 3},
  [4275] = {.lex_state = 99, .external_lex_state = 3},
  [4276] = {.lex_state = 99, .external_lex_state = 3},
  [4277] = {.lex_state = 99, .external_lex_state = 3},
  [4278] = {.lex_state = 99, .external_lex_state = 3},
  [4279] = {.lex_state = 99, .external_lex_state = 3},
  [4280] = {.lex_state = 80, .external_lex_state = 3},
  [4281] = {.lex_state = 92, .external_lex_state = 3},
  [4282] = {.lex_state = 99, .external_lex_state = 3},
  [4283] = {.lex_state = 28, .external_lex_state = 3},
  [4284] = {.lex_state = 99, .external_lex_state = 3},
  [4285] = {.lex_state = 92, .external_lex_state = 3},
  [4286] = {.lex_state = 99, .external_lex_state = 3},
  [4287] = {.lex_state = 99, .external_lex_state = 3},
  [4288] = {.lex_state = 28, .external_lex_state = 3},
  [4289] = {.lex_state = 28, .external_lex_state = 3},
  [4290] = {.lex_state = 28, .external_lex_state = 3},
  [4291] = {.lex_state = 28, .external_lex_state = 3},
  [4292] = {.lex_state = 28, .external_lex_state = 3},
  [4293] = {.lex_state = 28, .external_lex_state = 3},
  [4294] = {.lex_state = 99, .external_lex_state = 3},
  [4295] = {.lex_state = 92, .external_lex_state = 3},
  [4296] = {.lex_state = 28, .external_lex_state = 3},
  [4297] = {.lex_state = 92, .external_lex_state = 3},
  [4298] = {.lex_state = 28, .external_lex_state = 3},
  [4299] = {.lex_state = 28, .external_lex_state = 3},
  [4300] = {.lex_state = 81, .external_lex_state = 3},
  [4301] = {.lex_state = 28, .external_lex_state = 3},
  [4302] = {.lex_state = 92, .external_lex_state = 3},
  [4303] = {.lex_state = 99, .external_lex_state = 3},
  [4304] = {.lex_state = 99, .external_lex_state = 3},
  [4305] = {.lex_state = 99, .external_lex_state = 3},
  [4306] = {.lex_state = 28, .external_lex_state = 3},
  [4307] = {.lex_state = 28, .external_lex_state = 3},
  [4308] = {.lex_state = 28, .external_lex_state = 3},
  [4309] = {.lex_state = 92, .external_lex_state = 3},
  [4310] = {.lex_state = 28, .external_lex_state = 3},
  [4311] = {.lex_state = 28, .external_lex_state = 3},
  [4312] = {.lex_state = 28, .external_lex_state = 3},
  [4313] = {.lex_state = 92, .external_lex_state = 3},
  [4314] = {.lex_state = 28, .external_lex_state = 3},
  [4315] = {.lex_state = 92, .external_lex_state = 3},
  [4316] = {.lex_state = 28, .external_lex_state = 3},
  [4317] = {.lex_state = 99, .external_lex_state = 3},
  [4318] = {.lex_state = 28, .external_lex_state = 3},
  [4319] = {.lex_state = 92, .external_lex_state = 3},
  [4320] = {.lex_state = 92, .external_lex_state = 3},
  [4321] = {.lex_state = 28, .external_lex_state = 3},
  [4322] = {.lex_state = 28, .external_lex_state = 3},
  [4323] = {.lex_state = 92, .external_lex_state = 3},
  [4324] = {.lex_state = 99, .external_lex_state = 3},
  [4325] = {.lex_state = 99, .external_lex_state = 3},
  [4326] = {.lex_state = 92, .external_lex_state = 3},
  [4327] = {.lex_state = 28, .external_lex_state = 3},
  [4328] = {.lex_state = 28, .external_lex_state = 3},
  [4329] = {.lex_state = 99, .external_lex_state = 3},
  [4330] = {.lex_state = 28, .external_lex_state = 3},
  [4331] = {.lex_state = 92, .external_lex_state = 3},
  [4332] = {.lex_state = 28, .external_lex_state = 3},
  [4333] = {.lex_state = 28, .external_lex_state = 3},
  [4334] = {.lex_state = 28, .external_lex_state = 3},
  [4335] = {.lex_state = 99, .external_lex_state = 3},
  [4336] = {.lex_state = 92, .external_lex_state = 3},
  [4337] = {.lex_state = 92, .external_lex_state = 3},
  [4338] = {.lex_state = 28, .external_lex_state = 3},
  [4339] = {.lex_state = 28, .external_lex_state = 3},
  [4340] = {.lex_state = 99, .external_lex_state = 3},
  [4341] = {.lex_state = 92, .external_lex_state = 3},
  [4342] = {.lex_state = 92, .external_lex_state = 3},
  [4343] = {.lex_state = 99, .external_lex_state = 3},
  [4344] = {.lex_state = 28, .external_lex_state = 3},
  [4345] = {.lex_state = 92, .external_lex_state = 3},
  [4346] = {.lex_state = 99, .external_lex_state = 3},
  [4347] = {.lex_state = 99, .external_lex_state = 3},
  [4348] = {.lex_state = 28, .external_lex_state = 3},
  [4349] = {.lex_state = 92, .external_lex_state = 3},
  [4350] = {.lex_state = 99, .external_lex_state = 3},
  [4351] = {.lex_state = 92, .external_lex_state = 3},
  [4352] = {.lex_state = 92, .external_lex_state = 3},
  [4353] = {.lex_state = 92, .external_lex_state = 3},
  [4354] = {.lex_state = 28, .external_lex_state = 3},
  [4355] = {.lex_state = 28, .external_lex_state = 3},
  [4356] = {.lex_state = 99, .external_lex_state = 3},
  [4357] = {.lex_state = 99, .external_lex_state = 3},
  [4358] = {.lex_state = 28, .external_lex_state = 3},
  [4359] = {.lex_state = 28, .external_lex_state = 3},
  [4360] = {.lex_state = 92, .external_lex_state = 3},
  [4361] = {.lex_state = 28, .external_lex_state = 3},
  [4362] = {.lex_state = 28, .external_lex_state = 3},
  [4363] = {.lex_state = 28, .external_lex_state = 3},
  [4364] = {.lex_state = 28, .external_lex_state = 3},
  [4365] = {.lex_state = 92, .external_lex_state = 3},
  [4366] = {.lex_state = 99, .external_lex_state = 3},
  [4367] = {.lex_state = 28, .external_lex_state = 3},
  [4368] = {.lex_state = 28, .external_lex_state = 3},
  [4369] = {.lex_state = 28, .external_lex_state = 3},
  [4370] = {.lex_state = 92, .external_lex_state = 3},
  [4371] = {.lex_state = 99, .external_lex_state = 3},
  [4372] = {.lex_state = 28, .external_lex_state = 3},
  [4373] = {.lex_state = 92, .external_lex_state = 3},
  [4374] = {.lex_state = 92, .external_lex_state = 3},
  [4375] = {.lex_state = 28, .external_lex_state = 3},
  [4376] = {.lex_state = 99, .external_lex_state = 3},
  [4377] = {.lex_state = 99, .external_lex_state = 3},
  [4378] = {.lex_state = 28, .external_lex_state = 3},
  [4379] = {.lex_state = 28, .external_lex_state = 3},
  [4380] = {.lex_state = 72, .external_lex_state = 3},
  [4381] = {.lex_state = 28, .external_lex_state = 3},
  [4382] = {.lex_state = 99, .external_lex_state = 3},
  [4383] = {.lex_state = 92, .external_lex_state = 3},
  [4384] = {.lex_state = 28, .external_lex_state = 3},
  [4385] = {.lex_state = 28, .external_lex_state = 3},
  [4386] = {.lex_state = 28, .external_lex_state = 3},
  [4387] = {.lex_state = 28, .external_lex_state = 3},
  [4388] = {.lex_state = 28, .external_lex_state = 3},
  [4389] = {.lex_state = 28, .external_lex_state = 3},
  [4390] = {.lex_state = 28, .external_lex_state = 3},
  [4391] = {.lex_state = 99, .external_lex_state = 3},
  [4392] = {.lex_state = 28, .external_lex_state = 3},
  [4393] = {.lex_state = 28, .external_lex_state = 3},
  [4394] = {.lex_state = 28, .external_lex_state = 3},
  [4395] = {.lex_state = 28, .external_lex_state = 3},
  [4396] = {.lex_state = 99, .external_lex_state = 3},
  [4397] = {.lex_state = 28, .external_lex_state = 3},
  [4398] = {.lex_state = 28, .external_lex_state = 3},
  [4399] = {.lex_state = 28, .external_lex_state = 3},
  [4400] = {.lex_state = 28, .external_lex_state = 3},
  [4401] = {.lex_state = 92, .external_lex_state = 3},
  [4402] = {.lex_state = 28, .external_lex_state = 3},
  [4403] = {.lex_state = 92, .external_lex_state = 3},
  [4404] = {.lex_state = 99, .external_lex_state = 3},
  [4405] = {.lex_state = 28, .external_lex_state = 3},
  [4406] = {.lex_state = 28, .external_lex_state = 3},
  [4407] = {.lex_state = 28, .external_lex_state = 3},
  [4408] = {.lex_state = 28, .external_lex_state = 3},
  [4409] = {.lex_state = 99, .external_lex_state = 3},
  [4410] = {.lex_state = 99, .external_lex_state = 3},
  [4411] = {.lex_state = 92, .external_lex_state = 3},
  [4412] = {.lex_state = 28, .external_lex_state = 3},
  [4413] = {.lex_state = 99, .external_lex_state = 3},
  [4414] = {.lex_state = 28, .external_lex_state = 3},
  [4415] = {.lex_state = 28, .external_lex_state = 3},
  [4416] = {.lex_state = 28, .external_lex_state = 3},
  [4417] = {.lex_state = 92, .external_lex_state = 3},
  [4418] = {.lex_state = 28, .external_lex_state = 3},
  [4419] = {.lex_state = 92, .external_lex_state = 3},
  [4420] = {.lex_state = 92, .external_lex_state = 3},
  [4421] = {.lex_state = 28, .external_lex_state = 3},
  [4422] = {.lex_state = 99, .external_lex_state = 3},
  [4423] = {.lex_state = 75, .external_lex_state = 3},
  [4424] = {.lex_state = 28, .external_lex_state = 3},
  [4425] = {.lex_state = 92, .external_lex_state = 3},
  [4426] = {.lex_state = 28, .external_lex_state = 3},
  [4427] = {.lex_state = 92, .external_lex_state = 3},
  [4428] = {.lex_state = 28, .external_lex_state = 3},
  [4429] = {.lex_state = 99, .external_lex_state = 3},
  [4430] = {.lex_state = 28, .external_lex_state = 3},
  [4431] = {.lex_state = 28, .external_lex_state = 3},
  [4432] = {.lex_state = 92, .external_lex_state = 3},
  [4433] = {.lex_state = 28, .external_lex_state = 3},
  [4434] = {.lex_state = 28, .external_lex_state = 3},
  [4435] = {.lex_state = 92, .external_lex_state = 3},
  [4436] = {.lex_state = 28, .external_lex_state = 3},
  [4437] = {.lex_state = 28, .external_lex_state = 3},
  [4438] = {.lex_state = 28, .external_lex_state = 3},
  [4439] = {.lex_state = 72, .external_lex_state = 3},
  [4440] = {.lex_state = 28, .external_lex_state = 3},
  [4441] = {.lex_state = 99, .external_lex_state = 3},
  [4442] = {.lex_state = 99, .external_lex_state = 3},
  [4443] = {.lex_state = 99, .external_lex_state = 3},
  [4444] = {.lex_state = 28, .external_lex_state = 3},
  [4445] = {.lex_state = 28, .external_lex_state = 3},
  [4446] = {.lex_state = 28, .external_lex_state = 3},
  [4447] = {.lex_state = 99, .external_lex_state = 3},
  [4448] = {.lex_state = 99, .external_lex_state = 3},
  [4449] = {.lex_state = 28, .external_lex_state = 3},
  [4450] = {.lex_state = 28, .external_lex_state = 3},
  [4451] = {.lex_state = 92, .external_lex_state = 3},
  [4452] = {.lex_state = 92, .external_lex_state = 3},
  [4453] = {.lex_state = 99, .external_lex_state = 3},
  [4454] = {.lex_state = 92, .external_lex_state = 3},
  [4455] = {.lex_state = 92, .external_lex_state = 3},
  [4456] = {.lex_state = 28, .external_lex_state = 3},
  [4457] = {.lex_state = 28, .external_lex_state = 3},
  [4458] = {.lex_state = 99, .external_lex_state = 3},
  [4459] = {.lex_state = 28, .external_lex_state = 3},
  [4460] = {.lex_state = 28, .external_lex_state = 3},
  [4461] = {.lex_state = 99, .external_lex_state = 3},
  [4462] = {.lex_state = 28, .external_lex_state = 3},
  [4463] = {.lex_state = 28, .external_lex_state = 3},
  [4464] = {.lex_state = 99, .external_lex_state = 3},
  [4465] = {.lex_state = 99, .external_lex_state = 3},
  [4466] = {.lex_state = 92, .external_lex_state = 3},
  [4467] = {.lex_state = 28, .external_lex_state = 3},
  [4468] = {.lex_state = 92, .external_lex_state = 3},
  [4469] = {.lex_state = 92, .external_lex_state = 3},
  [4470] = {.lex_state = 99, .external_lex_state = 3},
  [4471] = {.lex_state = 92, .external_lex_state = 3},
  [4472] = {.lex_state = 99, .external_lex_state = 3},
  [4473] = {.lex_state = 28, .external_lex_state = 3},
  [4474] = {.lex_state = 99, .external_lex_state = 3},
  [4475] = {.lex_state = 92, .external_lex_state = 3},
  [4476] = {.lex_state = 28, .external_lex_state = 3},
  [4477] = {.lex_state = 28, .external_lex_state = 3},
  [4478] = {.lex_state = 92, .external_lex_state = 3},
  [4479] = {.lex_state = 28, .external_lex_state = 3},
  [4480] = {.lex_state = 99, .external_lex_state = 3},
  [4481] = {.lex_state = 28, .external_lex_state = 3},
  [4482] = {.lex_state = 92, .external_lex_state = 3},
  [4483] = {.lex_state = 28, .external_lex_state = 3},
  [4484] = {.lex_state = 28, .external_lex_state = 3},
  [4485] = {.lex_state = 28, .external_lex_state = 3},
  [4486] = {.lex_state = 28, .external_lex_state = 3},
  [4487] = {.lex_state = 81, .external_lex_state = 3},
  [4488] = {.lex_state = 28, .external_lex_state = 3},
  [4489] = {.lex_state = 28, .external_lex_state = 3},
  [4490] = {.lex_state = 28, .external_lex_state = 3},
  [4491] = {.lex_state = 28, .external_lex_state = 3},
  [4492] = {.lex_state = 28, .external_lex_state = 3},
  [4493] = {.lex_state = 28, .external_lex_state = 3},
  [4494] = {.lex_state = 28, .external_lex_state = 3},
  [4495] = {.lex_state = 28, .external_lex_state = 3},
  [4496] = {.lex_state = 28, .external_lex_state = 3},
  [4497] = {.lex_state = 28, .external_lex_state = 3},
  [4498] = {.lex_state = 28, .external_lex_state = 3},
  [4499] = {.lex_state = 28, .external_lex_state = 3},
  [4500] = {.lex_state = 28, .external_lex_state = 3},
  [4501] = {.lex_state = 28, .external_lex_state = 3},
  [4502] = {.lex_state = 28, .external_lex_state = 3},
  [4503] = {.lex_state = 28, .external_lex_state = 3},
  [4504] = {.lex_state = 28, .external_lex_state = 3},
  [4505] = {.lex_state = 28, .external_lex_state = 3},
  [4506] = {.lex_state = 81, .external_lex_state = 3},
  [4507] = {.lex_state = 77, .external_lex_state = 3},
  [4508] = {.lex_state = 28, .external_lex_state = 3},
  [4509] = {.lex_state = 28, .external_lex_state = 3},
  [4510] = {.lex_state = 28, .external_lex_state = 3},
  [4511] = {.lex_state = 28, .external_lex_state = 3},
  [4512] = {.lex_state = 28, .external_lex_state = 3},
  [4513] = {.lex_state = 28, .external_lex_state = 3},
  [4514] = {.lex_state = 28, .external_lex_state = 3},
  [4515] = {.lex_state = 28, .external_lex_state = 3},
  [4516] = {.lex_state = 28, .external_lex_state = 3},
  [4517] = {.lex_state = 28, .external_lex_state = 3},
  [4518] = {.lex_state = 28, .external_lex_state = 3},
  [4519] = {.lex_state = 28, .external_lex_state = 3},
  [4520] = {.lex_state = 28, .external_lex_state = 3},
  [4521] = {.lex_state = 28, .external_lex_state = 3},
  [4522] = {.lex_state = 28, .external_lex_state = 3},
  [4523] = {.lex_state = 28, .external_lex_state = 3},
  [4524] = {.lex_state = 28, .external_lex_state = 3},
  [4525] = {.lex_state = 28, .external_lex_state = 3},
  [4526] = {.lex_state = 28, .external_lex_state = 3},
  [4527] = {.lex_state = 28, .external_lex_state = 3},
  [4528] = {.lex_state = 28, .external_lex_state = 3},
  [4529] = {.lex_state = 28, .external_lex_state = 3},
  [4530] = {.lex_state = 28, .external_lex_state = 3},
  [4531] = {.lex_state = 82, .external_lex_state = 3},
  [4532] = {.lex_state = 28, .external_lex_state = 3},
  [4533] = {.lex_state = 28, .external_lex_state = 3},
  [4534] = {.lex_state = 28, .external_lex_state = 3},
  [4535] = {.lex_state = 28, .external_lex_state = 3},
  [4536] = {.lex_state = 28, .external_lex_state = 3},
  [4537] = {.lex_state = 28, .external_lex_state = 3},
  [4538] = {.lex_state = 28, .external_lex_state = 3},
  [4539] = {.lex_state = 28, .external_lex_state = 3},
  [4540] = {.lex_state = 28, .external_lex_state = 3},
  [4541] = {.lex_state = 28, .external_lex_state = 3},
  [4542] = {.lex_state = 73, .external_lex_state = 3},
  [4543] = {.lex_state = 28, .external_lex_state = 3},
  [4544] = {.lex_state = 28, .external_lex_state = 3},
  [4545] = {.lex_state = 28, .external_lex_state = 3},
  [4546] = {.lex_state = 73, .external_lex_state = 3},
  [4547] = {.lex_state = 28, .external_lex_state = 3},
  [4548] = {.lex_state = 28, .external_lex_state = 3},
  [4549] = {.lex_state = 28, .external_lex_state = 3},
  [4550] = {.lex_state = 28, .external_lex_state = 3},
  [4551] = {.lex_state = 28, .external_lex_state = 3},
  [4552] = {.lex_state = 28, .external_lex_state = 3},
  [4553] = {.lex_state = 6, .external_lex_state = 3},
  [4554] = {.lex_state = 77, .external_lex_state = 3},
  [4555] = {.lex_state = 6, .external_lex_state = 3},
  [4556] = {.lex_state = 28, .external_lex_state = 3},
  [4557] = {.lex_state = 28, .external_lex_state = 3},
  [4558] = {.lex_state = 28, .external_lex_state = 3},
  [4559] = {.lex_state = 28, .external_lex_state = 3},
  [4560] = {.lex_state = 76, .external_lex_state = 3},
  [4561] = {.lex_state = 28, .external_lex_state = 3},
  [4562] = {.lex_state = 6, .external_lex_state = 3},
  [4563] = {.lex_state = 28, .external_lex_state = 3},
  [4564] = {.lex_state = 6, .external_lex_state = 3},
  [4565] = {.lex_state = 28, .external_lex_state = 3},
  [4566] = {.lex_state = 28, .external_lex_state = 3},
  [4567] = {.lex_state = 28, .external_lex_state = 3},
  [4568] = {.lex_state = 28, .external_lex_state = 3},
  [4569] = {.lex_state = 28, .external_lex_state = 3},
  [4570] = {.lex_state = 6, .external_lex_state = 3},
  [4571] = {.lex_state = 28, .external_lex_state = 3},
  [4572] = {.lex_state = 28, .external_lex_state = 3},
  [4573] = {.lex_state = 6, .external_lex_state = 3},
  [4574] = {.lex_state = 6, .external_lex_state = 3},
  [4575] = {.lex_state = 77, .external_lex_state = 3},
  [4576] = {.lex_state = 28, .external_lex_state = 3},
  [4577] = {.lex_state = 28, .external_lex_state = 3},
  [4578] = {.lex_state = 6, .external_lex_state = 3},
  [4579] = {.lex_state = 28, .external_lex_state = 3},
  [4580] = {.lex_state = 28, .external_lex_state = 3},
  [4581] = {.lex_state = 28, .external_lex_state = 3},
  [4582] = {.lex_state = 6, .external_lex_state = 3},
  [4583] = {.lex_state = 6, .external_lex_state = 3},
  [4584] = {.lex_state = 28, .external_lex_state = 3},
  [4585] = {.lex_state = 28, .external_lex_state = 3},
  [4586] = {.lex_state = 6, .external_lex_state = 3},
  [4587] = {.lex_state = 28, .external_lex_state = 3},
  [4588] = {.lex_state = 28, .external_lex_state = 3},
  [4589] = {.lex_state = 28, .external_lex_state = 3},
  [4590] = {.lex_state = 6, .external_lex_state = 3},
  [4591] = {.lex_state = 28, .external_lex_state = 3},
  [4592] = {.lex_state = 28, .external_lex_state = 3},
  [4593] = {.lex_state = 6, .external_lex_state = 3},
  [4594] = {.lex_state = 28, .external_lex_state = 3},
  [4595] = {.lex_state = 28, .external_lex_state = 3},
  [4596] = {.lex_state = 28, .external_lex_state = 3},
  [4597] = {.lex_state = 28, .external_lex_state = 3},
  [4598] = {.lex_state = 6, .external_lex_state = 3},
  [4599] = {.lex_state = 28, .external_lex_state = 3},
  [4600] = {.lex_state = 6, .external_lex_state = 3},
  [4601] = {.lex_state = 28, .external_lex_state = 3},
  [4602] = {.lex_state = 82, .external_lex_state = 3},
  [4603] = {.lex_state = 6, .external_lex_state = 3},
  [4604] = {.lex_state = 6, .external_lex_state = 3},
  [4605] = {.lex_state = 28, .external_lex_state = 3},
  [4606] = {.lex_state = 6, .external_lex_state = 3},
  [4607] = {.lex_state = 28, .external_lex_state = 3},
  [4608] = {.lex_state = 6, .external_lex_state = 3},
  [4609] = {.lex_state = 28, .external_lex_state = 3},
  [4610] = {.lex_state = 28, .external_lex_state = 3},
  [4611] = {.lex_state = 6, .external_lex_state = 3},
  [4612] = {.lex_state = 28, .external_lex_state = 3},
  [4613] = {.lex_state = 82, .external_lex_state = 3},
  [4614] = {.lex_state = 28, .external_lex_state = 3},
  [4615] = {.lex_state = 28, .external_lex_state = 3},
  [4616] = {.lex_state = 6, .external_lex_state = 3},
  [4617] = {.lex_state = 83, .external_lex_state = 3},
  [4618] = {.lex_state = 28, .external_lex_state = 3},
  [4619] = {.lex_state = 28, .external_lex_state = 3},
  [4620] = {.lex_state = 28, .external_lex_state = 3},
  [4621] = {.lex_state = 6, .external_lex_state = 3},
  [4622] = {.lex_state = 28, .external_lex_state = 3},
  [4623] = {.lex_state = 28, .external_lex_state = 3},
  [4624] = {.lex_state = 28, .external_lex_state = 3},
  [4625] = {.lex_state = 28, .external_lex_state = 3},
  [4626] = {.lex_state = 28, .external_lex_state = 3},
  [4627] = {.lex_state = 28, .external_lex_state = 3},
  [4628] = {.lex_state = 28, .external_lex_state = 3},
  [4629] = {.lex_state = 6, .external_lex_state = 3},
  [4630] = {.lex_state = 28, .external_lex_state = 3},
  [4631] = {.lex_state = 28, .external_lex_state = 3},
  [4632] = {.lex_state = 28, .external_lex_state = 3},
  [4633] = {.lex_state = 28, .external_lex_state = 3},
  [4634] = {.lex_state = 28, .external_lex_state = 3},
  [4635] = {.lex_state = 28, .external_lex_state = 3},
  [4636] = {.lex_state = 28, .external_lex_state = 3},
  [4637] = {.lex_state = 28, .external_lex_state = 3},
  [4638] = {.lex_state = 83, .external_lex_state = 3},
  [4639] = {.lex_state = 28, .external_lex_state = 3},
  [4640] = {.lex_state = 83, .external_lex_state = 3},
  [4641] = {.lex_state = 28, .external_lex_state = 3},
  [4642] = {.lex_state = 28, .external_lex_state = 3},
  [4643] = {.lex_state = 28, .external_lex_state = 3},
  [4644] = {.lex_state = 28, .external_lex_state = 3},
  [4645] = {.lex_state = 28, .external_lex_state = 3},
  [4646] = {.lex_state = 6, .external_lex_state = 3},
  [4647] = {.lex_state = 28, .external_lex_state = 3},
  [4648] = {.lex_state = 28, .external_lex_state = 3},
  [4649] = {.lex_state = 76, .external_lex_state = 3},
  [4650] = {.lex_state = 6, .external_lex_state = 3},
  [4651] = {.lex_state = 6, .external_lex_state = 3},
  [4652] = {.lex_state = 28, .external_lex_state = 3},
  [4653] = {.lex_state = 28, .external_lex_state = 3},
  [4654] = {.lex_state = 28, .external_lex_state = 3},
  [4655] = {.lex_state = 28, .external_lex_state = 3},
  [4656] = {.lex_state = 6, .external_lex_state = 3},
  [4657] = {.lex_state = 28, .external_lex_state = 3},
  [4658] = {.lex_state = 76, .external_lex_state = 3},
  [4659] = {.lex_state = 28, .external_lex_state = 3},
  [4660] = {.lex_state = 28, .external_lex_state = 3},
  [4661] = {.lex_state = 28, .external_lex_state = 3},
  [4662] = {.lex_state = 28, .external_lex_state = 3},
  [4663] = {.lex_state = 28, .external_lex_state = 3},
  [4664] = {.lex_state = 28, .external_lex_state = 3},
  [4665] = {.lex_state = 28, .external_lex_state = 3},
  [4666] = {.lex_state = 28, .external_lex_state = 3},
  [4667] = {.lex_state = 6, .external_lex_state = 3},
  [4668] = {.lex_state = 6, .external_lex_state = 3},
  [4669] = {.lex_state = 6, .external_lex_state = 3},
  [4670] = {.lex_state = 6, .external_lex_state = 3},
  [4671] = {.lex_state = 6, .external_lex_state = 3},
  [4672] = {.lex_state = 6, .external_lex_state = 3},
  [4673] = {.lex_state = 6, .external_lex_state = 3},
  [4674] = {.lex_state = 6, .external_lex_state = 3},
  [4675] = {.lex_state = 6, .external_lex_state = 3},
  [4676] = {.lex_state = 6, .external_lex_state = 3},
  [4677] = {.lex_state = 6, .external_lex_state = 3},
  [4678] = {.lex_state = 6, .external_lex_state = 3},
  [4679] = {.lex_state = 6, .external_lex_state = 3},
  [4680] = {.lex_state = 6, .external_lex_state = 3},
  [4681] = {.lex_state = 116, .external_lex_state = 3},
  [4682] = {.lex_state = 6, .external_lex_state = 3},
  [4683] = {.lex_state = 116, .external_lex_state = 3},
  [4684] = {.lex_state = 6, .external_lex_state = 3},
  [4685] = {.lex_state = 6, .external_lex_state = 3},
  [4686] = {.lex_state = 6, .external_lex_state = 3},
  [4687] = {.lex_state = 6, .external_lex_state = 3},
  [4688] = {.lex_state = 6, .external_lex_state = 3},
  [4689] = {.lex_state = 116, .external_lex_state = 3},
  [4690] = {.lex_state = 116, .external_lex_state = 3},
  [4691] = {.lex_state = 6, .external_lex_state = 3},
  [4692] = {.lex_state = 116, .external_lex_state = 3},
  [4693] = {.lex_state = 6, .external_lex_state = 3},
  [4694] = {.lex_state = 6, .external_lex_state = 3},
  [4695] = {.lex_state = 6, .external_lex_state = 3},
  [4696] = {.lex_state = 6, .external_lex_state = 3},
  [4697] = {.lex_state = 6, .external_lex_state = 3},
  [4698] = {.lex_state = 116, .external_lex_state = 3},
  [4699] = {.lex_state = 6, .external_lex_state = 3},
  [4700] = {.lex_state = 6, .external_lex_state = 3},
  [4701] = {.lex_state = 6, .external_lex_state = 3},
  [4702] = {.lex_state = 6, .external_lex_state = 3},
  [4703] = {.lex_state = 116, .external_lex_state = 3},
  [4704] = {.lex_state = 6, .external_lex_state = 3},
  [4705] = {.lex_state = 6, .external_lex_state = 3},
  [4706] = {.lex_state = 6, .external_lex_state = 3},
  [4707] = {.lex_state = 6, .external_lex_state = 3},
  [4708] = {.lex_state = 116, .external_lex_state = 3},
  [4709] = {.lex_state = 18, .external_lex_state = 3},
  [4710] = {.lex_state = 6, .external_lex_state = 3},
  [4711] = {.lex_state = 6, .external_lex_state = 3},
  [4712] = {.lex_state = 6, .external_lex_state = 3},
  [4713] = {.lex_state = 6, .external_lex_state = 3},
  [4714] = {.lex_state = 6, .external_lex_state = 3},
  [4715] = {.lex_state = 6, .external_lex_state = 3},
  [4716] = {.lex_state = 6, .external_lex_state = 3},
  [4717] = {.lex_state = 6, .external_lex_state = 3},
  [4718] = {.lex_state = 6, .external_lex_state = 3},
  [4719] = {.lex_state = 6, .external_lex_state = 3},
  [4720] = {.lex_state = 6, .external_lex_state = 3},
  [4721] = {.lex_state = 116, .external_lex_state = 3},
  [4722] = {.lex_state = 6, .external_lex_state = 3},
  [4723] = {.lex_state = 6, .external_lex_state = 3},
  [4724] = {.lex_state = 6, .external_lex_state = 3},
  [4725] = {.lex_state = 6, .external_lex_state = 3},
  [4726] = {.lex_state = 6, .external_lex_state = 3},
  [4727] = {.lex_state = 18, .external_lex_state = 3},
  [4728] = {.lex_state = 6, .external_lex_state = 3},
  [4729] = {.lex_state = 6, .external_lex_state = 3},
  [4730] = {.lex_state = 6, .external_lex_state = 3},
  [4731] = {.lex_state = 6, .external_lex_state = 3},
  [4732] = {.lex_state = 6, .external_lex_state = 3},
  [4733] = {.lex_state = 6, .external_lex_state = 3},
  [4734] = {.lex_state = 6, .external_lex_state = 3},
  [4735] = {.lex_state = 6, .external_lex_state = 3},
  [4736] = {.lex_state = 6, .external_lex_state = 3},
  [4737] = {.lex_state = 6, .external_lex_state = 3},
  [4738] = {.lex_state = 6, .external_lex_state = 3},
  [4739] = {.lex_state = 6, .external_lex_state = 3},
  [4740] = {.lex_state = 6, .external_lex_state = 3},
  [4741] = {.lex_state = 6, .external_lex_state = 3},
  [4742] = {.lex_state = 6, .external_lex_state = 3},
  [4743] = {.lex_state = 6, .external_lex_state = 3},
  [4744] = {.lex_state = 6, .external_lex_state = 3},
  [4745] = {.lex_state = 6, .external_lex_state = 3},
  [4746] = {.lex_state = 6, .external_lex_state = 3},
  [4747] = {.lex_state = 6, .external_lex_state = 3},
  [4748] = {.lex_state = 6, .external_lex_state = 3},
  [4749] = {.lex_state = 6, .external_lex_state = 3},
  [4750] = {.lex_state = 6, .external_lex_state = 3},
  [4751] = {.lex_state = 6, .external_lex_state = 3},
  [4752] = {.lex_state = 116, .external_lex_state = 3},
  [4753] = {.lex_state = 6, .external_lex_state = 3},
  [4754] = {.lex_state = 6, .external_lex_state = 3},
  [4755] = {.lex_state = 6, .external_lex_state = 3},
  [4756] = {.lex_state = 6, .external_lex_state = 3},
  [4757] = {.lex_state = 6, .external_lex_state = 3},
  [4758] = {.lex_state = 6, .external_lex_state = 3},
  [4759] = {.lex_state = 6, .external_lex_state = 3},
  [4760] = {.lex_state = 6, .external_lex_state = 3},
  [4761] = {.lex_state = 6, .external_lex_state = 3},
  [4762] = {.lex_state = 6, .external_lex_state = 3},
  [4763] = {.lex_state = 6, .external_lex_state = 3},
  [4764] = {.lex_state = 6, .external_lex_state = 3},
  [4765] = {.lex_state = 6, .external_lex_state = 3},
  [4766] = {.lex_state = 6, .external_lex_state = 3},
  [4767] = {.lex_state = 6, .external_lex_state = 3},
  [4768] = {.lex_state = 6, .external_lex_state = 3},
  [4769] = {.lex_state = 116, .external_lex_state = 3},
  [4770] = {.lex_state = 6, .external_lex_state = 3},
  [4771] = {.lex_state = 6, .external_lex_state = 3},
  [4772] = {.lex_state = 18, .external_lex_state = 3},
  [4773] = {.lex_state = 117, .external_lex_state = 3},
  [4774] = {.lex_state = 116, .external_lex_state = 3},
  [4775] = {.lex_state = 116, .external_lex_state = 3},
  [4776] = {.lex_state = 116, .external_lex_state = 3},
  [4777] = {.lex_state = 116, .external_lex_state = 3},
  [4778] = {.lex_state = 6, .external_lex_state = 3},
  [4779] = {.lex_state = 116, .external_lex_state = 3},
  [4780] = {.lex_state = 6, .external_lex_state = 3},
  [4781] = {.lex_state = 116, .external_lex_state = 3},
  [4782] = {.lex_state = 116, .external_lex_state = 3},
  [4783] = {.lex_state = 116, .external_lex_state = 3},
  [4784] = {.lex_state = 116, .external_lex_state = 3},
  [4785] = {.lex_state = 6, .external_lex_state = 3},
  [4786] = {.lex_state = 116, .external_lex_state = 3},
  [4787] = {.lex_state = 116, .external_lex_state = 3},
  [4788] = {.lex_state = 116, .external_lex_state = 3},
  [4789] = {.lex_state = 116, .external_lex_state = 3},
  [4790] = {.lex_state = 116, .external_lex_state = 3},
  [4791] = {.lex_state = 6, .external_lex_state = 3},
  [4792] = {.lex_state = 116, .external_lex_state = 3},
  [4793] = {.lex_state = 6, .external_lex_state = 3},
  [4794] = {.lex_state = 116, .external_lex_state = 3},
  [4795] = {.lex_state = 6, .external_lex_state = 3},
  [4796] = {.lex_state = 6, .external_lex_state = 3},
  [4797] = {.lex_state = 6, .external_lex_state = 3},
  [4798] = {.lex_state = 6, .external_lex_state = 3},
  [4799] = {.lex_state = 6, .external_lex_state = 3},
  [4800] = {.lex_state = 6, .external_lex_state = 3},
  [4801] = {.lex_state = 116, .external_lex_state = 3},
  [4802] = {.lex_state = 116, .external_lex_state = 3},
  [4803] = {.lex_state = 116, .external_lex_state = 3},
  [4804] = {.lex_state = 6, .external_lex_state = 3},
  [4805] = {.lex_state = 6, .external_lex_state = 3},
  [4806] = {.lex_state = 116, .external_lex_state = 3},
  [4807] = {.lex_state = 116, .external_lex_state = 3},
  [4808] = {.lex_state = 116, .external_lex_state = 3},
  [4809] = {.lex_state = 6, .external_lex_state = 3},
  [4810] = {.lex_state = 116, .external_lex_state = 3},
  [4811] = {.lex_state = 116, .external_lex_state = 3},
  [4812] = {.lex_state = 116, .external_lex_state = 3},
  [4813] = {.lex_state = 116, .external_lex_state = 3},
  [4814] = {.lex_state = 6, .external_lex_state = 3},
  [4815] = {.lex_state = 6, .external_lex_state = 3},
  [4816] = {.lex_state = 116, .external_lex_state = 3},
  [4817] = {.lex_state = 116, .external_lex_state = 3},
  [4818] = {.lex_state = 6, .external_lex_state = 3},
  [4819] = {.lex_state = 6, .external_lex_state = 3},
  [4820] = {.lex_state = 6, .external_lex_state = 3},
  [4821] = {.lex_state = 116, .external_lex_state = 3},
  [4822] = {.lex_state = 116, .external_lex_state = 3},
  [4823] = {.lex_state = 116, .external_lex_state = 3},
  [4824] = {.lex_state = 116, .external_lex_state = 3},
  [4825] = {.lex_state = 116, .external_lex_state = 3},
  [4826] = {.lex_state = 117, .external_lex_state = 3},
  [4827] = {.lex_state = 6, .external_lex_state = 3},
  [4828] = {.lex_state = 6, .external_lex_state = 3},
  [4829] = {.lex_state = 117, .external_lex_state = 3},
  [4830] = {.lex_state = 116, .external_lex_state = 3},
  [4831] = {.lex_state = 6, .external_lex_state = 3},
  [4832] = {.lex_state = 6, .external_lex_state = 3},
  [4833] = {.lex_state = 6, .external_lex_state = 3},
  [4834] = {.lex_state = 116, .external_lex_state = 3},
  [4835] = {.lex_state = 116, .external_lex_state = 3},
  [4836] = {.lex_state = 116, .external_lex_state = 3},
  [4837] = {.lex_state = 116, .external_lex_state = 3},
  [4838] = {.lex_state = 116, .external_lex_state = 3},
  [4839] = {.lex_state = 6, .external_lex_state = 3},
  [4840] = {.lex_state = 6, .external_lex_state = 3},
  [4841] = {.lex_state = 117, .external_lex_state = 3},
  [4842] = {.lex_state = 6, .external_lex_state = 3},
  [4843] = {.lex_state = 6, .external_lex_state = 3},
  [4844] = {.lex_state = 116, .external_lex_state = 3},
  [4845] = {.lex_state = 6, .external_lex_state = 3},
  [4846] = {.lex_state = 6, .external_lex_state = 3},
  [4847] = {.lex_state = 116, .external_lex_state = 3},
  [4848] = {.lex_state = 116, .external_lex_state = 3},
  [4849] = {.lex_state = 116, .external_lex_state = 3},
  [4850] = {.lex_state = 6, .external_lex_state = 3},
  [4851] = {.lex_state = 116, .external_lex_state = 3},
  [4852] = {.lex_state = 117, .external_lex_state = 3},
  [4853] = {.lex_state = 6, .external_lex_state = 3},
  [4854] = {.lex_state = 116, .external_lex_state = 3},
  [4855] = {.lex_state = 6, .external_lex_state = 3},
  [4856] = {.lex_state = 116, .external_lex_state = 3},
  [4857] = {.lex_state = 116, .external_lex_state = 3},
  [4858] = {.lex_state = 116, .external_lex_state = 3},
  [4859] = {.lex_state = 6, .external_lex_state = 3},
  [4860] = {.lex_state = 6, .external_lex_state = 3},
  [4861] = {.lex_state = 6, .external_lex_state = 3},
  [4862] = {.lex_state = 116, .external_lex_state = 3},
  [4863] = {.lex_state = 116, .external_lex_state = 3},
  [4864] = {.lex_state = 6, .external_lex_state = 3},
  [4865] = {.lex_state = 116, .external_lex_state = 3},
  [4866] = {.lex_state = 6, .external_lex_state = 3},
  [4867] = {.lex_state = 116, .external_lex_state = 3},
  [4868] = {.lex_state = 116, .external_lex_state = 3},
  [4869] = {.lex_state = 117, .external_lex_state = 3},
  [4870] = {.lex_state = 116, .external_lex_state = 3},
  [4871] = {.lex_state = 117, .external_lex_state = 3},
  [4872] = {.lex_state = 6, .external_lex_state = 3},
  [4873] = {.lex_state = 117, .external_lex_state = 3},
  [4874] = {.lex_state = 116, .external_lex_state = 3},
  [4875] = {.lex_state = 116, .external_lex_state = 3},
  [4876] = {.lex_state = 116, .external_lex_state = 3},
  [4877] = {.lex_state = 116, .external_lex_state = 3},
  [4878] = {.lex_state = 6, .external_lex_state = 3},
  [4879] = {.lex_state = 116, .external_lex_state = 3},
  [4880] = {.lex_state = 6, .external_lex_state = 3},
  [4881] = {.lex_state = 116, .external_lex_state = 3},
  [4882] = {.lex_state = 116, .external_lex_state = 3},
  [4883] = {.lex_state = 6, .external_lex_state = 3},
  [4884] = {.lex_state = 116, .external_lex_state = 3},
  [4885] = {.lex_state = 116, .external_lex_state = 3},
  [4886] = {.lex_state = 6, .external_lex_state = 3},
  [4887] = {.lex_state = 116, .external_lex_state = 3},
  [4888] = {.lex_state = 116, .external_lex_state = 3},
  [4889] = {.lex_state = 116, .external_lex_state = 3},
  [4890] = {.lex_state = 116, .external_lex_state = 3},
  [4891] = {.lex_state = 117, .external_lex_state = 3},
  [4892] = {.lex_state = 117, .external_lex_state = 3},
  [4893] = {.lex_state = 6, .external_lex_state = 3},
  [4894] = {.lex_state = 117, .external_lex_state = 3},
  [4895] = {.lex_state = 116, .external_lex_state = 3},
  [4896] = {.lex_state = 6, .external_lex_state = 3},
  [4897] = {.lex_state = 116, .external_lex_state = 3},
  [4898] = {.lex_state = 6, .external_lex_state = 3},
  [4899] = {.lex_state = 116, .external_lex_state = 3},
  [4900] = {.lex_state = 116, .external_lex_state = 3},
  [4901] = {.lex_state = 116, .external_lex_state = 3},
  [4902] = {.lex_state = 116, .external_lex_state = 3},
  [4903] = {.lex_state = 18, .external_lex_state = 3},
  [4904] = {.lex_state = 117, .external_lex_state = 3},
  [4905] = {.lex_state = 117, .external_lex_state = 3},
  [4906] = {.lex_state = 85, .external_lex_state = 3},
  [4907] = {.lex_state = 117, .external_lex_state = 3},
  [4908] = {.lex_state = 117, .external_lex_state = 3},
  [4909] = {.lex_state = 117, .external_lex_state = 3},
  [4910] = {.lex_state = 117, .external_lex_state = 3},
  [4911] = {.lex_state = 117, .external_lex_state = 3},
  [4912] = {.lex_state = 117, .external_lex_state = 3},
  [4913] = {.lex_state = 117, .external_lex_state = 3},
  [4914] = {.lex_state = 117, .external_lex_state = 3},
  [4915] = {.lex_state = 117, .external_lex_state = 3},
  [4916] = {.lex_state = 117, .external_lex_state = 3},
  [4917] = {.lex_state = 117, .external_lex_state = 3},
  [4918] = {.lex_state = 117, .external_lex_state = 3},
  [4919] = {.lex_state = 117, .external_lex_state = 3},
  [4920] = {.lex_state = 117, .external_lex_state = 3},
  [4921] = {.lex_state = 117, .external_lex_state = 3},
  [4922] = {.lex_state = 117, .external_lex_state = 3},
  [4923] = {.lex_state = 117, .external_lex_state = 3},
  [4924] = {.lex_state = 117, .external_lex_state = 3},
  [4925] = {.lex_state = 117, .external_lex_state = 3},
  [4926] = {.lex_state = 6, .external_lex_state = 3},
  [4927] = {.lex_state = 117, .external_lex_state = 3},
  [4928] = {.lex_state = 117, .external_lex_state = 3},
  [4929] = {.lex_state = 117, .external_lex_state = 3},
  [4930] = {.lex_state = 117, .external_lex_state = 3},
  [4931] = {.lex_state = 117, .external_lex_state = 3},
  [4932] = {.lex_state = 117, .external_lex_state = 3},
  [4933] = {.lex_state = 117, .external_lex_state = 3},
  [4934] = {.lex_state = 117, .external_lex_state = 3},
  [4935] = {.lex_state = 117, .external_lex_state = 3},
  [4936] = {.lex_state = 85, .external_lex_state = 3},
  [4937] = {.lex_state = 117, .external_lex_state = 3},
  [4938] = {.lex_state = 117, .external_lex_state = 3},
  [4939] = {.lex_state = 117, .external_lex_state = 3},
  [4940] = {.lex_state = 117, .external_lex_state = 3},
  [4941] = {.lex_state = 6, .external_lex_state = 3},
  [4942] = {.lex_state = 117, .external_lex_state = 3},
  [4943] = {.lex_state = 117, .external_lex_state = 3},
  [4944] = {.lex_state = 6, .external_lex_state = 3},
  [4945] = {.lex_state = 117, .external_lex_state = 3},
  [4946] = {.lex_state = 117, .external_lex_state = 3},
  [4947] = {.lex_state = 117, .external_lex_state = 3},
  [4948] = {.lex_state = 6, .external_lex_state = 3},
  [4949] = {.lex_state = 85, .external_lex_state = 3},
  [4950] = {.lex_state = 117, .external_lex_state = 3},
  [4951] = {.lex_state = 117, .external_lex_state = 3},
  [4952] = {.lex_state = 117, .external_lex_state = 3},
  [4953] = {.lex_state = 117, .external_lex_state = 3},
  [4954] = {.lex_state = 117, .external_lex_state = 3},
  [4955] = {.lex_state = 117, .external_lex_state = 3},
  [4956] = {.lex_state = 117, .external_lex_state = 3},
  [4957] = {.lex_state = 117, .external_lex_state = 3},
  [4958] = {.lex_state = 85, .external_lex_state = 3},
  [4959] = {.lex_state = 117, .external_lex_state = 3},
  [4960] = {.lex_state = 117, .external_lex_state = 3},
  [4961] = {.lex_state = 117, .external_lex_state = 3},
  [4962] = {.lex_state = 117, .external_lex_state = 3},
  [4963] = {.lex_state = 117, .external_lex_state = 3},
  [4964] = {.lex_state = 85, .external_lex_state = 3},
  [4965] = {.lex_state = 117, .external_lex_state = 3},
  [4966] = {.lex_state = 117, .external_lex_state = 3},
  [4967] = {.lex_state = 85, .external_lex_state = 3},
  [4968] = {.lex_state = 117, .external_lex_state = 3},
  [4969] = {.lex_state = 117, .external_lex_state = 3},
  [4970] = {.lex_state = 117, .external_lex_state = 3},
  [4971] = {.lex_state = 117, .external_lex_state = 3},
  [4972] = {.lex_state = 117, .external_lex_state = 3},
  [4973] = {.lex_state = 117, .external_lex_state = 3},
  [4974] = {.lex_state = 117, .external_lex_state = 3},
  [4975] = {.lex_state = 117, .external_lex_state = 3},
  [4976] = {.lex_state = 6, .external_lex_state = 3},
  [4977] = {.lex_state = 85, .external_lex_state = 3},
  [4978] = {.lex_state = 117, .external_lex_state = 3},
  [4979] = {.lex_state = 117, .external_lex_state = 3},
  [4980] = {.lex_state = 117, .external_lex_state = 3},
  [4981] = {.lex_state = 6, .external_lex_state = 3},
  [4982] = {.lex_state = 85, .external_lex_state = 3},
  [4983] = {.lex_state = 117, .external_lex_state = 3},
  [4984] = {.lex_state = 117, .external_lex_state = 3},
  [4985] = {.lex_state = 117, .external_lex_state = 3},
  [4986] = {.lex_state = 117, .external_lex_state = 3},
  [4987] = {.lex_state = 85, .external_lex_state = 3},
  [4988] = {.lex_state = 117, .external_lex_state = 3},
  [4989] = {.lex_state = 117, .external_lex_state = 3},
  [4990] = {.lex_state = 117, .external_lex_state = 3},
  [4991] = {.lex_state = 117, .external_lex_state = 3},
  [4992] = {.lex_state = 6, .external_lex_state = 3},
  [4993] = {.lex_state = 85, .external_lex_state = 3},
  [4994] = {.lex_state = 84, .external_lex_state = 3},
  [4995] = {.lex_state = 85, .external_lex_state = 3},
  [4996] = {.lex_state = 6, .external_lex_state = 3},
  [4997] = {.lex_state = 85, .external_lex_state = 3},
  [4998] = {.lex_state = 6, .external_lex_state = 3},
  [4999] = {.lex_state = 85, .external_lex_state = 3},
  [5000] = {.lex_state = 85, .external_lex_state = 3},
  [5001] = {.lex_state = 85, .external_lex_state = 3},
  [5002] = {.lex_state = 6, .external_lex_state = 3},
  [5003] = {.lex_state = 85, .external_lex_state = 3},
  [5004] = {.lex_state = 6, .external_lex_state = 3},
  [5005] = {.lex_state = 85, .external_lex_state = 3},
  [5006] = {.lex_state = 6, .external_lex_state = 3},
  [5007] = {.lex_state = 85, .external_lex_state = 3},
  [5008] = {.lex_state = 6, .external_lex_state = 3},
  [5009] = {.lex_state = 85, .external_lex_state = 3},
  [5010] = {.lex_state = 6, .external_lex_state = 3},
  [5011] = {.lex_state = 87, .external_lex_state = 3},
  [5012] = {.lex_state = 6, .external_lex_state = 3},
  [5013] = {.lex_state = 85, .external_lex_state = 3},
  [5014] = {.lex_state = 85, .external_lex_state = 3},
  [5015] = {.lex_state = 87, .external_lex_state = 3},
  [5016] = {.lex_state = 6, .external_lex_state = 3},
  [5017] = {.lex_state = 85, .external_lex_state = 3},
  [5018] = {.lex_state = 85, .external_lex_state = 3},
  [5019] = {.lex_state = 87, .external_lex_state = 3},
  [5020] = {.lex_state = 85, .external_lex_state = 3},
  [5021] = {.lex_state = 85, .external_lex_state = 3},
  [5022] = {.lex_state = 85, .external_lex_state = 3},
  [5023] = {.lex_state = 85, .external_lex_state = 3},
  [5024] = {.lex_state = 85, .external_lex_state = 3},
  [5025] = {.lex_state = 6, .external_lex_state = 3},
  [5026] = {.lex_state = 85, .external_lex_state = 3},
  [5027] = {.lex_state = 6, .external_lex_state = 3},
  [5028] = {.lex_state = 6, .external_lex_state = 3},
  [5029] = {.lex_state = 6, .external_lex_state = 3},
  [5030] = {.lex_state = 85, .external_lex_state = 3},
  [5031] = {.lex_state = 6, .external_lex_state = 3},
  [5032] = {.lex_state = 6, .external_lex_state = 3},
  [5033] = {.lex_state = 85, .external_lex_state = 3},
  [5034] = {.lex_state = 85, .external_lex_state = 3},
  [5035] = {.lex_state = 6, .external_lex_state = 3},
  [5036] = {.lex_state = 6, .external_lex_state = 3},
  [5037] = {.lex_state = 6, .external_lex_state = 3},
  [5038] = {.lex_state = 85, .external_lex_state = 3},
  [5039] = {.lex_state = 6, .external_lex_state = 3},
  [5040] = {.lex_state = 84, .external_lex_state = 3},
  [5041] = {.lex_state = 6, .external_lex_state = 3},
  [5042] = {.lex_state = 85, .external_lex_state = 3},
  [5043] = {.lex_state = 85, .external_lex_state = 3},
  [5044] = {.lex_state = 85, .external_lex_state = 3},
  [5045] = {.lex_state = 85, .external_lex_state = 3},
  [5046] = {.lex_state = 85, .external_lex_state = 3},
  [5047] = {.lex_state = 6, .external_lex_state = 3},
  [5048] = {.lex_state = 84, .external_lex_state = 3},
  [5049] = {.lex_state = 6, .external_lex_state = 3},
  [5050] = {.lex_state = 19, .external_lex_state = 3},
  [5051] = {.lex_state = 6, .external_lex_state = 3},
  [5052] = {.lex_state = 28, .external_lex_state = 3},
  [5053] = {.lex_state = 6, .external_lex_state = 3},
  [5054] = {.lex_state = 6, .external_lex_state = 3},
  [5055] = {.lex_state = 6, .external_lex_state = 3},
  [5056] = {.lex_state = 6, .external_lex_state = 3},
  [5057] = {.lex_state = 85, .external_lex_state = 3},
  [5058] = {.lex_state = 6, .external_lex_state = 3},
  [5059] = {.lex_state = 85, .external_lex_state = 3},
  [5060] = {.lex_state = 6, .external_lex_state = 3},
  [5061] = {.lex_state = 85, .external_lex_state = 3},
  [5062] = {.lex_state = 6, .external_lex_state = 3},
  [5063] = {.lex_state = 85, .external_lex_state = 3},
  [5064] = {.lex_state = 85, .external_lex_state = 3},
  [5065] = {.lex_state = 85, .external_lex_state = 3},
  [5066] = {.lex_state = 6, .external_lex_state = 3},
  [5067] = {.lex_state = 85, .external_lex_state = 3},
  [5068] = {.lex_state = 85, .external_lex_state = 3},
  [5069] = {.lex_state = 6, .external_lex_state = 3},
  [5070] = {.lex_state = 85, .external_lex_state = 3},
  [5071] = {.lex_state = 6, .external_lex_state = 3},
  [5072] = {.lex_state = 85, .external_lex_state = 3},
  [5073] = {.lex_state = 6, .external_lex_state = 3},
  [5074] = {.lex_state = 85, .external_lex_state = 3},
  [5075] = {.lex_state = 85, .external_lex_state = 3},
  [5076] = {.lex_state = 85, .external_lex_state = 3},
  [5077] = {.lex_state = 85, .external_lex_state = 3},
  [5078] = {.lex_state = 6, .external_lex_state = 3},
  [5079] = {.lex_state = 87, .external_lex_state = 3},
  [5080] = {.lex_state = 6, .external_lex_state = 3},
  [5081] = {.lex_state = 85, .external_lex_state = 3},
  [5082] = {.lex_state = 84, .external_lex_state = 3},
  [5083] = {.lex_state = 84, .external_lex_state = 3},
  [5084] = {.lex_state = 85, .external_lex_state = 3},
  [5085] = {.lex_state = 18, .external_lex_state = 3},
  [5086] = {.lex_state = 84, .external_lex_state = 3},
  [5087] = {.lex_state = 6, .external_lex_state = 3},
  [5088] = {.lex_state = 87, .external_lex_state = 3},
  [5089] = {.lex_state = 87, .external_lex_state = 3},
  [5090] = {.lex_state = 28, .external_lex_state = 3},
  [5091] = {.lex_state = 87, .external_lex_state = 3},
  [5092] = {.lex_state = 6, .external_lex_state = 3},
  [5093] = {.lex_state = 84, .external_lex_state = 3},
  [5094] = {.lex_state = 6, .external_lex_state = 3},
  [5095] = {.lex_state = 84, .external_lex_state = 3},
  [5096] = {.lex_state = 85, .external_lex_state = 3},
  [5097] = {.lex_state = 28, .external_lex_state = 3},
  [5098] = {.lex_state = 6, .external_lex_state = 3},
  [5099] = {.lex_state = 6, .external_lex_state = 3},
  [5100] = {.lex_state = 84, .external_lex_state = 3},
  [5101] = {.lex_state = 85, .external_lex_state = 3},
  [5102] = {.lex_state = 84, .external_lex_state = 3},
  [5103] = {.lex_state = 85, .external_lex_state = 3},
  [5104] = {.lex_state = 84, .external_lex_state = 3},
  [5105] = {.lex_state = 85, .external_lex_state = 3},
  [5106] = {.lex_state = 87, .external_lex_state = 3},
  [5107] = {.lex_state = 87, .external_lex_state = 3},
  [5108] = {.lex_state = 6, .external_lex_state = 3},
  [5109] = {.lex_state = 87, .external_lex_state = 3},
  [5110] = {.lex_state = 85, .external_lex_state = 3},
  [5111] = {.lex_state = 85, .external_lex_state = 3},
  [5112] = {.lex_state = 6, .external_lex_state = 3},
  [5113] = {.lex_state = 85, .external_lex_state = 3},
  [5114] = {.lex_state = 6, .external_lex_state = 3},
  [5115] = {.lex_state = 85, .external_lex_state = 3},
  [5116] = {.lex_state = 85, .external_lex_state = 3},
  [5117] = {.lex_state = 85, .external_lex_state = 3},
  [5118] = {.lex_state = 6, .external_lex_state = 3},
  [5119] = {.lex_state = 85, .external_lex_state = 3},
  [5120] = {.lex_state = 6, .external_lex_state = 3},
  [5121] = {.lex_state = 85, .external_lex_state = 3},
  [5122] = {.lex_state = 85, .external_lex_state = 3},
  [5123] = {.lex_state = 85, .external_lex_state = 3},
  [5124] = {.lex_state = 85, .external_lex_state = 3},
  [5125] = {.lex_state = 85, .external_lex_state = 3},
  [5126] = {.lex_state = 85, .external_lex_state = 3},
  [5127] = {.lex_state = 85, .external_lex_state = 3},
  [5128] = {.lex_state = 85, .external_lex_state = 3},
  [5129] = {.lex_state = 85, .external_lex_state = 3},
  [5130] = {.lex_state = 85, .external_lex_state = 3},
  [5131] = {.lex_state = 85, .external_lex_state = 3},
  [5132] = {.lex_state = 85, .external_lex_state = 3},
  [5133] = {.lex_state = 6, .external_lex_state = 3},
  [5134] = {.lex_state = 6, .external_lex_state = 3},
  [5135] = {.lex_state = 6, .external_lex_state = 3},
  [5136] = {.lex_state = 85, .external_lex_state = 3},
  [5137] = {.lex_state = 85, .external_lex_state = 3},
  [5138] = {.lex_state = 6, .external_lex_state = 3},
  [5139] = {.lex_state = 85, .external_lex_state = 3},
  [5140] = {.lex_state = 6, .external_lex_state = 3},
  [5141] = {.lex_state = 85, .external_lex_state = 3},
  [5142] = {.lex_state = 116, .external_lex_state = 3},
  [5143] = {.lex_state = 6, .external_lex_state = 3},
  [5144] = {.lex_state = 6, .external_lex_state = 3},
  [5145] = {.lex_state = 85, .external_lex_state = 3},
  [5146] = {.lex_state = 87, .external_lex_state = 3},
  [5147] = {.lex_state = 87, .external_lex_state = 3},
  [5148] = {.lex_state = 86, .external_lex_state = 3},
  [5149] = {.lex_state = 84, .external_lex_state = 3},
  [5150] = {.lex_state = 84, .external_lex_state = 3},
  [5151] = {.lex_state = 87, .external_lex_state = 3},
  [5152] = {.lex_state = 84, .external_lex_state = 3},
  [5153] = {.lex_state = 87, .external_lex_state = 3},
  [5154] = {.lex_state = 87, .external_lex_state = 3},
  [5155] = {.lex_state = 177, .external_lex_state = 3},
  [5156] = {.lex_state = 87, .external_lex_state = 3},
  [5157] = {.lex_state = 87, .external_lex_state = 3},
  [5158] = {.lex_state = 84, .external_lex_state = 3},
  [5159] = {.lex_state = 84, .external_lex_state = 3},
  [5160] = {.lex_state = 86, .external_lex_state = 3},
  [5161] = {.lex_state = 84, .external_lex_state = 3},
  [5162] = {.lex_state = 84, .external_lex_state = 3},
  [5163] = {.lex_state = 86, .external_lex_state = 3},
  [5164] = {.lex_state = 84, .external_lex_state = 3},
  [5165] = {.lex_state = 84, .external_lex_state = 3},
  [5166] = {.lex_state = 87, .external_lex_state = 3},
  [5167] = {.lex_state = 84, .external_lex_state = 3},
  [5168] = {.lex_state = 87, .external_lex_state = 3},
  [5169] = {.lex_state = 84, .external_lex_state = 3},
  [5170] = {.lex_state = 84, .external_lex_state = 3},
  [5171] = {.lex_state = 87, .external_lex_state = 3},
  [5172] = {.lex_state = 87, .external_lex_state = 3},
  [5173] = {.lex_state = 84, .external_lex_state = 3},
  [5174] = {.lex_state = 87, .external_lex_state = 3},
  [5175] = {.lex_state = 84, .external_lex_state = 3},
  [5176] = {.lex_state = 87, .external_lex_state = 3},
  [5177] = {.lex_state = 84, .external_lex_state = 3},
  [5178] = {.lex_state = 84, .external_lex_state = 3},
  [5179] = {.lex_state = 87, .external_lex_state = 3},
  [5180] = {.lex_state = 84, .external_lex_state = 3},
  [5181] = {.lex_state = 84, .external_lex_state = 3},
  [5182] = {.lex_state = 84, .external_lex_state = 3},
  [5183] = {.lex_state = 87, .external_lex_state = 3},
  [5184] = {.lex_state = 117, .external_lex_state = 3},
  [5185] = {.lex_state = 87, .external_lex_state = 3},
  [5186] = {.lex_state = 87, .external_lex_state = 3},
  [5187] = {.lex_state = 84, .external_lex_state = 3},
  [5188] = {.lex_state = 87, .external_lex_state = 3},
  [5189] = {.lex_state = 84, .external_lex_state = 3},
  [5190] = {.lex_state = 84, .external_lex_state = 3},
  [5191] = {.lex_state = 84, .external_lex_state = 3},
  [5192] = {.lex_state = 84, .external_lex_state = 3},
  [5193] = {.lex_state = 87, .external_lex_state = 3},
  [5194] = {.lex_state = 87, .external_lex_state = 3},
  [5195] = {.lex_state = 84, .external_lex_state = 3},
  [5196] = {.lex_state = 87, .external_lex_state = 3},
  [5197] = {.lex_state = 85, .external_lex_state = 3},
  [5198] = {.lex_state = 87, .external_lex_state = 3},
  [5199] = {.lex_state = 87, .external_lex_state = 3},
  [5200] = {.lex_state = 84, .external_lex_state = 3},
  [5201] = {.lex_state = 87, .external_lex_state = 3},
  [5202] = {.lex_state = 84, .external_lex_state = 3},
  [5203] = {.lex_state = 84, .external_lex_state = 3},
  [5204] = {.lex_state = 84, .external_lex_state = 3},
  [5205] = {.lex_state = 87, .external_lex_state = 3},
  [5206] = {.lex_state = 87, .external_lex_state = 3},
  [5207] = {.lex_state = 84, .external_lex_state = 3},
  [5208] = {.lex_state = 84, .external_lex_state = 3},
  [5209] = {.lex_state = 84, .external_lex_state = 3},
  [5210] = {.lex_state = 84, .external_lex_state = 3},
  [5211] = {.lex_state = 87, .external_lex_state = 3},
  [5212] = {.lex_state = 84, .external_lex_state = 3},
  [5213] = {.lex_state = 84, .external_lex_state = 3},
  [5214] = {.lex_state = 87, .external_lex_state = 3},
  [5215] = {.lex_state = 87, .external_lex_state = 3},
  [5216] = {.lex_state = 84, .external_lex_state = 3},
  [5217] = {.lex_state = 84, .external_lex_state = 3},
  [5218] = {.lex_state = 84, .external_lex_state = 3},
  [5219] = {.lex_state = 87, .external_lex_state = 3},
  [5220] = {.lex_state = 84, .external_lex_state = 3},
  [5221] = {.lex_state = 84, .external_lex_state = 3},
  [5222] = {.lex_state = 84, .external_lex_state = 3},
  [5223] = {.lex_state = 87, .external_lex_state = 3},
  [5224] = {.lex_state = 87, .external_lex_state = 3},
  [5225] = {.lex_state = 84, .external_lex_state = 3},
  [5226] = {.lex_state = 87, .external_lex_state = 3},
  [5227] = {.lex_state = 87, .external_lex_state = 3},
  [5228] = {.lex_state = 84, .external_lex_state = 3},
  [5229] = {.lex_state = 87, .external_lex_state = 3},
  [5230] = {.lex_state = 179, .external_lex_state = 3},
  [5231] = {.lex_state = 87, .external_lex_state = 3},
  [5232] = {.lex_state = 87, .external_lex_state = 3},
  [5233] = {.lex_state = 84, .external_lex_state = 3},
  [5234] = {.lex_state = 84, .external_lex_state = 3},
  [5235] = {.lex_state = 87, .external_lex_state = 3},
  [5236] = {.lex_state = 84, .external_lex_state = 3},
  [5237] = {.lex_state = 84, .external_lex_state = 3},
  [5238] = {.lex_state = 84, .external_lex_state = 3},
  [5239] = {.lex_state = 84, .external_lex_state = 3},
  [5240] = {.lex_state = 87, .external_lex_state = 3},
  [5241] = {.lex_state = 87, .external_lex_state = 3},
  [5242] = {.lex_state = 19, .external_lex_state = 3},
  [5243] = {.lex_state = 87, .external_lex_state = 3},
  [5244] = {.lex_state = 84, .external_lex_state = 3},
  [5245] = {.lex_state = 87, .external_lex_state = 3},
  [5246] = {.lex_state = 84, .external_lex_state = 3},
  [5247] = {.lex_state = 87, .external_lex_state = 3},
  [5248] = {.lex_state = 84, .external_lex_state = 3},
  [5249] = {.lex_state = 87, .external_lex_state = 3},
  [5250] = {.lex_state = 84, .external_lex_state = 3},
  [5251] = {.lex_state = 84, .external_lex_state = 3},
  [5252] = {.lex_state = 84, .external_lex_state = 3},
  [5253] = {.lex_state = 84, .external_lex_state = 3},
  [5254] = {.lex_state = 84, .external_lex_state = 3},
  [5255] = {.lex_state = 87, .external_lex_state = 3},
  [5256] = {.lex_state = 84, .external_lex_state = 3},
  [5257] = {.lex_state = 87, .external_lex_state = 3},
  [5258] = {.lex_state = 87, .external_lex_state = 3},
  [5259] = {.lex_state = 84, .external_lex_state = 3},
  [5260] = {.lex_state = 87, .external_lex_state = 3},
  [5261] = {.lex_state = 84, .external_lex_state = 3},
  [5262] = {.lex_state = 87, .external_lex_state = 3},
  [5263] = {.lex_state = 84, .external_lex_state = 3},
  [5264] = {.lex_state = 87, .external_lex_state = 3},
  [5265] = {.lex_state = 84, .external_lex_state = 3},
  [5266] = {.lex_state = 84, .external_lex_state = 3},
  [5267] = {.lex_state = 87, .external_lex_state = 3},
  [5268] = {.lex_state = 84, .external_lex_state = 3},
  [5269] = {.lex_state = 87, .external_lex_state = 3},
  [5270] = {.lex_state = 87, .external_lex_state = 3},
  [5271] = {.lex_state = 87, .external_lex_state = 3},
  [5272] = {.lex_state = 87, .external_lex_state = 3},
  [5273] = {.lex_state = 18, .external_lex_state = 3},
  [5274] = {.lex_state = 87, .external_lex_state = 3},
  [5275] = {.lex_state = 87, .external_lex_state = 3},
  [5276] = {.lex_state = 116, .external_lex_state = 3},
  [5277] = {.lex_state = 87, .external_lex_state = 3},
  [5278] = {.lex_state = 87, .external_lex_state = 3},
  [5279] = {.lex_state = 84, .external_lex_state = 3},
  [5280] = {.lex_state = 86, .external_lex_state = 3},
  [5281] = {.lex_state = 87, .external_lex_state = 3},
  [5282] = {.lex_state = 84, .external_lex_state = 3},
  [5283] = {.lex_state = 87, .external_lex_state = 3},
  [5284] = {.lex_state = 86, .external_lex_state = 3},
  [5285] = {.lex_state = 86, .external_lex_state = 3},
  [5286] = {.lex_state = 86, .external_lex_state = 3},
  [5287] = {.lex_state = 177, .external_lex_state = 3},
  [5288] = {.lex_state = 84, .external_lex_state = 3},
  [5289] = {.lex_state = 84, .external_lex_state = 3},
  [5290] = {.lex_state = 87, .external_lex_state = 3},
  [5291] = {.lex_state = 84, .external_lex_state = 3},
  [5292] = {.lex_state = 87, .external_lex_state = 3},
  [5293] = {.lex_state = 84, .external_lex_state = 3},
  [5294] = {.lex_state = 116, .external_lex_state = 3},
  [5295] = {.lex_state = 84, .external_lex_state = 3},
  [5296] = {.lex_state = 87, .external_lex_state = 3},
  [5297] = {.lex_state = 87, .external_lex_state = 3},
  [5298] = {.lex_state = 87, .external_lex_state = 3},
  [5299] = {.lex_state = 87, .external_lex_state = 3},
  [5300] = {.lex_state = 87, .external_lex_state = 3},
  [5301] = {.lex_state = 179, .external_lex_state = 3},
  [5302] = {.lex_state = 87, .external_lex_state = 3},
  [5303] = {.lex_state = 87, .external_lex_state = 3},
  [5304] = {.lex_state = 84, .external_lex_state = 3},
  [5305] = {.lex_state = 86, .external_lex_state = 3},
  [5306] = {.lex_state = 87, .external_lex_state = 3},
  [5307] = {.lex_state = 86, .external_lex_state = 3},
  [5308] = {.lex_state = 86, .external_lex_state = 3},
  [5309] = {.lex_state = 87, .external_lex_state = 3},
  [5310] = {.lex_state = 86, .external_lex_state = 3},
  [5311] = {.lex_state = 86, .external_lex_state = 3},
  [5312] = {.lex_state = 86, .external_lex_state = 3},
  [5313] = {.lex_state = 86, .external_lex_state = 3},
  [5314] = {.lex_state = 86, .external_lex_state = 3},
  [5315] = {.lex_state = 185, .external_lex_state = 3},
  [5316] = {.lex_state = 117, .external_lex_state = 3},
  [5317] = {.lex_state = 86, .external_lex_state = 3},
  [5318] = {.lex_state = 86, .external_lex_state = 3},
  [5319] = {.lex_state = 86, .external_lex_state = 3},
  [5320] = {.lex_state = 86, .external_lex_state = 3},
  [5321] = {.lex_state = 179, .external_lex_state = 3},
  [5322] = {.lex_state = 86, .external_lex_state = 3},
  [5323] = {.lex_state = 86, .external_lex_state = 3},
  [5324] = {.lex_state = 86, .external_lex_state = 3},
  [5325] = {.lex_state = 185, .external_lex_state = 3},
  [5326] = {.lex_state = 86, .external_lex_state = 3},
  [5327] = {.lex_state = 86, .external_lex_state = 3},
  [5328] = {.lex_state = 86, .external_lex_state = 3},
  [5329] = {.lex_state = 86, .external_lex_state = 3},
  [5330] = {.lex_state = 86, .external_lex_state = 3},
  [5331] = {.lex_state = 86, .external_lex_state = 3},
  [5332] = {.lex_state = 86, .external_lex_state = 3},
  [5333] = {.lex_state = 86, .external_lex_state = 3},
  [5334] = {.lex_state = 86, .external_lex_state = 3},
  [5335] = {.lex_state = 178, .external_lex_state = 3},
  [5336] = {.lex_state = 86, .external_lex_state = 3},
  [5337] = {.lex_state = 86, .external_lex_state = 3},
  [5338] = {.lex_state = 86, .external_lex_state = 3},
  [5339] = {.lex_state = 86, .external_lex_state = 3},
  [5340] = {.lex_state = 86, .external_lex_state = 3},
  [5341] = {.lex_state = 86, .external_lex_state = 3},
  [5342] = {.lex_state = 87, .external_lex_state = 3},
  [5343] = {.lex_state = 86, .external_lex_state = 3},
  [5344] = {.lex_state = 117, .external_lex_state = 3},
  [5345] = {.lex_state = 177, .external_lex_state = 3},
  [5346] = {.lex_state = 86, .external_lex_state = 3},
  [5347] = {.lex_state = 86, .external_lex_state = 3},
  [5348] = {.lex_state = 86, .external_lex_state = 3},
  [5349] = {.lex_state = 86, .external_lex_state = 3},
  [5350] = {.lex_state = 86, .external_lex_state = 3},
  [5351] = {.lex_state = 86, .external_lex_state = 3},
  [5352] = {.lex_state = 86, .external_lex_state = 3},
  [5353] = {.lex_state = 86, .external_lex_state = 3},
  [5354] = {.lex_state = 86, .external_lex_state = 3},
  [5355] = {.lex_state = 86, .external_lex_state = 3},
  [5356] = {.lex_state = 185, .external_lex_state = 3},
  [5357] = {.lex_state = 86, .external_lex_state = 3},
  [5358] = {.lex_state = 86, .external_lex_state = 3},
  [5359] = {.lex_state = 86, .external_lex_state = 3},
  [5360] = {.lex_state = 86, .external_lex_state = 3},
  [5361] = {.lex_state = 86, .external_lex_state = 3},
  [5362] = {.lex_state = 86, .external_lex_state = 3},
  [5363] = {.lex_state = 183, .external_lex_state = 3},
  [5364] = {.lex_state = 177, .external_lex_state = 3},
  [5365] = {.lex_state = 183, .external_lex_state = 3},
  [5366] = {.lex_state = 86, .external_lex_state = 3},
  [5367] = {.lex_state = 183, .external_lex_state = 3},
  [5368] = {.lex_state = 86, .external_lex_state = 3},
  [5369] = {.lex_state = 183, .external_lex_state = 3},
  [5370] = {.lex_state = 86, .external_lex_state = 3},
  [5371] = {.lex_state = 86, .external_lex_state = 3},
  [5372] = {.lex_state = 183, .external_lex_state = 3},
  [5373] = {.lex_state = 177, .external_lex_state = 3},
  [5374] = {.lex_state = 86, .external_lex_state = 3},
  [5375] = {.lex_state = 86, .external_lex_state = 3},
  [5376] = {.lex_state = 179, .external_lex_state = 3},
  [5377] = {.lex_state = 86, .external_lex_state = 3},
  [5378] = {.lex_state = 86, .external_lex_state = 3},
  [5379] = {.lex_state = 86, .external_lex_state = 3},
  [5380] = {.lex_state = 86, .external_lex_state = 3},
  [5381] = {.lex_state = 179, .external_lex_state = 3},
  [5382] = {.lex_state = 86, .external_lex_state = 3},
  [5383] = {.lex_state = 86, .external_lex_state = 3},
  [5384] = {.lex_state = 86, .external_lex_state = 3},
  [5385] = {.lex_state = 178, .external_lex_state = 3},
  [5386] = {.lex_state = 420, .external_lex_state = 2},
  [5387] = {.lex_state = 86, .external_lex_state = 3},
  [5388] = {.lex_state = 183, .external_lex_state = 3},
  [5389] = {.lex_state = 86, .external_lex_state = 3},
  [5390] = {.lex_state = 420, .external_lex_state = 2},
  [5391] = {.lex_state = 86, .external_lex_state = 3},
  [5392] = {.lex_state = 86, .external_lex_state = 3},
  [5393] = {.lex_state = 86, .external_lex_state = 3},
  [5394] = {.lex_state = 183, .external_lex_state = 3},
  [5395] = {.lex_state = 157, .external_lex_state = 3},
  [5396] = {.lex_state = 86, .external_lex_state = 3},
  [5397] = {.lex_state = 86, .external_lex_state = 3},
  [5398] = {.lex_state = 86, .external_lex_state = 3},
  [5399] = {.lex_state = 86, .external_lex_state = 3},
  [5400] = {.lex_state = 185, .external_lex_state = 3},
  [5401] = {.lex_state = 185, .external_lex_state = 3},
  [5402] = {.lex_state = 185, .external_lex_state = 3},
  [5403] = {.lex_state = 183, .external_lex_state = 3},
  [5404] = {.lex_state = 183, .external_lex_state = 3},
  [5405] = {.lex_state = 180, .external_lex_state = 3},
  [5406] = {.lex_state = 183, .external_lex_state = 3},
  [5407] = {.lex_state = 86, .external_lex_state = 3},
  [5408] = {.lex_state = 183, .external_lex_state = 3},
  [5409] = {.lex_state = 86, .external_lex_state = 3},
  [5410] = {.lex_state = 86, .external_lex_state = 3},
  [5411] = {.lex_state = 86, .external_lex_state = 3},
  [5412] = {.lex_state = 86, .external_lex_state = 3},
  [5413] = {.lex_state = 86, .external_lex_state = 3},
  [5414] = {.lex_state = 177, .external_lex_state = 3},
  [5415] = {.lex_state = 185, .external_lex_state = 3},
  [5416] = {.lex_state = 179, .external_lex_state = 3},
  [5417] = {.lex_state = 185, .external_lex_state = 3},
  [5418] = {.lex_state = 180, .external_lex_state = 3},
  [5419] = {.lex_state = 420, .external_lex_state = 2},
  [5420] = {.lex_state = 185, .external_lex_state = 3},
  [5421] = {.lex_state = 185, .external_lex_state = 3},
  [5422] = {.lex_state = 86, .external_lex_state = 3},
  [5423] = {.lex_state = 185, .external_lex_state = 3},
  [5424] = {.lex_state = 179, .external_lex_state = 3},
  [5425] = {.lex_state = 178, .external_lex_state = 3},
  [5426] = {.lex_state = 186, .external_lex_state = 3},
  [5427] = {.lex_state = 180, .external_lex_state = 3},
  [5428] = {.lex_state = 179, .external_lex_state = 3},
  [5429] = {.lex_state = 130, .external_lex_state = 3},
  [5430] = {.lex_state = 177, .external_lex_state = 3},
  [5431] = {.lex_state = 180, .external_lex_state = 3},
  [5432] = {.lex_state = 179, .external_lex_state = 3},
  [5433] = {.lex_state = 179, .external_lex_state = 3},
  [5434] = {.lex_state = 177, .external_lex_state = 3},
  [5435] = {.lex_state = 130, .external_lex_state = 3},
  [5436] = {.lex_state = 179, .external_lex_state = 3},
  [5437] = {.lex_state = 130, .external_lex_state = 3},
  [5438] = {.lex_state = 186, .external_lex_state = 3},
  [5439] = {.lex_state = 179, .external_lex_state = 3},
  [5440] = {.lex_state = 177, .external_lex_state = 3},
  [5441] = {.lex_state = 179, .external_lex_state = 3},
  [5442] = {.lex_state = 179, .external_lex_state = 3},
  [5443] = {.lex_state = 186, .external_lex_state = 3},
  [5444] = {.lex_state = 180, .external_lex_state = 3},
  [5445] = {.lex_state = 186, .external_lex_state = 3},
  [5446] = {.lex_state = 177, .external_lex_state = 3},
  [5447] = {.lex_state = 130, .external_lex_state = 3},
  [5448] = {.lex_state = 177, .external_lex_state = 3},
  [5449] = {.lex_state = 186, .external_lex_state = 3},
  [5450] = {.lex_state = 177, .external_lex_state = 3},
  [5451] = {.lex_state = 186, .external_lex_state = 3},
  [5452] = {.lex_state = 179, .external_lex_state = 3},
  [5453] = {.lex_state = 179, .external_lex_state = 3},
  [5454] = {.lex_state = 179, .external_lex_state = 3},
  [5455] = {.lex_state = 179, .external_lex_state = 3},
  [5456] = {.lex_state = 179, .external_lex_state = 3},
  [5457] = {.lex_state = 177, .external_lex_state = 3},
  [5458] = {.lex_state = 179, .external_lex_state = 3},
  [5459] = {.lex_state = 179, .external_lex_state = 3},
  [5460] = {.lex_state = 186, .external_lex_state = 3},
  [5461] = {.lex_state = 177, .external_lex_state = 3},
  [5462] = {.lex_state = 177, .external_lex_state = 3},
  [5463] = {.lex_state = 85, .external_lex_state = 3},
  [5464] = {.lex_state = 179, .external_lex_state = 3},
  [5465] = {.lex_state = 177, .external_lex_state = 3},
  [5466] = {.lex_state = 179, .external_lex_state = 3},
  [5467] = {.lex_state = 179, .external_lex_state = 3},
  [5468] = {.lex_state = 179, .external_lex_state = 3},
  [5469] = {.lex_state = 130, .external_lex_state = 3},
  [5470] = {.lex_state = 186, .external_lex_state = 3},
  [5471] = {.lex_state = 179, .external_lex_state = 3},
  [5472] = {.lex_state = 130, .external_lex_state = 3},
  [5473] = {.lex_state = 130, .external_lex_state = 3},
  [5474] = {.lex_state = 179, .external_lex_state = 3},
  [5475] = {.lex_state = 179, .external_lex_state = 3},
  [5476] = {.lex_state = 177, .external_lex_state = 3},
  [5477] = {.lex_state = 177, .external_lex_state = 3},
  [5478] = {.lex_state = 180, .external_lex_state = 3},
  [5479] = {.lex_state = 85, .external_lex_state = 3},
  [5480] = {.lex_state = 178, .external_lex_state = 3},
  [5481] = {.lex_state = 179, .external_lex_state = 3},
  [5482] = {.lex_state = 184, .external_lex_state = 3},
  [5483] = {.lex_state = 179, .external_lex_state = 3},
  [5484] = {.lex_state = 177, .external_lex_state = 3},
  [5485] = {.lex_state = 179, .external_lex_state = 3},
  [5486] = {.lex_state = 177, .external_lex_state = 3},
  [5487] = {.lex_state = 177, .external_lex_state = 3},
  [5488] = {.lex_state = 177, .external_lex_state = 3},
  [5489] = {.lex_state = 179, .external_lex_state = 3},
  [5490] = {.lex_state = 177, .external_lex_state = 3},
  [5491] = {.lex_state = 184, .external_lex_state = 3},
  [5492] = {.lex_state = 184, .external_lex_state = 3},
  [5493] = {.lex_state = 177, .external_lex_state = 3},
  [5494] = {.lex_state = 179, .external_lex_state = 3},
  [5495] = {.lex_state = 186, .external_lex_state = 3},
  [5496] = {.lex_state = 179, .external_lex_state = 3},
  [5497] = {.lex_state = 184, .external_lex_state = 3},
  [5498] = {.lex_state = 177, .external_lex_state = 3},
  [5499] = {.lex_state = 179, .external_lex_state = 3},
  [5500] = {.lex_state = 179, .external_lex_state = 3},
  [5501] = {.lex_state = 186, .external_lex_state = 3},
  [5502] = {.lex_state = 177, .external_lex_state = 3},
  [5503] = {.lex_state = 130, .external_lex_state = 3},
  [5504] = {.lex_state = 177, .external_lex_state = 3},
  [5505] = {.lex_state = 179, .external_lex_state = 3},
  [5506] = {.lex_state = 177, .external_lex_state = 3},
  [5507] = {.lex_state = 159, .external_lex_state = 3},
  [5508] = {.lex_state = 177, .external_lex_state = 3},
  [5509] = {.lex_state = 179, .external_lex_state = 3},
  [5510] = {.lex_state = 184, .external_lex_state = 3},
  [5511] = {.lex_state = 177, .external_lex_state = 3},
  [5512] = {.lex_state = 177, .external_lex_state = 3},
  [5513] = {.lex_state = 179, .external_lex_state = 3},
  [5514] = {.lex_state = 177, .external_lex_state = 3},
  [5515] = {.lex_state = 177, .external_lex_state = 3},
  [5516] = {.lex_state = 130, .external_lex_state = 3},
  [5517] = {.lex_state = 179, .external_lex_state = 3},
  [5518] = {.lex_state = 179, .external_lex_state = 3},
  [5519] = {.lex_state = 177, .external_lex_state = 3},
  [5520] = {.lex_state = 177, .external_lex_state = 3},
  [5521] = {.lex_state = 177, .external_lex_state = 3},
  [5522] = {.lex_state = 184, .external_lex_state = 3},
  [5523] = {.lex_state = 186, .external_lex_state = 3},
  [5524] = {.lex_state = 179, .external_lex_state = 3},
  [5525] = {.lex_state = 178, .external_lex_state = 3},
  [5526] = {.lex_state = 177, .external_lex_state = 3},
  [5527] = {.lex_state = 177, .external_lex_state = 3},
  [5528] = {.lex_state = 156, .external_lex_state = 3},
  [5529] = {.lex_state = 177, .external_lex_state = 3},
  [5530] = {.lex_state = 179, .external_lex_state = 3},
  [5531] = {.lex_state = 177, .external_lex_state = 3},
  [5532] = {.lex_state = 177, .external_lex_state = 3},
  [5533] = {.lex_state = 179, .external_lex_state = 3},
  [5534] = {.lex_state = 179, .external_lex_state = 3},
  [5535] = {.lex_state = 177, .external_lex_state = 3},
  [5536] = {.lex_state = 177, .external_lex_state = 3},
  [5537] = {.lex_state = 179, .external_lex_state = 3},
  [5538] = {.lex_state = 179, .external_lex_state = 3},
  [5539] = {.lex_state = 177, .external_lex_state = 3},
  [5540] = {.lex_state = 177, .external_lex_state = 3},
  [5541] = {.lex_state = 179, .external_lex_state = 3},
  [5542] = {.lex_state = 179, .external_lex_state = 3},
  [5543] = {.lex_state = 177, .external_lex_state = 3},
  [5544] = {.lex_state = 184, .external_lex_state = 3},
  [5545] = {.lex_state = 179, .external_lex_state = 3},
  [5546] = {.lex_state = 184, .external_lex_state = 3},
  [5547] = {.lex_state = 130, .external_lex_state = 3},
  [5548] = {.lex_state = 177, .external_lex_state = 3},
  [5549] = {.lex_state = 177, .external_lex_state = 3},
  [5550] = {.lex_state = 177, .external_lex_state = 3},
  [5551] = {.lex_state = 184, .external_lex_state = 3},
  [5552] = {.lex_state = 177, .external_lex_state = 3},
  [5553] = {.lex_state = 179, .external_lex_state = 3},
  [5554] = {.lex_state = 178, .external_lex_state = 3},
  [5555] = {.lex_state = 177, .external_lex_state = 3},
  [5556] = {.lex_state = 184, .external_lex_state = 3},
  [5557] = {.lex_state = 177, .external_lex_state = 3},
  [5558] = {.lex_state = 179, .external_lex_state = 3},
  [5559] = {.lex_state = 177, .external_lex_state = 3},
  [5560] = {.lex_state = 179, .external_lex_state = 3},
  [5561] = {.lex_state = 179, .external_lex_state = 3},
  [5562] = {.lex_state = 130, .external_lex_state = 3},
  [5563] = {.lex_state = 177, .external_lex_state = 3},
  [5564] = {.lex_state = 184, .external_lex_state = 3},
  [5565] = {.lex_state = 177, .external_lex_state = 3},
  [5566] = {.lex_state = 179, .external_lex_state = 3},
  [5567] = {.lex_state = 180, .external_lex_state = 3},
  [5568] = {.lex_state = 180, .external_lex_state = 3},
  [5569] = {.lex_state = 130, .external_lex_state = 3},
  [5570] = {.lex_state = 130, .external_lex_state = 3},
  [5571] = {.lex_state = 130, .external_lex_state = 3},
  [5572] = {.lex_state = 130, .external_lex_state = 3},
  [5573] = {.lex_state = 84, .external_lex_state = 3},
  [5574] = {.lex_state = 180, .external_lex_state = 3},
  [5575] = {.lex_state = 180, .external_lex_state = 3},
  [5576] = {.lex_state = 180, .external_lex_state = 3},
  [5577] = {.lex_state = 180, .external_lex_state = 3},
  [5578] = {.lex_state = 130, .external_lex_state = 3},
  [5579] = {.lex_state = 180, .external_lex_state = 3},
  [5580] = {.lex_state = 178, .external_lex_state = 3},
  [5581] = {.lex_state = 178, .external_lex_state = 3},
  [5582] = {.lex_state = 87, .external_lex_state = 3},
  [5583] = {.lex_state = 178, .external_lex_state = 3},
  [5584] = {.lex_state = 130, .external_lex_state = 3},
  [5585] = {.lex_state = 180, .external_lex_state = 3},
  [5586] = {.lex_state = 180, .external_lex_state = 3},
  [5587] = {.lex_state = 178, .external_lex_state = 3},
  [5588] = {.lex_state = 180, .external_lex_state = 3},
  [5589] = {.lex_state = 178, .external_lex_state = 3},
  [5590] = {.lex_state = 178, .external_lex_state = 3},
  [5591] = {.lex_state = 178, .external_lex_state = 3},
  [5592] = {.lex_state = 130, .external_lex_state = 3},
  [5593] = {.lex_state = 180, .external_lex_state = 3},
  [5594] = {.lex_state = 178, .external_lex_state = 3},
  [5595] = {.lex_state = 178, .external_lex_state = 3},
  [5596] = {.lex_state = 130, .external_lex_state = 3},
  [5597] = {.lex_state = 180, .external_lex_state = 3},
  [5598] = {.lex_state = 131, .external_lex_state = 3},
  [5599] = {.lex_state = 178, .external_lex_state = 3},
  [5600] = {.lex_state = 87, .external_lex_state = 3},
  [5601] = {.lex_state = 178, .external_lex_state = 3},
  [5602] = {.lex_state = 131, .external_lex_state = 3},
  [5603] = {.lex_state = 130, .external_lex_state = 3},
  [5604] = {.lex_state = 180, .external_lex_state = 3},
  [5605] = {.lex_state = 130, .external_lex_state = 3},
  [5606] = {.lex_state = 180, .external_lex_state = 3},
  [5607] = {.lex_state = 180, .external_lex_state = 3},
  [5608] = {.lex_state = 130, .external_lex_state = 3},
  [5609] = {.lex_state = 131, .external_lex_state = 3},
  [5610] = {.lex_state = 180, .external_lex_state = 3},
  [5611] = {.lex_state = 130, .external_lex_state = 3},
  [5612] = {.lex_state = 180, .external_lex_state = 3},
  [5613] = {.lex_state = 130, .external_lex_state = 3},
  [5614] = {.lex_state = 130, .external_lex_state = 3},
  [5615] = {.lex_state = 130, .external_lex_state = 3},
  [5616] = {.lex_state = 130, .external_lex_state = 3},
  [5617] = {.lex_state = 130, .external_lex_state = 3},
  [5618] = {.lex_state = 130, .external_lex_state = 3},
  [5619] = {.lex_state = 130, .external_lex_state = 3},
  [5620] = {.lex_state = 180, .external_lex_state = 3},
  [5621] = {.lex_state = 130, .external_lex_state = 3},
  [5622] = {.lex_state = 180, .external_lex_state = 3},
  [5623] = {.lex_state = 130, .external_lex_state = 3},
  [5624] = {.lex_state = 180, .external_lex_state = 3},
  [5625] = {.lex_state = 130, .external_lex_state = 3},
  [5626] = {.lex_state = 180, .external_lex_state = 3},
  [5627] = {.lex_state = 180, .external_lex_state = 3},
  [5628] = {.lex_state = 180, .external_lex_state = 3},
  [5629] = {.lex_state = 180, .external_lex_state = 3},
  [5630] = {.lex_state = 180, .external_lex_state = 3},
  [5631] = {.lex_state = 180, .external_lex_state = 3},
  [5632] = {.lex_state = 180, .external_lex_state = 3},
  [5633] = {.lex_state = 130, .external_lex_state = 3},
  [5634] = {.lex_state = 180, .external_lex_state = 3},
  [5635] = {.lex_state = 180, .external_lex_state = 3},
  [5636] = {.lex_state = 180, .external_lex_state = 3},
  [5637] = {.lex_state = 180, .external_lex_state = 3},
  [5638] = {.lex_state = 180, .external_lex_state = 3},
  [5639] = {.lex_state = 180, .external_lex_state = 3},
  [5640] = {.lex_state = 180, .external_lex_state = 3},
  [5641] = {.lex_state = 180, .external_lex_state = 3},
  [5642] = {.lex_state = 130, .external_lex_state = 3},
  [5643] = {.lex_state = 130, .external_lex_state = 3},
  [5644] = {.lex_state = 130, .external_lex_state = 3},
  [5645] = {.lex_state = 130, .external_lex_state = 3},
  [5646] = {.lex_state = 130, .external_lex_state = 3},
  [5647] = {.lex_state = 180, .external_lex_state = 3},
  [5648] = {.lex_state = 130, .external_lex_state = 3},
  [5649] = {.lex_state = 130, .external_lex_state = 3},
  [5650] = {.lex_state = 180, .external_lex_state = 3},
  [5651] = {.lex_state = 180, .external_lex_state = 3},
  [5652] = {.lex_state = 180, .external_lex_state = 3},
  [5653] = {.lex_state = 180, .external_lex_state = 3},
  [5654] = {.lex_state = 180, .external_lex_state = 3},
  [5655] = {.lex_state = 130, .external_lex_state = 3},
  [5656] = {.lex_state = 180, .external_lex_state = 3},
  [5657] = {.lex_state = 178, .external_lex_state = 3},
  [5658] = {.lex_state = 180, .external_lex_state = 3},
  [5659] = {.lex_state = 178, .external_lex_state = 3},
  [5660] = {.lex_state = 158, .external_lex_state = 3},
  [5661] = {.lex_state = 130, .external_lex_state = 3},
  [5662] = {.lex_state = 130, .external_lex_state = 3},
  [5663] = {.lex_state = 180, .external_lex_state = 3},
  [5664] = {.lex_state = 180, .external_lex_state = 3},
  [5665] = {.lex_state = 131, .external_lex_state = 3},
  [5666] = {.lex_state = 131, .external_lex_state = 3},
  [5667] = {.lex_state = 131, .external_lex_state = 3},
  [5668] = {.lex_state = 180, .external_lex_state = 3},
  [5669] = {.lex_state = 130, .external_lex_state = 3},
  [5670] = {.lex_state = 178, .external_lex_state = 3},
  [5671] = {.lex_state = 131, .external_lex_state = 3},
  [5672] = {.lex_state = 178, .external_lex_state = 3},
  [5673] = {.lex_state = 180, .external_lex_state = 3},
  [5674] = {.lex_state = 178, .external_lex_state = 3},
  [5675] = {.lex_state = 84, .external_lex_state = 3},
  [5676] = {.lex_state = 178, .external_lex_state = 3},
  [5677] = {.lex_state = 180, .external_lex_state = 3},
  [5678] = {.lex_state = 178, .external_lex_state = 3},
  [5679] = {.lex_state = 178, .external_lex_state = 3},
  [5680] = {.lex_state = 178, .external_lex_state = 3},
  [5681] = {.lex_state = 131, .external_lex_state = 3},
  [5682] = {.lex_state = 131, .external_lex_state = 3},
  [5683] = {.lex_state = 131, .external_lex_state = 3},
  [5684] = {.lex_state = 130, .external_lex_state = 3},
  [5685] = {.lex_state = 178, .external_lex_state = 3},
  [5686] = {.lex_state = 178, .external_lex_state = 3},
  [5687] = {.lex_state = 178, .external_lex_state = 3},
  [5688] = {.lex_state = 178, .external_lex_state = 3},
  [5689] = {.lex_state = 131, .external_lex_state = 3},
  [5690] = {.lex_state = 130, .external_lex_state = 3},
  [5691] = {.lex_state = 178, .external_lex_state = 3},
  [5692] = {.lex_state = 178, .external_lex_state = 3},
  [5693] = {.lex_state = 178, .external_lex_state = 3},
  [5694] = {.lex_state = 130, .external_lex_state = 3},
  [5695] = {.lex_state = 178, .external_lex_state = 3},
  [5696] = {.lex_state = 178, .external_lex_state = 3},
  [5697] = {.lex_state = 178, .external_lex_state = 3},
  [5698] = {.lex_state = 178, .external_lex_state = 3},
  [5699] = {.lex_state = 178, .external_lex_state = 3},
  [5700] = {.lex_state = 130, .external_lex_state = 3},
  [5701] = {.lex_state = 178, .external_lex_state = 3},
  [5702] = {.lex_state = 178, .external_lex_state = 3},
  [5703] = {.lex_state = 178, .external_lex_state = 3},
  [5704] = {.lex_state = 178, .external_lex_state = 3},
  [5705] = {.lex_state = 130, .external_lex_state = 3},
  [5706] = {.lex_state = 130, .external_lex_state = 3},
  [5707] = {.lex_state = 178, .external_lex_state = 3},
  [5708] = {.lex_state = 130, .external_lex_state = 3},
  [5709] = {.lex_state = 178, .external_lex_state = 3},
  [5710] = {.lex_state = 178, .external_lex_state = 3},
  [5711] = {.lex_state = 178, .external_lex_state = 3},
  [5712] = {.lex_state = 130, .external_lex_state = 3},
  [5713] = {.lex_state = 130, .external_lex_state = 3},
  [5714] = {.lex_state = 178, .external_lex_state = 3},
  [5715] = {.lex_state = 178, .external_lex_state = 3},
  [5716] = {.lex_state = 178, .external_lex_state = 3},
  [5717] = {.lex_state = 178, .external_lex_state = 3},
  [5718] = {.lex_state = 130, .external_lex_state = 3},
  [5719] = {.lex_state = 178, .external_lex_state = 3},
  [5720] = {.lex_state = 130, .external_lex_state = 3},
  [5721] = {.lex_state = 178, .external_lex_state = 3},
  [5722] = {.lex_state = 130, .external_lex_state = 3},
  [5723] = {.lex_state = 178, .external_lex_state = 3},
  [5724] = {.lex_state = 130, .external_lex_state = 3},
  [5725] = {.lex_state = 180, .external_lex_state = 3},
  [5726] = {.lex_state = 130, .external_lex_state = 3},
  [5727] = {.lex_state = 130, .external_lex_state = 3},
  [5728] = {.lex_state = 130, .external_lex_state = 3},
  [5729] = {.lex_state = 178, .external_lex_state = 3},
  [5730] = {.lex_state = 130, .external_lex_state = 3},
  [5731] = {.lex_state = 178, .external_lex_state = 3},
  [5732] = {.lex_state = 130, .external_lex_state = 3},
  [5733] = {.lex_state = 130, .external_lex_state = 3},
  [5734] = {.lex_state = 130, .external_lex_state = 3},
  [5735] = {.lex_state = 130, .external_lex_state = 3},
  [5736] = {.lex_state = 130, .external_lex_state = 3},
  [5737] = {.lex_state = 130, .external_lex_state = 3},
  [5738] = {.lex_state = 130, .external_lex_state = 3},
  [5739] = {.lex_state = 130, .external_lex_state = 3},
  [5740] = {.lex_state = 130, .external_lex_state = 3},
  [5741] = {.lex_state = 130, .external_lex_state = 3},
  [5742] = {.lex_state = 130, .external_lex_state = 3},
  [5743] = {.lex_state = 130, .external_lex_state = 3},
  [5744] = {.lex_state = 130, .external_lex_state = 3},
  [5745] = {.lex_state = 130, .external_lex_state = 3},
  [5746] = {.lex_state = 130, .external_lex_state = 3},
  [5747] = {.lex_state = 130, .external_lex_state = 3},
  [5748] = {.lex_state = 130, .external_lex_state = 3},
  [5749] = {.lex_state = 130, .external_lex_state = 3},
  [5750] = {.lex_state = 130, .external_lex_state = 3},
  [5751] = {.lex_state = 130, .external_lex_state = 3},
  [5752] = {.lex_state = 130, .external_lex_state = 3},
  [5753] = {.lex_state = 130, .external_lex_state = 3},
  [5754] = {.lex_state = 131, .external_lex_state = 3},
  [5755] = {.lex_state = 131, .external_lex_state = 3},
  [5756] = {.lex_state = 120, .external_lex_state = 3},
  [5757] = {.lex_state = 120, .external_lex_state = 3},
  [5758] = {.lex_state = 28, .external_lex_state = 3},
  [5759] = {.lex_state = 28, .external_lex_state = 3},
  [5760] = {.lex_state = 28, .external_lex_state = 3},
  [5761] = {.lex_state = 28, .external_lex_state = 3},
  [5762] = {.lex_state = 28, .external_lex_state = 3},
  [5763] = {.lex_state = 28, .external_lex_state = 3},
  [5764] = {.lex_state = 131, .external_lex_state = 3},
  [5765] = {.lex_state = 131, .external_lex_state = 3},
  [5766] = {.lex_state = 86, .external_lex_state = 3},
  [5767] = {.lex_state = 28, .external_lex_state = 3},
  [5768] = {.lex_state = 131, .external_lex_state = 3},
  [5769] = {.lex_state = 86, .external_lex_state = 3},
  [5770] = {.lex_state = 131, .external_lex_state = 3},
  [5771] = {.lex_state = 131, .external_lex_state = 3},
  [5772] = {.lex_state = 131, .external_lex_state = 3},
  [5773] = {.lex_state = 131, .external_lex_state = 3},
  [5774] = {.lex_state = 28, .external_lex_state = 3},
  [5775] = {.lex_state = 28, .external_lex_state = 3},
  [5776] = {.lex_state = 120, .external_lex_state = 3},
  [5777] = {.lex_state = 120, .external_lex_state = 3},
  [5778] = {.lex_state = 131, .external_lex_state = 3},
  [5779] = {.lex_state = 131, .external_lex_state = 3},
  [5780] = {.lex_state = 120, .external_lex_state = 3},
  [5781] = {.lex_state = 131, .external_lex_state = 3},
  [5782] = {.lex_state = 131, .external_lex_state = 3},
  [5783] = {.lex_state = 131, .external_lex_state = 3},
  [5784] = {.lex_state = 131, .external_lex_state = 3},
  [5785] = {.lex_state = 120, .external_lex_state = 3},
  [5786] = {.lex_state = 131, .external_lex_state = 3},
  [5787] = {.lex_state = 120, .external_lex_state = 3},
  [5788] = {.lex_state = 131, .external_lex_state = 3},
  [5789] = {.lex_state = 131, .external_lex_state = 3},
  [5790] = {.lex_state = 131, .external_lex_state = 3},
  [5791] = {.lex_state = 120, .external_lex_state = 3},
  [5792] = {.lex_state = 131, .external_lex_state = 3},
  [5793] = {.lex_state = 120, .external_lex_state = 3},
  [5794] = {.lex_state = 131, .external_lex_state = 3},
  [5795] = {.lex_state = 131, .external_lex_state = 3},
  [5796] = {.lex_state = 131, .external_lex_state = 3},
  [5797] = {.lex_state = 131, .external_lex_state = 3},
  [5798] = {.lex_state = 131, .external_lex_state = 3},
  [5799] = {.lex_state = 120, .external_lex_state = 3},
  [5800] = {.lex_state = 131, .external_lex_state = 3},
  [5801] = {.lex_state = 131, .external_lex_state = 3},
  [5802] = {.lex_state = 131, .external_lex_state = 3},
  [5803] = {.lex_state = 131, .external_lex_state = 3},
  [5804] = {.lex_state = 131, .external_lex_state = 3},
  [5805] = {.lex_state = 131, .external_lex_state = 3},
  [5806] = {.lex_state = 131, .external_lex_state = 3},
  [5807] = {.lex_state = 131, .external_lex_state = 3},
  [5808] = {.lex_state = 131, .external_lex_state = 3},
  [5809] = {.lex_state = 131, .external_lex_state = 3},
  [5810] = {.lex_state = 131, .external_lex_state = 3},
  [5811] = {.lex_state = 131, .external_lex_state = 3},
  [5812] = {.lex_state = 131, .external_lex_state = 3},
  [5813] = {.lex_state = 131, .external_lex_state = 3},
  [5814] = {.lex_state = 131, .external_lex_state = 3},
  [5815] = {.lex_state = 131, .external_lex_state = 3},
  [5816] = {.lex_state = 131, .external_lex_state = 3},
  [5817] = {.lex_state = 131, .external_lex_state = 3},
  [5818] = {.lex_state = 131, .external_lex_state = 3},
  [5819] = {.lex_state = 131, .external_lex_state = 3},
  [5820] = {.lex_state = 131, .external_lex_state = 3},
  [5821] = {.lex_state = 131, .external_lex_state = 3},
  [5822] = {.lex_state = 131, .external_lex_state = 3},
  [5823] = {.lex_state = 131, .external_lex_state = 3},
  [5824] = {.lex_state = 131, .external_lex_state = 3},
  [5825] = {.lex_state = 131, .external_lex_state = 3},
  [5826] = {.lex_state = 131, .external_lex_state = 3},
  [5827] = {.lex_state = 131, .external_lex_state = 3},
  [5828] = {.lex_state = 131, .external_lex_state = 3},
  [5829] = {.lex_state = 131, .external_lex_state = 3},
  [5830] = {.lex_state = 131, .external_lex_state = 3},
  [5831] = {.lex_state = 131, .external_lex_state = 3},
  [5832] = {.lex_state = 131, .external_lex_state = 3},
  [5833] = {.lex_state = 131, .external_lex_state = 3},
  [5834] = {.lex_state = 131, .external_lex_state = 3},
  [5835] = {.lex_state = 131, .external_lex_state = 3},
  [5836] = {.lex_state = 131, .external_lex_state = 3},
  [5837] = {.lex_state = 120, .external_lex_state = 3},
  [5838] = {.lex_state = 131, .external_lex_state = 3},
  [5839] = {.lex_state = 131, .external_lex_state = 3},
  [5840] = {.lex_state = 131, .external_lex_state = 3},
  [5841] = {.lex_state = 131, .external_lex_state = 3},
  [5842] = {.lex_state = 131, .external_lex_state = 3},
  [5843] = {.lex_state = 131, .external_lex_state = 3},
  [5844] = {.lex_state = 131, .external_lex_state = 3},
  [5845] = {.lex_state = 131, .external_lex_state = 3},
  [5846] = {.lex_state = 131, .external_lex_state = 3},
  [5847] = {.lex_state = 131, .external_lex_state = 3},
  [5848] = {.lex_state = 131, .external_lex_state = 3},
  [5849] = {.lex_state = 35, .external_lex_state = 3},
  [5850] = {.lex_state = 35, .external_lex_state = 3},
  [5851] = {.lex_state = 34, .external_lex_state = 3},
  [5852] = {.lex_state = 34, .external_lex_state = 3},
  [5853] = {.lex_state = 35, .external_lex_state = 3},
  [5854] = {.lex_state = 34, .external_lex_state = 3},
  [5855] = {.lex_state = 120, .external_lex_state = 3},
  [5856] = {.lex_state = 120, .external_lex_state = 3},
  [5857] = {.lex_state = 120, .external_lex_state = 3},
  [5858] = {.lex_state = 120, .external_lex_state = 3},
  [5859] = {.lex_state = 35, .external_lex_state = 3},
  [5860] = {.lex_state = 120, .external_lex_state = 3},
  [5861] = {.lex_state = 35, .external_lex_state = 3},
  [5862] = {.lex_state = 34, .external_lex_state = 3},
  [5863] = {.lex_state = 34, .external_lex_state = 3},
  [5864] = {.lex_state = 120, .external_lex_state = 3},
  [5865] = {.lex_state = 122, .external_lex_state = 3},
  [5866] = {.lex_state = 121, .external_lex_state = 3},
  [5867] = {.lex_state = 122, .external_lex_state = 3},
  [5868] = {.lex_state = 34, .external_lex_state = 3},
  [5869] = {.lex_state = 120, .external_lex_state = 3},
  [5870] = {.lex_state = 121, .external_lex_state = 3},
  [5871] = {.lex_state = 34, .external_lex_state = 3},
  [5872] = {.lex_state = 34, .external_lex_state = 3},
  [5873] = {.lex_state = 34, .external_lex_state = 3},
  [5874] = {.lex_state = 120, .external_lex_state = 3},
  [5875] = {.lex_state = 35, .external_lex_state = 3},
  [5876] = {.lex_state = 34, .external_lex_state = 3},
  [5877] = {.lex_state = 34, .external_lex_state = 3},
  [5878] = {.lex_state = 34, .external_lex_state = 3},
  [5879] = {.lex_state = 34, .external_lex_state = 3},
  [5880] = {.lex_state = 35, .external_lex_state = 3},
  [5881] = {.lex_state = 120, .external_lex_state = 3},
  [5882] = {.lex_state = 34, .external_lex_state = 3},
  [5883] = {.lex_state = 120, .external_lex_state = 3},
  [5884] = {.lex_state = 120, .external_lex_state = 3},
  [5885] = {.lex_state = 120, .external_lex_state = 3},
  [5886] = {.lex_state = 34, .external_lex_state = 3},
  [5887] = {.lex_state = 34, .external_lex_state = 3},
  [5888] = {.lex_state = 34, .external_lex_state = 3},
  [5889] = {.lex_state = 120, .external_lex_state = 3},
  [5890] = {.lex_state = 120, .external_lex_state = 3},
  [5891] = {.lex_state = 34, .external_lex_state = 3},
  [5892] = {.lex_state = 125, .external_lex_state = 3},
  [5893] = {.lex_state = 34, .external_lex_state = 3},
  [5894] = {.lex_state = 34, .external_lex_state = 3},
  [5895] = {.lex_state = 118, .external_lex_state = 3},
  [5896] = {.lex_state = 34, .external_lex_state = 3},
  [5897] = {.lex_state = 130, .external_lex_state = 3},
  [5898] = {.lex_state = 34, .external_lex_state = 3},
  [5899] = {.lex_state = 34, .external_lex_state = 3},
  [5900] = {.lex_state = 34, .external_lex_state = 3},
  [5901] = {.lex_state = 34, .external_lex_state = 3},
  [5902] = {.lex_state = 120, .external_lex_state = 3},
  [5903] = {.lex_state = 34, .external_lex_state = 3},
  [5904] = {.lex_state = 34, .external_lex_state = 3},
  [5905] = {.lex_state = 34, .external_lex_state = 3},
  [5906] = {.lex_state = 120, .external_lex_state = 3},
  [5907] = {.lex_state = 124, .external_lex_state = 3},
  [5908] = {.lex_state = 35, .external_lex_state = 3},
  [5909] = {.lex_state = 35, .external_lex_state = 3},
  [5910] = {.lex_state = 34, .external_lex_state = 3},
  [5911] = {.lex_state = 34, .external_lex_state = 3},
  [5912] = {.lex_state = 34, .external_lex_state = 3},
  [5913] = {.lex_state = 34, .external_lex_state = 3},
  [5914] = {.lex_state = 34, .external_lex_state = 3},
  [5915] = {.lex_state = 120, .external_lex_state = 3},
  [5916] = {.lex_state = 34, .external_lex_state = 3},
  [5917] = {.lex_state = 34, .external_lex_state = 3},
  [5918] = {.lex_state = 34, .external_lex_state = 3},
  [5919] = {.lex_state = 34, .external_lex_state = 3},
  [5920] = {.lex_state = 122, .external_lex_state = 3},
  [5921] = {.lex_state = 34, .external_lex_state = 3},
  [5922] = {.lex_state = 34, .external_lex_state = 3},
  [5923] = {.lex_state = 34, .external_lex_state = 3},
  [5924] = {.lex_state = 34, .external_lex_state = 3},
  [5925] = {.lex_state = 120, .external_lex_state = 3},
  [5926] = {.lex_state = 35, .external_lex_state = 3},
  [5927] = {.lex_state = 35, .external_lex_state = 3},
  [5928] = {.lex_state = 35, .external_lex_state = 3},
  [5929] = {.lex_state = 34, .external_lex_state = 3},
  [5930] = {.lex_state = 35, .external_lex_state = 3},
  [5931] = {.lex_state = 35, .external_lex_state = 3},
  [5932] = {.lex_state = 34, .external_lex_state = 3},
  [5933] = {.lex_state = 34, .external_lex_state = 3},
  [5934] = {.lex_state = 34, .external_lex_state = 3},
  [5935] = {.lex_state = 35, .external_lex_state = 3},
  [5936] = {.lex_state = 34, .external_lex_state = 3},
  [5937] = {.lex_state = 120, .external_lex_state = 3},
  [5938] = {.lex_state = 120, .external_lex_state = 3},
  [5939] = {.lex_state = 34, .external_lex_state = 3},
  [5940] = {.lex_state = 35, .external_lex_state = 3},
  [5941] = {.lex_state = 120, .external_lex_state = 3},
  [5942] = {.lex_state = 35, .external_lex_state = 3},
  [5943] = {.lex_state = 120, .external_lex_state = 3},
  [5944] = {.lex_state = 120, .external_lex_state = 3},
  [5945] = {.lex_state = 122, .external_lex_state = 3},
  [5946] = {.lex_state = 120, .external_lex_state = 3},
  [5947] = {.lex_state = 120, .external_lex_state = 3},
  [5948] = {.lex_state = 122, .external_lex_state = 3},
  [5949] = {.lex_state = 120, .external_lex_state = 3},
  [5950] = {.lex_state = 35, .external_lex_state = 3},
  [5951] = {.lex_state = 120, .external_lex_state = 3},
  [5952] = {.lex_state = 122, .external_lex_state = 3},
  [5953] = {.lex_state = 120, .external_lex_state = 3},
  [5954] = {.lex_state = 35, .external_lex_state = 3},
  [5955] = {.lex_state = 34, .external_lex_state = 3},
  [5956] = {.lex_state = 122, .external_lex_state = 3},
  [5957] = {.lex_state = 35, .external_lex_state = 3},
  [5958] = {.lex_state = 35, .external_lex_state = 3},
  [5959] = {.lex_state = 35, .external_lex_state = 3},
  [5960] = {.lex_state = 35, .external_lex_state = 3},
  [5961] = {.lex_state = 34, .external_lex_state = 3},
  [5962] = {.lex_state = 35, .external_lex_state = 3},
  [5963] = {.lex_state = 120, .external_lex_state = 3},
  [5964] = {.lex_state = 35, .external_lex_state = 3},
  [5965] = {.lex_state = 35, .external_lex_state = 3},
  [5966] = {.lex_state = 35, .external_lex_state = 3},
  [5967] = {.lex_state = 35, .external_lex_state = 3},
  [5968] = {.lex_state = 35, .external_lex_state = 3},
  [5969] = {.lex_state = 35, .external_lex_state = 3},
  [5970] = {.lex_state = 35, .external_lex_state = 3},
  [5971] = {.lex_state = 35, .external_lex_state = 3},
  [5972] = {.lex_state = 120, .external_lex_state = 3},
  [5973] = {.lex_state = 35, .external_lex_state = 3},
  [5974] = {.lex_state = 35, .external_lex_state = 3},
  [5975] = {.lex_state = 35, .external_lex_state = 3},
  [5976] = {.lex_state = 35, .external_lex_state = 3},
  [5977] = {.lex_state = 124, .external_lex_state = 3},
  [5978] = {.lex_state = 35, .external_lex_state = 3},
  [5979] = {.lex_state = 35, .external_lex_state = 3},
  [5980] = {.lex_state = 35, .external_lex_state = 3},
  [5981] = {.lex_state = 35, .external_lex_state = 3},
  [5982] = {.lex_state = 35, .external_lex_state = 3},
  [5983] = {.lex_state = 120, .external_lex_state = 3},
  [5984] = {.lex_state = 35, .external_lex_state = 3},
  [5985] = {.lex_state = 35, .external_lex_state = 3},
  [5986] = {.lex_state = 35, .external_lex_state = 3},
  [5987] = {.lex_state = 120, .external_lex_state = 3},
  [5988] = {.lex_state = 121, .external_lex_state = 3},
  [5989] = {.lex_state = 35, .external_lex_state = 3},
  [5990] = {.lex_state = 121, .external_lex_state = 3},
  [5991] = {.lex_state = 35, .external_lex_state = 3},
  [5992] = {.lex_state = 35, .external_lex_state = 3},
  [5993] = {.lex_state = 35, .external_lex_state = 3},
  [5994] = {.lex_state = 120, .external_lex_state = 3},
  [5995] = {.lex_state = 125, .external_lex_state = 3},
  [5996] = {.lex_state = 35, .external_lex_state = 3},
  [5997] = {.lex_state = 121, .external_lex_state = 3},
  [5998] = {.lex_state = 122, .external_lex_state = 3},
  [5999] = {.lex_state = 120, .external_lex_state = 3},
  [6000] = {.lex_state = 35, .external_lex_state = 3},
  [6001] = {.lex_state = 34, .external_lex_state = 3},
  [6002] = {.lex_state = 120, .external_lex_state = 3},
  [6003] = {.lex_state = 120, .external_lex_state = 3},
  [6004] = {.lex_state = 120, .external_lex_state = 3},
  [6005] = {.lex_state = 35, .external_lex_state = 3},
  [6006] = {.lex_state = 35, .external_lex_state = 3},
  [6007] = {.lex_state = 35, .external_lex_state = 3},
  [6008] = {.lex_state = 120, .external_lex_state = 3},
  [6009] = {.lex_state = 121, .external_lex_state = 3},
  [6010] = {.lex_state = 120, .external_lex_state = 3},
  [6011] = {.lex_state = 120, .external_lex_state = 3},
  [6012] = {.lex_state = 121, .external_lex_state = 3},
  [6013] = {.lex_state = 35, .external_lex_state = 3},
  [6014] = {.lex_state = 35, .external_lex_state = 3},
  [6015] = {.lex_state = 124, .external_lex_state = 3},
  [6016] = {.lex_state = 122, .external_lex_state = 3},
  [6017] = {.lex_state = 34, .external_lex_state = 3},
  [6018] = {.lex_state = 121, .external_lex_state = 3},
  [6019] = {.lex_state = 121, .external_lex_state = 3},
  [6020] = {.lex_state = 120, .external_lex_state = 3},
  [6021] = {.lex_state = 121, .external_lex_state = 3},
  [6022] = {.lex_state = 35, .external_lex_state = 3},
  [6023] = {.lex_state = 35, .external_lex_state = 3},
  [6024] = {.lex_state = 35, .external_lex_state = 3},
  [6025] = {.lex_state = 126, .external_lex_state = 3},
  [6026] = {.lex_state = 35, .external_lex_state = 3},
  [6027] = {.lex_state = 35, .external_lex_state = 3},
  [6028] = {.lex_state = 35, .external_lex_state = 3},
  [6029] = {.lex_state = 35, .external_lex_state = 3},
  [6030] = {.lex_state = 35, .external_lex_state = 3},
  [6031] = {.lex_state = 34, .external_lex_state = 3},
  [6032] = {.lex_state = 120, .external_lex_state = 3},
  [6033] = {.lex_state = 34, .external_lex_state = 3},
  [6034] = {.lex_state = 120, .external_lex_state = 3},
  [6035] = {.lex_state = 125, .external_lex_state = 3},
  [6036] = {.lex_state = 125, .external_lex_state = 3},
  [6037] = {.lex_state = 125, .external_lex_state = 3},
  [6038] = {.lex_state = 35, .external_lex_state = 3},
  [6039] = {.lex_state = 126, .external_lex_state = 3},
  [6040] = {.lex_state = 34, .external_lex_state = 3},
  [6041] = {.lex_state = 121, .external_lex_state = 3},
  [6042] = {.lex_state = 120, .external_lex_state = 3},
  [6043] = {.lex_state = 120, .external_lex_state = 3},
  [6044] = {.lex_state = 35, .external_lex_state = 3},
  [6045] = {.lex_state = 120, .external_lex_state = 3},
  [6046] = {.lex_state = 35, .external_lex_state = 3},
  [6047] = {.lex_state = 120, .external_lex_state = 3},
  [6048] = {.lex_state = 34, .external_lex_state = 3},
  [6049] = {.lex_state = 35, .external_lex_state = 3},
  [6050] = {.lex_state = 85, .external_lex_state = 3},
  [6051] = {.lex_state = 125, .external_lex_state = 3},
  [6052] = {.lex_state = 125, .external_lex_state = 3},
  [6053] = {.lex_state = 125, .external_lex_state = 3},
  [6054] = {.lex_state = 35, .external_lex_state = 3},
  [6055] = {.lex_state = 35, .external_lex_state = 3},
  [6056] = {.lex_state = 35, .external_lex_state = 3},
  [6057] = {.lex_state = 120, .external_lex_state = 3},
  [6058] = {.lex_state = 122, .external_lex_state = 3},
  [6059] = {.lex_state = 35, .external_lex_state = 3},
  [6060] = {.lex_state = 35, .external_lex_state = 3},
  [6061] = {.lex_state = 126, .external_lex_state = 3},
  [6062] = {.lex_state = 35, .external_lex_state = 3},
  [6063] = {.lex_state = 34, .external_lex_state = 3},
  [6064] = {.lex_state = 120, .external_lex_state = 3},
  [6065] = {.lex_state = 120, .external_lex_state = 3},
  [6066] = {.lex_state = 120, .external_lex_state = 3},
  [6067] = {.lex_state = 35, .external_lex_state = 3},
  [6068] = {.lex_state = 34, .external_lex_state = 3},
  [6069] = {.lex_state = 120, .external_lex_state = 3},
  [6070] = {.lex_state = 124, .external_lex_state = 3},
  [6071] = {.lex_state = 120, .external_lex_state = 3},
  [6072] = {.lex_state = 120, .external_lex_state = 3},
  [6073] = {.lex_state = 120, .external_lex_state = 3},
  [6074] = {.lex_state = 124, .external_lex_state = 3},
  [6075] = {.lex_state = 120, .external_lex_state = 3},
  [6076] = {.lex_state = 124, .external_lex_state = 3},
  [6077] = {.lex_state = 120, .external_lex_state = 3},
  [6078] = {.lex_state = 124, .external_lex_state = 3},
  [6079] = {.lex_state = 120, .external_lex_state = 3},
  [6080] = {.lex_state = 124, .external_lex_state = 3},
  [6081] = {.lex_state = 34, .external_lex_state = 3},
  [6082] = {.lex_state = 124, .external_lex_state = 3},
  [6083] = {.lex_state = 118, .external_lex_state = 3},
  [6084] = {.lex_state = 120, .external_lex_state = 3},
  [6085] = {.lex_state = 34, .external_lex_state = 3},
  [6086] = {.lex_state = 35, .external_lex_state = 3},
  [6087] = {.lex_state = 120, .external_lex_state = 3},
  [6088] = {.lex_state = 34, .external_lex_state = 3},
  [6089] = {.lex_state = 120, .external_lex_state = 3},
  [6090] = {.lex_state = 34, .external_lex_state = 3},
  [6091] = {.lex_state = 34, .external_lex_state = 3},
  [6092] = {.lex_state = 34, .external_lex_state = 3},
  [6093] = {.lex_state = 120, .external_lex_state = 3},
  [6094] = {.lex_state = 34, .external_lex_state = 3},
  [6095] = {.lex_state = 34, .external_lex_state = 3},
  [6096] = {.lex_state = 34, .external_lex_state = 3},
  [6097] = {.lex_state = 124, .external_lex_state = 3},
  [6098] = {.lex_state = 34, .external_lex_state = 3},
  [6099] = {.lex_state = 34, .external_lex_state = 3},
  [6100] = {.lex_state = 118, .external_lex_state = 3},
  [6101] = {.lex_state = 35, .external_lex_state = 3},
  [6102] = {.lex_state = 34, .external_lex_state = 3},
  [6103] = {.lex_state = 34, .external_lex_state = 3},
  [6104] = {.lex_state = 122, .external_lex_state = 3},
  [6105] = {.lex_state = 34, .external_lex_state = 3},
  [6106] = {.lex_state = 120, .external_lex_state = 3},
  [6107] = {.lex_state = 120, .external_lex_state = 3},
  [6108] = {.lex_state = 120, .external_lex_state = 3},
  [6109] = {.lex_state = 118, .external_lex_state = 3},
  [6110] = {.lex_state = 120, .external_lex_state = 3},
  [6111] = {.lex_state = 120, .external_lex_state = 3},
  [6112] = {.lex_state = 120, .external_lex_state = 3},
  [6113] = {.lex_state = 120, .external_lex_state = 3},
  [6114] = {.lex_state = 120, .external_lex_state = 3},
  [6115] = {.lex_state = 34, .external_lex_state = 3},
  [6116] = {.lex_state = 34, .external_lex_state = 3},
  [6117] = {.lex_state = 124, .external_lex_state = 3},
  [6118] = {.lex_state = 126, .external_lex_state = 3},
  [6119] = {.lex_state = 126, .external_lex_state = 3},
  [6120] = {.lex_state = 126, .external_lex_state = 3},
  [6121] = {.lex_state = 126, .external_lex_state = 3},
  [6122] = {.lex_state = 34, .external_lex_state = 3},
  [6123] = {.lex_state = 118, .external_lex_state = 3},
  [6124] = {.lex_state = 126, .external_lex_state = 3},
  [6125] = {.lex_state = 126, .external_lex_state = 3},
  [6126] = {.lex_state = 126, .external_lex_state = 3},
  [6127] = {.lex_state = 35, .external_lex_state = 3},
  [6128] = {.lex_state = 34, .external_lex_state = 3},
  [6129] = {.lex_state = 125, .external_lex_state = 3},
  [6130] = {.lex_state = 34, .external_lex_state = 3},
  [6131] = {.lex_state = 35, .external_lex_state = 3},
  [6132] = {.lex_state = 34, .external_lex_state = 3},
  [6133] = {.lex_state = 34, .external_lex_state = 3},
  [6134] = {.lex_state = 35, .external_lex_state = 3},
  [6135] = {.lex_state = 126, .external_lex_state = 3},
  [6136] = {.lex_state = 34, .external_lex_state = 3},
  [6137] = {.lex_state = 125, .external_lex_state = 3},
  [6138] = {.lex_state = 120, .external_lex_state = 3},
  [6139] = {.lex_state = 120, .external_lex_state = 3},
  [6140] = {.lex_state = 118, .external_lex_state = 3},
  [6141] = {.lex_state = 118, .external_lex_state = 3},
  [6142] = {.lex_state = 118, .external_lex_state = 3},
  [6143] = {.lex_state = 35, .external_lex_state = 3},
  [6144] = {.lex_state = 34, .external_lex_state = 3},
  [6145] = {.lex_state = 34, .external_lex_state = 3},
  [6146] = {.lex_state = 125, .external_lex_state = 3},
  [6147] = {.lex_state = 35, .external_lex_state = 3},
  [6148] = {.lex_state = 118, .external_lex_state = 3},
  [6149] = {.lex_state = 118, .external_lex_state = 3},
  [6150] = {.lex_state = 118, .external_lex_state = 3},
  [6151] = {.lex_state = 129, .external_lex_state = 3},
  [6152] = {.lex_state = 421, .external_lex_state = 3},
  [6153] = {.lex_state = 126, .external_lex_state = 3},
  [6154] = {.lex_state = 118, .external_lex_state = 3},
  [6155] = {.lex_state = 121, .external_lex_state = 3},
  [6156] = {.lex_state = 118, .external_lex_state = 3},
  [6157] = {.lex_state = 126, .external_lex_state = 3},
  [6158] = {.lex_state = 121, .external_lex_state = 3},
  [6159] = {.lex_state = 118, .external_lex_state = 3},
  [6160] = {.lex_state = 122, .external_lex_state = 3},
  [6161] = {.lex_state = 118, .external_lex_state = 3},
  [6162] = {.lex_state = 126, .external_lex_state = 3},
  [6163] = {.lex_state = 118, .external_lex_state = 3},
  [6164] = {.lex_state = 118, .external_lex_state = 3},
  [6165] = {.lex_state = 121, .external_lex_state = 3},
  [6166] = {.lex_state = 126, .external_lex_state = 3},
  [6167] = {.lex_state = 121, .external_lex_state = 3},
  [6168] = {.lex_state = 121, .external_lex_state = 3},
  [6169] = {.lex_state = 118, .external_lex_state = 3},
  [6170] = {.lex_state = 121, .external_lex_state = 3},
  [6171] = {.lex_state = 118, .external_lex_state = 3},
  [6172] = {.lex_state = 126, .external_lex_state = 3},
  [6173] = {.lex_state = 126, .external_lex_state = 3},
  [6174] = {.lex_state = 118, .external_lex_state = 3},
  [6175] = {.lex_state = 126, .external_lex_state = 3},
  [6176] = {.lex_state = 123, .external_lex_state = 3},
  [6177] = {.lex_state = 126, .external_lex_state = 3},
  [6178] = {.lex_state = 126, .external_lex_state = 3},
  [6179] = {.lex_state = 126, .external_lex_state = 3},
  [6180] = {.lex_state = 126, .external_lex_state = 3},
  [6181] = {.lex_state = 118, .external_lex_state = 3},
  [6182] = {.lex_state = 122, .external_lex_state = 3},
  [6183] = {.lex_state = 123, .external_lex_state = 3},
  [6184] = {.lex_state = 124, .external_lex_state = 3},
  [6185] = {.lex_state = 126, .external_lex_state = 3},
  [6186] = {.lex_state = 126, .external_lex_state = 3},
  [6187] = {.lex_state = 118, .external_lex_state = 3},
  [6188] = {.lex_state = 125, .external_lex_state = 3},
  [6189] = {.lex_state = 121, .external_lex_state = 3},
  [6190] = {.lex_state = 123, .external_lex_state = 3},
  [6191] = {.lex_state = 118, .external_lex_state = 3},
  [6192] = {.lex_state = 126, .external_lex_state = 3},
  [6193] = {.lex_state = 126, .external_lex_state = 3},
  [6194] = {.lex_state = 126, .external_lex_state = 3},
  [6195] = {.lex_state = 122, .external_lex_state = 3},
  [6196] = {.lex_state = 125, .external_lex_state = 3},
  [6197] = {.lex_state = 126, .external_lex_state = 3},
  [6198] = {.lex_state = 126, .external_lex_state = 3},
  [6199] = {.lex_state = 126, .external_lex_state = 3},
  [6200] = {.lex_state = 118, .external_lex_state = 3},
  [6201] = {.lex_state = 124, .external_lex_state = 3},
  [6202] = {.lex_state = 124, .external_lex_state = 3},
  [6203] = {.lex_state = 118, .external_lex_state = 3},
  [6204] = {.lex_state = 126, .external_lex_state = 3},
  [6205] = {.lex_state = 126, .external_lex_state = 3},
  [6206] = {.lex_state = 124, .external_lex_state = 3},
  [6207] = {.lex_state = 124, .external_lex_state = 3},
  [6208] = {.lex_state = 126, .external_lex_state = 3},
  [6209] = {.lex_state = 118, .external_lex_state = 3},
  [6210] = {.lex_state = 124, .external_lex_state = 3},
  [6211] = {.lex_state = 125, .external_lex_state = 3},
  [6212] = {.lex_state = 125, .external_lex_state = 3},
  [6213] = {.lex_state = 126, .external_lex_state = 3},
  [6214] = {.lex_state = 126, .external_lex_state = 3},
  [6215] = {.lex_state = 126, .external_lex_state = 3},
  [6216] = {.lex_state = 126, .external_lex_state = 3},
  [6217] = {.lex_state = 118, .external_lex_state = 3},
  [6218] = {.lex_state = 126, .external_lex_state = 3},
  [6219] = {.lex_state = 118, .external_lex_state = 3},
  [6220] = {.lex_state = 126, .external_lex_state = 3},
  [6221] = {.lex_state = 126, .external_lex_state = 3},
  [6222] = {.lex_state = 126, .external_lex_state = 3},
  [6223] = {.lex_state = 118, .external_lex_state = 3},
  [6224] = {.lex_state = 122, .external_lex_state = 3},
  [6225] = {.lex_state = 126, .external_lex_state = 3},
  [6226] = {.lex_state = 126, .external_lex_state = 3},
  [6227] = {.lex_state = 126, .external_lex_state = 3},
  [6228] = {.lex_state = 126, .external_lex_state = 3},
  [6229] = {.lex_state = 118, .external_lex_state = 3},
  [6230] = {.lex_state = 126, .external_lex_state = 3},
  [6231] = {.lex_state = 126, .external_lex_state = 3},
  [6232] = {.lex_state = 118, .external_lex_state = 3},
  [6233] = {.lex_state = 118, .external_lex_state = 3},
  [6234] = {.lex_state = 125, .external_lex_state = 3},
  [6235] = {.lex_state = 118, .external_lex_state = 3},
  [6236] = {.lex_state = 126, .external_lex_state = 3},
  [6237] = {.lex_state = 122, .external_lex_state = 3},
  [6238] = {.lex_state = 126, .external_lex_state = 3},
  [6239] = {.lex_state = 126, .external_lex_state = 3},
  [6240] = {.lex_state = 126, .external_lex_state = 3},
  [6241] = {.lex_state = 118, .external_lex_state = 3},
  [6242] = {.lex_state = 122, .external_lex_state = 3},
  [6243] = {.lex_state = 118, .external_lex_state = 3},
  [6244] = {.lex_state = 118, .external_lex_state = 3},
  [6245] = {.lex_state = 118, .external_lex_state = 3},
  [6246] = {.lex_state = 122, .external_lex_state = 3},
  [6247] = {.lex_state = 126, .external_lex_state = 3},
  [6248] = {.lex_state = 122, .external_lex_state = 3},
  [6249] = {.lex_state = 122, .external_lex_state = 3},
  [6250] = {.lex_state = 125, .external_lex_state = 3},
  [6251] = {.lex_state = 118, .external_lex_state = 3},
  [6252] = {.lex_state = 124, .external_lex_state = 3},
  [6253] = {.lex_state = 118, .external_lex_state = 3},
  [6254] = {.lex_state = 118, .external_lex_state = 3},
  [6255] = {.lex_state = 124, .external_lex_state = 3},
  [6256] = {.lex_state = 118, .external_lex_state = 3},
  [6257] = {.lex_state = 124, .external_lex_state = 3},
  [6258] = {.lex_state = 122, .external_lex_state = 3},
  [6259] = {.lex_state = 118, .external_lex_state = 3},
  [6260] = {.lex_state = 118, .external_lex_state = 3},
  [6261] = {.lex_state = 122, .external_lex_state = 3},
  [6262] = {.lex_state = 126, .external_lex_state = 3},
  [6263] = {.lex_state = 118, .external_lex_state = 3},
  [6264] = {.lex_state = 118, .external_lex_state = 3},
  [6265] = {.lex_state = 124, .external_lex_state = 3},
  [6266] = {.lex_state = 125, .external_lex_state = 3},
  [6267] = {.lex_state = 124, .external_lex_state = 3},
  [6268] = {.lex_state = 125, .external_lex_state = 3},
  [6269] = {.lex_state = 124, .external_lex_state = 3},
  [6270] = {.lex_state = 124, .external_lex_state = 3},
  [6271] = {.lex_state = 121, .external_lex_state = 3},
  [6272] = {.lex_state = 124, .external_lex_state = 3},
  [6273] = {.lex_state = 421, .external_lex_state = 3},
  [6274] = {.lex_state = 125, .external_lex_state = 3},
  [6275] = {.lex_state = 7, .external_lex_state = 2},
  [6276] = {.lex_state = 121, .external_lex_state = 3},
  [6277] = {.lex_state = 7, .external_lex_state = 2},
  [6278] = {.lex_state = 124, .external_lex_state = 3},
  [6279] = {.lex_state = 118, .external_lex_state = 3},
  [6280] = {.lex_state = 421, .external_lex_state = 3},
  [6281] = {.lex_state = 118, .external_lex_state = 3},
  [6282] = {.lex_state = 124, .external_lex_state = 3},
  [6283] = {.lex_state = 118, .external_lex_state = 3},
  [6284] = {.lex_state = 124, .external_lex_state = 3},
  [6285] = {.lex_state = 124, .external_lex_state = 3},
  [6286] = {.lex_state = 124, .external_lex_state = 3},
  [6287] = {.lex_state = 121, .external_lex_state = 3},
  [6288] = {.lex_state = 125, .external_lex_state = 3},
  [6289] = {.lex_state = 124, .external_lex_state = 3},
  [6290] = {.lex_state = 124, .external_lex_state = 3},
  [6291] = {.lex_state = 124, .external_lex_state = 3},
  [6292] = {.lex_state = 421, .external_lex_state = 3},
  [6293] = {.lex_state = 118, .external_lex_state = 3},
  [6294] = {.lex_state = 421, .external_lex_state = 3},
  [6295] = {.lex_state = 118, .external_lex_state = 3},
  [6296] = {.lex_state = 124, .external_lex_state = 3},
  [6297] = {.lex_state = 124, .external_lex_state = 3},
  [6298] = {.lex_state = 7, .external_lex_state = 2},
  [6299] = {.lex_state = 124, .external_lex_state = 3},
  [6300] = {.lex_state = 124, .external_lex_state = 3},
  [6301] = {.lex_state = 126, .external_lex_state = 3},
  [6302] = {.lex_state = 122, .external_lex_state = 3},
  [6303] = {.lex_state = 121, .external_lex_state = 3},
  [6304] = {.lex_state = 126, .external_lex_state = 3},
  [6305] = {.lex_state = 124, .external_lex_state = 3},
  [6306] = {.lex_state = 124, .external_lex_state = 3},
  [6307] = {.lex_state = 124, .external_lex_state = 3},
  [6308] = {.lex_state = 124, .external_lex_state = 3},
  [6309] = {.lex_state = 125, .external_lex_state = 3},
  [6310] = {.lex_state = 124, .external_lex_state = 3},
  [6311] = {.lex_state = 125, .external_lex_state = 3},
  [6312] = {.lex_state = 124, .external_lex_state = 3},
  [6313] = {.lex_state = 124, .external_lex_state = 3},
  [6314] = {.lex_state = 124, .external_lex_state = 3},
  [6315] = {.lex_state = 118, .external_lex_state = 3},
  [6316] = {.lex_state = 118, .external_lex_state = 3},
  [6317] = {.lex_state = 124, .external_lex_state = 3},
  [6318] = {.lex_state = 124, .external_lex_state = 3},
  [6319] = {.lex_state = 124, .external_lex_state = 3},
  [6320] = {.lex_state = 124, .external_lex_state = 3},
  [6321] = {.lex_state = 125, .external_lex_state = 3},
  [6322] = {.lex_state = 124, .external_lex_state = 3},
  [6323] = {.lex_state = 124, .external_lex_state = 3},
  [6324] = {.lex_state = 125, .external_lex_state = 3},
  [6325] = {.lex_state = 118, .external_lex_state = 3},
  [6326] = {.lex_state = 118, .external_lex_state = 3},
  [6327] = {.lex_state = 118, .external_lex_state = 3},
  [6328] = {.lex_state = 124, .external_lex_state = 3},
  [6329] = {.lex_state = 127, .external_lex_state = 3},
  [6330] = {.lex_state = 124, .external_lex_state = 3},
  [6331] = {.lex_state = 124, .external_lex_state = 3},
  [6332] = {.lex_state = 124, .external_lex_state = 3},
  [6333] = {.lex_state = 125, .external_lex_state = 3},
  [6334] = {.lex_state = 421, .external_lex_state = 3},
  [6335] = {.lex_state = 126, .external_lex_state = 3},
  [6336] = {.lex_state = 125, .external_lex_state = 3},
  [6337] = {.lex_state = 126, .external_lex_state = 3},
  [6338] = {.lex_state = 127, .external_lex_state = 3},
  [6339] = {.lex_state = 124, .external_lex_state = 3},
  [6340] = {.lex_state = 125, .external_lex_state = 3},
  [6341] = {.lex_state = 122, .external_lex_state = 3},
  [6342] = {.lex_state = 125, .external_lex_state = 3},
  [6343] = {.lex_state = 118, .external_lex_state = 3},
  [6344] = {.lex_state = 121, .external_lex_state = 3},
  [6345] = {.lex_state = 122, .external_lex_state = 3},
  [6346] = {.lex_state = 122, .external_lex_state = 3},
  [6347] = {.lex_state = 121, .external_lex_state = 3},
  [6348] = {.lex_state = 129, .external_lex_state = 3},
  [6349] = {.lex_state = 125, .external_lex_state = 3},
  [6350] = {.lex_state = 125, .external_lex_state = 3},
  [6351] = {.lex_state = 121, .external_lex_state = 3},
  [6352] = {.lex_state = 124, .external_lex_state = 3},
  [6353] = {.lex_state = 421, .external_lex_state = 3},
  [6354] = {.lex_state = 124, .external_lex_state = 3},
  [6355] = {.lex_state = 121, .external_lex_state = 3},
  [6356] = {.lex_state = 122, .external_lex_state = 3},
  [6357] = {.lex_state = 118, .external_lex_state = 3},
  [6358] = {.lex_state = 118, .external_lex_state = 3},
  [6359] = {.lex_state = 126, .external_lex_state = 3},
  [6360] = {.lex_state = 118, .external_lex_state = 3},
  [6361] = {.lex_state = 126, .external_lex_state = 3},
  [6362] = {.lex_state = 127, .external_lex_state = 3},
  [6363] = {.lex_state = 125, .external_lex_state = 3},
  [6364] = {.lex_state = 421, .external_lex_state = 3},
  [6365] = {.lex_state = 127, .external_lex_state = 3},
  [6366] = {.lex_state = 118, .external_lex_state = 3},
  [6367] = {.lex_state = 126, .external_lex_state = 3},
  [6368] = {.lex_state = 122, .external_lex_state = 3},
  [6369] = {.lex_state = 127, .external_lex_state = 3},
  [6370] = {.lex_state = 121, .external_lex_state = 3},
  [6371] = {.lex_state = 127, .external_lex_state = 3},
  [6372] = {.lex_state = 127, .external_lex_state = 3},
  [6373] = {.lex_state = 126, .external_lex_state = 3},
  [6374] = {.lex_state = 118, .external_lex_state = 3},
  [6375] = {.lex_state = 126, .external_lex_state = 3},
  [6376] = {.lex_state = 127, .external_lex_state = 3},
  [6377] = {.lex_state = 127, .external_lex_state = 3},
  [6378] = {.lex_state = 127, .external_lex_state = 3},
  [6379] = {.lex_state = 124, .external_lex_state = 3},
  [6380] = {.lex_state = 118, .external_lex_state = 3},
  [6381] = {.lex_state = 125, .external_lex_state = 3},
  [6382] = {.lex_state = 87, .external_lex_state = 3},
  [6383] = {.lex_state = 126, .external_lex_state = 3},
  [6384] = {.lex_state = 122, .external_lex_state = 3},
  [6385] = {.lex_state = 128, .external_lex_state = 3},
  [6386] = {.lex_state = 122, .external_lex_state = 3},
  [6387] = {.lex_state = 122, .external_lex_state = 3},
  [6388] = {.lex_state = 126, .external_lex_state = 3},
  [6389] = {.lex_state = 126, .external_lex_state = 3},
  [6390] = {.lex_state = 421, .external_lex_state = 3},
  [6391] = {.lex_state = 122, .external_lex_state = 3},
  [6392] = {.lex_state = 125, .external_lex_state = 3},
  [6393] = {.lex_state = 124, .external_lex_state = 3},
  [6394] = {.lex_state = 122, .external_lex_state = 3},
  [6395] = {.lex_state = 122, .external_lex_state = 3},
  [6396] = {.lex_state = 122, .external_lex_state = 3},
  [6397] = {.lex_state = 7, .external_lex_state = 2},
  [6398] = {.lex_state = 122, .external_lex_state = 3},
  [6399] = {.lex_state = 122, .external_lex_state = 3},
  [6400] = {.lex_state = 121, .external_lex_state = 3},
  [6401] = {.lex_state = 118, .external_lex_state = 3},
  [6402] = {.lex_state = 125, .external_lex_state = 3},
  [6403] = {.lex_state = 124, .external_lex_state = 3},
  [6404] = {.lex_state = 128, .external_lex_state = 3},
  [6405] = {.lex_state = 125, .external_lex_state = 3},
  [6406] = {.lex_state = 121, .external_lex_state = 3},
  [6407] = {.lex_state = 121, .external_lex_state = 3},
  [6408] = {.lex_state = 130, .external_lex_state = 3},
  [6409] = {.lex_state = 126, .external_lex_state = 3},
  [6410] = {.lex_state = 128, .external_lex_state = 3},
  [6411] = {.lex_state = 129, .external_lex_state = 3},
  [6412] = {.lex_state = 126, .external_lex_state = 3},
  [6413] = {.lex_state = 118, .external_lex_state = 3},
  [6414] = {.lex_state = 122, .external_lex_state = 3},
  [6415] = {.lex_state = 121, .external_lex_state = 3},
  [6416] = {.lex_state = 118, .external_lex_state = 3},
  [6417] = {.lex_state = 119, .external_lex_state = 3},
  [6418] = {.lex_state = 121, .external_lex_state = 3},
  [6419] = {.lex_state = 121, .external_lex_state = 3},
  [6420] = {.lex_state = 121, .external_lex_state = 3},
  [6421] = {.lex_state = 121, .external_lex_state = 3},
  [6422] = {.lex_state = 129, .external_lex_state = 3},
  [6423] = {.lex_state = 129, .external_lex_state = 3},
  [6424] = {.lex_state = 129, .external_lex_state = 3},
  [6425] = {.lex_state = 118, .external_lex_state = 3},
  [6426] = {.lex_state = 125, .external_lex_state = 3},
  [6427] = {.lex_state = 121, .external_lex_state = 3},
  [6428] = {.lex_state = 125, .external_lex_state = 3},
  [6429] = {.lex_state = 121, .external_lex_state = 3},
  [6430] = {.lex_state = 121, .external_lex_state = 3},
  [6431] = {.lex_state = 125, .external_lex_state = 3},
  [6432] = {.lex_state = 118, .external_lex_state = 3},
  [6433] = {.lex_state = 121, .external_lex_state = 3},
  [6434] = {.lex_state = 118, .external_lex_state = 3},
  [6435] = {.lex_state = 121, .external_lex_state = 3},
  [6436] = {.lex_state = 122, .external_lex_state = 3},
  [6437] = {.lex_state = 125, .external_lex_state = 3},
  [6438] = {.lex_state = 124, .external_lex_state = 3},
  [6439] = {.lex_state = 125, .external_lex_state = 3},
  [6440] = {.lex_state = 121, .external_lex_state = 3},
  [6441] = {.lex_state = 121, .external_lex_state = 3},
  [6442] = {.lex_state = 121, .external_lex_state = 3},
  [6443] = {.lex_state = 129, .external_lex_state = 3},
  [6444] = {.lex_state = 129, .external_lex_state = 3},
  [6445] = {.lex_state = 122, .external_lex_state = 3},
  [6446] = {.lex_state = 7, .external_lex_state = 2},
  [6447] = {.lex_state = 121, .external_lex_state = 3},
  [6448] = {.lex_state = 122, .external_lex_state = 3},
  [6449] = {.lex_state = 124, .external_lex_state = 3},
  [6450] = {.lex_state = 126, .external_lex_state = 3},
  [6451] = {.lex_state = 118, .external_lex_state = 3},
  [6452] = {.lex_state = 126, .external_lex_state = 3},
  [6453] = {.lex_state = 123, .external_lex_state = 3},
  [6454] = {.lex_state = 125, .external_lex_state = 3},
  [6455] = {.lex_state = 121, .external_lex_state = 3},
  [6456] = {.lex_state = 125, .external_lex_state = 3},
  [6457] = {.lex_state = 125, .external_lex_state = 3},
  [6458] = {.lex_state = 126, .external_lex_state = 3},
  [6459] = {.lex_state = 122, .external_lex_state = 3},
  [6460] = {.lex_state = 125, .external_lex_state = 3},
  [6461] = {.lex_state = 125, .external_lex_state = 3},
  [6462] = {.lex_state = 121, .external_lex_state = 3},
  [6463] = {.lex_state = 125, .external_lex_state = 3},
  [6464] = {.lex_state = 121, .external_lex_state = 3},
  [6465] = {.lex_state = 122, .external_lex_state = 3},
  [6466] = {.lex_state = 121, .external_lex_state = 3},
  [6467] = {.lex_state = 125, .external_lex_state = 3},
  [6468] = {.lex_state = 122, .external_lex_state = 3},
  [6469] = {.lex_state = 125, .external_lex_state = 3},
  [6470] = {.lex_state = 125, .external_lex_state = 3},
  [6471] = {.lex_state = 121, .external_lex_state = 3},
  [6472] = {.lex_state = 126, .external_lex_state = 3},
  [6473] = {.lex_state = 125, .external_lex_state = 3},
  [6474] = {.lex_state = 125, .external_lex_state = 3},
  [6475] = {.lex_state = 125, .external_lex_state = 3},
  [6476] = {.lex_state = 7, .external_lex_state = 2},
  [6477] = {.lex_state = 129, .external_lex_state = 3},
  [6478] = {.lex_state = 125, .external_lex_state = 3},
  [6479] = {.lex_state = 125, .external_lex_state = 3},
  [6480] = {.lex_state = 123, .external_lex_state = 3},
  [6481] = {.lex_state = 125, .external_lex_state = 3},
  [6482] = {.lex_state = 125, .external_lex_state = 3},
  [6483] = {.lex_state = 122, .external_lex_state = 3},
  [6484] = {.lex_state = 125, .external_lex_state = 3},
  [6485] = {.lex_state = 123, .external_lex_state = 3},
  [6486] = {.lex_state = 121, .external_lex_state = 3},
  [6487] = {.lex_state = 121, .external_lex_state = 3},
  [6488] = {.lex_state = 121, .external_lex_state = 3},
  [6489] = {.lex_state = 125, .external_lex_state = 3},
  [6490] = {.lex_state = 121, .external_lex_state = 3},
  [6491] = {.lex_state = 124, .external_lex_state = 3},
  [6492] = {.lex_state = 122, .external_lex_state = 3},
  [6493] = {.lex_state = 126, .external_lex_state = 3},
  [6494] = {.lex_state = 122, .external_lex_state = 3},
  [6495] = {.lex_state = 126, .external_lex_state = 3},
  [6496] = {.lex_state = 125, .external_lex_state = 3},
  [6497] = {.lex_state = 125, .external_lex_state = 3},
  [6498] = {.lex_state = 122, .external_lex_state = 3},
  [6499] = {.lex_state = 118, .external_lex_state = 3},
  [6500] = {.lex_state = 122, .external_lex_state = 3},
  [6501] = {.lex_state = 122, .external_lex_state = 3},
  [6502] = {.lex_state = 122, .external_lex_state = 3},
  [6503] = {.lex_state = 124, .external_lex_state = 3},
  [6504] = {.lex_state = 122, .external_lex_state = 3},
  [6505] = {.lex_state = 126, .external_lex_state = 3},
  [6506] = {.lex_state = 122, .external_lex_state = 3},
  [6507] = {.lex_state = 123, .external_lex_state = 3},
  [6508] = {.lex_state = 126, .external_lex_state = 3},
  [6509] = {.lex_state = 122, .external_lex_state = 3},
  [6510] = {.lex_state = 122, .external_lex_state = 3},
  [6511] = {.lex_state = 125, .external_lex_state = 3},
  [6512] = {.lex_state = 123, .external_lex_state = 3},
  [6513] = {.lex_state = 118, .external_lex_state = 3},
  [6514] = {.lex_state = 125, .external_lex_state = 3},
  [6515] = {.lex_state = 125, .external_lex_state = 3},
  [6516] = {.lex_state = 125, .external_lex_state = 3},
  [6517] = {.lex_state = 126, .external_lex_state = 3},
  [6518] = {.lex_state = 121, .external_lex_state = 3},
  [6519] = {.lex_state = 122, .external_lex_state = 3},
  [6520] = {.lex_state = 125, .external_lex_state = 3},
  [6521] = {.lex_state = 122, .external_lex_state = 3},
  [6522] = {.lex_state = 126, .external_lex_state = 3},
  [6523] = {.lex_state = 122, .external_lex_state = 3},
  [6524] = {.lex_state = 126, .external_lex_state = 3},
  [6525] = {.lex_state = 123, .external_lex_state = 3},
  [6526] = {.lex_state = 126, .external_lex_state = 3},
  [6527] = {.lex_state = 125, .external_lex_state = 3},
  [6528] = {.lex_state = 122, .external_lex_state = 3},
  [6529] = {.lex_state = 118, .external_lex_state = 3},
  [6530] = {.lex_state = 122, .external_lex_state = 3},
  [6531] = {.lex_state = 118, .external_lex_state = 3},
  [6532] = {.lex_state = 121, .external_lex_state = 3},
  [6533] = {.lex_state = 118, .external_lex_state = 3},
  [6534] = {.lex_state = 122, .external_lex_state = 3},
  [6535] = {.lex_state = 122, .external_lex_state = 3},
  [6536] = {.lex_state = 121, .external_lex_state = 3},
  [6537] = {.lex_state = 125, .external_lex_state = 3},
  [6538] = {.lex_state = 123, .external_lex_state = 3},
  [6539] = {.lex_state = 125, .external_lex_state = 3},
  [6540] = {.lex_state = 119, .external_lex_state = 3},
  [6541] = {.lex_state = 125, .external_lex_state = 3},
  [6542] = {.lex_state = 124, .external_lex_state = 3},
  [6543] = {.lex_state = 126, .external_lex_state = 3},
  [6544] = {.lex_state = 124, .external_lex_state = 3},
  [6545] = {.lex_state = 118, .external_lex_state = 3},
  [6546] = {.lex_state = 127, .external_lex_state = 3},
  [6547] = {.lex_state = 118, .external_lex_state = 3},
  [6548] = {.lex_state = 118, .external_lex_state = 3},
  [6549] = {.lex_state = 121, .external_lex_state = 3},
  [6550] = {.lex_state = 124, .external_lex_state = 3},
  [6551] = {.lex_state = 121, .external_lex_state = 3},
  [6552] = {.lex_state = 119, .external_lex_state = 3},
  [6553] = {.lex_state = 119, .external_lex_state = 3},
  [6554] = {.lex_state = 119, .external_lex_state = 3},
  [6555] = {.lex_state = 122, .external_lex_state = 3},
  [6556] = {.lex_state = 126, .external_lex_state = 3},
  [6557] = {.lex_state = 122, .external_lex_state = 3},
  [6558] = {.lex_state = 123, .external_lex_state = 3},
  [6559] = {.lex_state = 118, .external_lex_state = 3},
  [6560] = {.lex_state = 119, .external_lex_state = 3},
  [6561] = {.lex_state = 119, .external_lex_state = 3},
  [6562] = {.lex_state = 118, .external_lex_state = 3},
  [6563] = {.lex_state = 118, .external_lex_state = 3},
  [6564] = {.lex_state = 124, .external_lex_state = 3},
  [6565] = {.lex_state = 124, .external_lex_state = 3},
  [6566] = {.lex_state = 121, .external_lex_state = 3},
  [6567] = {.lex_state = 122, .external_lex_state = 3},
  [6568] = {.lex_state = 121, .external_lex_state = 3},
  [6569] = {.lex_state = 124, .external_lex_state = 3},
  [6570] = {.lex_state = 119, .external_lex_state = 3},
  [6571] = {.lex_state = 122, .external_lex_state = 3},
  [6572] = {.lex_state = 7, .external_lex_state = 2},
  [6573] = {.lex_state = 124, .external_lex_state = 3},
  [6574] = {.lex_state = 126, .external_lex_state = 3},
  [6575] = {.lex_state = 122, .external_lex_state = 3},
  [6576] = {.lex_state = 122, .external_lex_state = 3},
  [6577] = {.lex_state = 124, .external_lex_state = 3},
  [6578] = {.lex_state = 122, .external_lex_state = 3},
  [6579] = {.lex_state = 122, .external_lex_state = 3},
  [6580] = {.lex_state = 125, .external_lex_state = 3},
  [6581] = {.lex_state = 125, .external_lex_state = 3},
  [6582] = {.lex_state = 126, .external_lex_state = 3},
  [6583] = {.lex_state = 125, .external_lex_state = 3},
  [6584] = {.lex_state = 125, .external_lex_state = 3},
  [6585] = {.lex_state = 124, .external_lex_state = 3},
  [6586] = {.lex_state = 124, .external_lex_state = 3},
  [6587] = {.lex_state = 124, .external_lex_state = 3},
  [6588] = {.lex_state = 118, .external_lex_state = 3},
  [6589] = {.lex_state = 119, .external_lex_state = 3},
  [6590] = {.lex_state = 7, .external_lex_state = 2},
  [6591] = {.lex_state = 122, .external_lex_state = 3},
  [6592] = {.lex_state = 125, .external_lex_state = 3},
  [6593] = {.lex_state = 130, .external_lex_state = 3},
  [6594] = {.lex_state = 118, .external_lex_state = 3},
  [6595] = {.lex_state = 125, .external_lex_state = 3},
  [6596] = {.lex_state = 121, .external_lex_state = 3},
  [6597] = {.lex_state = 124, .external_lex_state = 3},
  [6598] = {.lex_state = 119, .external_lex_state = 3},
  [6599] = {.lex_state = 122, .external_lex_state = 3},
  [6600] = {.lex_state = 124, .external_lex_state = 3},
  [6601] = {.lex_state = 121, .external_lex_state = 3},
  [6602] = {.lex_state = 125, .external_lex_state = 3},
  [6603] = {.lex_state = 122, .external_lex_state = 3},
  [6604] = {.lex_state = 122, .external_lex_state = 3},
  [6605] = {.lex_state = 129, .external_lex_state = 3},
  [6606] = {.lex_state = 121, .external_lex_state = 3},
  [6607] = {.lex_state = 131, .external_lex_state = 3},
  [6608] = {.lex_state = 118, .external_lex_state = 3},
  [6609] = {.lex_state = 124, .external_lex_state = 3},
  [6610] = {.lex_state = 121, .external_lex_state = 3},
  [6611] = {.lex_state = 124, .external_lex_state = 3},
  [6612] = {.lex_state = 128, .external_lex_state = 3},
  [6613] = {.lex_state = 128, .external_lex_state = 3},
  [6614] = {.lex_state = 128, .external_lex_state = 3},
  [6615] = {.lex_state = 125, .external_lex_state = 3},
  [6616] = {.lex_state = 124, .external_lex_state = 3},
  [6617] = {.lex_state = 119, .external_lex_state = 3},
  [6618] = {.lex_state = 124, .external_lex_state = 3},
  [6619] = {.lex_state = 121, .external_lex_state = 3},
  [6620] = {.lex_state = 121, .external_lex_state = 3},
  [6621] = {.lex_state = 126, .external_lex_state = 3},
  [6622] = {.lex_state = 121, .external_lex_state = 3},
  [6623] = {.lex_state = 125, .external_lex_state = 3},
  [6624] = {.lex_state = 121, .external_lex_state = 3},
  [6625] = {.lex_state = 128, .external_lex_state = 3},
  [6626] = {.lex_state = 121, .external_lex_state = 3},
  [6627] = {.lex_state = 128, .external_lex_state = 3},
  [6628] = {.lex_state = 128, .external_lex_state = 3},
  [6629] = {.lex_state = 121, .external_lex_state = 3},
  [6630] = {.lex_state = 122, .external_lex_state = 3},
  [6631] = {.lex_state = 121, .external_lex_state = 3},
  [6632] = {.lex_state = 121, .external_lex_state = 3},
  [6633] = {.lex_state = 122, .external_lex_state = 3},
  [6634] = {.lex_state = 128, .external_lex_state = 3},
  [6635] = {.lex_state = 122, .external_lex_state = 3},
  [6636] = {.lex_state = 421, .external_lex_state = 3},
  [6637] = {.lex_state = 121, .external_lex_state = 3},
  [6638] = {.lex_state = 121, .external_lex_state = 3},
  [6639] = {.lex_state = 122, .external_lex_state = 3},
  [6640] = {.lex_state = 122, .external_lex_state = 3},
  [6641] = {.lex_state = 121, .external_lex_state = 3},
  [6642] = {.lex_state = 122, .external_lex_state = 3},
  [6643] = {.lex_state = 421, .external_lex_state = 3},
  [6644] = {.lex_state = 122, .external_lex_state = 3},
  [6645] = {.lex_state = 121, .external_lex_state = 3},
  [6646] = {.lex_state = 125, .external_lex_state = 3},
  [6647] = {.lex_state = 124, .external_lex_state = 3},
  [6648] = {.lex_state = 121, .external_lex_state = 3},
  [6649] = {.lex_state = 125, .external_lex_state = 3},
  [6650] = {.lex_state = 125, .external_lex_state = 3},
  [6651] = {.lex_state = 121, .external_lex_state = 3},
  [6652] = {.lex_state = 121, .external_lex_state = 3},
  [6653] = {.lex_state = 121, .external_lex_state = 3},
  [6654] = {.lex_state = 118, .external_lex_state = 3},
  [6655] = {.lex_state = 121, .external_lex_state = 3},
  [6656] = {.lex_state = 121, .external_lex_state = 3},
  [6657] = {.lex_state = 125, .external_lex_state = 3},
  [6658] = {.lex_state = 121, .external_lex_state = 3},
  [6659] = {.lex_state = 128, .external_lex_state = 3},
  [6660] = {.lex_state = 124, .external_lex_state = 3},
  [6661] = {.lex_state = 122, .external_lex_state = 3},
  [6662] = {.lex_state = 421, .external_lex_state = 3},
  [6663] = {.lex_state = 129, .external_lex_state = 3},
  [6664] = {.lex_state = 421, .external_lex_state = 3},
  [6665] = {.lex_state = 122, .external_lex_state = 3},
  [6666] = {.lex_state = 125, .external_lex_state = 3},
  [6667] = {.lex_state = 421, .external_lex_state = 3},
  [6668] = {.lex_state = 128, .external_lex_state = 3},
  [6669] = {.lex_state = 30, .external_lex_state = 3},
  [6670] = {.lex_state = 30, .external_lex_state = 3},
  [6671] = {.lex_state = 421, .external_lex_state = 3},
  [6672] = {.lex_state = 7, .external_lex_state = 2},
  [6673] = {.lex_state = 30, .external_lex_state = 3},
  [6674] = {.lex_state = 30, .external_lex_state = 3},
  [6675] = {.lex_state = 30, .external_lex_state = 3},
  [6676] = {.lex_state = 30, .external_lex_state = 3},
  [6677] = {.lex_state = 30, .external_lex_state = 3},
  [6678] = {.lex_state = 30, .external_lex_state = 3},
  [6679] = {.lex_state = 30, .external_lex_state = 3},
  [6680] = {.lex_state = 30, .external_lex_state = 3},
  [6681] = {.lex_state = 30, .external_lex_state = 3},
  [6682] = {.lex_state = 30, .external_lex_state = 3},
  [6683] = {.lex_state = 128, .external_lex_state = 3},
  [6684] = {.lex_state = 123, .external_lex_state = 3},
  [6685] = {.lex_state = 30, .external_lex_state = 3},
  [6686] = {.lex_state = 30, .external_lex_state = 3},
  [6687] = {.lex_state = 30, .external_lex_state = 3},
  [6688] = {.lex_state = 30, .external_lex_state = 3},
  [6689] = {.lex_state = 30, .external_lex_state = 3},
  [6690] = {.lex_state = 30, .external_lex_state = 3},
  [6691] = {.lex_state = 30, .external_lex_state = 3},
  [6692] = {.lex_state = 30, .external_lex_state = 3},
  [6693] = {.lex_state = 30, .external_lex_state = 3},
  [6694] = {.lex_state = 30, .external_lex_state = 3},
  [6695] = {.lex_state = 30, .external_lex_state = 3},
  [6696] = {.lex_state = 30, .external_lex_state = 3},
  [6697] = {.lex_state = 128, .external_lex_state = 3},
  [6698] = {.lex_state = 30, .external_lex_state = 3},
  [6699] = {.lex_state = 30, .external_lex_state = 3},
  [6700] = {.lex_state = 30, .external_lex_state = 3},
  [6701] = {.lex_state = 30, .external_lex_state = 3},
  [6702] = {.lex_state = 30, .external_lex_state = 3},
  [6703] = {.lex_state = 30, .external_lex_state = 3},
  [6704] = {.lex_state = 30, .external_lex_state = 3},
  [6705] = {.lex_state = 30, .external_lex_state = 3},
  [6706] = {.lex_state = 421, .external_lex_state = 3},
  [6707] = {.lex_state = 30, .external_lex_state = 3},
  [6708] = {.lex_state = 127, .external_lex_state = 3},
  [6709] = {.lex_state = 421, .external_lex_state = 3},
  [6710] = {.lex_state = 30, .external_lex_state = 3},
  [6711] = {.lex_state = 421, .external_lex_state = 3},
  [6712] = {.lex_state = 123, .external_lex_state = 3},
  [6713] = {.lex_state = 421, .external_lex_state = 3},
  [6714] = {.lex_state = 421, .external_lex_state = 3},
  [6715] = {.lex_state = 421, .external_lex_state = 3},
  [6716] = {.lex_state = 421, .external_lex_state = 3},
  [6717] = {.lex_state = 30, .external_lex_state = 3},
  [6718] = {.lex_state = 123, .external_lex_state = 3},
  [6719] = {.lex_state = 30, .external_lex_state = 3},
  [6720] = {.lex_state = 30, .external_lex_state = 3},
  [6721] = {.lex_state = 30, .external_lex_state = 3},
  [6722] = {.lex_state = 30, .external_lex_state = 3},
  [6723] = {.lex_state = 30, .external_lex_state = 3},
  [6724] = {.lex_state = 30, .external_lex_state = 3},
  [6725] = {.lex_state = 421, .external_lex_state = 3},
  [6726] = {.lex_state = 421, .external_lex_state = 3},
  [6727] = {.lex_state = 421, .external_lex_state = 3},
  [6728] = {.lex_state = 123, .external_lex_state = 3},
  [6729] = {.lex_state = 421, .external_lex_state = 3},
  [6730] = {.lex_state = 421, .external_lex_state = 3},
  [6731] = {.lex_state = 123, .external_lex_state = 3},
  [6732] = {.lex_state = 421, .external_lex_state = 3},
  [6733] = {.lex_state = 123, .external_lex_state = 3},
  [6734] = {.lex_state = 123, .external_lex_state = 3},
  [6735] = {.lex_state = 421, .external_lex_state = 3},
  [6736] = {.lex_state = 123, .external_lex_state = 3},
  [6737] = {.lex_state = 421, .external_lex_state = 3},
  [6738] = {.lex_state = 123, .external_lex_state = 3},
  [6739] = {.lex_state = 128, .external_lex_state = 3},
  [6740] = {.lex_state = 123, .external_lex_state = 3},
  [6741] = {.lex_state = 119, .external_lex_state = 3},
  [6742] = {.lex_state = 421, .external_lex_state = 3},
  [6743] = {.lex_state = 123, .external_lex_state = 3},
  [6744] = {.lex_state = 421, .external_lex_state = 3},
  [6745] = {.lex_state = 421, .external_lex_state = 3},
  [6746] = {.lex_state = 421, .external_lex_state = 3},
  [6747] = {.lex_state = 123, .external_lex_state = 3},
  [6748] = {.lex_state = 123, .external_lex_state = 3},
  [6749] = {.lex_state = 421, .external_lex_state = 3},
  [6750] = {.lex_state = 421, .external_lex_state = 3},
  [6751] = {.lex_state = 421, .external_lex_state = 3},
  [6752] = {.lex_state = 421, .external_lex_state = 3},
  [6753] = {.lex_state = 421, .external_lex_state = 3},
  [6754] = {.lex_state = 421, .external_lex_state = 3},
  [6755] = {.lex_state = 421, .external_lex_state = 3},
  [6756] = {.lex_state = 421, .external_lex_state = 3},
  [6757] = {.lex_state = 421, .external_lex_state = 3},
  [6758] = {.lex_state = 421, .external_lex_state = 3},
  [6759] = {.lex_state = 421, .external_lex_state = 3},
  [6760] = {.lex_state = 421, .external_lex_state = 3},
  [6761] = {.lex_state = 30, .external_lex_state = 3},
  [6762] = {.lex_state = 421, .external_lex_state = 3},
  [6763] = {.lex_state = 119, .external_lex_state = 3},
  [6764] = {.lex_state = 421, .external_lex_state = 3},
  [6765] = {.lex_state = 421, .external_lex_state = 3},
  [6766] = {.lex_state = 421, .external_lex_state = 3},
  [6767] = {.lex_state = 421, .external_lex_state = 3},
  [6768] = {.lex_state = 421, .external_lex_state = 3},
  [6769] = {.lex_state = 421, .external_lex_state = 3},
  [6770] = {.lex_state = 421, .external_lex_state = 3},
  [6771] = {.lex_state = 421, .external_lex_state = 3},
  [6772] = {.lex_state = 421, .external_lex_state = 3},
  [6773] = {.lex_state = 421, .external_lex_state = 3},
  [6774] = {.lex_state = 421, .external_lex_state = 3},
  [6775] = {.lex_state = 421, .external_lex_state = 3},
  [6776] = {.lex_state = 123, .external_lex_state = 3},
  [6777] = {.lex_state = 421, .external_lex_state = 3},
  [6778] = {.lex_state = 421, .external_lex_state = 3},
  [6779] = {.lex_state = 421, .external_lex_state = 3},
  [6780] = {.lex_state = 421, .external_lex_state = 3},
  [6781] = {.lex_state = 421, .external_lex_state = 3},
  [6782] = {.lex_state = 421, .external_lex_state = 3},
  [6783] = {.lex_state = 421, .external_lex_state = 3},
  [6784] = {.lex_state = 421, .external_lex_state = 3},
  [6785] = {.lex_state = 421, .external_lex_state = 3},
  [6786] = {.lex_state = 421, .external_lex_state = 3},
  [6787] = {.lex_state = 421, .external_lex_state = 3},
  [6788] = {.lex_state = 421, .external_lex_state = 3},
  [6789] = {.lex_state = 421, .external_lex_state = 3},
  [6790] = {.lex_state = 421, .external_lex_state = 3},
  [6791] = {.lex_state = 421, .external_lex_state = 3},
  [6792] = {.lex_state = 421, .external_lex_state = 3},
  [6793] = {.lex_state = 421, .external_lex_state = 3},
  [6794] = {.lex_state = 129, .external_lex_state = 3},
  [6795] = {.lex_state = 421, .external_lex_state = 3},
  [6796] = {.lex_state = 421, .external_lex_state = 3},
  [6797] = {.lex_state = 421, .external_lex_state = 3},
  [6798] = {.lex_state = 421, .external_lex_state = 3},
  [6799] = {.lex_state = 421, .external_lex_state = 3},
  [6800] = {.lex_state = 129, .external_lex_state = 3},
  [6801] = {.lex_state = 123, .external_lex_state = 3},
  [6802] = {.lex_state = 129, .external_lex_state = 3},
  [6803] = {.lex_state = 421, .external_lex_state = 3},
  [6804] = {.lex_state = 421, .external_lex_state = 3},
  [6805] = {.lex_state = 421, .external_lex_state = 3},
  [6806] = {.lex_state = 421, .external_lex_state = 3},
  [6807] = {.lex_state = 421, .external_lex_state = 3},
  [6808] = {.lex_state = 123, .external_lex_state = 3},
  [6809] = {.lex_state = 129, .external_lex_state = 3},
  [6810] = {.lex_state = 421, .external_lex_state = 3},
  [6811] = {.lex_state = 128, .external_lex_state = 3},
  [6812] = {.lex_state = 119, .external_lex_state = 3},
  [6813] = {.lex_state = 123, .external_lex_state = 3},
  [6814] = {.lex_state = 421, .external_lex_state = 3},
  [6815] = {.lex_state = 421, .external_lex_state = 3},
  [6816] = {.lex_state = 421, .external_lex_state = 3},
  [6817] = {.lex_state = 123, .external_lex_state = 3},
  [6818] = {.lex_state = 30, .external_lex_state = 3},
  [6819] = {.lex_state = 123, .external_lex_state = 3},
  [6820] = {.lex_state = 123, .external_lex_state = 3},
  [6821] = {.lex_state = 123, .external_lex_state = 3},
  [6822] = {.lex_state = 421, .external_lex_state = 3},
  [6823] = {.lex_state = 123, .external_lex_state = 3},
  [6824] = {.lex_state = 421, .external_lex_state = 3},
  [6825] = {.lex_state = 421, .external_lex_state = 3},
  [6826] = {.lex_state = 421, .external_lex_state = 3},
  [6827] = {.lex_state = 129, .external_lex_state = 3},
  [6828] = {.lex_state = 123, .external_lex_state = 3},
  [6829] = {.lex_state = 123, .external_lex_state = 3},
  [6830] = {.lex_state = 119, .external_lex_state = 3},
  [6831] = {.lex_state = 128, .external_lex_state = 3},
  [6832] = {.lex_state = 128, .external_lex_state = 3},
  [6833] = {.lex_state = 129, .external_lex_state = 3},
  [6834] = {.lex_state = 119, .external_lex_state = 3},
  [6835] = {.lex_state = 30, .external_lex_state = 3},
  [6836] = {.lex_state = 119, .external_lex_state = 3},
  [6837] = {.lex_state = 123, .external_lex_state = 3},
  [6838] = {.lex_state = 123, .external_lex_state = 3},
  [6839] = {.lex_state = 119, .external_lex_state = 3},
  [6840] = {.lex_state = 123, .external_lex_state = 3},
  [6841] = {.lex_state = 421, .external_lex_state = 3},
  [6842] = {.lex_state = 421, .external_lex_state = 3},
  [6843] = {.lex_state = 421, .external_lex_state = 3},
  [6844] = {.lex_state = 129, .external_lex_state = 3},
  [6845] = {.lex_state = 421, .external_lex_state = 3},
  [6846] = {.lex_state = 123, .external_lex_state = 3},
  [6847] = {.lex_state = 421, .external_lex_state = 3},
  [6848] = {.lex_state = 129, .external_lex_state = 3},
  [6849] = {.lex_state = 421, .external_lex_state = 3},
  [6850] = {.lex_state = 127, .external_lex_state = 3},
  [6851] = {.lex_state = 421, .external_lex_state = 3},
  [6852] = {.lex_state = 129, .external_lex_state = 3},
  [6853] = {.lex_state = 421, .external_lex_state = 3},
  [6854] = {.lex_state = 119, .external_lex_state = 3},
  [6855] = {.lex_state = 30, .external_lex_state = 3},
  [6856] = {.lex_state = 119, .external_lex_state = 3},
  [6857] = {.lex_state = 421, .external_lex_state = 3},
  [6858] = {.lex_state = 127, .external_lex_state = 3},
  [6859] = {.lex_state = 123, .external_lex_state = 3},
  [6860] = {.lex_state = 119, .external_lex_state = 3},
  [6861] = {.lex_state = 421, .external_lex_state = 3},
  [6862] = {.lex_state = 421, .external_lex_state = 3},
  [6863] = {.lex_state = 119, .external_lex_state = 3},
  [6864] = {.lex_state = 421, .external_lex_state = 3},
  [6865] = {.lex_state = 119, .external_lex_state = 3},
  [6866] = {.lex_state = 129, .external_lex_state = 3},
  [6867] = {.lex_state = 119, .external_lex_state = 3},
  [6868] = {.lex_state = 30, .external_lex_state = 3},
  [6869] = {.lex_state = 129, .external_lex_state = 3},
  [6870] = {.lex_state = 119, .external_lex_state = 3},
  [6871] = {.lex_state = 129, .external_lex_state = 3},
  [6872] = {.lex_state = 119, .external_lex_state = 3},
  [6873] = {.lex_state = 11, .external_lex_state = 2},
  [6874] = {.lex_state = 421, .external_lex_state = 3},
  [6875] = {.lex_state = 421, .external_lex_state = 3},
  [6876] = {.lex_state = 129, .external_lex_state = 3},
  [6877] = {.lex_state = 119, .external_lex_state = 3},
  [6878] = {.lex_state = 421, .external_lex_state = 3},
  [6879] = {.lex_state = 421, .external_lex_state = 3},
  [6880] = {.lex_state = 119, .external_lex_state = 3},
  [6881] = {.lex_state = 128, .external_lex_state = 3},
  [6882] = {.lex_state = 421, .external_lex_state = 3},
  [6883] = {.lex_state = 119, .external_lex_state = 3},
  [6884] = {.lex_state = 421, .external_lex_state = 3},
  [6885] = {.lex_state = 129, .external_lex_state = 3},
  [6886] = {.lex_state = 119, .external_lex_state = 3},
  [6887] = {.lex_state = 129, .external_lex_state = 3},
  [6888] = {.lex_state = 421, .external_lex_state = 3},
  [6889] = {.lex_state = 129, .external_lex_state = 3},
  [6890] = {.lex_state = 421, .external_lex_state = 3},
  [6891] = {.lex_state = 421, .external_lex_state = 3},
  [6892] = {.lex_state = 421, .external_lex_state = 3},
  [6893] = {.lex_state = 421, .external_lex_state = 3},
  [6894] = {.lex_state = 421, .external_lex_state = 3},
  [6895] = {.lex_state = 123, .external_lex_state = 3},
  [6896] = {.lex_state = 421, .external_lex_state = 3},
  [6897] = {.lex_state = 127, .external_lex_state = 3},
  [6898] = {.lex_state = 129, .external_lex_state = 3},
  [6899] = {.lex_state = 119, .external_lex_state = 3},
  [6900] = {.lex_state = 129, .external_lex_state = 3},
  [6901] = {.lex_state = 11, .external_lex_state = 2},
  [6902] = {.lex_state = 119, .external_lex_state = 3},
  [6903] = {.lex_state = 119, .external_lex_state = 3},
  [6904] = {.lex_state = 7, .external_lex_state = 2},
  [6905] = {.lex_state = 119, .external_lex_state = 3},
  [6906] = {.lex_state = 119, .external_lex_state = 3},
  [6907] = {.lex_state = 119, .external_lex_state = 3},
  [6908] = {.lex_state = 129, .external_lex_state = 3},
  [6909] = {.lex_state = 119, .external_lex_state = 3},
  [6910] = {.lex_state = 421, .external_lex_state = 3},
  [6911] = {.lex_state = 119, .external_lex_state = 3},
  [6912] = {.lex_state = 421, .external_lex_state = 3},
  [6913] = {.lex_state = 123, .external_lex_state = 3},
  [6914] = {.lex_state = 128, .external_lex_state = 3},
  [6915] = {.lex_state = 128, .external_lex_state = 3},
  [6916] = {.lex_state = 123, .external_lex_state = 3},
  [6917] = {.lex_state = 7, .external_lex_state = 2},
  [6918] = {.lex_state = 123, .external_lex_state = 3},
  [6919] = {.lex_state = 123, .external_lex_state = 3},
  [6920] = {.lex_state = 119, .external_lex_state = 3},
  [6921] = {.lex_state = 119, .external_lex_state = 3},
  [6922] = {.lex_state = 129, .external_lex_state = 3},
  [6923] = {.lex_state = 421, .external_lex_state = 3},
  [6924] = {.lex_state = 129, .external_lex_state = 3},
  [6925] = {.lex_state = 119, .external_lex_state = 3},
  [6926] = {.lex_state = 119, .external_lex_state = 3},
  [6927] = {.lex_state = 421, .external_lex_state = 3},
  [6928] = {.lex_state = 119, .external_lex_state = 3},
  [6929] = {.lex_state = 128, .external_lex_state = 3},
  [6930] = {.lex_state = 128, .external_lex_state = 3},
  [6931] = {.lex_state = 123, .external_lex_state = 3},
  [6932] = {.lex_state = 421, .external_lex_state = 3},
  [6933] = {.lex_state = 123, .external_lex_state = 3},
  [6934] = {.lex_state = 119, .external_lex_state = 3},
  [6935] = {.lex_state = 129, .external_lex_state = 3},
  [6936] = {.lex_state = 119, .external_lex_state = 3},
  [6937] = {.lex_state = 127, .external_lex_state = 3},
  [6938] = {.lex_state = 120, .external_lex_state = 3},
  [6939] = {.lex_state = 128, .external_lex_state = 3},
  [6940] = {.lex_state = 119, .external_lex_state = 3},
  [6941] = {.lex_state = 128, .external_lex_state = 3},
  [6942] = {.lex_state = 119, .external_lex_state = 3},
  [6943] = {.lex_state = 119, .external_lex_state = 3},
  [6944] = {.lex_state = 119, .external_lex_state = 3},
  [6945] = {.lex_state = 127, .external_lex_state = 3},
  [6946] = {.lex_state = 127, .external_lex_state = 3},
  [6947] = {.lex_state = 119, .external_lex_state = 3},
  [6948] = {.lex_state = 128, .external_lex_state = 3},
  [6949] = {.lex_state = 127, .external_lex_state = 3},
  [6950] = {.lex_state = 127, .external_lex_state = 3},
  [6951] = {.lex_state = 119, .external_lex_state = 3},
  [6952] = {.lex_state = 127, .external_lex_state = 3},
  [6953] = {.lex_state = 421, .external_lex_state = 3},
  [6954] = {.lex_state = 127, .external_lex_state = 3},
  [6955] = {.lex_state = 421, .external_lex_state = 3},
  [6956] = {.lex_state = 127, .external_lex_state = 3},
  [6957] = {.lex_state = 421, .external_lex_state = 3},
  [6958] = {.lex_state = 127, .external_lex_state = 3},
  [6959] = {.lex_state = 119, .external_lex_state = 3},
  [6960] = {.lex_state = 421, .external_lex_state = 3},
  [6961] = {.lex_state = 127, .external_lex_state = 3},
  [6962] = {.lex_state = 123, .external_lex_state = 3},
  [6963] = {.lex_state = 127, .external_lex_state = 3},
  [6964] = {.lex_state = 127, .external_lex_state = 3},
  [6965] = {.lex_state = 421, .external_lex_state = 3},
  [6966] = {.lex_state = 128, .external_lex_state = 3},
  [6967] = {.lex_state = 127, .external_lex_state = 3},
  [6968] = {.lex_state = 127, .external_lex_state = 3},
  [6969] = {.lex_state = 30, .external_lex_state = 3},
  [6970] = {.lex_state = 119, .external_lex_state = 3},
  [6971] = {.lex_state = 30, .external_lex_state = 3},
  [6972] = {.lex_state = 119, .external_lex_state = 3},
  [6973] = {.lex_state = 119, .external_lex_state = 3},
  [6974] = {.lex_state = 119, .external_lex_state = 3},
  [6975] = {.lex_state = 131, .external_lex_state = 3},
  [6976] = {.lex_state = 30, .external_lex_state = 3},
  [6977] = {.lex_state = 421, .external_lex_state = 3},
  [6978] = {.lex_state = 123, .external_lex_state = 3},
  [6979] = {.lex_state = 127, .external_lex_state = 3},
  [6980] = {.lex_state = 127, .external_lex_state = 3},
  [6981] = {.lex_state = 129, .external_lex_state = 3},
  [6982] = {.lex_state = 123, .external_lex_state = 3},
  [6983] = {.lex_state = 127, .external_lex_state = 3},
  [6984] = {.lex_state = 421, .external_lex_state = 3},
  [6985] = {.lex_state = 119, .external_lex_state = 3},
  [6986] = {.lex_state = 421, .external_lex_state = 3},
  [6987] = {.lex_state = 30, .external_lex_state = 3},
  [6988] = {.lex_state = 119, .external_lex_state = 3},
  [6989] = {.lex_state = 127, .external_lex_state = 3},
  [6990] = {.lex_state = 129, .external_lex_state = 3},
  [6991] = {.lex_state = 421, .external_lex_state = 3},
  [6992] = {.lex_state = 123, .external_lex_state = 3},
  [6993] = {.lex_state = 123, .external_lex_state = 3},
  [6994] = {.lex_state = 30, .external_lex_state = 3},
  [6995] = {.lex_state = 127, .external_lex_state = 3},
  [6996] = {.lex_state = 127, .external_lex_state = 3},
  [6997] = {.lex_state = 30, .external_lex_state = 3},
  [6998] = {.lex_state = 119, .external_lex_state = 3},
  [6999] = {.lex_state = 119, .external_lex_state = 3},
  [7000] = {.lex_state = 128, .external_lex_state = 3},
  [7001] = {.lex_state = 127, .external_lex_state = 3},
  [7002] = {.lex_state = 421, .external_lex_state = 3},
  [7003] = {.lex_state = 30, .external_lex_state = 3},
  [7004] = {.lex_state = 119, .external_lex_state = 3},
  [7005] = {.lex_state = 30, .external_lex_state = 3},
  [7006] = {.lex_state = 119, .external_lex_state = 3},
  [7007] = {.lex_state = 127, .external_lex_state = 3},
  [7008] = {.lex_state = 127, .external_lex_state = 3},
  [7009] = {.lex_state = 127, .external_lex_state = 3},
  [7010] = {.lex_state = 127, .external_lex_state = 3},
  [7011] = {.lex_state = 127, .external_lex_state = 3},
  [7012] = {.lex_state = 127, .external_lex_state = 3},
  [7013] = {.lex_state = 127, .external_lex_state = 3},
  [7014] = {.lex_state = 127, .external_lex_state = 3},
  [7015] = {.lex_state = 119, .external_lex_state = 3},
  [7016] = {.lex_state = 131, .external_lex_state = 3},
  [7017] = {.lex_state = 30, .external_lex_state = 3},
  [7018] = {.lex_state = 127, .external_lex_state = 3},
  [7019] = {.lex_state = 30, .external_lex_state = 3},
  [7020] = {.lex_state = 7, .external_lex_state = 2},
  [7021] = {.lex_state = 127, .external_lex_state = 3},
  [7022] = {.lex_state = 123, .external_lex_state = 3},
  [7023] = {.lex_state = 421, .external_lex_state = 3},
  [7024] = {.lex_state = 123, .external_lex_state = 3},
  [7025] = {.lex_state = 30, .external_lex_state = 3},
  [7026] = {.lex_state = 421, .external_lex_state = 3},
  [7027] = {.lex_state = 119, .external_lex_state = 3},
  [7028] = {.lex_state = 30, .external_lex_state = 3},
  [7029] = {.lex_state = 421, .external_lex_state = 3},
  [7030] = {.lex_state = 421, .external_lex_state = 3},
  [7031] = {.lex_state = 119, .external_lex_state = 3},
  [7032] = {.lex_state = 127, .external_lex_state = 3},
  [7033] = {.lex_state = 127, .external_lex_state = 3},
  [7034] = {.lex_state = 30, .external_lex_state = 3},
  [7035] = {.lex_state = 127, .external_lex_state = 3},
  [7036] = {.lex_state = 127, .external_lex_state = 3},
  [7037] = {.lex_state = 421, .external_lex_state = 3},
  [7038] = {.lex_state = 119, .external_lex_state = 3},
  [7039] = {.lex_state = 127, .external_lex_state = 3},
  [7040] = {.lex_state = 421, .external_lex_state = 3},
  [7041] = {.lex_state = 30, .external_lex_state = 3},
  [7042] = {.lex_state = 127, .external_lex_state = 3},
  [7043] = {.lex_state = 129, .external_lex_state = 3},
  [7044] = {.lex_state = 129, .external_lex_state = 3},
  [7045] = {.lex_state = 127, .external_lex_state = 3},
  [7046] = {.lex_state = 127, .external_lex_state = 3},
  [7047] = {.lex_state = 127, .external_lex_state = 3},
  [7048] = {.lex_state = 123, .external_lex_state = 3},
  [7049] = {.lex_state = 123, .external_lex_state = 3},
  [7050] = {.lex_state = 127, .external_lex_state = 3},
  [7051] = {.lex_state = 119, .external_lex_state = 3},
  [7052] = {.lex_state = 127, .external_lex_state = 3},
  [7053] = {.lex_state = 123, .external_lex_state = 3},
  [7054] = {.lex_state = 421, .external_lex_state = 3},
  [7055] = {.lex_state = 123, .external_lex_state = 3},
  [7056] = {.lex_state = 123, .external_lex_state = 3},
  [7057] = {.lex_state = 421, .external_lex_state = 3},
  [7058] = {.lex_state = 30, .external_lex_state = 3},
  [7059] = {.lex_state = 421, .external_lex_state = 3},
  [7060] = {.lex_state = 119, .external_lex_state = 3},
  [7061] = {.lex_state = 421, .external_lex_state = 3},
  [7062] = {.lex_state = 123, .external_lex_state = 3},
  [7063] = {.lex_state = 128, .external_lex_state = 3},
  [7064] = {.lex_state = 119, .external_lex_state = 3},
  [7065] = {.lex_state = 119, .external_lex_state = 3},
  [7066] = {.lex_state = 421, .external_lex_state = 3},
  [7067] = {.lex_state = 129, .external_lex_state = 3},
  [7068] = {.lex_state = 11, .external_lex_state = 2},
  [7069] = {.lex_state = 127, .external_lex_state = 3},
  [7070] = {.lex_state = 30, .external_lex_state = 3},
  [7071] = {.lex_state = 127, .external_lex_state = 3},
  [7072] = {.lex_state = 119, .external_lex_state = 3},
  [7073] = {.lex_state = 421, .external_lex_state = 3},
  [7074] = {.lex_state = 421, .external_lex_state = 3},
  [7075] = {.lex_state = 421, .external_lex_state = 3},
  [7076] = {.lex_state = 421, .external_lex_state = 3},
  [7077] = {.lex_state = 30, .external_lex_state = 3},
  [7078] = {.lex_state = 123, .external_lex_state = 3},
  [7079] = {.lex_state = 123, .external_lex_state = 3},
  [7080] = {.lex_state = 421, .external_lex_state = 3},
  [7081] = {.lex_state = 129, .external_lex_state = 3},
  [7082] = {.lex_state = 421, .external_lex_state = 3},
  [7083] = {.lex_state = 127, .external_lex_state = 3},
  [7084] = {.lex_state = 127, .external_lex_state = 3},
  [7085] = {.lex_state = 127, .external_lex_state = 3},
  [7086] = {.lex_state = 128, .external_lex_state = 3},
  [7087] = {.lex_state = 421, .external_lex_state = 3},
  [7088] = {.lex_state = 128, .external_lex_state = 3},
  [7089] = {.lex_state = 30, .external_lex_state = 3},
  [7090] = {.lex_state = 123, .external_lex_state = 3},
  [7091] = {.lex_state = 123, .external_lex_state = 3},
  [7092] = {.lex_state = 127, .external_lex_state = 3},
  [7093] = {.lex_state = 127, .external_lex_state = 3},
  [7094] = {.lex_state = 127, .external_lex_state = 3},
  [7095] = {.lex_state = 127, .external_lex_state = 3},
  [7096] = {.lex_state = 123, .external_lex_state = 3},
  [7097] = {.lex_state = 128, .external_lex_state = 3},
  [7098] = {.lex_state = 123, .external_lex_state = 3},
  [7099] = {.lex_state = 127, .external_lex_state = 3},
  [7100] = {.lex_state = 123, .external_lex_state = 3},
  [7101] = {.lex_state = 123, .external_lex_state = 3},
  [7102] = {.lex_state = 127, .external_lex_state = 3},
  [7103] = {.lex_state = 129, .external_lex_state = 3},
  [7104] = {.lex_state = 119, .external_lex_state = 3},
  [7105] = {.lex_state = 127, .external_lex_state = 3},
  [7106] = {.lex_state = 11, .external_lex_state = 2},
  [7107] = {.lex_state = 119, .external_lex_state = 3},
  [7108] = {.lex_state = 123, .external_lex_state = 3},
  [7109] = {.lex_state = 119, .external_lex_state = 3},
  [7110] = {.lex_state = 7, .external_lex_state = 2},
  [7111] = {.lex_state = 129, .external_lex_state = 3},
  [7112] = {.lex_state = 123, .external_lex_state = 3},
  [7113] = {.lex_state = 123, .external_lex_state = 3},
  [7114] = {.lex_state = 128, .external_lex_state = 3},
  [7115] = {.lex_state = 421, .external_lex_state = 3},
  [7116] = {.lex_state = 119, .external_lex_state = 3},
  [7117] = {.lex_state = 421, .external_lex_state = 3},
  [7118] = {.lex_state = 119, .external_lex_state = 3},
  [7119] = {.lex_state = 127, .external_lex_state = 3},
  [7120] = {.lex_state = 128, .external_lex_state = 3},
  [7121] = {.lex_state = 127, .external_lex_state = 3},
  [7122] = {.lex_state = 127, .external_lex_state = 3},
  [7123] = {.lex_state = 129, .external_lex_state = 3},
  [7124] = {.lex_state = 119, .external_lex_state = 3},
  [7125] = {.lex_state = 119, .external_lex_state = 3},
  [7126] = {.lex_state = 127, .external_lex_state = 3},
  [7127] = {.lex_state = 127, .external_lex_state = 3},
  [7128] = {.lex_state = 128, .external_lex_state = 3},
  [7129] = {.lex_state = 127, .external_lex_state = 3},
  [7130] = {.lex_state = 119, .external_lex_state = 3},
  [7131] = {.lex_state = 128, .external_lex_state = 3},
  [7132] = {.lex_state = 128, .external_lex_state = 3},
  [7133] = {.lex_state = 30, .external_lex_state = 3},
  [7134] = {.lex_state = 30, .external_lex_state = 3},
  [7135] = {.lex_state = 127, .external_lex_state = 3},
  [7136] = {.lex_state = 128, .external_lex_state = 3},
  [7137] = {.lex_state = 128, .external_lex_state = 3},
  [7138] = {.lex_state = 127, .external_lex_state = 3},
  [7139] = {.lex_state = 30, .external_lex_state = 3},
  [7140] = {.lex_state = 128, .external_lex_state = 3},
  [7141] = {.lex_state = 128, .external_lex_state = 3},
  [7142] = {.lex_state = 128, .external_lex_state = 3},
  [7143] = {.lex_state = 129, .external_lex_state = 3},
  [7144] = {.lex_state = 128, .external_lex_state = 3},
  [7145] = {.lex_state = 129, .external_lex_state = 3},
  [7146] = {.lex_state = 7, .external_lex_state = 2},
  [7147] = {.lex_state = 129, .external_lex_state = 3},
  [7148] = {.lex_state = 128, .external_lex_state = 3},
  [7149] = {.lex_state = 128, .external_lex_state = 3},
  [7150] = {.lex_state = 128, .external_lex_state = 3},
  [7151] = {.lex_state = 119, .external_lex_state = 3},
  [7152] = {.lex_state = 30, .external_lex_state = 3},
  [7153] = {.lex_state = 129, .external_lex_state = 3},
  [7154] = {.lex_state = 129, .external_lex_state = 3},
  [7155] = {.lex_state = 129, .external_lex_state = 3},
  [7156] = {.lex_state = 128, .external_lex_state = 3},
  [7157] = {.lex_state = 128, .external_lex_state = 3},
  [7158] = {.lex_state = 30, .external_lex_state = 3},
  [7159] = {.lex_state = 129, .external_lex_state = 3},
  [7160] = {.lex_state = 123, .external_lex_state = 3},
  [7161] = {.lex_state = 421, .external_lex_state = 3},
  [7162] = {.lex_state = 129, .external_lex_state = 3},
  [7163] = {.lex_state = 421, .external_lex_state = 3},
  [7164] = {.lex_state = 129, .external_lex_state = 3},
  [7165] = {.lex_state = 421, .external_lex_state = 3},
  [7166] = {.lex_state = 129, .external_lex_state = 3},
  [7167] = {.lex_state = 30, .external_lex_state = 3},
  [7168] = {.lex_state = 30, .external_lex_state = 3},
  [7169] = {.lex_state = 30, .external_lex_state = 3},
  [7170] = {.lex_state = 129, .external_lex_state = 3},
  [7171] = {.lex_state = 128, .external_lex_state = 3},
  [7172] = {.lex_state = 128, .external_lex_state = 3},
  [7173] = {.lex_state = 30, .external_lex_state = 3},
  [7174] = {.lex_state = 128, .external_lex_state = 3},
  [7175] = {.lex_state = 128, .external_lex_state = 3},
  [7176] = {.lex_state = 128, .external_lex_state = 3},
  [7177] = {.lex_state = 128, .external_lex_state = 3},
  [7178] = {.lex_state = 128, .external_lex_state = 3},
  [7179] = {.lex_state = 30, .external_lex_state = 3},
  [7180] = {.lex_state = 129, .external_lex_state = 3},
  [7181] = {.lex_state = 30, .external_lex_state = 3},
  [7182] = {.lex_state = 128, .external_lex_state = 3},
  [7183] = {.lex_state = 129, .external_lex_state = 3},
  [7184] = {.lex_state = 128, .external_lex_state = 3},
  [7185] = {.lex_state = 129, .external_lex_state = 3},
  [7186] = {.lex_state = 123, .external_lex_state = 3},
  [7187] = {.lex_state = 123, .external_lex_state = 3},
  [7188] = {.lex_state = 11, .external_lex_state = 2},
  [7189] = {.lex_state = 119, .external_lex_state = 3},
  [7190] = {.lex_state = 123, .external_lex_state = 3},
  [7191] = {.lex_state = 129, .external_lex_state = 3},
  [7192] = {.lex_state = 129, .external_lex_state = 3},
  [7193] = {.lex_state = 119, .external_lex_state = 3},
  [7194] = {.lex_state = 127, .external_lex_state = 3},
  [7195] = {.lex_state = 129, .external_lex_state = 3},
  [7196] = {.lex_state = 30, .external_lex_state = 3},
  [7197] = {.lex_state = 128, .external_lex_state = 3},
  [7198] = {.lex_state = 128, .external_lex_state = 3},
  [7199] = {.lex_state = 30, .external_lex_state = 3},
  [7200] = {.lex_state = 128, .external_lex_state = 3},
  [7201] = {.lex_state = 123, .external_lex_state = 3},
  [7202] = {.lex_state = 129, .external_lex_state = 3},
  [7203] = {.lex_state = 129, .external_lex_state = 3},
  [7204] = {.lex_state = 129, .external_lex_state = 3},
  [7205] = {.lex_state = 129, .external_lex_state = 3},
  [7206] = {.lex_state = 129, .external_lex_state = 3},
  [7207] = {.lex_state = 123, .external_lex_state = 3},
  [7208] = {.lex_state = 123, .external_lex_state = 3},
  [7209] = {.lex_state = 421, .external_lex_state = 3},
  [7210] = {.lex_state = 421, .external_lex_state = 3},
  [7211] = {.lex_state = 421, .external_lex_state = 3},
  [7212] = {.lex_state = 128, .external_lex_state = 3},
  [7213] = {.lex_state = 421, .external_lex_state = 3},
  [7214] = {.lex_state = 128, .external_lex_state = 3},
  [7215] = {.lex_state = 128, .external_lex_state = 3},
  [7216] = {.lex_state = 129, .external_lex_state = 3},
  [7217] = {.lex_state = 129, .external_lex_state = 3},
  [7218] = {.lex_state = 128, .external_lex_state = 3},
  [7219] = {.lex_state = 123, .external_lex_state = 3},
  [7220] = {.lex_state = 128, .external_lex_state = 3},
  [7221] = {.lex_state = 128, .external_lex_state = 3},
  [7222] = {.lex_state = 127, .external_lex_state = 3},
  [7223] = {.lex_state = 128, .external_lex_state = 3},
  [7224] = {.lex_state = 129, .external_lex_state = 3},
  [7225] = {.lex_state = 128, .external_lex_state = 3},
  [7226] = {.lex_state = 128, .external_lex_state = 3},
  [7227] = {.lex_state = 129, .external_lex_state = 3},
  [7228] = {.lex_state = 129, .external_lex_state = 3},
  [7229] = {.lex_state = 128, .external_lex_state = 3},
  [7230] = {.lex_state = 129, .external_lex_state = 3},
  [7231] = {.lex_state = 129, .external_lex_state = 3},
  [7232] = {.lex_state = 129, .external_lex_state = 3},
  [7233] = {.lex_state = 26, .external_lex_state = 3},
  [7234] = {.lex_state = 127, .external_lex_state = 3},
  [7235] = {.lex_state = 129, .external_lex_state = 3},
  [7236] = {.lex_state = 127, .external_lex_state = 3},
  [7237] = {.lex_state = 123, .external_lex_state = 3},
  [7238] = {.lex_state = 11, .external_lex_state = 2},
  [7239] = {.lex_state = 7, .external_lex_state = 2},
  [7240] = {.lex_state = 129, .external_lex_state = 3},
  [7241] = {.lex_state = 129, .external_lex_state = 3},
  [7242] = {.lex_state = 11, .external_lex_state = 2},
  [7243] = {.lex_state = 24, .external_lex_state = 3},
  [7244] = {.lex_state = 421, .external_lex_state = 3},
  [7245] = {.lex_state = 129, .external_lex_state = 3},
  [7246] = {.lex_state = 129, .external_lex_state = 3},
  [7247] = {.lex_state = 127, .external_lex_state = 3},
  [7248] = {.lex_state = 123, .external_lex_state = 3},
  [7249] = {.lex_state = 127, .external_lex_state = 3},
  [7250] = {.lex_state = 129, .external_lex_state = 3},
  [7251] = {.lex_state = 128, .external_lex_state = 3},
  [7252] = {.lex_state = 123, .external_lex_state = 3},
  [7253] = {.lex_state = 128, .external_lex_state = 3},
  [7254] = {.lex_state = 129, .external_lex_state = 3},
  [7255] = {.lex_state = 123, .external_lex_state = 3},
  [7256] = {.lex_state = 128, .external_lex_state = 3},
  [7257] = {.lex_state = 128, .external_lex_state = 3},
  [7258] = {.lex_state = 129, .external_lex_state = 3},
  [7259] = {.lex_state = 128, .external_lex_state = 3},
  [7260] = {.lex_state = 129, .external_lex_state = 3},
  [7261] = {.lex_state = 128, .external_lex_state = 3},
  [7262] = {.lex_state = 128, .external_lex_state = 3},
  [7263] = {.lex_state = 128, .external_lex_state = 3},
  [7264] = {.lex_state = 129, .external_lex_state = 3},
  [7265] = {.lex_state = 119, .external_lex_state = 3},
  [7266] = {.lex_state = 119, .external_lex_state = 3},
  [7267] = {.lex_state = 128, .external_lex_state = 3},
  [7268] = {.lex_state = 128, .external_lex_state = 3},
  [7269] = {.lex_state = 127, .external_lex_state = 3},
  [7270] = {.lex_state = 129, .external_lex_state = 3},
  [7271] = {.lex_state = 30, .external_lex_state = 3},
  [7272] = {.lex_state = 129, .external_lex_state = 3},
  [7273] = {.lex_state = 30, .external_lex_state = 3},
  [7274] = {.lex_state = 7, .external_lex_state = 2},
  [7275] = {.lex_state = 128, .external_lex_state = 3},
  [7276] = {.lex_state = 30, .external_lex_state = 3},
  [7277] = {.lex_state = 128, .external_lex_state = 3},
  [7278] = {.lex_state = 128, .external_lex_state = 3},
  [7279] = {.lex_state = 128, .external_lex_state = 3},
  [7280] = {.lex_state = 30, .external_lex_state = 3},
  [7281] = {.lex_state = 15, .external_lex_state = 2},
  [7282] = {.lex_state = 15, .external_lex_state = 2},
  [7283] = {.lex_state = 15, .external_lex_state = 2},
  [7284] = {.lex_state = 15, .external_lex_state = 2},
  [7285] = {.lex_state = 172, .external_lex_state = 3},
  [7286] = {.lex_state = 15, .external_lex_state = 2},
  [7287] = {.lex_state = 15, .external_lex_state = 2},
  [7288] = {.lex_state = 15, .external_lex_state = 2},
  [7289] = {.lex_state = 15, .external_lex_state = 2},
  [7290] = {.lex_state = 15, .external_lex_state = 2},
  [7291] = {.lex_state = 15, .external_lex_state = 2},
  [7292] = {.lex_state = 15, .external_lex_state = 2},
  [7293] = {.lex_state = 15, .external_lex_state = 2},
  [7294] = {.lex_state = 26, .external_lex_state = 3},
  [7295] = {.lex_state = 15, .external_lex_state = 2},
  [7296] = {.lex_state = 26, .external_lex_state = 3},
  [7297] = {.lex_state = 15, .external_lex_state = 2},
  [7298] = {.lex_state = 15, .external_lex_state = 2},
  [7299] = {.lex_state = 15, .external_lex_state = 2},
  [7300] = {.lex_state = 15, .external_lex_state = 2},
  [7301] = {.lex_state = 26, .external_lex_state = 3},
  [7302] = {.lex_state = 26, .external_lex_state = 3},
  [7303] = {.lex_state = 15, .external_lex_state = 2},
  [7304] = {.lex_state = 15, .external_lex_state = 2},
  [7305] = {.lex_state = 15, .external_lex_state = 2},
  [7306] = {.lex_state = 15, .external_lex_state = 2},
  [7307] = {.lex_state = 26, .external_lex_state = 3},
  [7308] = {.lex_state = 15, .external_lex_state = 2},
  [7309] = {.lex_state = 15, .external_lex_state = 2},
  [7310] = {.lex_state = 15, .external_lex_state = 2},
  [7311] = {.lex_state = 15, .external_lex_state = 2},
  [7312] = {.lex_state = 26, .external_lex_state = 3},
  [7313] = {.lex_state = 26, .external_lex_state = 3},
  [7314] = {.lex_state = 15, .external_lex_state = 2},
  [7315] = {.lex_state = 172, .external_lex_state = 3},
  [7316] = {.lex_state = 15, .external_lex_state = 2},
  [7317] = {.lex_state = 15, .external_lex_state = 2},
  [7318] = {.lex_state = 15, .external_lex_state = 2},
  [7319] = {.lex_state = 24, .external_lex_state = 3},
  [7320] = {.lex_state = 15, .external_lex_state = 2},
  [7321] = {.lex_state = 15, .external_lex_state = 2},
  [7322] = {.lex_state = 26, .external_lex_state = 3},
  [7323] = {.lex_state = 15, .external_lex_state = 2},
  [7324] = {.lex_state = 15, .external_lex_state = 2},
  [7325] = {.lex_state = 15, .external_lex_state = 2},
  [7326] = {.lex_state = 15, .external_lex_state = 2},
  [7327] = {.lex_state = 15, .external_lex_state = 2},
  [7328] = {.lex_state = 15, .external_lex_state = 2},
  [7329] = {.lex_state = 11, .external_lex_state = 2},
  [7330] = {.lex_state = 15, .external_lex_state = 2},
  [7331] = {.lex_state = 26, .external_lex_state = 3},
  [7332] = {.lex_state = 15, .external_lex_state = 2},
  [7333] = {.lex_state = 15, .external_lex_state = 2},
  [7334] = {.lex_state = 15, .external_lex_state = 2},
  [7335] = {.lex_state = 15, .external_lex_state = 2},
  [7336] = {.lex_state = 26, .external_lex_state = 3},
  [7337] = {.lex_state = 15, .external_lex_state = 2},
  [7338] = {.lex_state = 15, .external_lex_state = 2},
  [7339] = {.lex_state = 15, .external_lex_state = 2},
  [7340] = {.lex_state = 15, .external_lex_state = 2},
  [7341] = {.lex_state = 15, .external_lex_state = 2},
  [7342] = {.lex_state = 15, .external_lex_state = 2},
  [7343] = {.lex_state = 15, .external_lex_state = 2},
  [7344] = {.lex_state = 24, .external_lex_state = 3},
  [7345] = {.lex_state = 15, .external_lex_state = 2},
  [7346] = {.lex_state = 15, .external_lex_state = 2},
  [7347] = {.lex_state = 26, .external_lex_state = 3},
  [7348] = {.lex_state = 15, .external_lex_state = 2},
  [7349] = {.lex_state = 26, .external_lex_state = 3},
  [7350] = {.lex_state = 26, .external_lex_state = 3},
  [7351] = {.lex_state = 11, .external_lex_state = 2},
  [7352] = {.lex_state = 26, .external_lex_state = 3},
  [7353] = {.lex_state = 11, .external_lex_state = 2},
  [7354] = {.lex_state = 11, .external_lex_state = 2},
  [7355] = {.lex_state = 26, .external_lex_state = 3},
  [7356] = {.lex_state = 11, .external_lex_state = 2},
  [7357] = {.lex_state = 11, .external_lex_state = 2},
  [7358] = {.lex_state = 24, .external_lex_state = 3},
  [7359] = {.lex_state = 11, .external_lex_state = 2},
  [7360] = {.lex_state = 11, .external_lex_state = 2},
  [7361] = {.lex_state = 121, .external_lex_state = 3},
  [7362] = {.lex_state = 15, .external_lex_state = 2},
  [7363] = {.lex_state = 15, .external_lex_state = 2},
  [7364] = {.lex_state = 26, .external_lex_state = 3},
  [7365] = {.lex_state = 15, .external_lex_state = 2},
  [7366] = {.lex_state = 11, .external_lex_state = 2},
  [7367] = {.lex_state = 11, .external_lex_state = 2},
  [7368] = {.lex_state = 11, .external_lex_state = 2},
  [7369] = {.lex_state = 26, .external_lex_state = 3},
  [7370] = {.lex_state = 24, .external_lex_state = 3},
  [7371] = {.lex_state = 11, .external_lex_state = 2},
  [7372] = {.lex_state = 26, .external_lex_state = 3},
  [7373] = {.lex_state = 26, .external_lex_state = 3},
  [7374] = {.lex_state = 24, .external_lex_state = 3},
  [7375] = {.lex_state = 173, .external_lex_state = 3},
  [7376] = {.lex_state = 11, .external_lex_state = 2},
  [7377] = {.lex_state = 15, .external_lex_state = 2},
  [7378] = {.lex_state = 11, .external_lex_state = 2},
  [7379] = {.lex_state = 11, .external_lex_state = 2},
  [7380] = {.lex_state = 15, .external_lex_state = 2},
  [7381] = {.lex_state = 24, .external_lex_state = 3},
  [7382] = {.lex_state = 24, .external_lex_state = 3},
  [7383] = {.lex_state = 15, .external_lex_state = 2},
  [7384] = {.lex_state = 11, .external_lex_state = 2},
  [7385] = {.lex_state = 15, .external_lex_state = 2},
  [7386] = {.lex_state = 15, .external_lex_state = 2},
  [7387] = {.lex_state = 11, .external_lex_state = 2},
  [7388] = {.lex_state = 11, .external_lex_state = 2},
  [7389] = {.lex_state = 11, .external_lex_state = 2},
  [7390] = {.lex_state = 11, .external_lex_state = 2},
  [7391] = {.lex_state = 11, .external_lex_state = 2},
  [7392] = {.lex_state = 173, .external_lex_state = 3},
  [7393] = {.lex_state = 24, .external_lex_state = 3},
  [7394] = {.lex_state = 11, .external_lex_state = 2},
  [7395] = {.lex_state = 11, .external_lex_state = 2},
  [7396] = {.lex_state = 11, .external_lex_state = 2},
  [7397] = {.lex_state = 11, .external_lex_state = 2},
  [7398] = {.lex_state = 11, .external_lex_state = 2},
  [7399] = {.lex_state = 11, .external_lex_state = 2},
  [7400] = {.lex_state = 11, .external_lex_state = 2},
  [7401] = {.lex_state = 24, .external_lex_state = 3},
  [7402] = {.lex_state = 11, .external_lex_state = 2},
  [7403] = {.lex_state = 11, .external_lex_state = 2},
  [7404] = {.lex_state = 11, .external_lex_state = 2},
  [7405] = {.lex_state = 11, .external_lex_state = 2},
  [7406] = {.lex_state = 11, .external_lex_state = 2},
  [7407] = {.lex_state = 11, .external_lex_state = 2},
  [7408] = {.lex_state = 11, .external_lex_state = 2},
  [7409] = {.lex_state = 11, .external_lex_state = 2},
  [7410] = {.lex_state = 11, .external_lex_state = 2},
  [7411] = {.lex_state = 15, .external_lex_state = 2},
  [7412] = {.lex_state = 15, .external_lex_state = 2},
  [7413] = {.lex_state = 11, .external_lex_state = 2},
  [7414] = {.lex_state = 11, .external_lex_state = 2},
  [7415] = {.lex_state = 11, .external_lex_state = 2},
  [7416] = {.lex_state = 120, .external_lex_state = 3},
  [7417] = {.lex_state = 11, .external_lex_state = 2},
  [7418] = {.lex_state = 24, .external_lex_state = 3},
  [7419] = {.lex_state = 11, .external_lex_state = 2},
  [7420] = {.lex_state = 11, .external_lex_state = 2},
  [7421] = {.lex_state = 11, .external_lex_state = 2},
  [7422] = {.lex_state = 11, .external_lex_state = 2},
  [7423] = {.lex_state = 11, .external_lex_state = 2},
  [7424] = {.lex_state = 24, .external_lex_state = 3},
  [7425] = {.lex_state = 11, .external_lex_state = 2},
  [7426] = {.lex_state = 26, .external_lex_state = 3},
  [7427] = {.lex_state = 11, .external_lex_state = 2},
  [7428] = {.lex_state = 120, .external_lex_state = 3},
  [7429] = {.lex_state = 193, .external_lex_state = 3},
  [7430] = {.lex_state = 11, .external_lex_state = 2},
  [7431] = {.lex_state = 194, .external_lex_state = 3},
  [7432] = {.lex_state = 24, .external_lex_state = 3},
  [7433] = {.lex_state = 15, .external_lex_state = 2},
  [7434] = {.lex_state = 15, .external_lex_state = 2},
  [7435] = {.lex_state = 15, .external_lex_state = 2},
  [7436] = {.lex_state = 15, .external_lex_state = 2},
  [7437] = {.lex_state = 125, .external_lex_state = 3},
  [7438] = {.lex_state = 15, .external_lex_state = 2},
  [7439] = {.lex_state = 24, .external_lex_state = 3},
  [7440] = {.lex_state = 11, .external_lex_state = 2},
  [7441] = {.lex_state = 15, .external_lex_state = 2},
  [7442] = {.lex_state = 11, .external_lex_state = 2},
  [7443] = {.lex_state = 11, .external_lex_state = 2},
  [7444] = {.lex_state = 24, .external_lex_state = 3},
  [7445] = {.lex_state = 24, .external_lex_state = 3},
  [7446] = {.lex_state = 118, .external_lex_state = 3},
  [7447] = {.lex_state = 122, .external_lex_state = 3},
  [7448] = {.lex_state = 15, .external_lex_state = 2},
  [7449] = {.lex_state = 24, .external_lex_state = 3},
  [7450] = {.lex_state = 24, .external_lex_state = 3},
  [7451] = {.lex_state = 11, .external_lex_state = 2},
  [7452] = {.lex_state = 24, .external_lex_state = 3},
  [7453] = {.lex_state = 11, .external_lex_state = 2},
  [7454] = {.lex_state = 15, .external_lex_state = 2},
  [7455] = {.lex_state = 24, .external_lex_state = 3},
  [7456] = {.lex_state = 15, .external_lex_state = 2},
  [7457] = {.lex_state = 15, .external_lex_state = 2},
  [7458] = {.lex_state = 126, .external_lex_state = 3},
  [7459] = {.lex_state = 15, .external_lex_state = 2},
  [7460] = {.lex_state = 11, .external_lex_state = 2},
  [7461] = {.lex_state = 15, .external_lex_state = 2},
  [7462] = {.lex_state = 11, .external_lex_state = 2},
  [7463] = {.lex_state = 24, .external_lex_state = 3},
  [7464] = {.lex_state = 124, .external_lex_state = 3},
  [7465] = {.lex_state = 15, .external_lex_state = 2},
  [7466] = {.lex_state = 30, .external_lex_state = 3},
  [7467] = {.lex_state = 14, .external_lex_state = 2},
  [7468] = {.lex_state = 172, .external_lex_state = 3},
  [7469] = {.lex_state = 172, .external_lex_state = 3},
  [7470] = {.lex_state = 14, .external_lex_state = 2},
  [7471] = {.lex_state = 14, .external_lex_state = 2},
  [7472] = {.lex_state = 14, .external_lex_state = 2},
  [7473] = {.lex_state = 173, .external_lex_state = 3},
  [7474] = {.lex_state = 173, .external_lex_state = 3},
  [7475] = {.lex_state = 172, .external_lex_state = 3},
  [7476] = {.lex_state = 172, .external_lex_state = 3},
  [7477] = {.lex_state = 173, .external_lex_state = 3},
  [7478] = {.lex_state = 172, .external_lex_state = 3},
  [7479] = {.lex_state = 173, .external_lex_state = 3},
  [7480] = {.lex_state = 14, .external_lex_state = 2},
  [7481] = {.lex_state = 14, .external_lex_state = 2},
  [7482] = {.lex_state = 10, .external_lex_state = 2},
  [7483] = {.lex_state = 172, .external_lex_state = 3},
  [7484] = {.lex_state = 173, .external_lex_state = 3},
  [7485] = {.lex_state = 14, .external_lex_state = 2},
  [7486] = {.lex_state = 14, .external_lex_state = 2},
  [7487] = {.lex_state = 172, .external_lex_state = 3},
  [7488] = {.lex_state = 14, .external_lex_state = 2},
  [7489] = {.lex_state = 14, .external_lex_state = 2},
  [7490] = {.lex_state = 14, .external_lex_state = 2},
  [7491] = {.lex_state = 14, .external_lex_state = 2},
  [7492] = {.lex_state = 172, .external_lex_state = 3},
  [7493] = {.lex_state = 172, .external_lex_state = 3},
  [7494] = {.lex_state = 14, .external_lex_state = 2},
  [7495] = {.lex_state = 14, .external_lex_state = 2},
  [7496] = {.lex_state = 14, .external_lex_state = 2},
  [7497] = {.lex_state = 14, .external_lex_state = 2},
  [7498] = {.lex_state = 14, .external_lex_state = 2},
  [7499] = {.lex_state = 124, .external_lex_state = 3},
  [7500] = {.lex_state = 14, .external_lex_state = 2},
  [7501] = {.lex_state = 123, .external_lex_state = 3},
  [7502] = {.lex_state = 126, .external_lex_state = 3},
  [7503] = {.lex_state = 172, .external_lex_state = 3},
  [7504] = {.lex_state = 172, .external_lex_state = 3},
  [7505] = {.lex_state = 173, .external_lex_state = 3},
  [7506] = {.lex_state = 173, .external_lex_state = 3},
  [7507] = {.lex_state = 173, .external_lex_state = 3},
  [7508] = {.lex_state = 173, .external_lex_state = 3},
  [7509] = {.lex_state = 173, .external_lex_state = 3},
  [7510] = {.lex_state = 173, .external_lex_state = 3},
  [7511] = {.lex_state = 173, .external_lex_state = 3},
  [7512] = {.lex_state = 173, .external_lex_state = 3},
  [7513] = {.lex_state = 173, .external_lex_state = 3},
  [7514] = {.lex_state = 173, .external_lex_state = 3},
  [7515] = {.lex_state = 173, .external_lex_state = 3},
  [7516] = {.lex_state = 429, .external_lex_state = 2},
  [7517] = {.lex_state = 172, .external_lex_state = 3},
  [7518] = {.lex_state = 124, .external_lex_state = 3},
  [7519] = {.lex_state = 421, .external_lex_state = 3},
  [7520] = {.lex_state = 14, .external_lex_state = 2},
  [7521] = {.lex_state = 14, .external_lex_state = 2},
  [7522] = {.lex_state = 173, .external_lex_state = 3},
  [7523] = {.lex_state = 173, .external_lex_state = 3},
  [7524] = {.lex_state = 14, .external_lex_state = 2},
  [7525] = {.lex_state = 14, .external_lex_state = 2},
  [7526] = {.lex_state = 173, .external_lex_state = 3},
  [7527] = {.lex_state = 129, .external_lex_state = 3},
  [7528] = {.lex_state = 14, .external_lex_state = 2},
  [7529] = {.lex_state = 14, .external_lex_state = 2},
  [7530] = {.lex_state = 173, .external_lex_state = 3},
  [7531] = {.lex_state = 173, .external_lex_state = 3},
  [7532] = {.lex_state = 126, .external_lex_state = 3},
  [7533] = {.lex_state = 122, .external_lex_state = 3},
  [7534] = {.lex_state = 423, .external_lex_state = 3},
  [7535] = {.lex_state = 173, .external_lex_state = 3},
  [7536] = {.lex_state = 173, .external_lex_state = 3},
  [7537] = {.lex_state = 172, .external_lex_state = 3},
  [7538] = {.lex_state = 173, .external_lex_state = 3},
  [7539] = {.lex_state = 125, .external_lex_state = 3},
  [7540] = {.lex_state = 118, .external_lex_state = 3},
  [7541] = {.lex_state = 173, .external_lex_state = 3},
  [7542] = {.lex_state = 173, .external_lex_state = 3},
  [7543] = {.lex_state = 173, .external_lex_state = 3},
  [7544] = {.lex_state = 173, .external_lex_state = 3},
  [7545] = {.lex_state = 118, .external_lex_state = 3},
  [7546] = {.lex_state = 11, .external_lex_state = 2},
  [7547] = {.lex_state = 10, .external_lex_state = 2},
  [7548] = {.lex_state = 11, .external_lex_state = 2},
  [7549] = {.lex_state = 173, .external_lex_state = 3},
  [7550] = {.lex_state = 11, .external_lex_state = 2},
  [7551] = {.lex_state = 14, .external_lex_state = 2},
  [7552] = {.lex_state = 14, .external_lex_state = 2},
  [7553] = {.lex_state = 125, .external_lex_state = 3},
  [7554] = {.lex_state = 173, .external_lex_state = 3},
  [7555] = {.lex_state = 122, .external_lex_state = 3},
  [7556] = {.lex_state = 11, .external_lex_state = 2},
  [7557] = {.lex_state = 11, .external_lex_state = 2},
  [7558] = {.lex_state = 11, .external_lex_state = 2},
  [7559] = {.lex_state = 173, .external_lex_state = 3},
  [7560] = {.lex_state = 11, .external_lex_state = 2},
  [7561] = {.lex_state = 173, .external_lex_state = 3},
  [7562] = {.lex_state = 429, .external_lex_state = 2},
  [7563] = {.lex_state = 172, .external_lex_state = 3},
  [7564] = {.lex_state = 172, .external_lex_state = 3},
  [7565] = {.lex_state = 173, .external_lex_state = 3},
  [7566] = {.lex_state = 11, .external_lex_state = 2},
  [7567] = {.lex_state = 11, .external_lex_state = 2},
  [7568] = {.lex_state = 172, .external_lex_state = 3},
  [7569] = {.lex_state = 121, .external_lex_state = 3},
  [7570] = {.lex_state = 11, .external_lex_state = 2},
  [7571] = {.lex_state = 425, .external_lex_state = 3},
  [7572] = {.lex_state = 11, .external_lex_state = 2},
  [7573] = {.lex_state = 11, .external_lex_state = 2},
  [7574] = {.lex_state = 11, .external_lex_state = 2},
  [7575] = {.lex_state = 11, .external_lex_state = 2},
  [7576] = {.lex_state = 14, .external_lex_state = 2},
  [7577] = {.lex_state = 14, .external_lex_state = 2},
  [7578] = {.lex_state = 11, .external_lex_state = 2},
  [7579] = {.lex_state = 172, .external_lex_state = 3},
  [7580] = {.lex_state = 14, .external_lex_state = 2},
  [7581] = {.lex_state = 14, .external_lex_state = 2},
  [7582] = {.lex_state = 173, .external_lex_state = 3},
  [7583] = {.lex_state = 172, .external_lex_state = 3},
  [7584] = {.lex_state = 421, .external_lex_state = 3},
  [7585] = {.lex_state = 10, .external_lex_state = 2},
  [7586] = {.lex_state = 421, .external_lex_state = 3},
  [7587] = {.lex_state = 423, .external_lex_state = 3},
  [7588] = {.lex_state = 11, .external_lex_state = 2},
  [7589] = {.lex_state = 172, .external_lex_state = 3},
  [7590] = {.lex_state = 421, .external_lex_state = 3},
  [7591] = {.lex_state = 172, .external_lex_state = 3},
  [7592] = {.lex_state = 172, .external_lex_state = 3},
  [7593] = {.lex_state = 173, .external_lex_state = 3},
  [7594] = {.lex_state = 172, .external_lex_state = 3},
  [7595] = {.lex_state = 173, .external_lex_state = 3},
  [7596] = {.lex_state = 11, .external_lex_state = 2},
  [7597] = {.lex_state = 11, .external_lex_state = 2},
  [7598] = {.lex_state = 173, .external_lex_state = 3},
  [7599] = {.lex_state = 173, .external_lex_state = 3},
  [7600] = {.lex_state = 173, .external_lex_state = 3},
  [7601] = {.lex_state = 11, .external_lex_state = 2},
  [7602] = {.lex_state = 172, .external_lex_state = 3},
  [7603] = {.lex_state = 173, .external_lex_state = 3},
  [7604] = {.lex_state = 14, .external_lex_state = 2},
  [7605] = {.lex_state = 14, .external_lex_state = 2},
  [7606] = {.lex_state = 14, .external_lex_state = 2},
  [7607] = {.lex_state = 14, .external_lex_state = 2},
  [7608] = {.lex_state = 173, .external_lex_state = 3},
  [7609] = {.lex_state = 172, .external_lex_state = 3},
  [7610] = {.lex_state = 14, .external_lex_state = 2},
  [7611] = {.lex_state = 14, .external_lex_state = 2},
  [7612] = {.lex_state = 128, .external_lex_state = 3},
  [7613] = {.lex_state = 172, .external_lex_state = 3},
  [7614] = {.lex_state = 121, .external_lex_state = 3},
  [7615] = {.lex_state = 14, .external_lex_state = 2},
  [7616] = {.lex_state = 14, .external_lex_state = 2},
  [7617] = {.lex_state = 14, .external_lex_state = 2},
  [7618] = {.lex_state = 173, .external_lex_state = 3},
  [7619] = {.lex_state = 173, .external_lex_state = 3},
  [7620] = {.lex_state = 173, .external_lex_state = 3},
  [7621] = {.lex_state = 172, .external_lex_state = 3},
  [7622] = {.lex_state = 173, .external_lex_state = 3},
  [7623] = {.lex_state = 421, .external_lex_state = 3},
  [7624] = {.lex_state = 172, .external_lex_state = 3},
  [7625] = {.lex_state = 172, .external_lex_state = 3},
  [7626] = {.lex_state = 172, .external_lex_state = 3},
  [7627] = {.lex_state = 173, .external_lex_state = 3},
  [7628] = {.lex_state = 173, .external_lex_state = 3},
  [7629] = {.lex_state = 172, .external_lex_state = 3},
  [7630] = {.lex_state = 172, .external_lex_state = 3},
  [7631] = {.lex_state = 173, .external_lex_state = 3},
  [7632] = {.lex_state = 172, .external_lex_state = 3},
  [7633] = {.lex_state = 173, .external_lex_state = 3},
  [7634] = {.lex_state = 172, .external_lex_state = 3},
  [7635] = {.lex_state = 172, .external_lex_state = 3},
  [7636] = {.lex_state = 173, .external_lex_state = 3},
  [7637] = {.lex_state = 172, .external_lex_state = 3},
  [7638] = {.lex_state = 172, .external_lex_state = 3},
  [7639] = {.lex_state = 11, .external_lex_state = 2},
  [7640] = {.lex_state = 173, .external_lex_state = 3},
  [7641] = {.lex_state = 421, .external_lex_state = 3},
  [7642] = {.lex_state = 173, .external_lex_state = 3},
  [7643] = {.lex_state = 173, .external_lex_state = 3},
  [7644] = {.lex_state = 172, .external_lex_state = 3},
  [7645] = {.lex_state = 173, .external_lex_state = 3},
  [7646] = {.lex_state = 172, .external_lex_state = 3},
  [7647] = {.lex_state = 172, .external_lex_state = 3},
  [7648] = {.lex_state = 172, .external_lex_state = 3},
  [7649] = {.lex_state = 14, .external_lex_state = 2},
  [7650] = {.lex_state = 172, .external_lex_state = 3},
  [7651] = {.lex_state = 172, .external_lex_state = 3},
  [7652] = {.lex_state = 172, .external_lex_state = 3},
  [7653] = {.lex_state = 421, .external_lex_state = 3},
  [7654] = {.lex_state = 421, .external_lex_state = 3},
  [7655] = {.lex_state = 173, .external_lex_state = 3},
  [7656] = {.lex_state = 172, .external_lex_state = 3},
  [7657] = {.lex_state = 172, .external_lex_state = 3},
  [7658] = {.lex_state = 172, .external_lex_state = 3},
  [7659] = {.lex_state = 14, .external_lex_state = 2},
  [7660] = {.lex_state = 119, .external_lex_state = 3},
  [7661] = {.lex_state = 173, .external_lex_state = 3},
  [7662] = {.lex_state = 14, .external_lex_state = 2},
  [7663] = {.lex_state = 172, .external_lex_state = 3},
  [7664] = {.lex_state = 172, .external_lex_state = 3},
  [7665] = {.lex_state = 172, .external_lex_state = 3},
  [7666] = {.lex_state = 14, .external_lex_state = 2},
  [7667] = {.lex_state = 172, .external_lex_state = 3},
  [7668] = {.lex_state = 173, .external_lex_state = 3},
  [7669] = {.lex_state = 14, .external_lex_state = 2},
  [7670] = {.lex_state = 14, .external_lex_state = 2},
  [7671] = {.lex_state = 173, .external_lex_state = 3},
  [7672] = {.lex_state = 14, .external_lex_state = 2},
  [7673] = {.lex_state = 173, .external_lex_state = 3},
  [7674] = {.lex_state = 173, .external_lex_state = 3},
  [7675] = {.lex_state = 14, .external_lex_state = 2},
  [7676] = {.lex_state = 14, .external_lex_state = 2},
  [7677] = {.lex_state = 14, .external_lex_state = 2},
  [7678] = {.lex_state = 14, .external_lex_state = 2},
  [7679] = {.lex_state = 172, .external_lex_state = 3},
  [7680] = {.lex_state = 172, .external_lex_state = 3},
  [7681] = {.lex_state = 14, .external_lex_state = 2},
  [7682] = {.lex_state = 14, .external_lex_state = 2},
  [7683] = {.lex_state = 14, .external_lex_state = 2},
  [7684] = {.lex_state = 14, .external_lex_state = 2},
  [7685] = {.lex_state = 127, .external_lex_state = 3},
  [7686] = {.lex_state = 172, .external_lex_state = 3},
  [7687] = {.lex_state = 172, .external_lex_state = 3},
  [7688] = {.lex_state = 172, .external_lex_state = 3},
  [7689] = {.lex_state = 14, .external_lex_state = 2},
  [7690] = {.lex_state = 14, .external_lex_state = 2},
  [7691] = {.lex_state = 14, .external_lex_state = 2},
  [7692] = {.lex_state = 14, .external_lex_state = 2},
  [7693] = {.lex_state = 14, .external_lex_state = 2},
  [7694] = {.lex_state = 14, .external_lex_state = 2},
  [7695] = {.lex_state = 14, .external_lex_state = 2},
  [7696] = {.lex_state = 14, .external_lex_state = 2},
  [7697] = {.lex_state = 14, .external_lex_state = 2},
  [7698] = {.lex_state = 14, .external_lex_state = 2},
  [7699] = {.lex_state = 14, .external_lex_state = 2},
  [7700] = {.lex_state = 14, .external_lex_state = 2},
  [7701] = {.lex_state = 14, .external_lex_state = 2},
  [7702] = {.lex_state = 14, .external_lex_state = 2},
  [7703] = {.lex_state = 14, .external_lex_state = 2},
  [7704] = {.lex_state = 14, .external_lex_state = 2},
  [7705] = {.lex_state = 172, .external_lex_state = 3},
  [7706] = {.lex_state = 14, .external_lex_state = 2},
  [7707] = {.lex_state = 14, .external_lex_state = 2},
  [7708] = {.lex_state = 14, .external_lex_state = 2},
  [7709] = {.lex_state = 14, .external_lex_state = 2},
  [7710] = {.lex_state = 14, .external_lex_state = 2},
  [7711] = {.lex_state = 14, .external_lex_state = 2},
  [7712] = {.lex_state = 14, .external_lex_state = 2},
  [7713] = {.lex_state = 429, .external_lex_state = 2},
  [7714] = {.lex_state = 14, .external_lex_state = 2},
  [7715] = {.lex_state = 421, .external_lex_state = 3},
  [7716] = {.lex_state = 173, .external_lex_state = 3},
  [7717] = {.lex_state = 429, .external_lex_state = 2},
  [7718] = {.lex_state = 14, .external_lex_state = 2},
  [7719] = {.lex_state = 14, .external_lex_state = 2},
  [7720] = {.lex_state = 14, .external_lex_state = 2},
  [7721] = {.lex_state = 172, .external_lex_state = 3},
  [7722] = {.lex_state = 14, .external_lex_state = 2},
  [7723] = {.lex_state = 172, .external_lex_state = 3},
  [7724] = {.lex_state = 172, .external_lex_state = 3},
  [7725] = {.lex_state = 14, .external_lex_state = 2},
  [7726] = {.lex_state = 172, .external_lex_state = 3},
  [7727] = {.lex_state = 172, .external_lex_state = 3},
  [7728] = {.lex_state = 423, .external_lex_state = 3},
  [7729] = {.lex_state = 423, .external_lex_state = 3},
  [7730] = {.lex_state = 30, .external_lex_state = 3},
  [7731] = {.lex_state = 123, .external_lex_state = 3},
  [7732] = {.lex_state = 7, .external_lex_state = 2},
  [7733] = {.lex_state = 7, .external_lex_state = 2},
  [7734] = {.lex_state = 30, .external_lex_state = 3},
  [7735] = {.lex_state = 7, .external_lex_state = 2},
  [7736] = {.lex_state = 30, .external_lex_state = 3},
  [7737] = {.lex_state = 30, .external_lex_state = 3},
  [7738] = {.lex_state = 7, .external_lex_state = 2},
  [7739] = {.lex_state = 423, .external_lex_state = 3},
  [7740] = {.lex_state = 129, .external_lex_state = 3},
  [7741] = {.lex_state = 30, .external_lex_state = 3},
  [7742] = {.lex_state = 423, .external_lex_state = 3},
  [7743] = {.lex_state = 423, .external_lex_state = 3},
  [7744] = {.lex_state = 423, .external_lex_state = 3},
  [7745] = {.lex_state = 423, .external_lex_state = 3},
  [7746] = {.lex_state = 423, .external_lex_state = 3},
  [7747] = {.lex_state = 423, .external_lex_state = 3},
  [7748] = {.lex_state = 123, .external_lex_state = 3},
  [7749] = {.lex_state = 423, .external_lex_state = 3},
  [7750] = {.lex_state = 423, .external_lex_state = 3},
  [7751] = {.lex_state = 128, .external_lex_state = 3},
  [7752] = {.lex_state = 7, .external_lex_state = 2},
  [7753] = {.lex_state = 7, .external_lex_state = 2},
  [7754] = {.lex_state = 423, .external_lex_state = 3},
  [7755] = {.lex_state = 7, .external_lex_state = 2},
  [7756] = {.lex_state = 7, .external_lex_state = 2},
  [7757] = {.lex_state = 423, .external_lex_state = 3},
  [7758] = {.lex_state = 423, .external_lex_state = 3},
  [7759] = {.lex_state = 423, .external_lex_state = 3},
  [7760] = {.lex_state = 423, .external_lex_state = 3},
  [7761] = {.lex_state = 423, .external_lex_state = 3},
  [7762] = {.lex_state = 129, .external_lex_state = 3},
  [7763] = {.lex_state = 423, .external_lex_state = 3},
  [7764] = {.lex_state = 7, .external_lex_state = 2},
  [7765] = {.lex_state = 423, .external_lex_state = 3},
  [7766] = {.lex_state = 423, .external_lex_state = 3},
  [7767] = {.lex_state = 7, .external_lex_state = 2},
  [7768] = {.lex_state = 423, .external_lex_state = 3},
  [7769] = {.lex_state = 423, .external_lex_state = 3},
  [7770] = {.lex_state = 423, .external_lex_state = 3},
  [7771] = {.lex_state = 423, .external_lex_state = 3},
  [7772] = {.lex_state = 7, .external_lex_state = 2},
  [7773] = {.lex_state = 7, .external_lex_state = 2},
  [7774] = {.lex_state = 423, .external_lex_state = 3},
  [7775] = {.lex_state = 423, .external_lex_state = 3},
  [7776] = {.lex_state = 174, .external_lex_state = 3},
  [7777] = {.lex_state = 423, .external_lex_state = 3},
  [7778] = {.lex_state = 423, .external_lex_state = 3},
  [7779] = {.lex_state = 7, .external_lex_state = 2},
  [7780] = {.lex_state = 174, .external_lex_state = 3},
  [7781] = {.lex_state = 423, .external_lex_state = 3},
  [7782] = {.lex_state = 423, .external_lex_state = 3},
  [7783] = {.lex_state = 7, .external_lex_state = 2},
  [7784] = {.lex_state = 7, .external_lex_state = 2},
  [7785] = {.lex_state = 423, .external_lex_state = 3},
  [7786] = {.lex_state = 30, .external_lex_state = 3},
  [7787] = {.lex_state = 423, .external_lex_state = 3},
  [7788] = {.lex_state = 7, .external_lex_state = 2},
  [7789] = {.lex_state = 7, .external_lex_state = 2},
  [7790] = {.lex_state = 7, .external_lex_state = 2},
  [7791] = {.lex_state = 127, .external_lex_state = 3},
  [7792] = {.lex_state = 7, .external_lex_state = 2},
  [7793] = {.lex_state = 7, .external_lex_state = 2},
  [7794] = {.lex_state = 423, .external_lex_state = 3},
  [7795] = {.lex_state = 423, .external_lex_state = 3},
  [7796] = {.lex_state = 423, .external_lex_state = 3},
  [7797] = {.lex_state = 423, .external_lex_state = 3},
  [7798] = {.lex_state = 7, .external_lex_state = 2},
  [7799] = {.lex_state = 423, .external_lex_state = 3},
  [7800] = {.lex_state = 423, .external_lex_state = 3},
  [7801] = {.lex_state = 423, .external_lex_state = 3},
  [7802] = {.lex_state = 423, .external_lex_state = 3},
  [7803] = {.lex_state = 423, .external_lex_state = 3},
  [7804] = {.lex_state = 30, .external_lex_state = 3},
  [7805] = {.lex_state = 128, .external_lex_state = 3},
  [7806] = {.lex_state = 423, .external_lex_state = 3},
  [7807] = {.lex_state = 423, .external_lex_state = 3},
  [7808] = {.lex_state = 423, .external_lex_state = 3},
  [7809] = {.lex_state = 423, .external_lex_state = 3},
  [7810] = {.lex_state = 423, .external_lex_state = 3},
  [7811] = {.lex_state = 423, .external_lex_state = 3},
  [7812] = {.lex_state = 7, .external_lex_state = 2},
  [7813] = {.lex_state = 423, .external_lex_state = 3},
  [7814] = {.lex_state = 423, .external_lex_state = 3},
  [7815] = {.lex_state = 423, .external_lex_state = 3},
  [7816] = {.lex_state = 423, .external_lex_state = 3},
  [7817] = {.lex_state = 423, .external_lex_state = 3},
  [7818] = {.lex_state = 423, .external_lex_state = 3},
  [7819] = {.lex_state = 423, .external_lex_state = 3},
  [7820] = {.lex_state = 119, .external_lex_state = 3},
  [7821] = {.lex_state = 7, .external_lex_state = 2},
  [7822] = {.lex_state = 7, .external_lex_state = 2},
  [7823] = {.lex_state = 423, .external_lex_state = 3},
  [7824] = {.lex_state = 423, .external_lex_state = 3},
  [7825] = {.lex_state = 423, .external_lex_state = 3},
  [7826] = {.lex_state = 119, .external_lex_state = 3},
  [7827] = {.lex_state = 127, .external_lex_state = 3},
  [7828] = {.lex_state = 423, .external_lex_state = 3},
  [7829] = {.lex_state = 423, .external_lex_state = 3},
  [7830] = {.lex_state = 7, .external_lex_state = 2},
  [7831] = {.lex_state = 423, .external_lex_state = 3},
  [7832] = {.lex_state = 195, .external_lex_state = 3},
  [7833] = {.lex_state = 7, .external_lex_state = 2},
  [7834] = {.lex_state = 423, .external_lex_state = 3},
  [7835] = {.lex_state = 31, .external_lex_state = 3},
  [7836] = {.lex_state = 31, .external_lex_state = 3},
  [7837] = {.lex_state = 7, .external_lex_state = 2},
  [7838] = {.lex_state = 174, .external_lex_state = 3},
  [7839] = {.lex_state = 7, .external_lex_state = 2},
  [7840] = {.lex_state = 174, .external_lex_state = 3},
  [7841] = {.lex_state = 31, .external_lex_state = 3},
  [7842] = {.lex_state = 31, .external_lex_state = 3},
  [7843] = {.lex_state = 213, .external_lex_state = 2},
  [7844] = {.lex_state = 209, .external_lex_state = 2},
  [7845] = {.lex_state = 7, .external_lex_state = 2},
  [7846] = {.lex_state = 7, .external_lex_state = 2},
  [7847] = {.lex_state = 31, .external_lex_state = 3},
  [7848] = {.lex_state = 7, .external_lex_state = 2},
  [7849] = {.lex_state = 31, .external_lex_state = 3},
  [7850] = {.lex_state = 7, .external_lex_state = 2},
  [7851] = {.lex_state = 174, .external_lex_state = 3},
  [7852] = {.lex_state = 7, .external_lex_state = 2},
  [7853] = {.lex_state = 209, .external_lex_state = 2},
  [7854] = {.lex_state = 174, .external_lex_state = 3},
  [7855] = {.lex_state = 174, .external_lex_state = 3},
  [7856] = {.lex_state = 174, .external_lex_state = 3},
  [7857] = {.lex_state = 174, .external_lex_state = 3},
  [7858] = {.lex_state = 15, .external_lex_state = 2},
  [7859] = {.lex_state = 7, .external_lex_state = 2},
  [7860] = {.lex_state = 165, .external_lex_state = 3},
  [7861] = {.lex_state = 7, .external_lex_state = 2},
  [7862] = {.lex_state = 213, .external_lex_state = 2},
  [7863] = {.lex_state = 15, .external_lex_state = 2},
  [7864] = {.lex_state = 7, .external_lex_state = 2},
  [7865] = {.lex_state = 174, .external_lex_state = 3},
  [7866] = {.lex_state = 7, .external_lex_state = 2},
  [7867] = {.lex_state = 174, .external_lex_state = 3},
  [7868] = {.lex_state = 174, .external_lex_state = 3},
  [7869] = {.lex_state = 174, .external_lex_state = 3},
  [7870] = {.lex_state = 174, .external_lex_state = 3},
  [7871] = {.lex_state = 7, .external_lex_state = 2},
  [7872] = {.lex_state = 31, .external_lex_state = 3},
  [7873] = {.lex_state = 213, .external_lex_state = 2},
  [7874] = {.lex_state = 7, .external_lex_state = 2},
  [7875] = {.lex_state = 7, .external_lex_state = 2},
  [7876] = {.lex_state = 174, .external_lex_state = 3},
  [7877] = {.lex_state = 31, .external_lex_state = 3},
  [7878] = {.lex_state = 7, .external_lex_state = 2},
  [7879] = {.lex_state = 209, .external_lex_state = 2},
  [7880] = {.lex_state = 31, .external_lex_state = 3},
  [7881] = {.lex_state = 7, .external_lex_state = 2},
  [7882] = {.lex_state = 31, .external_lex_state = 3},
  [7883] = {.lex_state = 174, .external_lex_state = 3},
  [7884] = {.lex_state = 213, .external_lex_state = 2},
  [7885] = {.lex_state = 12, .external_lex_state = 2},
  [7886] = {.lex_state = 12, .external_lex_state = 2},
  [7887] = {.lex_state = 31, .external_lex_state = 3},
  [7888] = {.lex_state = 12, .external_lex_state = 2},
  [7889] = {.lex_state = 174, .external_lex_state = 3},
  [7890] = {.lex_state = 12, .external_lex_state = 2},
  [7891] = {.lex_state = 174, .external_lex_state = 3},
  [7892] = {.lex_state = 213, .external_lex_state = 2},
  [7893] = {.lex_state = 174, .external_lex_state = 3},
  [7894] = {.lex_state = 174, .external_lex_state = 3},
  [7895] = {.lex_state = 174, .external_lex_state = 3},
  [7896] = {.lex_state = 174, .external_lex_state = 3},
  [7897] = {.lex_state = 7, .external_lex_state = 2},
  [7898] = {.lex_state = 31, .external_lex_state = 3},
  [7899] = {.lex_state = 174, .external_lex_state = 3},
  [7900] = {.lex_state = 31, .external_lex_state = 3},
  [7901] = {.lex_state = 213, .external_lex_state = 2},
  [7902] = {.lex_state = 31, .external_lex_state = 3},
  [7903] = {.lex_state = 31, .external_lex_state = 3},
  [7904] = {.lex_state = 209, .external_lex_state = 2},
  [7905] = {.lex_state = 31, .external_lex_state = 3},
  [7906] = {.lex_state = 174, .external_lex_state = 3},
  [7907] = {.lex_state = 209, .external_lex_state = 2},
  [7908] = {.lex_state = 31, .external_lex_state = 3},
  [7909] = {.lex_state = 213, .external_lex_state = 2},
  [7910] = {.lex_state = 7, .external_lex_state = 2},
  [7911] = {.lex_state = 7, .external_lex_state = 2},
  [7912] = {.lex_state = 174, .external_lex_state = 3},
  [7913] = {.lex_state = 7, .external_lex_state = 2},
  [7914] = {.lex_state = 213, .external_lex_state = 2},
  [7915] = {.lex_state = 31, .external_lex_state = 3},
  [7916] = {.lex_state = 7, .external_lex_state = 2},
  [7917] = {.lex_state = 174, .external_lex_state = 3},
  [7918] = {.lex_state = 174, .external_lex_state = 3},
  [7919] = {.lex_state = 7, .external_lex_state = 2},
  [7920] = {.lex_state = 15, .external_lex_state = 2},
  [7921] = {.lex_state = 213, .external_lex_state = 2},
  [7922] = {.lex_state = 174, .external_lex_state = 3},
  [7923] = {.lex_state = 166, .external_lex_state = 3},
  [7924] = {.lex_state = 174, .external_lex_state = 3},
  [7925] = {.lex_state = 174, .external_lex_state = 3},
  [7926] = {.lex_state = 174, .external_lex_state = 3},
  [7927] = {.lex_state = 174, .external_lex_state = 3},
  [7928] = {.lex_state = 15, .external_lex_state = 2},
  [7929] = {.lex_state = 15, .external_lex_state = 2},
  [7930] = {.lex_state = 213, .external_lex_state = 2},
  [7931] = {.lex_state = 31, .external_lex_state = 3},
  [7932] = {.lex_state = 7, .external_lex_state = 2},
  [7933] = {.lex_state = 7, .external_lex_state = 2},
  [7934] = {.lex_state = 213, .external_lex_state = 2},
  [7935] = {.lex_state = 7, .external_lex_state = 2},
  [7936] = {.lex_state = 7, .external_lex_state = 2},
  [7937] = {.lex_state = 15, .external_lex_state = 2},
  [7938] = {.lex_state = 174, .external_lex_state = 3},
  [7939] = {.lex_state = 7, .external_lex_state = 2},
  [7940] = {.lex_state = 31, .external_lex_state = 3},
  [7941] = {.lex_state = 174, .external_lex_state = 3},
  [7942] = {.lex_state = 7, .external_lex_state = 2},
  [7943] = {.lex_state = 174, .external_lex_state = 3},
  [7944] = {.lex_state = 31, .external_lex_state = 3},
  [7945] = {.lex_state = 7, .external_lex_state = 2},
  [7946] = {.lex_state = 31, .external_lex_state = 3},
  [7947] = {.lex_state = 15, .external_lex_state = 2},
  [7948] = {.lex_state = 15, .external_lex_state = 2},
  [7949] = {.lex_state = 31, .external_lex_state = 3},
  [7950] = {.lex_state = 7, .external_lex_state = 2},
  [7951] = {.lex_state = 15, .external_lex_state = 2},
  [7952] = {.lex_state = 15, .external_lex_state = 2},
  [7953] = {.lex_state = 31, .external_lex_state = 3},
  [7954] = {.lex_state = 31, .external_lex_state = 3},
  [7955] = {.lex_state = 15, .external_lex_state = 2},
  [7956] = {.lex_state = 7, .external_lex_state = 2},
  [7957] = {.lex_state = 15, .external_lex_state = 2},
  [7958] = {.lex_state = 15, .external_lex_state = 2},
  [7959] = {.lex_state = 7, .external_lex_state = 2},
  [7960] = {.lex_state = 7, .external_lex_state = 2},
  [7961] = {.lex_state = 174, .external_lex_state = 3},
  [7962] = {.lex_state = 7, .external_lex_state = 2},
  [7963] = {.lex_state = 7, .external_lex_state = 2},
  [7964] = {.lex_state = 31, .external_lex_state = 3},
  [7965] = {.lex_state = 15, .external_lex_state = 2},
  [7966] = {.lex_state = 31, .external_lex_state = 3},
  [7967] = {.lex_state = 31, .external_lex_state = 3},
  [7968] = {.lex_state = 7, .external_lex_state = 2},
  [7969] = {.lex_state = 174, .external_lex_state = 3},
  [7970] = {.lex_state = 31, .external_lex_state = 3},
  [7971] = {.lex_state = 213, .external_lex_state = 2},
  [7972] = {.lex_state = 209, .external_lex_state = 2},
  [7973] = {.lex_state = 213, .external_lex_state = 2},
  [7974] = {.lex_state = 174, .external_lex_state = 3},
  [7975] = {.lex_state = 7, .external_lex_state = 2},
  [7976] = {.lex_state = 15, .external_lex_state = 2},
  [7977] = {.lex_state = 31, .external_lex_state = 3},
  [7978] = {.lex_state = 7, .external_lex_state = 2},
  [7979] = {.lex_state = 31, .external_lex_state = 3},
  [7980] = {.lex_state = 31, .external_lex_state = 3},
  [7981] = {.lex_state = 31, .external_lex_state = 3},
  [7982] = {.lex_state = 31, .external_lex_state = 3},
  [7983] = {.lex_state = 15, .external_lex_state = 2},
  [7984] = {.lex_state = 31, .external_lex_state = 3},
  [7985] = {.lex_state = 31, .external_lex_state = 3},
  [7986] = {.lex_state = 31, .external_lex_state = 3},
  [7987] = {.lex_state = 15, .external_lex_state = 2},
  [7988] = {.lex_state = 15, .external_lex_state = 2},
  [7989] = {.lex_state = 31, .external_lex_state = 3},
  [7990] = {.lex_state = 31, .external_lex_state = 3},
  [7991] = {.lex_state = 31, .external_lex_state = 3},
  [7992] = {.lex_state = 31, .external_lex_state = 3},
  [7993] = {.lex_state = 31, .external_lex_state = 3},
  [7994] = {.lex_state = 31, .external_lex_state = 3},
  [7995] = {.lex_state = 15, .external_lex_state = 2},
  [7996] = {.lex_state = 7, .external_lex_state = 2},
  [7997] = {.lex_state = 7, .external_lex_state = 2},
  [7998] = {.lex_state = 31, .external_lex_state = 3},
  [7999] = {.lex_state = 31, .external_lex_state = 3},
  [8000] = {.lex_state = 7, .external_lex_state = 2},
  [8001] = {.lex_state = 174, .external_lex_state = 3},
  [8002] = {.lex_state = 31, .external_lex_state = 3},
  [8003] = {.lex_state = 213, .external_lex_state = 2},
  [8004] = {.lex_state = 213, .external_lex_state = 2},
  [8005] = {.lex_state = 31, .external_lex_state = 3},
  [8006] = {.lex_state = 31, .external_lex_state = 3},
  [8007] = {.lex_state = 174, .external_lex_state = 3},
  [8008] = {.lex_state = 174, .external_lex_state = 3},
  [8009] = {.lex_state = 31, .external_lex_state = 3},
  [8010] = {.lex_state = 174, .external_lex_state = 3},
  [8011] = {.lex_state = 213, .external_lex_state = 2},
  [8012] = {.lex_state = 31, .external_lex_state = 3},
  [8013] = {.lex_state = 31, .external_lex_state = 3},
  [8014] = {.lex_state = 174, .external_lex_state = 3},
  [8015] = {.lex_state = 31, .external_lex_state = 3},
  [8016] = {.lex_state = 31, .external_lex_state = 3},
  [8017] = {.lex_state = 15, .external_lex_state = 2},
  [8018] = {.lex_state = 31, .external_lex_state = 3},
  [8019] = {.lex_state = 31, .external_lex_state = 3},
  [8020] = {.lex_state = 213, .external_lex_state = 2},
  [8021] = {.lex_state = 7, .external_lex_state = 2},
  [8022] = {.lex_state = 31, .external_lex_state = 3},
  [8023] = {.lex_state = 15, .external_lex_state = 2},
  [8024] = {.lex_state = 31, .external_lex_state = 3},
  [8025] = {.lex_state = 31, .external_lex_state = 3},
  [8026] = {.lex_state = 31, .external_lex_state = 3},
  [8027] = {.lex_state = 7, .external_lex_state = 2},
  [8028] = {.lex_state = 7, .external_lex_state = 2},
  [8029] = {.lex_state = 31, .external_lex_state = 3},
  [8030] = {.lex_state = 31, .external_lex_state = 3},
  [8031] = {.lex_state = 7, .external_lex_state = 2},
  [8032] = {.lex_state = 174, .external_lex_state = 3},
  [8033] = {.lex_state = 174, .external_lex_state = 3},
  [8034] = {.lex_state = 213, .external_lex_state = 2},
  [8035] = {.lex_state = 31, .external_lex_state = 3},
  [8036] = {.lex_state = 213, .external_lex_state = 2},
  [8037] = {.lex_state = 174, .external_lex_state = 3},
  [8038] = {.lex_state = 7, .external_lex_state = 2},
  [8039] = {.lex_state = 174, .external_lex_state = 3},
  [8040] = {.lex_state = 174, .external_lex_state = 3},
  [8041] = {.lex_state = 174, .external_lex_state = 3},
  [8042] = {.lex_state = 31, .external_lex_state = 3},
  [8043] = {.lex_state = 31, .external_lex_state = 3},
  [8044] = {.lex_state = 31, .external_lex_state = 3},
  [8045] = {.lex_state = 15, .external_lex_state = 2},
  [8046] = {.lex_state = 31, .external_lex_state = 3},
  [8047] = {.lex_state = 7, .external_lex_state = 2},
  [8048] = {.lex_state = 174, .external_lex_state = 3},
  [8049] = {.lex_state = 7, .external_lex_state = 2},
  [8050] = {.lex_state = 31, .external_lex_state = 3},
  [8051] = {.lex_state = 47, .external_lex_state = 3},
  [8052] = {.lex_state = 174, .external_lex_state = 3},
  [8053] = {.lex_state = 174, .external_lex_state = 3},
  [8054] = {.lex_state = 7, .external_lex_state = 2},
  [8055] = {.lex_state = 7, .external_lex_state = 2},
  [8056] = {.lex_state = 47, .external_lex_state = 3},
  [8057] = {.lex_state = 7, .external_lex_state = 2},
  [8058] = {.lex_state = 31, .external_lex_state = 3},
  [8059] = {.lex_state = 174, .external_lex_state = 3},
  [8060] = {.lex_state = 31, .external_lex_state = 3},
  [8061] = {.lex_state = 174, .external_lex_state = 3},
  [8062] = {.lex_state = 174, .external_lex_state = 3},
  [8063] = {.lex_state = 174, .external_lex_state = 3},
  [8064] = {.lex_state = 31, .external_lex_state = 3},
  [8065] = {.lex_state = 31, .external_lex_state = 3},
  [8066] = {.lex_state = 31, .external_lex_state = 3},
  [8067] = {.lex_state = 7, .external_lex_state = 2},
  [8068] = {.lex_state = 7, .external_lex_state = 2},
  [8069] = {.lex_state = 174, .external_lex_state = 3},
  [8070] = {.lex_state = 31, .external_lex_state = 3},
  [8071] = {.lex_state = 31, .external_lex_state = 3},
  [8072] = {.lex_state = 213, .external_lex_state = 2},
  [8073] = {.lex_state = 174, .external_lex_state = 3},
  [8074] = {.lex_state = 31, .external_lex_state = 3},
  [8075] = {.lex_state = 47, .external_lex_state = 3},
  [8076] = {.lex_state = 31, .external_lex_state = 3},
  [8077] = {.lex_state = 174, .external_lex_state = 3},
  [8078] = {.lex_state = 7, .external_lex_state = 2},
  [8079] = {.lex_state = 31, .external_lex_state = 3},
  [8080] = {.lex_state = 31, .external_lex_state = 3},
  [8081] = {.lex_state = 7, .external_lex_state = 2},
  [8082] = {.lex_state = 7, .external_lex_state = 2},
  [8083] = {.lex_state = 7, .external_lex_state = 2},
  [8084] = {.lex_state = 31, .external_lex_state = 3},
  [8085] = {.lex_state = 7, .external_lex_state = 2},
  [8086] = {.lex_state = 7, .external_lex_state = 2},
  [8087] = {.lex_state = 7, .external_lex_state = 2},
  [8088] = {.lex_state = 31, .external_lex_state = 3},
  [8089] = {.lex_state = 174, .external_lex_state = 3},
  [8090] = {.lex_state = 31, .external_lex_state = 3},
  [8091] = {.lex_state = 7, .external_lex_state = 2},
  [8092] = {.lex_state = 426, .external_lex_state = 2},
  [8093] = {.lex_state = 174, .external_lex_state = 3},
  [8094] = {.lex_state = 174, .external_lex_state = 3},
  [8095] = {.lex_state = 7, .external_lex_state = 2},
  [8096] = {.lex_state = 7, .external_lex_state = 2},
  [8097] = {.lex_state = 7, .external_lex_state = 2},
  [8098] = {.lex_state = 7, .external_lex_state = 2},
  [8099] = {.lex_state = 7, .external_lex_state = 2},
  [8100] = {.lex_state = 174, .external_lex_state = 3},
  [8101] = {.lex_state = 7, .external_lex_state = 2},
  [8102] = {.lex_state = 7, .external_lex_state = 2},
  [8103] = {.lex_state = 427, .external_lex_state = 2},
  [8104] = {.lex_state = 14, .external_lex_state = 2},
  [8105] = {.lex_state = 7, .external_lex_state = 2},
  [8106] = {.lex_state = 10, .external_lex_state = 2},
  [8107] = {.lex_state = 7, .external_lex_state = 2},
  [8108] = {.lex_state = 7, .external_lex_state = 2},
  [8109] = {.lex_state = 29, .external_lex_state = 3},
  [8110] = {.lex_state = 14, .external_lex_state = 2},
  [8111] = {.lex_state = 7, .external_lex_state = 2},
  [8112] = {.lex_state = 10, .external_lex_state = 2},
  [8113] = {.lex_state = 7, .external_lex_state = 2},
  [8114] = {.lex_state = 7, .external_lex_state = 2},
  [8115] = {.lex_state = 7, .external_lex_state = 2},
  [8116] = {.lex_state = 10, .external_lex_state = 2},
  [8117] = {.lex_state = 14, .external_lex_state = 2},
  [8118] = {.lex_state = 7, .external_lex_state = 2},
  [8119] = {.lex_state = 7, .external_lex_state = 2},
  [8120] = {.lex_state = 10, .external_lex_state = 2},
  [8121] = {.lex_state = 10, .external_lex_state = 2},
  [8122] = {.lex_state = 47, .external_lex_state = 3},
  [8123] = {.lex_state = 10, .external_lex_state = 2},
  [8124] = {.lex_state = 10, .external_lex_state = 2},
  [8125] = {.lex_state = 29, .external_lex_state = 3},
  [8126] = {.lex_state = 10, .external_lex_state = 2},
  [8127] = {.lex_state = 10, .external_lex_state = 2},
  [8128] = {.lex_state = 7, .external_lex_state = 2},
  [8129] = {.lex_state = 10, .external_lex_state = 2},
  [8130] = {.lex_state = 10, .external_lex_state = 2},
  [8131] = {.lex_state = 10, .external_lex_state = 2},
  [8132] = {.lex_state = 10, .external_lex_state = 2},
  [8133] = {.lex_state = 10, .external_lex_state = 2},
  [8134] = {.lex_state = 10, .external_lex_state = 2},
  [8135] = {.lex_state = 29, .external_lex_state = 3},
  [8136] = {.lex_state = 10, .external_lex_state = 2},
  [8137] = {.lex_state = 10, .external_lex_state = 2},
  [8138] = {.lex_state = 10, .external_lex_state = 2},
  [8139] = {.lex_state = 7, .external_lex_state = 2},
  [8140] = {.lex_state = 10, .external_lex_state = 2},
  [8141] = {.lex_state = 7, .external_lex_state = 2},
  [8142] = {.lex_state = 7, .external_lex_state = 2},
  [8143] = {.lex_state = 14, .external_lex_state = 2},
  [8144] = {.lex_state = 10, .external_lex_state = 2},
  [8145] = {.lex_state = 10, .external_lex_state = 2},
  [8146] = {.lex_state = 10, .external_lex_state = 2},
  [8147] = {.lex_state = 7, .external_lex_state = 2},
  [8148] = {.lex_state = 426, .external_lex_state = 2},
  [8149] = {.lex_state = 7, .external_lex_state = 2},
  [8150] = {.lex_state = 7, .external_lex_state = 2},
  [8151] = {.lex_state = 7, .external_lex_state = 2},
  [8152] = {.lex_state = 7, .external_lex_state = 2},
  [8153] = {.lex_state = 7, .external_lex_state = 2},
  [8154] = {.lex_state = 7, .external_lex_state = 2},
  [8155] = {.lex_state = 10, .external_lex_state = 2},
  [8156] = {.lex_state = 29, .external_lex_state = 3},
  [8157] = {.lex_state = 14, .external_lex_state = 2},
  [8158] = {.lex_state = 7, .external_lex_state = 2},
  [8159] = {.lex_state = 10, .external_lex_state = 2},
  [8160] = {.lex_state = 7, .external_lex_state = 2},
  [8161] = {.lex_state = 29, .external_lex_state = 3},
  [8162] = {.lex_state = 14, .external_lex_state = 2},
  [8163] = {.lex_state = 10, .external_lex_state = 2},
  [8164] = {.lex_state = 10, .external_lex_state = 2},
  [8165] = {.lex_state = 36, .external_lex_state = 3},
  [8166] = {.lex_state = 7, .external_lex_state = 2},
  [8167] = {.lex_state = 10, .external_lex_state = 2},
  [8168] = {.lex_state = 7, .external_lex_state = 2},
  [8169] = {.lex_state = 7, .external_lex_state = 2},
  [8170] = {.lex_state = 10, .external_lex_state = 2},
  [8171] = {.lex_state = 10, .external_lex_state = 2},
  [8172] = {.lex_state = 10, .external_lex_state = 2},
  [8173] = {.lex_state = 7, .external_lex_state = 2},
  [8174] = {.lex_state = 7, .external_lex_state = 2},
  [8175] = {.lex_state = 7, .external_lex_state = 2},
  [8176] = {.lex_state = 10, .external_lex_state = 2},
  [8177] = {.lex_state = 14, .external_lex_state = 2},
  [8178] = {.lex_state = 10, .external_lex_state = 2},
  [8179] = {.lex_state = 7, .external_lex_state = 2},
  [8180] = {.lex_state = 10, .external_lex_state = 2},
  [8181] = {.lex_state = 7, .external_lex_state = 2},
  [8182] = {.lex_state = 7, .external_lex_state = 2},
  [8183] = {.lex_state = 7, .external_lex_state = 2},
  [8184] = {.lex_state = 10, .external_lex_state = 2},
  [8185] = {.lex_state = 10, .external_lex_state = 2},
  [8186] = {.lex_state = 10, .external_lex_state = 2},
  [8187] = {.lex_state = 10, .external_lex_state = 2},
  [8188] = {.lex_state = 10, .external_lex_state = 2},
  [8189] = {.lex_state = 7, .external_lex_state = 2},
  [8190] = {.lex_state = 427, .external_lex_state = 2},
  [8191] = {.lex_state = 7, .external_lex_state = 2},
  [8192] = {.lex_state = 7, .external_lex_state = 2},
  [8193] = {.lex_state = 7, .external_lex_state = 2},
  [8194] = {.lex_state = 427, .external_lex_state = 2},
  [8195] = {.lex_state = 10, .external_lex_state = 2},
  [8196] = {.lex_state = 7, .external_lex_state = 2},
  [8197] = {.lex_state = 7, .external_lex_state = 2},
  [8198] = {.lex_state = 7, .external_lex_state = 2},
  [8199] = {.lex_state = 29, .external_lex_state = 3},
  [8200] = {.lex_state = 10, .external_lex_state = 2},
  [8201] = {.lex_state = 7, .external_lex_state = 2},
  [8202] = {.lex_state = 10, .external_lex_state = 2},
  [8203] = {.lex_state = 10, .external_lex_state = 2},
  [8204] = {.lex_state = 7, .external_lex_state = 2},
  [8205] = {.lex_state = 7, .external_lex_state = 2},
  [8206] = {.lex_state = 7, .external_lex_state = 2},
  [8207] = {.lex_state = 14, .external_lex_state = 2},
  [8208] = {.lex_state = 7, .external_lex_state = 2},
  [8209] = {.lex_state = 7, .external_lex_state = 2},
  [8210] = {.lex_state = 10, .external_lex_state = 2},
  [8211] = {.lex_state = 14, .external_lex_state = 2},
  [8212] = {.lex_state = 10, .external_lex_state = 2},
  [8213] = {.lex_state = 14, .external_lex_state = 2},
  [8214] = {.lex_state = 7, .external_lex_state = 2},
  [8215] = {.lex_state = 10, .external_lex_state = 2},
  [8216] = {.lex_state = 10, .external_lex_state = 2},
  [8217] = {.lex_state = 14, .external_lex_state = 2},
  [8218] = {.lex_state = 14, .external_lex_state = 2},
  [8219] = {.lex_state = 14, .external_lex_state = 2},
  [8220] = {.lex_state = 14, .external_lex_state = 2},
  [8221] = {.lex_state = 14, .external_lex_state = 2},
  [8222] = {.lex_state = 7, .external_lex_state = 2},
  [8223] = {.lex_state = 7, .external_lex_state = 2},
  [8224] = {.lex_state = 7, .external_lex_state = 2},
  [8225] = {.lex_state = 10, .external_lex_state = 2},
  [8226] = {.lex_state = 10, .external_lex_state = 2},
  [8227] = {.lex_state = 10, .external_lex_state = 2},
  [8228] = {.lex_state = 14, .external_lex_state = 2},
  [8229] = {.lex_state = 7, .external_lex_state = 2},
  [8230] = {.lex_state = 10, .external_lex_state = 2},
  [8231] = {.lex_state = 7, .external_lex_state = 2},
  [8232] = {.lex_state = 7, .external_lex_state = 2},
  [8233] = {.lex_state = 7, .external_lex_state = 2},
  [8234] = {.lex_state = 7, .external_lex_state = 2},
  [8235] = {.lex_state = 7, .external_lex_state = 2},
  [8236] = {.lex_state = 7, .external_lex_state = 2},
  [8237] = {.lex_state = 10, .external_lex_state = 2},
  [8238] = {.lex_state = 10, .external_lex_state = 2},
  [8239] = {.lex_state = 10, .external_lex_state = 2},
  [8240] = {.lex_state = 7, .external_lex_state = 2},
  [8241] = {.lex_state = 10, .external_lex_state = 2},
  [8242] = {.lex_state = 10, .external_lex_state = 2},
  [8243] = {.lex_state = 10, .external_lex_state = 2},
  [8244] = {.lex_state = 10, .external_lex_state = 2},
  [8245] = {.lex_state = 10, .external_lex_state = 2},
  [8246] = {.lex_state = 10, .external_lex_state = 2},
  [8247] = {.lex_state = 10, .external_lex_state = 2},
  [8248] = {.lex_state = 10, .external_lex_state = 2},
  [8249] = {.lex_state = 7, .external_lex_state = 2},
  [8250] = {.lex_state = 7, .external_lex_state = 2},
  [8251] = {.lex_state = 7, .external_lex_state = 2},
  [8252] = {.lex_state = 14, .external_lex_state = 2},
  [8253] = {.lex_state = 7, .external_lex_state = 2},
  [8254] = {.lex_state = 10, .external_lex_state = 2},
  [8255] = {.lex_state = 10, .external_lex_state = 2},
  [8256] = {.lex_state = 10, .external_lex_state = 2},
  [8257] = {.lex_state = 14, .external_lex_state = 2},
  [8258] = {.lex_state = 10, .external_lex_state = 2},
  [8259] = {.lex_state = 14, .external_lex_state = 2},
  [8260] = {.lex_state = 7, .external_lex_state = 2},
  [8261] = {.lex_state = 10, .external_lex_state = 2},
  [8262] = {.lex_state = 14, .external_lex_state = 2},
  [8263] = {.lex_state = 14, .external_lex_state = 2},
  [8264] = {.lex_state = 10, .external_lex_state = 2},
  [8265] = {.lex_state = 7, .external_lex_state = 2},
  [8266] = {.lex_state = 14, .external_lex_state = 2},
  [8267] = {.lex_state = 7, .external_lex_state = 2},
  [8268] = {.lex_state = 7, .external_lex_state = 2},
  [8269] = {.lex_state = 14, .external_lex_state = 2},
  [8270] = {.lex_state = 10, .external_lex_state = 2},
  [8271] = {.lex_state = 14, .external_lex_state = 2},
  [8272] = {.lex_state = 10, .external_lex_state = 2},
  [8273] = {.lex_state = 10, .external_lex_state = 2},
  [8274] = {.lex_state = 10, .external_lex_state = 2},
  [8275] = {.lex_state = 10, .external_lex_state = 2},
  [8276] = {.lex_state = 10, .external_lex_state = 2},
  [8277] = {.lex_state = 14, .external_lex_state = 2},
  [8278] = {.lex_state = 14, .external_lex_state = 2},
  [8279] = {.lex_state = 7, .external_lex_state = 2},
  [8280] = {.lex_state = 10, .external_lex_state = 2},
  [8281] = {.lex_state = 14, .external_lex_state = 2},
  [8282] = {.lex_state = 14, .external_lex_state = 2},
  [8283] = {.lex_state = 14, .external_lex_state = 2},
  [8284] = {.lex_state = 7, .external_lex_state = 2},
  [8285] = {.lex_state = 10, .external_lex_state = 2},
  [8286] = {.lex_state = 10, .external_lex_state = 2},
  [8287] = {.lex_state = 36, .external_lex_state = 3},
  [8288] = {.lex_state = 10, .external_lex_state = 2},
  [8289] = {.lex_state = 10, .external_lex_state = 2},
  [8290] = {.lex_state = 10, .external_lex_state = 2},
  [8291] = {.lex_state = 36, .external_lex_state = 3},
  [8292] = {.lex_state = 420, .external_lex_state = 2},
  [8293] = {.lex_state = 420, .external_lex_state = 2},
  [8294] = {.lex_state = 420, .external_lex_state = 2},
  [8295] = {.lex_state = 420, .external_lex_state = 2},
  [8296] = {.lex_state = 10, .external_lex_state = 2},
  [8297] = {.lex_state = 10, .external_lex_state = 2},
  [8298] = {.lex_state = 420, .external_lex_state = 2},
  [8299] = {.lex_state = 10, .external_lex_state = 2},
  [8300] = {.lex_state = 10, .external_lex_state = 2},
  [8301] = {.lex_state = 10, .external_lex_state = 2},
  [8302] = {.lex_state = 10, .external_lex_state = 2},
  [8303] = {.lex_state = 420, .external_lex_state = 2},
  [8304] = {.lex_state = 10, .external_lex_state = 2},
  [8305] = {.lex_state = 10, .external_lex_state = 2},
  [8306] = {.lex_state = 10, .external_lex_state = 2},
  [8307] = {.lex_state = 10, .external_lex_state = 2},
  [8308] = {.lex_state = 10, .external_lex_state = 2},
  [8309] = {.lex_state = 10, .external_lex_state = 2},
  [8310] = {.lex_state = 10, .external_lex_state = 2},
  [8311] = {.lex_state = 31, .external_lex_state = 3},
  [8312] = {.lex_state = 420, .external_lex_state = 2},
  [8313] = {.lex_state = 420, .external_lex_state = 2},
  [8314] = {.lex_state = 420, .external_lex_state = 2},
  [8315] = {.lex_state = 420, .external_lex_state = 2},
  [8316] = {.lex_state = 208, .external_lex_state = 2},
  [8317] = {.lex_state = 420, .external_lex_state = 2},
  [8318] = {.lex_state = 420, .external_lex_state = 2},
  [8319] = {.lex_state = 420, .external_lex_state = 2},
  [8320] = {.lex_state = 420, .external_lex_state = 2},
  [8321] = {.lex_state = 420, .external_lex_state = 2},
  [8322] = {.lex_state = 420, .external_lex_state = 2},
  [8323] = {.lex_state = 420, .external_lex_state = 2},
  [8324] = {.lex_state = 420, .external_lex_state = 2},
  [8325] = {.lex_state = 420, .external_lex_state = 2},
  [8326] = {.lex_state = 420, .external_lex_state = 2},
  [8327] = {.lex_state = 420, .external_lex_state = 2},
  [8328] = {.lex_state = 420, .external_lex_state = 2},
  [8329] = {.lex_state = 420, .external_lex_state = 2},
  [8330] = {.lex_state = 420, .external_lex_state = 2},
  [8331] = {.lex_state = 420, .external_lex_state = 2},
  [8332] = {.lex_state = 208, .external_lex_state = 2},
  [8333] = {.lex_state = 420, .external_lex_state = 2},
  [8334] = {.lex_state = 420, .external_lex_state = 2},
  [8335] = {.lex_state = 420, .external_lex_state = 2},
  [8336] = {.lex_state = 420, .external_lex_state = 2},
  [8337] = {.lex_state = 420, .external_lex_state = 2},
  [8338] = {.lex_state = 420, .external_lex_state = 2},
  [8339] = {.lex_state = 420, .external_lex_state = 2},
  [8340] = {.lex_state = 420, .external_lex_state = 2},
  [8341] = {.lex_state = 10, .external_lex_state = 2},
  [8342] = {.lex_state = 420, .external_lex_state = 2},
  [8343] = {.lex_state = 10, .external_lex_state = 2},
  [8344] = {.lex_state = 10, .external_lex_state = 2},
  [8345] = {.lex_state = 10, .external_lex_state = 2},
  [8346] = {.lex_state = 420, .external_lex_state = 2},
  [8347] = {.lex_state = 10, .external_lex_state = 2},
  [8348] = {.lex_state = 36, .external_lex_state = 3},
  [8349] = {.lex_state = 420, .external_lex_state = 2},
  [8350] = {.lex_state = 10, .external_lex_state = 2},
  [8351] = {.lex_state = 10, .external_lex_state = 2},
  [8352] = {.lex_state = 420, .external_lex_state = 2},
  [8353] = {.lex_state = 420, .external_lex_state = 2},
  [8354] = {.lex_state = 208, .external_lex_state = 2},
  [8355] = {.lex_state = 420, .external_lex_state = 2},
  [8356] = {.lex_state = 10, .external_lex_state = 2},
  [8357] = {.lex_state = 420, .external_lex_state = 2},
  [8358] = {.lex_state = 420, .external_lex_state = 2},
  [8359] = {.lex_state = 10, .external_lex_state = 2},
  [8360] = {.lex_state = 10, .external_lex_state = 2},
  [8361] = {.lex_state = 10, .external_lex_state = 2},
  [8362] = {.lex_state = 420, .external_lex_state = 2},
  [8363] = {.lex_state = 10, .external_lex_state = 2},
  [8364] = {.lex_state = 10, .external_lex_state = 2},
  [8365] = {.lex_state = 420, .external_lex_state = 2},
  [8366] = {.lex_state = 10, .external_lex_state = 2},
  [8367] = {.lex_state = 420, .external_lex_state = 2},
  [8368] = {.lex_state = 420, .external_lex_state = 2},
  [8369] = {.lex_state = 420, .external_lex_state = 2},
  [8370] = {.lex_state = 10, .external_lex_state = 2},
  [8371] = {.lex_state = 10, .external_lex_state = 2},
  [8372] = {.lex_state = 10, .external_lex_state = 2},
  [8373] = {.lex_state = 10, .external_lex_state = 2},
  [8374] = {.lex_state = 420, .external_lex_state = 2},
  [8375] = {.lex_state = 10, .external_lex_state = 2},
  [8376] = {.lex_state = 420, .external_lex_state = 2},
  [8377] = {.lex_state = 208, .external_lex_state = 2},
  [8378] = {.lex_state = 10, .external_lex_state = 2},
  [8379] = {.lex_state = 420, .external_lex_state = 2},
  [8380] = {.lex_state = 420, .external_lex_state = 2},
  [8381] = {.lex_state = 420, .external_lex_state = 2},
  [8382] = {.lex_state = 420, .external_lex_state = 2},
  [8383] = {.lex_state = 10, .external_lex_state = 2},
  [8384] = {.lex_state = 31, .external_lex_state = 3},
  [8385] = {.lex_state = 420, .external_lex_state = 2},
  [8386] = {.lex_state = 420, .external_lex_state = 2},
  [8387] = {.lex_state = 420, .external_lex_state = 2},
  [8388] = {.lex_state = 420, .external_lex_state = 2},
  [8389] = {.lex_state = 420, .external_lex_state = 2},
  [8390] = {.lex_state = 31, .external_lex_state = 3},
  [8391] = {.lex_state = 420, .external_lex_state = 2},
  [8392] = {.lex_state = 420, .external_lex_state = 2},
  [8393] = {.lex_state = 420, .external_lex_state = 2},
  [8394] = {.lex_state = 420, .external_lex_state = 2},
  [8395] = {.lex_state = 420, .external_lex_state = 2},
  [8396] = {.lex_state = 420, .external_lex_state = 2},
  [8397] = {.lex_state = 420, .external_lex_state = 2},
  [8398] = {.lex_state = 420, .external_lex_state = 2},
  [8399] = {.lex_state = 420, .external_lex_state = 2},
  [8400] = {.lex_state = 420, .external_lex_state = 2},
  [8401] = {.lex_state = 420, .external_lex_state = 2},
  [8402] = {.lex_state = 420, .external_lex_state = 2},
  [8403] = {.lex_state = 420, .external_lex_state = 2},
  [8404] = {.lex_state = 420, .external_lex_state = 2},
  [8405] = {.lex_state = 420, .external_lex_state = 2},
  [8406] = {.lex_state = 167, .external_lex_state = 3},
  [8407] = {.lex_state = 31, .external_lex_state = 3},
  [8408] = {.lex_state = 420, .external_lex_state = 2},
  [8409] = {.lex_state = 420, .external_lex_state = 2},
  [8410] = {.lex_state = 10, .external_lex_state = 2},
  [8411] = {.lex_state = 31, .external_lex_state = 3},
  [8412] = {.lex_state = 31, .external_lex_state = 3},
  [8413] = {.lex_state = 420, .external_lex_state = 2},
  [8414] = {.lex_state = 31, .external_lex_state = 3},
  [8415] = {.lex_state = 420, .external_lex_state = 2},
  [8416] = {.lex_state = 420, .external_lex_state = 2},
  [8417] = {.lex_state = 31, .external_lex_state = 3},
  [8418] = {.lex_state = 420, .external_lex_state = 2},
  [8419] = {.lex_state = 171, .external_lex_state = 3},
  [8420] = {.lex_state = 171, .external_lex_state = 3},
  [8421] = {.lex_state = 420, .external_lex_state = 2},
  [8422] = {.lex_state = 420, .external_lex_state = 2},
  [8423] = {.lex_state = 420, .external_lex_state = 2},
  [8424] = {.lex_state = 420, .external_lex_state = 2},
  [8425] = {.lex_state = 420, .external_lex_state = 2},
  [8426] = {.lex_state = 420, .external_lex_state = 2},
  [8427] = {.lex_state = 420, .external_lex_state = 2},
  [8428] = {.lex_state = 420, .external_lex_state = 2},
  [8429] = {.lex_state = 420, .external_lex_state = 2},
  [8430] = {.lex_state = 420, .external_lex_state = 2},
  [8431] = {.lex_state = 420, .external_lex_state = 2},
  [8432] = {.lex_state = 420, .external_lex_state = 2},
  [8433] = {.lex_state = 420, .external_lex_state = 2},
  [8434] = {.lex_state = 420, .external_lex_state = 2},
  [8435] = {.lex_state = 420, .external_lex_state = 2},
  [8436] = {.lex_state = 420, .external_lex_state = 2},
  [8437] = {.lex_state = 420, .external_lex_state = 2},
  [8438] = {.lex_state = 420, .external_lex_state = 2},
  [8439] = {.lex_state = 167, .external_lex_state = 3},
  [8440] = {.lex_state = 171, .external_lex_state = 3},
  [8441] = {.lex_state = 208, .external_lex_state = 2},
  [8442] = {.lex_state = 167, .external_lex_state = 3},
  [8443] = {.lex_state = 208, .external_lex_state = 2},
  [8444] = {.lex_state = 171, .external_lex_state = 3},
  [8445] = {.lex_state = 167, .external_lex_state = 3},
  [8446] = {.lex_state = 208, .external_lex_state = 2},
  [8447] = {.lex_state = 7, .external_lex_state = 2},
  [8448] = {.lex_state = 170, .external_lex_state = 3},
  [8449] = {.lex_state = 171, .external_lex_state = 3},
  [8450] = {.lex_state = 208, .external_lex_state = 2},
  [8451] = {.lex_state = 208, .external_lex_state = 2},
  [8452] = {.lex_state = 420, .external_lex_state = 2},
  [8453] = {.lex_state = 7, .external_lex_state = 2},
  [8454] = {.lex_state = 7, .external_lex_state = 2},
  [8455] = {.lex_state = 167, .external_lex_state = 3},
  [8456] = {.lex_state = 7, .external_lex_state = 2},
  [8457] = {.lex_state = 208, .external_lex_state = 2},
  [8458] = {.lex_state = 7, .external_lex_state = 2},
  [8459] = {.lex_state = 208, .external_lex_state = 2},
  [8460] = {.lex_state = 208, .external_lex_state = 2},
  [8461] = {.lex_state = 420, .external_lex_state = 2},
  [8462] = {.lex_state = 420, .external_lex_state = 2},
  [8463] = {.lex_state = 208, .external_lex_state = 2},
  [8464] = {.lex_state = 7, .external_lex_state = 2},
  [8465] = {.lex_state = 420, .external_lex_state = 2},
  [8466] = {.lex_state = 208, .external_lex_state = 2},
  [8467] = {.lex_state = 208, .external_lex_state = 2},
  [8468] = {.lex_state = 420, .external_lex_state = 2},
  [8469] = {.lex_state = 208, .external_lex_state = 2},
  [8470] = {.lex_state = 208, .external_lex_state = 2},
  [8471] = {.lex_state = 7, .external_lex_state = 2},
  [8472] = {.lex_state = 420, .external_lex_state = 2},
  [8473] = {.lex_state = 420, .external_lex_state = 2},
  [8474] = {.lex_state = 420, .external_lex_state = 2},
  [8475] = {.lex_state = 170, .external_lex_state = 3},
  [8476] = {.lex_state = 420, .external_lex_state = 2},
  [8477] = {.lex_state = 420, .external_lex_state = 2},
  [8478] = {.lex_state = 420, .external_lex_state = 2},
  [8479] = {.lex_state = 208, .external_lex_state = 2},
  [8480] = {.lex_state = 208, .external_lex_state = 2},
  [8481] = {.lex_state = 420, .external_lex_state = 2},
  [8482] = {.lex_state = 420, .external_lex_state = 2},
  [8483] = {.lex_state = 420, .external_lex_state = 2},
  [8484] = {.lex_state = 208, .external_lex_state = 2},
  [8485] = {.lex_state = 420, .external_lex_state = 2},
  [8486] = {.lex_state = 208, .external_lex_state = 2},
  [8487] = {.lex_state = 208, .external_lex_state = 2},
  [8488] = {.lex_state = 420, .external_lex_state = 2},
  [8489] = {.lex_state = 420, .external_lex_state = 2},
  [8490] = {.lex_state = 208, .external_lex_state = 2},
  [8491] = {.lex_state = 208, .external_lex_state = 2},
  [8492] = {.lex_state = 208, .external_lex_state = 2},
  [8493] = {.lex_state = 208, .external_lex_state = 2},
  [8494] = {.lex_state = 7, .external_lex_state = 2},
  [8495] = {.lex_state = 208, .external_lex_state = 2},
  [8496] = {.lex_state = 208, .external_lex_state = 2},
  [8497] = {.lex_state = 208, .external_lex_state = 2},
  [8498] = {.lex_state = 420, .external_lex_state = 2},
  [8499] = {.lex_state = 420, .external_lex_state = 2},
  [8500] = {.lex_state = 420, .external_lex_state = 2},
  [8501] = {.lex_state = 420, .external_lex_state = 2},
  [8502] = {.lex_state = 420, .external_lex_state = 2},
  [8503] = {.lex_state = 420, .external_lex_state = 2},
  [8504] = {.lex_state = 171, .external_lex_state = 3},
  [8505] = {.lex_state = 420, .external_lex_state = 2},
  [8506] = {.lex_state = 420, .external_lex_state = 2},
  [8507] = {.lex_state = 208, .external_lex_state = 2},
  [8508] = {.lex_state = 208, .external_lex_state = 2},
  [8509] = {.lex_state = 420, .external_lex_state = 2},
  [8510] = {.lex_state = 420, .external_lex_state = 2},
  [8511] = {.lex_state = 420, .external_lex_state = 2},
  [8512] = {.lex_state = 208, .external_lex_state = 2},
  [8513] = {.lex_state = 181, .external_lex_state = 3},
  [8514] = {.lex_state = 208, .external_lex_state = 2},
  [8515] = {.lex_state = 208, .external_lex_state = 2},
  [8516] = {.lex_state = 208, .external_lex_state = 2},
  [8517] = {.lex_state = 208, .external_lex_state = 2},
  [8518] = {.lex_state = 420, .external_lex_state = 2},
  [8519] = {.lex_state = 420, .external_lex_state = 2},
  [8520] = {.lex_state = 420, .external_lex_state = 2},
  [8521] = {.lex_state = 167, .external_lex_state = 3},
  [8522] = {.lex_state = 420, .external_lex_state = 2},
  [8523] = {.lex_state = 208, .external_lex_state = 2},
  [8524] = {.lex_state = 420, .external_lex_state = 2},
  [8525] = {.lex_state = 420, .external_lex_state = 2},
  [8526] = {.lex_state = 420, .external_lex_state = 2},
  [8527] = {.lex_state = 208, .external_lex_state = 2},
  [8528] = {.lex_state = 196, .external_lex_state = 3},
  [8529] = {.lex_state = 208, .external_lex_state = 2},
  [8530] = {.lex_state = 181, .external_lex_state = 3},
  [8531] = {.lex_state = 208, .external_lex_state = 2},
  [8532] = {.lex_state = 208, .external_lex_state = 2},
  [8533] = {.lex_state = 420, .external_lex_state = 2},
  [8534] = {.lex_state = 420, .external_lex_state = 2},
  [8535] = {.lex_state = 7, .external_lex_state = 2},
  [8536] = {.lex_state = 420, .external_lex_state = 2},
  [8537] = {.lex_state = 7, .external_lex_state = 2},
  [8538] = {.lex_state = 420, .external_lex_state = 2},
  [8539] = {.lex_state = 208, .external_lex_state = 2},
  [8540] = {.lex_state = 420, .external_lex_state = 2},
  [8541] = {.lex_state = 208, .external_lex_state = 2},
  [8542] = {.lex_state = 420, .external_lex_state = 2},
  [8543] = {.lex_state = 208, .external_lex_state = 2},
  [8544] = {.lex_state = 420, .external_lex_state = 2},
  [8545] = {.lex_state = 420, .external_lex_state = 2},
  [8546] = {.lex_state = 420, .external_lex_state = 2},
  [8547] = {.lex_state = 208, .external_lex_state = 2},
  [8548] = {.lex_state = 420, .external_lex_state = 2},
  [8549] = {.lex_state = 208, .external_lex_state = 2},
  [8550] = {.lex_state = 420, .external_lex_state = 2},
  [8551] = {.lex_state = 420, .external_lex_state = 2},
  [8552] = {.lex_state = 420, .external_lex_state = 2},
  [8553] = {.lex_state = 7, .external_lex_state = 2},
  [8554] = {.lex_state = 420, .external_lex_state = 2},
  [8555] = {.lex_state = 208, .external_lex_state = 2},
  [8556] = {.lex_state = 208, .external_lex_state = 2},
  [8557] = {.lex_state = 420, .external_lex_state = 2},
  [8558] = {.lex_state = 7, .external_lex_state = 2},
  [8559] = {.lex_state = 7, .external_lex_state = 2},
  [8560] = {.lex_state = 170, .external_lex_state = 3},
  [8561] = {.lex_state = 170, .external_lex_state = 3},
  [8562] = {.lex_state = 7, .external_lex_state = 2},
  [8563] = {.lex_state = 7, .external_lex_state = 2},
  [8564] = {.lex_state = 170, .external_lex_state = 3},
  [8565] = {.lex_state = 187, .external_lex_state = 3},
  [8566] = {.lex_state = 187, .external_lex_state = 3},
  [8567] = {.lex_state = 187, .external_lex_state = 3},
  [8568] = {.lex_state = 187, .external_lex_state = 3},
  [8569] = {.lex_state = 187, .external_lex_state = 3},
  [8570] = {.lex_state = 426, .external_lex_state = 2},
  [8571] = {.lex_state = 181, .external_lex_state = 3},
  [8572] = {.lex_state = 7, .external_lex_state = 2},
  [8573] = {.lex_state = 7, .external_lex_state = 2},
  [8574] = {.lex_state = 420, .external_lex_state = 2},
  [8575] = {.lex_state = 7, .external_lex_state = 2},
  [8576] = {.lex_state = 7, .external_lex_state = 2},
  [8577] = {.lex_state = 7, .external_lex_state = 2},
  [8578] = {.lex_state = 7, .external_lex_state = 2},
  [8579] = {.lex_state = 170, .external_lex_state = 3},
  [8580] = {.lex_state = 7, .external_lex_state = 2},
  [8581] = {.lex_state = 187, .external_lex_state = 3},
  [8582] = {.lex_state = 187, .external_lex_state = 3},
  [8583] = {.lex_state = 7, .external_lex_state = 2},
  [8584] = {.lex_state = 7, .external_lex_state = 2},
  [8585] = {.lex_state = 7, .external_lex_state = 2},
  [8586] = {.lex_state = 7, .external_lex_state = 2},
  [8587] = {.lex_state = 7, .external_lex_state = 2},
  [8588] = {.lex_state = 7, .external_lex_state = 2},
  [8589] = {.lex_state = 7, .external_lex_state = 2},
  [8590] = {.lex_state = 7, .external_lex_state = 2},
  [8591] = {.lex_state = 420, .external_lex_state = 2},
  [8592] = {.lex_state = 187, .external_lex_state = 3},
  [8593] = {.lex_state = 7, .external_lex_state = 2},
  [8594] = {.lex_state = 7, .external_lex_state = 2},
  [8595] = {.lex_state = 170, .external_lex_state = 3},
  [8596] = {.lex_state = 7, .external_lex_state = 2},
  [8597] = {.lex_state = 7, .external_lex_state = 2},
  [8598] = {.lex_state = 7, .external_lex_state = 2},
  [8599] = {.lex_state = 7, .external_lex_state = 2},
  [8600] = {.lex_state = 7, .external_lex_state = 2},
  [8601] = {.lex_state = 170, .external_lex_state = 3},
  [8602] = {.lex_state = 7, .external_lex_state = 2},
  [8603] = {.lex_state = 7, .external_lex_state = 2},
  [8604] = {.lex_state = 7, .external_lex_state = 2},
  [8605] = {.lex_state = 170, .external_lex_state = 3},
  [8606] = {.lex_state = 170, .external_lex_state = 3},
  [8607] = {.lex_state = 7, .external_lex_state = 2},
  [8608] = {.lex_state = 7, .external_lex_state = 2},
  [8609] = {.lex_state = 7, .external_lex_state = 2},
  [8610] = {.lex_state = 420, .external_lex_state = 2},
  [8611] = {.lex_state = 181, .external_lex_state = 3},
  [8612] = {.lex_state = 7, .external_lex_state = 2},
  [8613] = {.lex_state = 170, .external_lex_state = 3},
  [8614] = {.lex_state = 7, .external_lex_state = 2},
  [8615] = {.lex_state = 7, .external_lex_state = 2},
  [8616] = {.lex_state = 7, .external_lex_state = 2},
  [8617] = {.lex_state = 7, .external_lex_state = 2},
  [8618] = {.lex_state = 420, .external_lex_state = 2},
  [8619] = {.lex_state = 181, .external_lex_state = 3},
  [8620] = {.lex_state = 7, .external_lex_state = 2},
  [8621] = {.lex_state = 7, .external_lex_state = 2},
  [8622] = {.lex_state = 170, .external_lex_state = 3},
  [8623] = {.lex_state = 7, .external_lex_state = 2},
  [8624] = {.lex_state = 7, .external_lex_state = 2},
  [8625] = {.lex_state = 7, .external_lex_state = 2},
  [8626] = {.lex_state = 7, .external_lex_state = 2},
  [8627] = {.lex_state = 7, .external_lex_state = 2},
  [8628] = {.lex_state = 7, .external_lex_state = 2},
  [8629] = {.lex_state = 7, .external_lex_state = 2},
  [8630] = {.lex_state = 7, .external_lex_state = 2},
  [8631] = {.lex_state = 7, .external_lex_state = 2},
  [8632] = {.lex_state = 426, .external_lex_state = 2},
  [8633] = {.lex_state = 426, .external_lex_state = 2},
  [8634] = {.lex_state = 7, .external_lex_state = 2},
  [8635] = {.lex_state = 7, .external_lex_state = 2},
  [8636] = {.lex_state = 420, .external_lex_state = 2},
  [8637] = {.lex_state = 187, .external_lex_state = 3},
  [8638] = {.lex_state = 7, .external_lex_state = 2},
  [8639] = {.lex_state = 181, .external_lex_state = 3},
  [8640] = {.lex_state = 420, .external_lex_state = 2},
  [8641] = {.lex_state = 170, .external_lex_state = 3},
  [8642] = {.lex_state = 7, .external_lex_state = 2},
  [8643] = {.lex_state = 7, .external_lex_state = 2},
  [8644] = {.lex_state = 170, .external_lex_state = 3},
  [8645] = {.lex_state = 170, .external_lex_state = 3},
  [8646] = {.lex_state = 7, .external_lex_state = 2},
  [8647] = {.lex_state = 427, .external_lex_state = 2},
  [8648] = {.lex_state = 7, .external_lex_state = 2},
  [8649] = {.lex_state = 170, .external_lex_state = 3},
  [8650] = {.lex_state = 7, .external_lex_state = 2},
  [8651] = {.lex_state = 7, .external_lex_state = 2},
  [8652] = {.lex_state = 7, .external_lex_state = 2},
  [8653] = {.lex_state = 426, .external_lex_state = 2},
  [8654] = {.lex_state = 7, .external_lex_state = 2},
  [8655] = {.lex_state = 7, .external_lex_state = 2},
  [8656] = {.lex_state = 7, .external_lex_state = 2},
  [8657] = {.lex_state = 7, .external_lex_state = 2},
  [8658] = {.lex_state = 170, .external_lex_state = 3},
  [8659] = {.lex_state = 7, .external_lex_state = 2},
  [8660] = {.lex_state = 7, .external_lex_state = 2},
  [8661] = {.lex_state = 7, .external_lex_state = 2},
  [8662] = {.lex_state = 7, .external_lex_state = 2},
  [8663] = {.lex_state = 7, .external_lex_state = 2},
  [8664] = {.lex_state = 170, .external_lex_state = 3},
  [8665] = {.lex_state = 7, .external_lex_state = 2},
  [8666] = {.lex_state = 7, .external_lex_state = 2},
  [8667] = {.lex_state = 187, .external_lex_state = 3},
  [8668] = {.lex_state = 7, .external_lex_state = 2},
  [8669] = {.lex_state = 7, .external_lex_state = 2},
  [8670] = {.lex_state = 7, .external_lex_state = 2},
  [8671] = {.lex_state = 7, .external_lex_state = 2},
  [8672] = {.lex_state = 7, .external_lex_state = 2},
  [8673] = {.lex_state = 7, .external_lex_state = 2},
  [8674] = {.lex_state = 420, .external_lex_state = 2},
  [8675] = {.lex_state = 7, .external_lex_state = 2},
  [8676] = {.lex_state = 7, .external_lex_state = 2},
  [8677] = {.lex_state = 7, .external_lex_state = 2},
  [8678] = {.lex_state = 428, .external_lex_state = 2},
  [8679] = {.lex_state = 420, .external_lex_state = 2},
  [8680] = {.lex_state = 420, .external_lex_state = 2},
  [8681] = {.lex_state = 7, .external_lex_state = 2},
  [8682] = {.lex_state = 420, .external_lex_state = 2},
  [8683] = {.lex_state = 7, .external_lex_state = 2},
  [8684] = {.lex_state = 7, .external_lex_state = 2},
  [8685] = {.lex_state = 7, .external_lex_state = 2},
  [8686] = {.lex_state = 7, .external_lex_state = 2},
  [8687] = {.lex_state = 7, .external_lex_state = 2},
  [8688] = {.lex_state = 7, .external_lex_state = 2},
  [8689] = {.lex_state = 7, .external_lex_state = 2},
  [8690] = {.lex_state = 7, .external_lex_state = 2},
  [8691] = {.lex_state = 7, .external_lex_state = 2},
  [8692] = {.lex_state = 7, .external_lex_state = 2},
  [8693] = {.lex_state = 170, .external_lex_state = 3},
  [8694] = {.lex_state = 7, .external_lex_state = 2},
  [8695] = {.lex_state = 7, .external_lex_state = 2},
  [8696] = {.lex_state = 7, .external_lex_state = 2},
  [8697] = {.lex_state = 7, .external_lex_state = 2},
  [8698] = {.lex_state = 7, .external_lex_state = 2},
  [8699] = {.lex_state = 170, .external_lex_state = 3},
  [8700] = {.lex_state = 7, .external_lex_state = 2},
  [8701] = {.lex_state = 170, .external_lex_state = 3},
  [8702] = {.lex_state = 170, .external_lex_state = 3},
  [8703] = {.lex_state = 7, .external_lex_state = 2},
  [8704] = {.lex_state = 7, .external_lex_state = 2},
  [8705] = {.lex_state = 7, .external_lex_state = 2},
  [8706] = {.lex_state = 7, .external_lex_state = 2},
  [8707] = {.lex_state = 170, .external_lex_state = 3},
  [8708] = {.lex_state = 428, .external_lex_state = 2},
  [8709] = {.lex_state = 7, .external_lex_state = 2},
  [8710] = {.lex_state = 7, .external_lex_state = 2},
  [8711] = {.lex_state = 420, .external_lex_state = 2},
  [8712] = {.lex_state = 420, .external_lex_state = 2},
  [8713] = {.lex_state = 426, .external_lex_state = 2},
  [8714] = {.lex_state = 420, .external_lex_state = 2},
  [8715] = {.lex_state = 170, .external_lex_state = 3},
  [8716] = {.lex_state = 7, .external_lex_state = 2},
  [8717] = {.lex_state = 7, .external_lex_state = 2},
  [8718] = {.lex_state = 170, .external_lex_state = 3},
  [8719] = {.lex_state = 7, .external_lex_state = 2},
  [8720] = {.lex_state = 426, .external_lex_state = 2},
  [8721] = {.lex_state = 170, .external_lex_state = 3},
  [8722] = {.lex_state = 7, .external_lex_state = 2},
  [8723] = {.lex_state = 7, .external_lex_state = 2},
  [8724] = {.lex_state = 7, .external_lex_state = 2},
  [8725] = {.lex_state = 7, .external_lex_state = 2},
  [8726] = {.lex_state = 170, .external_lex_state = 3},
  [8727] = {.lex_state = 170, .external_lex_state = 3},
  [8728] = {.lex_state = 7, .external_lex_state = 2},
  [8729] = {.lex_state = 7, .external_lex_state = 2},
  [8730] = {.lex_state = 7, .external_lex_state = 2},
  [8731] = {.lex_state = 7, .external_lex_state = 2},
  [8732] = {.lex_state = 7, .external_lex_state = 2},
  [8733] = {.lex_state = 7, .external_lex_state = 2},
  [8734] = {.lex_state = 7, .external_lex_state = 2},
  [8735] = {.lex_state = 7, .external_lex_state = 2},
  [8736] = {.lex_state = 7, .external_lex_state = 2},
  [8737] = {.lex_state = 7, .external_lex_state = 2},
  [8738] = {.lex_state = 7, .external_lex_state = 2},
  [8739] = {.lex_state = 7, .external_lex_state = 2},
  [8740] = {.lex_state = 7, .external_lex_state = 2},
  [8741] = {.lex_state = 7, .external_lex_state = 2},
  [8742] = {.lex_state = 7, .external_lex_state = 2},
  [8743] = {.lex_state = 7, .external_lex_state = 2},
  [8744] = {.lex_state = 7, .external_lex_state = 2},
  [8745] = {.lex_state = 7, .external_lex_state = 2},
  [8746] = {.lex_state = 7, .external_lex_state = 2},
  [8747] = {.lex_state = 7, .external_lex_state = 2},
  [8748] = {.lex_state = 170, .external_lex_state = 3},
  [8749] = {.lex_state = 7, .external_lex_state = 2},
  [8750] = {.lex_state = 7, .external_lex_state = 2},
  [8751] = {.lex_state = 7, .external_lex_state = 2},
  [8752] = {.lex_state = 7, .external_lex_state = 2},
  [8753] = {.lex_state = 7, .external_lex_state = 2},
  [8754] = {.lex_state = 7, .external_lex_state = 2},
  [8755] = {.lex_state = 7, .external_lex_state = 2},
  [8756] = {.lex_state = 170, .external_lex_state = 3},
  [8757] = {.lex_state = 17, .external_lex_state = 2},
  [8758] = {.lex_state = 170, .external_lex_state = 3},
  [8759] = {.lex_state = 170, .external_lex_state = 3},
  [8760] = {.lex_state = 170, .external_lex_state = 3},
  [8761] = {.lex_state = 7, .external_lex_state = 2},
  [8762] = {.lex_state = 170, .external_lex_state = 3},
  [8763] = {.lex_state = 7, .external_lex_state = 2},
  [8764] = {.lex_state = 170, .external_lex_state = 3},
  [8765] = {.lex_state = 7, .external_lex_state = 2},
  [8766] = {.lex_state = 170, .external_lex_state = 3},
  [8767] = {.lex_state = 7, .external_lex_state = 2},
  [8768] = {.lex_state = 7, .external_lex_state = 2},
  [8769] = {.lex_state = 17, .external_lex_state = 2},
  [8770] = {.lex_state = 170, .external_lex_state = 3},
  [8771] = {.lex_state = 420, .external_lex_state = 2},
  [8772] = {.lex_state = 7, .external_lex_state = 2},
  [8773] = {.lex_state = 7, .external_lex_state = 2},
  [8774] = {.lex_state = 7, .external_lex_state = 2},
  [8775] = {.lex_state = 7, .external_lex_state = 2},
  [8776] = {.lex_state = 7, .external_lex_state = 2},
  [8777] = {.lex_state = 170, .external_lex_state = 3},
  [8778] = {.lex_state = 187, .external_lex_state = 3},
  [8779] = {.lex_state = 170, .external_lex_state = 3},
  [8780] = {.lex_state = 7, .external_lex_state = 2},
  [8781] = {.lex_state = 7, .external_lex_state = 2},
  [8782] = {.lex_state = 170, .external_lex_state = 3},
  [8783] = {.lex_state = 7, .external_lex_state = 2},
  [8784] = {.lex_state = 7, .external_lex_state = 2},
  [8785] = {.lex_state = 7, .external_lex_state = 2},
  [8786] = {.lex_state = 7, .external_lex_state = 2},
  [8787] = {.lex_state = 428, .external_lex_state = 2},
  [8788] = {.lex_state = 7, .external_lex_state = 2},
  [8789] = {.lex_state = 7, .external_lex_state = 2},
  [8790] = {.lex_state = 170, .external_lex_state = 3},
  [8791] = {.lex_state = 7, .external_lex_state = 2},
  [8792] = {.lex_state = 7, .external_lex_state = 2},
  [8793] = {.lex_state = 170, .external_lex_state = 3},
  [8794] = {.lex_state = 420, .external_lex_state = 2},
  [8795] = {.lex_state = 7, .external_lex_state = 2},
  [8796] = {.lex_state = 7, .external_lex_state = 2},
  [8797] = {.lex_state = 7, .external_lex_state = 2},
  [8798] = {.lex_state = 7, .external_lex_state = 2},
  [8799] = {.lex_state = 170, .external_lex_state = 3},
  [8800] = {.lex_state = 7, .external_lex_state = 2},
  [8801] = {.lex_state = 7, .external_lex_state = 2},
  [8802] = {.lex_state = 7, .external_lex_state = 2},
  [8803] = {.lex_state = 7, .external_lex_state = 2},
  [8804] = {.lex_state = 7, .external_lex_state = 2},
  [8805] = {.lex_state = 170, .external_lex_state = 3},
  [8806] = {.lex_state = 170, .external_lex_state = 3},
  [8807] = {.lex_state = 420, .external_lex_state = 2},
  [8808] = {.lex_state = 7, .external_lex_state = 2},
  [8809] = {.lex_state = 7, .external_lex_state = 2},
  [8810] = {.lex_state = 420, .external_lex_state = 2},
  [8811] = {.lex_state = 170, .external_lex_state = 3},
  [8812] = {.lex_state = 420, .external_lex_state = 2},
  [8813] = {.lex_state = 170, .external_lex_state = 3},
  [8814] = {.lex_state = 170, .external_lex_state = 3},
  [8815] = {.lex_state = 170, .external_lex_state = 3},
  [8816] = {.lex_state = 7, .external_lex_state = 2},
  [8817] = {.lex_state = 170, .external_lex_state = 3},
  [8818] = {.lex_state = 7, .external_lex_state = 2},
  [8819] = {.lex_state = 170, .external_lex_state = 3},
  [8820] = {.lex_state = 170, .external_lex_state = 3},
  [8821] = {.lex_state = 7, .external_lex_state = 2},
  [8822] = {.lex_state = 7, .external_lex_state = 2},
  [8823] = {.lex_state = 170, .external_lex_state = 3},
  [8824] = {.lex_state = 7, .external_lex_state = 2},
  [8825] = {.lex_state = 7, .external_lex_state = 2},
  [8826] = {.lex_state = 420, .external_lex_state = 2},
  [8827] = {.lex_state = 7, .external_lex_state = 2},
  [8828] = {.lex_state = 7, .external_lex_state = 2},
  [8829] = {.lex_state = 420, .external_lex_state = 2},
  [8830] = {.lex_state = 420, .external_lex_state = 2},
  [8831] = {.lex_state = 420, .external_lex_state = 2},
  [8832] = {.lex_state = 420, .external_lex_state = 2},
  [8833] = {.lex_state = 420, .external_lex_state = 2},
  [8834] = {.lex_state = 420, .external_lex_state = 2},
  [8835] = {.lex_state = 7, .external_lex_state = 2},
  [8836] = {.lex_state = 420, .external_lex_state = 2},
  [8837] = {.lex_state = 420, .external_lex_state = 2},
  [8838] = {.lex_state = 170, .external_lex_state = 3},
  [8839] = {.lex_state = 170, .external_lex_state = 3},
  [8840] = {.lex_state = 170, .external_lex_state = 3},
  [8841] = {.lex_state = 170, .external_lex_state = 3},
  [8842] = {.lex_state = 420, .external_lex_state = 2},
  [8843] = {.lex_state = 420, .external_lex_state = 2},
  [8844] = {.lex_state = 420, .external_lex_state = 2},
  [8845] = {.lex_state = 420, .external_lex_state = 2},
  [8846] = {.lex_state = 420, .external_lex_state = 2},
  [8847] = {.lex_state = 420, .external_lex_state = 2},
  [8848] = {.lex_state = 7, .external_lex_state = 2},
  [8849] = {.lex_state = 420, .external_lex_state = 2},
  [8850] = {.lex_state = 7, .external_lex_state = 2},
  [8851] = {.lex_state = 17, .external_lex_state = 2},
  [8852] = {.lex_state = 420, .external_lex_state = 2},
  [8853] = {.lex_state = 420, .external_lex_state = 2},
  [8854] = {.lex_state = 7, .external_lex_state = 2},
  [8855] = {.lex_state = 7, .external_lex_state = 2},
  [8856] = {.lex_state = 170, .external_lex_state = 3},
  [8857] = {.lex_state = 7, .external_lex_state = 2},
  [8858] = {.lex_state = 7, .external_lex_state = 2},
  [8859] = {.lex_state = 7, .external_lex_state = 2},
  [8860] = {.lex_state = 7, .external_lex_state = 2},
  [8861] = {.lex_state = 420, .external_lex_state = 2},
  [8862] = {.lex_state = 420, .external_lex_state = 2},
  [8863] = {.lex_state = 7, .external_lex_state = 2},
  [8864] = {.lex_state = 7, .external_lex_state = 2},
  [8865] = {.lex_state = 7, .external_lex_state = 2},
  [8866] = {.lex_state = 170, .external_lex_state = 3},
  [8867] = {.lex_state = 170, .external_lex_state = 3},
  [8868] = {.lex_state = 170, .external_lex_state = 3},
  [8869] = {.lex_state = 7, .external_lex_state = 2},
  [8870] = {.lex_state = 170, .external_lex_state = 3},
  [8871] = {.lex_state = 170, .external_lex_state = 3},
  [8872] = {.lex_state = 181, .external_lex_state = 3},
  [8873] = {.lex_state = 181, .external_lex_state = 3},
  [8874] = {.lex_state = 181, .external_lex_state = 3},
  [8875] = {.lex_state = 15, .external_lex_state = 2},
  [8876] = {.lex_state = 15, .external_lex_state = 2},
  [8877] = {.lex_state = 420, .external_lex_state = 2},
  [8878] = {.lex_state = 181, .external_lex_state = 3},
  [8879] = {.lex_state = 420, .external_lex_state = 2},
  [8880] = {.lex_state = 426, .external_lex_state = 2},
  [8881] = {.lex_state = 181, .external_lex_state = 3},
  [8882] = {.lex_state = 181, .external_lex_state = 3},
  [8883] = {.lex_state = 420, .external_lex_state = 2},
  [8884] = {.lex_state = 181, .external_lex_state = 3},
  [8885] = {.lex_state = 181, .external_lex_state = 3},
  [8886] = {.lex_state = 426, .external_lex_state = 2},
  [8887] = {.lex_state = 426, .external_lex_state = 2},
  [8888] = {.lex_state = 181, .external_lex_state = 3},
  [8889] = {.lex_state = 181, .external_lex_state = 3},
  [8890] = {.lex_state = 181, .external_lex_state = 3},
  [8891] = {.lex_state = 181, .external_lex_state = 3},
  [8892] = {.lex_state = 181, .external_lex_state = 3},
  [8893] = {.lex_state = 420, .external_lex_state = 2},
  [8894] = {.lex_state = 181, .external_lex_state = 3},
  [8895] = {.lex_state = 181, .external_lex_state = 3},
  [8896] = {.lex_state = 181, .external_lex_state = 3},
  [8897] = {.lex_state = 181, .external_lex_state = 3},
  [8898] = {.lex_state = 181, .external_lex_state = 3},
  [8899] = {.lex_state = 426, .external_lex_state = 2},
  [8900] = {.lex_state = 420, .external_lex_state = 2},
  [8901] = {.lex_state = 181, .external_lex_state = 3},
  [8902] = {.lex_state = 15, .external_lex_state = 2},
  [8903] = {.lex_state = 15, .external_lex_state = 2},
  [8904] = {.lex_state = 426, .external_lex_state = 2},
  [8905] = {.lex_state = 181, .external_lex_state = 3},
  [8906] = {.lex_state = 181, .external_lex_state = 3},
  [8907] = {.lex_state = 181, .external_lex_state = 3},
  [8908] = {.lex_state = 426, .external_lex_state = 2},
  [8909] = {.lex_state = 426, .external_lex_state = 2},
  [8910] = {.lex_state = 181, .external_lex_state = 3},
  [8911] = {.lex_state = 181, .external_lex_state = 3},
  [8912] = {.lex_state = 181, .external_lex_state = 3},
  [8913] = {.lex_state = 181, .external_lex_state = 3},
  [8914] = {.lex_state = 181, .external_lex_state = 3},
  [8915] = {.lex_state = 426, .external_lex_state = 2},
  [8916] = {.lex_state = 181, .external_lex_state = 3},
  [8917] = {.lex_state = 181, .external_lex_state = 3},
  [8918] = {.lex_state = 426, .external_lex_state = 2},
  [8919] = {.lex_state = 420, .external_lex_state = 2},
  [8920] = {.lex_state = 181, .external_lex_state = 3},
  [8921] = {.lex_state = 181, .external_lex_state = 3},
  [8922] = {.lex_state = 426, .external_lex_state = 2},
  [8923] = {.lex_state = 428, .external_lex_state = 2},
  [8924] = {.lex_state = 181, .external_lex_state = 3},
  [8925] = {.lex_state = 426, .external_lex_state = 2},
  [8926] = {.lex_state = 426, .external_lex_state = 2},
  [8927] = {.lex_state = 181, .external_lex_state = 3},
  [8928] = {.lex_state = 181, .external_lex_state = 3},
  [8929] = {.lex_state = 181, .external_lex_state = 3},
  [8930] = {.lex_state = 181, .external_lex_state = 3},
  [8931] = {.lex_state = 181, .external_lex_state = 3},
  [8932] = {.lex_state = 181, .external_lex_state = 3},
  [8933] = {.lex_state = 420, .external_lex_state = 2},
  [8934] = {.lex_state = 181, .external_lex_state = 3},
  [8935] = {.lex_state = 181, .external_lex_state = 3},
  [8936] = {.lex_state = 428, .external_lex_state = 2},
  [8937] = {.lex_state = 181, .external_lex_state = 3},
  [8938] = {.lex_state = 181, .external_lex_state = 3},
  [8939] = {.lex_state = 181, .external_lex_state = 3},
  [8940] = {.lex_state = 181, .external_lex_state = 3},
  [8941] = {.lex_state = 181, .external_lex_state = 3},
  [8942] = {.lex_state = 181, .external_lex_state = 3},
  [8943] = {.lex_state = 181, .external_lex_state = 3},
  [8944] = {.lex_state = 181, .external_lex_state = 3},
  [8945] = {.lex_state = 181, .external_lex_state = 3},
  [8946] = {.lex_state = 226, .external_lex_state = 2},
  [8947] = {.lex_state = 226, .external_lex_state = 2},
  [8948] = {.lex_state = 226, .external_lex_state = 2},
  [8949] = {.lex_state = 420, .external_lex_state = 2},
  [8950] = {.lex_state = 420, .external_lex_state = 2},
  [8951] = {.lex_state = 420, .external_lex_state = 2},
  [8952] = {.lex_state = 431, .external_lex_state = 2},
  [8953] = {.lex_state = 420, .external_lex_state = 2},
  [8954] = {.lex_state = 225, .external_lex_state = 2},
  [8955] = {.lex_state = 420, .external_lex_state = 2},
  [8956] = {.lex_state = 225, .external_lex_state = 2},
  [8957] = {.lex_state = 420, .external_lex_state = 2},
  [8958] = {.lex_state = 225, .external_lex_state = 2},
  [8959] = {.lex_state = 7, .external_lex_state = 2},
  [8960] = {.lex_state = 7, .external_lex_state = 2},
  [8961] = {.lex_state = 420, .external_lex_state = 2},
  [8962] = {.lex_state = 7, .external_lex_state = 2},
  [8963] = {.lex_state = 7, .external_lex_state = 2},
  [8964] = {.lex_state = 7, .external_lex_state = 2},
  [8965] = {.lex_state = 420, .external_lex_state = 2},
  [8966] = {.lex_state = 7, .external_lex_state = 2},
  [8967] = {.lex_state = 216, .external_lex_state = 2},
  [8968] = {.lex_state = 7, .external_lex_state = 2},
  [8969] = {.lex_state = 426, .external_lex_state = 2},
  [8970] = {.lex_state = 225, .external_lex_state = 2},
  [8971] = {.lex_state = 420, .external_lex_state = 2},
  [8972] = {.lex_state = 426, .external_lex_state = 2},
  [8973] = {.lex_state = 7, .external_lex_state = 2},
  [8974] = {.lex_state = 7, .external_lex_state = 2},
  [8975] = {.lex_state = 7, .external_lex_state = 2},
  [8976] = {.lex_state = 420, .external_lex_state = 2},
  [8977] = {.lex_state = 7, .external_lex_state = 2},
  [8978] = {.lex_state = 420, .external_lex_state = 2},
  [8979] = {.lex_state = 7, .external_lex_state = 2},
  [8980] = {.lex_state = 7, .external_lex_state = 2},
  [8981] = {.lex_state = 7, .external_lex_state = 2},
  [8982] = {.lex_state = 226, .external_lex_state = 2},
  [8983] = {.lex_state = 7, .external_lex_state = 2},
  [8984] = {.lex_state = 426, .external_lex_state = 2},
  [8985] = {.lex_state = 7, .external_lex_state = 2},
  [8986] = {.lex_state = 7, .external_lex_state = 2},
  [8987] = {.lex_state = 7, .external_lex_state = 2},
  [8988] = {.lex_state = 434, .external_lex_state = 2},
  [8989] = {.lex_state = 420, .external_lex_state = 2},
  [8990] = {.lex_state = 215, .external_lex_state = 2},
  [8991] = {.lex_state = 7, .external_lex_state = 2},
  [8992] = {.lex_state = 434, .external_lex_state = 2},
  [8993] = {.lex_state = 420, .external_lex_state = 2},
  [8994] = {.lex_state = 7, .external_lex_state = 2},
  [8995] = {.lex_state = 7, .external_lex_state = 2},
  [8996] = {.lex_state = 7, .external_lex_state = 2},
  [8997] = {.lex_state = 7, .external_lex_state = 2},
  [8998] = {.lex_state = 7, .external_lex_state = 2},
  [8999] = {.lex_state = 7, .external_lex_state = 2},
  [9000] = {.lex_state = 7, .external_lex_state = 2},
  [9001] = {.lex_state = 7, .external_lex_state = 2},
  [9002] = {.lex_state = 7, .external_lex_state = 2},
  [9003] = {.lex_state = 420, .external_lex_state = 2},
  [9004] = {.lex_state = 426, .external_lex_state = 2},
  [9005] = {.lex_state = 7, .external_lex_state = 2},
  [9006] = {.lex_state = 7, .external_lex_state = 2},
  [9007] = {.lex_state = 426, .external_lex_state = 2},
  [9008] = {.lex_state = 7, .external_lex_state = 2},
  [9009] = {.lex_state = 7, .external_lex_state = 2},
  [9010] = {.lex_state = 7, .external_lex_state = 2},
  [9011] = {.lex_state = 426, .external_lex_state = 2},
  [9012] = {.lex_state = 216, .external_lex_state = 2},
  [9013] = {.lex_state = 215, .external_lex_state = 2},
  [9014] = {.lex_state = 434, .external_lex_state = 2},
  [9015] = {.lex_state = 7, .external_lex_state = 2},
  [9016] = {.lex_state = 7, .external_lex_state = 2},
  [9017] = {.lex_state = 7, .external_lex_state = 2},
  [9018] = {.lex_state = 7, .external_lex_state = 2},
  [9019] = {.lex_state = 7, .external_lex_state = 2},
  [9020] = {.lex_state = 7, .external_lex_state = 2},
  [9021] = {.lex_state = 7, .external_lex_state = 2},
  [9022] = {.lex_state = 7, .external_lex_state = 2},
  [9023] = {.lex_state = 7, .external_lex_state = 2},
  [9024] = {.lex_state = 7, .external_lex_state = 2},
  [9025] = {.lex_state = 216, .external_lex_state = 2},
  [9026] = {.lex_state = 7, .external_lex_state = 2},
  [9027] = {.lex_state = 7, .external_lex_state = 2},
  [9028] = {.lex_state = 7, .external_lex_state = 2},
  [9029] = {.lex_state = 7, .external_lex_state = 2},
  [9030] = {.lex_state = 7, .external_lex_state = 2},
  [9031] = {.lex_state = 7, .external_lex_state = 2},
  [9032] = {.lex_state = 28, .external_lex_state = 3},
  [9033] = {.lex_state = 28, .external_lex_state = 3},
  [9034] = {.lex_state = 226, .external_lex_state = 2},
  [9035] = {.lex_state = 432, .external_lex_state = 2},
  [9036] = {.lex_state = 7, .external_lex_state = 2},
  [9037] = {.lex_state = 7, .external_lex_state = 2},
  [9038] = {.lex_state = 225, .external_lex_state = 2},
  [9039] = {.lex_state = 28, .external_lex_state = 3},
  [9040] = {.lex_state = 28, .external_lex_state = 3},
  [9041] = {.lex_state = 7, .external_lex_state = 2},
  [9042] = {.lex_state = 7, .external_lex_state = 2},
  [9043] = {.lex_state = 28, .external_lex_state = 3},
  [9044] = {.lex_state = 7, .external_lex_state = 2},
  [9045] = {.lex_state = 226, .external_lex_state = 2},
  [9046] = {.lex_state = 28, .external_lex_state = 3},
  [9047] = {.lex_state = 225, .external_lex_state = 2},
  [9048] = {.lex_state = 182, .external_lex_state = 3},
  [9049] = {.lex_state = 225, .external_lex_state = 2},
  [9050] = {.lex_state = 225, .external_lex_state = 2},
  [9051] = {.lex_state = 7, .external_lex_state = 2},
  [9052] = {.lex_state = 216, .external_lex_state = 2},
  [9053] = {.lex_state = 226, .external_lex_state = 2},
  [9054] = {.lex_state = 216, .external_lex_state = 2},
  [9055] = {.lex_state = 7, .external_lex_state = 2},
  [9056] = {.lex_state = 7, .external_lex_state = 2},
  [9057] = {.lex_state = 225, .external_lex_state = 2},
  [9058] = {.lex_state = 28, .external_lex_state = 3},
  [9059] = {.lex_state = 226, .external_lex_state = 2},
  [9060] = {.lex_state = 225, .external_lex_state = 2},
  [9061] = {.lex_state = 7, .external_lex_state = 2},
  [9062] = {.lex_state = 28, .external_lex_state = 3},
  [9063] = {.lex_state = 7, .external_lex_state = 2},
  [9064] = {.lex_state = 7, .external_lex_state = 2},
  [9065] = {.lex_state = 7, .external_lex_state = 2},
  [9066] = {.lex_state = 28, .external_lex_state = 3},
  [9067] = {.lex_state = 7, .external_lex_state = 2},
  [9068] = {.lex_state = 225, .external_lex_state = 2},
  [9069] = {.lex_state = 7, .external_lex_state = 2},
  [9070] = {.lex_state = 28, .external_lex_state = 3},
  [9071] = {.lex_state = 225, .external_lex_state = 2},
  [9072] = {.lex_state = 28, .external_lex_state = 3},
  [9073] = {.lex_state = 216, .external_lex_state = 2},
  [9074] = {.lex_state = 28, .external_lex_state = 3},
  [9075] = {.lex_state = 7, .external_lex_state = 2},
  [9076] = {.lex_state = 7, .external_lex_state = 2},
  [9077] = {.lex_state = 28, .external_lex_state = 3},
  [9078] = {.lex_state = 28, .external_lex_state = 3},
  [9079] = {.lex_state = 7, .external_lex_state = 2},
  [9080] = {.lex_state = 28, .external_lex_state = 3},
  [9081] = {.lex_state = 28, .external_lex_state = 3},
  [9082] = {.lex_state = 225, .external_lex_state = 2},
  [9083] = {.lex_state = 28, .external_lex_state = 3},
  [9084] = {.lex_state = 28, .external_lex_state = 3},
  [9085] = {.lex_state = 225, .external_lex_state = 2},
  [9086] = {.lex_state = 28, .external_lex_state = 3},
  [9087] = {.lex_state = 28, .external_lex_state = 3},
  [9088] = {.lex_state = 7, .external_lex_state = 2},
  [9089] = {.lex_state = 7, .external_lex_state = 2},
  [9090] = {.lex_state = 7, .external_lex_state = 2},
  [9091] = {.lex_state = 7, .external_lex_state = 2},
  [9092] = {.lex_state = 7, .external_lex_state = 2},
  [9093] = {.lex_state = 7, .external_lex_state = 2},
  [9094] = {.lex_state = 7, .external_lex_state = 2},
  [9095] = {.lex_state = 7, .external_lex_state = 2},
  [9096] = {.lex_state = 7, .external_lex_state = 2},
  [9097] = {.lex_state = 7, .external_lex_state = 2},
  [9098] = {.lex_state = 7, .external_lex_state = 2},
  [9099] = {.lex_state = 225, .external_lex_state = 2},
  [9100] = {.lex_state = 225, .external_lex_state = 2},
  [9101] = {.lex_state = 28, .external_lex_state = 3},
  [9102] = {.lex_state = 7, .external_lex_state = 2},
  [9103] = {.lex_state = 28, .external_lex_state = 3},
  [9104] = {.lex_state = 7, .external_lex_state = 2},
  [9105] = {.lex_state = 28, .external_lex_state = 3},
  [9106] = {.lex_state = 28, .external_lex_state = 3},
  [9107] = {.lex_state = 7, .external_lex_state = 2},
  [9108] = {.lex_state = 225, .external_lex_state = 2},
  [9109] = {.lex_state = 7, .external_lex_state = 2},
  [9110] = {.lex_state = 7, .external_lex_state = 2},
  [9111] = {.lex_state = 215, .external_lex_state = 2},
  [9112] = {.lex_state = 7, .external_lex_state = 2},
  [9113] = {.lex_state = 28, .external_lex_state = 3},
  [9114] = {.lex_state = 226, .external_lex_state = 2},
  [9115] = {.lex_state = 28, .external_lex_state = 3},
  [9116] = {.lex_state = 7, .external_lex_state = 2},
  [9117] = {.lex_state = 7, .external_lex_state = 2},
  [9118] = {.lex_state = 7, .external_lex_state = 2},
  [9119] = {.lex_state = 7, .external_lex_state = 2},
  [9120] = {.lex_state = 215, .external_lex_state = 2},
  [9121] = {.lex_state = 7, .external_lex_state = 2},
  [9122] = {.lex_state = 227, .external_lex_state = 2},
  [9123] = {.lex_state = 7, .external_lex_state = 2},
  [9124] = {.lex_state = 7, .external_lex_state = 2},
  [9125] = {.lex_state = 226, .external_lex_state = 2},
  [9126] = {.lex_state = 7, .external_lex_state = 2},
  [9127] = {.lex_state = 434, .external_lex_state = 2},
  [9128] = {.lex_state = 7, .external_lex_state = 2},
  [9129] = {.lex_state = 28, .external_lex_state = 3},
  [9130] = {.lex_state = 28, .external_lex_state = 3},
  [9131] = {.lex_state = 7, .external_lex_state = 2},
  [9132] = {.lex_state = 28, .external_lex_state = 3},
  [9133] = {.lex_state = 7, .external_lex_state = 2},
  [9134] = {.lex_state = 28, .external_lex_state = 3},
  [9135] = {.lex_state = 226, .external_lex_state = 2},
  [9136] = {.lex_state = 7, .external_lex_state = 2},
  [9137] = {.lex_state = 216, .external_lex_state = 2},
  [9138] = {.lex_state = 7, .external_lex_state = 2},
  [9139] = {.lex_state = 7, .external_lex_state = 2},
  [9140] = {.lex_state = 215, .external_lex_state = 2},
  [9141] = {.lex_state = 182, .external_lex_state = 3},
  [9142] = {.lex_state = 28, .external_lex_state = 3},
  [9143] = {.lex_state = 7, .external_lex_state = 2},
  [9144] = {.lex_state = 226, .external_lex_state = 2},
  [9145] = {.lex_state = 7, .external_lex_state = 2},
  [9146] = {.lex_state = 28, .external_lex_state = 3},
  [9147] = {.lex_state = 28, .external_lex_state = 3},
  [9148] = {.lex_state = 28, .external_lex_state = 3},
  [9149] = {.lex_state = 7, .external_lex_state = 2},
  [9150] = {.lex_state = 7, .external_lex_state = 2},
  [9151] = {.lex_state = 7, .external_lex_state = 2},
  [9152] = {.lex_state = 225, .external_lex_state = 2},
  [9153] = {.lex_state = 7, .external_lex_state = 2},
  [9154] = {.lex_state = 7, .external_lex_state = 2},
  [9155] = {.lex_state = 426, .external_lex_state = 2},
  [9156] = {.lex_state = 226, .external_lex_state = 2},
  [9157] = {.lex_state = 430, .external_lex_state = 2},
  [9158] = {.lex_state = 7, .external_lex_state = 2},
  [9159] = {.lex_state = 28, .external_lex_state = 3},
  [9160] = {.lex_state = 28, .external_lex_state = 3},
  [9161] = {.lex_state = 215, .external_lex_state = 2},
  [9162] = {.lex_state = 7, .external_lex_state = 2},
  [9163] = {.lex_state = 28, .external_lex_state = 3},
  [9164] = {.lex_state = 28, .external_lex_state = 3},
  [9165] = {.lex_state = 28, .external_lex_state = 3},
  [9166] = {.lex_state = 7, .external_lex_state = 2},
  [9167] = {.lex_state = 432, .external_lex_state = 2},
  [9168] = {.lex_state = 7, .external_lex_state = 2},
  [9169] = {.lex_state = 7, .external_lex_state = 2},
  [9170] = {.lex_state = 225, .external_lex_state = 2},
  [9171] = {.lex_state = 225, .external_lex_state = 2},
  [9172] = {.lex_state = 15, .external_lex_state = 2},
  [9173] = {.lex_state = 225, .external_lex_state = 2},
  [9174] = {.lex_state = 225, .external_lex_state = 2},
  [9175] = {.lex_state = 225, .external_lex_state = 2},
  [9176] = {.lex_state = 28, .external_lex_state = 3},
  [9177] = {.lex_state = 28, .external_lex_state = 3},
  [9178] = {.lex_state = 28, .external_lex_state = 3},
  [9179] = {.lex_state = 28, .external_lex_state = 3},
  [9180] = {.lex_state = 15, .external_lex_state = 2},
  [9181] = {.lex_state = 7, .external_lex_state = 2},
  [9182] = {.lex_state = 15, .external_lex_state = 2},
  [9183] = {.lex_state = 215, .external_lex_state = 2},
  [9184] = {.lex_state = 28, .external_lex_state = 3},
  [9185] = {.lex_state = 7, .external_lex_state = 2},
  [9186] = {.lex_state = 7, .external_lex_state = 2},
  [9187] = {.lex_state = 227, .external_lex_state = 2},
  [9188] = {.lex_state = 28, .external_lex_state = 3},
  [9189] = {.lex_state = 7, .external_lex_state = 2},
  [9190] = {.lex_state = 7, .external_lex_state = 2},
  [9191] = {.lex_state = 15, .external_lex_state = 2},
  [9192] = {.lex_state = 7, .external_lex_state = 2},
  [9193] = {.lex_state = 7, .external_lex_state = 2},
  [9194] = {.lex_state = 7, .external_lex_state = 2},
  [9195] = {.lex_state = 7, .external_lex_state = 2},
  [9196] = {.lex_state = 28, .external_lex_state = 3},
  [9197] = {.lex_state = 28, .external_lex_state = 3},
  [9198] = {.lex_state = 7, .external_lex_state = 2},
  [9199] = {.lex_state = 7, .external_lex_state = 2},
  [9200] = {.lex_state = 28, .external_lex_state = 3},
  [9201] = {.lex_state = 225, .external_lex_state = 2},
  [9202] = {.lex_state = 226, .external_lex_state = 2},
  [9203] = {.lex_state = 7, .external_lex_state = 2},
  [9204] = {.lex_state = 226, .external_lex_state = 2},
  [9205] = {.lex_state = 7, .external_lex_state = 2},
  [9206] = {.lex_state = 7, .external_lex_state = 2},
  [9207] = {.lex_state = 28, .external_lex_state = 3},
  [9208] = {.lex_state = 215, .external_lex_state = 2},
  [9209] = {.lex_state = 7, .external_lex_state = 2},
  [9210] = {.lex_state = 226, .external_lex_state = 2},
  [9211] = {.lex_state = 216, .external_lex_state = 2},
  [9212] = {.lex_state = 226, .external_lex_state = 2},
  [9213] = {.lex_state = 420, .external_lex_state = 2},
  [9214] = {.lex_state = 226, .external_lex_state = 2},
  [9215] = {.lex_state = 215, .external_lex_state = 2},
  [9216] = {.lex_state = 7, .external_lex_state = 2},
  [9217] = {.lex_state = 226, .external_lex_state = 2},
  [9218] = {.lex_state = 7, .external_lex_state = 2},
  [9219] = {.lex_state = 28, .external_lex_state = 3},
  [9220] = {.lex_state = 7, .external_lex_state = 2},
  [9221] = {.lex_state = 28, .external_lex_state = 3},
  [9222] = {.lex_state = 226, .external_lex_state = 2},
  [9223] = {.lex_state = 28, .external_lex_state = 3},
  [9224] = {.lex_state = 28, .external_lex_state = 3},
  [9225] = {.lex_state = 28, .external_lex_state = 3},
  [9226] = {.lex_state = 28, .external_lex_state = 3},
  [9227] = {.lex_state = 28, .external_lex_state = 3},
  [9228] = {.lex_state = 28, .external_lex_state = 3},
  [9229] = {.lex_state = 28, .external_lex_state = 3},
  [9230] = {.lex_state = 7, .external_lex_state = 2},
  [9231] = {.lex_state = 28, .external_lex_state = 3},
  [9232] = {.lex_state = 226, .external_lex_state = 2},
  [9233] = {.lex_state = 28, .external_lex_state = 3},
  [9234] = {.lex_state = 7, .external_lex_state = 2},
  [9235] = {.lex_state = 225, .external_lex_state = 2},
  [9236] = {.lex_state = 430, .external_lex_state = 2},
  [9237] = {.lex_state = 28, .external_lex_state = 3},
  [9238] = {.lex_state = 28, .external_lex_state = 3},
  [9239] = {.lex_state = 7, .external_lex_state = 2},
  [9240] = {.lex_state = 28, .external_lex_state = 3},
  [9241] = {.lex_state = 225, .external_lex_state = 2},
  [9242] = {.lex_state = 225, .external_lex_state = 2},
  [9243] = {.lex_state = 28, .external_lex_state = 3},
  [9244] = {.lex_state = 7, .external_lex_state = 2},
  [9245] = {.lex_state = 28, .external_lex_state = 3},
  [9246] = {.lex_state = 28, .external_lex_state = 3},
  [9247] = {.lex_state = 7, .external_lex_state = 2},
  [9248] = {.lex_state = 226, .external_lex_state = 2},
  [9249] = {.lex_state = 7, .external_lex_state = 2},
  [9250] = {.lex_state = 7, .external_lex_state = 2},
  [9251] = {.lex_state = 7, .external_lex_state = 2},
  [9252] = {.lex_state = 227, .external_lex_state = 2},
  [9253] = {.lex_state = 7, .external_lex_state = 2},
  [9254] = {.lex_state = 7, .external_lex_state = 2},
  [9255] = {.lex_state = 215, .external_lex_state = 2},
  [9256] = {.lex_state = 420, .external_lex_state = 2},
  [9257] = {.lex_state = 28, .external_lex_state = 3},
  [9258] = {.lex_state = 420, .external_lex_state = 2},
  [9259] = {.lex_state = 7, .external_lex_state = 2},
  [9260] = {.lex_state = 28, .external_lex_state = 3},
  [9261] = {.lex_state = 7, .external_lex_state = 2},
  [9262] = {.lex_state = 7, .external_lex_state = 2},
  [9263] = {.lex_state = 7, .external_lex_state = 2},
  [9264] = {.lex_state = 7, .external_lex_state = 2},
  [9265] = {.lex_state = 28, .external_lex_state = 3},
  [9266] = {.lex_state = 28, .external_lex_state = 3},
  [9267] = {.lex_state = 7, .external_lex_state = 2},
  [9268] = {.lex_state = 28, .external_lex_state = 3},
  [9269] = {.lex_state = 7, .external_lex_state = 2},
  [9270] = {.lex_state = 28, .external_lex_state = 3},
  [9271] = {.lex_state = 7, .external_lex_state = 2},
  [9272] = {.lex_state = 426, .external_lex_state = 2},
  [9273] = {.lex_state = 7, .external_lex_state = 2},
  [9274] = {.lex_state = 7, .external_lex_state = 2},
  [9275] = {.lex_state = 7, .external_lex_state = 2},
  [9276] = {.lex_state = 226, .external_lex_state = 2},
  [9277] = {.lex_state = 7, .external_lex_state = 2},
  [9278] = {.lex_state = 28, .external_lex_state = 3},
  [9279] = {.lex_state = 7, .external_lex_state = 2},
  [9280] = {.lex_state = 226, .external_lex_state = 2},
  [9281] = {.lex_state = 7, .external_lex_state = 2},
  [9282] = {.lex_state = 226, .external_lex_state = 2},
  [9283] = {.lex_state = 7, .external_lex_state = 2},
  [9284] = {.lex_state = 7, .external_lex_state = 2},
  [9285] = {.lex_state = 7, .external_lex_state = 2},
  [9286] = {.lex_state = 7, .external_lex_state = 2},
  [9287] = {.lex_state = 7, .external_lex_state = 2},
  [9288] = {.lex_state = 216, .external_lex_state = 2},
  [9289] = {.lex_state = 226, .external_lex_state = 2},
  [9290] = {.lex_state = 225, .external_lex_state = 2},
  [9291] = {.lex_state = 7, .external_lex_state = 2},
  [9292] = {.lex_state = 7, .external_lex_state = 2},
  [9293] = {.lex_state = 7, .external_lex_state = 2},
  [9294] = {.lex_state = 226, .external_lex_state = 2},
  [9295] = {.lex_state = 225, .external_lex_state = 2},
  [9296] = {.lex_state = 7, .external_lex_state = 2},
  [9297] = {.lex_state = 226, .external_lex_state = 2},
  [9298] = {.lex_state = 225, .external_lex_state = 2},
  [9299] = {.lex_state = 226, .external_lex_state = 2},
  [9300] = {.lex_state = 225, .external_lex_state = 2},
  [9301] = {.lex_state = 7, .external_lex_state = 2},
  [9302] = {.lex_state = 28, .external_lex_state = 3},
  [9303] = {.lex_state = 7, .external_lex_state = 2},
  [9304] = {.lex_state = 7, .external_lex_state = 2},
  [9305] = {.lex_state = 430, .external_lex_state = 2},
  [9306] = {.lex_state = 7, .external_lex_state = 2},
  [9307] = {.lex_state = 7, .external_lex_state = 2},
  [9308] = {.lex_state = 226, .external_lex_state = 2},
  [9309] = {.lex_state = 7, .external_lex_state = 2},
  [9310] = {.lex_state = 225, .external_lex_state = 2},
  [9311] = {.lex_state = 7, .external_lex_state = 2},
  [9312] = {.lex_state = 7, .external_lex_state = 2},
  [9313] = {.lex_state = 430, .external_lex_state = 2},
  [9314] = {.lex_state = 225, .external_lex_state = 2},
  [9315] = {.lex_state = 226, .external_lex_state = 2},
  [9316] = {.lex_state = 225, .external_lex_state = 2},
  [9317] = {.lex_state = 226, .external_lex_state = 2},
  [9318] = {.lex_state = 226, .external_lex_state = 2},
  [9319] = {.lex_state = 7, .external_lex_state = 2},
  [9320] = {.lex_state = 226, .external_lex_state = 2},
  [9321] = {.lex_state = 7, .external_lex_state = 2},
  [9322] = {.lex_state = 7, .external_lex_state = 2},
  [9323] = {.lex_state = 7, .external_lex_state = 2},
  [9324] = {.lex_state = 7, .external_lex_state = 2},
  [9325] = {.lex_state = 7, .external_lex_state = 2},
  [9326] = {.lex_state = 225, .external_lex_state = 2},
  [9327] = {.lex_state = 7, .external_lex_state = 2},
  [9328] = {.lex_state = 216, .external_lex_state = 2},
  [9329] = {.lex_state = 7, .external_lex_state = 2},
  [9330] = {.lex_state = 7, .external_lex_state = 2},
  [9331] = {.lex_state = 7, .external_lex_state = 2},
  [9332] = {.lex_state = 7, .external_lex_state = 2},
  [9333] = {.lex_state = 226, .external_lex_state = 2},
  [9334] = {.lex_state = 7, .external_lex_state = 2},
  [9335] = {.lex_state = 226, .external_lex_state = 2},
  [9336] = {.lex_state = 28, .external_lex_state = 3},
  [9337] = {.lex_state = 7, .external_lex_state = 2},
  [9338] = {.lex_state = 428, .external_lex_state = 2},
  [9339] = {.lex_state = 225, .external_lex_state = 2},
  [9340] = {.lex_state = 7, .external_lex_state = 2},
  [9341] = {.lex_state = 7, .external_lex_state = 2},
  [9342] = {.lex_state = 7, .external_lex_state = 2},
  [9343] = {.lex_state = 432, .external_lex_state = 2},
  [9344] = {.lex_state = 215, .external_lex_state = 2},
  [9345] = {.lex_state = 215, .external_lex_state = 2},
  [9346] = {.lex_state = 215, .external_lex_state = 2},
  [9347] = {.lex_state = 14, .external_lex_state = 2},
  [9348] = {.lex_state = 434, .external_lex_state = 2},
  [9349] = {.lex_state = 216, .external_lex_state = 2},
  [9350] = {.lex_state = 434, .external_lex_state = 2},
  [9351] = {.lex_state = 215, .external_lex_state = 2},
  [9352] = {.lex_state = 434, .external_lex_state = 2},
  [9353] = {.lex_state = 434, .external_lex_state = 2},
  [9354] = {.lex_state = 173, .external_lex_state = 2},
  [9355] = {.lex_state = 426, .external_lex_state = 2},
  [9356] = {.lex_state = 215, .external_lex_state = 2},
  [9357] = {.lex_state = 207, .external_lex_state = 2},
  [9358] = {.lex_state = 434, .external_lex_state = 2},
  [9359] = {.lex_state = 434, .external_lex_state = 2},
  [9360] = {.lex_state = 434, .external_lex_state = 2},
  [9361] = {.lex_state = 434, .external_lex_state = 2},
  [9362] = {.lex_state = 426, .external_lex_state = 2},
  [9363] = {.lex_state = 215, .external_lex_state = 2},
  [9364] = {.lex_state = 215, .external_lex_state = 2},
  [9365] = {.lex_state = 434, .external_lex_state = 2},
  [9366] = {.lex_state = 7, .external_lex_state = 2},
  [9367] = {.lex_state = 434, .external_lex_state = 2},
  [9368] = {.lex_state = 434, .external_lex_state = 2},
  [9369] = {.lex_state = 434, .external_lex_state = 2},
  [9370] = {.lex_state = 434, .external_lex_state = 2},
  [9371] = {.lex_state = 216, .external_lex_state = 2},
  [9372] = {.lex_state = 211, .external_lex_state = 2},
  [9373] = {.lex_state = 216, .external_lex_state = 2},
  [9374] = {.lex_state = 434, .external_lex_state = 2},
  [9375] = {.lex_state = 426, .external_lex_state = 2},
  [9376] = {.lex_state = 434, .external_lex_state = 2},
  [9377] = {.lex_state = 216, .external_lex_state = 2},
  [9378] = {.lex_state = 216, .external_lex_state = 2},
  [9379] = {.lex_state = 216, .external_lex_state = 2},
  [9380] = {.lex_state = 434, .external_lex_state = 2},
  [9381] = {.lex_state = 215, .external_lex_state = 2},
  [9382] = {.lex_state = 215, .external_lex_state = 2},
  [9383] = {.lex_state = 14, .external_lex_state = 2},
  [9384] = {.lex_state = 434, .external_lex_state = 2},
  [9385] = {.lex_state = 434, .external_lex_state = 2},
  [9386] = {.lex_state = 215, .external_lex_state = 2},
  [9387] = {.lex_state = 172, .external_lex_state = 2},
  [9388] = {.lex_state = 434, .external_lex_state = 2},
  [9389] = {.lex_state = 14, .external_lex_state = 2},
  [9390] = {.lex_state = 14, .external_lex_state = 2},
  [9391] = {.lex_state = 215, .external_lex_state = 2},
  [9392] = {.lex_state = 426, .external_lex_state = 2},
  [9393] = {.lex_state = 172, .external_lex_state = 2},
  [9394] = {.lex_state = 14, .external_lex_state = 2},
  [9395] = {.lex_state = 14, .external_lex_state = 2},
  [9396] = {.lex_state = 172, .external_lex_state = 2},
  [9397] = {.lex_state = 432, .external_lex_state = 2},
  [9398] = {.lex_state = 434, .external_lex_state = 2},
  [9399] = {.lex_state = 7, .external_lex_state = 2},
  [9400] = {.lex_state = 215, .external_lex_state = 2},
  [9401] = {.lex_state = 207, .external_lex_state = 2},
  [9402] = {.lex_state = 7, .external_lex_state = 2},
  [9403] = {.lex_state = 426, .external_lex_state = 2},
  [9404] = {.lex_state = 426, .external_lex_state = 2},
  [9405] = {.lex_state = 173, .external_lex_state = 2},
  [9406] = {.lex_state = 215, .external_lex_state = 2},
  [9407] = {.lex_state = 7, .external_lex_state = 2},
  [9408] = {.lex_state = 14, .external_lex_state = 2},
  [9409] = {.lex_state = 14, .external_lex_state = 2},
  [9410] = {.lex_state = 215, .external_lex_state = 2},
  [9411] = {.lex_state = 182, .external_lex_state = 3},
  [9412] = {.lex_state = 434, .external_lex_state = 2},
  [9413] = {.lex_state = 426, .external_lex_state = 2},
  [9414] = {.lex_state = 216, .external_lex_state = 2},
  [9415] = {.lex_state = 434, .external_lex_state = 2},
  [9416] = {.lex_state = 215, .external_lex_state = 2},
  [9417] = {.lex_state = 434, .external_lex_state = 2},
  [9418] = {.lex_state = 215, .external_lex_state = 2},
  [9419] = {.lex_state = 434, .external_lex_state = 2},
  [9420] = {.lex_state = 216, .external_lex_state = 2},
  [9421] = {.lex_state = 14, .external_lex_state = 2},
  [9422] = {.lex_state = 434, .external_lex_state = 2},
  [9423] = {.lex_state = 215, .external_lex_state = 2},
  [9424] = {.lex_state = 215, .external_lex_state = 2},
  [9425] = {.lex_state = 14, .external_lex_state = 2},
  [9426] = {.lex_state = 432, .external_lex_state = 2},
  [9427] = {.lex_state = 434, .external_lex_state = 2},
  [9428] = {.lex_state = 216, .external_lex_state = 2},
  [9429] = {.lex_state = 215, .external_lex_state = 2},
  [9430] = {.lex_state = 215, .external_lex_state = 2},
  [9431] = {.lex_state = 14, .external_lex_state = 2},
  [9432] = {.lex_state = 432, .external_lex_state = 2},
  [9433] = {.lex_state = 14, .external_lex_state = 2},
  [9434] = {.lex_state = 14, .external_lex_state = 2},
  [9435] = {.lex_state = 434, .external_lex_state = 2},
  [9436] = {.lex_state = 215, .external_lex_state = 2},
  [9437] = {.lex_state = 215, .external_lex_state = 2},
  [9438] = {.lex_state = 434, .external_lex_state = 2},
  [9439] = {.lex_state = 434, .external_lex_state = 2},
  [9440] = {.lex_state = 216, .external_lex_state = 2},
  [9441] = {.lex_state = 216, .external_lex_state = 2},
  [9442] = {.lex_state = 426, .external_lex_state = 2},
  [9443] = {.lex_state = 172, .external_lex_state = 2},
  [9444] = {.lex_state = 7, .external_lex_state = 2},
  [9445] = {.lex_state = 216, .external_lex_state = 2},
  [9446] = {.lex_state = 207, .external_lex_state = 2},
  [9447] = {.lex_state = 216, .external_lex_state = 2},
  [9448] = {.lex_state = 173, .external_lex_state = 2},
  [9449] = {.lex_state = 173, .external_lex_state = 2},
  [9450] = {.lex_state = 215, .external_lex_state = 2},
  [9451] = {.lex_state = 215, .external_lex_state = 2},
  [9452] = {.lex_state = 172, .external_lex_state = 2},
  [9453] = {.lex_state = 173, .external_lex_state = 2},
  [9454] = {.lex_state = 426, .external_lex_state = 2},
  [9455] = {.lex_state = 14, .external_lex_state = 2},
  [9456] = {.lex_state = 14, .external_lex_state = 2},
  [9457] = {.lex_state = 182, .external_lex_state = 3},
  [9458] = {.lex_state = 14, .external_lex_state = 2},
  [9459] = {.lex_state = 434, .external_lex_state = 2},
  [9460] = {.lex_state = 432, .external_lex_state = 2},
  [9461] = {.lex_state = 434, .external_lex_state = 2},
  [9462] = {.lex_state = 7, .external_lex_state = 2},
  [9463] = {.lex_state = 216, .external_lex_state = 2},
  [9464] = {.lex_state = 426, .external_lex_state = 2},
  [9465] = {.lex_state = 14, .external_lex_state = 2},
  [9466] = {.lex_state = 216, .external_lex_state = 2},
  [9467] = {.lex_state = 172, .external_lex_state = 2},
  [9468] = {.lex_state = 215, .external_lex_state = 2},
  [9469] = {.lex_state = 215, .external_lex_state = 2},
  [9470] = {.lex_state = 216, .external_lex_state = 2},
  [9471] = {.lex_state = 216, .external_lex_state = 2},
  [9472] = {.lex_state = 216, .external_lex_state = 2},
  [9473] = {.lex_state = 14, .external_lex_state = 2},
  [9474] = {.lex_state = 227, .external_lex_state = 2},
  [9475] = {.lex_state = 216, .external_lex_state = 2},
  [9476] = {.lex_state = 432, .external_lex_state = 2},
  [9477] = {.lex_state = 426, .external_lex_state = 2},
  [9478] = {.lex_state = 215, .external_lex_state = 2},
  [9479] = {.lex_state = 426, .external_lex_state = 2},
  [9480] = {.lex_state = 14, .external_lex_state = 2},
  [9481] = {.lex_state = 7, .external_lex_state = 2},
  [9482] = {.lex_state = 432, .external_lex_state = 2},
  [9483] = {.lex_state = 215, .external_lex_state = 2},
  [9484] = {.lex_state = 14, .external_lex_state = 2},
  [9485] = {.lex_state = 426, .external_lex_state = 2},
  [9486] = {.lex_state = 216, .external_lex_state = 2},
  [9487] = {.lex_state = 216, .external_lex_state = 2},
  [9488] = {.lex_state = 216, .external_lex_state = 2},
  [9489] = {.lex_state = 216, .external_lex_state = 2},
  [9490] = {.lex_state = 216, .external_lex_state = 2},
  [9491] = {.lex_state = 216, .external_lex_state = 2},
  [9492] = {.lex_state = 207, .external_lex_state = 2},
  [9493] = {.lex_state = 432, .external_lex_state = 2},
  [9494] = {.lex_state = 216, .external_lex_state = 2},
  [9495] = {.lex_state = 216, .external_lex_state = 2},
  [9496] = {.lex_state = 426, .external_lex_state = 2},
  [9497] = {.lex_state = 216, .external_lex_state = 2},
  [9498] = {.lex_state = 7, .external_lex_state = 2},
  [9499] = {.lex_state = 215, .external_lex_state = 2},
  [9500] = {.lex_state = 182, .external_lex_state = 3},
  [9501] = {.lex_state = 215, .external_lex_state = 2},
  [9502] = {.lex_state = 216, .external_lex_state = 2},
  [9503] = {.lex_state = 216, .external_lex_state = 2},
  [9504] = {.lex_state = 215, .external_lex_state = 2},
  [9505] = {.lex_state = 216, .external_lex_state = 2},
  [9506] = {.lex_state = 211, .external_lex_state = 2},
  [9507] = {.lex_state = 14, .external_lex_state = 2},
  [9508] = {.lex_state = 215, .external_lex_state = 2},
  [9509] = {.lex_state = 173, .external_lex_state = 2},
  [9510] = {.lex_state = 182, .external_lex_state = 3},
  [9511] = {.lex_state = 9, .external_lex_state = 2},
  [9512] = {.lex_state = 7, .external_lex_state = 2},
  [9513] = {.lex_state = 426, .external_lex_state = 2},
  [9514] = {.lex_state = 426, .external_lex_state = 2},
  [9515] = {.lex_state = 207, .external_lex_state = 2},
  [9516] = {.lex_state = 14, .external_lex_state = 2},
  [9517] = {.lex_state = 216, .external_lex_state = 2},
  [9518] = {.lex_state = 216, .external_lex_state = 2},
  [9519] = {.lex_state = 215, .external_lex_state = 2},
  [9520] = {.lex_state = 426, .external_lex_state = 2},
  [9521] = {.lex_state = 215, .external_lex_state = 2},
  [9522] = {.lex_state = 14, .external_lex_state = 2},
  [9523] = {.lex_state = 216, .external_lex_state = 2},
  [9524] = {.lex_state = 434, .external_lex_state = 2},
  [9525] = {.lex_state = 14, .external_lex_state = 2},
  [9526] = {.lex_state = 16, .external_lex_state = 2},
  [9527] = {.lex_state = 9, .external_lex_state = 2},
  [9528] = {.lex_state = 227, .external_lex_state = 2},
  [9529] = {.lex_state = 227, .external_lex_state = 2},
  [9530] = {.lex_state = 432, .external_lex_state = 2},
  [9531] = {.lex_state = 227, .external_lex_state = 2},
  [9532] = {.lex_state = 15, .external_lex_state = 2},
  [9533] = {.lex_state = 432, .external_lex_state = 2},
  [9534] = {.lex_state = 15, .external_lex_state = 2},
  [9535] = {.lex_state = 227, .external_lex_state = 2},
  [9536] = {.lex_state = 15, .external_lex_state = 2},
  [9537] = {.lex_state = 432, .external_lex_state = 2},
  [9538] = {.lex_state = 16, .external_lex_state = 2},
  [9539] = {.lex_state = 15, .external_lex_state = 2},
  [9540] = {.lex_state = 432, .external_lex_state = 2},
  [9541] = {.lex_state = 432, .external_lex_state = 2},
  [9542] = {.lex_state = 432, .external_lex_state = 2},
  [9543] = {.lex_state = 15, .external_lex_state = 2},
  [9544] = {.lex_state = 15, .external_lex_state = 2},
  [9545] = {.lex_state = 15, .external_lex_state = 2},
  [9546] = {.lex_state = 15, .external_lex_state = 2},
  [9547] = {.lex_state = 421, .external_lex_state = 2},
  [9548] = {.lex_state = 15, .external_lex_state = 2},
  [9549] = {.lex_state = 15, .external_lex_state = 2},
  [9550] = {.lex_state = 15, .external_lex_state = 2},
  [9551] = {.lex_state = 15, .external_lex_state = 2},
  [9552] = {.lex_state = 15, .external_lex_state = 2},
  [9553] = {.lex_state = 227, .external_lex_state = 2},
  [9554] = {.lex_state = 227, .external_lex_state = 2},
  [9555] = {.lex_state = 227, .external_lex_state = 2},
  [9556] = {.lex_state = 227, .external_lex_state = 2},
  [9557] = {.lex_state = 227, .external_lex_state = 2},
  [9558] = {.lex_state = 227, .external_lex_state = 2},
  [9559] = {.lex_state = 227, .external_lex_state = 2},
  [9560] = {.lex_state = 227, .external_lex_state = 2},
  [9561] = {.lex_state = 432, .external_lex_state = 2},
  [9562] = {.lex_state = 227, .external_lex_state = 2},
  [9563] = {.lex_state = 16, .external_lex_state = 2},
  [9564] = {.lex_state = 14, .external_lex_state = 2},
  [9565] = {.lex_state = 227, .external_lex_state = 2},
  [9566] = {.lex_state = 16, .external_lex_state = 2},
  [9567] = {.lex_state = 16, .external_lex_state = 2},
  [9568] = {.lex_state = 9, .external_lex_state = 2},
  [9569] = {.lex_state = 9, .external_lex_state = 2},
  [9570] = {.lex_state = 165, .external_lex_state = 3},
  [9571] = {.lex_state = 16, .external_lex_state = 2},
  [9572] = {.lex_state = 16, .external_lex_state = 2},
  [9573] = {.lex_state = 16, .external_lex_state = 2},
  [9574] = {.lex_state = 432, .external_lex_state = 2},
  [9575] = {.lex_state = 220, .external_lex_state = 2},
  [9576] = {.lex_state = 16, .external_lex_state = 2},
  [9577] = {.lex_state = 16, .external_lex_state = 2},
  [9578] = {.lex_state = 432, .external_lex_state = 2},
  [9579] = {.lex_state = 16, .external_lex_state = 2},
  [9580] = {.lex_state = 16, .external_lex_state = 2},
  [9581] = {.lex_state = 9, .external_lex_state = 2},
  [9582] = {.lex_state = 16, .external_lex_state = 2},
  [9583] = {.lex_state = 16, .external_lex_state = 2},
  [9584] = {.lex_state = 9, .external_lex_state = 2},
  [9585] = {.lex_state = 9, .external_lex_state = 2},
  [9586] = {.lex_state = 16, .external_lex_state = 2},
  [9587] = {.lex_state = 16, .external_lex_state = 2},
  [9588] = {.lex_state = 16, .external_lex_state = 2},
  [9589] = {.lex_state = 172, .external_lex_state = 2},
  [9590] = {.lex_state = 14, .external_lex_state = 2},
  [9591] = {.lex_state = 9, .external_lex_state = 2},
  [9592] = {.lex_state = 432, .external_lex_state = 2},
  [9593] = {.lex_state = 9, .external_lex_state = 2},
  [9594] = {.lex_state = 9, .external_lex_state = 2},
  [9595] = {.lex_state = 14, .external_lex_state = 2},
  [9596] = {.lex_state = 14, .external_lex_state = 2},
  [9597] = {.lex_state = 16, .external_lex_state = 2},
  [9598] = {.lex_state = 211, .external_lex_state = 2},
  [9599] = {.lex_state = 14, .external_lex_state = 2},
  [9600] = {.lex_state = 432, .external_lex_state = 2},
  [9601] = {.lex_state = 14, .external_lex_state = 2},
  [9602] = {.lex_state = 14, .external_lex_state = 2},
  [9603] = {.lex_state = 14, .external_lex_state = 2},
  [9604] = {.lex_state = 420, .external_lex_state = 2},
  [9605] = {.lex_state = 14, .external_lex_state = 2},
  [9606] = {.lex_state = 14, .external_lex_state = 2},
  [9607] = {.lex_state = 426, .external_lex_state = 2},
  [9608] = {.lex_state = 199, .external_lex_state = 2},
  [9609] = {.lex_state = 16, .external_lex_state = 2},
  [9610] = {.lex_state = 216, .external_lex_state = 2},
  [9611] = {.lex_state = 14, .external_lex_state = 2},
  [9612] = {.lex_state = 14, .external_lex_state = 2},
  [9613] = {.lex_state = 14, .external_lex_state = 2},
  [9614] = {.lex_state = 9, .external_lex_state = 2},
  [9615] = {.lex_state = 9, .external_lex_state = 2},
  [9616] = {.lex_state = 9, .external_lex_state = 2},
  [9617] = {.lex_state = 14, .external_lex_state = 2},
  [9618] = {.lex_state = 420, .external_lex_state = 2},
  [9619] = {.lex_state = 16, .external_lex_state = 2},
  [9620] = {.lex_state = 14, .external_lex_state = 2},
  [9621] = {.lex_state = 9, .external_lex_state = 2},
  [9622] = {.lex_state = 16, .external_lex_state = 2},
  [9623] = {.lex_state = 16, .external_lex_state = 2},
  [9624] = {.lex_state = 426, .external_lex_state = 2},
  [9625] = {.lex_state = 227, .external_lex_state = 2},
  [9626] = {.lex_state = 16, .external_lex_state = 2},
  [9627] = {.lex_state = 9, .external_lex_state = 2},
  [9628] = {.lex_state = 227, .external_lex_state = 2},
  [9629] = {.lex_state = 16, .external_lex_state = 2},
  [9630] = {.lex_state = 16, .external_lex_state = 2},
  [9631] = {.lex_state = 16, .external_lex_state = 2},
  [9632] = {.lex_state = 16, .external_lex_state = 2},
  [9633] = {.lex_state = 227, .external_lex_state = 2},
  [9634] = {.lex_state = 9, .external_lex_state = 2},
  [9635] = {.lex_state = 9, .external_lex_state = 2},
  [9636] = {.lex_state = 9, .external_lex_state = 2},
  [9637] = {.lex_state = 227, .external_lex_state = 2},
  [9638] = {.lex_state = 432, .external_lex_state = 2},
  [9639] = {.lex_state = 16, .external_lex_state = 2},
  [9640] = {.lex_state = 9, .external_lex_state = 2},
  [9641] = {.lex_state = 16, .external_lex_state = 2},
  [9642] = {.lex_state = 9, .external_lex_state = 2},
  [9643] = {.lex_state = 227, .external_lex_state = 2},
  [9644] = {.lex_state = 16, .external_lex_state = 2},
  [9645] = {.lex_state = 16, .external_lex_state = 2},
  [9646] = {.lex_state = 9, .external_lex_state = 2},
  [9647] = {.lex_state = 16, .external_lex_state = 2},
  [9648] = {.lex_state = 14, .external_lex_state = 2},
  [9649] = {.lex_state = 16, .external_lex_state = 2},
  [9650] = {.lex_state = 9, .external_lex_state = 2},
  [9651] = {.lex_state = 9, .external_lex_state = 2},
  [9652] = {.lex_state = 9, .external_lex_state = 2},
  [9653] = {.lex_state = 227, .external_lex_state = 2},
  [9654] = {.lex_state = 9, .external_lex_state = 2},
  [9655] = {.lex_state = 9, .external_lex_state = 2},
  [9656] = {.lex_state = 9, .external_lex_state = 2},
  [9657] = {.lex_state = 16, .external_lex_state = 2},
  [9658] = {.lex_state = 173, .external_lex_state = 2},
  [9659] = {.lex_state = 16, .external_lex_state = 2},
  [9660] = {.lex_state = 9, .external_lex_state = 2},
  [9661] = {.lex_state = 16, .external_lex_state = 2},
  [9662] = {.lex_state = 16, .external_lex_state = 2},
  [9663] = {.lex_state = 9, .external_lex_state = 2},
  [9664] = {.lex_state = 9, .external_lex_state = 2},
  [9665] = {.lex_state = 9, .external_lex_state = 2},
  [9666] = {.lex_state = 16, .external_lex_state = 2},
  [9667] = {.lex_state = 227, .external_lex_state = 2},
  [9668] = {.lex_state = 9, .external_lex_state = 2},
  [9669] = {.lex_state = 16, .external_lex_state = 2},
  [9670] = {.lex_state = 227, .external_lex_state = 2},
  [9671] = {.lex_state = 14, .external_lex_state = 2},
  [9672] = {.lex_state = 16, .external_lex_state = 2},
  [9673] = {.lex_state = 16, .external_lex_state = 2},
  [9674] = {.lex_state = 16, .external_lex_state = 2},
  [9675] = {.lex_state = 16, .external_lex_state = 2},
  [9676] = {.lex_state = 9, .external_lex_state = 2},
  [9677] = {.lex_state = 9, .external_lex_state = 2},
  [9678] = {.lex_state = 16, .external_lex_state = 2},
  [9679] = {.lex_state = 9, .external_lex_state = 2},
  [9680] = {.lex_state = 16, .external_lex_state = 2},
  [9681] = {.lex_state = 16, .external_lex_state = 2},
  [9682] = {.lex_state = 9, .external_lex_state = 2},
  [9683] = {.lex_state = 15, .external_lex_state = 2},
  [9684] = {.lex_state = 420, .external_lex_state = 2},
  [9685] = {.lex_state = 426, .external_lex_state = 2},
  [9686] = {.lex_state = 16, .external_lex_state = 2},
  [9687] = {.lex_state = 15, .external_lex_state = 2},
  [9688] = {.lex_state = 426, .external_lex_state = 2},
  [9689] = {.lex_state = 9, .external_lex_state = 2},
  [9690] = {.lex_state = 426, .external_lex_state = 2},
  [9691] = {.lex_state = 9, .external_lex_state = 2},
  [9692] = {.lex_state = 16, .external_lex_state = 2},
  [9693] = {.lex_state = 211, .external_lex_state = 2},
  [9694] = {.lex_state = 9, .external_lex_state = 2},
  [9695] = {.lex_state = 211, .external_lex_state = 2},
  [9696] = {.lex_state = 16, .external_lex_state = 2},
  [9697] = {.lex_state = 9, .external_lex_state = 2},
  [9698] = {.lex_state = 9, .external_lex_state = 2},
  [9699] = {.lex_state = 421, .external_lex_state = 2},
  [9700] = {.lex_state = 9, .external_lex_state = 2},
  [9701] = {.lex_state = 421, .external_lex_state = 2},
  [9702] = {.lex_state = 16, .external_lex_state = 2},
  [9703] = {.lex_state = 16, .external_lex_state = 2},
  [9704] = {.lex_state = 420, .external_lex_state = 2},
  [9705] = {.lex_state = 428, .external_lex_state = 2},
  [9706] = {.lex_state = 15, .external_lex_state = 2},
  [9707] = {.lex_state = 432, .external_lex_state = 2},
  [9708] = {.lex_state = 211, .external_lex_state = 2},
  [9709] = {.lex_state = 9, .external_lex_state = 2},
  [9710] = {.lex_state = 9, .external_lex_state = 2},
  [9711] = {.lex_state = 222, .external_lex_state = 2},
  [9712] = {.lex_state = 420, .external_lex_state = 2},
  [9713] = {.lex_state = 432, .external_lex_state = 2},
  [9714] = {.lex_state = 227, .external_lex_state = 2},
  [9715] = {.lex_state = 421, .external_lex_state = 2},
  [9716] = {.lex_state = 432, .external_lex_state = 2},
  [9717] = {.lex_state = 16, .external_lex_state = 2},
  [9718] = {.lex_state = 9, .external_lex_state = 2},
  [9719] = {.lex_state = 16, .external_lex_state = 2},
  [9720] = {.lex_state = 16, .external_lex_state = 2},
  [9721] = {.lex_state = 432, .external_lex_state = 2},
  [9722] = {.lex_state = 16, .external_lex_state = 2},
  [9723] = {.lex_state = 9, .external_lex_state = 2},
  [9724] = {.lex_state = 432, .external_lex_state = 2},
  [9725] = {.lex_state = 9, .external_lex_state = 2},
  [9726] = {.lex_state = 15, .external_lex_state = 2},
  [9727] = {.lex_state = 16, .external_lex_state = 2},
  [9728] = {.lex_state = 426, .external_lex_state = 2},
  [9729] = {.lex_state = 16, .external_lex_state = 2},
  [9730] = {.lex_state = 432, .external_lex_state = 2},
  [9731] = {.lex_state = 432, .external_lex_state = 2},
  [9732] = {.lex_state = 432, .external_lex_state = 2},
  [9733] = {.lex_state = 16, .external_lex_state = 2},
  [9734] = {.lex_state = 426, .external_lex_state = 2},
  [9735] = {.lex_state = 426, .external_lex_state = 2},
  [9736] = {.lex_state = 16, .external_lex_state = 2},
  [9737] = {.lex_state = 16, .external_lex_state = 2},
  [9738] = {.lex_state = 9, .external_lex_state = 2},
  [9739] = {.lex_state = 16, .external_lex_state = 2},
  [9740] = {.lex_state = 16, .external_lex_state = 2},
  [9741] = {.lex_state = 16, .external_lex_state = 2},
  [9742] = {.lex_state = 426, .external_lex_state = 2},
  [9743] = {.lex_state = 9, .external_lex_state = 2},
  [9744] = {.lex_state = 432, .external_lex_state = 2},
  [9745] = {.lex_state = 9, .external_lex_state = 2},
  [9746] = {.lex_state = 432, .external_lex_state = 2},
  [9747] = {.lex_state = 432, .external_lex_state = 2},
  [9748] = {.lex_state = 14, .external_lex_state = 2},
  [9749] = {.lex_state = 9, .external_lex_state = 2},
  [9750] = {.lex_state = 9, .external_lex_state = 2},
  [9751] = {.lex_state = 9, .external_lex_state = 2},
  [9752] = {.lex_state = 16, .external_lex_state = 2},
  [9753] = {.lex_state = 14, .external_lex_state = 2},
  [9754] = {.lex_state = 9, .external_lex_state = 2},
  [9755] = {.lex_state = 16, .external_lex_state = 2},
  [9756] = {.lex_state = 16, .external_lex_state = 2},
  [9757] = {.lex_state = 432, .external_lex_state = 2},
  [9758] = {.lex_state = 432, .external_lex_state = 2},
  [9759] = {.lex_state = 432, .external_lex_state = 2},
  [9760] = {.lex_state = 211, .external_lex_state = 2},
  [9761] = {.lex_state = 9, .external_lex_state = 2},
  [9762] = {.lex_state = 211, .external_lex_state = 2},
  [9763] = {.lex_state = 173, .external_lex_state = 2},
  [9764] = {.lex_state = 9, .external_lex_state = 2},
  [9765] = {.lex_state = 215, .external_lex_state = 2},
  [9766] = {.lex_state = 426, .external_lex_state = 2},
  [9767] = {.lex_state = 432, .external_lex_state = 2},
  [9768] = {.lex_state = 220, .external_lex_state = 2},
  [9769] = {.lex_state = 432, .external_lex_state = 2},
  [9770] = {.lex_state = 16, .external_lex_state = 2},
  [9771] = {.lex_state = 9, .external_lex_state = 2},
  [9772] = {.lex_state = 16, .external_lex_state = 2},
  [9773] = {.lex_state = 16, .external_lex_state = 2},
  [9774] = {.lex_state = 9, .external_lex_state = 2},
  [9775] = {.lex_state = 227, .external_lex_state = 2},
  [9776] = {.lex_state = 9, .external_lex_state = 2},
  [9777] = {.lex_state = 9, .external_lex_state = 2},
  [9778] = {.lex_state = 9, .external_lex_state = 2},
  [9779] = {.lex_state = 9, .external_lex_state = 2},
  [9780] = {.lex_state = 227, .external_lex_state = 2},
  [9781] = {.lex_state = 9, .external_lex_state = 2},
  [9782] = {.lex_state = 15, .external_lex_state = 2},
  [9783] = {.lex_state = 222, .external_lex_state = 2},
  [9784] = {.lex_state = 16, .external_lex_state = 2},
  [9785] = {.lex_state = 9, .external_lex_state = 2},
  [9786] = {.lex_state = 432, .external_lex_state = 2},
  [9787] = {.lex_state = 426, .external_lex_state = 2},
  [9788] = {.lex_state = 227, .external_lex_state = 2},
  [9789] = {.lex_state = 15, .external_lex_state = 2},
  [9790] = {.lex_state = 211, .external_lex_state = 2},
  [9791] = {.lex_state = 227, .external_lex_state = 2},
  [9792] = {.lex_state = 227, .external_lex_state = 2},
  [9793] = {.lex_state = 211, .external_lex_state = 2},
  [9794] = {.lex_state = 426, .external_lex_state = 2},
  [9795] = {.lex_state = 227, .external_lex_state = 2},
  [9796] = {.lex_state = 16, .external_lex_state = 2},
  [9797] = {.lex_state = 16, .external_lex_state = 2},
  [9798] = {.lex_state = 9, .external_lex_state = 2},
  [9799] = {.lex_state = 9, .external_lex_state = 2},
  [9800] = {.lex_state = 9, .external_lex_state = 2},
  [9801] = {.lex_state = 9, .external_lex_state = 2},
  [9802] = {.lex_state = 9, .external_lex_state = 2},
  [9803] = {.lex_state = 227, .external_lex_state = 2},
  [9804] = {.lex_state = 166, .external_lex_state = 3},
  [9805] = {.lex_state = 9, .external_lex_state = 2},
  [9806] = {.lex_state = 9, .external_lex_state = 2},
  [9807] = {.lex_state = 9, .external_lex_state = 2},
  [9808] = {.lex_state = 9, .external_lex_state = 2},
  [9809] = {.lex_state = 9, .external_lex_state = 2},
  [9810] = {.lex_state = 9, .external_lex_state = 2},
  [9811] = {.lex_state = 16, .external_lex_state = 2},
  [9812] = {.lex_state = 9, .external_lex_state = 2},
  [9813] = {.lex_state = 16, .external_lex_state = 2},
  [9814] = {.lex_state = 16, .external_lex_state = 2},
  [9815] = {.lex_state = 426, .external_lex_state = 2},
  [9816] = {.lex_state = 9, .external_lex_state = 2},
  [9817] = {.lex_state = 7, .external_lex_state = 2},
  [9818] = {.lex_state = 9, .external_lex_state = 2},
  [9819] = {.lex_state = 9, .external_lex_state = 2},
  [9820] = {.lex_state = 227, .external_lex_state = 2},
  [9821] = {.lex_state = 9, .external_lex_state = 2},
  [9822] = {.lex_state = 9, .external_lex_state = 2},
  [9823] = {.lex_state = 426, .external_lex_state = 2},
  [9824] = {.lex_state = 426, .external_lex_state = 2},
  [9825] = {.lex_state = 420, .external_lex_state = 2},
  [9826] = {.lex_state = 46, .external_lex_state = 3},
  [9827] = {.lex_state = 9, .external_lex_state = 2},
  [9828] = {.lex_state = 9, .external_lex_state = 2},
  [9829] = {.lex_state = 9, .external_lex_state = 2},
  [9830] = {.lex_state = 421, .external_lex_state = 2},
  [9831] = {.lex_state = 172, .external_lex_state = 2},
  [9832] = {.lex_state = 9, .external_lex_state = 2},
  [9833] = {.lex_state = 9, .external_lex_state = 2},
  [9834] = {.lex_state = 9, .external_lex_state = 2},
  [9835] = {.lex_state = 16, .external_lex_state = 2},
  [9836] = {.lex_state = 432, .external_lex_state = 2},
  [9837] = {.lex_state = 9, .external_lex_state = 2},
  [9838] = {.lex_state = 432, .external_lex_state = 2},
  [9839] = {.lex_state = 9, .external_lex_state = 2},
  [9840] = {.lex_state = 9, .external_lex_state = 2},
  [9841] = {.lex_state = 9, .external_lex_state = 2},
  [9842] = {.lex_state = 9, .external_lex_state = 2},
  [9843] = {.lex_state = 9, .external_lex_state = 2},
  [9844] = {.lex_state = 9, .external_lex_state = 2},
  [9845] = {.lex_state = 421, .external_lex_state = 2},
  [9846] = {.lex_state = 9, .external_lex_state = 2},
  [9847] = {.lex_state = 9, .external_lex_state = 2},
  [9848] = {.lex_state = 16, .external_lex_state = 2},
  [9849] = {.lex_state = 9, .external_lex_state = 2},
  [9850] = {.lex_state = 9, .external_lex_state = 2},
  [9851] = {.lex_state = 9, .external_lex_state = 2},
  [9852] = {.lex_state = 227, .external_lex_state = 2},
  [9853] = {.lex_state = 420, .external_lex_state = 2},
  [9854] = {.lex_state = 200, .external_lex_state = 2},
  [9855] = {.lex_state = 9, .external_lex_state = 2},
  [9856] = {.lex_state = 432, .external_lex_state = 2},
  [9857] = {.lex_state = 16, .external_lex_state = 2},
  [9858] = {.lex_state = 16, .external_lex_state = 2},
  [9859] = {.lex_state = 16, .external_lex_state = 2},
  [9860] = {.lex_state = 16, .external_lex_state = 2},
  [9861] = {.lex_state = 9, .external_lex_state = 2},
  [9862] = {.lex_state = 9, .external_lex_state = 2},
  [9863] = {.lex_state = 16, .external_lex_state = 2},
  [9864] = {.lex_state = 432, .external_lex_state = 2},
  [9865] = {.lex_state = 420, .external_lex_state = 2},
  [9866] = {.lex_state = 432, .external_lex_state = 2},
  [9867] = {.lex_state = 9, .external_lex_state = 2},
  [9868] = {.lex_state = 16, .external_lex_state = 2},
  [9869] = {.lex_state = 9, .external_lex_state = 2},
  [9870] = {.lex_state = 7, .external_lex_state = 2},
  [9871] = {.lex_state = 15, .external_lex_state = 2},
  [9872] = {.lex_state = 211, .external_lex_state = 2},
  [9873] = {.lex_state = 7, .external_lex_state = 2},
  [9874] = {.lex_state = 221, .external_lex_state = 2},
  [9875] = {.lex_state = 15, .external_lex_state = 2},
  [9876] = {.lex_state = 221, .external_lex_state = 2},
  [9877] = {.lex_state = 221, .external_lex_state = 2},
  [9878] = {.lex_state = 7, .external_lex_state = 2},
  [9879] = {.lex_state = 216, .external_lex_state = 2},
  [9880] = {.lex_state = 15, .external_lex_state = 2},
  [9881] = {.lex_state = 7, .external_lex_state = 2},
  [9882] = {.lex_state = 7, .external_lex_state = 2},
  [9883] = {.lex_state = 15, .external_lex_state = 2},
  [9884] = {.lex_state = 7, .external_lex_state = 2},
  [9885] = {.lex_state = 15, .external_lex_state = 2},
  [9886] = {.lex_state = 15, .external_lex_state = 2},
  [9887] = {.lex_state = 7, .external_lex_state = 2},
  [9888] = {.lex_state = 7, .external_lex_state = 2},
  [9889] = {.lex_state = 7, .external_lex_state = 2},
  [9890] = {.lex_state = 7, .external_lex_state = 2},
  [9891] = {.lex_state = 15, .external_lex_state = 2},
  [9892] = {.lex_state = 28, .external_lex_state = 3},
  [9893] = {.lex_state = 15, .external_lex_state = 2},
  [9894] = {.lex_state = 426, .external_lex_state = 2},
  [9895] = {.lex_state = 28, .external_lex_state = 3},
  [9896] = {.lex_state = 7, .external_lex_state = 2},
  [9897] = {.lex_state = 7, .external_lex_state = 2},
  [9898] = {.lex_state = 215, .external_lex_state = 2},
  [9899] = {.lex_state = 204, .external_lex_state = 2},
  [9900] = {.lex_state = 7, .external_lex_state = 2},
  [9901] = {.lex_state = 7, .external_lex_state = 2},
  [9902] = {.lex_state = 7, .external_lex_state = 2},
  [9903] = {.lex_state = 7, .external_lex_state = 2},
  [9904] = {.lex_state = 30, .external_lex_state = 2},
  [9905] = {.lex_state = 172, .external_lex_state = 2},
  [9906] = {.lex_state = 7, .external_lex_state = 2},
  [9907] = {.lex_state = 420, .external_lex_state = 3},
  [9908] = {.lex_state = 7, .external_lex_state = 2},
  [9909] = {.lex_state = 7, .external_lex_state = 2},
  [9910] = {.lex_state = 7, .external_lex_state = 2},
  [9911] = {.lex_state = 7, .external_lex_state = 2},
  [9912] = {.lex_state = 7, .external_lex_state = 2},
  [9913] = {.lex_state = 7, .external_lex_state = 2},
  [9914] = {.lex_state = 7, .external_lex_state = 2},
  [9915] = {.lex_state = 7, .external_lex_state = 2},
  [9916] = {.lex_state = 426, .external_lex_state = 2},
  [9917] = {.lex_state = 15, .external_lex_state = 2},
  [9918] = {.lex_state = 7, .external_lex_state = 2},
  [9919] = {.lex_state = 7, .external_lex_state = 2},
  [9920] = {.lex_state = 432, .external_lex_state = 2},
  [9921] = {.lex_state = 7, .external_lex_state = 2},
  [9922] = {.lex_state = 7, .external_lex_state = 2},
  [9923] = {.lex_state = 15, .external_lex_state = 2},
  [9924] = {.lex_state = 426, .external_lex_state = 2},
  [9925] = {.lex_state = 7, .external_lex_state = 2},
  [9926] = {.lex_state = 15, .external_lex_state = 2},
  [9927] = {.lex_state = 7, .external_lex_state = 2},
  [9928] = {.lex_state = 7, .external_lex_state = 2},
  [9929] = {.lex_state = 7, .external_lex_state = 2},
  [9930] = {.lex_state = 211, .external_lex_state = 2},
  [9931] = {.lex_state = 7, .external_lex_state = 2},
  [9932] = {.lex_state = 7, .external_lex_state = 2},
  [9933] = {.lex_state = 7, .external_lex_state = 2},
  [9934] = {.lex_state = 7, .external_lex_state = 2},
  [9935] = {.lex_state = 223, .external_lex_state = 2},
  [9936] = {.lex_state = 7, .external_lex_state = 2},
  [9937] = {.lex_state = 7, .external_lex_state = 2},
  [9938] = {.lex_state = 7, .external_lex_state = 2},
  [9939] = {.lex_state = 7, .external_lex_state = 2},
  [9940] = {.lex_state = 7, .external_lex_state = 2},
  [9941] = {.lex_state = 7, .external_lex_state = 2},
  [9942] = {.lex_state = 7, .external_lex_state = 2},
  [9943] = {.lex_state = 7, .external_lex_state = 2},
  [9944] = {.lex_state = 7, .external_lex_state = 2},
  [9945] = {.lex_state = 7, .external_lex_state = 2},
  [9946] = {.lex_state = 7, .external_lex_state = 2},
  [9947] = {.lex_state = 215, .external_lex_state = 2},
  [9948] = {.lex_state = 426, .external_lex_state = 2},
  [9949] = {.lex_state = 216, .external_lex_state = 2},
  [9950] = {.lex_state = 7, .external_lex_state = 2},
  [9951] = {.lex_state = 211, .external_lex_state = 2},
  [9952] = {.lex_state = 7, .external_lex_state = 2},
  [9953] = {.lex_state = 7, .external_lex_state = 2},
  [9954] = {.lex_state = 7, .external_lex_state = 2},
  [9955] = {.lex_state = 426, .external_lex_state = 2},
  [9956] = {.lex_state = 7, .external_lex_state = 2},
  [9957] = {.lex_state = 30, .external_lex_state = 2},
  [9958] = {.lex_state = 7, .external_lex_state = 2},
  [9959] = {.lex_state = 7, .external_lex_state = 2},
  [9960] = {.lex_state = 426, .external_lex_state = 2},
  [9961] = {.lex_state = 7, .external_lex_state = 2},
  [9962] = {.lex_state = 421, .external_lex_state = 2},
  [9963] = {.lex_state = 7, .external_lex_state = 2},
  [9964] = {.lex_state = 173, .external_lex_state = 2},
  [9965] = {.lex_state = 211, .external_lex_state = 2},
  [9966] = {.lex_state = 7, .external_lex_state = 2},
  [9967] = {.lex_state = 7, .external_lex_state = 2},
  [9968] = {.lex_state = 211, .external_lex_state = 2},
  [9969] = {.lex_state = 426, .external_lex_state = 2},
  [9970] = {.lex_state = 7, .external_lex_state = 2},
  [9971] = {.lex_state = 216, .external_lex_state = 2},
  [9972] = {.lex_state = 203, .external_lex_state = 2},
  [9973] = {.lex_state = 30, .external_lex_state = 2},
  [9974] = {.lex_state = 7, .external_lex_state = 2},
  [9975] = {.lex_state = 7, .external_lex_state = 2},
  [9976] = {.lex_state = 211, .external_lex_state = 2},
  [9977] = {.lex_state = 7, .external_lex_state = 2},
  [9978] = {.lex_state = 28, .external_lex_state = 3},
  [9979] = {.lex_state = 223, .external_lex_state = 2},
  [9980] = {.lex_state = 28, .external_lex_state = 3},
  [9981] = {.lex_state = 223, .external_lex_state = 2},
  [9982] = {.lex_state = 426, .external_lex_state = 2},
  [9983] = {.lex_state = 7, .external_lex_state = 2},
  [9984] = {.lex_state = 211, .external_lex_state = 2},
  [9985] = {.lex_state = 7, .external_lex_state = 2},
  [9986] = {.lex_state = 211, .external_lex_state = 2},
  [9987] = {.lex_state = 426, .external_lex_state = 2},
  [9988] = {.lex_state = 30, .external_lex_state = 2},
  [9989] = {.lex_state = 173, .external_lex_state = 2},
  [9990] = {.lex_state = 211, .external_lex_state = 2},
  [9991] = {.lex_state = 7, .external_lex_state = 2},
  [9992] = {.lex_state = 7, .external_lex_state = 2},
  [9993] = {.lex_state = 426, .external_lex_state = 2},
  [9994] = {.lex_state = 7, .external_lex_state = 2},
  [9995] = {.lex_state = 211, .external_lex_state = 2},
  [9996] = {.lex_state = 7, .external_lex_state = 2},
  [9997] = {.lex_state = 7, .external_lex_state = 2},
  [9998] = {.lex_state = 426, .external_lex_state = 2},
  [9999] = {.lex_state = 7, .external_lex_state = 2},
  [10000] = {.lex_state = 7, .external_lex_state = 2},
  [10001] = {.lex_state = 7, .external_lex_state = 2},
  [10002] = {.lex_state = 173, .external_lex_state = 2},
  [10003] = {.lex_state = 7, .external_lex_state = 2},
  [10004] = {.lex_state = 7, .external_lex_state = 2},
  [10005] = {.lex_state = 7, .external_lex_state = 2},
  [10006] = {.lex_state = 7, .external_lex_state = 2},
  [10007] = {.lex_state = 7, .external_lex_state = 2},
  [10008] = {.lex_state = 7, .external_lex_state = 2},
  [10009] = {.lex_state = 7, .external_lex_state = 2},
  [10010] = {.lex_state = 216, .external_lex_state = 2},
  [10011] = {.lex_state = 426, .external_lex_state = 2},
  [10012] = {.lex_state = 7, .external_lex_state = 2},
  [10013] = {.lex_state = 7, .external_lex_state = 2},
  [10014] = {.lex_state = 221, .external_lex_state = 2},
  [10015] = {.lex_state = 211, .external_lex_state = 2},
  [10016] = {.lex_state = 426, .external_lex_state = 2},
  [10017] = {.lex_state = 173, .external_lex_state = 2},
  [10018] = {.lex_state = 173, .external_lex_state = 2},
  [10019] = {.lex_state = 15, .external_lex_state = 2},
  [10020] = {.lex_state = 211, .external_lex_state = 2},
  [10021] = {.lex_state = 30, .external_lex_state = 2},
  [10022] = {.lex_state = 211, .external_lex_state = 2},
  [10023] = {.lex_state = 30, .external_lex_state = 2},
  [10024] = {.lex_state = 433, .external_lex_state = 2},
  [10025] = {.lex_state = 7, .external_lex_state = 2},
  [10026] = {.lex_state = 211, .external_lex_state = 2},
  [10027] = {.lex_state = 211, .external_lex_state = 2},
  [10028] = {.lex_state = 211, .external_lex_state = 2},
  [10029] = {.lex_state = 420, .external_lex_state = 3},
  [10030] = {.lex_state = 426, .external_lex_state = 2},
  [10031] = {.lex_state = 28, .external_lex_state = 3},
  [10032] = {.lex_state = 211, .external_lex_state = 2},
  [10033] = {.lex_state = 7, .external_lex_state = 2},
  [10034] = {.lex_state = 7, .external_lex_state = 2},
  [10035] = {.lex_state = 173, .external_lex_state = 2},
  [10036] = {.lex_state = 223, .external_lex_state = 2},
  [10037] = {.lex_state = 211, .external_lex_state = 2},
  [10038] = {.lex_state = 172, .external_lex_state = 2},
  [10039] = {.lex_state = 223, .external_lex_state = 2},
  [10040] = {.lex_state = 426, .external_lex_state = 2},
  [10041] = {.lex_state = 211, .external_lex_state = 2},
  [10042] = {.lex_state = 15, .external_lex_state = 2},
  [10043] = {.lex_state = 426, .external_lex_state = 2},
  [10044] = {.lex_state = 426, .external_lex_state = 2},
  [10045] = {.lex_state = 211, .external_lex_state = 2},
  [10046] = {.lex_state = 215, .external_lex_state = 2},
  [10047] = {.lex_state = 7, .external_lex_state = 2},
  [10048] = {.lex_state = 426, .external_lex_state = 2},
  [10049] = {.lex_state = 15, .external_lex_state = 2},
  [10050] = {.lex_state = 211, .external_lex_state = 2},
  [10051] = {.lex_state = 172, .external_lex_state = 2},
  [10052] = {.lex_state = 221, .external_lex_state = 2},
  [10053] = {.lex_state = 201, .external_lex_state = 2},
  [10054] = {.lex_state = 211, .external_lex_state = 2},
  [10055] = {.lex_state = 7, .external_lex_state = 2},
  [10056] = {.lex_state = 7, .external_lex_state = 2},
  [10057] = {.lex_state = 7, .external_lex_state = 2},
  [10058] = {.lex_state = 426, .external_lex_state = 2},
  [10059] = {.lex_state = 7, .external_lex_state = 2},
  [10060] = {.lex_state = 211, .external_lex_state = 2},
  [10061] = {.lex_state = 172, .external_lex_state = 2},
  [10062] = {.lex_state = 28, .external_lex_state = 3},
  [10063] = {.lex_state = 426, .external_lex_state = 2},
  [10064] = {.lex_state = 223, .external_lex_state = 2},
  [10065] = {.lex_state = 7, .external_lex_state = 2},
  [10066] = {.lex_state = 215, .external_lex_state = 2},
  [10067] = {.lex_state = 7, .external_lex_state = 2},
  [10068] = {.lex_state = 216, .external_lex_state = 2},
  [10069] = {.lex_state = 7, .external_lex_state = 2},
  [10070] = {.lex_state = 211, .external_lex_state = 2},
  [10071] = {.lex_state = 7, .external_lex_state = 2},
  [10072] = {.lex_state = 202, .external_lex_state = 2},
  [10073] = {.lex_state = 7, .external_lex_state = 2},
  [10074] = {.lex_state = 432, .external_lex_state = 2},
  [10075] = {.lex_state = 211, .external_lex_state = 2},
  [10076] = {.lex_state = 211, .external_lex_state = 2},
  [10077] = {.lex_state = 7, .external_lex_state = 2},
  [10078] = {.lex_state = 433, .external_lex_state = 2},
  [10079] = {.lex_state = 426, .external_lex_state = 2},
  [10080] = {.lex_state = 216, .external_lex_state = 2},
  [10081] = {.lex_state = 176, .external_lex_state = 3},
  [10082] = {.lex_state = 211, .external_lex_state = 2},
  [10083] = {.lex_state = 7, .external_lex_state = 2},
  [10084] = {.lex_state = 172, .external_lex_state = 2},
  [10085] = {.lex_state = 7, .external_lex_state = 2},
  [10086] = {.lex_state = 7, .external_lex_state = 2},
  [10087] = {.lex_state = 7, .external_lex_state = 2},
  [10088] = {.lex_state = 7, .external_lex_state = 2},
  [10089] = {.lex_state = 211, .external_lex_state = 2},
  [10090] = {.lex_state = 211, .external_lex_state = 2},
  [10091] = {.lex_state = 7, .external_lex_state = 2},
  [10092] = {.lex_state = 7, .external_lex_state = 2},
  [10093] = {.lex_state = 211, .external_lex_state = 2},
  [10094] = {.lex_state = 215, .external_lex_state = 2},
  [10095] = {.lex_state = 215, .external_lex_state = 2},
  [10096] = {.lex_state = 421, .external_lex_state = 2},
  [10097] = {.lex_state = 211, .external_lex_state = 2},
  [10098] = {.lex_state = 211, .external_lex_state = 2},
  [10099] = {.lex_state = 7, .external_lex_state = 2},
  [10100] = {.lex_state = 28, .external_lex_state = 3},
  [10101] = {.lex_state = 7, .external_lex_state = 2},
  [10102] = {.lex_state = 7, .external_lex_state = 2},
  [10103] = {.lex_state = 7, .external_lex_state = 2},
  [10104] = {.lex_state = 211, .external_lex_state = 2},
  [10105] = {.lex_state = 211, .external_lex_state = 2},
  [10106] = {.lex_state = 172, .external_lex_state = 2},
  [10107] = {.lex_state = 221, .external_lex_state = 2},
  [10108] = {.lex_state = 15, .external_lex_state = 2},
  [10109] = {.lex_state = 7, .external_lex_state = 2},
  [10110] = {.lex_state = 6, .external_lex_state = 3},
  [10111] = {.lex_state = 208, .external_lex_state = 2},
  [10112] = {.lex_state = 6, .external_lex_state = 3},
  [10113] = {.lex_state = 431, .external_lex_state = 2},
  [10114] = {.lex_state = 172, .external_lex_state = 2},
  [10115] = {.lex_state = 6, .external_lex_state = 3},
  [10116] = {.lex_state = 6, .external_lex_state = 3},
  [10117] = {.lex_state = 208, .external_lex_state = 2},
  [10118] = {.lex_state = 172, .external_lex_state = 2},
  [10119] = {.lex_state = 6, .external_lex_state = 3},
  [10120] = {.lex_state = 6, .external_lex_state = 3},
  [10121] = {.lex_state = 432, .external_lex_state = 2},
  [10122] = {.lex_state = 173, .external_lex_state = 2},
  [10123] = {.lex_state = 6, .external_lex_state = 3},
  [10124] = {.lex_state = 172, .external_lex_state = 2},
  [10125] = {.lex_state = 172, .external_lex_state = 2},
  [10126] = {.lex_state = 6, .external_lex_state = 3},
  [10127] = {.lex_state = 172, .external_lex_state = 2},
  [10128] = {.lex_state = 173, .external_lex_state = 2},
  [10129] = {.lex_state = 208, .external_lex_state = 2},
  [10130] = {.lex_state = 6, .external_lex_state = 3},
  [10131] = {.lex_state = 172, .external_lex_state = 2},
  [10132] = {.lex_state = 173, .external_lex_state = 2},
  [10133] = {.lex_state = 172, .external_lex_state = 2},
  [10134] = {.lex_state = 6, .external_lex_state = 3},
  [10135] = {.lex_state = 208, .external_lex_state = 2},
  [10136] = {.lex_state = 432, .external_lex_state = 2},
  [10137] = {.lex_state = 14, .external_lex_state = 2},
  [10138] = {.lex_state = 6, .external_lex_state = 3},
  [10139] = {.lex_state = 173, .external_lex_state = 2},
  [10140] = {.lex_state = 6, .external_lex_state = 3},
  [10141] = {.lex_state = 208, .external_lex_state = 2},
  [10142] = {.lex_state = 6, .external_lex_state = 3},
  [10143] = {.lex_state = 173, .external_lex_state = 2},
  [10144] = {.lex_state = 208, .external_lex_state = 2},
  [10145] = {.lex_state = 173, .external_lex_state = 2},
  [10146] = {.lex_state = 173, .external_lex_state = 2},
  [10147] = {.lex_state = 6, .external_lex_state = 3},
  [10148] = {.lex_state = 173, .external_lex_state = 2},
  [10149] = {.lex_state = 172, .external_lex_state = 2},
  [10150] = {.lex_state = 434, .external_lex_state = 2},
  [10151] = {.lex_state = 6, .external_lex_state = 3},
  [10152] = {.lex_state = 208, .external_lex_state = 2},
  [10153] = {.lex_state = 6, .external_lex_state = 3},
  [10154] = {.lex_state = 6, .external_lex_state = 3},
  [10155] = {.lex_state = 6, .external_lex_state = 3},
  [10156] = {.lex_state = 173, .external_lex_state = 2},
  [10157] = {.lex_state = 173, .external_lex_state = 2},
  [10158] = {.lex_state = 6, .external_lex_state = 3},
  [10159] = {.lex_state = 188, .external_lex_state = 3},
  [10160] = {.lex_state = 6, .external_lex_state = 3},
  [10161] = {.lex_state = 433, .external_lex_state = 2},
  [10162] = {.lex_state = 173, .external_lex_state = 2},
  [10163] = {.lex_state = 6, .external_lex_state = 3},
  [10164] = {.lex_state = 426, .external_lex_state = 2},
  [10165] = {.lex_state = 421, .external_lex_state = 2},
  [10166] = {.lex_state = 172, .external_lex_state = 2},
  [10167] = {.lex_state = 6, .external_lex_state = 3},
  [10168] = {.lex_state = 173, .external_lex_state = 2},
  [10169] = {.lex_state = 208, .external_lex_state = 2},
  [10170] = {.lex_state = 431, .external_lex_state = 2},
  [10171] = {.lex_state = 172, .external_lex_state = 2},
  [10172] = {.lex_state = 203, .external_lex_state = 2},
  [10173] = {.lex_state = 426, .external_lex_state = 2},
  [10174] = {.lex_state = 203, .external_lex_state = 2},
  [10175] = {.lex_state = 431, .external_lex_state = 2},
  [10176] = {.lex_state = 6, .external_lex_state = 3},
  [10177] = {.lex_state = 188, .external_lex_state = 3},
  [10178] = {.lex_state = 208, .external_lex_state = 2},
  [10179] = {.lex_state = 6, .external_lex_state = 3},
  [10180] = {.lex_state = 173, .external_lex_state = 2},
  [10181] = {.lex_state = 173, .external_lex_state = 2},
  [10182] = {.lex_state = 426, .external_lex_state = 2},
  [10183] = {.lex_state = 173, .external_lex_state = 2},
  [10184] = {.lex_state = 223, .external_lex_state = 2},
  [10185] = {.lex_state = 173, .external_lex_state = 2},
  [10186] = {.lex_state = 172, .external_lex_state = 2},
  [10187] = {.lex_state = 208, .external_lex_state = 2},
  [10188] = {.lex_state = 208, .external_lex_state = 2},
  [10189] = {.lex_state = 173, .external_lex_state = 2},
  [10190] = {.lex_state = 173, .external_lex_state = 2},
  [10191] = {.lex_state = 173, .external_lex_state = 2},
  [10192] = {.lex_state = 431, .external_lex_state = 2},
  [10193] = {.lex_state = 208, .external_lex_state = 2},
  [10194] = {.lex_state = 221, .external_lex_state = 2},
  [10195] = {.lex_state = 208, .external_lex_state = 2},
  [10196] = {.lex_state = 188, .external_lex_state = 3},
  [10197] = {.lex_state = 432, .external_lex_state = 2},
  [10198] = {.lex_state = 208, .external_lex_state = 2},
  [10199] = {.lex_state = 426, .external_lex_state = 2},
  [10200] = {.lex_state = 14, .external_lex_state = 2},
  [10201] = {.lex_state = 172, .external_lex_state = 2},
  [10202] = {.lex_state = 6, .external_lex_state = 3},
  [10203] = {.lex_state = 431, .external_lex_state = 2},
  [10204] = {.lex_state = 421, .external_lex_state = 2},
  [10205] = {.lex_state = 421, .external_lex_state = 2},
  [10206] = {.lex_state = 426, .external_lex_state = 2},
  [10207] = {.lex_state = 30, .external_lex_state = 2},
  [10208] = {.lex_state = 223, .external_lex_state = 2},
  [10209] = {.lex_state = 6, .external_lex_state = 3},
  [10210] = {.lex_state = 221, .external_lex_state = 2},
  [10211] = {.lex_state = 172, .external_lex_state = 2},
  [10212] = {.lex_state = 208, .external_lex_state = 2},
  [10213] = {.lex_state = 173, .external_lex_state = 2},
  [10214] = {.lex_state = 208, .external_lex_state = 2},
  [10215] = {.lex_state = 6, .external_lex_state = 3},
  [10216] = {.lex_state = 432, .external_lex_state = 2},
  [10217] = {.lex_state = 423, .external_lex_state = 2},
  [10218] = {.lex_state = 208, .external_lex_state = 2},
  [10219] = {.lex_state = 204, .external_lex_state = 2},
  [10220] = {.lex_state = 173, .external_lex_state = 2},
  [10221] = {.lex_state = 421, .external_lex_state = 2},
  [10222] = {.lex_state = 208, .external_lex_state = 2},
  [10223] = {.lex_state = 208, .external_lex_state = 2},
  [10224] = {.lex_state = 14, .external_lex_state = 2},
  [10225] = {.lex_state = 426, .external_lex_state = 2},
  [10226] = {.lex_state = 223, .external_lex_state = 2},
  [10227] = {.lex_state = 223, .external_lex_state = 2},
  [10228] = {.lex_state = 208, .external_lex_state = 2},
  [10229] = {.lex_state = 172, .external_lex_state = 2},
  [10230] = {.lex_state = 6, .external_lex_state = 3},
  [10231] = {.lex_state = 6, .external_lex_state = 3},
  [10232] = {.lex_state = 173, .external_lex_state = 2},
  [10233] = {.lex_state = 173, .external_lex_state = 2},
  [10234] = {.lex_state = 426, .external_lex_state = 2},
  [10235] = {.lex_state = 6, .external_lex_state = 3},
  [10236] = {.lex_state = 421, .external_lex_state = 2},
  [10237] = {.lex_state = 6, .external_lex_state = 3},
  [10238] = {.lex_state = 6, .external_lex_state = 3},
  [10239] = {.lex_state = 208, .external_lex_state = 2},
  [10240] = {.lex_state = 173, .external_lex_state = 2},
  [10241] = {.lex_state = 172, .external_lex_state = 2},
  [10242] = {.lex_state = 426, .external_lex_state = 2},
  [10243] = {.lex_state = 6, .external_lex_state = 3},
  [10244] = {.lex_state = 173, .external_lex_state = 2},
  [10245] = {.lex_state = 14, .external_lex_state = 2},
  [10246] = {.lex_state = 6, .external_lex_state = 3},
  [10247] = {.lex_state = 173, .external_lex_state = 2},
  [10248] = {.lex_state = 6, .external_lex_state = 3},
  [10249] = {.lex_state = 173, .external_lex_state = 2},
  [10250] = {.lex_state = 6, .external_lex_state = 3},
  [10251] = {.lex_state = 6, .external_lex_state = 3},
  [10252] = {.lex_state = 208, .external_lex_state = 2},
  [10253] = {.lex_state = 172, .external_lex_state = 2},
  [10254] = {.lex_state = 6, .external_lex_state = 3},
  [10255] = {.lex_state = 426, .external_lex_state = 2},
  [10256] = {.lex_state = 212, .external_lex_state = 2},
  [10257] = {.lex_state = 6, .external_lex_state = 3},
  [10258] = {.lex_state = 6, .external_lex_state = 3},
  [10259] = {.lex_state = 173, .external_lex_state = 2},
  [10260] = {.lex_state = 173, .external_lex_state = 2},
  [10261] = {.lex_state = 6, .external_lex_state = 3},
  [10262] = {.lex_state = 14, .external_lex_state = 2},
  [10263] = {.lex_state = 14, .external_lex_state = 2},
  [10264] = {.lex_state = 14, .external_lex_state = 2},
  [10265] = {.lex_state = 208, .external_lex_state = 2},
  [10266] = {.lex_state = 6, .external_lex_state = 3},
  [10267] = {.lex_state = 6, .external_lex_state = 3},
  [10268] = {.lex_state = 212, .external_lex_state = 2},
  [10269] = {.lex_state = 6, .external_lex_state = 3},
  [10270] = {.lex_state = 172, .external_lex_state = 2},
  [10271] = {.lex_state = 14, .external_lex_state = 2},
  [10272] = {.lex_state = 14, .external_lex_state = 2},
  [10273] = {.lex_state = 14, .external_lex_state = 2},
  [10274] = {.lex_state = 173, .external_lex_state = 2},
  [10275] = {.lex_state = 14, .external_lex_state = 2},
  [10276] = {.lex_state = 14, .external_lex_state = 2},
  [10277] = {.lex_state = 6, .external_lex_state = 3},
  [10278] = {.lex_state = 6, .external_lex_state = 3},
  [10279] = {.lex_state = 432, .external_lex_state = 2},
  [10280] = {.lex_state = 6, .external_lex_state = 3},
  [10281] = {.lex_state = 14, .external_lex_state = 2},
  [10282] = {.lex_state = 6, .external_lex_state = 3},
  [10283] = {.lex_state = 6, .external_lex_state = 3},
  [10284] = {.lex_state = 6, .external_lex_state = 3},
  [10285] = {.lex_state = 173, .external_lex_state = 2},
  [10286] = {.lex_state = 172, .external_lex_state = 2},
  [10287] = {.lex_state = 6, .external_lex_state = 3},
  [10288] = {.lex_state = 203, .external_lex_state = 2},
  [10289] = {.lex_state = 172, .external_lex_state = 2},
  [10290] = {.lex_state = 6, .external_lex_state = 3},
  [10291] = {.lex_state = 6, .external_lex_state = 3},
  [10292] = {.lex_state = 14, .external_lex_state = 2},
  [10293] = {.lex_state = 172, .external_lex_state = 2},
  [10294] = {.lex_state = 14, .external_lex_state = 2},
  [10295] = {.lex_state = 204, .external_lex_state = 2},
  [10296] = {.lex_state = 172, .external_lex_state = 2},
  [10297] = {.lex_state = 431, .external_lex_state = 2},
  [10298] = {.lex_state = 211, .external_lex_state = 2},
  [10299] = {.lex_state = 204, .external_lex_state = 2},
  [10300] = {.lex_state = 14, .external_lex_state = 2},
  [10301] = {.lex_state = 14, .external_lex_state = 2},
  [10302] = {.lex_state = 431, .external_lex_state = 2},
  [10303] = {.lex_state = 172, .external_lex_state = 2},
  [10304] = {.lex_state = 172, .external_lex_state = 2},
  [10305] = {.lex_state = 30, .external_lex_state = 2},
  [10306] = {.lex_state = 6, .external_lex_state = 3},
  [10307] = {.lex_state = 221, .external_lex_state = 2},
  [10308] = {.lex_state = 6, .external_lex_state = 3},
  [10309] = {.lex_state = 211, .external_lex_state = 2},
  [10310] = {.lex_state = 14, .external_lex_state = 2},
  [10311] = {.lex_state = 173, .external_lex_state = 2},
  [10312] = {.lex_state = 6, .external_lex_state = 3},
  [10313] = {.lex_state = 173, .external_lex_state = 2},
  [10314] = {.lex_state = 14, .external_lex_state = 2},
  [10315] = {.lex_state = 14, .external_lex_state = 2},
  [10316] = {.lex_state = 431, .external_lex_state = 2},
  [10317] = {.lex_state = 6, .external_lex_state = 3},
  [10318] = {.lex_state = 6, .external_lex_state = 3},
  [10319] = {.lex_state = 172, .external_lex_state = 2},
  [10320] = {.lex_state = 426, .external_lex_state = 2},
  [10321] = {.lex_state = 172, .external_lex_state = 2},
  [10322] = {.lex_state = 431, .external_lex_state = 2},
  [10323] = {.lex_state = 173, .external_lex_state = 2},
  [10324] = {.lex_state = 432, .external_lex_state = 2},
  [10325] = {.lex_state = 172, .external_lex_state = 2},
  [10326] = {.lex_state = 172, .external_lex_state = 2},
  [10327] = {.lex_state = 172, .external_lex_state = 2},
  [10328] = {.lex_state = 172, .external_lex_state = 2},
  [10329] = {.lex_state = 172, .external_lex_state = 2},
  [10330] = {.lex_state = 172, .external_lex_state = 2},
  [10331] = {.lex_state = 14, .external_lex_state = 2},
  [10332] = {.lex_state = 173, .external_lex_state = 2},
  [10333] = {.lex_state = 14, .external_lex_state = 2},
  [10334] = {.lex_state = 14, .external_lex_state = 2},
  [10335] = {.lex_state = 426, .external_lex_state = 2},
  [10336] = {.lex_state = 426, .external_lex_state = 2},
  [10337] = {.lex_state = 208, .external_lex_state = 2},
  [10338] = {.lex_state = 14, .external_lex_state = 2},
  [10339] = {.lex_state = 204, .external_lex_state = 2},
  [10340] = {.lex_state = 6, .external_lex_state = 3},
  [10341] = {.lex_state = 172, .external_lex_state = 2},
  [10342] = {.lex_state = 426, .external_lex_state = 2},
  [10343] = {.lex_state = 172, .external_lex_state = 2},
  [10344] = {.lex_state = 431, .external_lex_state = 2},
  [10345] = {.lex_state = 203, .external_lex_state = 2},
  [10346] = {.lex_state = 221, .external_lex_state = 2},
  [10347] = {.lex_state = 431, .external_lex_state = 2},
  [10348] = {.lex_state = 208, .external_lex_state = 2},
  [10349] = {.lex_state = 6, .external_lex_state = 3},
  [10350] = {.lex_state = 172, .external_lex_state = 2},
  [10351] = {.lex_state = 172, .external_lex_state = 2},
  [10352] = {.lex_state = 208, .external_lex_state = 2},
  [10353] = {.lex_state = 426, .external_lex_state = 2},
  [10354] = {.lex_state = 16, .external_lex_state = 2},
  [10355] = {.lex_state = 421, .external_lex_state = 2},
  [10356] = {.lex_state = 421, .external_lex_state = 2},
  [10357] = {.lex_state = 421, .external_lex_state = 2},
  [10358] = {.lex_state = 165, .external_lex_state = 2},
  [10359] = {.lex_state = 426, .external_lex_state = 2},
  [10360] = {.lex_state = 16, .external_lex_state = 2},
  [10361] = {.lex_state = 165, .external_lex_state = 2},
  [10362] = {.lex_state = 426, .external_lex_state = 2},
  [10363] = {.lex_state = 426, .external_lex_state = 2},
  [10364] = {.lex_state = 10, .external_lex_state = 2},
  [10365] = {.lex_state = 10, .external_lex_state = 2},
  [10366] = {.lex_state = 14, .external_lex_state = 2},
  [10367] = {.lex_state = 6, .external_lex_state = 3},
  [10368] = {.lex_state = 174, .external_lex_state = 2},
  [10369] = {.lex_state = 170, .external_lex_state = 2},
  [10370] = {.lex_state = 426, .external_lex_state = 2},
  [10371] = {.lex_state = 16, .external_lex_state = 2},
  [10372] = {.lex_state = 426, .external_lex_state = 2},
  [10373] = {.lex_state = 426, .external_lex_state = 2},
  [10374] = {.lex_state = 426, .external_lex_state = 2},
  [10375] = {.lex_state = 426, .external_lex_state = 2},
  [10376] = {.lex_state = 426, .external_lex_state = 2},
  [10377] = {.lex_state = 426, .external_lex_state = 2},
  [10378] = {.lex_state = 434, .external_lex_state = 2},
  [10379] = {.lex_state = 14, .external_lex_state = 2},
  [10380] = {.lex_state = 10, .external_lex_state = 2},
  [10381] = {.lex_state = 188, .external_lex_state = 3},
  [10382] = {.lex_state = 426, .external_lex_state = 2},
  [10383] = {.lex_state = 426, .external_lex_state = 2},
  [10384] = {.lex_state = 426, .external_lex_state = 2},
  [10385] = {.lex_state = 426, .external_lex_state = 2},
  [10386] = {.lex_state = 426, .external_lex_state = 2},
  [10387] = {.lex_state = 426, .external_lex_state = 2},
  [10388] = {.lex_state = 426, .external_lex_state = 2},
  [10389] = {.lex_state = 211, .external_lex_state = 2},
  [10390] = {.lex_state = 426, .external_lex_state = 2},
  [10391] = {.lex_state = 426, .external_lex_state = 2},
  [10392] = {.lex_state = 426, .external_lex_state = 2},
  [10393] = {.lex_state = 431, .external_lex_state = 2},
  [10394] = {.lex_state = 426, .external_lex_state = 2},
  [10395] = {.lex_state = 426, .external_lex_state = 2},
  [10396] = {.lex_state = 426, .external_lex_state = 2},
  [10397] = {.lex_state = 426, .external_lex_state = 2},
  [10398] = {.lex_state = 426, .external_lex_state = 2},
  [10399] = {.lex_state = 10, .external_lex_state = 2},
  [10400] = {.lex_state = 426, .external_lex_state = 2},
  [10401] = {.lex_state = 200, .external_lex_state = 2},
  [10402] = {.lex_state = 426, .external_lex_state = 2},
  [10403] = {.lex_state = 426, .external_lex_state = 2},
  [10404] = {.lex_state = 426, .external_lex_state = 2},
  [10405] = {.lex_state = 426, .external_lex_state = 2},
  [10406] = {.lex_state = 426, .external_lex_state = 2},
  [10407] = {.lex_state = 200, .external_lex_state = 2},
  [10408] = {.lex_state = 200, .external_lex_state = 2},
  [10409] = {.lex_state = 426, .external_lex_state = 2},
  [10410] = {.lex_state = 426, .external_lex_state = 2},
  [10411] = {.lex_state = 200, .external_lex_state = 2},
  [10412] = {.lex_state = 434, .external_lex_state = 2},
  [10413] = {.lex_state = 420, .external_lex_state = 2},
  [10414] = {.lex_state = 426, .external_lex_state = 2},
  [10415] = {.lex_state = 426, .external_lex_state = 2},
  [10416] = {.lex_state = 426, .external_lex_state = 2},
  [10417] = {.lex_state = 426, .external_lex_state = 2},
  [10418] = {.lex_state = 211, .external_lex_state = 2},
  [10419] = {.lex_state = 426, .external_lex_state = 2},
  [10420] = {.lex_state = 426, .external_lex_state = 2},
  [10421] = {.lex_state = 421, .external_lex_state = 2},
  [10422] = {.lex_state = 426, .external_lex_state = 2},
  [10423] = {.lex_state = 426, .external_lex_state = 2},
  [10424] = {.lex_state = 426, .external_lex_state = 2},
  [10425] = {.lex_state = 10, .external_lex_state = 2},
  [10426] = {.lex_state = 10, .external_lex_state = 2},
  [10427] = {.lex_state = 426, .external_lex_state = 2},
  [10428] = {.lex_state = 426, .external_lex_state = 2},
  [10429] = {.lex_state = 426, .external_lex_state = 2},
  [10430] = {.lex_state = 15, .external_lex_state = 2},
  [10431] = {.lex_state = 227, .external_lex_state = 2},
  [10432] = {.lex_state = 426, .external_lex_state = 2},
  [10433] = {.lex_state = 426, .external_lex_state = 2},
  [10434] = {.lex_state = 426, .external_lex_state = 2},
  [10435] = {.lex_state = 426, .external_lex_state = 2},
  [10436] = {.lex_state = 426, .external_lex_state = 2},
  [10437] = {.lex_state = 211, .external_lex_state = 2},
  [10438] = {.lex_state = 434, .external_lex_state = 2},
  [10439] = {.lex_state = 426, .external_lex_state = 2},
  [10440] = {.lex_state = 212, .external_lex_state = 2},
  [10441] = {.lex_state = 421, .external_lex_state = 2},
  [10442] = {.lex_state = 14, .external_lex_state = 2},
  [10443] = {.lex_state = 426, .external_lex_state = 2},
  [10444] = {.lex_state = 426, .external_lex_state = 2},
  [10445] = {.lex_state = 426, .external_lex_state = 2},
  [10446] = {.lex_state = 14, .external_lex_state = 2},
  [10447] = {.lex_state = 426, .external_lex_state = 2},
  [10448] = {.lex_state = 426, .external_lex_state = 2},
  [10449] = {.lex_state = 426, .external_lex_state = 2},
  [10450] = {.lex_state = 426, .external_lex_state = 2},
  [10451] = {.lex_state = 10, .external_lex_state = 2},
  [10452] = {.lex_state = 211, .external_lex_state = 2},
  [10453] = {.lex_state = 426, .external_lex_state = 2},
  [10454] = {.lex_state = 211, .external_lex_state = 2},
  [10455] = {.lex_state = 426, .external_lex_state = 2},
  [10456] = {.lex_state = 16, .external_lex_state = 2},
  [10457] = {.lex_state = 426, .external_lex_state = 2},
  [10458] = {.lex_state = 16, .external_lex_state = 2},
  [10459] = {.lex_state = 16, .external_lex_state = 2},
  [10460] = {.lex_state = 16, .external_lex_state = 2},
  [10461] = {.lex_state = 434, .external_lex_state = 2},
  [10462] = {.lex_state = 30, .external_lex_state = 2},
  [10463] = {.lex_state = 426, .external_lex_state = 2},
  [10464] = {.lex_state = 211, .external_lex_state = 2},
  [10465] = {.lex_state = 426, .external_lex_state = 2},
  [10466] = {.lex_state = 426, .external_lex_state = 2},
  [10467] = {.lex_state = 426, .external_lex_state = 2},
  [10468] = {.lex_state = 30, .external_lex_state = 2},
  [10469] = {.lex_state = 30, .external_lex_state = 2},
  [10470] = {.lex_state = 16, .external_lex_state = 2},
  [10471] = {.lex_state = 30, .external_lex_state = 2},
  [10472] = {.lex_state = 426, .external_lex_state = 2},
  [10473] = {.lex_state = 426, .external_lex_state = 2},
  [10474] = {.lex_state = 16, .external_lex_state = 2},
  [10475] = {.lex_state = 426, .external_lex_state = 2},
  [10476] = {.lex_state = 426, .external_lex_state = 2},
  [10477] = {.lex_state = 217, .external_lex_state = 2},
  [10478] = {.lex_state = 426, .external_lex_state = 2},
  [10479] = {.lex_state = 217, .external_lex_state = 2},
  [10480] = {.lex_state = 426, .external_lex_state = 2},
  [10481] = {.lex_state = 426, .external_lex_state = 2},
  [10482] = {.lex_state = 15, .external_lex_state = 2},
  [10483] = {.lex_state = 15, .external_lex_state = 2},
  [10484] = {.lex_state = 426, .external_lex_state = 2},
  [10485] = {.lex_state = 426, .external_lex_state = 2},
  [10486] = {.lex_state = 426, .external_lex_state = 2},
  [10487] = {.lex_state = 426, .external_lex_state = 2},
  [10488] = {.lex_state = 16, .external_lex_state = 2},
  [10489] = {.lex_state = 431, .external_lex_state = 2},
  [10490] = {.lex_state = 426, .external_lex_state = 2},
  [10491] = {.lex_state = 15, .external_lex_state = 2},
  [10492] = {.lex_state = 421, .external_lex_state = 2},
  [10493] = {.lex_state = 16, .external_lex_state = 2},
  [10494] = {.lex_state = 426, .external_lex_state = 2},
  [10495] = {.lex_state = 426, .external_lex_state = 2},
  [10496] = {.lex_state = 426, .external_lex_state = 2},
  [10497] = {.lex_state = 426, .external_lex_state = 2},
  [10498] = {.lex_state = 426, .external_lex_state = 2},
  [10499] = {.lex_state = 426, .external_lex_state = 2},
  [10500] = {.lex_state = 10, .external_lex_state = 2},
  [10501] = {.lex_state = 426, .external_lex_state = 2},
  [10502] = {.lex_state = 426, .external_lex_state = 2},
  [10503] = {.lex_state = 426, .external_lex_state = 2},
  [10504] = {.lex_state = 426, .external_lex_state = 2},
  [10505] = {.lex_state = 30, .external_lex_state = 2},
  [10506] = {.lex_state = 426, .external_lex_state = 2},
  [10507] = {.lex_state = 426, .external_lex_state = 2},
  [10508] = {.lex_state = 14, .external_lex_state = 2},
  [10509] = {.lex_state = 426, .external_lex_state = 2},
  [10510] = {.lex_state = 16, .external_lex_state = 2},
  [10511] = {.lex_state = 426, .external_lex_state = 2},
  [10512] = {.lex_state = 14, .external_lex_state = 2},
  [10513] = {.lex_state = 426, .external_lex_state = 2},
  [10514] = {.lex_state = 426, .external_lex_state = 2},
  [10515] = {.lex_state = 426, .external_lex_state = 2},
  [10516] = {.lex_state = 426, .external_lex_state = 2},
  [10517] = {.lex_state = 426, .external_lex_state = 2},
  [10518] = {.lex_state = 426, .external_lex_state = 2},
  [10519] = {.lex_state = 421, .external_lex_state = 2},
  [10520] = {.lex_state = 426, .external_lex_state = 2},
  [10521] = {.lex_state = 426, .external_lex_state = 2},
  [10522] = {.lex_state = 426, .external_lex_state = 2},
  [10523] = {.lex_state = 14, .external_lex_state = 2},
  [10524] = {.lex_state = 14, .external_lex_state = 2},
  [10525] = {.lex_state = 426, .external_lex_state = 2},
  [10526] = {.lex_state = 426, .external_lex_state = 2},
  [10527] = {.lex_state = 426, .external_lex_state = 2},
  [10528] = {.lex_state = 426, .external_lex_state = 2},
  [10529] = {.lex_state = 426, .external_lex_state = 2},
  [10530] = {.lex_state = 14, .external_lex_state = 2},
  [10531] = {.lex_state = 15, .external_lex_state = 2},
  [10532] = {.lex_state = 14, .external_lex_state = 2},
  [10533] = {.lex_state = 426, .external_lex_state = 2},
  [10534] = {.lex_state = 426, .external_lex_state = 2},
  [10535] = {.lex_state = 16, .external_lex_state = 2},
  [10536] = {.lex_state = 426, .external_lex_state = 2},
  [10537] = {.lex_state = 426, .external_lex_state = 2},
  [10538] = {.lex_state = 426, .external_lex_state = 2},
  [10539] = {.lex_state = 426, .external_lex_state = 2},
  [10540] = {.lex_state = 426, .external_lex_state = 2},
  [10541] = {.lex_state = 14, .external_lex_state = 2},
  [10542] = {.lex_state = 426, .external_lex_state = 2},
  [10543] = {.lex_state = 14, .external_lex_state = 2},
  [10544] = {.lex_state = 426, .external_lex_state = 2},
  [10545] = {.lex_state = 14, .external_lex_state = 2},
  [10546] = {.lex_state = 14, .external_lex_state = 2},
  [10547] = {.lex_state = 16, .external_lex_state = 2},
  [10548] = {.lex_state = 14, .external_lex_state = 2},
  [10549] = {.lex_state = 46, .external_lex_state = 3},
  [10550] = {.lex_state = 426, .external_lex_state = 2},
  [10551] = {.lex_state = 10, .external_lex_state = 2},
  [10552] = {.lex_state = 426, .external_lex_state = 2},
  [10553] = {.lex_state = 14, .external_lex_state = 2},
  [10554] = {.lex_state = 14, .external_lex_state = 2},
  [10555] = {.lex_state = 46, .external_lex_state = 3},
  [10556] = {.lex_state = 426, .external_lex_state = 2},
  [10557] = {.lex_state = 426, .external_lex_state = 2},
  [10558] = {.lex_state = 426, .external_lex_state = 2},
  [10559] = {.lex_state = 426, .external_lex_state = 2},
  [10560] = {.lex_state = 426, .external_lex_state = 2},
  [10561] = {.lex_state = 426, .external_lex_state = 2},
  [10562] = {.lex_state = 426, .external_lex_state = 2},
  [10563] = {.lex_state = 421, .external_lex_state = 2},
  [10564] = {.lex_state = 426, .external_lex_state = 2},
  [10565] = {.lex_state = 16, .external_lex_state = 2},
  [10566] = {.lex_state = 426, .external_lex_state = 2},
  [10567] = {.lex_state = 426, .external_lex_state = 2},
  [10568] = {.lex_state = 426, .external_lex_state = 2},
  [10569] = {.lex_state = 426, .external_lex_state = 2},
  [10570] = {.lex_state = 421, .external_lex_state = 2},
  [10571] = {.lex_state = 426, .external_lex_state = 2},
  [10572] = {.lex_state = 426, .external_lex_state = 2},
  [10573] = {.lex_state = 14, .external_lex_state = 2},
  [10574] = {.lex_state = 426, .external_lex_state = 2},
  [10575] = {.lex_state = 421, .external_lex_state = 2},
  [10576] = {.lex_state = 14, .external_lex_state = 2},
  [10577] = {.lex_state = 426, .external_lex_state = 2},
  [10578] = {.lex_state = 426, .external_lex_state = 2},
  [10579] = {.lex_state = 15, .external_lex_state = 2},
  [10580] = {.lex_state = 426, .external_lex_state = 2},
  [10581] = {.lex_state = 426, .external_lex_state = 2},
  [10582] = {.lex_state = 426, .external_lex_state = 2},
  [10583] = {.lex_state = 217, .external_lex_state = 2},
  [10584] = {.lex_state = 426, .external_lex_state = 2},
  [10585] = {.lex_state = 421, .external_lex_state = 2},
  [10586] = {.lex_state = 426, .external_lex_state = 2},
  [10587] = {.lex_state = 199, .external_lex_state = 2},
  [10588] = {.lex_state = 426, .external_lex_state = 2},
  [10589] = {.lex_state = 15, .external_lex_state = 2},
  [10590] = {.lex_state = 16, .external_lex_state = 2},
  [10591] = {.lex_state = 15, .external_lex_state = 2},
  [10592] = {.lex_state = 217, .external_lex_state = 2},
  [10593] = {.lex_state = 426, .external_lex_state = 2},
  [10594] = {.lex_state = 217, .external_lex_state = 2},
  [10595] = {.lex_state = 426, .external_lex_state = 2},
  [10596] = {.lex_state = 426, .external_lex_state = 2},
  [10597] = {.lex_state = 426, .external_lex_state = 2},
  [10598] = {.lex_state = 15, .external_lex_state = 2},
  [10599] = {.lex_state = 15, .external_lex_state = 2},
  [10600] = {.lex_state = 15, .external_lex_state = 2},
  [10601] = {.lex_state = 426, .external_lex_state = 2},
  [10602] = {.lex_state = 221, .external_lex_state = 2},
  [10603] = {.lex_state = 15, .external_lex_state = 2},
  [10604] = {.lex_state = 16, .external_lex_state = 2},
  [10605] = {.lex_state = 16, .external_lex_state = 2},
  [10606] = {.lex_state = 426, .external_lex_state = 2},
  [10607] = {.lex_state = 16, .external_lex_state = 2},
  [10608] = {.lex_state = 426, .external_lex_state = 2},
  [10609] = {.lex_state = 10, .external_lex_state = 2},
  [10610] = {.lex_state = 15, .external_lex_state = 2},
  [10611] = {.lex_state = 16, .external_lex_state = 2},
  [10612] = {.lex_state = 426, .external_lex_state = 2},
  [10613] = {.lex_state = 421, .external_lex_state = 2},
  [10614] = {.lex_state = 15, .external_lex_state = 2},
  [10615] = {.lex_state = 16, .external_lex_state = 2},
  [10616] = {.lex_state = 15, .external_lex_state = 2},
  [10617] = {.lex_state = 426, .external_lex_state = 2},
  [10618] = {.lex_state = 426, .external_lex_state = 2},
  [10619] = {.lex_state = 15, .external_lex_state = 2},
  [10620] = {.lex_state = 426, .external_lex_state = 2},
  [10621] = {.lex_state = 15, .external_lex_state = 2},
  [10622] = {.lex_state = 15, .external_lex_state = 2},
  [10623] = {.lex_state = 15, .external_lex_state = 2},
  [10624] = {.lex_state = 46, .external_lex_state = 3},
  [10625] = {.lex_state = 426, .external_lex_state = 2},
  [10626] = {.lex_state = 426, .external_lex_state = 2},
  [10627] = {.lex_state = 426, .external_lex_state = 2},
  [10628] = {.lex_state = 217, .external_lex_state = 2},
  [10629] = {.lex_state = 217, .external_lex_state = 2},
  [10630] = {.lex_state = 10, .external_lex_state = 2},
  [10631] = {.lex_state = 426, .external_lex_state = 2},
  [10632] = {.lex_state = 10, .external_lex_state = 2},
  [10633] = {.lex_state = 426, .external_lex_state = 2},
  [10634] = {.lex_state = 426, .external_lex_state = 2},
  [10635] = {.lex_state = 426, .external_lex_state = 2},
  [10636] = {.lex_state = 421, .external_lex_state = 2},
  [10637] = {.lex_state = 199, .external_lex_state = 2},
  [10638] = {.lex_state = 421, .external_lex_state = 2},
  [10639] = {.lex_state = 426, .external_lex_state = 2},
  [10640] = {.lex_state = 421, .external_lex_state = 2},
  [10641] = {.lex_state = 426, .external_lex_state = 2},
  [10642] = {.lex_state = 421, .external_lex_state = 2},
  [10643] = {.lex_state = 426, .external_lex_state = 2},
  [10644] = {.lex_state = 421, .external_lex_state = 2},
  [10645] = {.lex_state = 426, .external_lex_state = 2},
  [10646] = {.lex_state = 426, .external_lex_state = 2},
  [10647] = {.lex_state = 217, .external_lex_state = 2},
  [10648] = {.lex_state = 16, .external_lex_state = 2},
  [10649] = {.lex_state = 421, .external_lex_state = 2},
  [10650] = {.lex_state = 199, .external_lex_state = 2},
  [10651] = {.lex_state = 16, .external_lex_state = 2},
  [10652] = {.lex_state = 199, .external_lex_state = 2},
  [10653] = {.lex_state = 421, .external_lex_state = 2},
  [10654] = {.lex_state = 16, .external_lex_state = 2},
  [10655] = {.lex_state = 426, .external_lex_state = 2},
  [10656] = {.lex_state = 426, .external_lex_state = 2},
  [10657] = {.lex_state = 426, .external_lex_state = 2},
  [10658] = {.lex_state = 426, .external_lex_state = 2},
  [10659] = {.lex_state = 16, .external_lex_state = 2},
  [10660] = {.lex_state = 426, .external_lex_state = 2},
  [10661] = {.lex_state = 426, .external_lex_state = 2},
  [10662] = {.lex_state = 426, .external_lex_state = 2},
  [10663] = {.lex_state = 426, .external_lex_state = 2},
  [10664] = {.lex_state = 426, .external_lex_state = 2},
  [10665] = {.lex_state = 217, .external_lex_state = 2},
  [10666] = {.lex_state = 420, .external_lex_state = 3},
  [10667] = {.lex_state = 426, .external_lex_state = 2},
  [10668] = {.lex_state = 426, .external_lex_state = 2},
  [10669] = {.lex_state = 421, .external_lex_state = 2},
  [10670] = {.lex_state = 421, .external_lex_state = 2},
  [10671] = {.lex_state = 420, .external_lex_state = 2},
  [10672] = {.lex_state = 421, .external_lex_state = 2},
  [10673] = {.lex_state = 426, .external_lex_state = 2},
  [10674] = {.lex_state = 421, .external_lex_state = 2},
  [10675] = {.lex_state = 421, .external_lex_state = 2},
  [10676] = {.lex_state = 426, .external_lex_state = 2},
  [10677] = {.lex_state = 426, .external_lex_state = 2},
  [10678] = {.lex_state = 16, .external_lex_state = 2},
  [10679] = {.lex_state = 16, .external_lex_state = 2},
  [10680] = {.lex_state = 16, .external_lex_state = 2},
  [10681] = {.lex_state = 421, .external_lex_state = 2},
  [10682] = {.lex_state = 421, .external_lex_state = 2},
  [10683] = {.lex_state = 421, .external_lex_state = 2},
  [10684] = {.lex_state = 426, .external_lex_state = 2},
  [10685] = {.lex_state = 421, .external_lex_state = 2},
  [10686] = {.lex_state = 421, .external_lex_state = 2},
  [10687] = {.lex_state = 16, .external_lex_state = 2},
  [10688] = {.lex_state = 421, .external_lex_state = 2},
  [10689] = {.lex_state = 426, .external_lex_state = 2},
  [10690] = {.lex_state = 421, .external_lex_state = 2},
  [10691] = {.lex_state = 223, .external_lex_state = 2},
  [10692] = {.lex_state = 426, .external_lex_state = 2},
  [10693] = {.lex_state = 217, .external_lex_state = 2},
  [10694] = {.lex_state = 217, .external_lex_state = 2},
  [10695] = {.lex_state = 421, .external_lex_state = 2},
  [10696] = {.lex_state = 421, .external_lex_state = 2},
  [10697] = {.lex_state = 421, .external_lex_state = 2},
  [10698] = {.lex_state = 426, .external_lex_state = 2},
  [10699] = {.lex_state = 426, .external_lex_state = 2},
  [10700] = {.lex_state = 426, .external_lex_state = 2},
  [10701] = {.lex_state = 426, .external_lex_state = 2},
  [10702] = {.lex_state = 426, .external_lex_state = 2},
  [10703] = {.lex_state = 426, .external_lex_state = 2},
  [10704] = {.lex_state = 421, .external_lex_state = 2},
  [10705] = {.lex_state = 426, .external_lex_state = 2},
  [10706] = {.lex_state = 426, .external_lex_state = 2},
  [10707] = {.lex_state = 221, .external_lex_state = 2},
  [10708] = {.lex_state = 208, .external_lex_state = 2},
  [10709] = {.lex_state = 221, .external_lex_state = 2},
  [10710] = {.lex_state = 221, .external_lex_state = 2},
  [10711] = {.lex_state = 426, .external_lex_state = 2},
  [10712] = {.lex_state = 208, .external_lex_state = 2},
  [10713] = {.lex_state = 431, .external_lex_state = 2},
  [10714] = {.lex_state = 208, .external_lex_state = 2},
  [10715] = {.lex_state = 208, .external_lex_state = 2},
  [10716] = {.lex_state = 426, .external_lex_state = 2},
  [10717] = {.lex_state = 420, .external_lex_state = 2},
  [10718] = {.lex_state = 431, .external_lex_state = 2},
  [10719] = {.lex_state = 199, .external_lex_state = 2},
  [10720] = {.lex_state = 208, .external_lex_state = 2},
  [10721] = {.lex_state = 208, .external_lex_state = 2},
  [10722] = {.lex_state = 223, .external_lex_state = 2},
  [10723] = {.lex_state = 208, .external_lex_state = 2},
  [10724] = {.lex_state = 208, .external_lex_state = 2},
  [10725] = {.lex_state = 208, .external_lex_state = 2},
  [10726] = {.lex_state = 221, .external_lex_state = 2},
  [10727] = {.lex_state = 221, .external_lex_state = 2},
  [10728] = {.lex_state = 208, .external_lex_state = 2},
  [10729] = {.lex_state = 426, .external_lex_state = 2},
  [10730] = {.lex_state = 208, .external_lex_state = 2},
  [10731] = {.lex_state = 221, .external_lex_state = 2},
  [10732] = {.lex_state = 208, .external_lex_state = 2},
  [10733] = {.lex_state = 420, .external_lex_state = 2},
  [10734] = {.lex_state = 420, .external_lex_state = 2},
  [10735] = {.lex_state = 223, .external_lex_state = 2},
  [10736] = {.lex_state = 426, .external_lex_state = 2},
  [10737] = {.lex_state = 431, .external_lex_state = 2},
  [10738] = {.lex_state = 221, .external_lex_state = 2},
  [10739] = {.lex_state = 46, .external_lex_state = 3},
  [10740] = {.lex_state = 208, .external_lex_state = 2},
  [10741] = {.lex_state = 426, .external_lex_state = 2},
  [10742] = {.lex_state = 426, .external_lex_state = 2},
  [10743] = {.lex_state = 431, .external_lex_state = 2},
  [10744] = {.lex_state = 208, .external_lex_state = 2},
  [10745] = {.lex_state = 426, .external_lex_state = 2},
  [10746] = {.lex_state = 208, .external_lex_state = 2},
  [10747] = {.lex_state = 15, .external_lex_state = 2},
  [10748] = {.lex_state = 431, .external_lex_state = 2},
  [10749] = {.lex_state = 208, .external_lex_state = 2},
  [10750] = {.lex_state = 208, .external_lex_state = 2},
  [10751] = {.lex_state = 431, .external_lex_state = 2},
  [10752] = {.lex_state = 431, .external_lex_state = 2},
  [10753] = {.lex_state = 431, .external_lex_state = 2},
  [10754] = {.lex_state = 208, .external_lex_state = 2},
  [10755] = {.lex_state = 208, .external_lex_state = 2},
  [10756] = {.lex_state = 221, .external_lex_state = 2},
  [10757] = {.lex_state = 221, .external_lex_state = 2},
  [10758] = {.lex_state = 431, .external_lex_state = 2},
  [10759] = {.lex_state = 431, .external_lex_state = 2},
  [10760] = {.lex_state = 221, .external_lex_state = 2},
  [10761] = {.lex_state = 208, .external_lex_state = 2},
  [10762] = {.lex_state = 223, .external_lex_state = 2},
  [10763] = {.lex_state = 223, .external_lex_state = 2},
  [10764] = {.lex_state = 208, .external_lex_state = 2},
  [10765] = {.lex_state = 208, .external_lex_state = 2},
  [10766] = {.lex_state = 208, .external_lex_state = 2},
  [10767] = {.lex_state = 208, .external_lex_state = 2},
  [10768] = {.lex_state = 30, .external_lex_state = 2},
  [10769] = {.lex_state = 223, .external_lex_state = 2},
  [10770] = {.lex_state = 217, .external_lex_state = 2},
  [10771] = {.lex_state = 208, .external_lex_state = 2},
  [10772] = {.lex_state = 201, .external_lex_state = 2},
  [10773] = {.lex_state = 208, .external_lex_state = 2},
  [10774] = {.lex_state = 221, .external_lex_state = 2},
  [10775] = {.lex_state = 201, .external_lex_state = 2},
  [10776] = {.lex_state = 223, .external_lex_state = 2},
  [10777] = {.lex_state = 223, .external_lex_state = 2},
  [10778] = {.lex_state = 199, .external_lex_state = 2},
  [10779] = {.lex_state = 223, .external_lex_state = 2},
  [10780] = {.lex_state = 431, .external_lex_state = 2},
  [10781] = {.lex_state = 431, .external_lex_state = 2},
  [10782] = {.lex_state = 208, .external_lex_state = 2},
  [10783] = {.lex_state = 426, .external_lex_state = 2},
  [10784] = {.lex_state = 223, .external_lex_state = 2},
  [10785] = {.lex_state = 431, .external_lex_state = 2},
  [10786] = {.lex_state = 431, .external_lex_state = 2},
  [10787] = {.lex_state = 208, .external_lex_state = 2},
  [10788] = {.lex_state = 201, .external_lex_state = 2},
  [10789] = {.lex_state = 208, .external_lex_state = 2},
  [10790] = {.lex_state = 223, .external_lex_state = 2},
  [10791] = {.lex_state = 431, .external_lex_state = 2},
  [10792] = {.lex_state = 223, .external_lex_state = 2},
  [10793] = {.lex_state = 223, .external_lex_state = 2},
  [10794] = {.lex_state = 426, .external_lex_state = 2},
  [10795] = {.lex_state = 223, .external_lex_state = 2},
  [10796] = {.lex_state = 30, .external_lex_state = 2},
  [10797] = {.lex_state = 223, .external_lex_state = 2},
  [10798] = {.lex_state = 223, .external_lex_state = 2},
  [10799] = {.lex_state = 227, .external_lex_state = 2},
  [10800] = {.lex_state = 208, .external_lex_state = 2},
  [10801] = {.lex_state = 426, .external_lex_state = 2},
  [10802] = {.lex_state = 431, .external_lex_state = 2},
  [10803] = {.lex_state = 30, .external_lex_state = 2},
  [10804] = {.lex_state = 208, .external_lex_state = 2},
  [10805] = {.lex_state = 217, .external_lex_state = 2},
  [10806] = {.lex_state = 208, .external_lex_state = 2},
  [10807] = {.lex_state = 431, .external_lex_state = 2},
  [10808] = {.lex_state = 208, .external_lex_state = 2},
  [10809] = {.lex_state = 208, .external_lex_state = 2},
  [10810] = {.lex_state = 221, .external_lex_state = 2},
  [10811] = {.lex_state = 208, .external_lex_state = 2},
  [10812] = {.lex_state = 208, .external_lex_state = 2},
  [10813] = {.lex_state = 208, .external_lex_state = 2},
  [10814] = {.lex_state = 30, .external_lex_state = 2},
  [10815] = {.lex_state = 432, .external_lex_state = 2},
  [10816] = {.lex_state = 30, .external_lex_state = 2},
  [10817] = {.lex_state = 6, .external_lex_state = 3},
  [10818] = {.lex_state = 167, .external_lex_state = 3},
  [10819] = {.lex_state = 420, .external_lex_state = 2},
  [10820] = {.lex_state = 420, .external_lex_state = 2},
  [10821] = {.lex_state = 30, .external_lex_state = 2},
  [10822] = {.lex_state = 420, .external_lex_state = 2},
  [10823] = {.lex_state = 208, .external_lex_state = 2},
  [10824] = {.lex_state = 223, .external_lex_state = 2},
  [10825] = {.lex_state = 223, .external_lex_state = 2},
  [10826] = {.lex_state = 223, .external_lex_state = 2},
  [10827] = {.lex_state = 426, .external_lex_state = 2},
  [10828] = {.lex_state = 208, .external_lex_state = 2},
  [10829] = {.lex_state = 221, .external_lex_state = 2},
  [10830] = {.lex_state = 221, .external_lex_state = 2},
  [10831] = {.lex_state = 431, .external_lex_state = 2},
  [10832] = {.lex_state = 221, .external_lex_state = 2},
  [10833] = {.lex_state = 223, .external_lex_state = 2},
  [10834] = {.lex_state = 15, .external_lex_state = 2},
  [10835] = {.lex_state = 426, .external_lex_state = 2},
  [10836] = {.lex_state = 223, .external_lex_state = 2},
  [10837] = {.lex_state = 208, .external_lex_state = 2},
  [10838] = {.lex_state = 431, .external_lex_state = 2},
  [10839] = {.lex_state = 223, .external_lex_state = 2},
  [10840] = {.lex_state = 431, .external_lex_state = 2},
  [10841] = {.lex_state = 431, .external_lex_state = 2},
  [10842] = {.lex_state = 431, .external_lex_state = 2},
  [10843] = {.lex_state = 208, .external_lex_state = 2},
  [10844] = {.lex_state = 223, .external_lex_state = 2},
  [10845] = {.lex_state = 208, .external_lex_state = 2},
  [10846] = {.lex_state = 223, .external_lex_state = 2},
  [10847] = {.lex_state = 223, .external_lex_state = 2},
  [10848] = {.lex_state = 30, .external_lex_state = 2},
  [10849] = {.lex_state = 426, .external_lex_state = 2},
  [10850] = {.lex_state = 431, .external_lex_state = 2},
  [10851] = {.lex_state = 223, .external_lex_state = 2},
  [10852] = {.lex_state = 30, .external_lex_state = 2},
  [10853] = {.lex_state = 426, .external_lex_state = 2},
  [10854] = {.lex_state = 431, .external_lex_state = 2},
  [10855] = {.lex_state = 30, .external_lex_state = 2},
  [10856] = {.lex_state = 227, .external_lex_state = 2},
  [10857] = {.lex_state = 431, .external_lex_state = 2},
  [10858] = {.lex_state = 227, .external_lex_state = 2},
  [10859] = {.lex_state = 208, .external_lex_state = 2},
  [10860] = {.lex_state = 208, .external_lex_state = 2},
  [10861] = {.lex_state = 221, .external_lex_state = 2},
  [10862] = {.lex_state = 208, .external_lex_state = 2},
  [10863] = {.lex_state = 426, .external_lex_state = 2},
  [10864] = {.lex_state = 221, .external_lex_state = 2},
  [10865] = {.lex_state = 208, .external_lex_state = 2},
  [10866] = {.lex_state = 426, .external_lex_state = 2},
  [10867] = {.lex_state = 223, .external_lex_state = 2},
  [10868] = {.lex_state = 208, .external_lex_state = 2},
  [10869] = {.lex_state = 223, .external_lex_state = 2},
  [10870] = {.lex_state = 30, .external_lex_state = 2},
  [10871] = {.lex_state = 208, .external_lex_state = 2},
  [10872] = {.lex_state = 223, .external_lex_state = 2},
  [10873] = {.lex_state = 223, .external_lex_state = 2},
  [10874] = {.lex_state = 420, .external_lex_state = 2},
  [10875] = {.lex_state = 208, .external_lex_state = 2},
  [10876] = {.lex_state = 208, .external_lex_state = 2},
  [10877] = {.lex_state = 221, .external_lex_state = 2},
  [10878] = {.lex_state = 221, .external_lex_state = 2},
  [10879] = {.lex_state = 30, .external_lex_state = 2},
  [10880] = {.lex_state = 426, .external_lex_state = 2},
  [10881] = {.lex_state = 30, .external_lex_state = 2},
  [10882] = {.lex_state = 223, .external_lex_state = 2},
  [10883] = {.lex_state = 208, .external_lex_state = 2},
  [10884] = {.lex_state = 223, .external_lex_state = 2},
  [10885] = {.lex_state = 221, .external_lex_state = 2},
  [10886] = {.lex_state = 223, .external_lex_state = 2},
  [10887] = {.lex_state = 223, .external_lex_state = 2},
  [10888] = {.lex_state = 221, .external_lex_state = 2},
  [10889] = {.lex_state = 420, .external_lex_state = 2},
  [10890] = {.lex_state = 208, .external_lex_state = 2},
  [10891] = {.lex_state = 221, .external_lex_state = 2},
  [10892] = {.lex_state = 221, .external_lex_state = 2},
  [10893] = {.lex_state = 221, .external_lex_state = 2},
  [10894] = {.lex_state = 208, .external_lex_state = 2},
  [10895] = {.lex_state = 30, .external_lex_state = 2},
  [10896] = {.lex_state = 426, .external_lex_state = 2},
  [10897] = {.lex_state = 208, .external_lex_state = 2},
  [10898] = {.lex_state = 420, .external_lex_state = 2},
  [10899] = {.lex_state = 221, .external_lex_state = 2},
  [10900] = {.lex_state = 199, .external_lex_state = 2},
  [10901] = {.lex_state = 221, .external_lex_state = 2},
  [10902] = {.lex_state = 221, .external_lex_state = 2},
  [10903] = {.lex_state = 221, .external_lex_state = 2},
  [10904] = {.lex_state = 431, .external_lex_state = 2},
  [10905] = {.lex_state = 221, .external_lex_state = 2},
  [10906] = {.lex_state = 200, .external_lex_state = 2},
  [10907] = {.lex_state = 431, .external_lex_state = 2},
  [10908] = {.lex_state = 30, .external_lex_state = 2},
  [10909] = {.lex_state = 432, .external_lex_state = 2},
  [10910] = {.lex_state = 227, .external_lex_state = 2},
  [10911] = {.lex_state = 208, .external_lex_state = 2},
  [10912] = {.lex_state = 221, .external_lex_state = 2},
  [10913] = {.lex_state = 202, .external_lex_state = 2},
  [10914] = {.lex_state = 221, .external_lex_state = 2},
  [10915] = {.lex_state = 202, .external_lex_state = 2},
  [10916] = {.lex_state = 30, .external_lex_state = 2},
  [10917] = {.lex_state = 431, .external_lex_state = 2},
  [10918] = {.lex_state = 30, .external_lex_state = 2},
  [10919] = {.lex_state = 420, .external_lex_state = 2},
  [10920] = {.lex_state = 202, .external_lex_state = 2},
  [10921] = {.lex_state = 431, .external_lex_state = 2},
  [10922] = {.lex_state = 30, .external_lex_state = 2},
  [10923] = {.lex_state = 431, .external_lex_state = 2},
  [10924] = {.lex_state = 30, .external_lex_state = 2},
  [10925] = {.lex_state = 208, .external_lex_state = 2},
  [10926] = {.lex_state = 431, .external_lex_state = 2},
  [10927] = {.lex_state = 208, .external_lex_state = 2},
  [10928] = {.lex_state = 432, .external_lex_state = 2},
  [10929] = {.lex_state = 208, .external_lex_state = 2},
  [10930] = {.lex_state = 426, .external_lex_state = 2},
  [10931] = {.lex_state = 426, .external_lex_state = 2},
  [10932] = {.lex_state = 30, .external_lex_state = 2},
  [10933] = {.lex_state = 426, .external_lex_state = 2},
  [10934] = {.lex_state = 30, .external_lex_state = 2},
  [10935] = {.lex_state = 30, .external_lex_state = 2},
  [10936] = {.lex_state = 208, .external_lex_state = 2},
  [10937] = {.lex_state = 420, .external_lex_state = 2},
  [10938] = {.lex_state = 30, .external_lex_state = 2},
  [10939] = {.lex_state = 30, .external_lex_state = 2},
  [10940] = {.lex_state = 208, .external_lex_state = 2},
  [10941] = {.lex_state = 426, .external_lex_state = 2},
  [10942] = {.lex_state = 30, .external_lex_state = 2},
  [10943] = {.lex_state = 426, .external_lex_state = 2},
  [10944] = {.lex_state = 30, .external_lex_state = 2},
  [10945] = {.lex_state = 223, .external_lex_state = 2},
  [10946] = {.lex_state = 30, .external_lex_state = 2},
  [10947] = {.lex_state = 426, .external_lex_state = 2},
  [10948] = {.lex_state = 30, .external_lex_state = 2},
  [10949] = {.lex_state = 426, .external_lex_state = 2},
  [10950] = {.lex_state = 30, .external_lex_state = 2},
  [10951] = {.lex_state = 208, .external_lex_state = 2},
  [10952] = {.lex_state = 30, .external_lex_state = 2},
  [10953] = {.lex_state = 30, .external_lex_state = 2},
  [10954] = {.lex_state = 420, .external_lex_state = 2},
  [10955] = {.lex_state = 420, .external_lex_state = 2},
  [10956] = {.lex_state = 30, .external_lex_state = 2},
  [10957] = {.lex_state = 223, .external_lex_state = 2},
  [10958] = {.lex_state = 426, .external_lex_state = 2},
  [10959] = {.lex_state = 30, .external_lex_state = 2},
  [10960] = {.lex_state = 221, .external_lex_state = 2},
  [10961] = {.lex_state = 221, .external_lex_state = 2},
  [10962] = {.lex_state = 15, .external_lex_state = 2},
  [10963] = {.lex_state = 7, .external_lex_state = 2},
  [10964] = {.lex_state = 426, .external_lex_state = 2},
  [10965] = {.lex_state = 15, .external_lex_state = 2},
  [10966] = {.lex_state = 221, .external_lex_state = 2},
  [10967] = {.lex_state = 15, .external_lex_state = 2},
  [10968] = {.lex_state = 221, .external_lex_state = 2},
  [10969] = {.lex_state = 221, .external_lex_state = 2},
  [10970] = {.lex_state = 30, .external_lex_state = 2},
  [10971] = {.lex_state = 30, .external_lex_state = 2},
  [10972] = {.lex_state = 426, .external_lex_state = 2},
  [10973] = {.lex_state = 426, .external_lex_state = 2},
  [10974] = {.lex_state = 200, .external_lex_state = 2},
  [10975] = {.lex_state = 221, .external_lex_state = 2},
  [10976] = {.lex_state = 208, .external_lex_state = 2},
  [10977] = {.lex_state = 208, .external_lex_state = 2},
  [10978] = {.lex_state = 426, .external_lex_state = 2},
  [10979] = {.lex_state = 426, .external_lex_state = 2},
  [10980] = {.lex_state = 426, .external_lex_state = 2},
  [10981] = {.lex_state = 208, .external_lex_state = 2},
  [10982] = {.lex_state = 208, .external_lex_state = 2},
  [10983] = {.lex_state = 15, .external_lex_state = 2},
  [10984] = {.lex_state = 15, .external_lex_state = 2},
  [10985] = {.lex_state = 15, .external_lex_state = 2},
  [10986] = {.lex_state = 15, .external_lex_state = 2},
  [10987] = {.lex_state = 426, .external_lex_state = 2},
  [10988] = {.lex_state = 223, .external_lex_state = 2},
  [10989] = {.lex_state = 15, .external_lex_state = 2},
  [10990] = {.lex_state = 15, .external_lex_state = 2},
  [10991] = {.lex_state = 15, .external_lex_state = 2},
  [10992] = {.lex_state = 15, .external_lex_state = 2},
  [10993] = {.lex_state = 223, .external_lex_state = 2},
  [10994] = {.lex_state = 30, .external_lex_state = 2},
  [10995] = {.lex_state = 15, .external_lex_state = 2},
  [10996] = {.lex_state = 200, .external_lex_state = 2},
  [10997] = {.lex_state = 432, .external_lex_state = 2},
  [10998] = {.lex_state = 208, .external_lex_state = 2},
  [10999] = {.lex_state = 426, .external_lex_state = 2},
  [11000] = {.lex_state = 426, .external_lex_state = 2},
  [11001] = {.lex_state = 426, .external_lex_state = 2},
  [11002] = {.lex_state = 426, .external_lex_state = 2},
  [11003] = {.lex_state = 211, .external_lex_state = 2},
  [11004] = {.lex_state = 211, .external_lex_state = 2},
  [11005] = {.lex_state = 426, .external_lex_state = 2},
  [11006] = {.lex_state = 167, .external_lex_state = 3},
  [11007] = {.lex_state = 420, .external_lex_state = 2},
  [11008] = {.lex_state = 426, .external_lex_state = 2},
  [11009] = {.lex_state = 211, .external_lex_state = 2},
  [11010] = {.lex_state = 217, .external_lex_state = 2},
  [11011] = {.lex_state = 426, .external_lex_state = 2},
  [11012] = {.lex_state = 420, .external_lex_state = 2},
  [11013] = {.lex_state = 217, .external_lex_state = 2},
  [11014] = {.lex_state = 420, .external_lex_state = 2},
  [11015] = {.lex_state = 426, .external_lex_state = 2},
  [11016] = {.lex_state = 420, .external_lex_state = 2},
  [11017] = {.lex_state = 217, .external_lex_state = 2},
  [11018] = {.lex_state = 217, .external_lex_state = 2},
  [11019] = {.lex_state = 426, .external_lex_state = 2},
  [11020] = {.lex_state = 420, .external_lex_state = 2},
  [11021] = {.lex_state = 420, .external_lex_state = 2},
  [11022] = {.lex_state = 217, .external_lex_state = 2},
  [11023] = {.lex_state = 426, .external_lex_state = 2},
  [11024] = {.lex_state = 217, .external_lex_state = 2},
  [11025] = {.lex_state = 432, .external_lex_state = 2},
  [11026] = {.lex_state = 219, .external_lex_state = 2},
  [11027] = {.lex_state = 217, .external_lex_state = 2},
  [11028] = {.lex_state = 16, .external_lex_state = 2},
  [11029] = {.lex_state = 426, .external_lex_state = 2},
  [11030] = {.lex_state = 420, .external_lex_state = 2},
  [11031] = {.lex_state = 217, .external_lex_state = 2},
  [11032] = {.lex_state = 217, .external_lex_state = 2},
  [11033] = {.lex_state = 426, .external_lex_state = 2},
  [11034] = {.lex_state = 217, .external_lex_state = 2},
  [11035] = {.lex_state = 420, .external_lex_state = 2},
  [11036] = {.lex_state = 426, .external_lex_state = 2},
  [11037] = {.lex_state = 431, .external_lex_state = 2},
  [11038] = {.lex_state = 217, .external_lex_state = 2},
  [11039] = {.lex_state = 431, .external_lex_state = 2},
  [11040] = {.lex_state = 217, .external_lex_state = 2},
  [11041] = {.lex_state = 426, .external_lex_state = 2},
  [11042] = {.lex_state = 217, .external_lex_state = 2},
  [11043] = {.lex_state = 16, .external_lex_state = 2},
  [11044] = {.lex_state = 16, .external_lex_state = 2},
  [11045] = {.lex_state = 420, .external_lex_state = 2},
  [11046] = {.lex_state = 420, .external_lex_state = 2},
  [11047] = {.lex_state = 16, .external_lex_state = 2},
  [11048] = {.lex_state = 420, .external_lex_state = 2},
  [11049] = {.lex_state = 423, .external_lex_state = 2},
  [11050] = {.lex_state = 420, .external_lex_state = 2},
  [11051] = {.lex_state = 420, .external_lex_state = 2},
  [11052] = {.lex_state = 431, .external_lex_state = 2},
  [11053] = {.lex_state = 426, .external_lex_state = 2},
  [11054] = {.lex_state = 420, .external_lex_state = 2},
  [11055] = {.lex_state = 426, .external_lex_state = 2},
  [11056] = {.lex_state = 426, .external_lex_state = 2},
  [11057] = {.lex_state = 426, .external_lex_state = 2},
  [11058] = {.lex_state = 217, .external_lex_state = 2},
  [11059] = {.lex_state = 6, .external_lex_state = 2},
  [11060] = {.lex_state = 426, .external_lex_state = 2},
  [11061] = {.lex_state = 420, .external_lex_state = 2},
  [11062] = {.lex_state = 426, .external_lex_state = 2},
  [11063] = {.lex_state = 217, .external_lex_state = 2},
  [11064] = {.lex_state = 426, .external_lex_state = 2},
  [11065] = {.lex_state = 420, .external_lex_state = 2},
  [11066] = {.lex_state = 426, .external_lex_state = 2},
  [11067] = {.lex_state = 420, .external_lex_state = 2},
  [11068] = {.lex_state = 31, .external_lex_state = 2},
  [11069] = {.lex_state = 426, .external_lex_state = 2},
  [11070] = {.lex_state = 426, .external_lex_state = 2},
  [11071] = {.lex_state = 10, .external_lex_state = 2},
  [11072] = {.lex_state = 217, .external_lex_state = 2},
  [11073] = {.lex_state = 426, .external_lex_state = 2},
  [11074] = {.lex_state = 426, .external_lex_state = 2},
  [11075] = {.lex_state = 420, .external_lex_state = 2},
  [11076] = {.lex_state = 211, .external_lex_state = 2},
  [11077] = {.lex_state = 16, .external_lex_state = 2},
  [11078] = {.lex_state = 420, .external_lex_state = 2},
  [11079] = {.lex_state = 426, .external_lex_state = 2},
  [11080] = {.lex_state = 426, .external_lex_state = 2},
  [11081] = {.lex_state = 423, .external_lex_state = 2},
  [11082] = {.lex_state = 432, .external_lex_state = 2},
  [11083] = {.lex_state = 420, .external_lex_state = 3},
  [11084] = {.lex_state = 420, .external_lex_state = 2},
  [11085] = {.lex_state = 420, .external_lex_state = 2},
  [11086] = {.lex_state = 420, .external_lex_state = 2},
  [11087] = {.lex_state = 426, .external_lex_state = 2},
  [11088] = {.lex_state = 217, .external_lex_state = 2},
  [11089] = {.lex_state = 217, .external_lex_state = 2},
  [11090] = {.lex_state = 420, .external_lex_state = 2},
  [11091] = {.lex_state = 217, .external_lex_state = 2},
  [11092] = {.lex_state = 426, .external_lex_state = 2},
  [11093] = {.lex_state = 431, .external_lex_state = 2},
  [11094] = {.lex_state = 217, .external_lex_state = 2},
  [11095] = {.lex_state = 426, .external_lex_state = 2},
  [11096] = {.lex_state = 217, .external_lex_state = 2},
  [11097] = {.lex_state = 31, .external_lex_state = 2},
  [11098] = {.lex_state = 31, .external_lex_state = 2},
  [11099] = {.lex_state = 423, .external_lex_state = 2},
  [11100] = {.lex_state = 420, .external_lex_state = 3},
  [11101] = {.lex_state = 8, .external_lex_state = 2},
  [11102] = {.lex_state = 426, .external_lex_state = 2},
  [11103] = {.lex_state = 420, .external_lex_state = 2},
  [11104] = {.lex_state = 426, .external_lex_state = 2},
  [11105] = {.lex_state = 420, .external_lex_state = 2},
  [11106] = {.lex_state = 420, .external_lex_state = 3},
  [11107] = {.lex_state = 426, .external_lex_state = 2},
  [11108] = {.lex_state = 426, .external_lex_state = 2},
  [11109] = {.lex_state = 426, .external_lex_state = 2},
  [11110] = {.lex_state = 217, .external_lex_state = 2},
  [11111] = {.lex_state = 217, .external_lex_state = 2},
  [11112] = {.lex_state = 426, .external_lex_state = 2},
  [11113] = {.lex_state = 420, .external_lex_state = 2},
  [11114] = {.lex_state = 420, .external_lex_state = 2},
  [11115] = {.lex_state = 426, .external_lex_state = 2},
  [11116] = {.lex_state = 426, .external_lex_state = 2},
  [11117] = {.lex_state = 16, .external_lex_state = 2},
  [11118] = {.lex_state = 16, .external_lex_state = 2},
  [11119] = {.lex_state = 420, .external_lex_state = 2},
  [11120] = {.lex_state = 426, .external_lex_state = 2},
  [11121] = {.lex_state = 420, .external_lex_state = 2},
  [11122] = {.lex_state = 420, .external_lex_state = 2},
  [11123] = {.lex_state = 217, .external_lex_state = 2},
  [11124] = {.lex_state = 217, .external_lex_state = 2},
  [11125] = {.lex_state = 200, .external_lex_state = 2},
  [11126] = {.lex_state = 16, .external_lex_state = 2},
  [11127] = {.lex_state = 16, .external_lex_state = 2},
  [11128] = {.lex_state = 426, .external_lex_state = 2},
  [11129] = {.lex_state = 420, .external_lex_state = 2},
  [11130] = {.lex_state = 426, .external_lex_state = 2},
  [11131] = {.lex_state = 426, .external_lex_state = 2},
  [11132] = {.lex_state = 426, .external_lex_state = 2},
  [11133] = {.lex_state = 16, .external_lex_state = 2},
  [11134] = {.lex_state = 217, .external_lex_state = 2},
  [11135] = {.lex_state = 426, .external_lex_state = 2},
  [11136] = {.lex_state = 217, .external_lex_state = 2},
  [11137] = {.lex_state = 426, .external_lex_state = 2},
  [11138] = {.lex_state = 426, .external_lex_state = 2},
  [11139] = {.lex_state = 426, .external_lex_state = 2},
  [11140] = {.lex_state = 426, .external_lex_state = 2},
  [11141] = {.lex_state = 28, .external_lex_state = 3},
  [11142] = {.lex_state = 10, .external_lex_state = 2},
  [11143] = {.lex_state = 426, .external_lex_state = 2},
  [11144] = {.lex_state = 8, .external_lex_state = 2},
  [11145] = {.lex_state = 420, .external_lex_state = 2},
  [11146] = {.lex_state = 8, .external_lex_state = 2},
  [11147] = {.lex_state = 426, .external_lex_state = 2},
  [11148] = {.lex_state = 420, .external_lex_state = 2},
  [11149] = {.lex_state = 426, .external_lex_state = 2},
  [11150] = {.lex_state = 426, .external_lex_state = 2},
  [11151] = {.lex_state = 426, .external_lex_state = 2},
  [11152] = {.lex_state = 420, .external_lex_state = 2},
  [11153] = {.lex_state = 426, .external_lex_state = 2},
  [11154] = {.lex_state = 217, .external_lex_state = 2},
  [11155] = {.lex_state = 426, .external_lex_state = 2},
  [11156] = {.lex_state = 432, .external_lex_state = 2},
  [11157] = {.lex_state = 6, .external_lex_state = 2},
  [11158] = {.lex_state = 420, .external_lex_state = 2},
  [11159] = {.lex_state = 426, .external_lex_state = 2},
  [11160] = {.lex_state = 426, .external_lex_state = 2},
  [11161] = {.lex_state = 16, .external_lex_state = 2},
  [11162] = {.lex_state = 426, .external_lex_state = 2},
  [11163] = {.lex_state = 420, .external_lex_state = 2},
  [11164] = {.lex_state = 16, .external_lex_state = 2},
  [11165] = {.lex_state = 10, .external_lex_state = 2},
  [11166] = {.lex_state = 16, .external_lex_state = 2},
  [11167] = {.lex_state = 16, .external_lex_state = 2},
  [11168] = {.lex_state = 426, .external_lex_state = 2},
  [11169] = {.lex_state = 420, .external_lex_state = 2},
  [11170] = {.lex_state = 426, .external_lex_state = 2},
  [11171] = {.lex_state = 16, .external_lex_state = 2},
  [11172] = {.lex_state = 420, .external_lex_state = 2},
  [11173] = {.lex_state = 420, .external_lex_state = 2},
  [11174] = {.lex_state = 426, .external_lex_state = 2},
  [11175] = {.lex_state = 217, .external_lex_state = 2},
  [11176] = {.lex_state = 426, .external_lex_state = 2},
  [11177] = {.lex_state = 426, .external_lex_state = 2},
  [11178] = {.lex_state = 217, .external_lex_state = 2},
  [11179] = {.lex_state = 16, .external_lex_state = 2},
  [11180] = {.lex_state = 16, .external_lex_state = 2},
  [11181] = {.lex_state = 420, .external_lex_state = 2},
  [11182] = {.lex_state = 426, .external_lex_state = 2},
  [11183] = {.lex_state = 420, .external_lex_state = 2},
  [11184] = {.lex_state = 426, .external_lex_state = 2},
  [11185] = {.lex_state = 16, .external_lex_state = 2},
  [11186] = {.lex_state = 426, .external_lex_state = 2},
  [11187] = {.lex_state = 426, .external_lex_state = 2},
  [11188] = {.lex_state = 426, .external_lex_state = 2},
  [11189] = {.lex_state = 426, .external_lex_state = 2},
  [11190] = {.lex_state = 16, .external_lex_state = 2},
  [11191] = {.lex_state = 426, .external_lex_state = 2},
  [11192] = {.lex_state = 420, .external_lex_state = 2},
  [11193] = {.lex_state = 426, .external_lex_state = 2},
  [11194] = {.lex_state = 426, .external_lex_state = 2},
  [11195] = {.lex_state = 16, .external_lex_state = 2},
  [11196] = {.lex_state = 16, .external_lex_state = 2},
  [11197] = {.lex_state = 217, .external_lex_state = 2},
  [11198] = {.lex_state = 16, .external_lex_state = 2},
  [11199] = {.lex_state = 199, .external_lex_state = 2},
  [11200] = {.lex_state = 426, .external_lex_state = 2},
  [11201] = {.lex_state = 420, .external_lex_state = 2},
  [11202] = {.lex_state = 431, .external_lex_state = 2},
  [11203] = {.lex_state = 431, .external_lex_state = 2},
  [11204] = {.lex_state = 16, .external_lex_state = 2},
  [11205] = {.lex_state = 420, .external_lex_state = 2},
  [11206] = {.lex_state = 16, .external_lex_state = 2},
  [11207] = {.lex_state = 217, .external_lex_state = 2},
  [11208] = {.lex_state = 420, .external_lex_state = 2},
  [11209] = {.lex_state = 426, .external_lex_state = 2},
  [11210] = {.lex_state = 420, .external_lex_state = 2},
  [11211] = {.lex_state = 420, .external_lex_state = 2},
  [11212] = {.lex_state = 420, .external_lex_state = 2},
  [11213] = {.lex_state = 420, .external_lex_state = 2},
  [11214] = {.lex_state = 420, .external_lex_state = 2},
  [11215] = {.lex_state = 420, .external_lex_state = 2},
  [11216] = {.lex_state = 420, .external_lex_state = 2},
  [11217] = {.lex_state = 420, .external_lex_state = 2},
  [11218] = {.lex_state = 420, .external_lex_state = 2},
  [11219] = {.lex_state = 420, .external_lex_state = 2},
  [11220] = {.lex_state = 28, .external_lex_state = 2},
  [11221] = {.lex_state = 420, .external_lex_state = 2},
  [11222] = {.lex_state = 420, .external_lex_state = 2},
  [11223] = {.lex_state = 420, .external_lex_state = 2},
  [11224] = {.lex_state = 28, .external_lex_state = 2},
  [11225] = {.lex_state = 420, .external_lex_state = 2},
  [11226] = {.lex_state = 420, .external_lex_state = 2},
  [11227] = {.lex_state = 420, .external_lex_state = 2},
  [11228] = {.lex_state = 15, .external_lex_state = 2},
  [11229] = {.lex_state = 420, .external_lex_state = 2},
  [11230] = {.lex_state = 420, .external_lex_state = 2},
  [11231] = {.lex_state = 420, .external_lex_state = 2},
  [11232] = {.lex_state = 420, .external_lex_state = 2},
  [11233] = {.lex_state = 28, .external_lex_state = 2},
  [11234] = {.lex_state = 420, .external_lex_state = 2},
  [11235] = {.lex_state = 420, .external_lex_state = 2},
  [11236] = {.lex_state = 17, .external_lex_state = 2},
  [11237] = {.lex_state = 420, .external_lex_state = 2},
  [11238] = {.lex_state = 420, .external_lex_state = 2},
  [11239] = {.lex_state = 28, .external_lex_state = 2},
  [11240] = {.lex_state = 420, .external_lex_state = 2},
  [11241] = {.lex_state = 420, .external_lex_state = 2},
  [11242] = {.lex_state = 420, .external_lex_state = 2},
  [11243] = {.lex_state = 420, .external_lex_state = 2},
  [11244] = {.lex_state = 420, .external_lex_state = 2},
  [11245] = {.lex_state = 420, .external_lex_state = 2},
  [11246] = {.lex_state = 420, .external_lex_state = 2},
  [11247] = {.lex_state = 10, .external_lex_state = 2},
  [11248] = {.lex_state = 10, .external_lex_state = 2},
  [11249] = {.lex_state = 420, .external_lex_state = 2},
  [11250] = {.lex_state = 28, .external_lex_state = 2},
  [11251] = {.lex_state = 420, .external_lex_state = 2},
  [11252] = {.lex_state = 420, .external_lex_state = 2},
  [11253] = {.lex_state = 10, .external_lex_state = 2},
  [11254] = {.lex_state = 426, .external_lex_state = 2},
  [11255] = {.lex_state = 420, .external_lex_state = 2},
  [11256] = {.lex_state = 420, .external_lex_state = 2},
  [11257] = {.lex_state = 420, .external_lex_state = 2},
  [11258] = {.lex_state = 219, .external_lex_state = 2},
  [11259] = {.lex_state = 426, .external_lex_state = 2},
  [11260] = {.lex_state = 420, .external_lex_state = 2},
  [11261] = {.lex_state = 420, .external_lex_state = 2},
  [11262] = {.lex_state = 420, .external_lex_state = 2},
  [11263] = {.lex_state = 420, .external_lex_state = 2},
  [11264] = {.lex_state = 420, .external_lex_state = 2},
  [11265] = {.lex_state = 420, .external_lex_state = 2},
  [11266] = {.lex_state = 420, .external_lex_state = 2},
  [11267] = {.lex_state = 420, .external_lex_state = 2},
  [11268] = {.lex_state = 420, .external_lex_state = 2},
  [11269] = {.lex_state = 28, .external_lex_state = 2},
  [11270] = {.lex_state = 420, .external_lex_state = 2},
  [11271] = {.lex_state = 420, .external_lex_state = 2},
  [11272] = {.lex_state = 420, .external_lex_state = 2},
  [11273] = {.lex_state = 420, .external_lex_state = 2},
  [11274] = {.lex_state = 420, .external_lex_state = 2},
  [11275] = {.lex_state = 420, .external_lex_state = 2},
  [11276] = {.lex_state = 10, .external_lex_state = 2},
  [11277] = {.lex_state = 28, .external_lex_state = 2},
  [11278] = {.lex_state = 420, .external_lex_state = 2},
  [11279] = {.lex_state = 420, .external_lex_state = 2},
  [11280] = {.lex_state = 420, .external_lex_state = 2},
  [11281] = {.lex_state = 420, .external_lex_state = 2},
  [11282] = {.lex_state = 420, .external_lex_state = 2},
  [11283] = {.lex_state = 28, .external_lex_state = 2},
  [11284] = {.lex_state = 16, .external_lex_state = 2},
  [11285] = {.lex_state = 16, .external_lex_state = 2},
  [11286] = {.lex_state = 16, .external_lex_state = 2},
  [11287] = {.lex_state = 16, .external_lex_state = 2},
  [11288] = {.lex_state = 420, .external_lex_state = 2},
  [11289] = {.lex_state = 16, .external_lex_state = 2},
  [11290] = {.lex_state = 16, .external_lex_state = 2},
  [11291] = {.lex_state = 16, .external_lex_state = 2},
  [11292] = {.lex_state = 16, .external_lex_state = 2},
  [11293] = {.lex_state = 16, .external_lex_state = 2},
  [11294] = {.lex_state = 16, .external_lex_state = 2},
  [11295] = {.lex_state = 16, .external_lex_state = 2},
  [11296] = {.lex_state = 16, .external_lex_state = 2},
  [11297] = {.lex_state = 420, .external_lex_state = 2},
  [11298] = {.lex_state = 420, .external_lex_state = 2},
  [11299] = {.lex_state = 420, .external_lex_state = 2},
  [11300] = {.lex_state = 426, .external_lex_state = 2},
  [11301] = {.lex_state = 28, .external_lex_state = 2},
  [11302] = {.lex_state = 28, .external_lex_state = 2},
  [11303] = {.lex_state = 420, .external_lex_state = 2},
  [11304] = {.lex_state = 420, .external_lex_state = 2},
  [11305] = {.lex_state = 420, .external_lex_state = 2},
  [11306] = {.lex_state = 420, .external_lex_state = 2},
  [11307] = {.lex_state = 420, .external_lex_state = 2},
  [11308] = {.lex_state = 420, .external_lex_state = 2},
  [11309] = {.lex_state = 420, .external_lex_state = 2},
  [11310] = {.lex_state = 28, .external_lex_state = 2},
  [11311] = {.lex_state = 420, .external_lex_state = 2},
  [11312] = {.lex_state = 10, .external_lex_state = 2},
  [11313] = {.lex_state = 10, .external_lex_state = 2},
  [11314] = {.lex_state = 420, .external_lex_state = 2},
  [11315] = {.lex_state = 420, .external_lex_state = 2},
  [11316] = {.lex_state = 420, .external_lex_state = 2},
  [11317] = {.lex_state = 28, .external_lex_state = 2},
  [11318] = {.lex_state = 420, .external_lex_state = 2},
  [11319] = {.lex_state = 420, .external_lex_state = 2},
  [11320] = {.lex_state = 420, .external_lex_state = 2},
  [11321] = {.lex_state = 420, .external_lex_state = 2},
  [11322] = {.lex_state = 420, .external_lex_state = 2},
  [11323] = {.lex_state = 420, .external_lex_state = 2},
  [11324] = {.lex_state = 420, .external_lex_state = 2},
  [11325] = {.lex_state = 420, .external_lex_state = 2},
  [11326] = {.lex_state = 420, .external_lex_state = 2},
  [11327] = {.lex_state = 28, .external_lex_state = 2},
  [11328] = {.lex_state = 28, .external_lex_state = 2},
  [11329] = {.lex_state = 420, .external_lex_state = 2},
  [11330] = {.lex_state = 420, .external_lex_state = 2},
  [11331] = {.lex_state = 28, .external_lex_state = 2},
  [11332] = {.lex_state = 420, .external_lex_state = 2},
  [11333] = {.lex_state = 420, .external_lex_state = 2},
  [11334] = {.lex_state = 420, .external_lex_state = 2},
  [11335] = {.lex_state = 420, .external_lex_state = 2},
  [11336] = {.lex_state = 420, .external_lex_state = 2},
  [11337] = {.lex_state = 420, .external_lex_state = 2},
  [11338] = {.lex_state = 420, .external_lex_state = 2},
  [11339] = {.lex_state = 420, .external_lex_state = 2},
  [11340] = {.lex_state = 420, .external_lex_state = 2},
  [11341] = {.lex_state = 28, .external_lex_state = 2},
  [11342] = {.lex_state = 28, .external_lex_state = 2},
  [11343] = {.lex_state = 420, .external_lex_state = 2},
  [11344] = {.lex_state = 420, .external_lex_state = 2},
  [11345] = {.lex_state = 420, .external_lex_state = 2},
  [11346] = {.lex_state = 16, .external_lex_state = 2},
  [11347] = {.lex_state = 426, .external_lex_state = 2},
  [11348] = {.lex_state = 420, .external_lex_state = 2},
  [11349] = {.lex_state = 426, .external_lex_state = 2},
  [11350] = {.lex_state = 28, .external_lex_state = 2},
  [11351] = {.lex_state = 420, .external_lex_state = 2},
  [11352] = {.lex_state = 420, .external_lex_state = 2},
  [11353] = {.lex_state = 28, .external_lex_state = 2},
  [11354] = {.lex_state = 420, .external_lex_state = 2},
  [11355] = {.lex_state = 420, .external_lex_state = 2},
  [11356] = {.lex_state = 420, .external_lex_state = 2},
  [11357] = {.lex_state = 420, .external_lex_state = 2},
  [11358] = {.lex_state = 420, .external_lex_state = 2},
  [11359] = {.lex_state = 420, .external_lex_state = 2},
  [11360] = {.lex_state = 420, .external_lex_state = 2},
  [11361] = {.lex_state = 420, .external_lex_state = 2},
  [11362] = {.lex_state = 420, .external_lex_state = 2},
  [11363] = {.lex_state = 420, .external_lex_state = 2},
  [11364] = {.lex_state = 420, .external_lex_state = 2},
  [11365] = {.lex_state = 420, .external_lex_state = 2},
  [11366] = {.lex_state = 420, .external_lex_state = 2},
  [11367] = {.lex_state = 420, .external_lex_state = 2},
  [11368] = {.lex_state = 28, .external_lex_state = 2},
  [11369] = {.lex_state = 420, .external_lex_state = 2},
  [11370] = {.lex_state = 420, .external_lex_state = 2},
  [11371] = {.lex_state = 420, .external_lex_state = 2},
  [11372] = {.lex_state = 420, .external_lex_state = 2},
  [11373] = {.lex_state = 420, .external_lex_state = 2},
  [11374] = {.lex_state = 28, .external_lex_state = 2},
  [11375] = {.lex_state = 420, .external_lex_state = 2},
  [11376] = {.lex_state = 420, .external_lex_state = 2},
  [11377] = {.lex_state = 420, .external_lex_state = 2},
  [11378] = {.lex_state = 420, .external_lex_state = 2},
  [11379] = {.lex_state = 28, .external_lex_state = 2},
  [11380] = {.lex_state = 420, .external_lex_state = 2},
  [11381] = {.lex_state = 420, .external_lex_state = 2},
  [11382] = {.lex_state = 420, .external_lex_state = 2},
  [11383] = {.lex_state = 420, .external_lex_state = 2},
  [11384] = {.lex_state = 420, .external_lex_state = 2},
  [11385] = {.lex_state = 420, .external_lex_state = 2},
  [11386] = {.lex_state = 420, .external_lex_state = 2},
  [11387] = {.lex_state = 420, .external_lex_state = 2},
  [11388] = {.lex_state = 420, .external_lex_state = 2},
  [11389] = {.lex_state = 420, .external_lex_state = 2},
  [11390] = {.lex_state = 211, .external_lex_state = 2},
  [11391] = {.lex_state = 10, .external_lex_state = 2},
  [11392] = {.lex_state = 28, .external_lex_state = 2},
  [11393] = {.lex_state = 420, .external_lex_state = 2},
  [11394] = {.lex_state = 420, .external_lex_state = 2},
  [11395] = {.lex_state = 420, .external_lex_state = 2},
  [11396] = {.lex_state = 420, .external_lex_state = 2},
  [11397] = {.lex_state = 420, .external_lex_state = 2},
  [11398] = {.lex_state = 420, .external_lex_state = 2},
  [11399] = {.lex_state = 420, .external_lex_state = 2},
  [11400] = {.lex_state = 420, .external_lex_state = 2},
  [11401] = {.lex_state = 420, .external_lex_state = 2},
  [11402] = {.lex_state = 10, .external_lex_state = 2},
  [11403] = {.lex_state = 420, .external_lex_state = 2},
  [11404] = {.lex_state = 28, .external_lex_state = 2},
  [11405] = {.lex_state = 420, .external_lex_state = 2},
  [11406] = {.lex_state = 420, .external_lex_state = 2},
  [11407] = {.lex_state = 28, .external_lex_state = 2},
  [11408] = {.lex_state = 10, .external_lex_state = 2},
  [11409] = {.lex_state = 420, .external_lex_state = 2},
  [11410] = {.lex_state = 166, .external_lex_state = 2},
  [11411] = {.lex_state = 426, .external_lex_state = 2},
  [11412] = {.lex_state = 420, .external_lex_state = 2},
  [11413] = {.lex_state = 420, .external_lex_state = 2},
  [11414] = {.lex_state = 28, .external_lex_state = 2},
  [11415] = {.lex_state = 420, .external_lex_state = 2},
  [11416] = {.lex_state = 420, .external_lex_state = 2},
  [11417] = {.lex_state = 166, .external_lex_state = 2},
  [11418] = {.lex_state = 166, .external_lex_state = 2},
  [11419] = {.lex_state = 420, .external_lex_state = 2},
  [11420] = {.lex_state = 420, .external_lex_state = 2},
  [11421] = {.lex_state = 420, .external_lex_state = 2},
  [11422] = {.lex_state = 420, .external_lex_state = 2},
  [11423] = {.lex_state = 420, .external_lex_state = 2},
  [11424] = {.lex_state = 420, .external_lex_state = 2},
  [11425] = {.lex_state = 420, .external_lex_state = 2},
  [11426] = {.lex_state = 420, .external_lex_state = 2},
  [11427] = {.lex_state = 420, .external_lex_state = 2},
  [11428] = {.lex_state = 17, .external_lex_state = 2},
  [11429] = {.lex_state = 28, .external_lex_state = 2},
  [11430] = {.lex_state = 420, .external_lex_state = 2},
  [11431] = {.lex_state = 420, .external_lex_state = 2},
  [11432] = {.lex_state = 420, .external_lex_state = 2},
  [11433] = {.lex_state = 10, .external_lex_state = 2},
  [11434] = {.lex_state = 420, .external_lex_state = 2},
  [11435] = {.lex_state = 420, .external_lex_state = 2},
  [11436] = {.lex_state = 420, .external_lex_state = 2},
  [11437] = {.lex_state = 240, .external_lex_state = 2},
  [11438] = {.lex_state = 420, .external_lex_state = 2},
  [11439] = {.lex_state = 420, .external_lex_state = 2},
  [11440] = {.lex_state = 420, .external_lex_state = 2},
  [11441] = {.lex_state = 420, .external_lex_state = 2},
  [11442] = {.lex_state = 420, .external_lex_state = 2},
  [11443] = {.lex_state = 420, .external_lex_state = 2},
  [11444] = {.lex_state = 420, .external_lex_state = 2},
  [11445] = {.lex_state = 420, .external_lex_state = 2},
  [11446] = {.lex_state = 420, .external_lex_state = 2},
  [11447] = {.lex_state = 420, .external_lex_state = 2},
  [11448] = {.lex_state = 420, .external_lex_state = 2},
  [11449] = {.lex_state = 28, .external_lex_state = 2},
  [11450] = {.lex_state = 420, .external_lex_state = 2},
  [11451] = {.lex_state = 426, .external_lex_state = 2},
  [11452] = {.lex_state = 426, .external_lex_state = 2},
  [11453] = {.lex_state = 211, .external_lex_state = 2},
  [11454] = {.lex_state = 420, .external_lex_state = 2},
  [11455] = {.lex_state = 420, .external_lex_state = 2},
  [11456] = {.lex_state = 426, .external_lex_state = 2},
  [11457] = {.lex_state = 420, .external_lex_state = 2},
  [11458] = {.lex_state = 420, .external_lex_state = 2},
  [11459] = {.lex_state = 420, .external_lex_state = 2},
  [11460] = {.lex_state = 16, .external_lex_state = 2},
  [11461] = {.lex_state = 28, .external_lex_state = 2},
  [11462] = {.lex_state = 420, .external_lex_state = 2},
  [11463] = {.lex_state = 420, .external_lex_state = 2},
  [11464] = {.lex_state = 426, .external_lex_state = 2},
  [11465] = {.lex_state = 420, .external_lex_state = 2},
  [11466] = {.lex_state = 420, .external_lex_state = 2},
  [11467] = {.lex_state = 420, .external_lex_state = 2},
  [11468] = {.lex_state = 420, .external_lex_state = 2},
  [11469] = {.lex_state = 420, .external_lex_state = 2},
  [11470] = {.lex_state = 420, .external_lex_state = 2},
  [11471] = {.lex_state = 420, .external_lex_state = 2},
  [11472] = {.lex_state = 420, .external_lex_state = 2},
  [11473] = {.lex_state = 420, .external_lex_state = 2},
  [11474] = {.lex_state = 426, .external_lex_state = 2},
  [11475] = {.lex_state = 217, .external_lex_state = 2},
  [11476] = {.lex_state = 17, .external_lex_state = 2},
  [11477] = {.lex_state = 17, .external_lex_state = 2},
  [11478] = {.lex_state = 17, .external_lex_state = 2},
  [11479] = {.lex_state = 17, .external_lex_state = 2},
  [11480] = {.lex_state = 17, .external_lex_state = 2},
  [11481] = {.lex_state = 17, .external_lex_state = 2},
  [11482] = {.lex_state = 17, .external_lex_state = 2},
  [11483] = {.lex_state = 17, .external_lex_state = 2},
  [11484] = {.lex_state = 420, .external_lex_state = 2},
  [11485] = {.lex_state = 17, .external_lex_state = 2},
  [11486] = {.lex_state = 17, .external_lex_state = 2},
  [11487] = {.lex_state = 17, .external_lex_state = 2},
  [11488] = {.lex_state = 17, .external_lex_state = 2},
  [11489] = {.lex_state = 217, .external_lex_state = 2},
  [11490] = {.lex_state = 211, .external_lex_state = 2},
  [11491] = {.lex_state = 420, .external_lex_state = 2},
  [11492] = {.lex_state = 420, .external_lex_state = 2},
  [11493] = {.lex_state = 17, .external_lex_state = 2},
  [11494] = {.lex_state = 420, .external_lex_state = 2},
  [11495] = {.lex_state = 420, .external_lex_state = 2},
  [11496] = {.lex_state = 420, .external_lex_state = 2},
  [11497] = {.lex_state = 420, .external_lex_state = 2},
  [11498] = {.lex_state = 420, .external_lex_state = 2},
  [11499] = {.lex_state = 420, .external_lex_state = 2},
  [11500] = {.lex_state = 420, .external_lex_state = 2},
  [11501] = {.lex_state = 420, .external_lex_state = 2},
  [11502] = {.lex_state = 28, .external_lex_state = 2},
  [11503] = {.lex_state = 420, .external_lex_state = 2},
  [11504] = {.lex_state = 420, .external_lex_state = 2},
  [11505] = {.lex_state = 420, .external_lex_state = 2},
  [11506] = {.lex_state = 420, .external_lex_state = 2},
  [11507] = {.lex_state = 217, .external_lex_state = 2},
  [11508] = {.lex_state = 420, .external_lex_state = 2},
  [11509] = {.lex_state = 420, .external_lex_state = 2},
  [11510] = {.lex_state = 432, .external_lex_state = 2},
  [11511] = {.lex_state = 420, .external_lex_state = 2},
  [11512] = {.lex_state = 420, .external_lex_state = 2},
  [11513] = {.lex_state = 420, .external_lex_state = 2},
  [11514] = {.lex_state = 426, .external_lex_state = 2},
  [11515] = {.lex_state = 217, .external_lex_state = 2},
  [11516] = {.lex_state = 420, .external_lex_state = 2},
  [11517] = {.lex_state = 217, .external_lex_state = 2},
  [11518] = {.lex_state = 420, .external_lex_state = 2},
  [11519] = {.lex_state = 420, .external_lex_state = 2},
  [11520] = {.lex_state = 28, .external_lex_state = 2},
  [11521] = {.lex_state = 420, .external_lex_state = 2},
  [11522] = {.lex_state = 420, .external_lex_state = 2},
  [11523] = {.lex_state = 28, .external_lex_state = 2},
  [11524] = {.lex_state = 420, .external_lex_state = 2},
  [11525] = {.lex_state = 420, .external_lex_state = 2},
  [11526] = {.lex_state = 420, .external_lex_state = 2},
  [11527] = {.lex_state = 420, .external_lex_state = 2},
  [11528] = {.lex_state = 420, .external_lex_state = 2},
  [11529] = {.lex_state = 240, .external_lex_state = 2},
  [11530] = {.lex_state = 420, .external_lex_state = 2},
  [11531] = {.lex_state = 420, .external_lex_state = 2},
  [11532] = {.lex_state = 420, .external_lex_state = 2},
  [11533] = {.lex_state = 420, .external_lex_state = 2},
  [11534] = {.lex_state = 420, .external_lex_state = 2},
  [11535] = {.lex_state = 420, .external_lex_state = 2},
  [11536] = {.lex_state = 420, .external_lex_state = 2},
  [11537] = {.lex_state = 426, .external_lex_state = 2},
  [11538] = {.lex_state = 426, .external_lex_state = 2},
  [11539] = {.lex_state = 420, .external_lex_state = 2},
  [11540] = {.lex_state = 420, .external_lex_state = 2},
  [11541] = {.lex_state = 420, .external_lex_state = 2},
  [11542] = {.lex_state = 217, .external_lex_state = 2},
  [11543] = {.lex_state = 28, .external_lex_state = 2},
  [11544] = {.lex_state = 28, .external_lex_state = 2},
  [11545] = {.lex_state = 420, .external_lex_state = 2},
  [11546] = {.lex_state = 420, .external_lex_state = 2},
  [11547] = {.lex_state = 420, .external_lex_state = 2},
  [11548] = {.lex_state = 420, .external_lex_state = 2},
  [11549] = {.lex_state = 420, .external_lex_state = 2},
  [11550] = {.lex_state = 420, .external_lex_state = 2},
  [11551] = {.lex_state = 420, .external_lex_state = 2},
  [11552] = {.lex_state = 420, .external_lex_state = 2},
  [11553] = {.lex_state = 426, .external_lex_state = 2},
  [11554] = {.lex_state = 420, .external_lex_state = 2},
  [11555] = {.lex_state = 420, .external_lex_state = 2},
  [11556] = {.lex_state = 420, .external_lex_state = 2},
  [11557] = {.lex_state = 426, .external_lex_state = 2},
  [11558] = {.lex_state = 28, .external_lex_state = 2},
  [11559] = {.lex_state = 420, .external_lex_state = 2},
  [11560] = {.lex_state = 426, .external_lex_state = 2},
  [11561] = {.lex_state = 420, .external_lex_state = 2},
  [11562] = {.lex_state = 420, .external_lex_state = 2},
  [11563] = {.lex_state = 420, .external_lex_state = 2},
  [11564] = {.lex_state = 28, .external_lex_state = 2},
  [11565] = {.lex_state = 420, .external_lex_state = 2},
  [11566] = {.lex_state = 420, .external_lex_state = 2},
  [11567] = {.lex_state = 420, .external_lex_state = 2},
  [11568] = {.lex_state = 420, .external_lex_state = 2},
  [11569] = {.lex_state = 426, .external_lex_state = 2},
  [11570] = {.lex_state = 10, .external_lex_state = 2},
  [11571] = {.lex_state = 420, .external_lex_state = 2},
  [11572] = {.lex_state = 420, .external_lex_state = 2},
  [11573] = {.lex_state = 420, .external_lex_state = 2},
  [11574] = {.lex_state = 10, .external_lex_state = 2},
  [11575] = {.lex_state = 420, .external_lex_state = 2},
  [11576] = {.lex_state = 420, .external_lex_state = 2},
  [11577] = {.lex_state = 420, .external_lex_state = 2},
  [11578] = {.lex_state = 426, .external_lex_state = 2},
  [11579] = {.lex_state = 420, .external_lex_state = 2},
  [11580] = {.lex_state = 16, .external_lex_state = 2},
  [11581] = {.lex_state = 420, .external_lex_state = 2},
  [11582] = {.lex_state = 420, .external_lex_state = 2},
  [11583] = {.lex_state = 16, .external_lex_state = 2},
  [11584] = {.lex_state = 16, .external_lex_state = 2},
  [11585] = {.lex_state = 28, .external_lex_state = 2},
  [11586] = {.lex_state = 420, .external_lex_state = 2},
  [11587] = {.lex_state = 16, .external_lex_state = 2},
  [11588] = {.lex_state = 420, .external_lex_state = 2},
  [11589] = {.lex_state = 426, .external_lex_state = 2},
  [11590] = {.lex_state = 420, .external_lex_state = 2},
  [11591] = {.lex_state = 420, .external_lex_state = 2},
  [11592] = {.lex_state = 28, .external_lex_state = 2},
  [11593] = {.lex_state = 420, .external_lex_state = 2},
  [11594] = {.lex_state = 420, .external_lex_state = 2},
  [11595] = {.lex_state = 16, .external_lex_state = 2},
  [11596] = {.lex_state = 420, .external_lex_state = 2},
  [11597] = {.lex_state = 420, .external_lex_state = 2},
  [11598] = {.lex_state = 420, .external_lex_state = 2},
  [11599] = {.lex_state = 420, .external_lex_state = 2},
  [11600] = {.lex_state = 426, .external_lex_state = 2},
  [11601] = {.lex_state = 420, .external_lex_state = 2},
  [11602] = {.lex_state = 28, .external_lex_state = 2},
  [11603] = {.lex_state = 17, .external_lex_state = 2},
  [11604] = {.lex_state = 420, .external_lex_state = 2},
  [11605] = {.lex_state = 420, .external_lex_state = 2},
  [11606] = {.lex_state = 420, .external_lex_state = 2},
  [11607] = {.lex_state = 420, .external_lex_state = 2},
  [11608] = {.lex_state = 420, .external_lex_state = 2},
  [11609] = {.lex_state = 420, .external_lex_state = 2},
  [11610] = {.lex_state = 420, .external_lex_state = 2},
  [11611] = {.lex_state = 420, .external_lex_state = 2},
  [11612] = {.lex_state = 420, .external_lex_state = 2},
  [11613] = {.lex_state = 420, .external_lex_state = 2},
  [11614] = {.lex_state = 420, .external_lex_state = 2},
  [11615] = {.lex_state = 420, .external_lex_state = 2},
  [11616] = {.lex_state = 420, .external_lex_state = 2},
  [11617] = {.lex_state = 420, .external_lex_state = 2},
  [11618] = {.lex_state = 420, .external_lex_state = 2},
  [11619] = {.lex_state = 420, .external_lex_state = 2},
  [11620] = {.lex_state = 10, .external_lex_state = 2},
  [11621] = {.lex_state = 10, .external_lex_state = 2},
  [11622] = {.lex_state = 28, .external_lex_state = 2},
  [11623] = {.lex_state = 420, .external_lex_state = 2},
  [11624] = {.lex_state = 420, .external_lex_state = 2},
  [11625] = {.lex_state = 28, .external_lex_state = 2},
  [11626] = {.lex_state = 420, .external_lex_state = 2},
  [11627] = {.lex_state = 420, .external_lex_state = 2},
  [11628] = {.lex_state = 17, .external_lex_state = 2},
  [11629] = {.lex_state = 420, .external_lex_state = 2},
  [11630] = {.lex_state = 420, .external_lex_state = 2},
  [11631] = {.lex_state = 17, .external_lex_state = 2},
  [11632] = {.lex_state = 174, .external_lex_state = 2},
  [11633] = {.lex_state = 426, .external_lex_state = 2},
  [11634] = {.lex_state = 10, .external_lex_state = 2},
  [11635] = {.lex_state = 420, .external_lex_state = 2},
  [11636] = {.lex_state = 420, .external_lex_state = 2},
  [11637] = {.lex_state = 420, .external_lex_state = 2},
  [11638] = {.lex_state = 420, .external_lex_state = 2},
  [11639] = {.lex_state = 174, .external_lex_state = 2},
  [11640] = {.lex_state = 420, .external_lex_state = 2},
  [11641] = {.lex_state = 174, .external_lex_state = 2},
  [11642] = {.lex_state = 420, .external_lex_state = 2},
  [11643] = {.lex_state = 420, .external_lex_state = 2},
  [11644] = {.lex_state = 420, .external_lex_state = 2},
  [11645] = {.lex_state = 420, .external_lex_state = 2},
  [11646] = {.lex_state = 420, .external_lex_state = 2},
  [11647] = {.lex_state = 420, .external_lex_state = 2},
  [11648] = {.lex_state = 426, .external_lex_state = 2},
  [11649] = {.lex_state = 420, .external_lex_state = 2},
  [11650] = {.lex_state = 420, .external_lex_state = 2},
  [11651] = {.lex_state = 420, .external_lex_state = 2},
  [11652] = {.lex_state = 420, .external_lex_state = 2},
  [11653] = {.lex_state = 420, .external_lex_state = 2},
  [11654] = {.lex_state = 420, .external_lex_state = 2},
  [11655] = {.lex_state = 420, .external_lex_state = 2},
  [11656] = {.lex_state = 420, .external_lex_state = 2},
  [11657] = {.lex_state = 420, .external_lex_state = 2},
  [11658] = {.lex_state = 426, .external_lex_state = 2},
  [11659] = {.lex_state = 420, .external_lex_state = 2},
  [11660] = {.lex_state = 420, .external_lex_state = 2},
  [11661] = {.lex_state = 420, .external_lex_state = 2},
  [11662] = {.lex_state = 420, .external_lex_state = 2},
  [11663] = {.lex_state = 28, .external_lex_state = 2},
  [11664] = {.lex_state = 420, .external_lex_state = 2},
  [11665] = {.lex_state = 420, .external_lex_state = 2},
  [11666] = {.lex_state = 420, .external_lex_state = 2},
  [11667] = {.lex_state = 420, .external_lex_state = 2},
  [11668] = {.lex_state = 426, .external_lex_state = 2},
  [11669] = {.lex_state = 420, .external_lex_state = 2},
  [11670] = {.lex_state = 420, .external_lex_state = 2},
  [11671] = {.lex_state = 420, .external_lex_state = 2},
  [11672] = {.lex_state = 28, .external_lex_state = 2},
  [11673] = {.lex_state = 165, .external_lex_state = 2},
  [11674] = {.lex_state = 165, .external_lex_state = 2},
  [11675] = {.lex_state = 420, .external_lex_state = 2},
  [11676] = {.lex_state = 420, .external_lex_state = 2},
  [11677] = {.lex_state = 17, .external_lex_state = 2},
  [11678] = {.lex_state = 165, .external_lex_state = 2},
  [11679] = {.lex_state = 420, .external_lex_state = 2},
  [11680] = {.lex_state = 420, .external_lex_state = 2},
  [11681] = {.lex_state = 420, .external_lex_state = 2},
  [11682] = {.lex_state = 28, .external_lex_state = 2},
  [11683] = {.lex_state = 420, .external_lex_state = 2},
  [11684] = {.lex_state = 28, .external_lex_state = 2},
  [11685] = {.lex_state = 420, .external_lex_state = 2},
  [11686] = {.lex_state = 420, .external_lex_state = 2},
  [11687] = {.lex_state = 420, .external_lex_state = 2},
  [11688] = {.lex_state = 420, .external_lex_state = 2},
  [11689] = {.lex_state = 420, .external_lex_state = 2},
  [11690] = {.lex_state = 420, .external_lex_state = 2},
  [11691] = {.lex_state = 426, .external_lex_state = 2},
  [11692] = {.lex_state = 426, .external_lex_state = 2},
  [11693] = {.lex_state = 420, .external_lex_state = 2},
  [11694] = {.lex_state = 420, .external_lex_state = 2},
  [11695] = {.lex_state = 420, .external_lex_state = 2},
  [11696] = {.lex_state = 426, .external_lex_state = 2},
  [11697] = {.lex_state = 420, .external_lex_state = 2},
  [11698] = {.lex_state = 420, .external_lex_state = 2},
  [11699] = {.lex_state = 164, .external_lex_state = 2},
  [11700] = {.lex_state = 420, .external_lex_state = 2},
  [11701] = {.lex_state = 420, .external_lex_state = 2},
  [11702] = {.lex_state = 420, .external_lex_state = 2},
  [11703] = {.lex_state = 420, .external_lex_state = 2},
  [11704] = {.lex_state = 420, .external_lex_state = 2},
  [11705] = {.lex_state = 170, .external_lex_state = 2},
  [11706] = {.lex_state = 426, .external_lex_state = 2},
  [11707] = {.lex_state = 8, .external_lex_state = 2},
  [11708] = {.lex_state = 426, .external_lex_state = 2},
  [11709] = {.lex_state = 426, .external_lex_state = 2},
  [11710] = {.lex_state = 426, .external_lex_state = 2},
  [11711] = {.lex_state = 28, .external_lex_state = 2},
  [11712] = {.lex_state = 420, .external_lex_state = 2},
  [11713] = {.lex_state = 420, .external_lex_state = 2},
  [11714] = {.lex_state = 420, .external_lex_state = 2},
  [11715] = {.lex_state = 420, .external_lex_state = 2},
  [11716] = {.lex_state = 420, .external_lex_state = 2},
  [11717] = {.lex_state = 420, .external_lex_state = 2},
  [11718] = {.lex_state = 420, .external_lex_state = 2},
  [11719] = {.lex_state = 420, .external_lex_state = 2},
  [11720] = {.lex_state = 426, .external_lex_state = 2},
  [11721] = {.lex_state = 420, .external_lex_state = 2},
  [11722] = {.lex_state = 420, .external_lex_state = 2},
  [11723] = {.lex_state = 420, .external_lex_state = 2},
  [11724] = {.lex_state = 420, .external_lex_state = 2},
  [11725] = {.lex_state = 420, .external_lex_state = 2},
  [11726] = {.lex_state = 420, .external_lex_state = 2},
  [11727] = {.lex_state = 420, .external_lex_state = 2},
  [11728] = {.lex_state = 420, .external_lex_state = 2},
  [11729] = {.lex_state = 420, .external_lex_state = 2},
  [11730] = {.lex_state = 420, .external_lex_state = 2},
  [11731] = {.lex_state = 420, .external_lex_state = 2},
  [11732] = {.lex_state = 420, .external_lex_state = 2},
  [11733] = {.lex_state = 28, .external_lex_state = 3},
  [11734] = {.lex_state = 31, .external_lex_state = 2},
  [11735] = {.lex_state = 426, .external_lex_state = 2},
  [11736] = {.lex_state = 426, .external_lex_state = 2},
  [11737] = {.lex_state = 426, .external_lex_state = 2},
  [11738] = {.lex_state = 426, .external_lex_state = 2},
  [11739] = {.lex_state = 426, .external_lex_state = 2},
  [11740] = {.lex_state = 31, .external_lex_state = 2},
  [11741] = {.lex_state = 31, .external_lex_state = 2},
  [11742] = {.lex_state = 31, .external_lex_state = 2},
  [11743] = {.lex_state = 426, .external_lex_state = 2},
  [11744] = {.lex_state = 426, .external_lex_state = 2},
  [11745] = {.lex_state = 426, .external_lex_state = 2},
  [11746] = {.lex_state = 426, .external_lex_state = 2},
  [11747] = {.lex_state = 426, .external_lex_state = 2},
  [11748] = {.lex_state = 164, .external_lex_state = 2},
  [11749] = {.lex_state = 426, .external_lex_state = 2},
  [11750] = {.lex_state = 426, .external_lex_state = 2},
  [11751] = {.lex_state = 420, .external_lex_state = 2},
  [11752] = {.lex_state = 28, .external_lex_state = 3},
  [11753] = {.lex_state = 420, .external_lex_state = 2},
  [11754] = {.lex_state = 28, .external_lex_state = 2},
  [11755] = {.lex_state = 420, .external_lex_state = 2},
  [11756] = {.lex_state = 426, .external_lex_state = 2},
  [11757] = {.lex_state = 420, .external_lex_state = 2},
  [11758] = {.lex_state = 16, .external_lex_state = 2},
  [11759] = {.lex_state = 16, .external_lex_state = 2},
  [11760] = {.lex_state = 16, .external_lex_state = 2},
  [11761] = {.lex_state = 16, .external_lex_state = 2},
  [11762] = {.lex_state = 16, .external_lex_state = 2},
  [11763] = {.lex_state = 420, .external_lex_state = 2},
  [11764] = {.lex_state = 28, .external_lex_state = 2},
  [11765] = {.lex_state = 28, .external_lex_state = 2},
  [11766] = {.lex_state = 426, .external_lex_state = 2},
  [11767] = {.lex_state = 426, .external_lex_state = 2},
  [11768] = {.lex_state = 426, .external_lex_state = 2},
  [11769] = {.lex_state = 426, .external_lex_state = 2},
  [11770] = {.lex_state = 426, .external_lex_state = 2},
  [11771] = {.lex_state = 31, .external_lex_state = 2},
  [11772] = {.lex_state = 426, .external_lex_state = 2},
  [11773] = {.lex_state = 31, .external_lex_state = 2},
  [11774] = {.lex_state = 426, .external_lex_state = 2},
  [11775] = {.lex_state = 31, .external_lex_state = 2},
  [11776] = {.lex_state = 31, .external_lex_state = 2},
  [11777] = {.lex_state = 31, .external_lex_state = 2},
  [11778] = {.lex_state = 16, .external_lex_state = 2},
  [11779] = {.lex_state = 420, .external_lex_state = 2},
  [11780] = {.lex_state = 426, .external_lex_state = 2},
  [11781] = {.lex_state = 426, .external_lex_state = 2},
  [11782] = {.lex_state = 420, .external_lex_state = 2},
  [11783] = {.lex_state = 420, .external_lex_state = 2},
  [11784] = {.lex_state = 426, .external_lex_state = 2},
  [11785] = {.lex_state = 31, .external_lex_state = 2},
  [11786] = {.lex_state = 420, .external_lex_state = 2},
  [11787] = {.lex_state = 426, .external_lex_state = 2},
  [11788] = {.lex_state = 164, .external_lex_state = 2},
  [11789] = {.lex_state = 31, .external_lex_state = 2},
  [11790] = {.lex_state = 31, .external_lex_state = 2},
  [11791] = {.lex_state = 16, .external_lex_state = 2},
  [11792] = {.lex_state = 31, .external_lex_state = 2},
  [11793] = {.lex_state = 426, .external_lex_state = 2},
  [11794] = {.lex_state = 31, .external_lex_state = 2},
  [11795] = {.lex_state = 164, .external_lex_state = 2},
  [11796] = {.lex_state = 426, .external_lex_state = 2},
  [11797] = {.lex_state = 31, .external_lex_state = 2},
  [11798] = {.lex_state = 31, .external_lex_state = 2},
  [11799] = {.lex_state = 31, .external_lex_state = 2},
  [11800] = {.lex_state = 426, .external_lex_state = 2},
  [11801] = {.lex_state = 16, .external_lex_state = 2},
  [11802] = {.lex_state = 31, .external_lex_state = 2},
  [11803] = {.lex_state = 31, .external_lex_state = 2},
  [11804] = {.lex_state = 31, .external_lex_state = 2},
  [11805] = {.lex_state = 431, .external_lex_state = 2},
  [11806] = {.lex_state = 31, .external_lex_state = 2},
  [11807] = {.lex_state = 31, .external_lex_state = 2},
  [11808] = {.lex_state = 31, .external_lex_state = 2},
  [11809] = {.lex_state = 31, .external_lex_state = 2},
  [11810] = {.lex_state = 17, .external_lex_state = 2},
  [11811] = {.lex_state = 426, .external_lex_state = 2},
  [11812] = {.lex_state = 426, .external_lex_state = 2},
  [11813] = {.lex_state = 31, .external_lex_state = 2},
  [11814] = {.lex_state = 31, .external_lex_state = 2},
  [11815] = {.lex_state = 28, .external_lex_state = 3},
  [11816] = {.lex_state = 426, .external_lex_state = 2},
  [11817] = {.lex_state = 426, .external_lex_state = 2},
  [11818] = {.lex_state = 426, .external_lex_state = 2},
  [11819] = {.lex_state = 31, .external_lex_state = 2},
  [11820] = {.lex_state = 31, .external_lex_state = 2},
  [11821] = {.lex_state = 426, .external_lex_state = 2},
  [11822] = {.lex_state = 31, .external_lex_state = 2},
  [11823] = {.lex_state = 420, .external_lex_state = 2},
  [11824] = {.lex_state = 17, .external_lex_state = 2},
  [11825] = {.lex_state = 426, .external_lex_state = 2},
  [11826] = {.lex_state = 17, .external_lex_state = 2},
  [11827] = {.lex_state = 17, .external_lex_state = 2},
  [11828] = {.lex_state = 17, .external_lex_state = 2},
  [11829] = {.lex_state = 17, .external_lex_state = 2},
  [11830] = {.lex_state = 17, .external_lex_state = 2},
  [11831] = {.lex_state = 17, .external_lex_state = 2},
  [11832] = {.lex_state = 426, .external_lex_state = 2},
  [11833] = {.lex_state = 17, .external_lex_state = 2},
  [11834] = {.lex_state = 17, .external_lex_state = 2},
  [11835] = {.lex_state = 17, .external_lex_state = 2},
  [11836] = {.lex_state = 17, .external_lex_state = 2},
  [11837] = {.lex_state = 28, .external_lex_state = 3},
  [11838] = {.lex_state = 426, .external_lex_state = 2},
  [11839] = {.lex_state = 420, .external_lex_state = 2},
  [11840] = {.lex_state = 17, .external_lex_state = 2},
  [11841] = {.lex_state = 426, .external_lex_state = 2},
  [11842] = {.lex_state = 420, .external_lex_state = 2},
  [11843] = {.lex_state = 426, .external_lex_state = 2},
  [11844] = {.lex_state = 164, .external_lex_state = 2},
  [11845] = {.lex_state = 240, .external_lex_state = 2},
  [11846] = {.lex_state = 28, .external_lex_state = 3},
  [11847] = {.lex_state = 426, .external_lex_state = 2},
  [11848] = {.lex_state = 426, .external_lex_state = 2},
  [11849] = {.lex_state = 420, .external_lex_state = 2},
  [11850] = {.lex_state = 164, .external_lex_state = 2},
  [11851] = {.lex_state = 426, .external_lex_state = 2},
  [11852] = {.lex_state = 426, .external_lex_state = 2},
  [11853] = {.lex_state = 426, .external_lex_state = 2},
  [11854] = {.lex_state = 210, .external_lex_state = 2},
  [11855] = {.lex_state = 8, .external_lex_state = 2},
  [11856] = {.lex_state = 164, .external_lex_state = 2},
  [11857] = {.lex_state = 211, .external_lex_state = 2},
  [11858] = {.lex_state = 426, .external_lex_state = 2},
  [11859] = {.lex_state = 426, .external_lex_state = 2},
  [11860] = {.lex_state = 426, .external_lex_state = 2},
  [11861] = {.lex_state = 426, .external_lex_state = 2},
  [11862] = {.lex_state = 426, .external_lex_state = 2},
  [11863] = {.lex_state = 28, .external_lex_state = 3},
  [11864] = {.lex_state = 16, .external_lex_state = 2},
  [11865] = {.lex_state = 31, .external_lex_state = 2},
  [11866] = {.lex_state = 240, .external_lex_state = 2},
  [11867] = {.lex_state = 426, .external_lex_state = 2},
  [11868] = {.lex_state = 426, .external_lex_state = 2},
  [11869] = {.lex_state = 426, .external_lex_state = 2},
  [11870] = {.lex_state = 16, .external_lex_state = 2},
  [11871] = {.lex_state = 16, .external_lex_state = 2},
  [11872] = {.lex_state = 420, .external_lex_state = 2},
  [11873] = {.lex_state = 426, .external_lex_state = 2},
  [11874] = {.lex_state = 16, .external_lex_state = 2},
  [11875] = {.lex_state = 16, .external_lex_state = 2},
  [11876] = {.lex_state = 16, .external_lex_state = 2},
  [11877] = {.lex_state = 426, .external_lex_state = 2},
  [11878] = {.lex_state = 16, .external_lex_state = 2},
  [11879] = {.lex_state = 16, .external_lex_state = 2},
  [11880] = {.lex_state = 420, .external_lex_state = 2},
  [11881] = {.lex_state = 420, .external_lex_state = 2},
  [11882] = {.lex_state = 16, .external_lex_state = 2},
  [11883] = {.lex_state = 164, .external_lex_state = 2},
  [11884] = {.lex_state = 16, .external_lex_state = 2},
  [11885] = {.lex_state = 16, .external_lex_state = 2},
  [11886] = {.lex_state = 16, .external_lex_state = 2},
  [11887] = {.lex_state = 16, .external_lex_state = 2},
  [11888] = {.lex_state = 16, .external_lex_state = 2},
  [11889] = {.lex_state = 420, .external_lex_state = 2},
  [11890] = {.lex_state = 420, .external_lex_state = 2},
  [11891] = {.lex_state = 420, .external_lex_state = 2},
  [11892] = {.lex_state = 420, .external_lex_state = 2},
  [11893] = {.lex_state = 31, .external_lex_state = 2},
  [11894] = {.lex_state = 420, .external_lex_state = 2},
  [11895] = {.lex_state = 28, .external_lex_state = 3},
  [11896] = {.lex_state = 16, .external_lex_state = 2},
  [11897] = {.lex_state = 16, .external_lex_state = 2},
  [11898] = {.lex_state = 164, .external_lex_state = 2},
  [11899] = {.lex_state = 17, .external_lex_state = 2},
  [11900] = {.lex_state = 17, .external_lex_state = 2},
  [11901] = {.lex_state = 28, .external_lex_state = 2},
  [11902] = {.lex_state = 16, .external_lex_state = 2},
  [11903] = {.lex_state = 15, .external_lex_state = 2},
  [11904] = {.lex_state = 15, .external_lex_state = 2},
  [11905] = {.lex_state = 14, .external_lex_state = 2},
  [11906] = {.lex_state = 14, .external_lex_state = 2},
  [11907] = {.lex_state = 28, .external_lex_state = 2},
  [11908] = {.lex_state = 28, .external_lex_state = 2},
  [11909] = {.lex_state = 16, .external_lex_state = 2},
  [11910] = {.lex_state = 28, .external_lex_state = 2},
  [11911] = {.lex_state = 28, .external_lex_state = 2},
  [11912] = {.lex_state = 14, .external_lex_state = 2},
  [11913] = {.lex_state = 426, .external_lex_state = 2},
  [11914] = {.lex_state = 28, .external_lex_state = 2},
  [11915] = {.lex_state = 14, .external_lex_state = 2},
  [11916] = {.lex_state = 14, .external_lex_state = 2},
  [11917] = {.lex_state = 28, .external_lex_state = 2},
  [11918] = {.lex_state = 426, .external_lex_state = 2},
  [11919] = {.lex_state = 14, .external_lex_state = 2},
  [11920] = {.lex_state = 431, .external_lex_state = 2},
  [11921] = {.lex_state = 431, .external_lex_state = 2},
  [11922] = {.lex_state = 431, .external_lex_state = 2},
  [11923] = {.lex_state = 217, .external_lex_state = 2},
  [11924] = {.lex_state = 14, .external_lex_state = 2},
  [11925] = {.lex_state = 14, .external_lex_state = 2},
  [11926] = {.lex_state = 14, .external_lex_state = 2},
  [11927] = {.lex_state = 14, .external_lex_state = 2},
  [11928] = {.lex_state = 14, .external_lex_state = 2},
  [11929] = {.lex_state = 14, .external_lex_state = 2},
  [11930] = {.lex_state = 28, .external_lex_state = 2},
  [11931] = {.lex_state = 14, .external_lex_state = 2},
  [11932] = {.lex_state = 14, .external_lex_state = 2},
  [11933] = {.lex_state = 28, .external_lex_state = 2},
  [11934] = {.lex_state = 14, .external_lex_state = 2},
  [11935] = {.lex_state = 28, .external_lex_state = 2},
  [11936] = {.lex_state = 14, .external_lex_state = 2},
  [11937] = {.lex_state = 14, .external_lex_state = 2},
  [11938] = {.lex_state = 14, .external_lex_state = 2},
  [11939] = {.lex_state = 426, .external_lex_state = 2},
  [11940] = {.lex_state = 206, .external_lex_state = 2},
  [11941] = {.lex_state = 28, .external_lex_state = 2},
  [11942] = {.lex_state = 28, .external_lex_state = 2},
  [11943] = {.lex_state = 15, .external_lex_state = 2},
  [11944] = {.lex_state = 15, .external_lex_state = 2},
  [11945] = {.lex_state = 15, .external_lex_state = 2},
  [11946] = {.lex_state = 15, .external_lex_state = 2},
  [11947] = {.lex_state = 15, .external_lex_state = 2},
  [11948] = {.lex_state = 15, .external_lex_state = 2},
  [11949] = {.lex_state = 15, .external_lex_state = 2},
  [11950] = {.lex_state = 28, .external_lex_state = 2},
  [11951] = {.lex_state = 15, .external_lex_state = 2},
  [11952] = {.lex_state = 15, .external_lex_state = 2},
  [11953] = {.lex_state = 15, .external_lex_state = 2},
  [11954] = {.lex_state = 15, .external_lex_state = 2},
  [11955] = {.lex_state = 28, .external_lex_state = 2},
  [11956] = {.lex_state = 15, .external_lex_state = 2},
  [11957] = {.lex_state = 28, .external_lex_state = 2},
  [11958] = {.lex_state = 431, .external_lex_state = 2},
  [11959] = {.lex_state = 15, .external_lex_state = 2},
  [11960] = {.lex_state = 15, .external_lex_state = 2},
  [11961] = {.lex_state = 14, .external_lex_state = 2},
  [11962] = {.lex_state = 15, .external_lex_state = 2},
  [11963] = {.lex_state = 14, .external_lex_state = 2},
  [11964] = {.lex_state = 28, .external_lex_state = 2},
  [11965] = {.lex_state = 14, .external_lex_state = 2},
  [11966] = {.lex_state = 431, .external_lex_state = 2},
  [11967] = {.lex_state = 28, .external_lex_state = 2},
  [11968] = {.lex_state = 431, .external_lex_state = 2},
  [11969] = {.lex_state = 14, .external_lex_state = 2},
  [11970] = {.lex_state = 16, .external_lex_state = 2},
  [11971] = {.lex_state = 206, .external_lex_state = 2},
  [11972] = {.lex_state = 16, .external_lex_state = 2},
  [11973] = {.lex_state = 206, .external_lex_state = 2},
  [11974] = {.lex_state = 206, .external_lex_state = 2},
  [11975] = {.lex_state = 206, .external_lex_state = 2},
  [11976] = {.lex_state = 426, .external_lex_state = 2},
  [11977] = {.lex_state = 16, .external_lex_state = 2},
  [11978] = {.lex_state = 8, .external_lex_state = 2},
  [11979] = {.lex_state = 28, .external_lex_state = 2},
  [11980] = {.lex_state = 28, .external_lex_state = 2},
  [11981] = {.lex_state = 217, .external_lex_state = 2},
  [11982] = {.lex_state = 16, .external_lex_state = 2},
  [11983] = {.lex_state = 426, .external_lex_state = 2},
  [11984] = {.lex_state = 426, .external_lex_state = 2},
  [11985] = {.lex_state = 16, .external_lex_state = 2},
  [11986] = {.lex_state = 16, .external_lex_state = 2},
  [11987] = {.lex_state = 14, .external_lex_state = 2},
  [11988] = {.lex_state = 16, .external_lex_state = 2},
  [11989] = {.lex_state = 426, .external_lex_state = 2},
  [11990] = {.lex_state = 14, .external_lex_state = 2},
  [11991] = {.lex_state = 14, .external_lex_state = 2},
  [11992] = {.lex_state = 16, .external_lex_state = 2},
  [11993] = {.lex_state = 14, .external_lex_state = 2},
  [11994] = {.lex_state = 14, .external_lex_state = 2},
  [11995] = {.lex_state = 14, .external_lex_state = 2},
  [11996] = {.lex_state = 14, .external_lex_state = 2},
  [11997] = {.lex_state = 28, .external_lex_state = 2},
  [11998] = {.lex_state = 15, .external_lex_state = 2},
  [11999] = {.lex_state = 217, .external_lex_state = 2},
  [12000] = {.lex_state = 217, .external_lex_state = 2},
  [12001] = {.lex_state = 14, .external_lex_state = 2},
  [12002] = {.lex_state = 28, .external_lex_state = 2},
  [12003] = {.lex_state = 420, .external_lex_state = 2},
  [12004] = {.lex_state = 15, .external_lex_state = 2},
  [12005] = {.lex_state = 15, .external_lex_state = 2},
  [12006] = {.lex_state = 206, .external_lex_state = 2},
  [12007] = {.lex_state = 206, .external_lex_state = 2},
  [12008] = {.lex_state = 28, .external_lex_state = 2},
  [12009] = {.lex_state = 206, .external_lex_state = 2},
  [12010] = {.lex_state = 426, .external_lex_state = 2},
  [12011] = {.lex_state = 14, .external_lex_state = 2},
  [12012] = {.lex_state = 15, .external_lex_state = 2},
  [12013] = {.lex_state = 28, .external_lex_state = 2},
  [12014] = {.lex_state = 14, .external_lex_state = 2},
  [12015] = {.lex_state = 15, .external_lex_state = 2},
  [12016] = {.lex_state = 8, .external_lex_state = 2},
  [12017] = {.lex_state = 28, .external_lex_state = 2},
  [12018] = {.lex_state = 14, .external_lex_state = 2},
  [12019] = {.lex_state = 28, .external_lex_state = 2},
  [12020] = {.lex_state = 28, .external_lex_state = 2},
  [12021] = {.lex_state = 28, .external_lex_state = 2},
  [12022] = {.lex_state = 28, .external_lex_state = 2},
  [12023] = {.lex_state = 14, .external_lex_state = 2},
  [12024] = {.lex_state = 28, .external_lex_state = 2},
  [12025] = {.lex_state = 15, .external_lex_state = 2},
  [12026] = {.lex_state = 15, .external_lex_state = 2},
  [12027] = {.lex_state = 28, .external_lex_state = 2},
  [12028] = {.lex_state = 426, .external_lex_state = 2},
  [12029] = {.lex_state = 14, .external_lex_state = 2},
  [12030] = {.lex_state = 426, .external_lex_state = 2},
  [12031] = {.lex_state = 16, .external_lex_state = 2},
  [12032] = {.lex_state = 16, .external_lex_state = 2},
  [12033] = {.lex_state = 16, .external_lex_state = 2},
  [12034] = {.lex_state = 420, .external_lex_state = 2},
  [12035] = {.lex_state = 431, .external_lex_state = 2},
  [12036] = {.lex_state = 14, .external_lex_state = 2},
  [12037] = {.lex_state = 15, .external_lex_state = 2},
  [12038] = {.lex_state = 28, .external_lex_state = 2},
  [12039] = {.lex_state = 15, .external_lex_state = 2},
  [12040] = {.lex_state = 16, .external_lex_state = 2},
  [12041] = {.lex_state = 16, .external_lex_state = 2},
  [12042] = {.lex_state = 16, .external_lex_state = 2},
  [12043] = {.lex_state = 16, .external_lex_state = 2},
  [12044] = {.lex_state = 16, .external_lex_state = 2},
  [12045] = {.lex_state = 28, .external_lex_state = 2},
  [12046] = {.lex_state = 16, .external_lex_state = 2},
  [12047] = {.lex_state = 28, .external_lex_state = 2},
  [12048] = {.lex_state = 426, .external_lex_state = 2},
  [12049] = {.lex_state = 426, .external_lex_state = 2},
  [12050] = {.lex_state = 16, .external_lex_state = 2},
  [12051] = {.lex_state = 426, .external_lex_state = 2},
  [12052] = {.lex_state = 14, .external_lex_state = 2},
  [12053] = {.lex_state = 16, .external_lex_state = 2},
  [12054] = {.lex_state = 28, .external_lex_state = 2},
  [12055] = {.lex_state = 16, .external_lex_state = 2},
  [12056] = {.lex_state = 16, .external_lex_state = 2},
  [12057] = {.lex_state = 218, .external_lex_state = 2},
  [12058] = {.lex_state = 426, .external_lex_state = 2},
  [12059] = {.lex_state = 426, .external_lex_state = 2},
  [12060] = {.lex_state = 426, .external_lex_state = 2},
  [12061] = {.lex_state = 28, .external_lex_state = 2},
  [12062] = {.lex_state = 218, .external_lex_state = 2},
  [12063] = {.lex_state = 28, .external_lex_state = 2},
  [12064] = {.lex_state = 28, .external_lex_state = 2},
  [12065] = {.lex_state = 28, .external_lex_state = 2},
  [12066] = {.lex_state = 426, .external_lex_state = 2},
  [12067] = {.lex_state = 420, .external_lex_state = 2},
  [12068] = {.lex_state = 426, .external_lex_state = 2},
  [12069] = {.lex_state = 426, .external_lex_state = 2},
  [12070] = {.lex_state = 14, .external_lex_state = 2},
  [12071] = {.lex_state = 426, .external_lex_state = 2},
  [12072] = {.lex_state = 426, .external_lex_state = 2},
  [12073] = {.lex_state = 426, .external_lex_state = 2},
  [12074] = {.lex_state = 426, .external_lex_state = 2},
  [12075] = {.lex_state = 431, .external_lex_state = 2},
  [12076] = {.lex_state = 426, .external_lex_state = 2},
  [12077] = {.lex_state = 426, .external_lex_state = 2},
  [12078] = {.lex_state = 426, .external_lex_state = 2},
  [12079] = {.lex_state = 28, .external_lex_state = 2},
  [12080] = {.lex_state = 28, .external_lex_state = 2},
  [12081] = {.lex_state = 426, .external_lex_state = 2},
  [12082] = {.lex_state = 426, .external_lex_state = 2},
  [12083] = {.lex_state = 8, .external_lex_state = 2},
  [12084] = {.lex_state = 426, .external_lex_state = 2},
  [12085] = {.lex_state = 420, .external_lex_state = 2},
  [12086] = {.lex_state = 14, .external_lex_state = 2},
  [12087] = {.lex_state = 14, .external_lex_state = 2},
  [12088] = {.lex_state = 14, .external_lex_state = 2},
  [12089] = {.lex_state = 426, .external_lex_state = 2},
  [12090] = {.lex_state = 28, .external_lex_state = 2},
  [12091] = {.lex_state = 14, .external_lex_state = 2},
  [12092] = {.lex_state = 28, .external_lex_state = 2},
  [12093] = {.lex_state = 426, .external_lex_state = 2},
  [12094] = {.lex_state = 14, .external_lex_state = 2},
  [12095] = {.lex_state = 28, .external_lex_state = 2},
  [12096] = {.lex_state = 28, .external_lex_state = 2},
  [12097] = {.lex_state = 14, .external_lex_state = 2},
  [12098] = {.lex_state = 14, .external_lex_state = 2},
  [12099] = {.lex_state = 218, .external_lex_state = 2},
  [12100] = {.lex_state = 16, .external_lex_state = 2},
  [12101] = {.lex_state = 16, .external_lex_state = 2},
  [12102] = {.lex_state = 16, .external_lex_state = 2},
  [12103] = {.lex_state = 16, .external_lex_state = 2},
  [12104] = {.lex_state = 14, .external_lex_state = 2},
  [12105] = {.lex_state = 14, .external_lex_state = 2},
  [12106] = {.lex_state = 14, .external_lex_state = 2},
  [12107] = {.lex_state = 14, .external_lex_state = 2},
  [12108] = {.lex_state = 14, .external_lex_state = 2},
  [12109] = {.lex_state = 14, .external_lex_state = 2},
  [12110] = {.lex_state = 14, .external_lex_state = 2},
  [12111] = {.lex_state = 16, .external_lex_state = 2},
  [12112] = {.lex_state = 426, .external_lex_state = 2},
  [12113] = {.lex_state = 14, .external_lex_state = 2},
  [12114] = {.lex_state = 14, .external_lex_state = 2},
  [12115] = {.lex_state = 14, .external_lex_state = 2},
  [12116] = {.lex_state = 14, .external_lex_state = 2},
  [12117] = {.lex_state = 28, .external_lex_state = 2},
  [12118] = {.lex_state = 14, .external_lex_state = 2},
  [12119] = {.lex_state = 14, .external_lex_state = 2},
  [12120] = {.lex_state = 14, .external_lex_state = 2},
  [12121] = {.lex_state = 14, .external_lex_state = 2},
  [12122] = {.lex_state = 426, .external_lex_state = 2},
  [12123] = {.lex_state = 16, .external_lex_state = 2},
  [12124] = {.lex_state = 426, .external_lex_state = 2},
  [12125] = {.lex_state = 426, .external_lex_state = 2},
  [12126] = {.lex_state = 426, .external_lex_state = 2},
  [12127] = {.lex_state = 426, .external_lex_state = 2},
  [12128] = {.lex_state = 28, .external_lex_state = 2},
  [12129] = {.lex_state = 14, .external_lex_state = 2},
  [12130] = {.lex_state = 14, .external_lex_state = 2},
  [12131] = {.lex_state = 431, .external_lex_state = 2},
  [12132] = {.lex_state = 28, .external_lex_state = 2},
  [12133] = {.lex_state = 431, .external_lex_state = 2},
  [12134] = {.lex_state = 14, .external_lex_state = 2},
  [12135] = {.lex_state = 14, .external_lex_state = 2},
  [12136] = {.lex_state = 14, .external_lex_state = 2},
  [12137] = {.lex_state = 28, .external_lex_state = 2},
  [12138] = {.lex_state = 28, .external_lex_state = 2},
  [12139] = {.lex_state = 14, .external_lex_state = 2},
  [12140] = {.lex_state = 14, .external_lex_state = 2},
  [12141] = {.lex_state = 14, .external_lex_state = 2},
  [12142] = {.lex_state = 16, .external_lex_state = 2},
  [12143] = {.lex_state = 16, .external_lex_state = 2},
  [12144] = {.lex_state = 28, .external_lex_state = 2},
  [12145] = {.lex_state = 14, .external_lex_state = 2},
  [12146] = {.lex_state = 14, .external_lex_state = 2},
  [12147] = {.lex_state = 14, .external_lex_state = 2},
  [12148] = {.lex_state = 14, .external_lex_state = 2},
  [12149] = {.lex_state = 218, .external_lex_state = 2},
  [12150] = {.lex_state = 14, .external_lex_state = 2},
  [12151] = {.lex_state = 14, .external_lex_state = 2},
  [12152] = {.lex_state = 14, .external_lex_state = 2},
  [12153] = {.lex_state = 14, .external_lex_state = 2},
  [12154] = {.lex_state = 14, .external_lex_state = 2},
  [12155] = {.lex_state = 28, .external_lex_state = 2},
  [12156] = {.lex_state = 28, .external_lex_state = 2},
  [12157] = {.lex_state = 16, .external_lex_state = 2},
  [12158] = {.lex_state = 28, .external_lex_state = 2},
  [12159] = {.lex_state = 14, .external_lex_state = 2},
  [12160] = {.lex_state = 16, .external_lex_state = 2},
  [12161] = {.lex_state = 14, .external_lex_state = 2},
  [12162] = {.lex_state = 28, .external_lex_state = 2},
  [12163] = {.lex_state = 16, .external_lex_state = 2},
  [12164] = {.lex_state = 16, .external_lex_state = 2},
  [12165] = {.lex_state = 28, .external_lex_state = 2},
  [12166] = {.lex_state = 16, .external_lex_state = 2},
  [12167] = {.lex_state = 16, .external_lex_state = 2},
  [12168] = {.lex_state = 16, .external_lex_state = 2},
  [12169] = {.lex_state = 16, .external_lex_state = 2},
  [12170] = {.lex_state = 14, .external_lex_state = 2},
  [12171] = {.lex_state = 14, .external_lex_state = 2},
  [12172] = {.lex_state = 16, .external_lex_state = 2},
  [12173] = {.lex_state = 426, .external_lex_state = 2},
  [12174] = {.lex_state = 28, .external_lex_state = 2},
  [12175] = {.lex_state = 14, .external_lex_state = 2},
  [12176] = {.lex_state = 14, .external_lex_state = 2},
  [12177] = {.lex_state = 28, .external_lex_state = 2},
  [12178] = {.lex_state = 28, .external_lex_state = 2},
  [12179] = {.lex_state = 14, .external_lex_state = 2},
  [12180] = {.lex_state = 28, .external_lex_state = 2},
  [12181] = {.lex_state = 420, .external_lex_state = 2},
  [12182] = {.lex_state = 16, .external_lex_state = 2},
  [12183] = {.lex_state = 16, .external_lex_state = 2},
  [12184] = {.lex_state = 14, .external_lex_state = 2},
  [12185] = {.lex_state = 28, .external_lex_state = 2},
  [12186] = {.lex_state = 426, .external_lex_state = 2},
  [12187] = {.lex_state = 14, .external_lex_state = 2},
  [12188] = {.lex_state = 14, .external_lex_state = 2},
  [12189] = {.lex_state = 426, .external_lex_state = 2},
  [12190] = {.lex_state = 14, .external_lex_state = 2},
  [12191] = {.lex_state = 14, .external_lex_state = 2},
  [12192] = {.lex_state = 8, .external_lex_state = 2},
  [12193] = {.lex_state = 14, .external_lex_state = 2},
  [12194] = {.lex_state = 28, .external_lex_state = 2},
  [12195] = {.lex_state = 14, .external_lex_state = 2},
  [12196] = {.lex_state = 14, .external_lex_state = 2},
  [12197] = {.lex_state = 14, .external_lex_state = 2},
  [12198] = {.lex_state = 28, .external_lex_state = 2},
  [12199] = {.lex_state = 426, .external_lex_state = 2},
  [12200] = {.lex_state = 28, .external_lex_state = 2},
  [12201] = {.lex_state = 426, .external_lex_state = 2},
  [12202] = {.lex_state = 426, .external_lex_state = 2},
  [12203] = {.lex_state = 426, .external_lex_state = 2},
  [12204] = {.lex_state = 28, .external_lex_state = 2},
  [12205] = {.lex_state = 14, .external_lex_state = 2},
  [12206] = {.lex_state = 426, .external_lex_state = 2},
  [12207] = {.lex_state = 28, .external_lex_state = 2},
  [12208] = {.lex_state = 14, .external_lex_state = 2},
  [12209] = {.lex_state = 218, .external_lex_state = 2},
  [12210] = {.lex_state = 14, .external_lex_state = 2},
  [12211] = {.lex_state = 16, .external_lex_state = 2},
  [12212] = {.lex_state = 15, .external_lex_state = 2},
  [12213] = {.lex_state = 14, .external_lex_state = 2},
  [12214] = {.lex_state = 16, .external_lex_state = 2},
  [12215] = {.lex_state = 197, .external_lex_state = 5},
  [12216] = {.lex_state = 15, .external_lex_state = 2},
  [12217] = {.lex_state = 15, .external_lex_state = 2},
  [12218] = {.lex_state = 197, .external_lex_state = 5},
  [12219] = {.lex_state = 16, .external_lex_state = 2},
  [12220] = {.lex_state = 197, .external_lex_state = 5},
  [12221] = {.lex_state = 197, .external_lex_state = 5},
  [12222] = {.lex_state = 14, .external_lex_state = 2},
  [12223] = {.lex_state = 28, .external_lex_state = 2},
  [12224] = {.lex_state = 14, .external_lex_state = 2},
  [12225] = {.lex_state = 16, .external_lex_state = 2},
  [12226] = {.lex_state = 28, .external_lex_state = 2},
  [12227] = {.lex_state = 14, .external_lex_state = 2},
  [12228] = {.lex_state = 16, .external_lex_state = 2},
  [12229] = {.lex_state = 14, .external_lex_state = 2},
  [12230] = {.lex_state = 28, .external_lex_state = 2},
  [12231] = {.lex_state = 16, .external_lex_state = 2},
  [12232] = {.lex_state = 28, .external_lex_state = 2},
  [12233] = {.lex_state = 15, .external_lex_state = 2},
  [12234] = {.lex_state = 14, .external_lex_state = 2},
  [12235] = {.lex_state = 15, .external_lex_state = 2},
  [12236] = {.lex_state = 16, .external_lex_state = 2},
  [12237] = {.lex_state = 197, .external_lex_state = 5},
  [12238] = {.lex_state = 16, .external_lex_state = 2},
  [12239] = {.lex_state = 16, .external_lex_state = 2},
  [12240] = {.lex_state = 197, .external_lex_state = 5},
  [12241] = {.lex_state = 426, .external_lex_state = 2},
  [12242] = {.lex_state = 16, .external_lex_state = 2},
  [12243] = {.lex_state = 197, .external_lex_state = 5},
  [12244] = {.lex_state = 197, .external_lex_state = 5},
  [12245] = {.lex_state = 197, .external_lex_state = 5},
  [12246] = {.lex_state = 15, .external_lex_state = 2},
  [12247] = {.lex_state = 15, .external_lex_state = 2},
  [12248] = {.lex_state = 16, .external_lex_state = 2},
  [12249] = {.lex_state = 28, .external_lex_state = 2},
  [12250] = {.lex_state = 15, .external_lex_state = 2},
  [12251] = {.lex_state = 197, .external_lex_state = 5},
  [12252] = {.lex_state = 15, .external_lex_state = 2},
  [12253] = {.lex_state = 15, .external_lex_state = 2},
  [12254] = {.lex_state = 16, .external_lex_state = 2},
  [12255] = {.lex_state = 197, .external_lex_state = 5},
  [12256] = {.lex_state = 15, .external_lex_state = 2},
  [12257] = {.lex_state = 16, .external_lex_state = 2},
  [12258] = {.lex_state = 197, .external_lex_state = 5},
  [12259] = {.lex_state = 217, .external_lex_state = 2},
  [12260] = {.lex_state = 15, .external_lex_state = 2},
  [12261] = {.lex_state = 15, .external_lex_state = 2},
  [12262] = {.lex_state = 15, .external_lex_state = 2},
  [12263] = {.lex_state = 197, .external_lex_state = 5},
  [12264] = {.lex_state = 15, .external_lex_state = 2},
  [12265] = {.lex_state = 197, .external_lex_state = 5},
  [12266] = {.lex_state = 197, .external_lex_state = 5},
  [12267] = {.lex_state = 15, .external_lex_state = 2},
  [12268] = {.lex_state = 197, .external_lex_state = 5},
  [12269] = {.lex_state = 15, .external_lex_state = 2},
  [12270] = {.lex_state = 15, .external_lex_state = 2},
  [12271] = {.lex_state = 15, .external_lex_state = 2},
  [12272] = {.lex_state = 15, .external_lex_state = 2},
  [12273] = {.lex_state = 15, .external_lex_state = 2},
  [12274] = {.lex_state = 15, .external_lex_state = 2},
  [12275] = {.lex_state = 15, .external_lex_state = 2},
  [12276] = {.lex_state = 16, .external_lex_state = 2},
  [12277] = {.lex_state = 14, .external_lex_state = 2},
  [12278] = {.lex_state = 15, .external_lex_state = 2},
  [12279] = {.lex_state = 15, .external_lex_state = 2},
  [12280] = {.lex_state = 15, .external_lex_state = 2},
  [12281] = {.lex_state = 205, .external_lex_state = 2},
  [12282] = {.lex_state = 217, .external_lex_state = 2},
  [12283] = {.lex_state = 218, .external_lex_state = 2},
  [12284] = {.lex_state = 15, .external_lex_state = 2},
  [12285] = {.lex_state = 426, .external_lex_state = 2},
  [12286] = {.lex_state = 197, .external_lex_state = 5},
  [12287] = {.lex_state = 420, .external_lex_state = 2},
  [12288] = {.lex_state = 420, .external_lex_state = 2},
  [12289] = {.lex_state = 420, .external_lex_state = 2},
  [12290] = {.lex_state = 197, .external_lex_state = 5},
  [12291] = {.lex_state = 420, .external_lex_state = 2},
  [12292] = {.lex_state = 197, .external_lex_state = 5},
  [12293] = {.lex_state = 15, .external_lex_state = 2},
  [12294] = {.lex_state = 15, .external_lex_state = 2},
  [12295] = {.lex_state = 15, .external_lex_state = 2},
  [12296] = {.lex_state = 15, .external_lex_state = 2},
  [12297] = {.lex_state = 14, .external_lex_state = 2},
  [12298] = {.lex_state = 15, .external_lex_state = 2},
  [12299] = {.lex_state = 15, .external_lex_state = 2},
  [12300] = {.lex_state = 15, .external_lex_state = 2},
  [12301] = {.lex_state = 15, .external_lex_state = 2},
  [12302] = {.lex_state = 197, .external_lex_state = 5},
  [12303] = {.lex_state = 15, .external_lex_state = 2},
  [12304] = {.lex_state = 15, .external_lex_state = 2},
  [12305] = {.lex_state = 420, .external_lex_state = 2},
  [12306] = {.lex_state = 15, .external_lex_state = 2},
  [12307] = {.lex_state = 15, .external_lex_state = 2},
  [12308] = {.lex_state = 197, .external_lex_state = 5},
  [12309] = {.lex_state = 15, .external_lex_state = 2},
  [12310] = {.lex_state = 420, .external_lex_state = 2},
  [12311] = {.lex_state = 197, .external_lex_state = 5},
  [12312] = {.lex_state = 15, .external_lex_state = 2},
  [12313] = {.lex_state = 15, .external_lex_state = 2},
  [12314] = {.lex_state = 197, .external_lex_state = 5},
  [12315] = {.lex_state = 420, .external_lex_state = 2},
  [12316] = {.lex_state = 420, .external_lex_state = 2},
  [12317] = {.lex_state = 15, .external_lex_state = 2},
  [12318] = {.lex_state = 197, .external_lex_state = 5},
  [12319] = {.lex_state = 16, .external_lex_state = 2},
  [12320] = {.lex_state = 15, .external_lex_state = 2},
  [12321] = {.lex_state = 15, .external_lex_state = 2},
  [12322] = {.lex_state = 197, .external_lex_state = 5},
  [12323] = {.lex_state = 426, .external_lex_state = 2},
  [12324] = {.lex_state = 197, .external_lex_state = 5},
  [12325] = {.lex_state = 15, .external_lex_state = 2},
  [12326] = {.lex_state = 197, .external_lex_state = 5},
  [12327] = {.lex_state = 15, .external_lex_state = 2},
  [12328] = {.lex_state = 15, .external_lex_state = 2},
  [12329] = {.lex_state = 15, .external_lex_state = 2},
  [12330] = {.lex_state = 15, .external_lex_state = 2},
  [12331] = {.lex_state = 15, .external_lex_state = 2},
  [12332] = {.lex_state = 15, .external_lex_state = 2},
  [12333] = {.lex_state = 14, .external_lex_state = 2},
  [12334] = {.lex_state = 197, .external_lex_state = 5},
  [12335] = {.lex_state = 14, .external_lex_state = 2},
  [12336] = {.lex_state = 14, .external_lex_state = 2},
  [12337] = {.lex_state = 14, .external_lex_state = 2},
  [12338] = {.lex_state = 15, .external_lex_state = 2},
  [12339] = {.lex_state = 15, .external_lex_state = 2},
  [12340] = {.lex_state = 14, .external_lex_state = 2},
  [12341] = {.lex_state = 15, .external_lex_state = 2},
  [12342] = {.lex_state = 15, .external_lex_state = 2},
  [12343] = {.lex_state = 197, .external_lex_state = 5},
  [12344] = {.lex_state = 15, .external_lex_state = 2},
  [12345] = {.lex_state = 197, .external_lex_state = 5},
  [12346] = {.lex_state = 14, .external_lex_state = 2},
  [12347] = {.lex_state = 15, .external_lex_state = 2},
  [12348] = {.lex_state = 15, .external_lex_state = 2},
  [12349] = {.lex_state = 15, .external_lex_state = 2},
  [12350] = {.lex_state = 420, .external_lex_state = 2},
  [12351] = {.lex_state = 15, .external_lex_state = 2},
  [12352] = {.lex_state = 15, .external_lex_state = 2},
  [12353] = {.lex_state = 426, .external_lex_state = 2},
  [12354] = {.lex_state = 420, .external_lex_state = 2},
  [12355] = {.lex_state = 420, .external_lex_state = 2},
  [12356] = {.lex_state = 420, .external_lex_state = 2},
  [12357] = {.lex_state = 15, .external_lex_state = 2},
  [12358] = {.lex_state = 15, .external_lex_state = 2},
  [12359] = {.lex_state = 15, .external_lex_state = 2},
  [12360] = {.lex_state = 15, .external_lex_state = 2},
  [12361] = {.lex_state = 420, .external_lex_state = 2},
  [12362] = {.lex_state = 420, .external_lex_state = 2},
  [12363] = {.lex_state = 15, .external_lex_state = 2},
  [12364] = {.lex_state = 15, .external_lex_state = 2},
  [12365] = {.lex_state = 15, .external_lex_state = 2},
  [12366] = {.lex_state = 426, .external_lex_state = 2},
  [12367] = {.lex_state = 15, .external_lex_state = 2},
  [12368] = {.lex_state = 197, .external_lex_state = 5},
  [12369] = {.lex_state = 420, .external_lex_state = 2},
  [12370] = {.lex_state = 15, .external_lex_state = 2},
  [12371] = {.lex_state = 15, .external_lex_state = 2},
  [12372] = {.lex_state = 15, .external_lex_state = 2},
  [12373] = {.lex_state = 15, .external_lex_state = 2},
  [12374] = {.lex_state = 420, .external_lex_state = 2},
  [12375] = {.lex_state = 15, .external_lex_state = 2},
  [12376] = {.lex_state = 28, .external_lex_state = 2},
  [12377] = {.lex_state = 15, .external_lex_state = 2},
  [12378] = {.lex_state = 28, .external_lex_state = 2},
  [12379] = {.lex_state = 14, .external_lex_state = 2},
  [12380] = {.lex_state = 14, .external_lex_state = 2},
  [12381] = {.lex_state = 14, .external_lex_state = 2},
  [12382] = {.lex_state = 15, .external_lex_state = 2},
  [12383] = {.lex_state = 28, .external_lex_state = 2},
  [12384] = {.lex_state = 15, .external_lex_state = 2},
  [12385] = {.lex_state = 15, .external_lex_state = 2},
  [12386] = {.lex_state = 197, .external_lex_state = 5},
  [12387] = {.lex_state = 16, .external_lex_state = 2},
  [12388] = {.lex_state = 28, .external_lex_state = 2},
  [12389] = {.lex_state = 15, .external_lex_state = 2},
  [12390] = {.lex_state = 15, .external_lex_state = 2},
  [12391] = {.lex_state = 15, .external_lex_state = 2},
  [12392] = {.lex_state = 28, .external_lex_state = 2},
  [12393] = {.lex_state = 15, .external_lex_state = 2},
  [12394] = {.lex_state = 426, .external_lex_state = 2},
  [12395] = {.lex_state = 197, .external_lex_state = 5},
  [12396] = {.lex_state = 15, .external_lex_state = 2},
  [12397] = {.lex_state = 426, .external_lex_state = 2},
  [12398] = {.lex_state = 15, .external_lex_state = 2},
  [12399] = {.lex_state = 14, .external_lex_state = 2},
  [12400] = {.lex_state = 15, .external_lex_state = 2},
  [12401] = {.lex_state = 15, .external_lex_state = 2},
  [12402] = {.lex_state = 15, .external_lex_state = 2},
  [12403] = {.lex_state = 14, .external_lex_state = 2},
  [12404] = {.lex_state = 197, .external_lex_state = 5},
  [12405] = {.lex_state = 14, .external_lex_state = 2},
  [12406] = {.lex_state = 15, .external_lex_state = 2},
  [12407] = {.lex_state = 14, .external_lex_state = 2},
  [12408] = {.lex_state = 14, .external_lex_state = 2},
  [12409] = {.lex_state = 14, .external_lex_state = 2},
  [12410] = {.lex_state = 15, .external_lex_state = 2},
  [12411] = {.lex_state = 426, .external_lex_state = 2},
  [12412] = {.lex_state = 15, .external_lex_state = 2},
  [12413] = {.lex_state = 14, .external_lex_state = 2},
  [12414] = {.lex_state = 14, .external_lex_state = 2},
  [12415] = {.lex_state = 15, .external_lex_state = 2},
  [12416] = {.lex_state = 14, .external_lex_state = 2},
  [12417] = {.lex_state = 197, .external_lex_state = 5},
  [12418] = {.lex_state = 15, .external_lex_state = 2},
  [12419] = {.lex_state = 14, .external_lex_state = 2},
  [12420] = {.lex_state = 15, .external_lex_state = 2},
  [12421] = {.lex_state = 15, .external_lex_state = 2},
  [12422] = {.lex_state = 14, .external_lex_state = 2},
  [12423] = {.lex_state = 14, .external_lex_state = 2},
  [12424] = {.lex_state = 14, .external_lex_state = 2},
  [12425] = {.lex_state = 14, .external_lex_state = 2},
  [12426] = {.lex_state = 14, .external_lex_state = 2},
  [12427] = {.lex_state = 420, .external_lex_state = 2},
  [12428] = {.lex_state = 14, .external_lex_state = 2},
  [12429] = {.lex_state = 10, .external_lex_state = 2},
  [12430] = {.lex_state = 14, .external_lex_state = 2},
  [12431] = {.lex_state = 14, .external_lex_state = 2},
  [12432] = {.lex_state = 16, .external_lex_state = 2},
  [12433] = {.lex_state = 14, .external_lex_state = 2},
  [12434] = {.lex_state = 14, .external_lex_state = 2},
  [12435] = {.lex_state = 16, .external_lex_state = 2},
  [12436] = {.lex_state = 15, .external_lex_state = 2},
  [12437] = {.lex_state = 14, .external_lex_state = 2},
  [12438] = {.lex_state = 15, .external_lex_state = 2},
  [12439] = {.lex_state = 15, .external_lex_state = 2},
  [12440] = {.lex_state = 14, .external_lex_state = 2},
  [12441] = {.lex_state = 14, .external_lex_state = 2},
  [12442] = {.lex_state = 15, .external_lex_state = 2},
  [12443] = {.lex_state = 197, .external_lex_state = 5},
  [12444] = {.lex_state = 14, .external_lex_state = 2},
  [12445] = {.lex_state = 14, .external_lex_state = 2},
  [12446] = {.lex_state = 197, .external_lex_state = 5},
  [12447] = {.lex_state = 14, .external_lex_state = 2},
  [12448] = {.lex_state = 14, .external_lex_state = 2},
  [12449] = {.lex_state = 197, .external_lex_state = 5},
  [12450] = {.lex_state = 14, .external_lex_state = 2},
  [12451] = {.lex_state = 14, .external_lex_state = 2},
  [12452] = {.lex_state = 14, .external_lex_state = 2},
  [12453] = {.lex_state = 14, .external_lex_state = 2},
  [12454] = {.lex_state = 15, .external_lex_state = 2},
  [12455] = {.lex_state = 14, .external_lex_state = 2},
  [12456] = {.lex_state = 15, .external_lex_state = 2},
  [12457] = {.lex_state = 15, .external_lex_state = 2},
  [12458] = {.lex_state = 14, .external_lex_state = 2},
  [12459] = {.lex_state = 15, .external_lex_state = 2},
  [12460] = {.lex_state = 15, .external_lex_state = 2},
  [12461] = {.lex_state = 14, .external_lex_state = 2},
  [12462] = {.lex_state = 15, .external_lex_state = 2},
  [12463] = {.lex_state = 15, .external_lex_state = 2},
  [12464] = {.lex_state = 14, .external_lex_state = 2},
  [12465] = {.lex_state = 197, .external_lex_state = 5},
  [12466] = {.lex_state = 15, .external_lex_state = 2},
  [12467] = {.lex_state = 15, .external_lex_state = 2},
  [12468] = {.lex_state = 14, .external_lex_state = 2},
  [12469] = {.lex_state = 14, .external_lex_state = 2},
  [12470] = {.lex_state = 14, .external_lex_state = 2},
  [12471] = {.lex_state = 15, .external_lex_state = 2},
  [12472] = {.lex_state = 15, .external_lex_state = 2},
  [12473] = {.lex_state = 15, .external_lex_state = 2},
  [12474] = {.lex_state = 15, .external_lex_state = 2},
  [12475] = {.lex_state = 14, .external_lex_state = 2},
  [12476] = {.lex_state = 28, .external_lex_state = 2},
  [12477] = {.lex_state = 28, .external_lex_state = 2},
  [12478] = {.lex_state = 28, .external_lex_state = 2},
  [12479] = {.lex_state = 14, .external_lex_state = 2},
  [12480] = {.lex_state = 28, .external_lex_state = 2},
  [12481] = {.lex_state = 15, .external_lex_state = 2},
  [12482] = {.lex_state = 15, .external_lex_state = 2},
  [12483] = {.lex_state = 15, .external_lex_state = 2},
  [12484] = {.lex_state = 15, .external_lex_state = 2},
  [12485] = {.lex_state = 14, .external_lex_state = 2},
  [12486] = {.lex_state = 15, .external_lex_state = 2},
  [12487] = {.lex_state = 28, .external_lex_state = 2},
  [12488] = {.lex_state = 197, .external_lex_state = 5},
  [12489] = {.lex_state = 28, .external_lex_state = 2},
  [12490] = {.lex_state = 15, .external_lex_state = 2},
  [12491] = {.lex_state = 15, .external_lex_state = 2},
  [12492] = {.lex_state = 15, .external_lex_state = 2},
  [12493] = {.lex_state = 15, .external_lex_state = 2},
  [12494] = {.lex_state = 197, .external_lex_state = 5},
  [12495] = {.lex_state = 15, .external_lex_state = 2},
  [12496] = {.lex_state = 426, .external_lex_state = 2},
  [12497] = {.lex_state = 15, .external_lex_state = 2},
  [12498] = {.lex_state = 197, .external_lex_state = 5},
  [12499] = {.lex_state = 197, .external_lex_state = 5},
  [12500] = {.lex_state = 14, .external_lex_state = 2},
  [12501] = {.lex_state = 14, .external_lex_state = 2},
  [12502] = {.lex_state = 15, .external_lex_state = 2},
  [12503] = {.lex_state = 205, .external_lex_state = 2},
  [12504] = {.lex_state = 14, .external_lex_state = 2},
  [12505] = {.lex_state = 15, .external_lex_state = 2},
  [12506] = {.lex_state = 15, .external_lex_state = 2},
  [12507] = {.lex_state = 15, .external_lex_state = 2},
  [12508] = {.lex_state = 15, .external_lex_state = 2},
  [12509] = {.lex_state = 15, .external_lex_state = 2},
  [12510] = {.lex_state = 15, .external_lex_state = 2},
  [12511] = {.lex_state = 15, .external_lex_state = 2},
  [12512] = {.lex_state = 15, .external_lex_state = 2},
  [12513] = {.lex_state = 15, .external_lex_state = 2},
  [12514] = {.lex_state = 15, .external_lex_state = 2},
  [12515] = {.lex_state = 426, .external_lex_state = 2},
  [12516] = {.lex_state = 14, .external_lex_state = 2},
  [12517] = {.lex_state = 15, .external_lex_state = 2},
  [12518] = {.lex_state = 426, .external_lex_state = 2},
  [12519] = {.lex_state = 15, .external_lex_state = 2},
  [12520] = {.lex_state = 15, .external_lex_state = 2},
  [12521] = {.lex_state = 15, .external_lex_state = 2},
  [12522] = {.lex_state = 197, .external_lex_state = 5},
  [12523] = {.lex_state = 14, .external_lex_state = 2},
  [12524] = {.lex_state = 15, .external_lex_state = 2},
  [12525] = {.lex_state = 15, .external_lex_state = 2},
  [12526] = {.lex_state = 15, .external_lex_state = 2},
  [12527] = {.lex_state = 197, .external_lex_state = 5},
  [12528] = {.lex_state = 14, .external_lex_state = 2},
  [12529] = {.lex_state = 426, .external_lex_state = 2},
  [12530] = {.lex_state = 197, .external_lex_state = 5},
  [12531] = {.lex_state = 15, .external_lex_state = 2},
  [12532] = {.lex_state = 420, .external_lex_state = 2},
  [12533] = {.lex_state = 197, .external_lex_state = 5},
  [12534] = {.lex_state = 28, .external_lex_state = 2},
  [12535] = {.lex_state = 426, .external_lex_state = 2},
  [12536] = {.lex_state = 15, .external_lex_state = 2},
  [12537] = {.lex_state = 15, .external_lex_state = 2},
  [12538] = {.lex_state = 28, .external_lex_state = 2},
  [12539] = {.lex_state = 14, .external_lex_state = 2},
  [12540] = {.lex_state = 14, .external_lex_state = 2},
  [12541] = {.lex_state = 15, .external_lex_state = 2},
  [12542] = {.lex_state = 15, .external_lex_state = 2},
  [12543] = {.lex_state = 14, .external_lex_state = 2},
  [12544] = {.lex_state = 28, .external_lex_state = 2},
  [12545] = {.lex_state = 14, .external_lex_state = 2},
  [12546] = {.lex_state = 15, .external_lex_state = 2},
  [12547] = {.lex_state = 14, .external_lex_state = 2},
  [12548] = {.lex_state = 14, .external_lex_state = 2},
  [12549] = {.lex_state = 14, .external_lex_state = 2},
  [12550] = {.lex_state = 14, .external_lex_state = 2},
  [12551] = {.lex_state = 197, .external_lex_state = 5},
  [12552] = {.lex_state = 15, .external_lex_state = 2},
  [12553] = {.lex_state = 15, .external_lex_state = 2},
  [12554] = {.lex_state = 426, .external_lex_state = 2},
  [12555] = {.lex_state = 197, .external_lex_state = 5},
  [12556] = {.lex_state = 14, .external_lex_state = 2},
  [12557] = {.lex_state = 14, .external_lex_state = 2},
  [12558] = {.lex_state = 15, .external_lex_state = 2},
  [12559] = {.lex_state = 15, .external_lex_state = 2},
  [12560] = {.lex_state = 15, .external_lex_state = 2},
  [12561] = {.lex_state = 197, .external_lex_state = 5},
  [12562] = {.lex_state = 15, .external_lex_state = 2},
  [12563] = {.lex_state = 197, .external_lex_state = 5},
  [12564] = {.lex_state = 15, .external_lex_state = 2},
  [12565] = {.lex_state = 15, .external_lex_state = 2},
  [12566] = {.lex_state = 14, .external_lex_state = 2},
  [12567] = {.lex_state = 15, .external_lex_state = 2},
  [12568] = {.lex_state = 16, .external_lex_state = 2},
  [12569] = {.lex_state = 426, .external_lex_state = 2},
  [12570] = {.lex_state = 10, .external_lex_state = 2},
  [12571] = {.lex_state = 15, .external_lex_state = 2},
  [12572] = {.lex_state = 28, .external_lex_state = 2},
  [12573] = {.lex_state = 15, .external_lex_state = 2},
  [12574] = {.lex_state = 426, .external_lex_state = 2},
  [12575] = {.lex_state = 426, .external_lex_state = 2},
  [12576] = {.lex_state = 15, .external_lex_state = 2},
  [12577] = {.lex_state = 217, .external_lex_state = 2},
  [12578] = {.lex_state = 217, .external_lex_state = 2},
  [12579] = {.lex_state = 426, .external_lex_state = 2},
  [12580] = {.lex_state = 197, .external_lex_state = 5},
  [12581] = {.lex_state = 15, .external_lex_state = 2},
  [12582] = {.lex_state = 15, .external_lex_state = 2},
  [12583] = {.lex_state = 15, .external_lex_state = 2},
  [12584] = {.lex_state = 15, .external_lex_state = 2},
  [12585] = {.lex_state = 15, .external_lex_state = 2},
  [12586] = {.lex_state = 15, .external_lex_state = 2},
  [12587] = {.lex_state = 197, .external_lex_state = 5},
  [12588] = {.lex_state = 15, .external_lex_state = 2},
  [12589] = {.lex_state = 15, .external_lex_state = 2},
  [12590] = {.lex_state = 15, .external_lex_state = 2},
  [12591] = {.lex_state = 426, .external_lex_state = 2},
  [12592] = {.lex_state = 15, .external_lex_state = 2},
  [12593] = {.lex_state = 28, .external_lex_state = 2},
  [12594] = {.lex_state = 15, .external_lex_state = 2},
  [12595] = {.lex_state = 28, .external_lex_state = 2},
  [12596] = {.lex_state = 28, .external_lex_state = 2},
  [12597] = {.lex_state = 28, .external_lex_state = 2},
  [12598] = {.lex_state = 197, .external_lex_state = 5},
  [12599] = {.lex_state = 197, .external_lex_state = 5},
  [12600] = {.lex_state = 28, .external_lex_state = 2},
  [12601] = {.lex_state = 420, .external_lex_state = 2},
  [12602] = {.lex_state = 15, .external_lex_state = 2},
  [12603] = {.lex_state = 197, .external_lex_state = 5},
  [12604] = {.lex_state = 15, .external_lex_state = 2},
  [12605] = {.lex_state = 420, .external_lex_state = 2},
  [12606] = {.lex_state = 15, .external_lex_state = 2},
  [12607] = {.lex_state = 15, .external_lex_state = 2},
  [12608] = {.lex_state = 15, .external_lex_state = 2},
  [12609] = {.lex_state = 15, .external_lex_state = 2},
  [12610] = {.lex_state = 16, .external_lex_state = 2},
  [12611] = {.lex_state = 15, .external_lex_state = 2},
  [12612] = {.lex_state = 16, .external_lex_state = 2},
  [12613] = {.lex_state = 15, .external_lex_state = 2},
  [12614] = {.lex_state = 15, .external_lex_state = 2},
  [12615] = {.lex_state = 197, .external_lex_state = 5},
  [12616] = {.lex_state = 197, .external_lex_state = 5},
  [12617] = {.lex_state = 15, .external_lex_state = 2},
  [12618] = {.lex_state = 15, .external_lex_state = 2},
  [12619] = {.lex_state = 15, .external_lex_state = 2},
  [12620] = {.lex_state = 15, .external_lex_state = 2},
  [12621] = {.lex_state = 15, .external_lex_state = 2},
  [12622] = {.lex_state = 14, .external_lex_state = 2},
  [12623] = {.lex_state = 15, .external_lex_state = 2},
  [12624] = {.lex_state = 28, .external_lex_state = 2},
  [12625] = {.lex_state = 28, .external_lex_state = 2},
  [12626] = {.lex_state = 28, .external_lex_state = 2},
  [12627] = {.lex_state = 197, .external_lex_state = 5},
  [12628] = {.lex_state = 420, .external_lex_state = 2},
  [12629] = {.lex_state = 218, .external_lex_state = 2},
  [12630] = {.lex_state = 218, .external_lex_state = 2},
  [12631] = {.lex_state = 218, .external_lex_state = 2},
  [12632] = {.lex_state = 28, .external_lex_state = 2},
  [12633] = {.lex_state = 218, .external_lex_state = 2},
  [12634] = {.lex_state = 218, .external_lex_state = 2},
  [12635] = {.lex_state = 15, .external_lex_state = 2},
  [12636] = {.lex_state = 28, .external_lex_state = 2},
  [12637] = {.lex_state = 218, .external_lex_state = 2},
  [12638] = {.lex_state = 218, .external_lex_state = 2},
  [12639] = {.lex_state = 218, .external_lex_state = 2},
  [12640] = {.lex_state = 426, .external_lex_state = 2},
  [12641] = {.lex_state = 241, .external_lex_state = 2},
  [12642] = {.lex_state = 28, .external_lex_state = 2},
  [12643] = {.lex_state = 218, .external_lex_state = 2},
  [12644] = {.lex_state = 218, .external_lex_state = 2},
  [12645] = {.lex_state = 15, .external_lex_state = 2},
  [12646] = {.lex_state = 28, .external_lex_state = 2},
  [12647] = {.lex_state = 218, .external_lex_state = 2},
  [12648] = {.lex_state = 426, .external_lex_state = 2},
  [12649] = {.lex_state = 420, .external_lex_state = 2},
  [12650] = {.lex_state = 420, .external_lex_state = 2},
  [12651] = {.lex_state = 218, .external_lex_state = 2},
  [12652] = {.lex_state = 15, .external_lex_state = 2},
  [12653] = {.lex_state = 218, .external_lex_state = 2},
  [12654] = {.lex_state = 197, .external_lex_state = 5},
  [12655] = {.lex_state = 15, .external_lex_state = 2},
  [12656] = {.lex_state = 28, .external_lex_state = 2},
  [12657] = {.lex_state = 265, .external_lex_state = 2},
  [12658] = {.lex_state = 218, .external_lex_state = 2},
  [12659] = {.lex_state = 15, .external_lex_state = 2},
  [12660] = {.lex_state = 426, .external_lex_state = 2},
  [12661] = {.lex_state = 28, .external_lex_state = 2},
  [12662] = {.lex_state = 426, .external_lex_state = 2},
  [12663] = {.lex_state = 15, .external_lex_state = 2},
  [12664] = {.lex_state = 31, .external_lex_state = 2},
  [12665] = {.lex_state = 218, .external_lex_state = 2},
  [12666] = {.lex_state = 218, .external_lex_state = 2},
  [12667] = {.lex_state = 28, .external_lex_state = 2},
  [12668] = {.lex_state = 15, .external_lex_state = 2},
  [12669] = {.lex_state = 15, .external_lex_state = 2},
  [12670] = {.lex_state = 15, .external_lex_state = 2},
  [12671] = {.lex_state = 265, .external_lex_state = 2},
  [12672] = {.lex_state = 15, .external_lex_state = 2},
  [12673] = {.lex_state = 15, .external_lex_state = 2},
  [12674] = {.lex_state = 16, .external_lex_state = 2},
  [12675] = {.lex_state = 15, .external_lex_state = 2},
  [12676] = {.lex_state = 28, .external_lex_state = 2},
  [12677] = {.lex_state = 28, .external_lex_state = 2},
  [12678] = {.lex_state = 15, .external_lex_state = 2},
  [12679] = {.lex_state = 15, .external_lex_state = 2},
  [12680] = {.lex_state = 218, .external_lex_state = 2},
  [12681] = {.lex_state = 28, .external_lex_state = 2},
  [12682] = {.lex_state = 15, .external_lex_state = 2},
  [12683] = {.lex_state = 28, .external_lex_state = 2},
  [12684] = {.lex_state = 218, .external_lex_state = 2},
  [12685] = {.lex_state = 15, .external_lex_state = 2},
  [12686] = {.lex_state = 218, .external_lex_state = 2},
  [12687] = {.lex_state = 218, .external_lex_state = 2},
  [12688] = {.lex_state = 15, .external_lex_state = 2},
  [12689] = {.lex_state = 8, .external_lex_state = 2},
  [12690] = {.lex_state = 15, .external_lex_state = 2},
  [12691] = {.lex_state = 218, .external_lex_state = 2},
  [12692] = {.lex_state = 265, .external_lex_state = 2},
  [12693] = {.lex_state = 28, .external_lex_state = 2},
  [12694] = {.lex_state = 15, .external_lex_state = 2},
  [12695] = {.lex_state = 218, .external_lex_state = 2},
  [12696] = {.lex_state = 15, .external_lex_state = 2},
  [12697] = {.lex_state = 218, .external_lex_state = 2},
  [12698] = {.lex_state = 28, .external_lex_state = 2},
  [12699] = {.lex_state = 28, .external_lex_state = 2},
  [12700] = {.lex_state = 15, .external_lex_state = 2},
  [12701] = {.lex_state = 28, .external_lex_state = 2},
  [12702] = {.lex_state = 218, .external_lex_state = 2},
  [12703] = {.lex_state = 15, .external_lex_state = 2},
  [12704] = {.lex_state = 28, .external_lex_state = 2},
  [12705] = {.lex_state = 265, .external_lex_state = 2},
  [12706] = {.lex_state = 28, .external_lex_state = 2},
  [12707] = {.lex_state = 218, .external_lex_state = 2},
  [12708] = {.lex_state = 31, .external_lex_state = 2},
  [12709] = {.lex_state = 28, .external_lex_state = 2},
  [12710] = {.lex_state = 31, .external_lex_state = 2},
  [12711] = {.lex_state = 28, .external_lex_state = 2},
  [12712] = {.lex_state = 15, .external_lex_state = 2},
  [12713] = {.lex_state = 28, .external_lex_state = 2},
  [12714] = {.lex_state = 218, .external_lex_state = 2},
  [12715] = {.lex_state = 426, .external_lex_state = 2},
  [12716] = {.lex_state = 426, .external_lex_state = 2},
  [12717] = {.lex_state = 218, .external_lex_state = 2},
  [12718] = {.lex_state = 8, .external_lex_state = 2},
  [12719] = {.lex_state = 28, .external_lex_state = 2},
  [12720] = {.lex_state = 28, .external_lex_state = 2},
  [12721] = {.lex_state = 28, .external_lex_state = 2},
  [12722] = {.lex_state = 28, .external_lex_state = 2},
  [12723] = {.lex_state = 426, .external_lex_state = 2},
  [12724] = {.lex_state = 15, .external_lex_state = 2},
  [12725] = {.lex_state = 218, .external_lex_state = 2},
  [12726] = {.lex_state = 15, .external_lex_state = 2},
  [12727] = {.lex_state = 218, .external_lex_state = 2},
  [12728] = {.lex_state = 15, .external_lex_state = 2},
  [12729] = {.lex_state = 426, .external_lex_state = 2},
  [12730] = {.lex_state = 218, .external_lex_state = 2},
  [12731] = {.lex_state = 426, .external_lex_state = 2},
  [12732] = {.lex_state = 426, .external_lex_state = 2},
  [12733] = {.lex_state = 31, .external_lex_state = 2},
  [12734] = {.lex_state = 31, .external_lex_state = 2},
  [12735] = {.lex_state = 8, .external_lex_state = 2},
  [12736] = {.lex_state = 15, .external_lex_state = 2},
  [12737] = {.lex_state = 31, .external_lex_state = 2},
  [12738] = {.lex_state = 15, .external_lex_state = 2},
  [12739] = {.lex_state = 15, .external_lex_state = 2},
  [12740] = {.lex_state = 15, .external_lex_state = 2},
  [12741] = {.lex_state = 228, .external_lex_state = 2},
  [12742] = {.lex_state = 15, .external_lex_state = 2},
  [12743] = {.lex_state = 28, .external_lex_state = 2},
  [12744] = {.lex_state = 426, .external_lex_state = 2},
  [12745] = {.lex_state = 426, .external_lex_state = 2},
  [12746] = {.lex_state = 15, .external_lex_state = 2},
  [12747] = {.lex_state = 28, .external_lex_state = 2},
  [12748] = {.lex_state = 28, .external_lex_state = 2},
  [12749] = {.lex_state = 31, .external_lex_state = 2},
  [12750] = {.lex_state = 426, .external_lex_state = 2},
  [12751] = {.lex_state = 15, .external_lex_state = 2},
  [12752] = {.lex_state = 426, .external_lex_state = 2},
  [12753] = {.lex_state = 15, .external_lex_state = 2},
  [12754] = {.lex_state = 15, .external_lex_state = 2},
  [12755] = {.lex_state = 426, .external_lex_state = 2},
  [12756] = {.lex_state = 426, .external_lex_state = 2},
  [12757] = {.lex_state = 15, .external_lex_state = 2},
  [12758] = {.lex_state = 28, .external_lex_state = 2},
  [12759] = {.lex_state = 426, .external_lex_state = 2},
  [12760] = {.lex_state = 15, .external_lex_state = 2},
  [12761] = {.lex_state = 265, .external_lex_state = 2},
  [12762] = {.lex_state = 228, .external_lex_state = 2},
  [12763] = {.lex_state = 28, .external_lex_state = 2},
  [12764] = {.lex_state = 15, .external_lex_state = 2},
  [12765] = {.lex_state = 228, .external_lex_state = 2},
  [12766] = {.lex_state = 28, .external_lex_state = 2},
  [12767] = {.lex_state = 426, .external_lex_state = 2},
  [12768] = {.lex_state = 15, .external_lex_state = 2},
  [12769] = {.lex_state = 28, .external_lex_state = 2},
  [12770] = {.lex_state = 28, .external_lex_state = 2},
  [12771] = {.lex_state = 15, .external_lex_state = 2},
  [12772] = {.lex_state = 28, .external_lex_state = 2},
  [12773] = {.lex_state = 426, .external_lex_state = 2},
  [12774] = {.lex_state = 15, .external_lex_state = 2},
  [12775] = {.lex_state = 265, .external_lex_state = 2},
  [12776] = {.lex_state = 218, .external_lex_state = 2},
  [12777] = {.lex_state = 426, .external_lex_state = 2},
  [12778] = {.lex_state = 426, .external_lex_state = 2},
  [12779] = {.lex_state = 15, .external_lex_state = 2},
  [12780] = {.lex_state = 15, .external_lex_state = 2},
  [12781] = {.lex_state = 28, .external_lex_state = 2},
  [12782] = {.lex_state = 15, .external_lex_state = 2},
  [12783] = {.lex_state = 426, .external_lex_state = 2},
  [12784] = {.lex_state = 15, .external_lex_state = 2},
  [12785] = {.lex_state = 426, .external_lex_state = 2},
  [12786] = {.lex_state = 15, .external_lex_state = 2},
  [12787] = {.lex_state = 15, .external_lex_state = 2},
  [12788] = {.lex_state = 8, .external_lex_state = 2},
  [12789] = {.lex_state = 265, .external_lex_state = 2},
  [12790] = {.lex_state = 15, .external_lex_state = 2},
  [12791] = {.lex_state = 15, .external_lex_state = 2},
  [12792] = {.lex_state = 15, .external_lex_state = 2},
  [12793] = {.lex_state = 28, .external_lex_state = 2},
  [12794] = {.lex_state = 28, .external_lex_state = 2},
  [12795] = {.lex_state = 15, .external_lex_state = 2},
  [12796] = {.lex_state = 15, .external_lex_state = 2},
  [12797] = {.lex_state = 15, .external_lex_state = 2},
  [12798] = {.lex_state = 426, .external_lex_state = 2},
  [12799] = {.lex_state = 15, .external_lex_state = 2},
  [12800] = {.lex_state = 15, .external_lex_state = 2},
  [12801] = {.lex_state = 28, .external_lex_state = 2},
  [12802] = {.lex_state = 426, .external_lex_state = 2},
  [12803] = {.lex_state = 15, .external_lex_state = 2},
  [12804] = {.lex_state = 28, .external_lex_state = 2},
  [12805] = {.lex_state = 15, .external_lex_state = 2},
  [12806] = {.lex_state = 15, .external_lex_state = 2},
  [12807] = {.lex_state = 15, .external_lex_state = 2},
  [12808] = {.lex_state = 426, .external_lex_state = 2},
  [12809] = {.lex_state = 28, .external_lex_state = 2},
  [12810] = {.lex_state = 426, .external_lex_state = 2},
  [12811] = {.lex_state = 265, .external_lex_state = 2},
  [12812] = {.lex_state = 15, .external_lex_state = 2},
  [12813] = {.lex_state = 15, .external_lex_state = 2},
  [12814] = {.lex_state = 28, .external_lex_state = 2},
  [12815] = {.lex_state = 420, .external_lex_state = 2},
  [12816] = {.lex_state = 15, .external_lex_state = 2},
  [12817] = {.lex_state = 15, .external_lex_state = 2},
  [12818] = {.lex_state = 15, .external_lex_state = 2},
  [12819] = {.lex_state = 426, .external_lex_state = 2},
  [12820] = {.lex_state = 28, .external_lex_state = 2},
  [12821] = {.lex_state = 15, .external_lex_state = 2},
  [12822] = {.lex_state = 426, .external_lex_state = 2},
  [12823] = {.lex_state = 15, .external_lex_state = 2},
  [12824] = {.lex_state = 28, .external_lex_state = 2},
  [12825] = {.lex_state = 8, .external_lex_state = 2},
  [12826] = {.lex_state = 28, .external_lex_state = 2},
  [12827] = {.lex_state = 8, .external_lex_state = 2},
  [12828] = {.lex_state = 31, .external_lex_state = 2},
  [12829] = {.lex_state = 12, .external_lex_state = 2},
  [12830] = {.lex_state = 31, .external_lex_state = 2},
  [12831] = {.lex_state = 8, .external_lex_state = 2},
  [12832] = {.lex_state = 8, .external_lex_state = 2},
  [12833] = {.lex_state = 8, .external_lex_state = 2},
  [12834] = {.lex_state = 8, .external_lex_state = 2},
  [12835] = {.lex_state = 8, .external_lex_state = 2},
  [12836] = {.lex_state = 426, .external_lex_state = 2},
  [12837] = {.lex_state = 31, .external_lex_state = 2},
  [12838] = {.lex_state = 8, .external_lex_state = 2},
  [12839] = {.lex_state = 228, .external_lex_state = 2},
  [12840] = {.lex_state = 426, .external_lex_state = 2},
  [12841] = {.lex_state = 8, .external_lex_state = 2},
  [12842] = {.lex_state = 8, .external_lex_state = 2},
  [12843] = {.lex_state = 8, .external_lex_state = 2},
  [12844] = {.lex_state = 8, .external_lex_state = 2},
  [12845] = {.lex_state = 426, .external_lex_state = 2},
  [12846] = {.lex_state = 12, .external_lex_state = 2},
  [12847] = {.lex_state = 12, .external_lex_state = 2},
  [12848] = {.lex_state = 214, .external_lex_state = 2},
  [12849] = {.lex_state = 8, .external_lex_state = 2},
  [12850] = {.lex_state = 228, .external_lex_state = 2},
  [12851] = {.lex_state = 426, .external_lex_state = 2},
  [12852] = {.lex_state = 426, .external_lex_state = 2},
  [12853] = {.lex_state = 228, .external_lex_state = 2},
  [12854] = {.lex_state = 228, .external_lex_state = 2},
  [12855] = {.lex_state = 228, .external_lex_state = 2},
  [12856] = {.lex_state = 228, .external_lex_state = 2},
  [12857] = {.lex_state = 228, .external_lex_state = 2},
  [12858] = {.lex_state = 228, .external_lex_state = 2},
  [12859] = {.lex_state = 228, .external_lex_state = 2},
  [12860] = {.lex_state = 228, .external_lex_state = 2},
  [12861] = {.lex_state = 228, .external_lex_state = 2},
  [12862] = {.lex_state = 228, .external_lex_state = 2},
  [12863] = {.lex_state = 31, .external_lex_state = 2},
  [12864] = {.lex_state = 242, .external_lex_state = 2},
  [12865] = {.lex_state = 228, .external_lex_state = 2},
  [12866] = {.lex_state = 224, .external_lex_state = 2},
  [12867] = {.lex_state = 228, .external_lex_state = 2},
  [12868] = {.lex_state = 31, .external_lex_state = 2},
  [12869] = {.lex_state = 426, .external_lex_state = 2},
  [12870] = {.lex_state = 228, .external_lex_state = 2},
  [12871] = {.lex_state = 228, .external_lex_state = 2},
  [12872] = {.lex_state = 12, .external_lex_state = 2},
  [12873] = {.lex_state = 8, .external_lex_state = 2},
  [12874] = {.lex_state = 228, .external_lex_state = 2},
  [12875] = {.lex_state = 214, .external_lex_state = 2},
  [12876] = {.lex_state = 228, .external_lex_state = 2},
  [12877] = {.lex_state = 31, .external_lex_state = 2},
  [12878] = {.lex_state = 214, .external_lex_state = 2},
  [12879] = {.lex_state = 31, .external_lex_state = 2},
  [12880] = {.lex_state = 214, .external_lex_state = 2},
  [12881] = {.lex_state = 12, .external_lex_state = 2},
  [12882] = {.lex_state = 7, .external_lex_state = 2},
  [12883] = {.lex_state = 7, .external_lex_state = 2},
  [12884] = {.lex_state = 426, .external_lex_state = 2},
  [12885] = {.lex_state = 8, .external_lex_state = 2},
  [12886] = {.lex_state = 8, .external_lex_state = 2},
  [12887] = {.lex_state = 228, .external_lex_state = 2},
  [12888] = {.lex_state = 228, .external_lex_state = 2},
  [12889] = {.lex_state = 228, .external_lex_state = 2},
  [12890] = {.lex_state = 8, .external_lex_state = 2},
  [12891] = {.lex_state = 228, .external_lex_state = 2},
  [12892] = {.lex_state = 214, .external_lex_state = 2},
  [12893] = {.lex_state = 242, .external_lex_state = 2},
  [12894] = {.lex_state = 242, .external_lex_state = 2},
  [12895] = {.lex_state = 228, .external_lex_state = 2},
  [12896] = {.lex_state = 31, .external_lex_state = 2},
  [12897] = {.lex_state = 242, .external_lex_state = 2},
  [12898] = {.lex_state = 224, .external_lex_state = 2},
  [12899] = {.lex_state = 242, .external_lex_state = 2},
  [12900] = {.lex_state = 228, .external_lex_state = 2},
  [12901] = {.lex_state = 426, .external_lex_state = 2},
  [12902] = {.lex_state = 228, .external_lex_state = 2},
  [12903] = {.lex_state = 228, .external_lex_state = 2},
  [12904] = {.lex_state = 228, .external_lex_state = 2},
  [12905] = {.lex_state = 228, .external_lex_state = 2},
  [12906] = {.lex_state = 228, .external_lex_state = 2},
  [12907] = {.lex_state = 426, .external_lex_state = 2},
  [12908] = {.lex_state = 242, .external_lex_state = 2},
  [12909] = {.lex_state = 197, .external_lex_state = 5},
  [12910] = {.lex_state = 242, .external_lex_state = 2},
  [12911] = {.lex_state = 242, .external_lex_state = 2},
  [12912] = {.lex_state = 228, .external_lex_state = 2},
  [12913] = {.lex_state = 228, .external_lex_state = 2},
  [12914] = {.lex_state = 228, .external_lex_state = 2},
  [12915] = {.lex_state = 12, .external_lex_state = 2},
  [12916] = {.lex_state = 8, .external_lex_state = 2},
  [12917] = {.lex_state = 228, .external_lex_state = 2},
  [12918] = {.lex_state = 224, .external_lex_state = 2},
  [12919] = {.lex_state = 218, .external_lex_state = 2},
  [12920] = {.lex_state = 7, .external_lex_state = 2},
  [12921] = {.lex_state = 210, .external_lex_state = 2},
  [12922] = {.lex_state = 214, .external_lex_state = 2},
  [12923] = {.lex_state = 197, .external_lex_state = 5},
  [12924] = {.lex_state = 228, .external_lex_state = 2},
  [12925] = {.lex_state = 420, .external_lex_state = 2},
  [12926] = {.lex_state = 420, .external_lex_state = 2},
  [12927] = {.lex_state = 420, .external_lex_state = 2},
  [12928] = {.lex_state = 28, .external_lex_state = 2},
  [12929] = {.lex_state = 28, .external_lex_state = 2},
  [12930] = {.lex_state = 420, .external_lex_state = 2},
  [12931] = {.lex_state = 241, .external_lex_state = 2},
  [12932] = {.lex_state = 420, .external_lex_state = 2},
  [12933] = {.lex_state = 246, .external_lex_state = 2},
  [12934] = {.lex_state = 420, .external_lex_state = 2},
  [12935] = {.lex_state = 28, .external_lex_state = 2},
  [12936] = {.lex_state = 420, .external_lex_state = 2},
  [12937] = {.lex_state = 242, .external_lex_state = 2},
  [12938] = {.lex_state = 420, .external_lex_state = 2},
  [12939] = {.lex_state = 420, .external_lex_state = 2},
  [12940] = {.lex_state = 420, .external_lex_state = 2},
  [12941] = {.lex_state = 420, .external_lex_state = 2},
  [12942] = {.lex_state = 420, .external_lex_state = 2},
  [12943] = {.lex_state = 420, .external_lex_state = 2},
  [12944] = {.lex_state = 218, .external_lex_state = 2},
  [12945] = {.lex_state = 420, .external_lex_state = 2},
  [12946] = {.lex_state = 420, .external_lex_state = 2},
  [12947] = {.lex_state = 28, .external_lex_state = 2},
  [12948] = {.lex_state = 420, .external_lex_state = 2},
  [12949] = {.lex_state = 420, .external_lex_state = 2},
  [12950] = {.lex_state = 420, .external_lex_state = 2},
  [12951] = {.lex_state = 420, .external_lex_state = 2},
  [12952] = {.lex_state = 420, .external_lex_state = 2},
  [12953] = {.lex_state = 420, .external_lex_state = 2},
  [12954] = {.lex_state = 241, .external_lex_state = 2},
  [12955] = {.lex_state = 242, .external_lex_state = 2},
  [12956] = {.lex_state = 228, .external_lex_state = 2},
  [12957] = {.lex_state = 420, .external_lex_state = 2},
  [12958] = {.lex_state = 420, .external_lex_state = 2},
  [12959] = {.lex_state = 420, .external_lex_state = 2},
  [12960] = {.lex_state = 28, .external_lex_state = 2},
  [12961] = {.lex_state = 420, .external_lex_state = 2},
  [12962] = {.lex_state = 420, .external_lex_state = 2},
  [12963] = {.lex_state = 420, .external_lex_state = 2},
  [12964] = {.lex_state = 420, .external_lex_state = 2},
  [12965] = {.lex_state = 420, .external_lex_state = 2},
  [12966] = {.lex_state = 420, .external_lex_state = 2},
  [12967] = {.lex_state = 420, .external_lex_state = 2},
  [12968] = {.lex_state = 205, .external_lex_state = 2},
  [12969] = {.lex_state = 28, .external_lex_state = 2},
  [12970] = {.lex_state = 420, .external_lex_state = 2},
  [12971] = {.lex_state = 420, .external_lex_state = 2},
  [12972] = {.lex_state = 420, .external_lex_state = 2},
  [12973] = {.lex_state = 420, .external_lex_state = 2},
  [12974] = {.lex_state = 420, .external_lex_state = 2},
  [12975] = {.lex_state = 420, .external_lex_state = 2},
  [12976] = {.lex_state = 420, .external_lex_state = 2},
  [12977] = {.lex_state = 28, .external_lex_state = 2},
  [12978] = {.lex_state = 28, .external_lex_state = 2},
  [12979] = {.lex_state = 28, .external_lex_state = 2},
  [12980] = {.lex_state = 420, .external_lex_state = 2},
  [12981] = {.lex_state = 420, .external_lex_state = 2},
  [12982] = {.lex_state = 420, .external_lex_state = 2},
  [12983] = {.lex_state = 28, .external_lex_state = 2},
  [12984] = {.lex_state = 420, .external_lex_state = 2},
  [12985] = {.lex_state = 420, .external_lex_state = 2},
  [12986] = {.lex_state = 420, .external_lex_state = 2},
  [12987] = {.lex_state = 420, .external_lex_state = 2},
  [12988] = {.lex_state = 420, .external_lex_state = 2},
  [12989] = {.lex_state = 420, .external_lex_state = 2},
  [12990] = {.lex_state = 420, .external_lex_state = 2},
  [12991] = {.lex_state = 420, .external_lex_state = 2},
  [12992] = {.lex_state = 420, .external_lex_state = 2},
  [12993] = {.lex_state = 28, .external_lex_state = 2},
  [12994] = {.lex_state = 420, .external_lex_state = 2},
  [12995] = {.lex_state = 420, .external_lex_state = 2},
  [12996] = {.lex_state = 420, .external_lex_state = 2},
  [12997] = {.lex_state = 420, .external_lex_state = 2},
  [12998] = {.lex_state = 420, .external_lex_state = 2},
  [12999] = {.lex_state = 420, .external_lex_state = 2},
  [13000] = {.lex_state = 420, .external_lex_state = 2},
  [13001] = {.lex_state = 420, .external_lex_state = 2},
  [13002] = {.lex_state = 420, .external_lex_state = 2},
  [13003] = {.lex_state = 420, .external_lex_state = 2},
  [13004] = {.lex_state = 420, .external_lex_state = 2},
  [13005] = {.lex_state = 420, .external_lex_state = 2},
  [13006] = {.lex_state = 420, .external_lex_state = 2},
  [13007] = {.lex_state = 420, .external_lex_state = 2},
  [13008] = {.lex_state = 242, .external_lex_state = 2},
  [13009] = {.lex_state = 420, .external_lex_state = 2},
  [13010] = {.lex_state = 420, .external_lex_state = 2},
  [13011] = {.lex_state = 420, .external_lex_state = 2},
  [13012] = {.lex_state = 420, .external_lex_state = 2},
  [13013] = {.lex_state = 420, .external_lex_state = 2},
  [13014] = {.lex_state = 420, .external_lex_state = 2},
  [13015] = {.lex_state = 420, .external_lex_state = 2},
  [13016] = {.lex_state = 28, .external_lex_state = 2},
  [13017] = {.lex_state = 420, .external_lex_state = 2},
  [13018] = {.lex_state = 420, .external_lex_state = 2},
  [13019] = {.lex_state = 420, .external_lex_state = 2},
  [13020] = {.lex_state = 28, .external_lex_state = 2},
  [13021] = {.lex_state = 420, .external_lex_state = 2},
  [13022] = {.lex_state = 420, .external_lex_state = 2},
  [13023] = {.lex_state = 420, .external_lex_state = 2},
  [13024] = {.lex_state = 420, .external_lex_state = 2},
  [13025] = {.lex_state = 420, .external_lex_state = 2},
  [13026] = {.lex_state = 420, .external_lex_state = 2},
  [13027] = {.lex_state = 420, .external_lex_state = 2},
  [13028] = {.lex_state = 28, .external_lex_state = 2},
  [13029] = {.lex_state = 420, .external_lex_state = 2},
  [13030] = {.lex_state = 420, .external_lex_state = 2},
  [13031] = {.lex_state = 420, .external_lex_state = 2},
  [13032] = {.lex_state = 420, .external_lex_state = 2},
  [13033] = {.lex_state = 28, .external_lex_state = 2},
  [13034] = {.lex_state = 420, .external_lex_state = 2},
  [13035] = {.lex_state = 420, .external_lex_state = 2},
  [13036] = {.lex_state = 420, .external_lex_state = 2},
  [13037] = {.lex_state = 242, .external_lex_state = 2},
  [13038] = {.lex_state = 420, .external_lex_state = 2},
  [13039] = {.lex_state = 241, .external_lex_state = 2},
  [13040] = {.lex_state = 420, .external_lex_state = 2},
  [13041] = {.lex_state = 420, .external_lex_state = 2},
  [13042] = {.lex_state = 420, .external_lex_state = 2},
  [13043] = {.lex_state = 224, .external_lex_state = 2},
  [13044] = {.lex_state = 420, .external_lex_state = 2},
  [13045] = {.lex_state = 420, .external_lex_state = 2},
  [13046] = {.lex_state = 420, .external_lex_state = 2},
  [13047] = {.lex_state = 420, .external_lex_state = 2},
  [13048] = {.lex_state = 28, .external_lex_state = 2},
  [13049] = {.lex_state = 420, .external_lex_state = 2},
  [13050] = {.lex_state = 420, .external_lex_state = 2},
  [13051] = {.lex_state = 420, .external_lex_state = 2},
  [13052] = {.lex_state = 28, .external_lex_state = 2},
  [13053] = {.lex_state = 420, .external_lex_state = 2},
  [13054] = {.lex_state = 420, .external_lex_state = 2},
  [13055] = {.lex_state = 12, .external_lex_state = 2},
  [13056] = {.lex_state = 420, .external_lex_state = 2},
  [13057] = {.lex_state = 242, .external_lex_state = 2},
  [13058] = {.lex_state = 420, .external_lex_state = 2},
  [13059] = {.lex_state = 420, .external_lex_state = 2},
  [13060] = {.lex_state = 420, .external_lex_state = 2},
  [13061] = {.lex_state = 420, .external_lex_state = 2},
  [13062] = {.lex_state = 420, .external_lex_state = 2},
  [13063] = {.lex_state = 420, .external_lex_state = 2},
  [13064] = {.lex_state = 420, .external_lex_state = 2},
  [13065] = {.lex_state = 420, .external_lex_state = 2},
  [13066] = {.lex_state = 28, .external_lex_state = 2},
  [13067] = {.lex_state = 420, .external_lex_state = 2},
  [13068] = {.lex_state = 420, .external_lex_state = 2},
  [13069] = {.lex_state = 420, .external_lex_state = 2},
  [13070] = {.lex_state = 420, .external_lex_state = 2},
  [13071] = {.lex_state = 420, .external_lex_state = 2},
  [13072] = {.lex_state = 420, .external_lex_state = 2},
  [13073] = {.lex_state = 420, .external_lex_state = 2},
  [13074] = {.lex_state = 228, .external_lex_state = 2},
  [13075] = {.lex_state = 420, .external_lex_state = 2},
  [13076] = {.lex_state = 242, .external_lex_state = 2},
  [13077] = {.lex_state = 28, .external_lex_state = 2},
  [13078] = {.lex_state = 420, .external_lex_state = 2},
  [13079] = {.lex_state = 28, .external_lex_state = 2},
  [13080] = {.lex_state = 28, .external_lex_state = 2},
  [13081] = {.lex_state = 420, .external_lex_state = 2},
  [13082] = {.lex_state = 420, .external_lex_state = 2},
  [13083] = {.lex_state = 28, .external_lex_state = 2},
  [13084] = {.lex_state = 420, .external_lex_state = 2},
  [13085] = {.lex_state = 420, .external_lex_state = 2},
  [13086] = {.lex_state = 28, .external_lex_state = 2},
  [13087] = {.lex_state = 420, .external_lex_state = 2},
  [13088] = {.lex_state = 420, .external_lex_state = 2},
  [13089] = {.lex_state = 420, .external_lex_state = 2},
  [13090] = {.lex_state = 420, .external_lex_state = 2},
  [13091] = {.lex_state = 420, .external_lex_state = 2},
  [13092] = {.lex_state = 420, .external_lex_state = 2},
  [13093] = {.lex_state = 242, .external_lex_state = 2},
  [13094] = {.lex_state = 420, .external_lex_state = 2},
  [13095] = {.lex_state = 420, .external_lex_state = 2},
  [13096] = {.lex_state = 28, .external_lex_state = 2},
  [13097] = {.lex_state = 420, .external_lex_state = 2},
  [13098] = {.lex_state = 420, .external_lex_state = 2},
  [13099] = {.lex_state = 420, .external_lex_state = 2},
  [13100] = {.lex_state = 420, .external_lex_state = 2},
  [13101] = {.lex_state = 420, .external_lex_state = 2},
  [13102] = {.lex_state = 420, .external_lex_state = 2},
  [13103] = {.lex_state = 420, .external_lex_state = 2},
  [13104] = {.lex_state = 420, .external_lex_state = 2},
  [13105] = {.lex_state = 28, .external_lex_state = 2},
  [13106] = {.lex_state = 420, .external_lex_state = 2},
  [13107] = {.lex_state = 242, .external_lex_state = 2},
  [13108] = {.lex_state = 28, .external_lex_state = 2},
  [13109] = {.lex_state = 420, .external_lex_state = 2},
  [13110] = {.lex_state = 28, .external_lex_state = 2},
  [13111] = {.lex_state = 420, .external_lex_state = 2},
  [13112] = {.lex_state = 28, .external_lex_state = 2},
  [13113] = {.lex_state = 28, .external_lex_state = 2},
  [13114] = {.lex_state = 420, .external_lex_state = 2},
  [13115] = {.lex_state = 420, .external_lex_state = 2},
  [13116] = {.lex_state = 420, .external_lex_state = 2},
  [13117] = {.lex_state = 420, .external_lex_state = 2},
  [13118] = {.lex_state = 420, .external_lex_state = 2},
  [13119] = {.lex_state = 420, .external_lex_state = 2},
  [13120] = {.lex_state = 420, .external_lex_state = 2},
  [13121] = {.lex_state = 420, .external_lex_state = 2},
  [13122] = {.lex_state = 420, .external_lex_state = 2},
  [13123] = {.lex_state = 420, .external_lex_state = 2},
  [13124] = {.lex_state = 28, .external_lex_state = 2},
  [13125] = {.lex_state = 28, .external_lex_state = 2},
  [13126] = {.lex_state = 28, .external_lex_state = 2},
  [13127] = {.lex_state = 420, .external_lex_state = 2},
  [13128] = {.lex_state = 420, .external_lex_state = 2},
  [13129] = {.lex_state = 420, .external_lex_state = 2},
  [13130] = {.lex_state = 420, .external_lex_state = 2},
  [13131] = {.lex_state = 205, .external_lex_state = 2},
  [13132] = {.lex_state = 420, .external_lex_state = 2},
  [13133] = {.lex_state = 420, .external_lex_state = 2},
  [13134] = {.lex_state = 420, .external_lex_state = 2},
  [13135] = {.lex_state = 28, .external_lex_state = 2},
  [13136] = {.lex_state = 28, .external_lex_state = 2},
  [13137] = {.lex_state = 420, .external_lex_state = 2},
  [13138] = {.lex_state = 205, .external_lex_state = 2},
  [13139] = {.lex_state = 205, .external_lex_state = 2},
  [13140] = {.lex_state = 205, .external_lex_state = 2},
  [13141] = {.lex_state = 208, .external_lex_state = 2},
  [13142] = {.lex_state = 224, .external_lex_state = 2},
  [13143] = {.lex_state = 420, .external_lex_state = 2},
  [13144] = {.lex_state = 218, .external_lex_state = 2},
  [13145] = {.lex_state = 218, .external_lex_state = 2},
  [13146] = {.lex_state = 218, .external_lex_state = 2},
  [13147] = {.lex_state = 420, .external_lex_state = 2},
  [13148] = {.lex_state = 420, .external_lex_state = 2},
  [13149] = {.lex_state = 420, .external_lex_state = 2},
  [13150] = {.lex_state = 420, .external_lex_state = 2},
  [13151] = {.lex_state = 208, .external_lex_state = 2},
  [13152] = {.lex_state = 420, .external_lex_state = 2},
  [13153] = {.lex_state = 420, .external_lex_state = 2},
  [13154] = {.lex_state = 420, .external_lex_state = 2},
  [13155] = {.lex_state = 28, .external_lex_state = 2},
  [13156] = {.lex_state = 224, .external_lex_state = 2},
  [13157] = {.lex_state = 224, .external_lex_state = 2},
  [13158] = {.lex_state = 208, .external_lex_state = 2},
  [13159] = {.lex_state = 224, .external_lex_state = 2},
  [13160] = {.lex_state = 224, .external_lex_state = 2},
  [13161] = {.lex_state = 218, .external_lex_state = 2},
  [13162] = {.lex_state = 224, .external_lex_state = 2},
  [13163] = {.lex_state = 224, .external_lex_state = 2},
  [13164] = {.lex_state = 224, .external_lex_state = 2},
  [13165] = {.lex_state = 218, .external_lex_state = 2},
  [13166] = {.lex_state = 241, .external_lex_state = 2},
  [13167] = {.lex_state = 224, .external_lex_state = 2},
  [13168] = {.lex_state = 224, .external_lex_state = 2},
  [13169] = {.lex_state = 224, .external_lex_state = 2},
  [13170] = {.lex_state = 224, .external_lex_state = 2},
  [13171] = {.lex_state = 224, .external_lex_state = 2},
  [13172] = {.lex_state = 224, .external_lex_state = 2},
  [13173] = {.lex_state = 224, .external_lex_state = 2},
  [13174] = {.lex_state = 224, .external_lex_state = 2},
  [13175] = {.lex_state = 224, .external_lex_state = 2},
  [13176] = {.lex_state = 224, .external_lex_state = 2},
  [13177] = {.lex_state = 224, .external_lex_state = 2},
  [13178] = {.lex_state = 420, .external_lex_state = 2},
  [13179] = {.lex_state = 224, .external_lex_state = 2},
  [13180] = {.lex_state = 224, .external_lex_state = 2},
  [13181] = {.lex_state = 224, .external_lex_state = 2},
  [13182] = {.lex_state = 224, .external_lex_state = 2},
  [13183] = {.lex_state = 224, .external_lex_state = 2},
  [13184] = {.lex_state = 224, .external_lex_state = 2},
  [13185] = {.lex_state = 224, .external_lex_state = 2},
  [13186] = {.lex_state = 224, .external_lex_state = 2},
  [13187] = {.lex_state = 224, .external_lex_state = 2},
  [13188] = {.lex_state = 224, .external_lex_state = 2},
  [13189] = {.lex_state = 420, .external_lex_state = 2},
  [13190] = {.lex_state = 224, .external_lex_state = 2},
  [13191] = {.lex_state = 224, .external_lex_state = 2},
  [13192] = {.lex_state = 224, .external_lex_state = 2},
  [13193] = {.lex_state = 28, .external_lex_state = 2},
  [13194] = {.lex_state = 214, .external_lex_state = 2},
  [13195] = {.lex_state = 8, .external_lex_state = 2},
  [13196] = {.lex_state = 205, .external_lex_state = 2},
  [13197] = {.lex_state = 205, .external_lex_state = 2},
  [13198] = {.lex_state = 205, .external_lex_state = 2},
  [13199] = {.lex_state = 8, .external_lex_state = 2},
  [13200] = {.lex_state = 214, .external_lex_state = 2},
  [13201] = {.lex_state = 214, .external_lex_state = 2},
  [13202] = {.lex_state = 205, .external_lex_state = 2},
  [13203] = {.lex_state = 205, .external_lex_state = 2},
  [13204] = {.lex_state = 205, .external_lex_state = 2},
  [13205] = {.lex_state = 8, .external_lex_state = 2},
  [13206] = {.lex_state = 205, .external_lex_state = 2},
  [13207] = {.lex_state = 205, .external_lex_state = 2},
  [13208] = {.lex_state = 8, .external_lex_state = 2},
  [13209] = {.lex_state = 28, .external_lex_state = 2},
  [13210] = {.lex_state = 205, .external_lex_state = 2},
  [13211] = {.lex_state = 205, .external_lex_state = 2},
  [13212] = {.lex_state = 8, .external_lex_state = 2},
  [13213] = {.lex_state = 205, .external_lex_state = 2},
  [13214] = {.lex_state = 205, .external_lex_state = 2},
  [13215] = {.lex_state = 205, .external_lex_state = 2},
  [13216] = {.lex_state = 8, .external_lex_state = 2},
  [13217] = {.lex_state = 28, .external_lex_state = 2},
  [13218] = {.lex_state = 28, .external_lex_state = 2},
  [13219] = {.lex_state = 7, .external_lex_state = 2},
  [13220] = {.lex_state = 214, .external_lex_state = 2},
  [13221] = {.lex_state = 246, .external_lex_state = 2},
  [13222] = {.lex_state = 205, .external_lex_state = 2},
  [13223] = {.lex_state = 205, .external_lex_state = 2},
  [13224] = {.lex_state = 228, .external_lex_state = 2},
  [13225] = {.lex_state = 28, .external_lex_state = 2},
  [13226] = {.lex_state = 205, .external_lex_state = 2},
  [13227] = {.lex_state = 205, .external_lex_state = 2},
  [13228] = {.lex_state = 208, .external_lex_state = 2},
  [13229] = {.lex_state = 8, .external_lex_state = 2},
  [13230] = {.lex_state = 28, .external_lex_state = 2},
  [13231] = {.lex_state = 205, .external_lex_state = 2},
  [13232] = {.lex_state = 8, .external_lex_state = 2},
  [13233] = {.lex_state = 205, .external_lex_state = 2},
  [13234] = {.lex_state = 214, .external_lex_state = 2},
  [13235] = {.lex_state = 214, .external_lex_state = 2},
  [13236] = {.lex_state = 420, .external_lex_state = 2},
  [13237] = {.lex_state = 246, .external_lex_state = 2},
  [13238] = {.lex_state = 205, .external_lex_state = 2},
  [13239] = {.lex_state = 205, .external_lex_state = 2},
  [13240] = {.lex_state = 228, .external_lex_state = 2},
  [13241] = {.lex_state = 4, .external_lex_state = 6},
  [13242] = {.lex_state = 243, .external_lex_state = 2},
  [13243] = {.lex_state = 4, .external_lex_state = 6},
  [13244] = {.lex_state = 205, .external_lex_state = 2},
  [13245] = {.lex_state = 243, .external_lex_state = 2},
  [13246] = {.lex_state = 243, .external_lex_state = 2},
  [13247] = {.lex_state = 4, .external_lex_state = 6},
  [13248] = {.lex_state = 420, .external_lex_state = 2},
  [13249] = {.lex_state = 8, .external_lex_state = 2},
  [13250] = {.lex_state = 420, .external_lex_state = 2},
  [13251] = {.lex_state = 4, .external_lex_state = 6},
  [13252] = {.lex_state = 28, .external_lex_state = 2},
  [13253] = {.lex_state = 4, .external_lex_state = 6},
  [13254] = {.lex_state = 4, .external_lex_state = 6},
  [13255] = {.lex_state = 243, .external_lex_state = 2},
  [13256] = {.lex_state = 4, .external_lex_state = 6},
  [13257] = {.lex_state = 243, .external_lex_state = 2},
  [13258] = {.lex_state = 246, .external_lex_state = 2},
  [13259] = {.lex_state = 243, .external_lex_state = 2},
  [13260] = {.lex_state = 28, .external_lex_state = 2},
  [13261] = {.lex_state = 8, .external_lex_state = 2},
  [13262] = {.lex_state = 214, .external_lex_state = 2},
  [13263] = {.lex_state = 28, .external_lex_state = 2},
  [13264] = {.lex_state = 4, .external_lex_state = 6},
  [13265] = {.lex_state = 28, .external_lex_state = 2},
  [13266] = {.lex_state = 4, .external_lex_state = 6},
  [13267] = {.lex_state = 420, .external_lex_state = 2},
  [13268] = {.lex_state = 237, .external_lex_state = 7},
  [13269] = {.lex_state = 4, .external_lex_state = 6},
  [13270] = {.lex_state = 4, .external_lex_state = 6},
  [13271] = {.lex_state = 420, .external_lex_state = 2},
  [13272] = {.lex_state = 420, .external_lex_state = 2},
  [13273] = {.lex_state = 4, .external_lex_state = 6},
  [13274] = {.lex_state = 4, .external_lex_state = 6},
  [13275] = {.lex_state = 243, .external_lex_state = 2},
  [13276] = {.lex_state = 243, .external_lex_state = 2},
  [13277] = {.lex_state = 243, .external_lex_state = 2},
  [13278] = {.lex_state = 4, .external_lex_state = 6},
  [13279] = {.lex_state = 28, .external_lex_state = 2},
  [13280] = {.lex_state = 243, .external_lex_state = 2},
  [13281] = {.lex_state = 243, .external_lex_state = 2},
  [13282] = {.lex_state = 28, .external_lex_state = 2},
  [13283] = {.lex_state = 420, .external_lex_state = 2},
  [13284] = {.lex_state = 243, .external_lex_state = 2},
  [13285] = {.lex_state = 4, .external_lex_state = 6},
  [13286] = {.lex_state = 28, .external_lex_state = 2},
  [13287] = {.lex_state = 420, .external_lex_state = 2},
  [13288] = {.lex_state = 243, .external_lex_state = 2},
  [13289] = {.lex_state = 243, .external_lex_state = 2},
  [13290] = {.lex_state = 420, .external_lex_state = 2},
  [13291] = {.lex_state = 243, .external_lex_state = 2},
  [13292] = {.lex_state = 4, .external_lex_state = 6},
  [13293] = {.lex_state = 28, .external_lex_state = 2},
  [13294] = {.lex_state = 28, .external_lex_state = 2},
  [13295] = {.lex_state = 4, .external_lex_state = 6},
  [13296] = {.lex_state = 4, .external_lex_state = 6},
  [13297] = {.lex_state = 28, .external_lex_state = 2},
  [13298] = {.lex_state = 420, .external_lex_state = 2},
  [13299] = {.lex_state = 214, .external_lex_state = 2},
  [13300] = {.lex_state = 4, .external_lex_state = 6},
  [13301] = {.lex_state = 8, .external_lex_state = 2},
  [13302] = {.lex_state = 28, .external_lex_state = 2},
  [13303] = {.lex_state = 8, .external_lex_state = 2},
  [13304] = {.lex_state = 4, .external_lex_state = 6},
  [13305] = {.lex_state = 243, .external_lex_state = 2},
  [13306] = {.lex_state = 228, .external_lex_state = 2},
  [13307] = {.lex_state = 420, .external_lex_state = 2},
  [13308] = {.lex_state = 28, .external_lex_state = 2},
  [13309] = {.lex_state = 205, .external_lex_state = 2},
  [13310] = {.lex_state = 28, .external_lex_state = 2},
  [13311] = {.lex_state = 205, .external_lex_state = 2},
  [13312] = {.lex_state = 28, .external_lex_state = 2},
  [13313] = {.lex_state = 243, .external_lex_state = 2},
  [13314] = {.lex_state = 28, .external_lex_state = 2},
  [13315] = {.lex_state = 28, .external_lex_state = 2},
  [13316] = {.lex_state = 28, .external_lex_state = 2},
  [13317] = {.lex_state = 4, .external_lex_state = 6},
  [13318] = {.lex_state = 4, .external_lex_state = 6},
  [13319] = {.lex_state = 4, .external_lex_state = 6},
  [13320] = {.lex_state = 4, .external_lex_state = 6},
  [13321] = {.lex_state = 243, .external_lex_state = 2},
  [13322] = {.lex_state = 4, .external_lex_state = 6},
  [13323] = {.lex_state = 4, .external_lex_state = 6},
  [13324] = {.lex_state = 4, .external_lex_state = 6},
  [13325] = {.lex_state = 228, .external_lex_state = 2},
  [13326] = {.lex_state = 4, .external_lex_state = 6},
  [13327] = {.lex_state = 205, .external_lex_state = 2},
  [13328] = {.lex_state = 4, .external_lex_state = 6},
  [13329] = {.lex_state = 205, .external_lex_state = 2},
  [13330] = {.lex_state = 28, .external_lex_state = 2},
  [13331] = {.lex_state = 243, .external_lex_state = 2},
  [13332] = {.lex_state = 28, .external_lex_state = 2},
  [13333] = {.lex_state = 214, .external_lex_state = 2},
  [13334] = {.lex_state = 4, .external_lex_state = 6},
  [13335] = {.lex_state = 420, .external_lex_state = 2},
  [13336] = {.lex_state = 4, .external_lex_state = 6},
  [13337] = {.lex_state = 4, .external_lex_state = 6},
  [13338] = {.lex_state = 420, .external_lex_state = 2},
  [13339] = {.lex_state = 246, .external_lex_state = 2},
  [13340] = {.lex_state = 4, .external_lex_state = 6},
  [13341] = {.lex_state = 4, .external_lex_state = 6},
  [13342] = {.lex_state = 243, .external_lex_state = 2},
  [13343] = {.lex_state = 4, .external_lex_state = 6},
  [13344] = {.lex_state = 243, .external_lex_state = 2},
  [13345] = {.lex_state = 420, .external_lex_state = 2},
  [13346] = {.lex_state = 243, .external_lex_state = 2},
  [13347] = {.lex_state = 243, .external_lex_state = 2},
  [13348] = {.lex_state = 243, .external_lex_state = 2},
  [13349] = {.lex_state = 28, .external_lex_state = 2},
  [13350] = {.lex_state = 4, .external_lex_state = 6},
  [13351] = {.lex_state = 214, .external_lex_state = 2},
  [13352] = {.lex_state = 4, .external_lex_state = 6},
  [13353] = {.lex_state = 243, .external_lex_state = 2},
  [13354] = {.lex_state = 28, .external_lex_state = 2},
  [13355] = {.lex_state = 28, .external_lex_state = 2},
  [13356] = {.lex_state = 420, .external_lex_state = 2},
  [13357] = {.lex_state = 28, .external_lex_state = 2},
  [13358] = {.lex_state = 28, .external_lex_state = 2},
  [13359] = {.lex_state = 243, .external_lex_state = 2},
  [13360] = {.lex_state = 243, .external_lex_state = 2},
  [13361] = {.lex_state = 28, .external_lex_state = 2},
  [13362] = {.lex_state = 4, .external_lex_state = 6},
  [13363] = {.lex_state = 208, .external_lex_state = 2},
  [13364] = {.lex_state = 243, .external_lex_state = 2},
  [13365] = {.lex_state = 4, .external_lex_state = 6},
  [13366] = {.lex_state = 4, .external_lex_state = 6},
  [13367] = {.lex_state = 420, .external_lex_state = 2},
  [13368] = {.lex_state = 228, .external_lex_state = 2},
  [13369] = {.lex_state = 4, .external_lex_state = 6},
  [13370] = {.lex_state = 8, .external_lex_state = 2},
  [13371] = {.lex_state = 4, .external_lex_state = 6},
  [13372] = {.lex_state = 8, .external_lex_state = 2},
  [13373] = {.lex_state = 4, .external_lex_state = 6},
  [13374] = {.lex_state = 243, .external_lex_state = 2},
  [13375] = {.lex_state = 243, .external_lex_state = 2},
  [13376] = {.lex_state = 4, .external_lex_state = 6},
  [13377] = {.lex_state = 420, .external_lex_state = 2},
  [13378] = {.lex_state = 4, .external_lex_state = 6},
  [13379] = {.lex_state = 8, .external_lex_state = 2},
  [13380] = {.lex_state = 8, .external_lex_state = 2},
  [13381] = {.lex_state = 243, .external_lex_state = 2},
  [13382] = {.lex_state = 243, .external_lex_state = 2},
  [13383] = {.lex_state = 8, .external_lex_state = 2},
  [13384] = {.lex_state = 243, .external_lex_state = 2},
  [13385] = {.lex_state = 4, .external_lex_state = 6},
  [13386] = {.lex_state = 243, .external_lex_state = 2},
  [13387] = {.lex_state = 4, .external_lex_state = 6},
  [13388] = {.lex_state = 4, .external_lex_state = 6},
  [13389] = {.lex_state = 4, .external_lex_state = 6},
  [13390] = {.lex_state = 4, .external_lex_state = 6},
  [13391] = {.lex_state = 8, .external_lex_state = 2},
  [13392] = {.lex_state = 4, .external_lex_state = 6},
  [13393] = {.lex_state = 4, .external_lex_state = 6},
  [13394] = {.lex_state = 420, .external_lex_state = 2},
  [13395] = {.lex_state = 243, .external_lex_state = 2},
  [13396] = {.lex_state = 4, .external_lex_state = 6},
  [13397] = {.lex_state = 243, .external_lex_state = 2},
  [13398] = {.lex_state = 228, .external_lex_state = 2},
  [13399] = {.lex_state = 205, .external_lex_state = 2},
  [13400] = {.lex_state = 4, .external_lex_state = 6},
  [13401] = {.lex_state = 8, .external_lex_state = 2},
  [13402] = {.lex_state = 205, .external_lex_state = 2},
  [13403] = {.lex_state = 420, .external_lex_state = 2},
  [13404] = {.lex_state = 243, .external_lex_state = 2},
  [13405] = {.lex_state = 420, .external_lex_state = 2},
  [13406] = {.lex_state = 243, .external_lex_state = 2},
  [13407] = {.lex_state = 8, .external_lex_state = 2},
  [13408] = {.lex_state = 8, .external_lex_state = 2},
  [13409] = {.lex_state = 28, .external_lex_state = 2},
  [13410] = {.lex_state = 420, .external_lex_state = 2},
  [13411] = {.lex_state = 8, .external_lex_state = 2},
  [13412] = {.lex_state = 4, .external_lex_state = 6},
  [13413] = {.lex_state = 4, .external_lex_state = 6},
  [13414] = {.lex_state = 243, .external_lex_state = 2},
  [13415] = {.lex_state = 243, .external_lex_state = 2},
  [13416] = {.lex_state = 243, .external_lex_state = 2},
  [13417] = {.lex_state = 243, .external_lex_state = 2},
  [13418] = {.lex_state = 28, .external_lex_state = 2},
  [13419] = {.lex_state = 4, .external_lex_state = 6},
  [13420] = {.lex_state = 243, .external_lex_state = 2},
  [13421] = {.lex_state = 243, .external_lex_state = 2},
  [13422] = {.lex_state = 28, .external_lex_state = 2},
  [13423] = {.lex_state = 28, .external_lex_state = 2},
  [13424] = {.lex_state = 28, .external_lex_state = 2},
  [13425] = {.lex_state = 7, .external_lex_state = 2},
  [13426] = {.lex_state = 426, .external_lex_state = 2},
  [13427] = {.lex_state = 28, .external_lex_state = 2},
  [13428] = {.lex_state = 28, .external_lex_state = 2},
  [13429] = {.lex_state = 205, .external_lex_state = 2},
  [13430] = {.lex_state = 28, .external_lex_state = 2},
  [13431] = {.lex_state = 7, .external_lex_state = 2},
  [13432] = {.lex_state = 28, .external_lex_state = 2},
  [13433] = {.lex_state = 28, .external_lex_state = 2},
  [13434] = {.lex_state = 426, .external_lex_state = 2},
  [13435] = {.lex_state = 7, .external_lex_state = 2},
  [13436] = {.lex_state = 7, .external_lex_state = 2},
  [13437] = {.lex_state = 420, .external_lex_state = 2},
  [13438] = {.lex_state = 28, .external_lex_state = 2},
  [13439] = {.lex_state = 205, .external_lex_state = 2},
  [13440] = {.lex_state = 7, .external_lex_state = 2},
  [13441] = {.lex_state = 420, .external_lex_state = 2},
  [13442] = {.lex_state = 28, .external_lex_state = 2},
  [13443] = {.lex_state = 7, .external_lex_state = 2},
  [13444] = {.lex_state = 28, .external_lex_state = 2},
  [13445] = {.lex_state = 7, .external_lex_state = 2},
  [13446] = {.lex_state = 426, .external_lex_state = 2},
  [13447] = {.lex_state = 28, .external_lex_state = 2},
  [13448] = {.lex_state = 28, .external_lex_state = 2},
  [13449] = {.lex_state = 7, .external_lex_state = 2},
  [13450] = {.lex_state = 28, .external_lex_state = 2},
  [13451] = {.lex_state = 205, .external_lex_state = 2},
  [13452] = {.lex_state = 28, .external_lex_state = 2},
  [13453] = {.lex_state = 7, .external_lex_state = 2},
  [13454] = {.lex_state = 7, .external_lex_state = 2},
  [13455] = {.lex_state = 7, .external_lex_state = 2},
  [13456] = {.lex_state = 28, .external_lex_state = 2},
  [13457] = {.lex_state = 426, .external_lex_state = 2},
  [13458] = {.lex_state = 237, .external_lex_state = 7},
  [13459] = {.lex_state = 7, .external_lex_state = 2},
  [13460] = {.lex_state = 28, .external_lex_state = 2},
  [13461] = {.lex_state = 28, .external_lex_state = 2},
  [13462] = {.lex_state = 28, .external_lex_state = 2},
  [13463] = {.lex_state = 7, .external_lex_state = 2},
  [13464] = {.lex_state = 224, .external_lex_state = 2},
  [13465] = {.lex_state = 28, .external_lex_state = 2},
  [13466] = {.lex_state = 7, .external_lex_state = 2},
  [13467] = {.lex_state = 7, .external_lex_state = 2},
  [13468] = {.lex_state = 28, .external_lex_state = 2},
  [13469] = {.lex_state = 7, .external_lex_state = 2},
  [13470] = {.lex_state = 7, .external_lex_state = 2},
  [13471] = {.lex_state = 237, .external_lex_state = 7},
  [13472] = {.lex_state = 7, .external_lex_state = 2},
  [13473] = {.lex_state = 7, .external_lex_state = 2},
  [13474] = {.lex_state = 7, .external_lex_state = 2},
  [13475] = {.lex_state = 28, .external_lex_state = 2},
  [13476] = {.lex_state = 7, .external_lex_state = 2},
  [13477] = {.lex_state = 205, .external_lex_state = 2},
  [13478] = {.lex_state = 7, .external_lex_state = 2},
  [13479] = {.lex_state = 28, .external_lex_state = 2},
  [13480] = {.lex_state = 28, .external_lex_state = 2},
  [13481] = {.lex_state = 205, .external_lex_state = 2},
  [13482] = {.lex_state = 205, .external_lex_state = 2},
  [13483] = {.lex_state = 28, .external_lex_state = 2},
  [13484] = {.lex_state = 426, .external_lex_state = 2},
  [13485] = {.lex_state = 28, .external_lex_state = 2},
  [13486] = {.lex_state = 28, .external_lex_state = 2},
  [13487] = {.lex_state = 205, .external_lex_state = 2},
  [13488] = {.lex_state = 7, .external_lex_state = 2},
  [13489] = {.lex_state = 205, .external_lex_state = 2},
  [13490] = {.lex_state = 7, .external_lex_state = 2},
  [13491] = {.lex_state = 214, .external_lex_state = 2},
  [13492] = {.lex_state = 28, .external_lex_state = 2},
  [13493] = {.lex_state = 7, .external_lex_state = 2},
  [13494] = {.lex_state = 7, .external_lex_state = 2},
  [13495] = {.lex_state = 7, .external_lex_state = 2},
  [13496] = {.lex_state = 28, .external_lex_state = 2},
  [13497] = {.lex_state = 224, .external_lex_state = 2},
  [13498] = {.lex_state = 28, .external_lex_state = 2},
  [13499] = {.lex_state = 209, .external_lex_state = 2},
  [13500] = {.lex_state = 205, .external_lex_state = 2},
  [13501] = {.lex_state = 205, .external_lex_state = 2},
  [13502] = {.lex_state = 28, .external_lex_state = 2},
  [13503] = {.lex_state = 28, .external_lex_state = 2},
  [13504] = {.lex_state = 28, .external_lex_state = 2},
  [13505] = {.lex_state = 6, .external_lex_state = 2},
  [13506] = {.lex_state = 214, .external_lex_state = 2},
  [13507] = {.lex_state = 28, .external_lex_state = 2},
  [13508] = {.lex_state = 29, .external_lex_state = 2},
  [13509] = {.lex_state = 205, .external_lex_state = 2},
  [13510] = {.lex_state = 28, .external_lex_state = 2},
  [13511] = {.lex_state = 28, .external_lex_state = 2},
  [13512] = {.lex_state = 229, .external_lex_state = 2},
  [13513] = {.lex_state = 28, .external_lex_state = 2},
  [13514] = {.lex_state = 28, .external_lex_state = 2},
  [13515] = {.lex_state = 28, .external_lex_state = 2},
  [13516] = {.lex_state = 205, .external_lex_state = 2},
  [13517] = {.lex_state = 29, .external_lex_state = 2},
  [13518] = {.lex_state = 28, .external_lex_state = 2},
  [13519] = {.lex_state = 8, .external_lex_state = 2},
  [13520] = {.lex_state = 28, .external_lex_state = 2},
  [13521] = {.lex_state = 28, .external_lex_state = 2},
  [13522] = {.lex_state = 205, .external_lex_state = 2},
  [13523] = {.lex_state = 224, .external_lex_state = 2},
  [13524] = {.lex_state = 28, .external_lex_state = 2},
  [13525] = {.lex_state = 28, .external_lex_state = 2},
  [13526] = {.lex_state = 28, .external_lex_state = 2},
  [13527] = {.lex_state = 6, .external_lex_state = 2},
  [13528] = {.lex_state = 6, .external_lex_state = 2},
  [13529] = {.lex_state = 28, .external_lex_state = 2},
  [13530] = {.lex_state = 28, .external_lex_state = 2},
  [13531] = {.lex_state = 28, .external_lex_state = 2},
  [13532] = {.lex_state = 28, .external_lex_state = 2},
  [13533] = {.lex_state = 28, .external_lex_state = 2},
  [13534] = {.lex_state = 6, .external_lex_state = 2},
  [13535] = {.lex_state = 28, .external_lex_state = 2},
  [13536] = {.lex_state = 28, .external_lex_state = 2},
  [13537] = {.lex_state = 8, .external_lex_state = 2},
  [13538] = {.lex_state = 28, .external_lex_state = 2},
  [13539] = {.lex_state = 28, .external_lex_state = 2},
  [13540] = {.lex_state = 205, .external_lex_state = 2},
  [13541] = {.lex_state = 28, .external_lex_state = 2},
  [13542] = {.lex_state = 8, .external_lex_state = 2},
  [13543] = {.lex_state = 28, .external_lex_state = 2},
  [13544] = {.lex_state = 28, .external_lex_state = 2},
  [13545] = {.lex_state = 28, .external_lex_state = 2},
  [13546] = {.lex_state = 28, .external_lex_state = 2},
  [13547] = {.lex_state = 28, .external_lex_state = 2},
  [13548] = {.lex_state = 28, .external_lex_state = 2},
  [13549] = {.lex_state = 205, .external_lex_state = 2},
  [13550] = {.lex_state = 28, .external_lex_state = 2},
  [13551] = {.lex_state = 8, .external_lex_state = 2},
  [13552] = {.lex_state = 28, .external_lex_state = 2},
  [13553] = {.lex_state = 8, .external_lex_state = 2},
  [13554] = {.lex_state = 28, .external_lex_state = 2},
  [13555] = {.lex_state = 28, .external_lex_state = 2},
  [13556] = {.lex_state = 28, .external_lex_state = 2},
  [13557] = {.lex_state = 28, .external_lex_state = 2},
  [13558] = {.lex_state = 8, .external_lex_state = 2},
  [13559] = {.lex_state = 28, .external_lex_state = 2},
  [13560] = {.lex_state = 28, .external_lex_state = 2},
  [13561] = {.lex_state = 28, .external_lex_state = 2},
  [13562] = {.lex_state = 205, .external_lex_state = 2},
  [13563] = {.lex_state = 28, .external_lex_state = 2},
  [13564] = {.lex_state = 214, .external_lex_state = 2},
  [13565] = {.lex_state = 8, .external_lex_state = 2},
  [13566] = {.lex_state = 8, .external_lex_state = 2},
  [13567] = {.lex_state = 28, .external_lex_state = 2},
  [13568] = {.lex_state = 209, .external_lex_state = 2},
  [13569] = {.lex_state = 28, .external_lex_state = 2},
  [13570] = {.lex_state = 28, .external_lex_state = 2},
  [13571] = {.lex_state = 28, .external_lex_state = 2},
  [13572] = {.lex_state = 214, .external_lex_state = 2},
  [13573] = {.lex_state = 28, .external_lex_state = 2},
  [13574] = {.lex_state = 28, .external_lex_state = 2},
  [13575] = {.lex_state = 214, .external_lex_state = 2},
  [13576] = {.lex_state = 28, .external_lex_state = 2},
  [13577] = {.lex_state = 214, .external_lex_state = 2},
  [13578] = {.lex_state = 224, .external_lex_state = 2},
  [13579] = {.lex_state = 229, .external_lex_state = 2},
  [13580] = {.lex_state = 214, .external_lex_state = 2},
  [13581] = {.lex_state = 28, .external_lex_state = 8},
  [13582] = {.lex_state = 224, .external_lex_state = 2},
  [13583] = {.lex_state = 28, .external_lex_state = 2},
  [13584] = {.lex_state = 229, .external_lex_state = 2},
  [13585] = {.lex_state = 28, .external_lex_state = 2},
  [13586] = {.lex_state = 28, .external_lex_state = 2},
  [13587] = {.lex_state = 28, .external_lex_state = 2},
  [13588] = {.lex_state = 28, .external_lex_state = 2},
  [13589] = {.lex_state = 28, .external_lex_state = 2},
  [13590] = {.lex_state = 214, .external_lex_state = 2},
  [13591] = {.lex_state = 28, .external_lex_state = 2},
  [13592] = {.lex_state = 28, .external_lex_state = 2},
  [13593] = {.lex_state = 8, .external_lex_state = 2},
  [13594] = {.lex_state = 205, .external_lex_state = 2},
  [13595] = {.lex_state = 28, .external_lex_state = 2},
  [13596] = {.lex_state = 28, .external_lex_state = 8},
  [13597] = {.lex_state = 28, .external_lex_state = 2},
  [13598] = {.lex_state = 205, .external_lex_state = 2},
  [13599] = {.lex_state = 8, .external_lex_state = 2},
  [13600] = {.lex_state = 28, .external_lex_state = 2},
  [13601] = {.lex_state = 28, .external_lex_state = 2},
  [13602] = {.lex_state = 214, .external_lex_state = 2},
  [13603] = {.lex_state = 28, .external_lex_state = 2},
  [13604] = {.lex_state = 176, .external_lex_state = 2},
  [13605] = {.lex_state = 214, .external_lex_state = 2},
  [13606] = {.lex_state = 28, .external_lex_state = 2},
  [13607] = {.lex_state = 176, .external_lex_state = 2},
  [13608] = {.lex_state = 28, .external_lex_state = 2},
  [13609] = {.lex_state = 214, .external_lex_state = 2},
  [13610] = {.lex_state = 214, .external_lex_state = 2},
  [13611] = {.lex_state = 28, .external_lex_state = 2},
  [13612] = {.lex_state = 28, .external_lex_state = 2},
  [13613] = {.lex_state = 28, .external_lex_state = 2},
  [13614] = {.lex_state = 209, .external_lex_state = 2},
  [13615] = {.lex_state = 28, .external_lex_state = 2},
  [13616] = {.lex_state = 28, .external_lex_state = 2},
  [13617] = {.lex_state = 28, .external_lex_state = 8},
  [13618] = {.lex_state = 28, .external_lex_state = 2},
  [13619] = {.lex_state = 28, .external_lex_state = 8},
  [13620] = {.lex_state = 214, .external_lex_state = 2},
  [13621] = {.lex_state = 6, .external_lex_state = 2},
  [13622] = {.lex_state = 28, .external_lex_state = 2},
  [13623] = {.lex_state = 8, .external_lex_state = 2},
  [13624] = {.lex_state = 28, .external_lex_state = 2},
  [13625] = {.lex_state = 28, .external_lex_state = 2},
  [13626] = {.lex_state = 28, .external_lex_state = 2},
  [13627] = {.lex_state = 28, .external_lex_state = 2},
  [13628] = {.lex_state = 28, .external_lex_state = 2},
  [13629] = {.lex_state = 28, .external_lex_state = 2},
  [13630] = {.lex_state = 209, .external_lex_state = 2},
  [13631] = {.lex_state = 28, .external_lex_state = 2},
  [13632] = {.lex_state = 28, .external_lex_state = 2},
  [13633] = {.lex_state = 28, .external_lex_state = 2},
  [13634] = {.lex_state = 28, .external_lex_state = 2},
  [13635] = {.lex_state = 28, .external_lex_state = 2},
  [13636] = {.lex_state = 28, .external_lex_state = 2},
  [13637] = {.lex_state = 28, .external_lex_state = 2},
  [13638] = {.lex_state = 28, .external_lex_state = 2},
  [13639] = {.lex_state = 28, .external_lex_state = 2},
  [13640] = {.lex_state = 28, .external_lex_state = 2},
  [13641] = {.lex_state = 28, .external_lex_state = 2},
  [13642] = {.lex_state = 28, .external_lex_state = 2},
  [13643] = {.lex_state = 28, .external_lex_state = 2},
  [13644] = {.lex_state = 28, .external_lex_state = 2},
  [13645] = {.lex_state = 8, .external_lex_state = 2},
  [13646] = {.lex_state = 28, .external_lex_state = 2},
  [13647] = {.lex_state = 28, .external_lex_state = 2},
  [13648] = {.lex_state = 28, .external_lex_state = 2},
  [13649] = {.lex_state = 28, .external_lex_state = 2},
  [13650] = {.lex_state = 28, .external_lex_state = 2},
  [13651] = {.lex_state = 28, .external_lex_state = 2},
  [13652] = {.lex_state = 28, .external_lex_state = 2},
  [13653] = {.lex_state = 28, .external_lex_state = 2},
  [13654] = {.lex_state = 8, .external_lex_state = 2},
  [13655] = {.lex_state = 28, .external_lex_state = 2},
  [13656] = {.lex_state = 28, .external_lex_state = 2},
  [13657] = {.lex_state = 28, .external_lex_state = 2},
  [13658] = {.lex_state = 28, .external_lex_state = 2},
  [13659] = {.lex_state = 28, .external_lex_state = 2},
  [13660] = {.lex_state = 28, .external_lex_state = 2},
  [13661] = {.lex_state = 205, .external_lex_state = 2},
  [13662] = {.lex_state = 28, .external_lex_state = 8},
  [13663] = {.lex_state = 28, .external_lex_state = 2},
  [13664] = {.lex_state = 28, .external_lex_state = 8},
  [13665] = {.lex_state = 28, .external_lex_state = 2},
  [13666] = {.lex_state = 28, .external_lex_state = 2},
  [13667] = {.lex_state = 28, .external_lex_state = 2},
  [13668] = {.lex_state = 8, .external_lex_state = 2},
  [13669] = {.lex_state = 28, .external_lex_state = 2},
  [13670] = {.lex_state = 205, .external_lex_state = 2},
  [13671] = {.lex_state = 28, .external_lex_state = 2},
  [13672] = {.lex_state = 28, .external_lex_state = 8},
  [13673] = {.lex_state = 28, .external_lex_state = 2},
  [13674] = {.lex_state = 214, .external_lex_state = 2},
  [13675] = {.lex_state = 28, .external_lex_state = 2},
  [13676] = {.lex_state = 214, .external_lex_state = 2},
  [13677] = {.lex_state = 28, .external_lex_state = 2},
  [13678] = {.lex_state = 28, .external_lex_state = 2},
  [13679] = {.lex_state = 214, .external_lex_state = 2},
  [13680] = {.lex_state = 8, .external_lex_state = 2},
  [13681] = {.lex_state = 28, .external_lex_state = 2},
  [13682] = {.lex_state = 28, .external_lex_state = 2},
  [13683] = {.lex_state = 6, .external_lex_state = 2},
  [13684] = {.lex_state = 28, .external_lex_state = 2},
  [13685] = {.lex_state = 28, .external_lex_state = 2},
  [13686] = {.lex_state = 28, .external_lex_state = 2},
  [13687] = {.lex_state = 28, .external_lex_state = 2},
  [13688] = {.lex_state = 28, .external_lex_state = 2},
  [13689] = {.lex_state = 28, .external_lex_state = 2},
  [13690] = {.lex_state = 8, .external_lex_state = 2},
  [13691] = {.lex_state = 28, .external_lex_state = 2},
  [13692] = {.lex_state = 205, .external_lex_state = 2},
  [13693] = {.lex_state = 28, .external_lex_state = 2},
  [13694] = {.lex_state = 214, .external_lex_state = 2},
  [13695] = {.lex_state = 8, .external_lex_state = 2},
  [13696] = {.lex_state = 6, .external_lex_state = 2},
  [13697] = {.lex_state = 28, .external_lex_state = 2},
  [13698] = {.lex_state = 28, .external_lex_state = 2},
  [13699] = {.lex_state = 28, .external_lex_state = 2},
  [13700] = {.lex_state = 214, .external_lex_state = 2},
  [13701] = {.lex_state = 214, .external_lex_state = 2},
  [13702] = {.lex_state = 28, .external_lex_state = 2},
  [13703] = {.lex_state = 214, .external_lex_state = 2},
  [13704] = {.lex_state = 28, .external_lex_state = 2},
  [13705] = {.lex_state = 8, .external_lex_state = 2},
  [13706] = {.lex_state = 28, .external_lex_state = 2},
  [13707] = {.lex_state = 28, .external_lex_state = 8},
  [13708] = {.lex_state = 28, .external_lex_state = 2},
  [13709] = {.lex_state = 28, .external_lex_state = 2},
  [13710] = {.lex_state = 28, .external_lex_state = 2},
  [13711] = {.lex_state = 214, .external_lex_state = 2},
  [13712] = {.lex_state = 28, .external_lex_state = 2},
  [13713] = {.lex_state = 28, .external_lex_state = 2},
  [13714] = {.lex_state = 8, .external_lex_state = 2},
  [13715] = {.lex_state = 8, .external_lex_state = 2},
  [13716] = {.lex_state = 28, .external_lex_state = 2},
  [13717] = {.lex_state = 214, .external_lex_state = 2},
  [13718] = {.lex_state = 214, .external_lex_state = 2},
  [13719] = {.lex_state = 28, .external_lex_state = 2},
  [13720] = {.lex_state = 426, .external_lex_state = 2},
  [13721] = {.lex_state = 6, .external_lex_state = 2},
  [13722] = {.lex_state = 28, .external_lex_state = 2},
  [13723] = {.lex_state = 28, .external_lex_state = 2},
  [13724] = {.lex_state = 176, .external_lex_state = 2},
  [13725] = {.lex_state = 214, .external_lex_state = 2},
  [13726] = {.lex_state = 214, .external_lex_state = 2},
  [13727] = {.lex_state = 176, .external_lex_state = 2},
  [13728] = {.lex_state = 28, .external_lex_state = 2},
  [13729] = {.lex_state = 214, .external_lex_state = 2},
  [13730] = {.lex_state = 176, .external_lex_state = 2},
  [13731] = {.lex_state = 28, .external_lex_state = 2},
  [13732] = {.lex_state = 28, .external_lex_state = 8},
  [13733] = {.lex_state = 28, .external_lex_state = 8},
  [13734] = {.lex_state = 205, .external_lex_state = 2},
  [13735] = {.lex_state = 176, .external_lex_state = 2},
  [13736] = {.lex_state = 6, .external_lex_state = 2},
  [13737] = {.lex_state = 176, .external_lex_state = 2},
  [13738] = {.lex_state = 229, .external_lex_state = 2},
  [13739] = {.lex_state = 28, .external_lex_state = 2},
  [13740] = {.lex_state = 214, .external_lex_state = 2},
  [13741] = {.lex_state = 28, .external_lex_state = 2},
  [13742] = {.lex_state = 28, .external_lex_state = 2},
  [13743] = {.lex_state = 28, .external_lex_state = 2},
  [13744] = {.lex_state = 28, .external_lex_state = 2},
  [13745] = {.lex_state = 28, .external_lex_state = 2},
  [13746] = {.lex_state = 28, .external_lex_state = 2},
  [13747] = {.lex_state = 28, .external_lex_state = 2},
  [13748] = {.lex_state = 28, .external_lex_state = 2},
  [13749] = {.lex_state = 176, .external_lex_state = 2},
  [13750] = {.lex_state = 28, .external_lex_state = 2},
  [13751] = {.lex_state = 28, .external_lex_state = 2},
  [13752] = {.lex_state = 214, .external_lex_state = 2},
  [13753] = {.lex_state = 28, .external_lex_state = 2},
  [13754] = {.lex_state = 176, .external_lex_state = 2},
  [13755] = {.lex_state = 214, .external_lex_state = 2},
  [13756] = {.lex_state = 28, .external_lex_state = 2},
  [13757] = {.lex_state = 8, .external_lex_state = 2},
  [13758] = {.lex_state = 28, .external_lex_state = 2},
  [13759] = {.lex_state = 6, .external_lex_state = 2},
  [13760] = {.lex_state = 28, .external_lex_state = 2},
  [13761] = {.lex_state = 8, .external_lex_state = 2},
  [13762] = {.lex_state = 28, .external_lex_state = 2},
  [13763] = {.lex_state = 8, .external_lex_state = 2},
  [13764] = {.lex_state = 176, .external_lex_state = 2},
  [13765] = {.lex_state = 28, .external_lex_state = 2},
  [13766] = {.lex_state = 28, .external_lex_state = 2},
  [13767] = {.lex_state = 28, .external_lex_state = 2},
  [13768] = {.lex_state = 28, .external_lex_state = 2},
  [13769] = {.lex_state = 28, .external_lex_state = 2},
  [13770] = {.lex_state = 28, .external_lex_state = 2},
  [13771] = {.lex_state = 8, .external_lex_state = 2},
  [13772] = {.lex_state = 28, .external_lex_state = 2},
  [13773] = {.lex_state = 28, .external_lex_state = 2},
  [13774] = {.lex_state = 229, .external_lex_state = 2},
  [13775] = {.lex_state = 28, .external_lex_state = 2},
  [13776] = {.lex_state = 28, .external_lex_state = 2},
  [13777] = {.lex_state = 28, .external_lex_state = 2},
  [13778] = {.lex_state = 6, .external_lex_state = 2},
  [13779] = {.lex_state = 28, .external_lex_state = 2},
  [13780] = {.lex_state = 176, .external_lex_state = 2},
  [13781] = {.lex_state = 28, .external_lex_state = 8},
  [13782] = {.lex_state = 28, .external_lex_state = 2},
  [13783] = {.lex_state = 8, .external_lex_state = 2},
  [13784] = {.lex_state = 28, .external_lex_state = 2},
  [13785] = {.lex_state = 6, .external_lex_state = 2},
  [13786] = {.lex_state = 8, .external_lex_state = 2},
  [13787] = {.lex_state = 28, .external_lex_state = 2},
  [13788] = {.lex_state = 28, .external_lex_state = 2},
  [13789] = {.lex_state = 28, .external_lex_state = 2},
  [13790] = {.lex_state = 28, .external_lex_state = 2},
  [13791] = {.lex_state = 28, .external_lex_state = 2},
  [13792] = {.lex_state = 28, .external_lex_state = 8},
  [13793] = {.lex_state = 28, .external_lex_state = 2},
  [13794] = {.lex_state = 8, .external_lex_state = 2},
  [13795] = {.lex_state = 214, .external_lex_state = 2},
  [13796] = {.lex_state = 214, .external_lex_state = 2},
  [13797] = {.lex_state = 176, .external_lex_state = 2},
  [13798] = {.lex_state = 205, .external_lex_state = 2},
  [13799] = {.lex_state = 28, .external_lex_state = 2},
  [13800] = {.lex_state = 6, .external_lex_state = 2},
  [13801] = {.lex_state = 28, .external_lex_state = 2},
  [13802] = {.lex_state = 28, .external_lex_state = 2},
  [13803] = {.lex_state = 28, .external_lex_state = 2},
  [13804] = {.lex_state = 28, .external_lex_state = 2},
  [13805] = {.lex_state = 28, .external_lex_state = 2},
  [13806] = {.lex_state = 28, .external_lex_state = 2},
  [13807] = {.lex_state = 6, .external_lex_state = 2},
  [13808] = {.lex_state = 28, .external_lex_state = 8},
  [13809] = {.lex_state = 28, .external_lex_state = 2},
  [13810] = {.lex_state = 28, .external_lex_state = 2},
  [13811] = {.lex_state = 28, .external_lex_state = 8},
  [13812] = {.lex_state = 28, .external_lex_state = 2},
  [13813] = {.lex_state = 205, .external_lex_state = 2},
  [13814] = {.lex_state = 28, .external_lex_state = 2},
  [13815] = {.lex_state = 28, .external_lex_state = 2},
  [13816] = {.lex_state = 28, .external_lex_state = 2},
  [13817] = {.lex_state = 28, .external_lex_state = 2},
  [13818] = {.lex_state = 28, .external_lex_state = 2},
  [13819] = {.lex_state = 28, .external_lex_state = 2},
  [13820] = {.lex_state = 28, .external_lex_state = 2},
  [13821] = {.lex_state = 28, .external_lex_state = 8},
  [13822] = {.lex_state = 6, .external_lex_state = 2},
  [13823] = {.lex_state = 28, .external_lex_state = 2},
  [13824] = {.lex_state = 28, .external_lex_state = 2},
  [13825] = {.lex_state = 205, .external_lex_state = 2},
  [13826] = {.lex_state = 237, .external_lex_state = 7},
  [13827] = {.lex_state = 28, .external_lex_state = 2},
  [13828] = {.lex_state = 28, .external_lex_state = 2},
  [13829] = {.lex_state = 8, .external_lex_state = 2},
  [13830] = {.lex_state = 214, .external_lex_state = 2},
  [13831] = {.lex_state = 28, .external_lex_state = 2},
  [13832] = {.lex_state = 6, .external_lex_state = 2},
  [13833] = {.lex_state = 28, .external_lex_state = 2},
  [13834] = {.lex_state = 28, .external_lex_state = 2},
  [13835] = {.lex_state = 28, .external_lex_state = 2},
  [13836] = {.lex_state = 6, .external_lex_state = 2},
  [13837] = {.lex_state = 28, .external_lex_state = 2},
  [13838] = {.lex_state = 28, .external_lex_state = 2},
  [13839] = {.lex_state = 28, .external_lex_state = 2},
  [13840] = {.lex_state = 17, .external_lex_state = 2},
  [13841] = {.lex_state = 17, .external_lex_state = 2},
  [13842] = {.lex_state = 28, .external_lex_state = 2},
  [13843] = {.lex_state = 6, .external_lex_state = 2},
  [13844] = {.lex_state = 28, .external_lex_state = 2},
  [13845] = {.lex_state = 28, .external_lex_state = 2},
  [13846] = {.lex_state = 6, .external_lex_state = 2},
  [13847] = {.lex_state = 6, .external_lex_state = 2},
  [13848] = {.lex_state = 28, .external_lex_state = 2},
  [13849] = {.lex_state = 28, .external_lex_state = 2},
  [13850] = {.lex_state = 28, .external_lex_state = 2},
  [13851] = {.lex_state = 6, .external_lex_state = 2},
  [13852] = {.lex_state = 28, .external_lex_state = 2},
  [13853] = {.lex_state = 6, .external_lex_state = 2},
  [13854] = {.lex_state = 6, .external_lex_state = 2},
  [13855] = {.lex_state = 28, .external_lex_state = 2},
  [13856] = {.lex_state = 28, .external_lex_state = 2},
  [13857] = {.lex_state = 6, .external_lex_state = 2},
  [13858] = {.lex_state = 17, .external_lex_state = 2},
  [13859] = {.lex_state = 28, .external_lex_state = 2},
  [13860] = {.lex_state = 28, .external_lex_state = 2},
  [13861] = {.lex_state = 17, .external_lex_state = 2},
  [13862] = {.lex_state = 28, .external_lex_state = 2},
  [13863] = {.lex_state = 28, .external_lex_state = 2},
  [13864] = {.lex_state = 28, .external_lex_state = 2},
  [13865] = {.lex_state = 28, .external_lex_state = 2},
  [13866] = {.lex_state = 28, .external_lex_state = 2},
  [13867] = {.lex_state = 28, .external_lex_state = 2},
  [13868] = {.lex_state = 17, .external_lex_state = 2},
  [13869] = {.lex_state = 28, .external_lex_state = 2},
  [13870] = {.lex_state = 6, .external_lex_state = 2},
  [13871] = {.lex_state = 28, .external_lex_state = 2},
  [13872] = {.lex_state = 28, .external_lex_state = 2},
  [13873] = {.lex_state = 6, .external_lex_state = 2},
  [13874] = {.lex_state = 28, .external_lex_state = 2},
  [13875] = {.lex_state = 28, .external_lex_state = 2},
  [13876] = {.lex_state = 28, .external_lex_state = 2},
  [13877] = {.lex_state = 28, .external_lex_state = 2},
  [13878] = {.lex_state = 28, .external_lex_state = 2},
  [13879] = {.lex_state = 6, .external_lex_state = 2},
  [13880] = {.lex_state = 28, .external_lex_state = 2},
  [13881] = {.lex_state = 28, .external_lex_state = 2},
  [13882] = {.lex_state = 28, .external_lex_state = 2},
  [13883] = {.lex_state = 6, .external_lex_state = 2},
  [13884] = {.lex_state = 28, .external_lex_state = 2},
  [13885] = {.lex_state = 28, .external_lex_state = 2},
  [13886] = {.lex_state = 28, .external_lex_state = 2},
  [13887] = {.lex_state = 6, .external_lex_state = 2},
  [13888] = {.lex_state = 28, .external_lex_state = 2},
  [13889] = {.lex_state = 28, .external_lex_state = 2},
  [13890] = {.lex_state = 28, .external_lex_state = 2},
  [13891] = {.lex_state = 6, .external_lex_state = 2},
  [13892] = {.lex_state = 28, .external_lex_state = 2},
  [13893] = {.lex_state = 28, .external_lex_state = 2},
  [13894] = {.lex_state = 426, .external_lex_state = 2},
  [13895] = {.lex_state = 28, .external_lex_state = 2},
  [13896] = {.lex_state = 28, .external_lex_state = 2},
  [13897] = {.lex_state = 28, .external_lex_state = 2},
  [13898] = {.lex_state = 28, .external_lex_state = 2},
  [13899] = {.lex_state = 28, .external_lex_state = 2},
  [13900] = {.lex_state = 6, .external_lex_state = 2},
  [13901] = {.lex_state = 6, .external_lex_state = 2},
  [13902] = {.lex_state = 28, .external_lex_state = 2},
  [13903] = {.lex_state = 28, .external_lex_state = 2},
  [13904] = {.lex_state = 6, .external_lex_state = 2},
  [13905] = {.lex_state = 28, .external_lex_state = 2},
  [13906] = {.lex_state = 28, .external_lex_state = 2},
  [13907] = {.lex_state = 6, .external_lex_state = 2},
  [13908] = {.lex_state = 6, .external_lex_state = 2},
  [13909] = {.lex_state = 6, .external_lex_state = 2},
  [13910] = {.lex_state = 28, .external_lex_state = 2},
  [13911] = {.lex_state = 6, .external_lex_state = 2},
  [13912] = {.lex_state = 28, .external_lex_state = 2},
  [13913] = {.lex_state = 28, .external_lex_state = 2},
  [13914] = {.lex_state = 28, .external_lex_state = 2},
  [13915] = {.lex_state = 28, .external_lex_state = 2},
  [13916] = {.lex_state = 28, .external_lex_state = 2},
  [13917] = {.lex_state = 28, .external_lex_state = 2},
  [13918] = {.lex_state = 28, .external_lex_state = 2},
  [13919] = {.lex_state = 6, .external_lex_state = 2},
  [13920] = {.lex_state = 6, .external_lex_state = 2},
  [13921] = {.lex_state = 28, .external_lex_state = 2},
  [13922] = {.lex_state = 28, .external_lex_state = 2},
  [13923] = {.lex_state = 28, .external_lex_state = 2},
  [13924] = {.lex_state = 28, .external_lex_state = 2},
  [13925] = {.lex_state = 6, .external_lex_state = 2},
  [13926] = {.lex_state = 6, .external_lex_state = 2},
  [13927] = {.lex_state = 6, .external_lex_state = 2},
  [13928] = {.lex_state = 28, .external_lex_state = 2},
  [13929] = {.lex_state = 6, .external_lex_state = 2},
  [13930] = {.lex_state = 6, .external_lex_state = 2},
  [13931] = {.lex_state = 28, .external_lex_state = 2},
  [13932] = {.lex_state = 28, .external_lex_state = 2},
  [13933] = {.lex_state = 28, .external_lex_state = 2},
  [13934] = {.lex_state = 28, .external_lex_state = 2},
  [13935] = {.lex_state = 28, .external_lex_state = 2},
  [13936] = {.lex_state = 28, .external_lex_state = 2},
  [13937] = {.lex_state = 28, .external_lex_state = 2},
  [13938] = {.lex_state = 28, .external_lex_state = 2},
  [13939] = {.lex_state = 28, .external_lex_state = 2},
  [13940] = {.lex_state = 6, .external_lex_state = 2},
  [13941] = {.lex_state = 28, .external_lex_state = 2},
  [13942] = {.lex_state = 6, .external_lex_state = 2},
  [13943] = {.lex_state = 6, .external_lex_state = 2},
  [13944] = {.lex_state = 28, .external_lex_state = 2},
  [13945] = {.lex_state = 28, .external_lex_state = 2},
  [13946] = {.lex_state = 28, .external_lex_state = 2},
  [13947] = {.lex_state = 28, .external_lex_state = 2},
  [13948] = {.lex_state = 28, .external_lex_state = 2},
  [13949] = {.lex_state = 28, .external_lex_state = 2},
  [13950] = {.lex_state = 28, .external_lex_state = 2},
  [13951] = {.lex_state = 28, .external_lex_state = 2},
  [13952] = {.lex_state = 28, .external_lex_state = 2},
  [13953] = {.lex_state = 28, .external_lex_state = 2},
  [13954] = {.lex_state = 6, .external_lex_state = 2},
  [13955] = {.lex_state = 6, .external_lex_state = 2},
  [13956] = {.lex_state = 28, .external_lex_state = 2},
  [13957] = {.lex_state = 6, .external_lex_state = 2},
  [13958] = {.lex_state = 28, .external_lex_state = 2},
  [13959] = {.lex_state = 28, .external_lex_state = 2},
  [13960] = {.lex_state = 28, .external_lex_state = 2},
  [13961] = {.lex_state = 28, .external_lex_state = 2},
  [13962] = {.lex_state = 28, .external_lex_state = 2},
  [13963] = {.lex_state = 28, .external_lex_state = 2},
  [13964] = {.lex_state = 28, .external_lex_state = 2},
  [13965] = {.lex_state = 28, .external_lex_state = 2},
  [13966] = {.lex_state = 28, .external_lex_state = 2},
  [13967] = {.lex_state = 28, .external_lex_state = 2},
  [13968] = {.lex_state = 28, .external_lex_state = 2},
  [13969] = {.lex_state = 6, .external_lex_state = 2},
  [13970] = {.lex_state = 28, .external_lex_state = 2},
  [13971] = {.lex_state = 28, .external_lex_state = 2},
  [13972] = {.lex_state = 28, .external_lex_state = 2},
  [13973] = {.lex_state = 17, .external_lex_state = 2},
  [13974] = {.lex_state = 6, .external_lex_state = 2},
  [13975] = {.lex_state = 6, .external_lex_state = 2},
  [13976] = {.lex_state = 28, .external_lex_state = 2},
  [13977] = {.lex_state = 28, .external_lex_state = 2},
  [13978] = {.lex_state = 28, .external_lex_state = 2},
  [13979] = {.lex_state = 28, .external_lex_state = 2},
  [13980] = {.lex_state = 28, .external_lex_state = 2},
  [13981] = {.lex_state = 28, .external_lex_state = 2},
  [13982] = {.lex_state = 6, .external_lex_state = 2},
  [13983] = {.lex_state = 6, .external_lex_state = 2},
  [13984] = {.lex_state = 28, .external_lex_state = 2},
  [13985] = {.lex_state = 28, .external_lex_state = 2},
  [13986] = {.lex_state = 28, .external_lex_state = 2},
  [13987] = {.lex_state = 6, .external_lex_state = 2},
  [13988] = {.lex_state = 28, .external_lex_state = 2},
  [13989] = {.lex_state = 28, .external_lex_state = 2},
  [13990] = {.lex_state = 28, .external_lex_state = 2},
  [13991] = {.lex_state = 28, .external_lex_state = 2},
  [13992] = {.lex_state = 28, .external_lex_state = 2},
  [13993] = {.lex_state = 6, .external_lex_state = 2},
  [13994] = {.lex_state = 17, .external_lex_state = 2},
  [13995] = {.lex_state = 6, .external_lex_state = 2},
  [13996] = {.lex_state = 28, .external_lex_state = 2},
  [13997] = {.lex_state = 28, .external_lex_state = 2},
  [13998] = {.lex_state = 6, .external_lex_state = 2},
  [13999] = {.lex_state = 28, .external_lex_state = 2},
  [14000] = {.lex_state = 28, .external_lex_state = 2},
  [14001] = {.lex_state = 6, .external_lex_state = 2},
  [14002] = {.lex_state = 6, .external_lex_state = 2},
  [14003] = {.lex_state = 28, .external_lex_state = 2},
  [14004] = {.lex_state = 28, .external_lex_state = 2},
  [14005] = {.lex_state = 28, .external_lex_state = 2},
  [14006] = {.lex_state = 28, .external_lex_state = 2},
  [14007] = {.lex_state = 28, .external_lex_state = 2},
  [14008] = {.lex_state = 28, .external_lex_state = 2},
  [14009] = {.lex_state = 28, .external_lex_state = 2},
  [14010] = {.lex_state = 6, .external_lex_state = 2},
  [14011] = {.lex_state = 6, .external_lex_state = 2},
  [14012] = {.lex_state = 6, .external_lex_state = 2},
  [14013] = {.lex_state = 28, .external_lex_state = 2},
  [14014] = {.lex_state = 28, .external_lex_state = 2},
  [14015] = {.lex_state = 28, .external_lex_state = 2},
  [14016] = {.lex_state = 28, .external_lex_state = 2},
  [14017] = {.lex_state = 28, .external_lex_state = 2},
  [14018] = {.lex_state = 28, .external_lex_state = 2},
  [14019] = {.lex_state = 6, .external_lex_state = 2},
  [14020] = {.lex_state = 6, .external_lex_state = 2},
  [14021] = {.lex_state = 28, .external_lex_state = 2},
  [14022] = {.lex_state = 28, .external_lex_state = 2},
  [14023] = {.lex_state = 28, .external_lex_state = 2},
  [14024] = {.lex_state = 6, .external_lex_state = 2},
  [14025] = {.lex_state = 6, .external_lex_state = 2},
  [14026] = {.lex_state = 6, .external_lex_state = 2},
  [14027] = {.lex_state = 6, .external_lex_state = 2},
  [14028] = {.lex_state = 28, .external_lex_state = 2},
  [14029] = {.lex_state = 28, .external_lex_state = 2},
  [14030] = {.lex_state = 6, .external_lex_state = 2},
  [14031] = {.lex_state = 6, .external_lex_state = 2},
  [14032] = {.lex_state = 6, .external_lex_state = 2},
  [14033] = {.lex_state = 28, .external_lex_state = 2},
  [14034] = {.lex_state = 6, .external_lex_state = 2},
  [14035] = {.lex_state = 28, .external_lex_state = 2},
  [14036] = {.lex_state = 28, .external_lex_state = 2},
  [14037] = {.lex_state = 28, .external_lex_state = 2},
  [14038] = {.lex_state = 28, .external_lex_state = 2},
  [14039] = {.lex_state = 28, .external_lex_state = 2},
  [14040] = {.lex_state = 6, .external_lex_state = 2},
  [14041] = {.lex_state = 28, .external_lex_state = 2},
  [14042] = {.lex_state = 28, .external_lex_state = 2},
  [14043] = {.lex_state = 28, .external_lex_state = 2},
  [14044] = {.lex_state = 28, .external_lex_state = 2},
  [14045] = {.lex_state = 6, .external_lex_state = 2},
  [14046] = {.lex_state = 6, .external_lex_state = 2},
  [14047] = {.lex_state = 28, .external_lex_state = 2},
  [14048] = {.lex_state = 28, .external_lex_state = 2},
  [14049] = {.lex_state = 6, .external_lex_state = 2},
  [14050] = {.lex_state = 28, .external_lex_state = 2},
  [14051] = {.lex_state = 17, .external_lex_state = 2},
  [14052] = {.lex_state = 28, .external_lex_state = 2},
  [14053] = {.lex_state = 28, .external_lex_state = 2},
  [14054] = {.lex_state = 28, .external_lex_state = 2},
  [14055] = {.lex_state = 6, .external_lex_state = 2},
  [14056] = {.lex_state = 28, .external_lex_state = 2},
  [14057] = {.lex_state = 28, .external_lex_state = 2},
  [14058] = {.lex_state = 28, .external_lex_state = 2},
  [14059] = {.lex_state = 28, .external_lex_state = 2},
  [14060] = {.lex_state = 28, .external_lex_state = 2},
  [14061] = {.lex_state = 28, .external_lex_state = 2},
  [14062] = {.lex_state = 28, .external_lex_state = 2},
  [14063] = {.lex_state = 28, .external_lex_state = 2},
  [14064] = {.lex_state = 6, .external_lex_state = 2},
  [14065] = {.lex_state = 6, .external_lex_state = 2},
  [14066] = {.lex_state = 28, .external_lex_state = 2},
  [14067] = {.lex_state = 28, .external_lex_state = 2},
  [14068] = {.lex_state = 28, .external_lex_state = 2},
  [14069] = {.lex_state = 17, .external_lex_state = 2},
  [14070] = {.lex_state = 28, .external_lex_state = 2},
  [14071] = {.lex_state = 28, .external_lex_state = 2},
  [14072] = {.lex_state = 28, .external_lex_state = 2},
  [14073] = {.lex_state = 28, .external_lex_state = 2},
  [14074] = {.lex_state = 28, .external_lex_state = 2},
  [14075] = {.lex_state = 28, .external_lex_state = 2},
  [14076] = {.lex_state = 6, .external_lex_state = 2},
  [14077] = {.lex_state = 28, .external_lex_state = 2},
  [14078] = {.lex_state = 426, .external_lex_state = 2},
  [14079] = {.lex_state = 28, .external_lex_state = 2},
  [14080] = {.lex_state = 28, .external_lex_state = 2},
  [14081] = {.lex_state = 28, .external_lex_state = 2},
  [14082] = {.lex_state = 28, .external_lex_state = 2},
  [14083] = {.lex_state = 28, .external_lex_state = 2},
  [14084] = {.lex_state = 28, .external_lex_state = 2},
  [14085] = {.lex_state = 28, .external_lex_state = 2},
  [14086] = {.lex_state = 28, .external_lex_state = 2},
  [14087] = {.lex_state = 6, .external_lex_state = 2},
  [14088] = {.lex_state = 28, .external_lex_state = 2},
  [14089] = {.lex_state = 28, .external_lex_state = 2},
  [14090] = {.lex_state = 28, .external_lex_state = 2},
  [14091] = {.lex_state = 28, .external_lex_state = 2},
  [14092] = {.lex_state = 28, .external_lex_state = 2},
  [14093] = {.lex_state = 6, .external_lex_state = 2},
  [14094] = {.lex_state = 6, .external_lex_state = 2},
  [14095] = {.lex_state = 28, .external_lex_state = 2},
  [14096] = {.lex_state = 6, .external_lex_state = 2},
  [14097] = {.lex_state = 28, .external_lex_state = 2},
  [14098] = {.lex_state = 28, .external_lex_state = 2},
  [14099] = {.lex_state = 28, .external_lex_state = 2},
  [14100] = {.lex_state = 28, .external_lex_state = 2},
  [14101] = {.lex_state = 28, .external_lex_state = 2},
  [14102] = {.lex_state = 6, .external_lex_state = 2},
  [14103] = {.lex_state = 6, .external_lex_state = 2},
  [14104] = {.lex_state = 28, .external_lex_state = 2},
  [14105] = {.lex_state = 28, .external_lex_state = 2},
  [14106] = {.lex_state = 28, .external_lex_state = 2},
  [14107] = {.lex_state = 28, .external_lex_state = 2},
  [14108] = {.lex_state = 6, .external_lex_state = 2},
  [14109] = {.lex_state = 28, .external_lex_state = 2},
  [14110] = {.lex_state = 6, .external_lex_state = 2},
  [14111] = {.lex_state = 28, .external_lex_state = 2},
  [14112] = {.lex_state = 28, .external_lex_state = 2},
  [14113] = {.lex_state = 28, .external_lex_state = 2},
  [14114] = {.lex_state = 28, .external_lex_state = 2},
  [14115] = {.lex_state = 28, .external_lex_state = 2},
  [14116] = {.lex_state = 6, .external_lex_state = 2},
  [14117] = {.lex_state = 28, .external_lex_state = 2},
  [14118] = {.lex_state = 28, .external_lex_state = 2},
  [14119] = {.lex_state = 28, .external_lex_state = 2},
  [14120] = {.lex_state = 28, .external_lex_state = 2},
  [14121] = {.lex_state = 28, .external_lex_state = 2},
  [14122] = {.lex_state = 28, .external_lex_state = 2},
  [14123] = {.lex_state = 28, .external_lex_state = 2},
  [14124] = {.lex_state = 6, .external_lex_state = 2},
  [14125] = {.lex_state = 28, .external_lex_state = 2},
  [14126] = {.lex_state = 28, .external_lex_state = 2},
  [14127] = {.lex_state = 28, .external_lex_state = 2},
  [14128] = {.lex_state = 28, .external_lex_state = 2},
  [14129] = {.lex_state = 28, .external_lex_state = 2},
  [14130] = {.lex_state = 28, .external_lex_state = 2},
  [14131] = {.lex_state = 6, .external_lex_state = 2},
  [14132] = {.lex_state = 28, .external_lex_state = 2},
  [14133] = {.lex_state = 28, .external_lex_state = 2},
  [14134] = {.lex_state = 28, .external_lex_state = 2},
  [14135] = {.lex_state = 28, .external_lex_state = 2},
  [14136] = {.lex_state = 28, .external_lex_state = 2},
  [14137] = {.lex_state = 6, .external_lex_state = 2},
  [14138] = {.lex_state = 28, .external_lex_state = 2},
  [14139] = {.lex_state = 28, .external_lex_state = 2},
  [14140] = {.lex_state = 28, .external_lex_state = 2},
  [14141] = {.lex_state = 6, .external_lex_state = 2},
  [14142] = {.lex_state = 17, .external_lex_state = 2},
  [14143] = {.lex_state = 28, .external_lex_state = 2},
  [14144] = {.lex_state = 28, .external_lex_state = 2},
  [14145] = {.lex_state = 17, .external_lex_state = 2},
  [14146] = {.lex_state = 28, .external_lex_state = 2},
  [14147] = {.lex_state = 6, .external_lex_state = 2},
  [14148] = {.lex_state = 28, .external_lex_state = 2},
  [14149] = {.lex_state = 6, .external_lex_state = 2},
  [14150] = {.lex_state = 6, .external_lex_state = 2},
  [14151] = {.lex_state = 28, .external_lex_state = 2},
  [14152] = {.lex_state = 8, .external_lex_state = 2},
  [14153] = {.lex_state = 28, .external_lex_state = 2},
  [14154] = {.lex_state = 28, .external_lex_state = 2},
  [14155] = {.lex_state = 28, .external_lex_state = 2},
  [14156] = {.lex_state = 28, .external_lex_state = 2},
  [14157] = {.lex_state = 426, .external_lex_state = 2},
  [14158] = {.lex_state = 28, .external_lex_state = 2},
  [14159] = {.lex_state = 28, .external_lex_state = 2},
  [14160] = {.lex_state = 28, .external_lex_state = 2},
  [14161] = {.lex_state = 28, .external_lex_state = 2},
  [14162] = {.lex_state = 17, .external_lex_state = 2},
  [14163] = {.lex_state = 28, .external_lex_state = 2},
  [14164] = {.lex_state = 28, .external_lex_state = 2},
  [14165] = {.lex_state = 6, .external_lex_state = 2},
  [14166] = {.lex_state = 28, .external_lex_state = 2},
  [14167] = {.lex_state = 28, .external_lex_state = 2},
  [14168] = {.lex_state = 28, .external_lex_state = 2},
  [14169] = {.lex_state = 28, .external_lex_state = 2},
  [14170] = {.lex_state = 426, .external_lex_state = 2},
  [14171] = {.lex_state = 28, .external_lex_state = 2},
  [14172] = {.lex_state = 28, .external_lex_state = 2},
  [14173] = {.lex_state = 28, .external_lex_state = 2},
  [14174] = {.lex_state = 6, .external_lex_state = 2},
  [14175] = {.lex_state = 6, .external_lex_state = 2},
  [14176] = {.lex_state = 28, .external_lex_state = 2},
  [14177] = {.lex_state = 28, .external_lex_state = 2},
  [14178] = {.lex_state = 28, .external_lex_state = 2},
  [14179] = {.lex_state = 420, .external_lex_state = 2},
  [14180] = {.lex_state = 420, .external_lex_state = 2},
  [14181] = {.lex_state = 28, .external_lex_state = 2},
  [14182] = {.lex_state = 28, .external_lex_state = 2},
  [14183] = {.lex_state = 28, .external_lex_state = 2},
  [14184] = {.lex_state = 28, .external_lex_state = 2},
  [14185] = {.lex_state = 420, .external_lex_state = 2},
  [14186] = {.lex_state = 6, .external_lex_state = 2},
  [14187] = {.lex_state = 28, .external_lex_state = 2},
  [14188] = {.lex_state = 28, .external_lex_state = 2},
  [14189] = {.lex_state = 28, .external_lex_state = 2},
  [14190] = {.lex_state = 6, .external_lex_state = 2},
  [14191] = {.lex_state = 28, .external_lex_state = 2},
  [14192] = {.lex_state = 28, .external_lex_state = 2},
  [14193] = {.lex_state = 28, .external_lex_state = 2},
  [14194] = {.lex_state = 37, .external_lex_state = 2},
  [14195] = {.lex_state = 28, .external_lex_state = 2},
  [14196] = {.lex_state = 28, .external_lex_state = 2},
  [14197] = {.lex_state = 28, .external_lex_state = 2},
  [14198] = {.lex_state = 28, .external_lex_state = 2},
  [14199] = {.lex_state = 6, .external_lex_state = 2},
  [14200] = {.lex_state = 28, .external_lex_state = 2},
  [14201] = {.lex_state = 28, .external_lex_state = 2},
  [14202] = {.lex_state = 28, .external_lex_state = 2},
  [14203] = {.lex_state = 28, .external_lex_state = 2},
  [14204] = {.lex_state = 28, .external_lex_state = 2},
  [14205] = {.lex_state = 28, .external_lex_state = 2},
  [14206] = {.lex_state = 28, .external_lex_state = 2},
  [14207] = {.lex_state = 28, .external_lex_state = 2},
  [14208] = {.lex_state = 28, .external_lex_state = 2},
  [14209] = {.lex_state = 6, .external_lex_state = 2},
  [14210] = {.lex_state = 28, .external_lex_state = 2},
  [14211] = {.lex_state = 28, .external_lex_state = 2},
  [14212] = {.lex_state = 28, .external_lex_state = 2},
  [14213] = {.lex_state = 420, .external_lex_state = 2},
  [14214] = {.lex_state = 28, .external_lex_state = 2},
  [14215] = {.lex_state = 420, .external_lex_state = 2},
  [14216] = {.lex_state = 420, .external_lex_state = 2},
  [14217] = {.lex_state = 28, .external_lex_state = 2},
  [14218] = {.lex_state = 28, .external_lex_state = 2},
  [14219] = {.lex_state = 28, .external_lex_state = 2},
  [14220] = {.lex_state = 420, .external_lex_state = 2},
  [14221] = {.lex_state = 12, .external_lex_state = 2},
  [14222] = {.lex_state = 6, .external_lex_state = 2},
  [14223] = {.lex_state = 28, .external_lex_state = 2},
  [14224] = {.lex_state = 420, .external_lex_state = 2},
  [14225] = {.lex_state = 12, .external_lex_state = 2},
  [14226] = {.lex_state = 28, .external_lex_state = 2},
  [14227] = {.lex_state = 28, .external_lex_state = 2},
  [14228] = {.lex_state = 28, .external_lex_state = 2},
  [14229] = {.lex_state = 6, .external_lex_state = 2},
  [14230] = {.lex_state = 28, .external_lex_state = 2},
  [14231] = {.lex_state = 28, .external_lex_state = 2},
  [14232] = {.lex_state = 6, .external_lex_state = 2},
  [14233] = {.lex_state = 28, .external_lex_state = 2},
  [14234] = {.lex_state = 28, .external_lex_state = 2},
  [14235] = {.lex_state = 6, .external_lex_state = 2},
  [14236] = {.lex_state = 6, .external_lex_state = 2},
  [14237] = {.lex_state = 6, .external_lex_state = 2},
  [14238] = {.lex_state = 28, .external_lex_state = 2},
  [14239] = {.lex_state = 6, .external_lex_state = 2},
  [14240] = {.lex_state = 420, .external_lex_state = 2},
  [14241] = {.lex_state = 6, .external_lex_state = 2},
  [14242] = {.lex_state = 6, .external_lex_state = 2},
  [14243] = {.lex_state = 28, .external_lex_state = 2},
  [14244] = {.lex_state = 420, .external_lex_state = 2},
  [14245] = {.lex_state = 28, .external_lex_state = 2},
  [14246] = {.lex_state = 6, .external_lex_state = 2},
  [14247] = {.lex_state = 420, .external_lex_state = 2},
  [14248] = {.lex_state = 28, .external_lex_state = 2},
  [14249] = {.lex_state = 420, .external_lex_state = 2},
  [14250] = {.lex_state = 28, .external_lex_state = 2},
  [14251] = {.lex_state = 28, .external_lex_state = 2},
  [14252] = {.lex_state = 28, .external_lex_state = 2},
  [14253] = {.lex_state = 28, .external_lex_state = 2},
  [14254] = {.lex_state = 28, .external_lex_state = 2},
  [14255] = {.lex_state = 420, .external_lex_state = 2},
  [14256] = {.lex_state = 28, .external_lex_state = 2},
  [14257] = {.lex_state = 18, .external_lex_state = 2},
  [14258] = {.lex_state = 28, .external_lex_state = 2},
  [14259] = {.lex_state = 28, .external_lex_state = 2},
  [14260] = {.lex_state = 28, .external_lex_state = 2},
  [14261] = {.lex_state = 420, .external_lex_state = 2},
  [14262] = {.lex_state = 12, .external_lex_state = 2},
  [14263] = {.lex_state = 28, .external_lex_state = 2},
  [14264] = {.lex_state = 28, .external_lex_state = 2},
  [14265] = {.lex_state = 18, .external_lex_state = 2},
  [14266] = {.lex_state = 28, .external_lex_state = 2},
  [14267] = {.lex_state = 28, .external_lex_state = 2},
  [14268] = {.lex_state = 6, .external_lex_state = 2},
  [14269] = {.lex_state = 28, .external_lex_state = 2},
  [14270] = {.lex_state = 28, .external_lex_state = 2},
  [14271] = {.lex_state = 28, .external_lex_state = 2},
  [14272] = {.lex_state = 28, .external_lex_state = 2},
  [14273] = {.lex_state = 420, .external_lex_state = 2},
  [14274] = {.lex_state = 28, .external_lex_state = 2},
  [14275] = {.lex_state = 28, .external_lex_state = 2},
  [14276] = {.lex_state = 214, .external_lex_state = 2},
  [14277] = {.lex_state = 6, .external_lex_state = 2},
  [14278] = {.lex_state = 28, .external_lex_state = 2},
  [14279] = {.lex_state = 28, .external_lex_state = 2},
  [14280] = {.lex_state = 28, .external_lex_state = 2},
  [14281] = {.lex_state = 28, .external_lex_state = 2},
  [14282] = {.lex_state = 6, .external_lex_state = 2},
  [14283] = {.lex_state = 6, .external_lex_state = 2},
  [14284] = {.lex_state = 28, .external_lex_state = 2},
  [14285] = {.lex_state = 28, .external_lex_state = 2},
  [14286] = {.lex_state = 214, .external_lex_state = 2},
  [14287] = {.lex_state = 12, .external_lex_state = 2},
  [14288] = {.lex_state = 28, .external_lex_state = 2},
  [14289] = {.lex_state = 12, .external_lex_state = 2},
  [14290] = {.lex_state = 28, .external_lex_state = 2},
  [14291] = {.lex_state = 420, .external_lex_state = 2},
  [14292] = {.lex_state = 28, .external_lex_state = 2},
  [14293] = {.lex_state = 28, .external_lex_state = 2},
  [14294] = {.lex_state = 6, .external_lex_state = 2},
  [14295] = {.lex_state = 28, .external_lex_state = 2},
  [14296] = {.lex_state = 6, .external_lex_state = 2},
  [14297] = {.lex_state = 28, .external_lex_state = 2},
  [14298] = {.lex_state = 28, .external_lex_state = 2},
  [14299] = {.lex_state = 28, .external_lex_state = 2},
  [14300] = {.lex_state = 420, .external_lex_state = 2},
  [14301] = {.lex_state = 426, .external_lex_state = 2},
  [14302] = {.lex_state = 420, .external_lex_state = 2},
  [14303] = {.lex_state = 6, .external_lex_state = 2},
  [14304] = {.lex_state = 6, .external_lex_state = 2},
  [14305] = {.lex_state = 214, .external_lex_state = 2},
  [14306] = {.lex_state = 28, .external_lex_state = 2},
  [14307] = {.lex_state = 28, .external_lex_state = 2},
  [14308] = {.lex_state = 28, .external_lex_state = 2},
  [14309] = {.lex_state = 28, .external_lex_state = 2},
  [14310] = {.lex_state = 6, .external_lex_state = 2},
  [14311] = {.lex_state = 6, .external_lex_state = 2},
  [14312] = {.lex_state = 28, .external_lex_state = 2},
  [14313] = {.lex_state = 6, .external_lex_state = 2},
  [14314] = {.lex_state = 28, .external_lex_state = 2},
  [14315] = {.lex_state = 28, .external_lex_state = 2},
  [14316] = {.lex_state = 28, .external_lex_state = 2},
  [14317] = {.lex_state = 28, .external_lex_state = 2},
  [14318] = {.lex_state = 28, .external_lex_state = 2},
  [14319] = {.lex_state = 28, .external_lex_state = 2},
  [14320] = {.lex_state = 28, .external_lex_state = 2},
  [14321] = {.lex_state = 28, .external_lex_state = 2},
  [14322] = {.lex_state = 28, .external_lex_state = 2},
  [14323] = {.lex_state = 28, .external_lex_state = 2},
  [14324] = {.lex_state = 28, .external_lex_state = 2},
  [14325] = {.lex_state = 28, .external_lex_state = 2},
  [14326] = {.lex_state = 28, .external_lex_state = 2},
  [14327] = {.lex_state = 28, .external_lex_state = 2},
  [14328] = {.lex_state = 6, .external_lex_state = 2},
  [14329] = {.lex_state = 28, .external_lex_state = 2},
  [14330] = {.lex_state = 28, .external_lex_state = 2},
  [14331] = {.lex_state = 6, .external_lex_state = 2},
  [14332] = {.lex_state = 6, .external_lex_state = 2},
  [14333] = {.lex_state = 6, .external_lex_state = 2},
  [14334] = {.lex_state = 28, .external_lex_state = 2},
  [14335] = {.lex_state = 28, .external_lex_state = 2},
  [14336] = {.lex_state = 8, .external_lex_state = 2},
  [14337] = {.lex_state = 420, .external_lex_state = 2},
  [14338] = {.lex_state = 18, .external_lex_state = 2},
  [14339] = {.lex_state = 28, .external_lex_state = 2},
  [14340] = {.lex_state = 28, .external_lex_state = 2},
  [14341] = {.lex_state = 28, .external_lex_state = 2},
  [14342] = {.lex_state = 28, .external_lex_state = 2},
  [14343] = {.lex_state = 28, .external_lex_state = 2},
  [14344] = {.lex_state = 28, .external_lex_state = 2},
  [14345] = {.lex_state = 28, .external_lex_state = 2},
  [14346] = {.lex_state = 28, .external_lex_state = 2},
  [14347] = {.lex_state = 420, .external_lex_state = 2},
  [14348] = {.lex_state = 6, .external_lex_state = 2},
  [14349] = {.lex_state = 37, .external_lex_state = 2},
  [14350] = {.lex_state = 28, .external_lex_state = 2},
  [14351] = {.lex_state = 28, .external_lex_state = 2},
  [14352] = {.lex_state = 6, .external_lex_state = 2},
  [14353] = {.lex_state = 28, .external_lex_state = 2},
  [14354] = {.lex_state = 28, .external_lex_state = 2},
  [14355] = {.lex_state = 28, .external_lex_state = 2},
  [14356] = {.lex_state = 28, .external_lex_state = 2},
  [14357] = {.lex_state = 420, .external_lex_state = 2},
  [14358] = {.lex_state = 28, .external_lex_state = 2},
  [14359] = {.lex_state = 28, .external_lex_state = 2},
  [14360] = {.lex_state = 214, .external_lex_state = 2},
  [14361] = {.lex_state = 28, .external_lex_state = 2},
  [14362] = {.lex_state = 28, .external_lex_state = 2},
  [14363] = {.lex_state = 28, .external_lex_state = 2},
  [14364] = {.lex_state = 28, .external_lex_state = 2},
  [14365] = {.lex_state = 28, .external_lex_state = 2},
  [14366] = {.lex_state = 28, .external_lex_state = 2},
  [14367] = {.lex_state = 28, .external_lex_state = 2},
  [14368] = {.lex_state = 28, .external_lex_state = 2},
  [14369] = {.lex_state = 28, .external_lex_state = 2},
  [14370] = {.lex_state = 28, .external_lex_state = 2},
  [14371] = {.lex_state = 6, .external_lex_state = 2},
  [14372] = {.lex_state = 12, .external_lex_state = 2},
  [14373] = {.lex_state = 28, .external_lex_state = 2},
  [14374] = {.lex_state = 426, .external_lex_state = 2},
  [14375] = {.lex_state = 28, .external_lex_state = 2},
  [14376] = {.lex_state = 6, .external_lex_state = 2},
  [14377] = {.lex_state = 6, .external_lex_state = 2},
  [14378] = {.lex_state = 12, .external_lex_state = 2},
  [14379] = {.lex_state = 28, .external_lex_state = 2},
  [14380] = {.lex_state = 6, .external_lex_state = 2},
  [14381] = {.lex_state = 28, .external_lex_state = 2},
  [14382] = {.lex_state = 28, .external_lex_state = 2},
  [14383] = {.lex_state = 28, .external_lex_state = 2},
  [14384] = {.lex_state = 28, .external_lex_state = 2},
  [14385] = {.lex_state = 28, .external_lex_state = 2},
  [14386] = {.lex_state = 6, .external_lex_state = 2},
  [14387] = {.lex_state = 37, .external_lex_state = 2},
  [14388] = {.lex_state = 6, .external_lex_state = 2},
  [14389] = {.lex_state = 28, .external_lex_state = 2},
  [14390] = {.lex_state = 6, .external_lex_state = 2},
  [14391] = {.lex_state = 28, .external_lex_state = 2},
  [14392] = {.lex_state = 28, .external_lex_state = 2},
  [14393] = {.lex_state = 28, .external_lex_state = 2},
  [14394] = {.lex_state = 28, .external_lex_state = 2},
  [14395] = {.lex_state = 28, .external_lex_state = 2},
  [14396] = {.lex_state = 6, .external_lex_state = 2},
  [14397] = {.lex_state = 6, .external_lex_state = 2},
  [14398] = {.lex_state = 6, .external_lex_state = 2},
  [14399] = {.lex_state = 28, .external_lex_state = 2},
  [14400] = {.lex_state = 28, .external_lex_state = 2},
  [14401] = {.lex_state = 28, .external_lex_state = 2},
  [14402] = {.lex_state = 6, .external_lex_state = 2},
  [14403] = {.lex_state = 6, .external_lex_state = 2},
  [14404] = {.lex_state = 6, .external_lex_state = 2},
  [14405] = {.lex_state = 28, .external_lex_state = 2},
  [14406] = {.lex_state = 420, .external_lex_state = 2},
  [14407] = {.lex_state = 28, .external_lex_state = 2},
  [14408] = {.lex_state = 28, .external_lex_state = 2},
  [14409] = {.lex_state = 18, .external_lex_state = 2},
  [14410] = {.lex_state = 420, .external_lex_state = 2},
  [14411] = {.lex_state = 12, .external_lex_state = 2},
  [14412] = {.lex_state = 420, .external_lex_state = 2},
  [14413] = {.lex_state = 420, .external_lex_state = 2},
  [14414] = {.lex_state = 420, .external_lex_state = 2},
  [14415] = {.lex_state = 420, .external_lex_state = 2},
  [14416] = {.lex_state = 420, .external_lex_state = 2},
  [14417] = {.lex_state = 11, .external_lex_state = 2},
  [14418] = {.lex_state = 28, .external_lex_state = 2},
  [14419] = {.lex_state = 420, .external_lex_state = 2},
  [14420] = {.lex_state = 11, .external_lex_state = 2},
  [14421] = {.lex_state = 18, .external_lex_state = 2},
  [14422] = {.lex_state = 28, .external_lex_state = 2},
  [14423] = {.lex_state = 8, .external_lex_state = 2},
  [14424] = {.lex_state = 420, .external_lex_state = 2},
  [14425] = {.lex_state = 12, .external_lex_state = 2},
  [14426] = {.lex_state = 11, .external_lex_state = 2},
  [14427] = {.lex_state = 420, .external_lex_state = 2},
  [14428] = {.lex_state = 6, .external_lex_state = 2},
  [14429] = {.lex_state = 28, .external_lex_state = 2},
  [14430] = {.lex_state = 28, .external_lex_state = 2},
  [14431] = {.lex_state = 28, .external_lex_state = 2},
  [14432] = {.lex_state = 28, .external_lex_state = 2},
  [14433] = {.lex_state = 28, .external_lex_state = 2},
  [14434] = {.lex_state = 28, .external_lex_state = 2},
  [14435] = {.lex_state = 7, .external_lex_state = 2},
  [14436] = {.lex_state = 18, .external_lex_state = 2},
  [14437] = {.lex_state = 28, .external_lex_state = 2},
  [14438] = {.lex_state = 249, .external_lex_state = 8},
  [14439] = {.lex_state = 8, .external_lex_state = 2},
  [14440] = {.lex_state = 6, .external_lex_state = 2},
  [14441] = {.lex_state = 18, .external_lex_state = 2},
  [14442] = {.lex_state = 6, .external_lex_state = 2},
  [14443] = {.lex_state = 28, .external_lex_state = 2},
  [14444] = {.lex_state = 6, .external_lex_state = 2},
  [14445] = {.lex_state = 11, .external_lex_state = 2},
  [14446] = {.lex_state = 420, .external_lex_state = 2},
  [14447] = {.lex_state = 420, .external_lex_state = 2},
  [14448] = {.lex_state = 28, .external_lex_state = 2},
  [14449] = {.lex_state = 28, .external_lex_state = 2},
  [14450] = {.lex_state = 28, .external_lex_state = 2},
  [14451] = {.lex_state = 28, .external_lex_state = 2},
  [14452] = {.lex_state = 18, .external_lex_state = 2},
  [14453] = {.lex_state = 28, .external_lex_state = 2},
  [14454] = {.lex_state = 18, .external_lex_state = 2},
  [14455] = {.lex_state = 18, .external_lex_state = 2},
  [14456] = {.lex_state = 18, .external_lex_state = 2},
  [14457] = {.lex_state = 6, .external_lex_state = 2},
  [14458] = {.lex_state = 28, .external_lex_state = 2},
  [14459] = {.lex_state = 18, .external_lex_state = 2},
  [14460] = {.lex_state = 18, .external_lex_state = 2},
  [14461] = {.lex_state = 420, .external_lex_state = 2},
  [14462] = {.lex_state = 18, .external_lex_state = 2},
  [14463] = {.lex_state = 28, .external_lex_state = 2},
  [14464] = {.lex_state = 6, .external_lex_state = 2},
  [14465] = {.lex_state = 28, .external_lex_state = 2},
  [14466] = {.lex_state = 6, .external_lex_state = 2},
  [14467] = {.lex_state = 28, .external_lex_state = 2},
  [14468] = {.lex_state = 28, .external_lex_state = 2},
  [14469] = {.lex_state = 18, .external_lex_state = 2},
  [14470] = {.lex_state = 205, .external_lex_state = 2},
  [14471] = {.lex_state = 28, .external_lex_state = 2},
  [14472] = {.lex_state = 18, .external_lex_state = 2},
  [14473] = {.lex_state = 420, .external_lex_state = 2},
  [14474] = {.lex_state = 6, .external_lex_state = 2},
  [14475] = {.lex_state = 28, .external_lex_state = 2},
  [14476] = {.lex_state = 420, .external_lex_state = 2},
  [14477] = {.lex_state = 420, .external_lex_state = 2},
  [14478] = {.lex_state = 18, .external_lex_state = 2},
  [14479] = {.lex_state = 18, .external_lex_state = 2},
  [14480] = {.lex_state = 12, .external_lex_state = 2},
  [14481] = {.lex_state = 420, .external_lex_state = 2},
  [14482] = {.lex_state = 28, .external_lex_state = 2},
  [14483] = {.lex_state = 420, .external_lex_state = 2},
  [14484] = {.lex_state = 18, .external_lex_state = 2},
  [14485] = {.lex_state = 249, .external_lex_state = 8},
  [14486] = {.lex_state = 420, .external_lex_state = 2},
  [14487] = {.lex_state = 28, .external_lex_state = 2},
  [14488] = {.lex_state = 28, .external_lex_state = 2},
  [14489] = {.lex_state = 6, .external_lex_state = 2},
  [14490] = {.lex_state = 28, .external_lex_state = 2},
  [14491] = {.lex_state = 11, .external_lex_state = 2},
  [14492] = {.lex_state = 28, .external_lex_state = 2},
  [14493] = {.lex_state = 28, .external_lex_state = 2},
  [14494] = {.lex_state = 18, .external_lex_state = 2},
  [14495] = {.lex_state = 8, .external_lex_state = 2},
  [14496] = {.lex_state = 28, .external_lex_state = 2},
  [14497] = {.lex_state = 28, .external_lex_state = 2},
  [14498] = {.lex_state = 420, .external_lex_state = 2},
  [14499] = {.lex_state = 28, .external_lex_state = 2},
  [14500] = {.lex_state = 249, .external_lex_state = 8},
  [14501] = {.lex_state = 420, .external_lex_state = 2},
  [14502] = {.lex_state = 420, .external_lex_state = 2},
  [14503] = {.lex_state = 28, .external_lex_state = 2},
  [14504] = {.lex_state = 420, .external_lex_state = 2},
  [14505] = {.lex_state = 28, .external_lex_state = 2},
  [14506] = {.lex_state = 420, .external_lex_state = 2},
  [14507] = {.lex_state = 6, .external_lex_state = 2},
  [14508] = {.lex_state = 18, .external_lex_state = 2},
  [14509] = {.lex_state = 420, .external_lex_state = 2},
  [14510] = {.lex_state = 28, .external_lex_state = 2},
  [14511] = {.lex_state = 420, .external_lex_state = 2},
  [14512] = {.lex_state = 17, .external_lex_state = 2},
  [14513] = {.lex_state = 28, .external_lex_state = 2},
  [14514] = {.lex_state = 11, .external_lex_state = 2},
  [14515] = {.lex_state = 6, .external_lex_state = 2},
  [14516] = {.lex_state = 18, .external_lex_state = 2},
  [14517] = {.lex_state = 18, .external_lex_state = 2},
  [14518] = {.lex_state = 18, .external_lex_state = 2},
  [14519] = {.lex_state = 18, .external_lex_state = 2},
  [14520] = {.lex_state = 28, .external_lex_state = 2},
  [14521] = {.lex_state = 28, .external_lex_state = 2},
  [14522] = {.lex_state = 6, .external_lex_state = 2},
  [14523] = {.lex_state = 420, .external_lex_state = 2},
  [14524] = {.lex_state = 420, .external_lex_state = 2},
  [14525] = {.lex_state = 420, .external_lex_state = 2},
  [14526] = {.lex_state = 420, .external_lex_state = 2},
  [14527] = {.lex_state = 6, .external_lex_state = 2},
  [14528] = {.lex_state = 28, .external_lex_state = 2},
  [14529] = {.lex_state = 28, .external_lex_state = 2},
  [14530] = {.lex_state = 18, .external_lex_state = 2},
  [14531] = {.lex_state = 18, .external_lex_state = 2},
  [14532] = {.lex_state = 18, .external_lex_state = 2},
  [14533] = {.lex_state = 28, .external_lex_state = 2},
  [14534] = {.lex_state = 6, .external_lex_state = 2},
  [14535] = {.lex_state = 18, .external_lex_state = 2},
  [14536] = {.lex_state = 18, .external_lex_state = 2},
  [14537] = {.lex_state = 28, .external_lex_state = 2},
  [14538] = {.lex_state = 28, .external_lex_state = 2},
  [14539] = {.lex_state = 28, .external_lex_state = 2},
  [14540] = {.lex_state = 6, .external_lex_state = 2},
  [14541] = {.lex_state = 18, .external_lex_state = 2},
  [14542] = {.lex_state = 420, .external_lex_state = 2},
  [14543] = {.lex_state = 18, .external_lex_state = 2},
  [14544] = {.lex_state = 28, .external_lex_state = 2},
  [14545] = {.lex_state = 18, .external_lex_state = 2},
  [14546] = {.lex_state = 28, .external_lex_state = 2},
  [14547] = {.lex_state = 28, .external_lex_state = 2},
  [14548] = {.lex_state = 28, .external_lex_state = 2},
  [14549] = {.lex_state = 420, .external_lex_state = 2},
  [14550] = {.lex_state = 420, .external_lex_state = 2},
  [14551] = {.lex_state = 420, .external_lex_state = 2},
  [14552] = {.lex_state = 28, .external_lex_state = 2},
  [14553] = {.lex_state = 28, .external_lex_state = 2},
  [14554] = {.lex_state = 11, .external_lex_state = 2},
  [14555] = {.lex_state = 28, .external_lex_state = 2},
  [14556] = {.lex_state = 28, .external_lex_state = 2},
  [14557] = {.lex_state = 18, .external_lex_state = 2},
  [14558] = {.lex_state = 18, .external_lex_state = 2},
  [14559] = {.lex_state = 28, .external_lex_state = 2},
  [14560] = {.lex_state = 28, .external_lex_state = 2},
  [14561] = {.lex_state = 28, .external_lex_state = 2},
  [14562] = {.lex_state = 6, .external_lex_state = 2},
  [14563] = {.lex_state = 18, .external_lex_state = 2},
  [14564] = {.lex_state = 420, .external_lex_state = 2},
  [14565] = {.lex_state = 18, .external_lex_state = 2},
  [14566] = {.lex_state = 420, .external_lex_state = 2},
  [14567] = {.lex_state = 11, .external_lex_state = 2},
  [14568] = {.lex_state = 6, .external_lex_state = 2},
  [14569] = {.lex_state = 6, .external_lex_state = 2},
  [14570] = {.lex_state = 420, .external_lex_state = 2},
  [14571] = {.lex_state = 18, .external_lex_state = 2},
  [14572] = {.lex_state = 420, .external_lex_state = 2},
  [14573] = {.lex_state = 6, .external_lex_state = 2},
  [14574] = {.lex_state = 6, .external_lex_state = 2},
  [14575] = {.lex_state = 28, .external_lex_state = 2},
  [14576] = {.lex_state = 28, .external_lex_state = 2},
  [14577] = {.lex_state = 28, .external_lex_state = 2},
  [14578] = {.lex_state = 17, .external_lex_state = 2},
  [14579] = {.lex_state = 6, .external_lex_state = 2},
  [14580] = {.lex_state = 420, .external_lex_state = 2},
  [14581] = {.lex_state = 18, .external_lex_state = 2},
  [14582] = {.lex_state = 18, .external_lex_state = 2},
  [14583] = {.lex_state = 18, .external_lex_state = 2},
  [14584] = {.lex_state = 6, .external_lex_state = 2},
  [14585] = {.lex_state = 18, .external_lex_state = 2},
  [14586] = {.lex_state = 11, .external_lex_state = 2},
  [14587] = {.lex_state = 28, .external_lex_state = 2},
  [14588] = {.lex_state = 18, .external_lex_state = 2},
  [14589] = {.lex_state = 18, .external_lex_state = 2},
  [14590] = {.lex_state = 28, .external_lex_state = 2},
  [14591] = {.lex_state = 6, .external_lex_state = 2},
  [14592] = {.lex_state = 18, .external_lex_state = 2},
  [14593] = {.lex_state = 18, .external_lex_state = 2},
  [14594] = {.lex_state = 18, .external_lex_state = 2},
  [14595] = {.lex_state = 420, .external_lex_state = 2},
  [14596] = {.lex_state = 28, .external_lex_state = 2},
  [14597] = {.lex_state = 420, .external_lex_state = 2},
  [14598] = {.lex_state = 6, .external_lex_state = 2},
  [14599] = {.lex_state = 28, .external_lex_state = 2},
  [14600] = {.lex_state = 6, .external_lex_state = 2},
  [14601] = {.lex_state = 18, .external_lex_state = 2},
  [14602] = {.lex_state = 420, .external_lex_state = 2},
  [14603] = {.lex_state = 28, .external_lex_state = 2},
  [14604] = {.lex_state = 420, .external_lex_state = 2},
  [14605] = {.lex_state = 11, .external_lex_state = 2},
  [14606] = {.lex_state = 420, .external_lex_state = 2},
  [14607] = {.lex_state = 11, .external_lex_state = 2},
  [14608] = {.lex_state = 28, .external_lex_state = 2},
  [14609] = {.lex_state = 420, .external_lex_state = 2},
  [14610] = {.lex_state = 12, .external_lex_state = 2},
  [14611] = {.lex_state = 420, .external_lex_state = 2},
  [14612] = {.lex_state = 18, .external_lex_state = 2},
  [14613] = {.lex_state = 28, .external_lex_state = 2},
  [14614] = {.lex_state = 420, .external_lex_state = 2},
  [14615] = {.lex_state = 28, .external_lex_state = 2},
  [14616] = {.lex_state = 28, .external_lex_state = 2},
  [14617] = {.lex_state = 420, .external_lex_state = 2},
  [14618] = {.lex_state = 6, .external_lex_state = 2},
  [14619] = {.lex_state = 28, .external_lex_state = 2},
  [14620] = {.lex_state = 28, .external_lex_state = 2},
  [14621] = {.lex_state = 28, .external_lex_state = 2},
  [14622] = {.lex_state = 28, .external_lex_state = 2},
  [14623] = {.lex_state = 28, .external_lex_state = 2},
  [14624] = {.lex_state = 8, .external_lex_state = 2},
  [14625] = {.lex_state = 420, .external_lex_state = 2},
  [14626] = {.lex_state = 28, .external_lex_state = 2},
  [14627] = {.lex_state = 420, .external_lex_state = 2},
  [14628] = {.lex_state = 420, .external_lex_state = 2},
  [14629] = {.lex_state = 18, .external_lex_state = 2},
  [14630] = {.lex_state = 28, .external_lex_state = 2},
  [14631] = {.lex_state = 18, .external_lex_state = 2},
  [14632] = {.lex_state = 28, .external_lex_state = 2},
  [14633] = {.lex_state = 17, .external_lex_state = 2},
  [14634] = {.lex_state = 11, .external_lex_state = 2},
  [14635] = {.lex_state = 28, .external_lex_state = 2},
  [14636] = {.lex_state = 11, .external_lex_state = 2},
  [14637] = {.lex_state = 420, .external_lex_state = 2},
  [14638] = {.lex_state = 420, .external_lex_state = 2},
  [14639] = {.lex_state = 18, .external_lex_state = 2},
  [14640] = {.lex_state = 420, .external_lex_state = 2},
  [14641] = {.lex_state = 28, .external_lex_state = 2},
  [14642] = {.lex_state = 28, .external_lex_state = 2},
  [14643] = {.lex_state = 17, .external_lex_state = 2},
  [14644] = {.lex_state = 17, .external_lex_state = 2},
  [14645] = {.lex_state = 18, .external_lex_state = 2},
  [14646] = {.lex_state = 8, .external_lex_state = 2},
  [14647] = {.lex_state = 28, .external_lex_state = 2},
  [14648] = {.lex_state = 28, .external_lex_state = 2},
  [14649] = {.lex_state = 420, .external_lex_state = 2},
  [14650] = {.lex_state = 28, .external_lex_state = 2},
  [14651] = {.lex_state = 18, .external_lex_state = 2},
  [14652] = {.lex_state = 28, .external_lex_state = 2},
  [14653] = {.lex_state = 6, .external_lex_state = 2},
  [14654] = {.lex_state = 8, .external_lex_state = 2},
  [14655] = {.lex_state = 28, .external_lex_state = 2},
  [14656] = {.lex_state = 205, .external_lex_state = 2},
  [14657] = {.lex_state = 18, .external_lex_state = 2},
  [14658] = {.lex_state = 18, .external_lex_state = 2},
  [14659] = {.lex_state = 28, .external_lex_state = 2},
  [14660] = {.lex_state = 28, .external_lex_state = 2},
  [14661] = {.lex_state = 28, .external_lex_state = 2},
  [14662] = {.lex_state = 28, .external_lex_state = 2},
  [14663] = {.lex_state = 28, .external_lex_state = 2},
  [14664] = {.lex_state = 17, .external_lex_state = 2},
  [14665] = {.lex_state = 6, .external_lex_state = 2},
  [14666] = {.lex_state = 28, .external_lex_state = 2},
  [14667] = {.lex_state = 28, .external_lex_state = 2},
  [14668] = {.lex_state = 420, .external_lex_state = 2},
  [14669] = {.lex_state = 28, .external_lex_state = 2},
  [14670] = {.lex_state = 28, .external_lex_state = 2},
  [14671] = {.lex_state = 28, .external_lex_state = 2},
  [14672] = {.lex_state = 28, .external_lex_state = 2},
  [14673] = {.lex_state = 6, .external_lex_state = 2},
  [14674] = {.lex_state = 28, .external_lex_state = 2},
  [14675] = {.lex_state = 420, .external_lex_state = 2},
  [14676] = {.lex_state = 28, .external_lex_state = 2},
  [14677] = {.lex_state = 11, .external_lex_state = 2},
  [14678] = {.lex_state = 18, .external_lex_state = 2},
  [14679] = {.lex_state = 18, .external_lex_state = 2},
  [14680] = {.lex_state = 420, .external_lex_state = 2},
  [14681] = {.lex_state = 17, .external_lex_state = 2},
  [14682] = {.lex_state = 6, .external_lex_state = 2},
  [14683] = {.lex_state = 420, .external_lex_state = 2},
  [14684] = {.lex_state = 420, .external_lex_state = 2},
  [14685] = {.lex_state = 28, .external_lex_state = 2},
  [14686] = {.lex_state = 28, .external_lex_state = 2},
  [14687] = {.lex_state = 420, .external_lex_state = 2},
  [14688] = {.lex_state = 420, .external_lex_state = 2},
  [14689] = {.lex_state = 28, .external_lex_state = 2},
  [14690] = {.lex_state = 18, .external_lex_state = 2},
  [14691] = {.lex_state = 6, .external_lex_state = 2},
  [14692] = {.lex_state = 28, .external_lex_state = 2},
  [14693] = {.lex_state = 18, .external_lex_state = 2},
  [14694] = {.lex_state = 420, .external_lex_state = 2},
  [14695] = {.lex_state = 18, .external_lex_state = 2},
  [14696] = {.lex_state = 420, .external_lex_state = 2},
  [14697] = {.lex_state = 28, .external_lex_state = 2},
  [14698] = {.lex_state = 8, .external_lex_state = 2},
  [14699] = {.lex_state = 28, .external_lex_state = 2},
  [14700] = {.lex_state = 6, .external_lex_state = 2},
  [14701] = {.lex_state = 420, .external_lex_state = 2},
  [14702] = {.lex_state = 420, .external_lex_state = 2},
  [14703] = {.lex_state = 28, .external_lex_state = 2},
  [14704] = {.lex_state = 6, .external_lex_state = 2},
  [14705] = {.lex_state = 11, .external_lex_state = 2},
  [14706] = {.lex_state = 28, .external_lex_state = 2},
  [14707] = {.lex_state = 28, .external_lex_state = 2},
  [14708] = {.lex_state = 420, .external_lex_state = 2},
  [14709] = {.lex_state = 11, .external_lex_state = 2},
  [14710] = {.lex_state = 12, .external_lex_state = 2},
  [14711] = {.lex_state = 28, .external_lex_state = 2},
  [14712] = {.lex_state = 28, .external_lex_state = 2},
  [14713] = {.lex_state = 420, .external_lex_state = 2},
  [14714] = {.lex_state = 28, .external_lex_state = 2},
  [14715] = {.lex_state = 6, .external_lex_state = 2},
  [14716] = {.lex_state = 28, .external_lex_state = 2},
  [14717] = {.lex_state = 18, .external_lex_state = 2},
  [14718] = {.lex_state = 28, .external_lex_state = 2},
  [14719] = {.lex_state = 420, .external_lex_state = 2},
  [14720] = {.lex_state = 28, .external_lex_state = 2},
  [14721] = {.lex_state = 420, .external_lex_state = 2},
  [14722] = {.lex_state = 420, .external_lex_state = 2},
  [14723] = {.lex_state = 420, .external_lex_state = 2},
  [14724] = {.lex_state = 420, .external_lex_state = 2},
  [14725] = {.lex_state = 420, .external_lex_state = 2},
  [14726] = {.lex_state = 28, .external_lex_state = 2},
  [14727] = {.lex_state = 18, .external_lex_state = 2},
  [14728] = {.lex_state = 28, .external_lex_state = 2},
  [14729] = {.lex_state = 8, .external_lex_state = 2},
  [14730] = {.lex_state = 28, .external_lex_state = 2},
  [14731] = {.lex_state = 420, .external_lex_state = 2},
  [14732] = {.lex_state = 420, .external_lex_state = 2},
  [14733] = {.lex_state = 18, .external_lex_state = 2},
  [14734] = {.lex_state = 18, .external_lex_state = 2},
  [14735] = {.lex_state = 12, .external_lex_state = 2},
  [14736] = {.lex_state = 6, .external_lex_state = 2},
  [14737] = {.lex_state = 28, .external_lex_state = 2},
  [14738] = {.lex_state = 6, .external_lex_state = 2},
  [14739] = {.lex_state = 28, .external_lex_state = 2},
  [14740] = {.lex_state = 28, .external_lex_state = 2},
  [14741] = {.lex_state = 420, .external_lex_state = 2},
  [14742] = {.lex_state = 28, .external_lex_state = 2},
  [14743] = {.lex_state = 28, .external_lex_state = 2},
  [14744] = {.lex_state = 28, .external_lex_state = 2},
  [14745] = {.lex_state = 18, .external_lex_state = 2},
  [14746] = {.lex_state = 18, .external_lex_state = 2},
  [14747] = {.lex_state = 28, .external_lex_state = 2},
  [14748] = {.lex_state = 6, .external_lex_state = 2},
  [14749] = {.lex_state = 28, .external_lex_state = 2},
  [14750] = {.lex_state = 28, .external_lex_state = 2},
  [14751] = {.lex_state = 11, .external_lex_state = 2},
  [14752] = {.lex_state = 28, .external_lex_state = 2},
  [14753] = {.lex_state = 6, .external_lex_state = 2},
  [14754] = {.lex_state = 6, .external_lex_state = 2},
  [14755] = {.lex_state = 18, .external_lex_state = 2},
  [14756] = {.lex_state = 18, .external_lex_state = 2},
  [14757] = {.lex_state = 28, .external_lex_state = 2},
  [14758] = {.lex_state = 11, .external_lex_state = 2},
  [14759] = {.lex_state = 420, .external_lex_state = 2},
  [14760] = {.lex_state = 28, .external_lex_state = 2},
  [14761] = {.lex_state = 420, .external_lex_state = 2},
  [14762] = {.lex_state = 18, .external_lex_state = 2},
  [14763] = {.lex_state = 18, .external_lex_state = 2},
  [14764] = {.lex_state = 18, .external_lex_state = 2},
  [14765] = {.lex_state = 6, .external_lex_state = 2},
  [14766] = {.lex_state = 420, .external_lex_state = 2},
  [14767] = {.lex_state = 420, .external_lex_state = 2},
  [14768] = {.lex_state = 6, .external_lex_state = 2},
  [14769] = {.lex_state = 420, .external_lex_state = 2},
  [14770] = {.lex_state = 18, .external_lex_state = 2},
  [14771] = {.lex_state = 18, .external_lex_state = 2},
  [14772] = {.lex_state = 28, .external_lex_state = 2},
  [14773] = {.lex_state = 8, .external_lex_state = 2},
  [14774] = {.lex_state = 28, .external_lex_state = 2},
  [14775] = {.lex_state = 420, .external_lex_state = 2},
  [14776] = {.lex_state = 420, .external_lex_state = 2},
  [14777] = {.lex_state = 11, .external_lex_state = 2},
  [14778] = {.lex_state = 420, .external_lex_state = 2},
  [14779] = {.lex_state = 28, .external_lex_state = 2},
  [14780] = {.lex_state = 18, .external_lex_state = 2},
  [14781] = {.lex_state = 420, .external_lex_state = 2},
  [14782] = {.lex_state = 6, .external_lex_state = 2},
  [14783] = {.lex_state = 28, .external_lex_state = 2},
  [14784] = {.lex_state = 28, .external_lex_state = 2},
  [14785] = {.lex_state = 11, .external_lex_state = 2},
  [14786] = {.lex_state = 18, .external_lex_state = 2},
  [14787] = {.lex_state = 11, .external_lex_state = 2},
  [14788] = {.lex_state = 420, .external_lex_state = 2},
  [14789] = {.lex_state = 28, .external_lex_state = 2},
  [14790] = {.lex_state = 28, .external_lex_state = 2},
  [14791] = {.lex_state = 420, .external_lex_state = 2},
  [14792] = {.lex_state = 420, .external_lex_state = 2},
  [14793] = {.lex_state = 28, .external_lex_state = 2},
  [14794] = {.lex_state = 420, .external_lex_state = 2},
  [14795] = {.lex_state = 420, .external_lex_state = 2},
  [14796] = {.lex_state = 28, .external_lex_state = 2},
  [14797] = {.lex_state = 11, .external_lex_state = 2},
  [14798] = {.lex_state = 6, .external_lex_state = 2},
  [14799] = {.lex_state = 420, .external_lex_state = 2},
  [14800] = {.lex_state = 420, .external_lex_state = 2},
  [14801] = {.lex_state = 28, .external_lex_state = 2},
  [14802] = {.lex_state = 420, .external_lex_state = 2},
  [14803] = {.lex_state = 6, .external_lex_state = 2},
  [14804] = {.lex_state = 18, .external_lex_state = 2},
  [14805] = {.lex_state = 28, .external_lex_state = 2},
  [14806] = {.lex_state = 28, .external_lex_state = 2},
  [14807] = {.lex_state = 28, .external_lex_state = 2},
  [14808] = {.lex_state = 28, .external_lex_state = 2},
  [14809] = {.lex_state = 28, .external_lex_state = 2},
  [14810] = {.lex_state = 28, .external_lex_state = 2},
  [14811] = {.lex_state = 420, .external_lex_state = 2},
  [14812] = {.lex_state = 28, .external_lex_state = 2},
  [14813] = {.lex_state = 420, .external_lex_state = 2},
  [14814] = {.lex_state = 6, .external_lex_state = 2},
  [14815] = {.lex_state = 420, .external_lex_state = 2},
  [14816] = {.lex_state = 28, .external_lex_state = 2},
  [14817] = {.lex_state = 18, .external_lex_state = 2},
  [14818] = {.lex_state = 6, .external_lex_state = 2},
  [14819] = {.lex_state = 6, .external_lex_state = 2},
  [14820] = {.lex_state = 28, .external_lex_state = 2},
  [14821] = {.lex_state = 28, .external_lex_state = 2},
  [14822] = {.lex_state = 6, .external_lex_state = 2},
  [14823] = {.lex_state = 18, .external_lex_state = 2},
  [14824] = {.lex_state = 6, .external_lex_state = 2},
  [14825] = {.lex_state = 28, .external_lex_state = 2},
  [14826] = {.lex_state = 11, .external_lex_state = 2},
  [14827] = {.lex_state = 18, .external_lex_state = 2},
  [14828] = {.lex_state = 28, .external_lex_state = 2},
  [14829] = {.lex_state = 28, .external_lex_state = 2},
  [14830] = {.lex_state = 420, .external_lex_state = 2},
  [14831] = {.lex_state = 18, .external_lex_state = 2},
  [14832] = {.lex_state = 18, .external_lex_state = 2},
  [14833] = {.lex_state = 6, .external_lex_state = 2},
  [14834] = {.lex_state = 28, .external_lex_state = 2},
  [14835] = {.lex_state = 28, .external_lex_state = 2},
  [14836] = {.lex_state = 420, .external_lex_state = 2},
  [14837] = {.lex_state = 420, .external_lex_state = 2},
  [14838] = {.lex_state = 420, .external_lex_state = 2},
  [14839] = {.lex_state = 6, .external_lex_state = 2},
  [14840] = {.lex_state = 420, .external_lex_state = 2},
  [14841] = {.lex_state = 28, .external_lex_state = 2},
  [14842] = {.lex_state = 28, .external_lex_state = 2},
  [14843] = {.lex_state = 28, .external_lex_state = 2},
  [14844] = {.lex_state = 28, .external_lex_state = 2},
  [14845] = {.lex_state = 28, .external_lex_state = 2},
  [14846] = {.lex_state = 28, .external_lex_state = 2},
  [14847] = {.lex_state = 420, .external_lex_state = 2},
  [14848] = {.lex_state = 28, .external_lex_state = 2},
  [14849] = {.lex_state = 18, .external_lex_state = 2},
  [14850] = {.lex_state = 18, .external_lex_state = 2},
  [14851] = {.lex_state = 28, .external_lex_state = 2},
  [14852] = {.lex_state = 8, .external_lex_state = 2},
  [14853] = {.lex_state = 18, .external_lex_state = 2},
  [14854] = {.lex_state = 11, .external_lex_state = 2},
  [14855] = {.lex_state = 28, .external_lex_state = 2},
  [14856] = {.lex_state = 6, .external_lex_state = 2},
  [14857] = {.lex_state = 6, .external_lex_state = 2},
  [14858] = {.lex_state = 6, .external_lex_state = 2},
  [14859] = {.lex_state = 28, .external_lex_state = 2},
  [14860] = {.lex_state = 18, .external_lex_state = 2},
  [14861] = {.lex_state = 420, .external_lex_state = 2},
  [14862] = {.lex_state = 6, .external_lex_state = 2},
  [14863] = {.lex_state = 28, .external_lex_state = 2},
  [14864] = {.lex_state = 6, .external_lex_state = 2},
  [14865] = {.lex_state = 420, .external_lex_state = 2},
  [14866] = {.lex_state = 420, .external_lex_state = 2},
  [14867] = {.lex_state = 28, .external_lex_state = 2},
  [14868] = {.lex_state = 28, .external_lex_state = 2},
  [14869] = {.lex_state = 18, .external_lex_state = 2},
  [14870] = {.lex_state = 420, .external_lex_state = 2},
  [14871] = {.lex_state = 420, .external_lex_state = 2},
  [14872] = {.lex_state = 28, .external_lex_state = 2},
  [14873] = {.lex_state = 28, .external_lex_state = 2},
  [14874] = {.lex_state = 28, .external_lex_state = 2},
  [14875] = {.lex_state = 28, .external_lex_state = 2},
  [14876] = {.lex_state = 28, .external_lex_state = 2},
  [14877] = {.lex_state = 420, .external_lex_state = 2},
  [14878] = {.lex_state = 28, .external_lex_state = 2},
  [14879] = {.lex_state = 420, .external_lex_state = 2},
  [14880] = {.lex_state = 11, .external_lex_state = 2},
  [14881] = {.lex_state = 6, .external_lex_state = 2},
  [14882] = {.lex_state = 28, .external_lex_state = 2},
  [14883] = {.lex_state = 6, .external_lex_state = 2},
  [14884] = {.lex_state = 28, .external_lex_state = 2},
  [14885] = {.lex_state = 18, .external_lex_state = 2},
  [14886] = {.lex_state = 28, .external_lex_state = 2},
  [14887] = {.lex_state = 28, .external_lex_state = 2},
  [14888] = {.lex_state = 28, .external_lex_state = 2},
  [14889] = {.lex_state = 28, .external_lex_state = 2},
  [14890] = {.lex_state = 18, .external_lex_state = 2},
  [14891] = {.lex_state = 28, .external_lex_state = 2},
  [14892] = {.lex_state = 28, .external_lex_state = 2},
  [14893] = {.lex_state = 420, .external_lex_state = 2},
  [14894] = {.lex_state = 28, .external_lex_state = 2},
  [14895] = {.lex_state = 28, .external_lex_state = 2},
  [14896] = {.lex_state = 6, .external_lex_state = 2},
  [14897] = {.lex_state = 28, .external_lex_state = 2},
  [14898] = {.lex_state = 420, .external_lex_state = 2},
  [14899] = {.lex_state = 12, .external_lex_state = 2},
  [14900] = {.lex_state = 28, .external_lex_state = 2},
  [14901] = {.lex_state = 420, .external_lex_state = 2},
  [14902] = {.lex_state = 420, .external_lex_state = 2},
  [14903] = {.lex_state = 11, .external_lex_state = 2},
  [14904] = {.lex_state = 420, .external_lex_state = 2},
  [14905] = {.lex_state = 28, .external_lex_state = 2},
  [14906] = {.lex_state = 420, .external_lex_state = 2},
  [14907] = {.lex_state = 18, .external_lex_state = 2},
  [14908] = {.lex_state = 18, .external_lex_state = 2},
  [14909] = {.lex_state = 18, .external_lex_state = 2},
  [14910] = {.lex_state = 420, .external_lex_state = 2},
  [14911] = {.lex_state = 18, .external_lex_state = 2},
  [14912] = {.lex_state = 18, .external_lex_state = 2},
  [14913] = {.lex_state = 28, .external_lex_state = 2},
  [14914] = {.lex_state = 28, .external_lex_state = 2},
  [14915] = {.lex_state = 18, .external_lex_state = 2},
  [14916] = {.lex_state = 28, .external_lex_state = 2},
  [14917] = {.lex_state = 28, .external_lex_state = 2},
  [14918] = {.lex_state = 6, .external_lex_state = 2},
  [14919] = {.lex_state = 18, .external_lex_state = 2},
  [14920] = {.lex_state = 420, .external_lex_state = 2},
  [14921] = {.lex_state = 28, .external_lex_state = 2},
  [14922] = {.lex_state = 18, .external_lex_state = 2},
  [14923] = {.lex_state = 420, .external_lex_state = 2},
  [14924] = {.lex_state = 18, .external_lex_state = 2},
  [14925] = {.lex_state = 18, .external_lex_state = 2},
  [14926] = {.lex_state = 11, .external_lex_state = 2},
  [14927] = {.lex_state = 18, .external_lex_state = 2},
  [14928] = {.lex_state = 6, .external_lex_state = 2},
  [14929] = {.lex_state = 420, .external_lex_state = 2},
  [14930] = {.lex_state = 17, .external_lex_state = 2},
  [14931] = {.lex_state = 6, .external_lex_state = 2},
  [14932] = {.lex_state = 28, .external_lex_state = 2},
  [14933] = {.lex_state = 17, .external_lex_state = 2},
  [14934] = {.lex_state = 28, .external_lex_state = 2},
  [14935] = {.lex_state = 18, .external_lex_state = 2},
  [14936] = {.lex_state = 6, .external_lex_state = 2},
  [14937] = {.lex_state = 18, .external_lex_state = 2},
  [14938] = {.lex_state = 11, .external_lex_state = 2},
  [14939] = {.lex_state = 420, .external_lex_state = 2},
  [14940] = {.lex_state = 18, .external_lex_state = 2},
  [14941] = {.lex_state = 28, .external_lex_state = 2},
  [14942] = {.lex_state = 28, .external_lex_state = 2},
  [14943] = {.lex_state = 18, .external_lex_state = 2},
  [14944] = {.lex_state = 6, .external_lex_state = 2},
  [14945] = {.lex_state = 11, .external_lex_state = 2},
  [14946] = {.lex_state = 28, .external_lex_state = 2},
  [14947] = {.lex_state = 18, .external_lex_state = 2},
  [14948] = {.lex_state = 420, .external_lex_state = 2},
  [14949] = {.lex_state = 28, .external_lex_state = 2},
  [14950] = {.lex_state = 11, .external_lex_state = 2},
  [14951] = {.lex_state = 18, .external_lex_state = 2},
  [14952] = {.lex_state = 6, .external_lex_state = 2},
  [14953] = {.lex_state = 420, .external_lex_state = 2},
  [14954] = {.lex_state = 420, .external_lex_state = 2},
  [14955] = {.lex_state = 420, .external_lex_state = 2},
  [14956] = {.lex_state = 28, .external_lex_state = 2},
  [14957] = {.lex_state = 28, .external_lex_state = 2},
  [14958] = {.lex_state = 8, .external_lex_state = 2},
  [14959] = {.lex_state = 420, .external_lex_state = 2},
  [14960] = {.lex_state = 28, .external_lex_state = 2},
  [14961] = {.lex_state = 28, .external_lex_state = 2},
  [14962] = {.lex_state = 28, .external_lex_state = 2},
  [14963] = {.lex_state = 6, .external_lex_state = 2},
  [14964] = {.lex_state = 420, .external_lex_state = 2},
  [14965] = {.lex_state = 420, .external_lex_state = 2},
  [14966] = {.lex_state = 420, .external_lex_state = 2},
  [14967] = {.lex_state = 18, .external_lex_state = 2},
  [14968] = {.lex_state = 28, .external_lex_state = 2},
  [14969] = {.lex_state = 28, .external_lex_state = 2},
  [14970] = {.lex_state = 420, .external_lex_state = 2},
  [14971] = {.lex_state = 11, .external_lex_state = 2},
  [14972] = {.lex_state = 28, .external_lex_state = 2},
  [14973] = {.lex_state = 28, .external_lex_state = 2},
  [14974] = {.lex_state = 6, .external_lex_state = 2},
  [14975] = {.lex_state = 6, .external_lex_state = 2},
  [14976] = {.lex_state = 18, .external_lex_state = 2},
  [14977] = {.lex_state = 18, .external_lex_state = 2},
  [14978] = {.lex_state = 420, .external_lex_state = 2},
  [14979] = {.lex_state = 11, .external_lex_state = 2},
  [14980] = {.lex_state = 6, .external_lex_state = 2},
  [14981] = {.lex_state = 420, .external_lex_state = 2},
  [14982] = {.lex_state = 6, .external_lex_state = 2},
  [14983] = {.lex_state = 420, .external_lex_state = 2},
  [14984] = {.lex_state = 420, .external_lex_state = 2},
  [14985] = {.lex_state = 420, .external_lex_state = 2},
  [14986] = {.lex_state = 6, .external_lex_state = 2},
  [14987] = {.lex_state = 28, .external_lex_state = 2},
  [14988] = {.lex_state = 11, .external_lex_state = 2},
  [14989] = {.lex_state = 420, .external_lex_state = 2},
  [14990] = {.lex_state = 11, .external_lex_state = 2},
  [14991] = {.lex_state = 28, .external_lex_state = 2},
  [14992] = {.lex_state = 420, .external_lex_state = 2},
  [14993] = {.lex_state = 6, .external_lex_state = 2},
  [14994] = {.lex_state = 420, .external_lex_state = 2},
  [14995] = {.lex_state = 28, .external_lex_state = 2},
  [14996] = {.lex_state = 28, .external_lex_state = 2},
  [14997] = {.lex_state = 18, .external_lex_state = 2},
  [14998] = {.lex_state = 420, .external_lex_state = 2},
  [14999] = {.lex_state = 18, .external_lex_state = 2},
  [15000] = {.lex_state = 18, .external_lex_state = 2},
  [15001] = {.lex_state = 18, .external_lex_state = 2},
  [15002] = {.lex_state = 17, .external_lex_state = 2},
  [15003] = {.lex_state = 28, .external_lex_state = 2},
  [15004] = {.lex_state = 28, .external_lex_state = 2},
  [15005] = {.lex_state = 28, .external_lex_state = 2},
  [15006] = {.lex_state = 11, .external_lex_state = 2},
  [15007] = {.lex_state = 6, .external_lex_state = 2},
  [15008] = {.lex_state = 11, .external_lex_state = 2},
  [15009] = {.lex_state = 28, .external_lex_state = 2},
  [15010] = {.lex_state = 6, .external_lex_state = 2},
  [15011] = {.lex_state = 18, .external_lex_state = 2},
  [15012] = {.lex_state = 6, .external_lex_state = 2},
  [15013] = {.lex_state = 6, .external_lex_state = 2},
  [15014] = {.lex_state = 28, .external_lex_state = 2},
  [15015] = {.lex_state = 8, .external_lex_state = 2},
  [15016] = {.lex_state = 420, .external_lex_state = 2},
  [15017] = {.lex_state = 11, .external_lex_state = 2},
  [15018] = {.lex_state = 420, .external_lex_state = 2},
  [15019] = {.lex_state = 6, .external_lex_state = 2},
  [15020] = {.lex_state = 420, .external_lex_state = 2},
  [15021] = {.lex_state = 6, .external_lex_state = 2},
  [15022] = {.lex_state = 28, .external_lex_state = 2},
  [15023] = {.lex_state = 18, .external_lex_state = 2},
  [15024] = {.lex_state = 420, .external_lex_state = 2},
  [15025] = {.lex_state = 420, .external_lex_state = 2},
  [15026] = {.lex_state = 420, .external_lex_state = 2},
  [15027] = {.lex_state = 28, .external_lex_state = 2},
  [15028] = {.lex_state = 28, .external_lex_state = 2},
  [15029] = {.lex_state = 28, .external_lex_state = 2},
  [15030] = {.lex_state = 28, .external_lex_state = 2},
  [15031] = {.lex_state = 420, .external_lex_state = 2},
  [15032] = {.lex_state = 28, .external_lex_state = 2},
  [15033] = {.lex_state = 420, .external_lex_state = 2},
  [15034] = {.lex_state = 420, .external_lex_state = 2},
  [15035] = {.lex_state = 28, .external_lex_state = 2},
  [15036] = {.lex_state = 28, .external_lex_state = 2},
  [15037] = {.lex_state = 11, .external_lex_state = 2},
  [15038] = {.lex_state = 420, .external_lex_state = 2},
  [15039] = {.lex_state = 28, .external_lex_state = 2},
  [15040] = {.lex_state = 28, .external_lex_state = 2},
  [15041] = {.lex_state = 420, .external_lex_state = 2},
  [15042] = {.lex_state = 420, .external_lex_state = 2},
  [15043] = {.lex_state = 420, .external_lex_state = 2},
  [15044] = {.lex_state = 28, .external_lex_state = 2},
  [15045] = {.lex_state = 18, .external_lex_state = 2},
  [15046] = {.lex_state = 426, .external_lex_state = 2},
  [15047] = {.lex_state = 11, .external_lex_state = 2},
  [15048] = {.lex_state = 28, .external_lex_state = 2},
  [15049] = {.lex_state = 6, .external_lex_state = 2},
  [15050] = {.lex_state = 420, .external_lex_state = 2},
  [15051] = {.lex_state = 18, .external_lex_state = 2},
  [15052] = {.lex_state = 18, .external_lex_state = 2},
  [15053] = {.lex_state = 420, .external_lex_state = 2},
  [15054] = {.lex_state = 18, .external_lex_state = 2},
  [15055] = {.lex_state = 28, .external_lex_state = 2},
  [15056] = {.lex_state = 6, .external_lex_state = 2},
  [15057] = {.lex_state = 420, .external_lex_state = 2},
  [15058] = {.lex_state = 28, .external_lex_state = 2},
  [15059] = {.lex_state = 28, .external_lex_state = 2},
  [15060] = {.lex_state = 6, .external_lex_state = 2},
  [15061] = {.lex_state = 11, .external_lex_state = 2},
  [15062] = {.lex_state = 28, .external_lex_state = 2},
  [15063] = {.lex_state = 6, .external_lex_state = 2},
  [15064] = {.lex_state = 11, .external_lex_state = 2},
  [15065] = {.lex_state = 28, .external_lex_state = 2},
  [15066] = {.lex_state = 11, .external_lex_state = 2},
  [15067] = {.lex_state = 420, .external_lex_state = 2},
  [15068] = {.lex_state = 420, .external_lex_state = 2},
  [15069] = {.lex_state = 28, .external_lex_state = 2},
  [15070] = {.lex_state = 28, .external_lex_state = 2},
  [15071] = {.lex_state = 11, .external_lex_state = 2},
  [15072] = {.lex_state = 6, .external_lex_state = 2},
  [15073] = {.lex_state = 11, .external_lex_state = 2},
  [15074] = {.lex_state = 420, .external_lex_state = 2},
  [15075] = {.lex_state = 28, .external_lex_state = 2},
  [15076] = {.lex_state = 28, .external_lex_state = 2},
  [15077] = {.lex_state = 6, .external_lex_state = 2},
  [15078] = {.lex_state = 28, .external_lex_state = 2},
  [15079] = {.lex_state = 28, .external_lex_state = 2},
  [15080] = {.lex_state = 28, .external_lex_state = 2},
  [15081] = {.lex_state = 28, .external_lex_state = 2},
  [15082] = {.lex_state = 28, .external_lex_state = 2},
  [15083] = {.lex_state = 135, .external_lex_state = 2},
  [15084] = {.lex_state = 420, .external_lex_state = 2},
  [15085] = {.lex_state = 420, .external_lex_state = 2},
  [15086] = {.lex_state = 243, .external_lex_state = 2},
  [15087] = {.lex_state = 28, .external_lex_state = 2},
  [15088] = {.lex_state = 28, .external_lex_state = 2},
  [15089] = {.lex_state = 136, .external_lex_state = 2},
  [15090] = {.lex_state = 136, .external_lex_state = 2},
  [15091] = {.lex_state = 420, .external_lex_state = 2},
  [15092] = {.lex_state = 420, .external_lex_state = 2},
  [15093] = {.lex_state = 420, .external_lex_state = 2},
  [15094] = {.lex_state = 28, .external_lex_state = 2},
  [15095] = {.lex_state = 135, .external_lex_state = 2},
  [15096] = {.lex_state = 136, .external_lex_state = 2},
  [15097] = {.lex_state = 249, .external_lex_state = 8},
  [15098] = {.lex_state = 11, .external_lex_state = 2},
  [15099] = {.lex_state = 18, .external_lex_state = 2},
  [15100] = {.lex_state = 249, .external_lex_state = 8},
  [15101] = {.lex_state = 28, .external_lex_state = 2},
  [15102] = {.lex_state = 420, .external_lex_state = 2},
  [15103] = {.lex_state = 420, .external_lex_state = 2},
  [15104] = {.lex_state = 18, .external_lex_state = 2},
  [15105] = {.lex_state = 11, .external_lex_state = 2},
  [15106] = {.lex_state = 136, .external_lex_state = 2},
  [15107] = {.lex_state = 136, .external_lex_state = 2},
  [15108] = {.lex_state = 28, .external_lex_state = 2},
  [15109] = {.lex_state = 28, .external_lex_state = 2},
  [15110] = {.lex_state = 249, .external_lex_state = 8},
  [15111] = {.lex_state = 136, .external_lex_state = 2},
  [15112] = {.lex_state = 18, .external_lex_state = 2},
  [15113] = {.lex_state = 426, .external_lex_state = 2},
  [15114] = {.lex_state = 11, .external_lex_state = 2},
  [15115] = {.lex_state = 136, .external_lex_state = 2},
  [15116] = {.lex_state = 136, .external_lex_state = 2},
  [15117] = {.lex_state = 28, .external_lex_state = 2},
  [15118] = {.lex_state = 136, .external_lex_state = 2},
  [15119] = {.lex_state = 420, .external_lex_state = 2},
  [15120] = {.lex_state = 135, .external_lex_state = 2},
  [15121] = {.lex_state = 420, .external_lex_state = 2},
  [15122] = {.lex_state = 136, .external_lex_state = 2},
  [15123] = {.lex_state = 11, .external_lex_state = 2},
  [15124] = {.lex_state = 136, .external_lex_state = 2},
  [15125] = {.lex_state = 136, .external_lex_state = 2},
  [15126] = {.lex_state = 136, .external_lex_state = 2},
  [15127] = {.lex_state = 136, .external_lex_state = 2},
  [15128] = {.lex_state = 28, .external_lex_state = 2},
  [15129] = {.lex_state = 136, .external_lex_state = 2},
  [15130] = {.lex_state = 249, .external_lex_state = 8},
  [15131] = {.lex_state = 136, .external_lex_state = 2},
  [15132] = {.lex_state = 243, .external_lex_state = 2},
  [15133] = {.lex_state = 136, .external_lex_state = 2},
  [15134] = {.lex_state = 11, .external_lex_state = 2},
  [15135] = {.lex_state = 420, .external_lex_state = 2},
  [15136] = {.lex_state = 420, .external_lex_state = 2},
  [15137] = {.lex_state = 11, .external_lex_state = 2},
  [15138] = {.lex_state = 28, .external_lex_state = 2},
  [15139] = {.lex_state = 11, .external_lex_state = 2},
  [15140] = {.lex_state = 28, .external_lex_state = 2},
  [15141] = {.lex_state = 28, .external_lex_state = 2},
  [15142] = {.lex_state = 136, .external_lex_state = 2},
  [15143] = {.lex_state = 426, .external_lex_state = 2},
  [15144] = {.lex_state = 136, .external_lex_state = 2},
  [15145] = {.lex_state = 136, .external_lex_state = 2},
  [15146] = {.lex_state = 136, .external_lex_state = 2},
  [15147] = {.lex_state = 136, .external_lex_state = 2},
  [15148] = {.lex_state = 136, .external_lex_state = 2},
  [15149] = {.lex_state = 11, .external_lex_state = 2},
  [15150] = {.lex_state = 136, .external_lex_state = 2},
  [15151] = {.lex_state = 420, .external_lex_state = 2},
  [15152] = {.lex_state = 136, .external_lex_state = 2},
  [15153] = {.lex_state = 135, .external_lex_state = 2},
  [15154] = {.lex_state = 28, .external_lex_state = 2},
  [15155] = {.lex_state = 11, .external_lex_state = 2},
  [15156] = {.lex_state = 37, .external_lex_state = 2},
  [15157] = {.lex_state = 18, .external_lex_state = 2},
  [15158] = {.lex_state = 136, .external_lex_state = 2},
  [15159] = {.lex_state = 420, .external_lex_state = 2},
  [15160] = {.lex_state = 136, .external_lex_state = 2},
  [15161] = {.lex_state = 28, .external_lex_state = 2},
  [15162] = {.lex_state = 135, .external_lex_state = 2},
  [15163] = {.lex_state = 136, .external_lex_state = 2},
  [15164] = {.lex_state = 28, .external_lex_state = 2},
  [15165] = {.lex_state = 28, .external_lex_state = 2},
  [15166] = {.lex_state = 18, .external_lex_state = 2},
  [15167] = {.lex_state = 136, .external_lex_state = 2},
  [15168] = {.lex_state = 136, .external_lex_state = 2},
  [15169] = {.lex_state = 136, .external_lex_state = 2},
  [15170] = {.lex_state = 18, .external_lex_state = 2},
  [15171] = {.lex_state = 28, .external_lex_state = 2},
  [15172] = {.lex_state = 420, .external_lex_state = 2},
  [15173] = {.lex_state = 426, .external_lex_state = 2},
  [15174] = {.lex_state = 28, .external_lex_state = 2},
  [15175] = {.lex_state = 136, .external_lex_state = 2},
  [15176] = {.lex_state = 28, .external_lex_state = 2},
  [15177] = {.lex_state = 136, .external_lex_state = 2},
  [15178] = {.lex_state = 243, .external_lex_state = 2},
  [15179] = {.lex_state = 37, .external_lex_state = 2},
  [15180] = {.lex_state = 420, .external_lex_state = 2},
  [15181] = {.lex_state = 136, .external_lex_state = 2},
  [15182] = {.lex_state = 28, .external_lex_state = 2},
  [15183] = {.lex_state = 136, .external_lex_state = 2},
  [15184] = {.lex_state = 136, .external_lex_state = 2},
  [15185] = {.lex_state = 28, .external_lex_state = 2},
  [15186] = {.lex_state = 11, .external_lex_state = 2},
  [15187] = {.lex_state = 28, .external_lex_state = 2},
  [15188] = {.lex_state = 249, .external_lex_state = 8},
  [15189] = {.lex_state = 420, .external_lex_state = 2},
  [15190] = {.lex_state = 28, .external_lex_state = 2},
  [15191] = {.lex_state = 136, .external_lex_state = 2},
  [15192] = {.lex_state = 135, .external_lex_state = 2},
  [15193] = {.lex_state = 28, .external_lex_state = 2},
  [15194] = {.lex_state = 28, .external_lex_state = 2},
  [15195] = {.lex_state = 136, .external_lex_state = 2},
  [15196] = {.lex_state = 420, .external_lex_state = 2},
  [15197] = {.lex_state = 28, .external_lex_state = 2},
  [15198] = {.lex_state = 136, .external_lex_state = 2},
  [15199] = {.lex_state = 28, .external_lex_state = 2},
  [15200] = {.lex_state = 18, .external_lex_state = 2},
  [15201] = {.lex_state = 135, .external_lex_state = 2},
  [15202] = {.lex_state = 136, .external_lex_state = 2},
  [15203] = {.lex_state = 11, .external_lex_state = 2},
  [15204] = {.lex_state = 420, .external_lex_state = 2},
  [15205] = {.lex_state = 136, .external_lex_state = 2},
  [15206] = {.lex_state = 249, .external_lex_state = 8},
  [15207] = {.lex_state = 28, .external_lex_state = 2},
  [15208] = {.lex_state = 136, .external_lex_state = 2},
  [15209] = {.lex_state = 28, .external_lex_state = 2},
  [15210] = {.lex_state = 28, .external_lex_state = 2},
  [15211] = {.lex_state = 28, .external_lex_state = 2},
  [15212] = {.lex_state = 136, .external_lex_state = 2},
  [15213] = {.lex_state = 420, .external_lex_state = 2},
  [15214] = {.lex_state = 136, .external_lex_state = 2},
  [15215] = {.lex_state = 136, .external_lex_state = 2},
  [15216] = {.lex_state = 420, .external_lex_state = 2},
  [15217] = {.lex_state = 136, .external_lex_state = 2},
  [15218] = {.lex_state = 28, .external_lex_state = 2},
  [15219] = {.lex_state = 136, .external_lex_state = 2},
  [15220] = {.lex_state = 11, .external_lex_state = 2},
  [15221] = {.lex_state = 136, .external_lex_state = 2},
  [15222] = {.lex_state = 11, .external_lex_state = 2},
  [15223] = {.lex_state = 420, .external_lex_state = 2},
  [15224] = {.lex_state = 28, .external_lex_state = 2},
  [15225] = {.lex_state = 136, .external_lex_state = 2},
  [15226] = {.lex_state = 28, .external_lex_state = 2},
  [15227] = {.lex_state = 420, .external_lex_state = 2},
  [15228] = {.lex_state = 136, .external_lex_state = 2},
  [15229] = {.lex_state = 136, .external_lex_state = 2},
  [15230] = {.lex_state = 426, .external_lex_state = 2},
  [15231] = {.lex_state = 243, .external_lex_state = 2},
  [15232] = {.lex_state = 249, .external_lex_state = 8},
  [15233] = {.lex_state = 249, .external_lex_state = 8},
  [15234] = {.lex_state = 18, .external_lex_state = 2},
  [15235] = {.lex_state = 249, .external_lex_state = 8},
  [15236] = {.lex_state = 11, .external_lex_state = 2},
  [15237] = {.lex_state = 11, .external_lex_state = 2},
  [15238] = {.lex_state = 249, .external_lex_state = 8},
  [15239] = {.lex_state = 136, .external_lex_state = 2},
  [15240] = {.lex_state = 19, .external_lex_state = 2},
  [15241] = {.lex_state = 18, .external_lex_state = 2},
  [15242] = {.lex_state = 136, .external_lex_state = 2},
  [15243] = {.lex_state = 136, .external_lex_state = 2},
  [15244] = {.lex_state = 136, .external_lex_state = 2},
  [15245] = {.lex_state = 136, .external_lex_state = 2},
  [15246] = {.lex_state = 11, .external_lex_state = 2},
  [15247] = {.lex_state = 28, .external_lex_state = 2},
  [15248] = {.lex_state = 420, .external_lex_state = 2},
  [15249] = {.lex_state = 135, .external_lex_state = 2},
  [15250] = {.lex_state = 420, .external_lex_state = 2},
  [15251] = {.lex_state = 420, .external_lex_state = 2},
  [15252] = {.lex_state = 28, .external_lex_state = 2},
  [15253] = {.lex_state = 11, .external_lex_state = 2},
  [15254] = {.lex_state = 136, .external_lex_state = 2},
  [15255] = {.lex_state = 28, .external_lex_state = 2},
  [15256] = {.lex_state = 136, .external_lex_state = 2},
  [15257] = {.lex_state = 28, .external_lex_state = 2},
  [15258] = {.lex_state = 28, .external_lex_state = 2},
  [15259] = {.lex_state = 249, .external_lex_state = 8},
  [15260] = {.lex_state = 28, .external_lex_state = 2},
  [15261] = {.lex_state = 28, .external_lex_state = 2},
  [15262] = {.lex_state = 136, .external_lex_state = 2},
  [15263] = {.lex_state = 136, .external_lex_state = 2},
  [15264] = {.lex_state = 11, .external_lex_state = 2},
  [15265] = {.lex_state = 28, .external_lex_state = 2},
  [15266] = {.lex_state = 136, .external_lex_state = 2},
  [15267] = {.lex_state = 11, .external_lex_state = 2},
  [15268] = {.lex_state = 136, .external_lex_state = 2},
  [15269] = {.lex_state = 18, .external_lex_state = 2},
  [15270] = {.lex_state = 28, .external_lex_state = 2},
  [15271] = {.lex_state = 426, .external_lex_state = 2},
  [15272] = {.lex_state = 18, .external_lex_state = 2},
  [15273] = {.lex_state = 420, .external_lex_state = 2},
  [15274] = {.lex_state = 243, .external_lex_state = 2},
  [15275] = {.lex_state = 420, .external_lex_state = 2},
  [15276] = {.lex_state = 18, .external_lex_state = 2},
  [15277] = {.lex_state = 136, .external_lex_state = 2},
  [15278] = {.lex_state = 28, .external_lex_state = 2},
  [15279] = {.lex_state = 18, .external_lex_state = 2},
  [15280] = {.lex_state = 136, .external_lex_state = 2},
  [15281] = {.lex_state = 136, .external_lex_state = 2},
  [15282] = {.lex_state = 426, .external_lex_state = 2},
  [15283] = {.lex_state = 135, .external_lex_state = 2},
  [15284] = {.lex_state = 28, .external_lex_state = 2},
  [15285] = {.lex_state = 136, .external_lex_state = 2},
  [15286] = {.lex_state = 136, .external_lex_state = 2},
  [15287] = {.lex_state = 11, .external_lex_state = 2},
  [15288] = {.lex_state = 18, .external_lex_state = 2},
  [15289] = {.lex_state = 420, .external_lex_state = 2},
  [15290] = {.lex_state = 249, .external_lex_state = 8},
  [15291] = {.lex_state = 11, .external_lex_state = 2},
  [15292] = {.lex_state = 28, .external_lex_state = 2},
  [15293] = {.lex_state = 37, .external_lex_state = 2},
  [15294] = {.lex_state = 136, .external_lex_state = 2},
  [15295] = {.lex_state = 420, .external_lex_state = 2},
  [15296] = {.lex_state = 18, .external_lex_state = 2},
  [15297] = {.lex_state = 420, .external_lex_state = 2},
  [15298] = {.lex_state = 420, .external_lex_state = 2},
  [15299] = {.lex_state = 420, .external_lex_state = 2},
  [15300] = {.lex_state = 135, .external_lex_state = 2},
  [15301] = {.lex_state = 18, .external_lex_state = 2},
  [15302] = {.lex_state = 135, .external_lex_state = 2},
  [15303] = {.lex_state = 11, .external_lex_state = 2},
  [15304] = {.lex_state = 28, .external_lex_state = 2},
  [15305] = {.lex_state = 136, .external_lex_state = 2},
  [15306] = {.lex_state = 28, .external_lex_state = 2},
  [15307] = {.lex_state = 28, .external_lex_state = 2},
  [15308] = {.lex_state = 420, .external_lex_state = 2},
  [15309] = {.lex_state = 136, .external_lex_state = 2},
  [15310] = {.lex_state = 249, .external_lex_state = 8},
  [15311] = {.lex_state = 28, .external_lex_state = 2},
  [15312] = {.lex_state = 18, .external_lex_state = 2},
  [15313] = {.lex_state = 243, .external_lex_state = 2},
  [15314] = {.lex_state = 136, .external_lex_state = 2},
  [15315] = {.lex_state = 420, .external_lex_state = 2},
  [15316] = {.lex_state = 136, .external_lex_state = 2},
  [15317] = {.lex_state = 136, .external_lex_state = 2},
  [15318] = {.lex_state = 136, .external_lex_state = 2},
  [15319] = {.lex_state = 136, .external_lex_state = 2},
  [15320] = {.lex_state = 249, .external_lex_state = 8},
  [15321] = {.lex_state = 420, .external_lex_state = 2},
  [15322] = {.lex_state = 28, .external_lex_state = 2},
  [15323] = {.lex_state = 28, .external_lex_state = 2},
  [15324] = {.lex_state = 136, .external_lex_state = 2},
  [15325] = {.lex_state = 136, .external_lex_state = 2},
  [15326] = {.lex_state = 136, .external_lex_state = 2},
  [15327] = {.lex_state = 420, .external_lex_state = 2},
  [15328] = {.lex_state = 28, .external_lex_state = 2},
  [15329] = {.lex_state = 420, .external_lex_state = 2},
  [15330] = {.lex_state = 420, .external_lex_state = 2},
  [15331] = {.lex_state = 136, .external_lex_state = 2},
  [15332] = {.lex_state = 37, .external_lex_state = 2},
  [15333] = {.lex_state = 420, .external_lex_state = 2},
  [15334] = {.lex_state = 37, .external_lex_state = 2},
  [15335] = {.lex_state = 420, .external_lex_state = 2},
  [15336] = {.lex_state = 28, .external_lex_state = 2},
  [15337] = {.lex_state = 136, .external_lex_state = 2},
  [15338] = {.lex_state = 136, .external_lex_state = 2},
  [15339] = {.lex_state = 136, .external_lex_state = 2},
  [15340] = {.lex_state = 136, .external_lex_state = 2},
  [15341] = {.lex_state = 11, .external_lex_state = 2},
  [15342] = {.lex_state = 420, .external_lex_state = 2},
  [15343] = {.lex_state = 420, .external_lex_state = 2},
  [15344] = {.lex_state = 135, .external_lex_state = 2},
  [15345] = {.lex_state = 243, .external_lex_state = 2},
  [15346] = {.lex_state = 420, .external_lex_state = 2},
  [15347] = {.lex_state = 136, .external_lex_state = 2},
  [15348] = {.lex_state = 420, .external_lex_state = 2},
  [15349] = {.lex_state = 136, .external_lex_state = 2},
  [15350] = {.lex_state = 28, .external_lex_state = 2},
  [15351] = {.lex_state = 136, .external_lex_state = 2},
  [15352] = {.lex_state = 28, .external_lex_state = 2},
  [15353] = {.lex_state = 136, .external_lex_state = 2},
  [15354] = {.lex_state = 420, .external_lex_state = 2},
  [15355] = {.lex_state = 28, .external_lex_state = 2},
  [15356] = {.lex_state = 28, .external_lex_state = 2},
  [15357] = {.lex_state = 37, .external_lex_state = 2},
  [15358] = {.lex_state = 136, .external_lex_state = 2},
  [15359] = {.lex_state = 420, .external_lex_state = 2},
  [15360] = {.lex_state = 28, .external_lex_state = 2},
  [15361] = {.lex_state = 28, .external_lex_state = 2},
  [15362] = {.lex_state = 135, .external_lex_state = 2},
  [15363] = {.lex_state = 18, .external_lex_state = 2},
  [15364] = {.lex_state = 420, .external_lex_state = 2},
  [15365] = {.lex_state = 249, .external_lex_state = 8},
  [15366] = {.lex_state = 420, .external_lex_state = 2},
  [15367] = {.lex_state = 18, .external_lex_state = 2},
  [15368] = {.lex_state = 18, .external_lex_state = 2},
  [15369] = {.lex_state = 243, .external_lex_state = 2},
  [15370] = {.lex_state = 136, .external_lex_state = 2},
  [15371] = {.lex_state = 420, .external_lex_state = 2},
  [15372] = {.lex_state = 426, .external_lex_state = 2},
  [15373] = {.lex_state = 28, .external_lex_state = 2},
  [15374] = {.lex_state = 28, .external_lex_state = 2},
  [15375] = {.lex_state = 136, .external_lex_state = 2},
  [15376] = {.lex_state = 420, .external_lex_state = 2},
  [15377] = {.lex_state = 28, .external_lex_state = 2},
  [15378] = {.lex_state = 420, .external_lex_state = 2},
  [15379] = {.lex_state = 136, .external_lex_state = 2},
  [15380] = {.lex_state = 136, .external_lex_state = 2},
  [15381] = {.lex_state = 135, .external_lex_state = 2},
  [15382] = {.lex_state = 28, .external_lex_state = 2},
  [15383] = {.lex_state = 28, .external_lex_state = 2},
  [15384] = {.lex_state = 28, .external_lex_state = 2},
  [15385] = {.lex_state = 136, .external_lex_state = 2},
  [15386] = {.lex_state = 420, .external_lex_state = 2},
  [15387] = {.lex_state = 28, .external_lex_state = 2},
  [15388] = {.lex_state = 243, .external_lex_state = 2},
  [15389] = {.lex_state = 249, .external_lex_state = 8},
  [15390] = {.lex_state = 28, .external_lex_state = 2},
  [15391] = {.lex_state = 11, .external_lex_state = 2},
  [15392] = {.lex_state = 28, .external_lex_state = 2},
  [15393] = {.lex_state = 28, .external_lex_state = 2},
  [15394] = {.lex_state = 136, .external_lex_state = 2},
  [15395] = {.lex_state = 11, .external_lex_state = 2},
  [15396] = {.lex_state = 28, .external_lex_state = 2},
  [15397] = {.lex_state = 37, .external_lex_state = 2},
  [15398] = {.lex_state = 11, .external_lex_state = 2},
  [15399] = {.lex_state = 136, .external_lex_state = 2},
  [15400] = {.lex_state = 135, .external_lex_state = 2},
  [15401] = {.lex_state = 28, .external_lex_state = 2},
  [15402] = {.lex_state = 249, .external_lex_state = 8},
  [15403] = {.lex_state = 249, .external_lex_state = 8},
  [15404] = {.lex_state = 28, .external_lex_state = 2},
  [15405] = {.lex_state = 28, .external_lex_state = 2},
  [15406] = {.lex_state = 11, .external_lex_state = 2},
  [15407] = {.lex_state = 136, .external_lex_state = 2},
  [15408] = {.lex_state = 28, .external_lex_state = 2},
  [15409] = {.lex_state = 136, .external_lex_state = 2},
  [15410] = {.lex_state = 136, .external_lex_state = 2},
  [15411] = {.lex_state = 136, .external_lex_state = 2},
  [15412] = {.lex_state = 18, .external_lex_state = 2},
  [15413] = {.lex_state = 249, .external_lex_state = 8},
  [15414] = {.lex_state = 28, .external_lex_state = 2},
  [15415] = {.lex_state = 136, .external_lex_state = 2},
  [15416] = {.lex_state = 136, .external_lex_state = 2},
  [15417] = {.lex_state = 11, .external_lex_state = 2},
  [15418] = {.lex_state = 28, .external_lex_state = 2},
  [15419] = {.lex_state = 136, .external_lex_state = 2},
  [15420] = {.lex_state = 11, .external_lex_state = 2},
  [15421] = {.lex_state = 11, .external_lex_state = 2},
  [15422] = {.lex_state = 249, .external_lex_state = 8},
  [15423] = {.lex_state = 28, .external_lex_state = 2},
  [15424] = {.lex_state = 136, .external_lex_state = 2},
  [15425] = {.lex_state = 136, .external_lex_state = 2},
  [15426] = {.lex_state = 28, .external_lex_state = 2},
  [15427] = {.lex_state = 11, .external_lex_state = 2},
  [15428] = {.lex_state = 28, .external_lex_state = 2},
  [15429] = {.lex_state = 28, .external_lex_state = 2},
  [15430] = {.lex_state = 28, .external_lex_state = 2},
  [15431] = {.lex_state = 136, .external_lex_state = 2},
  [15432] = {.lex_state = 136, .external_lex_state = 2},
  [15433] = {.lex_state = 136, .external_lex_state = 2},
  [15434] = {.lex_state = 426, .external_lex_state = 2},
  [15435] = {.lex_state = 426, .external_lex_state = 2},
  [15436] = {.lex_state = 136, .external_lex_state = 2},
  [15437] = {.lex_state = 28, .external_lex_state = 2},
  [15438] = {.lex_state = 135, .external_lex_state = 2},
  [15439] = {.lex_state = 28, .external_lex_state = 2},
  [15440] = {.lex_state = 18, .external_lex_state = 2},
  [15441] = {.lex_state = 18, .external_lex_state = 2},
  [15442] = {.lex_state = 136, .external_lex_state = 2},
  [15443] = {.lex_state = 136, .external_lex_state = 2},
  [15444] = {.lex_state = 249, .external_lex_state = 8},
  [15445] = {.lex_state = 28, .external_lex_state = 2},
  [15446] = {.lex_state = 426, .external_lex_state = 2},
  [15447] = {.lex_state = 28, .external_lex_state = 2},
  [15448] = {.lex_state = 135, .external_lex_state = 2},
  [15449] = {.lex_state = 243, .external_lex_state = 2},
  [15450] = {.lex_state = 28, .external_lex_state = 2},
  [15451] = {.lex_state = 11, .external_lex_state = 2},
  [15452] = {.lex_state = 136, .external_lex_state = 2},
  [15453] = {.lex_state = 11, .external_lex_state = 2},
  [15454] = {.lex_state = 18, .external_lex_state = 2},
  [15455] = {.lex_state = 28, .external_lex_state = 2},
  [15456] = {.lex_state = 420, .external_lex_state = 2},
  [15457] = {.lex_state = 420, .external_lex_state = 2},
  [15458] = {.lex_state = 136, .external_lex_state = 2},
  [15459] = {.lex_state = 28, .external_lex_state = 2},
  [15460] = {.lex_state = 136, .external_lex_state = 2},
  [15461] = {.lex_state = 37, .external_lex_state = 2},
  [15462] = {.lex_state = 249, .external_lex_state = 8},
  [15463] = {.lex_state = 243, .external_lex_state = 2},
  [15464] = {.lex_state = 28, .external_lex_state = 2},
  [15465] = {.lex_state = 249, .external_lex_state = 8},
  [15466] = {.lex_state = 18, .external_lex_state = 2},
  [15467] = {.lex_state = 28, .external_lex_state = 2},
  [15468] = {.lex_state = 249, .external_lex_state = 8},
  [15469] = {.lex_state = 136, .external_lex_state = 2},
  [15470] = {.lex_state = 136, .external_lex_state = 2},
  [15471] = {.lex_state = 18, .external_lex_state = 2},
  [15472] = {.lex_state = 249, .external_lex_state = 8},
  [15473] = {.lex_state = 37, .external_lex_state = 2},
  [15474] = {.lex_state = 18, .external_lex_state = 2},
  [15475] = {.lex_state = 28, .external_lex_state = 2},
  [15476] = {.lex_state = 426, .external_lex_state = 2},
  [15477] = {.lex_state = 37, .external_lex_state = 2},
  [15478] = {.lex_state = 18, .external_lex_state = 2},
  [15479] = {.lex_state = 28, .external_lex_state = 2},
  [15480] = {.lex_state = 249, .external_lex_state = 8},
  [15481] = {.lex_state = 11, .external_lex_state = 2},
  [15482] = {.lex_state = 12, .external_lex_state = 2},
  [15483] = {.lex_state = 136, .external_lex_state = 2},
  [15484] = {.lex_state = 249, .external_lex_state = 8},
  [15485] = {.lex_state = 28, .external_lex_state = 2},
  [15486] = {.lex_state = 28, .external_lex_state = 2},
  [15487] = {.lex_state = 426, .external_lex_state = 2},
  [15488] = {.lex_state = 136, .external_lex_state = 2},
  [15489] = {.lex_state = 136, .external_lex_state = 2},
  [15490] = {.lex_state = 136, .external_lex_state = 2},
  [15491] = {.lex_state = 18, .external_lex_state = 2},
  [15492] = {.lex_state = 11, .external_lex_state = 2},
  [15493] = {.lex_state = 28, .external_lex_state = 2},
  [15494] = {.lex_state = 37, .external_lex_state = 2},
  [15495] = {.lex_state = 28, .external_lex_state = 2},
  [15496] = {.lex_state = 28, .external_lex_state = 2},
  [15497] = {.lex_state = 28, .external_lex_state = 2},
  [15498] = {.lex_state = 28, .external_lex_state = 2},
  [15499] = {.lex_state = 18, .external_lex_state = 2},
  [15500] = {.lex_state = 28, .external_lex_state = 2},
  [15501] = {.lex_state = 28, .external_lex_state = 2},
  [15502] = {.lex_state = 136, .external_lex_state = 2},
  [15503] = {.lex_state = 136, .external_lex_state = 2},
  [15504] = {.lex_state = 249, .external_lex_state = 8},
  [15505] = {.lex_state = 136, .external_lex_state = 2},
  [15506] = {.lex_state = 135, .external_lex_state = 2},
  [15507] = {.lex_state = 28, .external_lex_state = 2},
  [15508] = {.lex_state = 11, .external_lex_state = 2},
  [15509] = {.lex_state = 136, .external_lex_state = 2},
  [15510] = {.lex_state = 249, .external_lex_state = 8},
  [15511] = {.lex_state = 28, .external_lex_state = 2},
  [15512] = {.lex_state = 37, .external_lex_state = 2},
  [15513] = {.lex_state = 136, .external_lex_state = 2},
  [15514] = {.lex_state = 136, .external_lex_state = 2},
  [15515] = {.lex_state = 28, .external_lex_state = 2},
  [15516] = {.lex_state = 28, .external_lex_state = 2},
  [15517] = {.lex_state = 18, .external_lex_state = 2},
  [15518] = {.lex_state = 420, .external_lex_state = 2},
  [15519] = {.lex_state = 136, .external_lex_state = 2},
  [15520] = {.lex_state = 28, .external_lex_state = 2},
  [15521] = {.lex_state = 420, .external_lex_state = 2},
  [15522] = {.lex_state = 37, .external_lex_state = 2},
  [15523] = {.lex_state = 28, .external_lex_state = 2},
  [15524] = {.lex_state = 28, .external_lex_state = 2},
  [15525] = {.lex_state = 136, .external_lex_state = 2},
  [15526] = {.lex_state = 28, .external_lex_state = 2},
  [15527] = {.lex_state = 136, .external_lex_state = 2},
  [15528] = {.lex_state = 420, .external_lex_state = 2},
  [15529] = {.lex_state = 420, .external_lex_state = 2},
  [15530] = {.lex_state = 136, .external_lex_state = 2},
  [15531] = {.lex_state = 420, .external_lex_state = 2},
  [15532] = {.lex_state = 135, .external_lex_state = 2},
  [15533] = {.lex_state = 11, .external_lex_state = 2},
  [15534] = {.lex_state = 28, .external_lex_state = 2},
  [15535] = {.lex_state = 249, .external_lex_state = 8},
  [15536] = {.lex_state = 28, .external_lex_state = 2},
  [15537] = {.lex_state = 136, .external_lex_state = 2},
  [15538] = {.lex_state = 420, .external_lex_state = 2},
  [15539] = {.lex_state = 420, .external_lex_state = 2},
  [15540] = {.lex_state = 28, .external_lex_state = 2},
  [15541] = {.lex_state = 28, .external_lex_state = 2},
  [15542] = {.lex_state = 28, .external_lex_state = 2},
  [15543] = {.lex_state = 426, .external_lex_state = 2},
  [15544] = {.lex_state = 28, .external_lex_state = 2},
  [15545] = {.lex_state = 243, .external_lex_state = 2},
  [15546] = {.lex_state = 136, .external_lex_state = 2},
  [15547] = {.lex_state = 28, .external_lex_state = 2},
  [15548] = {.lex_state = 136, .external_lex_state = 2},
  [15549] = {.lex_state = 28, .external_lex_state = 2},
  [15550] = {.lex_state = 420, .external_lex_state = 3},
  [15551] = {.lex_state = 136, .external_lex_state = 2},
  [15552] = {.lex_state = 136, .external_lex_state = 2},
  [15553] = {.lex_state = 135, .external_lex_state = 2},
  [15554] = {.lex_state = 249, .external_lex_state = 8},
  [15555] = {.lex_state = 18, .external_lex_state = 2},
  [15556] = {.lex_state = 18, .external_lex_state = 2},
  [15557] = {.lex_state = 243, .external_lex_state = 2},
  [15558] = {.lex_state = 28, .external_lex_state = 2},
  [15559] = {.lex_state = 249, .external_lex_state = 8},
  [15560] = {.lex_state = 28, .external_lex_state = 2},
  [15561] = {.lex_state = 28, .external_lex_state = 2},
  [15562] = {.lex_state = 28, .external_lex_state = 2},
  [15563] = {.lex_state = 136, .external_lex_state = 2},
  [15564] = {.lex_state = 249, .external_lex_state = 8},
  [15565] = {.lex_state = 136, .external_lex_state = 2},
  [15566] = {.lex_state = 28, .external_lex_state = 2},
  [15567] = {.lex_state = 136, .external_lex_state = 2},
  [15568] = {.lex_state = 28, .external_lex_state = 2},
  [15569] = {.lex_state = 136, .external_lex_state = 2},
  [15570] = {.lex_state = 28, .external_lex_state = 2},
  [15571] = {.lex_state = 11, .external_lex_state = 2},
  [15572] = {.lex_state = 249, .external_lex_state = 8},
  [15573] = {.lex_state = 28, .external_lex_state = 2},
  [15574] = {.lex_state = 11, .external_lex_state = 2},
  [15575] = {.lex_state = 249, .external_lex_state = 8},
  [15576] = {.lex_state = 28, .external_lex_state = 2},
  [15577] = {.lex_state = 136, .external_lex_state = 2},
  [15578] = {.lex_state = 420, .external_lex_state = 2},
  [15579] = {.lex_state = 28, .external_lex_state = 2},
  [15580] = {.lex_state = 420, .external_lex_state = 2},
  [15581] = {.lex_state = 28, .external_lex_state = 2},
  [15582] = {.lex_state = 28, .external_lex_state = 2},
  [15583] = {.lex_state = 136, .external_lex_state = 2},
  [15584] = {.lex_state = 249, .external_lex_state = 8},
  [15585] = {.lex_state = 28, .external_lex_state = 2},
  [15586] = {.lex_state = 420, .external_lex_state = 2},
  [15587] = {.lex_state = 136, .external_lex_state = 2},
  [15588] = {.lex_state = 11, .external_lex_state = 2},
  [15589] = {.lex_state = 243, .external_lex_state = 2},
  [15590] = {.lex_state = 136, .external_lex_state = 2},
  [15591] = {.lex_state = 420, .external_lex_state = 2},
  [15592] = {.lex_state = 136, .external_lex_state = 2},
  [15593] = {.lex_state = 136, .external_lex_state = 2},
  [15594] = {.lex_state = 420, .external_lex_state = 2},
  [15595] = {.lex_state = 28, .external_lex_state = 2},
  [15596] = {.lex_state = 28, .external_lex_state = 2},
  [15597] = {.lex_state = 249, .external_lex_state = 8},
  [15598] = {.lex_state = 136, .external_lex_state = 2},
  [15599] = {.lex_state = 28, .external_lex_state = 2},
  [15600] = {.lex_state = 426, .external_lex_state = 2},
  [15601] = {.lex_state = 18, .external_lex_state = 2},
  [15602] = {.lex_state = 12, .external_lex_state = 2},
  [15603] = {.lex_state = 420, .external_lex_state = 2},
  [15604] = {.lex_state = 136, .external_lex_state = 2},
  [15605] = {.lex_state = 420, .external_lex_state = 2},
  [15606] = {.lex_state = 136, .external_lex_state = 2},
  [15607] = {.lex_state = 28, .external_lex_state = 2},
  [15608] = {.lex_state = 18, .external_lex_state = 2},
  [15609] = {.lex_state = 249, .external_lex_state = 8},
  [15610] = {.lex_state = 18, .external_lex_state = 2},
  [15611] = {.lex_state = 28, .external_lex_state = 2},
  [15612] = {.lex_state = 18, .external_lex_state = 2},
  [15613] = {.lex_state = 249, .external_lex_state = 8},
  [15614] = {.lex_state = 37, .external_lex_state = 2},
  [15615] = {.lex_state = 426, .external_lex_state = 2},
  [15616] = {.lex_state = 28, .external_lex_state = 2},
  [15617] = {.lex_state = 136, .external_lex_state = 2},
  [15618] = {.lex_state = 136, .external_lex_state = 2},
  [15619] = {.lex_state = 249, .external_lex_state = 8},
  [15620] = {.lex_state = 136, .external_lex_state = 2},
  [15621] = {.lex_state = 28, .external_lex_state = 2},
  [15622] = {.lex_state = 136, .external_lex_state = 2},
  [15623] = {.lex_state = 420, .external_lex_state = 2},
  [15624] = {.lex_state = 18, .external_lex_state = 2},
  [15625] = {.lex_state = 135, .external_lex_state = 2},
  [15626] = {.lex_state = 136, .external_lex_state = 2},
  [15627] = {.lex_state = 28, .external_lex_state = 2},
  [15628] = {.lex_state = 18, .external_lex_state = 2},
  [15629] = {.lex_state = 136, .external_lex_state = 2},
  [15630] = {.lex_state = 136, .external_lex_state = 2},
  [15631] = {.lex_state = 420, .external_lex_state = 2},
  [15632] = {.lex_state = 28, .external_lex_state = 2},
  [15633] = {.lex_state = 28, .external_lex_state = 2},
  [15634] = {.lex_state = 136, .external_lex_state = 2},
  [15635] = {.lex_state = 28, .external_lex_state = 2},
  [15636] = {.lex_state = 136, .external_lex_state = 2},
  [15637] = {.lex_state = 28, .external_lex_state = 2},
  [15638] = {.lex_state = 135, .external_lex_state = 2},
  [15639] = {.lex_state = 136, .external_lex_state = 2},
  [15640] = {.lex_state = 249, .external_lex_state = 8},
  [15641] = {.lex_state = 18, .external_lex_state = 2},
  [15642] = {.lex_state = 18, .external_lex_state = 2},
  [15643] = {.lex_state = 426, .external_lex_state = 2},
  [15644] = {.lex_state = 249, .external_lex_state = 8},
  [15645] = {.lex_state = 28, .external_lex_state = 2},
  [15646] = {.lex_state = 135, .external_lex_state = 2},
  [15647] = {.lex_state = 28, .external_lex_state = 2},
  [15648] = {.lex_state = 28, .external_lex_state = 2},
  [15649] = {.lex_state = 28, .external_lex_state = 2},
  [15650] = {.lex_state = 243, .external_lex_state = 2},
  [15651] = {.lex_state = 18, .external_lex_state = 2},
  [15652] = {.lex_state = 136, .external_lex_state = 2},
  [15653] = {.lex_state = 36, .external_lex_state = 2},
  [15654] = {.lex_state = 28, .external_lex_state = 2},
  [15655] = {.lex_state = 11, .external_lex_state = 2},
  [15656] = {.lex_state = 136, .external_lex_state = 2},
  [15657] = {.lex_state = 249, .external_lex_state = 8},
  [15658] = {.lex_state = 243, .external_lex_state = 2},
  [15659] = {.lex_state = 136, .external_lex_state = 2},
  [15660] = {.lex_state = 420, .external_lex_state = 2},
  [15661] = {.lex_state = 11, .external_lex_state = 2},
  [15662] = {.lex_state = 243, .external_lex_state = 2},
  [15663] = {.lex_state = 28, .external_lex_state = 2},
  [15664] = {.lex_state = 136, .external_lex_state = 2},
  [15665] = {.lex_state = 18, .external_lex_state = 2},
  [15666] = {.lex_state = 28, .external_lex_state = 2},
  [15667] = {.lex_state = 28, .external_lex_state = 2},
  [15668] = {.lex_state = 11, .external_lex_state = 2},
  [15669] = {.lex_state = 136, .external_lex_state = 2},
  [15670] = {.lex_state = 136, .external_lex_state = 2},
  [15671] = {.lex_state = 28, .external_lex_state = 2},
  [15672] = {.lex_state = 37, .external_lex_state = 2},
  [15673] = {.lex_state = 426, .external_lex_state = 2},
  [15674] = {.lex_state = 37, .external_lex_state = 2},
  [15675] = {.lex_state = 136, .external_lex_state = 2},
  [15676] = {.lex_state = 18, .external_lex_state = 2},
  [15677] = {.lex_state = 420, .external_lex_state = 2},
  [15678] = {.lex_state = 249, .external_lex_state = 8},
  [15679] = {.lex_state = 18, .external_lex_state = 2},
  [15680] = {.lex_state = 18, .external_lex_state = 2},
  [15681] = {.lex_state = 426, .external_lex_state = 2},
  [15682] = {.lex_state = 136, .external_lex_state = 2},
  [15683] = {.lex_state = 136, .external_lex_state = 2},
  [15684] = {.lex_state = 420, .external_lex_state = 2},
  [15685] = {.lex_state = 28, .external_lex_state = 2},
  [15686] = {.lex_state = 28, .external_lex_state = 2},
  [15687] = {.lex_state = 420, .external_lex_state = 2},
  [15688] = {.lex_state = 18, .external_lex_state = 2},
  [15689] = {.lex_state = 135, .external_lex_state = 2},
  [15690] = {.lex_state = 136, .external_lex_state = 2},
  [15691] = {.lex_state = 28, .external_lex_state = 2},
  [15692] = {.lex_state = 136, .external_lex_state = 2},
  [15693] = {.lex_state = 420, .external_lex_state = 2},
  [15694] = {.lex_state = 28, .external_lex_state = 2},
  [15695] = {.lex_state = 420, .external_lex_state = 2},
  [15696] = {.lex_state = 136, .external_lex_state = 2},
  [15697] = {.lex_state = 249, .external_lex_state = 8},
  [15698] = {.lex_state = 136, .external_lex_state = 2},
  [15699] = {.lex_state = 28, .external_lex_state = 2},
  [15700] = {.lex_state = 420, .external_lex_state = 2},
  [15701] = {.lex_state = 136, .external_lex_state = 2},
  [15702] = {.lex_state = 28, .external_lex_state = 2},
  [15703] = {.lex_state = 18, .external_lex_state = 2},
  [15704] = {.lex_state = 28, .external_lex_state = 2},
  [15705] = {.lex_state = 11, .external_lex_state = 2},
  [15706] = {.lex_state = 135, .external_lex_state = 2},
  [15707] = {.lex_state = 28, .external_lex_state = 2},
  [15708] = {.lex_state = 136, .external_lex_state = 2},
  [15709] = {.lex_state = 136, .external_lex_state = 2},
  [15710] = {.lex_state = 11, .external_lex_state = 2},
  [15711] = {.lex_state = 136, .external_lex_state = 2},
  [15712] = {.lex_state = 18, .external_lex_state = 2},
  [15713] = {.lex_state = 136, .external_lex_state = 2},
  [15714] = {.lex_state = 136, .external_lex_state = 2},
  [15715] = {.lex_state = 11, .external_lex_state = 2},
  [15716] = {.lex_state = 135, .external_lex_state = 2},
  [15717] = {.lex_state = 37, .external_lex_state = 2},
  [15718] = {.lex_state = 28, .external_lex_state = 2},
  [15719] = {.lex_state = 18, .external_lex_state = 2},
  [15720] = {.lex_state = 37, .external_lex_state = 2},
  [15721] = {.lex_state = 136, .external_lex_state = 2},
  [15722] = {.lex_state = 136, .external_lex_state = 2},
  [15723] = {.lex_state = 18, .external_lex_state = 2},
  [15724] = {.lex_state = 243, .external_lex_state = 2},
  [15725] = {.lex_state = 28, .external_lex_state = 2},
  [15726] = {.lex_state = 136, .external_lex_state = 2},
  [15727] = {.lex_state = 249, .external_lex_state = 8},
  [15728] = {.lex_state = 28, .external_lex_state = 2},
  [15729] = {.lex_state = 136, .external_lex_state = 2},
  [15730] = {.lex_state = 136, .external_lex_state = 2},
  [15731] = {.lex_state = 28, .external_lex_state = 2},
  [15732] = {.lex_state = 249, .external_lex_state = 8},
  [15733] = {.lex_state = 249, .external_lex_state = 8},
  [15734] = {.lex_state = 11, .external_lex_state = 2},
  [15735] = {.lex_state = 426, .external_lex_state = 2},
  [15736] = {.lex_state = 136, .external_lex_state = 2},
  [15737] = {.lex_state = 243, .external_lex_state = 2},
  [15738] = {.lex_state = 420, .external_lex_state = 2},
  [15739] = {.lex_state = 136, .external_lex_state = 2},
  [15740] = {.lex_state = 18, .external_lex_state = 2},
  [15741] = {.lex_state = 243, .external_lex_state = 2},
  [15742] = {.lex_state = 28, .external_lex_state = 2},
  [15743] = {.lex_state = 28, .external_lex_state = 2},
  [15744] = {.lex_state = 28, .external_lex_state = 2},
  [15745] = {.lex_state = 28, .external_lex_state = 2},
  [15746] = {.lex_state = 28, .external_lex_state = 2},
  [15747] = {.lex_state = 136, .external_lex_state = 2},
  [15748] = {.lex_state = 28, .external_lex_state = 2},
  [15749] = {.lex_state = 11, .external_lex_state = 2},
  [15750] = {.lex_state = 28, .external_lex_state = 2},
  [15751] = {.lex_state = 420, .external_lex_state = 2},
  [15752] = {.lex_state = 135, .external_lex_state = 2},
  [15753] = {.lex_state = 136, .external_lex_state = 2},
  [15754] = {.lex_state = 136, .external_lex_state = 2},
  [15755] = {.lex_state = 420, .external_lex_state = 2},
  [15756] = {.lex_state = 136, .external_lex_state = 2},
  [15757] = {.lex_state = 136, .external_lex_state = 2},
  [15758] = {.lex_state = 135, .external_lex_state = 2},
  [15759] = {.lex_state = 28, .external_lex_state = 2},
  [15760] = {.lex_state = 28, .external_lex_state = 2},
  [15761] = {.lex_state = 136, .external_lex_state = 2},
  [15762] = {.lex_state = 28, .external_lex_state = 2},
  [15763] = {.lex_state = 136, .external_lex_state = 2},
  [15764] = {.lex_state = 28, .external_lex_state = 2},
  [15765] = {.lex_state = 249, .external_lex_state = 8},
  [15766] = {.lex_state = 136, .external_lex_state = 2},
  [15767] = {.lex_state = 28, .external_lex_state = 2},
  [15768] = {.lex_state = 11, .external_lex_state = 2},
  [15769] = {.lex_state = 28, .external_lex_state = 2},
  [15770] = {.lex_state = 28, .external_lex_state = 2},
  [15771] = {.lex_state = 249, .external_lex_state = 8},
  [15772] = {.lex_state = 28, .external_lex_state = 2},
  [15773] = {.lex_state = 28, .external_lex_state = 2},
  [15774] = {.lex_state = 28, .external_lex_state = 2},
  [15775] = {.lex_state = 136, .external_lex_state = 2},
  [15776] = {.lex_state = 18, .external_lex_state = 2},
  [15777] = {.lex_state = 249, .external_lex_state = 8},
  [15778] = {.lex_state = 28, .external_lex_state = 2},
  [15779] = {.lex_state = 28, .external_lex_state = 2},
  [15780] = {.lex_state = 249, .external_lex_state = 8},
  [15781] = {.lex_state = 28, .external_lex_state = 2},
  [15782] = {.lex_state = 11, .external_lex_state = 2},
  [15783] = {.lex_state = 249, .external_lex_state = 8},
  [15784] = {.lex_state = 136, .external_lex_state = 2},
  [15785] = {.lex_state = 136, .external_lex_state = 2},
  [15786] = {.lex_state = 28, .external_lex_state = 2},
  [15787] = {.lex_state = 136, .external_lex_state = 2},
  [15788] = {.lex_state = 28, .external_lex_state = 2},
  [15789] = {.lex_state = 243, .external_lex_state = 2},
  [15790] = {.lex_state = 243, .external_lex_state = 2},
  [15791] = {.lex_state = 28, .external_lex_state = 2},
  [15792] = {.lex_state = 420, .external_lex_state = 2},
  [15793] = {.lex_state = 249, .external_lex_state = 8},
  [15794] = {.lex_state = 243, .external_lex_state = 2},
  [15795] = {.lex_state = 18, .external_lex_state = 2},
  [15796] = {.lex_state = 18, .external_lex_state = 2},
  [15797] = {.lex_state = 243, .external_lex_state = 2},
  [15798] = {.lex_state = 11, .external_lex_state = 2},
  [15799] = {.lex_state = 426, .external_lex_state = 2},
  [15800] = {.lex_state = 28, .external_lex_state = 2},
  [15801] = {.lex_state = 28, .external_lex_state = 2},
  [15802] = {.lex_state = 420, .external_lex_state = 2},
  [15803] = {.lex_state = 28, .external_lex_state = 2},
  [15804] = {.lex_state = 249, .external_lex_state = 8},
  [15805] = {.lex_state = 28, .external_lex_state = 2},
  [15806] = {.lex_state = 11, .external_lex_state = 2},
  [15807] = {.lex_state = 243, .external_lex_state = 2},
  [15808] = {.lex_state = 426, .external_lex_state = 2},
  [15809] = {.lex_state = 18, .external_lex_state = 2},
  [15810] = {.lex_state = 18, .external_lex_state = 2},
  [15811] = {.lex_state = 11, .external_lex_state = 2},
  [15812] = {.lex_state = 18, .external_lex_state = 2},
  [15813] = {.lex_state = 136, .external_lex_state = 2},
  [15814] = {.lex_state = 18, .external_lex_state = 2},
  [15815] = {.lex_state = 28, .external_lex_state = 2},
  [15816] = {.lex_state = 18, .external_lex_state = 2},
  [15817] = {.lex_state = 136, .external_lex_state = 2},
  [15818] = {.lex_state = 136, .external_lex_state = 2},
  [15819] = {.lex_state = 28, .external_lex_state = 2},
  [15820] = {.lex_state = 426, .external_lex_state = 2},
  [15821] = {.lex_state = 28, .external_lex_state = 2},
  [15822] = {.lex_state = 37, .external_lex_state = 2},
  [15823] = {.lex_state = 136, .external_lex_state = 2},
  [15824] = {.lex_state = 18, .external_lex_state = 2},
  [15825] = {.lex_state = 18, .external_lex_state = 2},
  [15826] = {.lex_state = 18, .external_lex_state = 2},
  [15827] = {.lex_state = 426, .external_lex_state = 2},
  [15828] = {.lex_state = 136, .external_lex_state = 2},
  [15829] = {.lex_state = 18, .external_lex_state = 2},
  [15830] = {.lex_state = 37, .external_lex_state = 2},
  [15831] = {.lex_state = 11, .external_lex_state = 2},
  [15832] = {.lex_state = 28, .external_lex_state = 2},
  [15833] = {.lex_state = 18, .external_lex_state = 2},
  [15834] = {.lex_state = 136, .external_lex_state = 2},
  [15835] = {.lex_state = 243, .external_lex_state = 2},
  [15836] = {.lex_state = 135, .external_lex_state = 2},
  [15837] = {.lex_state = 11, .external_lex_state = 2},
  [15838] = {.lex_state = 420, .external_lex_state = 2},
  [15839] = {.lex_state = 28, .external_lex_state = 2},
  [15840] = {.lex_state = 18, .external_lex_state = 2},
  [15841] = {.lex_state = 18, .external_lex_state = 2},
  [15842] = {.lex_state = 426, .external_lex_state = 2},
  [15843] = {.lex_state = 136, .external_lex_state = 2},
  [15844] = {.lex_state = 28, .external_lex_state = 2},
  [15845] = {.lex_state = 420, .external_lex_state = 2},
  [15846] = {.lex_state = 28, .external_lex_state = 2},
  [15847] = {.lex_state = 420, .external_lex_state = 2},
  [15848] = {.lex_state = 11, .external_lex_state = 2},
  [15849] = {.lex_state = 37, .external_lex_state = 2},
  [15850] = {.lex_state = 136, .external_lex_state = 2},
  [15851] = {.lex_state = 136, .external_lex_state = 2},
  [15852] = {.lex_state = 37, .external_lex_state = 2},
  [15853] = {.lex_state = 136, .external_lex_state = 2},
  [15854] = {.lex_state = 136, .external_lex_state = 2},
  [15855] = {.lex_state = 136, .external_lex_state = 2},
  [15856] = {.lex_state = 420, .external_lex_state = 3},
  [15857] = {.lex_state = 243, .external_lex_state = 2},
  [15858] = {.lex_state = 18, .external_lex_state = 2},
  [15859] = {.lex_state = 28, .external_lex_state = 2},
  [15860] = {.lex_state = 18, .external_lex_state = 2},
  [15861] = {.lex_state = 420, .external_lex_state = 2},
  [15862] = {.lex_state = 28, .external_lex_state = 2},
  [15863] = {.lex_state = 136, .external_lex_state = 2},
  [15864] = {.lex_state = 426, .external_lex_state = 2},
  [15865] = {.lex_state = 28, .external_lex_state = 2},
  [15866] = {.lex_state = 135, .external_lex_state = 2},
  [15867] = {.lex_state = 28, .external_lex_state = 2},
  [15868] = {.lex_state = 11, .external_lex_state = 2},
  [15869] = {.lex_state = 420, .external_lex_state = 2},
  [15870] = {.lex_state = 28, .external_lex_state = 2},
  [15871] = {.lex_state = 28, .external_lex_state = 2},
  [15872] = {.lex_state = 28, .external_lex_state = 2},
  [15873] = {.lex_state = 420, .external_lex_state = 2},
  [15874] = {.lex_state = 136, .external_lex_state = 2},
  [15875] = {.lex_state = 18, .external_lex_state = 2},
  [15876] = {.lex_state = 136, .external_lex_state = 2},
  [15877] = {.lex_state = 28, .external_lex_state = 2},
  [15878] = {.lex_state = 37, .external_lex_state = 2},
  [15879] = {.lex_state = 136, .external_lex_state = 2},
  [15880] = {.lex_state = 249, .external_lex_state = 8},
  [15881] = {.lex_state = 420, .external_lex_state = 2},
  [15882] = {.lex_state = 18, .external_lex_state = 2},
  [15883] = {.lex_state = 420, .external_lex_state = 2},
  [15884] = {.lex_state = 136, .external_lex_state = 2},
  [15885] = {.lex_state = 420, .external_lex_state = 2},
  [15886] = {.lex_state = 135, .external_lex_state = 2},
  [15887] = {.lex_state = 249, .external_lex_state = 8},
  [15888] = {.lex_state = 28, .external_lex_state = 2},
  [15889] = {.lex_state = 12, .external_lex_state = 2},
  [15890] = {.lex_state = 136, .external_lex_state = 2},
  [15891] = {.lex_state = 37, .external_lex_state = 2},
  [15892] = {.lex_state = 18, .external_lex_state = 2},
  [15893] = {.lex_state = 12, .external_lex_state = 2},
  [15894] = {.lex_state = 420, .external_lex_state = 2},
  [15895] = {.lex_state = 18, .external_lex_state = 2},
  [15896] = {.lex_state = 28, .external_lex_state = 2},
  [15897] = {.lex_state = 18, .external_lex_state = 2},
  [15898] = {.lex_state = 11, .external_lex_state = 2},
  [15899] = {.lex_state = 136, .external_lex_state = 2},
  [15900] = {.lex_state = 136, .external_lex_state = 2},
  [15901] = {.lex_state = 420, .external_lex_state = 2},
  [15902] = {.lex_state = 11, .external_lex_state = 2},
  [15903] = {.lex_state = 28, .external_lex_state = 2},
  [15904] = {.lex_state = 136, .external_lex_state = 2},
  [15905] = {.lex_state = 243, .external_lex_state = 2},
  [15906] = {.lex_state = 136, .external_lex_state = 2},
  [15907] = {.lex_state = 28, .external_lex_state = 2},
  [15908] = {.lex_state = 11, .external_lex_state = 2},
  [15909] = {.lex_state = 136, .external_lex_state = 2},
  [15910] = {.lex_state = 426, .external_lex_state = 2},
  [15911] = {.lex_state = 11, .external_lex_state = 2},
  [15912] = {.lex_state = 12, .external_lex_state = 2},
  [15913] = {.lex_state = 135, .external_lex_state = 2},
  [15914] = {.lex_state = 18, .external_lex_state = 2},
  [15915] = {.lex_state = 18, .external_lex_state = 2},
  [15916] = {.lex_state = 28, .external_lex_state = 2},
  [15917] = {.lex_state = 420, .external_lex_state = 2},
  [15918] = {.lex_state = 420, .external_lex_state = 2},
  [15919] = {.lex_state = 28, .external_lex_state = 2},
  [15920] = {.lex_state = 249, .external_lex_state = 8},
  [15921] = {.lex_state = 28, .external_lex_state = 2},
  [15922] = {.lex_state = 249, .external_lex_state = 8},
  [15923] = {.lex_state = 11, .external_lex_state = 2},
  [15924] = {.lex_state = 420, .external_lex_state = 2},
  [15925] = {.lex_state = 28, .external_lex_state = 2},
  [15926] = {.lex_state = 420, .external_lex_state = 2},
  [15927] = {.lex_state = 136, .external_lex_state = 2},
  [15928] = {.lex_state = 28, .external_lex_state = 2},
  [15929] = {.lex_state = 135, .external_lex_state = 2},
  [15930] = {.lex_state = 18, .external_lex_state = 2},
  [15931] = {.lex_state = 28, .external_lex_state = 2},
  [15932] = {.lex_state = 18, .external_lex_state = 2},
  [15933] = {.lex_state = 28, .external_lex_state = 2},
  [15934] = {.lex_state = 28, .external_lex_state = 2},
  [15935] = {.lex_state = 136, .external_lex_state = 2},
  [15936] = {.lex_state = 426, .external_lex_state = 2},
  [15937] = {.lex_state = 420, .external_lex_state = 2},
  [15938] = {.lex_state = 136, .external_lex_state = 2},
  [15939] = {.lex_state = 28, .external_lex_state = 2},
  [15940] = {.lex_state = 18, .external_lex_state = 2},
  [15941] = {.lex_state = 28, .external_lex_state = 2},
  [15942] = {.lex_state = 18, .external_lex_state = 2},
  [15943] = {.lex_state = 11, .external_lex_state = 2},
  [15944] = {.lex_state = 420, .external_lex_state = 2},
  [15945] = {.lex_state = 249, .external_lex_state = 8},
  [15946] = {.lex_state = 28, .external_lex_state = 2},
  [15947] = {.lex_state = 28, .external_lex_state = 2},
  [15948] = {.lex_state = 28, .external_lex_state = 2},
  [15949] = {.lex_state = 136, .external_lex_state = 2},
  [15950] = {.lex_state = 28, .external_lex_state = 2},
  [15951] = {.lex_state = 28, .external_lex_state = 2},
  [15952] = {.lex_state = 420, .external_lex_state = 2},
  [15953] = {.lex_state = 28, .external_lex_state = 2},
  [15954] = {.lex_state = 243, .external_lex_state = 2},
  [15955] = {.lex_state = 28, .external_lex_state = 2},
  [15956] = {.lex_state = 136, .external_lex_state = 2},
  [15957] = {.lex_state = 426, .external_lex_state = 2},
  [15958] = {.lex_state = 11, .external_lex_state = 2},
  [15959] = {.lex_state = 28, .external_lex_state = 2},
  [15960] = {.lex_state = 136, .external_lex_state = 2},
  [15961] = {.lex_state = 18, .external_lex_state = 2},
  [15962] = {.lex_state = 18, .external_lex_state = 2},
  [15963] = {.lex_state = 136, .external_lex_state = 2},
  [15964] = {.lex_state = 18, .external_lex_state = 2},
  [15965] = {.lex_state = 136, .external_lex_state = 2},
  [15966] = {.lex_state = 136, .external_lex_state = 2},
  [15967] = {.lex_state = 18, .external_lex_state = 2},
  [15968] = {.lex_state = 28, .external_lex_state = 2},
  [15969] = {.lex_state = 136, .external_lex_state = 2},
  [15970] = {.lex_state = 426, .external_lex_state = 2},
  [15971] = {.lex_state = 420, .external_lex_state = 2},
  [15972] = {.lex_state = 135, .external_lex_state = 2},
  [15973] = {.lex_state = 28, .external_lex_state = 2},
  [15974] = {.lex_state = 136, .external_lex_state = 2},
  [15975] = {.lex_state = 11, .external_lex_state = 2},
  [15976] = {.lex_state = 11, .external_lex_state = 2},
  [15977] = {.lex_state = 420, .external_lex_state = 2},
  [15978] = {.lex_state = 243, .external_lex_state = 2},
  [15979] = {.lex_state = 28, .external_lex_state = 2},
  [15980] = {.lex_state = 11, .external_lex_state = 2},
  [15981] = {.lex_state = 28, .external_lex_state = 2},
  [15982] = {.lex_state = 243, .external_lex_state = 2},
  [15983] = {.lex_state = 18, .external_lex_state = 2},
  [15984] = {.lex_state = 11, .external_lex_state = 2},
  [15985] = {.lex_state = 249, .external_lex_state = 8},
  [15986] = {.lex_state = 28, .external_lex_state = 2},
  [15987] = {.lex_state = 28, .external_lex_state = 2},
  [15988] = {.lex_state = 18, .external_lex_state = 2},
  [15989] = {.lex_state = 18, .external_lex_state = 2},
  [15990] = {.lex_state = 136, .external_lex_state = 2},
  [15991] = {.lex_state = 28, .external_lex_state = 2},
  [15992] = {.lex_state = 426, .external_lex_state = 2},
  [15993] = {.lex_state = 136, .external_lex_state = 2},
  [15994] = {.lex_state = 37, .external_lex_state = 2},
  [15995] = {.lex_state = 136, .external_lex_state = 2},
  [15996] = {.lex_state = 420, .external_lex_state = 2},
  [15997] = {.lex_state = 136, .external_lex_state = 2},
  [15998] = {.lex_state = 37, .external_lex_state = 2},
  [15999] = {.lex_state = 136, .external_lex_state = 2},
  [16000] = {.lex_state = 136, .external_lex_state = 2},
  [16001] = {.lex_state = 17, .external_lex_state = 2},
  [16002] = {.lex_state = 28, .external_lex_state = 2},
  [16003] = {.lex_state = 28, .external_lex_state = 2},
  [16004] = {.lex_state = 420, .external_lex_state = 2},
  [16005] = {.lex_state = 135, .external_lex_state = 2},
  [16006] = {.lex_state = 420, .external_lex_state = 2},
  [16007] = {.lex_state = 18, .external_lex_state = 2},
  [16008] = {.lex_state = 12, .external_lex_state = 2},
  [16009] = {.lex_state = 18, .external_lex_state = 2},
  [16010] = {.lex_state = 37, .external_lex_state = 2},
  [16011] = {.lex_state = 426, .external_lex_state = 2},
  [16012] = {.lex_state = 28, .external_lex_state = 2},
  [16013] = {.lex_state = 249, .external_lex_state = 8},
  [16014] = {.lex_state = 136, .external_lex_state = 2},
  [16015] = {.lex_state = 28, .external_lex_state = 2},
  [16016] = {.lex_state = 136, .external_lex_state = 2},
  [16017] = {.lex_state = 136, .external_lex_state = 2},
  [16018] = {.lex_state = 136, .external_lex_state = 2},
  [16019] = {.lex_state = 136, .external_lex_state = 2},
  [16020] = {.lex_state = 11, .external_lex_state = 2},
  [16021] = {.lex_state = 18, .external_lex_state = 2},
  [16022] = {.lex_state = 11, .external_lex_state = 2},
  [16023] = {.lex_state = 18, .external_lex_state = 2},
  [16024] = {.lex_state = 11, .external_lex_state = 2},
  [16025] = {.lex_state = 136, .external_lex_state = 2},
  [16026] = {.lex_state = 420, .external_lex_state = 2},
  [16027] = {.lex_state = 135, .external_lex_state = 2},
  [16028] = {.lex_state = 136, .external_lex_state = 2},
  [16029] = {.lex_state = 420, .external_lex_state = 2},
  [16030] = {.lex_state = 18, .external_lex_state = 2},
  [16031] = {.lex_state = 136, .external_lex_state = 2},
  [16032] = {.lex_state = 28, .external_lex_state = 2},
  [16033] = {.lex_state = 420, .external_lex_state = 2},
  [16034] = {.lex_state = 28, .external_lex_state = 2},
  [16035] = {.lex_state = 420, .external_lex_state = 2},
  [16036] = {.lex_state = 18, .external_lex_state = 2},
  [16037] = {.lex_state = 136, .external_lex_state = 2},
  [16038] = {.lex_state = 136, .external_lex_state = 2},
  [16039] = {.lex_state = 420, .external_lex_state = 2},
  [16040] = {.lex_state = 28, .external_lex_state = 2},
  [16041] = {.lex_state = 136, .external_lex_state = 2},
  [16042] = {.lex_state = 11, .external_lex_state = 2},
  [16043] = {.lex_state = 426, .external_lex_state = 2},
  [16044] = {.lex_state = 136, .external_lex_state = 2},
  [16045] = {.lex_state = 136, .external_lex_state = 2},
  [16046] = {.lex_state = 420, .external_lex_state = 2},
  [16047] = {.lex_state = 420, .external_lex_state = 2},
  [16048] = {.lex_state = 28, .external_lex_state = 2},
  [16049] = {.lex_state = 28, .external_lex_state = 2},
  [16050] = {.lex_state = 11, .external_lex_state = 2},
  [16051] = {.lex_state = 136, .external_lex_state = 2},
  [16052] = {.lex_state = 420, .external_lex_state = 2},
  [16053] = {.lex_state = 420, .external_lex_state = 2},
  [16054] = {.lex_state = 28, .external_lex_state = 2},
  [16055] = {.lex_state = 18, .external_lex_state = 2},
  [16056] = {.lex_state = 136, .external_lex_state = 2},
  [16057] = {.lex_state = 136, .external_lex_state = 2},
  [16058] = {.lex_state = 136, .external_lex_state = 2},
  [16059] = {.lex_state = 426, .external_lex_state = 2},
  [16060] = {.lex_state = 28, .external_lex_state = 2},
  [16061] = {.lex_state = 28, .external_lex_state = 2},
  [16062] = {.lex_state = 11, .external_lex_state = 2},
  [16063] = {.lex_state = 420, .external_lex_state = 2},
  [16064] = {.lex_state = 249, .external_lex_state = 8},
  [16065] = {.lex_state = 420, .external_lex_state = 2},
  [16066] = {.lex_state = 249, .external_lex_state = 8},
  [16067] = {.lex_state = 37, .external_lex_state = 2},
  [16068] = {.lex_state = 28, .external_lex_state = 2},
  [16069] = {.lex_state = 28, .external_lex_state = 2},
  [16070] = {.lex_state = 136, .external_lex_state = 2},
  [16071] = {.lex_state = 420, .external_lex_state = 2},
  [16072] = {.lex_state = 28, .external_lex_state = 2},
  [16073] = {.lex_state = 11, .external_lex_state = 2},
  [16074] = {.lex_state = 243, .external_lex_state = 2},
  [16075] = {.lex_state = 11, .external_lex_state = 2},
  [16076] = {.lex_state = 420, .external_lex_state = 2},
  [16077] = {.lex_state = 18, .external_lex_state = 2},
  [16078] = {.lex_state = 28, .external_lex_state = 2},
  [16079] = {.lex_state = 28, .external_lex_state = 2},
  [16080] = {.lex_state = 18, .external_lex_state = 2},
  [16081] = {.lex_state = 249, .external_lex_state = 8},
  [16082] = {.lex_state = 136, .external_lex_state = 2},
  [16083] = {.lex_state = 11, .external_lex_state = 2},
  [16084] = {.lex_state = 136, .external_lex_state = 2},
  [16085] = {.lex_state = 420, .external_lex_state = 2},
  [16086] = {.lex_state = 28, .external_lex_state = 2},
  [16087] = {.lex_state = 18, .external_lex_state = 2},
  [16088] = {.lex_state = 18, .external_lex_state = 2},
  [16089] = {.lex_state = 37, .external_lex_state = 2},
  [16090] = {.lex_state = 37, .external_lex_state = 2},
  [16091] = {.lex_state = 135, .external_lex_state = 2},
  [16092] = {.lex_state = 136, .external_lex_state = 2},
  [16093] = {.lex_state = 28, .external_lex_state = 2},
  [16094] = {.lex_state = 18, .external_lex_state = 2},
  [16095] = {.lex_state = 28, .external_lex_state = 2},
  [16096] = {.lex_state = 28, .external_lex_state = 2},
  [16097] = {.lex_state = 136, .external_lex_state = 2},
  [16098] = {.lex_state = 28, .external_lex_state = 2},
  [16099] = {.lex_state = 11, .external_lex_state = 2},
  [16100] = {.lex_state = 28, .external_lex_state = 2},
  [16101] = {.lex_state = 28, .external_lex_state = 2},
  [16102] = {.lex_state = 136, .external_lex_state = 2},
  [16103] = {.lex_state = 420, .external_lex_state = 2},
  [16104] = {.lex_state = 420, .external_lex_state = 2},
  [16105] = {.lex_state = 136, .external_lex_state = 2},
  [16106] = {.lex_state = 28, .external_lex_state = 2},
  [16107] = {.lex_state = 28, .external_lex_state = 2},
  [16108] = {.lex_state = 28, .external_lex_state = 2},
  [16109] = {.lex_state = 243, .external_lex_state = 2},
  [16110] = {.lex_state = 11, .external_lex_state = 2},
  [16111] = {.lex_state = 18, .external_lex_state = 2},
  [16112] = {.lex_state = 37, .external_lex_state = 2},
  [16113] = {.lex_state = 18, .external_lex_state = 2},
  [16114] = {.lex_state = 426, .external_lex_state = 2},
  [16115] = {.lex_state = 18, .external_lex_state = 2},
  [16116] = {.lex_state = 28, .external_lex_state = 2},
  [16117] = {.lex_state = 136, .external_lex_state = 2},
  [16118] = {.lex_state = 18, .external_lex_state = 2},
  [16119] = {.lex_state = 420, .external_lex_state = 2},
  [16120] = {.lex_state = 28, .external_lex_state = 2},
  [16121] = {.lex_state = 28, .external_lex_state = 2},
  [16122] = {.lex_state = 28, .external_lex_state = 2},
  [16123] = {.lex_state = 420, .external_lex_state = 2},
  [16124] = {.lex_state = 243, .external_lex_state = 2},
  [16125] = {.lex_state = 249, .external_lex_state = 8},
  [16126] = {.lex_state = 136, .external_lex_state = 2},
  [16127] = {.lex_state = 249, .external_lex_state = 8},
  [16128] = {.lex_state = 28, .external_lex_state = 2},
  [16129] = {.lex_state = 426, .external_lex_state = 2},
  [16130] = {.lex_state = 136, .external_lex_state = 2},
  [16131] = {.lex_state = 37, .external_lex_state = 2},
  [16132] = {.lex_state = 28, .external_lex_state = 2},
  [16133] = {.lex_state = 18, .external_lex_state = 2},
  [16134] = {.lex_state = 28, .external_lex_state = 2},
  [16135] = {.lex_state = 136, .external_lex_state = 2},
  [16136] = {.lex_state = 18, .external_lex_state = 2},
  [16137] = {.lex_state = 420, .external_lex_state = 2},
  [16138] = {.lex_state = 28, .external_lex_state = 2},
  [16139] = {.lex_state = 249, .external_lex_state = 8},
  [16140] = {.lex_state = 18, .external_lex_state = 2},
  [16141] = {.lex_state = 420, .external_lex_state = 2},
  [16142] = {.lex_state = 426, .external_lex_state = 2},
  [16143] = {.lex_state = 11, .external_lex_state = 2},
  [16144] = {.lex_state = 249, .external_lex_state = 8},
  [16145] = {.lex_state = 37, .external_lex_state = 2},
  [16146] = {.lex_state = 18, .external_lex_state = 2},
  [16147] = {.lex_state = 136, .external_lex_state = 2},
  [16148] = {.lex_state = 28, .external_lex_state = 2},
  [16149] = {.lex_state = 135, .external_lex_state = 2},
  [16150] = {.lex_state = 136, .external_lex_state = 2},
  [16151] = {.lex_state = 37, .external_lex_state = 2},
  [16152] = {.lex_state = 136, .external_lex_state = 2},
  [16153] = {.lex_state = 18, .external_lex_state = 2},
  [16154] = {.lex_state = 243, .external_lex_state = 2},
  [16155] = {.lex_state = 136, .external_lex_state = 2},
  [16156] = {.lex_state = 136, .external_lex_state = 2},
  [16157] = {.lex_state = 28, .external_lex_state = 2},
  [16158] = {.lex_state = 37, .external_lex_state = 2},
  [16159] = {.lex_state = 28, .external_lex_state = 2},
  [16160] = {.lex_state = 136, .external_lex_state = 2},
  [16161] = {.lex_state = 11, .external_lex_state = 2},
  [16162] = {.lex_state = 136, .external_lex_state = 2},
  [16163] = {.lex_state = 11, .external_lex_state = 2},
  [16164] = {.lex_state = 18, .external_lex_state = 2},
  [16165] = {.lex_state = 135, .external_lex_state = 2},
  [16166] = {.lex_state = 135, .external_lex_state = 2},
  [16167] = {.lex_state = 136, .external_lex_state = 2},
  [16168] = {.lex_state = 136, .external_lex_state = 2},
  [16169] = {.lex_state = 243, .external_lex_state = 2},
  [16170] = {.lex_state = 249, .external_lex_state = 8},
  [16171] = {.lex_state = 28, .external_lex_state = 2},
  [16172] = {.lex_state = 11, .external_lex_state = 2},
  [16173] = {.lex_state = 18, .external_lex_state = 2},
  [16174] = {.lex_state = 37, .external_lex_state = 2},
  [16175] = {.lex_state = 135, .external_lex_state = 2},
  [16176] = {.lex_state = 136, .external_lex_state = 2},
  [16177] = {.lex_state = 136, .external_lex_state = 2},
  [16178] = {.lex_state = 28, .external_lex_state = 2},
  [16179] = {.lex_state = 28, .external_lex_state = 2},
  [16180] = {.lex_state = 28, .external_lex_state = 2},
  [16181] = {.lex_state = 426, .external_lex_state = 2},
  [16182] = {.lex_state = 420, .external_lex_state = 2},
  [16183] = {.lex_state = 249, .external_lex_state = 8},
  [16184] = {.lex_state = 136, .external_lex_state = 2},
  [16185] = {.lex_state = 420, .external_lex_state = 2},
  [16186] = {.lex_state = 420, .external_lex_state = 2},
  [16187] = {.lex_state = 420, .external_lex_state = 2},
  [16188] = {.lex_state = 28, .external_lex_state = 2},
  [16189] = {.lex_state = 11, .external_lex_state = 2},
  [16190] = {.lex_state = 28, .external_lex_state = 2},
  [16191] = {.lex_state = 420, .external_lex_state = 2},
  [16192] = {.lex_state = 420, .external_lex_state = 2},
  [16193] = {.lex_state = 420, .external_lex_state = 2},
  [16194] = {.lex_state = 136, .external_lex_state = 2},
  [16195] = {.lex_state = 11, .external_lex_state = 2},
  [16196] = {.lex_state = 136, .external_lex_state = 2},
  [16197] = {.lex_state = 136, .external_lex_state = 2},
  [16198] = {.lex_state = 136, .external_lex_state = 2},
  [16199] = {.lex_state = 136, .external_lex_state = 2},
  [16200] = {.lex_state = 37, .external_lex_state = 2},
  [16201] = {.lex_state = 28, .external_lex_state = 2},
  [16202] = {.lex_state = 135, .external_lex_state = 2},
  [16203] = {.lex_state = 420, .external_lex_state = 2},
  [16204] = {.lex_state = 136, .external_lex_state = 2},
  [16205] = {.lex_state = 28, .external_lex_state = 2},
  [16206] = {.lex_state = 28, .external_lex_state = 2},
  [16207] = {.lex_state = 18, .external_lex_state = 2},
  [16208] = {.lex_state = 18, .external_lex_state = 2},
  [16209] = {.lex_state = 426, .external_lex_state = 2},
  [16210] = {.lex_state = 136, .external_lex_state = 2},
  [16211] = {.lex_state = 28, .external_lex_state = 2},
  [16212] = {.lex_state = 18, .external_lex_state = 2},
  [16213] = {.lex_state = 135, .external_lex_state = 2},
  [16214] = {.lex_state = 420, .external_lex_state = 2},
  [16215] = {.lex_state = 426, .external_lex_state = 2},
  [16216] = {.lex_state = 28, .external_lex_state = 2},
  [16217] = {.lex_state = 136, .external_lex_state = 2},
  [16218] = {.lex_state = 28, .external_lex_state = 2},
  [16219] = {.lex_state = 18, .external_lex_state = 2},
  [16220] = {.lex_state = 28, .external_lex_state = 2},
  [16221] = {.lex_state = 28, .external_lex_state = 2},
  [16222] = {.lex_state = 28, .external_lex_state = 2},
  [16223] = {.lex_state = 136, .external_lex_state = 2},
  [16224] = {.lex_state = 426, .external_lex_state = 2},
  [16225] = {.lex_state = 18, .external_lex_state = 2},
  [16226] = {.lex_state = 135, .external_lex_state = 2},
  [16227] = {.lex_state = 28, .external_lex_state = 2},
  [16228] = {.lex_state = 136, .external_lex_state = 2},
  [16229] = {.lex_state = 243, .external_lex_state = 2},
  [16230] = {.lex_state = 18, .external_lex_state = 2},
  [16231] = {.lex_state = 136, .external_lex_state = 2},
  [16232] = {.lex_state = 18, .external_lex_state = 2},
  [16233] = {.lex_state = 249, .external_lex_state = 8},
  [16234] = {.lex_state = 18, .external_lex_state = 2},
  [16235] = {.lex_state = 7, .external_lex_state = 2},
  [16236] = {.lex_state = 420, .external_lex_state = 2},
  [16237] = {.lex_state = 28, .external_lex_state = 2},
  [16238] = {.lex_state = 18, .external_lex_state = 2},
  [16239] = {.lex_state = 18, .external_lex_state = 2},
  [16240] = {.lex_state = 136, .external_lex_state = 2},
  [16241] = {.lex_state = 136, .external_lex_state = 2},
  [16242] = {.lex_state = 28, .external_lex_state = 2},
  [16243] = {.lex_state = 28, .external_lex_state = 2},
  [16244] = {.lex_state = 28, .external_lex_state = 2},
  [16245] = {.lex_state = 19, .external_lex_state = 2},
  [16246] = {.lex_state = 18, .external_lex_state = 2},
  [16247] = {.lex_state = 18, .external_lex_state = 2},
  [16248] = {.lex_state = 426, .external_lex_state = 2},
  [16249] = {.lex_state = 28, .external_lex_state = 2},
  [16250] = {.lex_state = 243, .external_lex_state = 2},
  [16251] = {.lex_state = 37, .external_lex_state = 2},
  [16252] = {.lex_state = 420, .external_lex_state = 2},
  [16253] = {.lex_state = 426, .external_lex_state = 2},
  [16254] = {.lex_state = 420, .external_lex_state = 2},
  [16255] = {.lex_state = 420, .external_lex_state = 2},
  [16256] = {.lex_state = 420, .external_lex_state = 2},
  [16257] = {.lex_state = 136, .external_lex_state = 2},
  [16258] = {.lex_state = 136, .external_lex_state = 2},
  [16259] = {.lex_state = 420, .external_lex_state = 2},
  [16260] = {.lex_state = 249, .external_lex_state = 8},
  [16261] = {.lex_state = 37, .external_lex_state = 2},
  [16262] = {.lex_state = 28, .external_lex_state = 2},
  [16263] = {.lex_state = 18, .external_lex_state = 2},
  [16264] = {.lex_state = 18, .external_lex_state = 2},
  [16265] = {.lex_state = 136, .external_lex_state = 2},
  [16266] = {.lex_state = 136, .external_lex_state = 2},
  [16267] = {.lex_state = 420, .external_lex_state = 2},
  [16268] = {.lex_state = 135, .external_lex_state = 2},
  [16269] = {.lex_state = 135, .external_lex_state = 2},
  [16270] = {.lex_state = 28, .external_lex_state = 2},
  [16271] = {.lex_state = 135, .external_lex_state = 2},
  [16272] = {.lex_state = 28, .external_lex_state = 2},
  [16273] = {.lex_state = 28, .external_lex_state = 2},
  [16274] = {.lex_state = 136, .external_lex_state = 2},
  [16275] = {.lex_state = 420, .external_lex_state = 2},
  [16276] = {.lex_state = 18, .external_lex_state = 2},
  [16277] = {.lex_state = 18, .external_lex_state = 2},
  [16278] = {.lex_state = 28, .external_lex_state = 2},
  [16279] = {.lex_state = 136, .external_lex_state = 2},
  [16280] = {.lex_state = 420, .external_lex_state = 2},
  [16281] = {.lex_state = 420, .external_lex_state = 2},
  [16282] = {.lex_state = 426, .external_lex_state = 2},
  [16283] = {.lex_state = 28, .external_lex_state = 2},
  [16284] = {.lex_state = 426, .external_lex_state = 2},
  [16285] = {.lex_state = 136, .external_lex_state = 2},
  [16286] = {.lex_state = 28, .external_lex_state = 2},
  [16287] = {.lex_state = 420, .external_lex_state = 2},
  [16288] = {.lex_state = 136, .external_lex_state = 2},
  [16289] = {.lex_state = 28, .external_lex_state = 2},
  [16290] = {.lex_state = 136, .external_lex_state = 2},
  [16291] = {.lex_state = 135, .external_lex_state = 2},
  [16292] = {.lex_state = 426, .external_lex_state = 2},
  [16293] = {.lex_state = 18, .external_lex_state = 2},
  [16294] = {.lex_state = 420, .external_lex_state = 2},
  [16295] = {.lex_state = 18, .external_lex_state = 2},
  [16296] = {.lex_state = 136, .external_lex_state = 2},
  [16297] = {.lex_state = 135, .external_lex_state = 2},
  [16298] = {.lex_state = 420, .external_lex_state = 2},
  [16299] = {.lex_state = 136, .external_lex_state = 2},
  [16300] = {.lex_state = 37, .external_lex_state = 2},
  [16301] = {.lex_state = 136, .external_lex_state = 2},
  [16302] = {.lex_state = 37, .external_lex_state = 2},
  [16303] = {.lex_state = 37, .external_lex_state = 2},
  [16304] = {.lex_state = 28, .external_lex_state = 2},
  [16305] = {.lex_state = 28, .external_lex_state = 2},
  [16306] = {.lex_state = 18, .external_lex_state = 2},
  [16307] = {.lex_state = 135, .external_lex_state = 2},
  [16308] = {.lex_state = 18, .external_lex_state = 2},
  [16309] = {.lex_state = 11, .external_lex_state = 2},
  [16310] = {.lex_state = 136, .external_lex_state = 2},
  [16311] = {.lex_state = 136, .external_lex_state = 2},
  [16312] = {.lex_state = 136, .external_lex_state = 2},
  [16313] = {.lex_state = 28, .external_lex_state = 2},
  [16314] = {.lex_state = 136, .external_lex_state = 2},
  [16315] = {.lex_state = 11, .external_lex_state = 2},
  [16316] = {.lex_state = 28, .external_lex_state = 2},
  [16317] = {.lex_state = 249, .external_lex_state = 8},
  [16318] = {.lex_state = 136, .external_lex_state = 2},
  [16319] = {.lex_state = 11, .external_lex_state = 2},
  [16320] = {.lex_state = 243, .external_lex_state = 2},
  [16321] = {.lex_state = 28, .external_lex_state = 2},
  [16322] = {.lex_state = 28, .external_lex_state = 2},
  [16323] = {.lex_state = 249, .external_lex_state = 8},
  [16324] = {.lex_state = 28, .external_lex_state = 2},
  [16325] = {.lex_state = 136, .external_lex_state = 2},
  [16326] = {.lex_state = 11, .external_lex_state = 2},
  [16327] = {.lex_state = 135, .external_lex_state = 2},
  [16328] = {.lex_state = 420, .external_lex_state = 2},
  [16329] = {.lex_state = 136, .external_lex_state = 2},
  [16330] = {.lex_state = 420, .external_lex_state = 2},
  [16331] = {.lex_state = 37, .external_lex_state = 2},
  [16332] = {.lex_state = 420, .external_lex_state = 2},
  [16333] = {.lex_state = 11, .external_lex_state = 2},
  [16334] = {.lex_state = 136, .external_lex_state = 2},
  [16335] = {.lex_state = 136, .external_lex_state = 2},
  [16336] = {.lex_state = 136, .external_lex_state = 2},
  [16337] = {.lex_state = 420, .external_lex_state = 2},
  [16338] = {.lex_state = 11, .external_lex_state = 2},
  [16339] = {.lex_state = 11, .external_lex_state = 2},
  [16340] = {.lex_state = 420, .external_lex_state = 2},
  [16341] = {.lex_state = 28, .external_lex_state = 2},
  [16342] = {.lex_state = 135, .external_lex_state = 2},
  [16343] = {.lex_state = 136, .external_lex_state = 2},
  [16344] = {.lex_state = 426, .external_lex_state = 2},
  [16345] = {.lex_state = 136, .external_lex_state = 2},
  [16346] = {.lex_state = 136, .external_lex_state = 2},
  [16347] = {.lex_state = 136, .external_lex_state = 2},
  [16348] = {.lex_state = 136, .external_lex_state = 2},
  [16349] = {.lex_state = 136, .external_lex_state = 2},
  [16350] = {.lex_state = 135, .external_lex_state = 2},
  [16351] = {.lex_state = 136, .external_lex_state = 2},
  [16352] = {.lex_state = 249, .external_lex_state = 8},
  [16353] = {.lex_state = 136, .external_lex_state = 2},
  [16354] = {.lex_state = 136, .external_lex_state = 2},
  [16355] = {.lex_state = 136, .external_lex_state = 2},
  [16356] = {.lex_state = 136, .external_lex_state = 2},
  [16357] = {.lex_state = 28, .external_lex_state = 2},
  [16358] = {.lex_state = 243, .external_lex_state = 2},
  [16359] = {.lex_state = 249, .external_lex_state = 8},
  [16360] = {.lex_state = 37, .external_lex_state = 2},
  [16361] = {.lex_state = 136, .external_lex_state = 2},
  [16362] = {.lex_state = 136, .external_lex_state = 2},
  [16363] = {.lex_state = 28, .external_lex_state = 2},
  [16364] = {.lex_state = 28, .external_lex_state = 2},
  [16365] = {.lex_state = 12, .external_lex_state = 2},
  [16366] = {.lex_state = 28, .external_lex_state = 2},
  [16367] = {.lex_state = 18, .external_lex_state = 2},
  [16368] = {.lex_state = 11, .external_lex_state = 2},
  [16369] = {.lex_state = 28, .external_lex_state = 2},
  [16370] = {.lex_state = 249, .external_lex_state = 8},
  [16371] = {.lex_state = 18, .external_lex_state = 2},
  [16372] = {.lex_state = 18, .external_lex_state = 2},
  [16373] = {.lex_state = 243, .external_lex_state = 2},
  [16374] = {.lex_state = 136, .external_lex_state = 2},
  [16375] = {.lex_state = 420, .external_lex_state = 2},
  [16376] = {.lex_state = 28, .external_lex_state = 2},
  [16377] = {.lex_state = 420, .external_lex_state = 2},
  [16378] = {.lex_state = 136, .external_lex_state = 2},
  [16379] = {.lex_state = 136, .external_lex_state = 2},
  [16380] = {.lex_state = 420, .external_lex_state = 2},
  [16381] = {.lex_state = 11, .external_lex_state = 2},
  [16382] = {.lex_state = 420, .external_lex_state = 2},
  [16383] = {.lex_state = 136, .external_lex_state = 2},
  [16384] = {.lex_state = 420, .external_lex_state = 2},
  [16385] = {.lex_state = 136, .external_lex_state = 2},
  [16386] = {.lex_state = 28, .external_lex_state = 2},
  [16387] = {.lex_state = 135, .external_lex_state = 2},
  [16388] = {.lex_state = 28, .external_lex_state = 2},
  [16389] = {.lex_state = 18, .external_lex_state = 2},
  [16390] = {.lex_state = 18, .external_lex_state = 2},
  [16391] = {.lex_state = 426, .external_lex_state = 2},
  [16392] = {.lex_state = 28, .external_lex_state = 2},
  [16393] = {.lex_state = 28, .external_lex_state = 2},
  [16394] = {.lex_state = 28, .external_lex_state = 2},
  [16395] = {.lex_state = 420, .external_lex_state = 2},
  [16396] = {.lex_state = 18, .external_lex_state = 2},
  [16397] = {.lex_state = 11, .external_lex_state = 2},
  [16398] = {.lex_state = 11, .external_lex_state = 2},
  [16399] = {.lex_state = 18, .external_lex_state = 2},
  [16400] = {.lex_state = 243, .external_lex_state = 2},
  [16401] = {.lex_state = 420, .external_lex_state = 2},
  [16402] = {.lex_state = 28, .external_lex_state = 2},
  [16403] = {.lex_state = 28, .external_lex_state = 2},
  [16404] = {.lex_state = 136, .external_lex_state = 2},
  [16405] = {.lex_state = 12, .external_lex_state = 2},
  [16406] = {.lex_state = 136, .external_lex_state = 2},
  [16407] = {.lex_state = 28, .external_lex_state = 2},
  [16408] = {.lex_state = 136, .external_lex_state = 2},
  [16409] = {.lex_state = 426, .external_lex_state = 2},
  [16410] = {.lex_state = 18, .external_lex_state = 2},
  [16411] = {.lex_state = 18, .external_lex_state = 2},
  [16412] = {.lex_state = 136, .external_lex_state = 2},
  [16413] = {.lex_state = 135, .external_lex_state = 2},
  [16414] = {.lex_state = 37, .external_lex_state = 2},
  [16415] = {.lex_state = 37, .external_lex_state = 2},
  [16416] = {.lex_state = 136, .external_lex_state = 2},
  [16417] = {.lex_state = 136, .external_lex_state = 2},
  [16418] = {.lex_state = 136, .external_lex_state = 2},
  [16419] = {.lex_state = 28, .external_lex_state = 2},
  [16420] = {.lex_state = 28, .external_lex_state = 2},
  [16421] = {.lex_state = 135, .external_lex_state = 2},
  [16422] = {.lex_state = 18, .external_lex_state = 2},
  [16423] = {.lex_state = 18, .external_lex_state = 2},
  [16424] = {.lex_state = 136, .external_lex_state = 2},
  [16425] = {.lex_state = 135, .external_lex_state = 2},
  [16426] = {.lex_state = 426, .external_lex_state = 2},
  [16427] = {.lex_state = 18, .external_lex_state = 2},
  [16428] = {.lex_state = 28, .external_lex_state = 2},
  [16429] = {.lex_state = 136, .external_lex_state = 2},
  [16430] = {.lex_state = 249, .external_lex_state = 8},
  [16431] = {.lex_state = 136, .external_lex_state = 2},
  [16432] = {.lex_state = 37, .external_lex_state = 2},
  [16433] = {.lex_state = 136, .external_lex_state = 2},
  [16434] = {.lex_state = 136, .external_lex_state = 2},
  [16435] = {.lex_state = 136, .external_lex_state = 2},
  [16436] = {.lex_state = 136, .external_lex_state = 2},
  [16437] = {.lex_state = 243, .external_lex_state = 2},
  [16438] = {.lex_state = 243, .external_lex_state = 2},
  [16439] = {.lex_state = 135, .external_lex_state = 2},
  [16440] = {.lex_state = 420, .external_lex_state = 2},
  [16441] = {.lex_state = 136, .external_lex_state = 2},
  [16442] = {.lex_state = 28, .external_lex_state = 2},
  [16443] = {.lex_state = 420, .external_lex_state = 2},
  [16444] = {.lex_state = 136, .external_lex_state = 2},
  [16445] = {.lex_state = 37, .external_lex_state = 2},
  [16446] = {.lex_state = 28, .external_lex_state = 2},
  [16447] = {.lex_state = 28, .external_lex_state = 2},
  [16448] = {.lex_state = 28, .external_lex_state = 2},
  [16449] = {.lex_state = 18, .external_lex_state = 2},
  [16450] = {.lex_state = 136, .external_lex_state = 2},
  [16451] = {.lex_state = 28, .external_lex_state = 2},
  [16452] = {.lex_state = 420, .external_lex_state = 2},
  [16453] = {.lex_state = 136, .external_lex_state = 2},
  [16454] = {.lex_state = 135, .external_lex_state = 2},
  [16455] = {.lex_state = 249, .external_lex_state = 8},
  [16456] = {.lex_state = 136, .external_lex_state = 2},
  [16457] = {.lex_state = 28, .external_lex_state = 2},
  [16458] = {.lex_state = 426, .external_lex_state = 2},
  [16459] = {.lex_state = 28, .external_lex_state = 2},
  [16460] = {.lex_state = 11, .external_lex_state = 2},
  [16461] = {.lex_state = 136, .external_lex_state = 2},
  [16462] = {.lex_state = 420, .external_lex_state = 2},
  [16463] = {.lex_state = 11, .external_lex_state = 2},
  [16464] = {.lex_state = 136, .external_lex_state = 2},
  [16465] = {.lex_state = 136, .external_lex_state = 2},
  [16466] = {.lex_state = 28, .external_lex_state = 2},
  [16467] = {.lex_state = 18, .external_lex_state = 2},
  [16468] = {.lex_state = 420, .external_lex_state = 2},
  [16469] = {.lex_state = 136, .external_lex_state = 2},
  [16470] = {.lex_state = 136, .external_lex_state = 2},
  [16471] = {.lex_state = 135, .external_lex_state = 2},
  [16472] = {.lex_state = 18, .external_lex_state = 2},
  [16473] = {.lex_state = 249, .external_lex_state = 8},
  [16474] = {.lex_state = 11, .external_lex_state = 2},
  [16475] = {.lex_state = 136, .external_lex_state = 2},
  [16476] = {.lex_state = 420, .external_lex_state = 2},
  [16477] = {.lex_state = 136, .external_lex_state = 2},
  [16478] = {.lex_state = 12, .external_lex_state = 2},
  [16479] = {.lex_state = 28, .external_lex_state = 2},
  [16480] = {.lex_state = 11, .external_lex_state = 2},
  [16481] = {.lex_state = 136, .external_lex_state = 2},
  [16482] = {.lex_state = 28, .external_lex_state = 2},
  [16483] = {.lex_state = 136, .external_lex_state = 2},
  [16484] = {.lex_state = 136, .external_lex_state = 2},
  [16485] = {.lex_state = 37, .external_lex_state = 2},
  [16486] = {.lex_state = 135, .external_lex_state = 2},
  [16487] = {.lex_state = 249, .external_lex_state = 8},
  [16488] = {.lex_state = 18, .external_lex_state = 2},
  [16489] = {.lex_state = 11, .external_lex_state = 2},
  [16490] = {.lex_state = 28, .external_lex_state = 2},
  [16491] = {.lex_state = 12, .external_lex_state = 2},
  [16492] = {.lex_state = 420, .external_lex_state = 2},
  [16493] = {.lex_state = 420, .external_lex_state = 2},
  [16494] = {.lex_state = 28, .external_lex_state = 2},
  [16495] = {.lex_state = 28, .external_lex_state = 2},
  [16496] = {.lex_state = 28, .external_lex_state = 2},
  [16497] = {.lex_state = 28, .external_lex_state = 2},
  [16498] = {.lex_state = 28, .external_lex_state = 2},
  [16499] = {.lex_state = 18, .external_lex_state = 2},
  [16500] = {.lex_state = 420, .external_lex_state = 2},
  [16501] = {.lex_state = 420, .external_lex_state = 2},
  [16502] = {.lex_state = 18, .external_lex_state = 2},
  [16503] = {.lex_state = 37, .external_lex_state = 2},
  [16504] = {.lex_state = 11, .external_lex_state = 2},
  [16505] = {.lex_state = 136, .external_lex_state = 2},
  [16506] = {.lex_state = 136, .external_lex_state = 2},
  [16507] = {.lex_state = 420, .external_lex_state = 8},
  [16508] = {.lex_state = 420, .external_lex_state = 2},
  [16509] = {.lex_state = 28, .external_lex_state = 2},
  [16510] = {.lex_state = 28, .external_lex_state = 2},
  [16511] = {.lex_state = 420, .external_lex_state = 2},
  [16512] = {.lex_state = 420, .external_lex_state = 2},
  [16513] = {.lex_state = 420, .external_lex_state = 2},
  [16514] = {.lex_state = 420, .external_lex_state = 2},
  [16515] = {.lex_state = 18, .external_lex_state = 2},
  [16516] = {.lex_state = 420, .external_lex_state = 2},
  [16517] = {.lex_state = 18, .external_lex_state = 2},
  [16518] = {.lex_state = 420, .external_lex_state = 2},
  [16519] = {.lex_state = 420, .external_lex_state = 2},
  [16520] = {.lex_state = 420, .external_lex_state = 2},
  [16521] = {.lex_state = 28, .external_lex_state = 2},
  [16522] = {.lex_state = 420, .external_lex_state = 2},
  [16523] = {.lex_state = 8, .external_lex_state = 2},
  [16524] = {.lex_state = 420, .external_lex_state = 2},
  [16525] = {.lex_state = 28, .external_lex_state = 2},
  [16526] = {.lex_state = 18, .external_lex_state = 2},
  [16527] = {.lex_state = 28, .external_lex_state = 2},
  [16528] = {.lex_state = 420, .external_lex_state = 2},
  [16529] = {.lex_state = 28, .external_lex_state = 2},
  [16530] = {.lex_state = 28, .external_lex_state = 2},
  [16531] = {.lex_state = 18, .external_lex_state = 2},
  [16532] = {.lex_state = 420, .external_lex_state = 2},
  [16533] = {.lex_state = 420, .external_lex_state = 2},
  [16534] = {.lex_state = 28, .external_lex_state = 2},
  [16535] = {.lex_state = 420, .external_lex_state = 2},
  [16536] = {.lex_state = 420, .external_lex_state = 2},
  [16537] = {.lex_state = 420, .external_lex_state = 2},
  [16538] = {.lex_state = 28, .external_lex_state = 2},
  [16539] = {.lex_state = 28, .external_lex_state = 2},
  [16540] = {.lex_state = 420, .external_lex_state = 2},
  [16541] = {.lex_state = 18, .external_lex_state = 2},
  [16542] = {.lex_state = 28, .external_lex_state = 2},
  [16543] = {.lex_state = 420, .external_lex_state = 2},
  [16544] = {.lex_state = 136, .external_lex_state = 2},
  [16545] = {.lex_state = 136, .external_lex_state = 2},
  [16546] = {.lex_state = 136, .external_lex_state = 2},
  [16547] = {.lex_state = 28, .external_lex_state = 2},
  [16548] = {.lex_state = 8, .external_lex_state = 2},
  [16549] = {.lex_state = 420, .external_lex_state = 2},
  [16550] = {.lex_state = 420, .external_lex_state = 2},
  [16551] = {.lex_state = 420, .external_lex_state = 8},
  [16552] = {.lex_state = 420, .external_lex_state = 2},
  [16553] = {.lex_state = 18, .external_lex_state = 2},
  [16554] = {.lex_state = 420, .external_lex_state = 2},
  [16555] = {.lex_state = 420, .external_lex_state = 2},
  [16556] = {.lex_state = 28, .external_lex_state = 2},
  [16557] = {.lex_state = 420, .external_lex_state = 2},
  [16558] = {.lex_state = 420, .external_lex_state = 8},
  [16559] = {.lex_state = 420, .external_lex_state = 2},
  [16560] = {.lex_state = 420, .external_lex_state = 8},
  [16561] = {.lex_state = 28, .external_lex_state = 2},
  [16562] = {.lex_state = 420, .external_lex_state = 8},
  [16563] = {.lex_state = 28, .external_lex_state = 2},
  [16564] = {.lex_state = 420, .external_lex_state = 8},
  [16565] = {.lex_state = 28, .external_lex_state = 2},
  [16566] = {.lex_state = 28, .external_lex_state = 2},
  [16567] = {.lex_state = 420, .external_lex_state = 2},
  [16568] = {.lex_state = 420, .external_lex_state = 2},
  [16569] = {.lex_state = 420, .external_lex_state = 2},
  [16570] = {.lex_state = 420, .external_lex_state = 2},
  [16571] = {.lex_state = 420, .external_lex_state = 2},
  [16572] = {.lex_state = 18, .external_lex_state = 2},
  [16573] = {.lex_state = 420, .external_lex_state = 2},
  [16574] = {.lex_state = 420, .external_lex_state = 2},
  [16575] = {.lex_state = 420, .external_lex_state = 2},
  [16576] = {.lex_state = 18, .external_lex_state = 2},
  [16577] = {.lex_state = 420, .external_lex_state = 2},
  [16578] = {.lex_state = 18, .external_lex_state = 2},
  [16579] = {.lex_state = 420, .external_lex_state = 2},
  [16580] = {.lex_state = 420, .external_lex_state = 8},
  [16581] = {.lex_state = 420, .external_lex_state = 2},
  [16582] = {.lex_state = 420, .external_lex_state = 2},
  [16583] = {.lex_state = 420, .external_lex_state = 2},
  [16584] = {.lex_state = 420, .external_lex_state = 2},
  [16585] = {.lex_state = 420, .external_lex_state = 2},
  [16586] = {.lex_state = 420, .external_lex_state = 2},
  [16587] = {.lex_state = 28, .external_lex_state = 2},
  [16588] = {.lex_state = 420, .external_lex_state = 8},
  [16589] = {.lex_state = 136, .external_lex_state = 2},
  [16590] = {.lex_state = 136, .external_lex_state = 2},
  [16591] = {.lex_state = 420, .external_lex_state = 2},
  [16592] = {.lex_state = 28, .external_lex_state = 2},
  [16593] = {.lex_state = 420, .external_lex_state = 2},
  [16594] = {.lex_state = 28, .external_lex_state = 2},
  [16595] = {.lex_state = 420, .external_lex_state = 2},
  [16596] = {.lex_state = 420, .external_lex_state = 2},
  [16597] = {.lex_state = 28, .external_lex_state = 2},
  [16598] = {.lex_state = 136, .external_lex_state = 2},
  [16599] = {.lex_state = 18, .external_lex_state = 2},
  [16600] = {.lex_state = 18, .external_lex_state = 2},
  [16601] = {.lex_state = 18, .external_lex_state = 2},
  [16602] = {.lex_state = 37, .external_lex_state = 2},
  [16603] = {.lex_state = 28, .external_lex_state = 2},
  [16604] = {.lex_state = 28, .external_lex_state = 2},
  [16605] = {.lex_state = 136, .external_lex_state = 2},
  [16606] = {.lex_state = 28, .external_lex_state = 2},
  [16607] = {.lex_state = 420, .external_lex_state = 2},
  [16608] = {.lex_state = 11, .external_lex_state = 2},
  [16609] = {.lex_state = 136, .external_lex_state = 2},
  [16610] = {.lex_state = 420, .external_lex_state = 2},
  [16611] = {.lex_state = 18, .external_lex_state = 2},
  [16612] = {.lex_state = 420, .external_lex_state = 2},
  [16613] = {.lex_state = 136, .external_lex_state = 2},
  [16614] = {.lex_state = 18, .external_lex_state = 2},
  [16615] = {.lex_state = 420, .external_lex_state = 2},
  [16616] = {.lex_state = 420, .external_lex_state = 2},
  [16617] = {.lex_state = 136, .external_lex_state = 2},
  [16618] = {.lex_state = 136, .external_lex_state = 2},
  [16619] = {.lex_state = 136, .external_lex_state = 2},
  [16620] = {.lex_state = 18, .external_lex_state = 2},
  [16621] = {.lex_state = 18, .external_lex_state = 2},
  [16622] = {.lex_state = 136, .external_lex_state = 2},
  [16623] = {.lex_state = 136, .external_lex_state = 2},
  [16624] = {.lex_state = 136, .external_lex_state = 2},
  [16625] = {.lex_state = 8, .external_lex_state = 2},
  [16626] = {.lex_state = 136, .external_lex_state = 2},
  [16627] = {.lex_state = 28, .external_lex_state = 2},
  [16628] = {.lex_state = 28, .external_lex_state = 2},
  [16629] = {.lex_state = 420, .external_lex_state = 2},
  [16630] = {.lex_state = 18, .external_lex_state = 2},
  [16631] = {.lex_state = 37, .external_lex_state = 2},
  [16632] = {.lex_state = 420, .external_lex_state = 2},
  [16633] = {.lex_state = 11, .external_lex_state = 2},
  [16634] = {.lex_state = 136, .external_lex_state = 2},
  [16635] = {.lex_state = 136, .external_lex_state = 2},
  [16636] = {.lex_state = 18, .external_lex_state = 2},
  [16637] = {.lex_state = 420, .external_lex_state = 2},
  [16638] = {.lex_state = 420, .external_lex_state = 2},
  [16639] = {.lex_state = 420, .external_lex_state = 2},
  [16640] = {.lex_state = 136, .external_lex_state = 2},
  [16641] = {.lex_state = 136, .external_lex_state = 2},
  [16642] = {.lex_state = 420, .external_lex_state = 2},
  [16643] = {.lex_state = 18, .external_lex_state = 2},
  [16644] = {.lex_state = 18, .external_lex_state = 2},
  [16645] = {.lex_state = 420, .external_lex_state = 2},
  [16646] = {.lex_state = 12, .external_lex_state = 2},
  [16647] = {.lex_state = 12, .external_lex_state = 2},
  [16648] = {.lex_state = 12, .external_lex_state = 2},
  [16649] = {.lex_state = 420, .external_lex_state = 2},
  [16650] = {.lex_state = 12, .external_lex_state = 2},
  [16651] = {.lex_state = 12, .external_lex_state = 2},
  [16652] = {.lex_state = 420, .external_lex_state = 2},
  [16653] = {.lex_state = 12, .external_lex_state = 2},
  [16654] = {.lex_state = 12, .external_lex_state = 2},
  [16655] = {.lex_state = 18, .external_lex_state = 2},
  [16656] = {.lex_state = 12, .external_lex_state = 2},
  [16657] = {.lex_state = 420, .external_lex_state = 2},
  [16658] = {.lex_state = 8, .external_lex_state = 2},
  [16659] = {.lex_state = 28, .external_lex_state = 2},
  [16660] = {.lex_state = 28, .external_lex_state = 2},
  [16661] = {.lex_state = 28, .external_lex_state = 2},
  [16662] = {.lex_state = 28, .external_lex_state = 2},
  [16663] = {.lex_state = 28, .external_lex_state = 2},
  [16664] = {.lex_state = 28, .external_lex_state = 2},
  [16665] = {.lex_state = 420, .external_lex_state = 2},
  [16666] = {.lex_state = 420, .external_lex_state = 2},
  [16667] = {.lex_state = 420, .external_lex_state = 2},
  [16668] = {.lex_state = 28, .external_lex_state = 2},
  [16669] = {.lex_state = 18, .external_lex_state = 2},
  [16670] = {.lex_state = 18, .external_lex_state = 2},
  [16671] = {.lex_state = 420, .external_lex_state = 2},
  [16672] = {.lex_state = 18, .external_lex_state = 2},
  [16673] = {.lex_state = 420, .external_lex_state = 2},
  [16674] = {.lex_state = 420, .external_lex_state = 2},
  [16675] = {.lex_state = 420, .external_lex_state = 2},
  [16676] = {.lex_state = 28, .external_lex_state = 2},
  [16677] = {.lex_state = 420, .external_lex_state = 2},
  [16678] = {.lex_state = 18, .external_lex_state = 2},
  [16679] = {.lex_state = 28, .external_lex_state = 2},
  [16680] = {.lex_state = 28, .external_lex_state = 2},
  [16681] = {.lex_state = 18, .external_lex_state = 2},
  [16682] = {.lex_state = 18, .external_lex_state = 2},
  [16683] = {.lex_state = 18, .external_lex_state = 2},
  [16684] = {.lex_state = 18, .external_lex_state = 2},
  [16685] = {.lex_state = 18, .external_lex_state = 2},
  [16686] = {.lex_state = 18, .external_lex_state = 2},
  [16687] = {.lex_state = 136, .external_lex_state = 2},
  [16688] = {.lex_state = 18, .external_lex_state = 2},
  [16689] = {.lex_state = 136, .external_lex_state = 2},
  [16690] = {.lex_state = 136, .external_lex_state = 2},
  [16691] = {.lex_state = 420, .external_lex_state = 2},
  [16692] = {.lex_state = 28, .external_lex_state = 2},
  [16693] = {.lex_state = 18, .external_lex_state = 2},
  [16694] = {.lex_state = 18, .external_lex_state = 2},
  [16695] = {.lex_state = 420, .external_lex_state = 2},
  [16696] = {.lex_state = 18, .external_lex_state = 2},
  [16697] = {.lex_state = 420, .external_lex_state = 2},
  [16698] = {.lex_state = 18, .external_lex_state = 2},
  [16699] = {.lex_state = 136, .external_lex_state = 2},
  [16700] = {.lex_state = 28, .external_lex_state = 2},
  [16701] = {.lex_state = 28, .external_lex_state = 2},
  [16702] = {.lex_state = 28, .external_lex_state = 2},
  [16703] = {.lex_state = 28, .external_lex_state = 2},
  [16704] = {.lex_state = 420, .external_lex_state = 2},
  [16705] = {.lex_state = 28, .external_lex_state = 2},
  [16706] = {.lex_state = 420, .external_lex_state = 2},
  [16707] = {.lex_state = 18, .external_lex_state = 2},
  [16708] = {.lex_state = 420, .external_lex_state = 2},
  [16709] = {.lex_state = 18, .external_lex_state = 2},
  [16710] = {.lex_state = 28, .external_lex_state = 2},
  [16711] = {.lex_state = 8, .external_lex_state = 2},
  [16712] = {.lex_state = 18, .external_lex_state = 2},
  [16713] = {.lex_state = 420, .external_lex_state = 2},
  [16714] = {.lex_state = 18, .external_lex_state = 2},
  [16715] = {.lex_state = 420, .external_lex_state = 2},
  [16716] = {.lex_state = 420, .external_lex_state = 2},
  [16717] = {.lex_state = 420, .external_lex_state = 2},
  [16718] = {.lex_state = 28, .external_lex_state = 2},
  [16719] = {.lex_state = 28, .external_lex_state = 2},
  [16720] = {.lex_state = 18, .external_lex_state = 2},
  [16721] = {.lex_state = 28, .external_lex_state = 2},
  [16722] = {.lex_state = 18, .external_lex_state = 2},
  [16723] = {.lex_state = 18, .external_lex_state = 2},
  [16724] = {.lex_state = 420, .external_lex_state = 2},
  [16725] = {.lex_state = 18, .external_lex_state = 2},
  [16726] = {.lex_state = 18, .external_lex_state = 2},
  [16727] = {.lex_state = 136, .external_lex_state = 2},
  [16728] = {.lex_state = 136, .external_lex_state = 2},
  [16729] = {.lex_state = 18, .external_lex_state = 2},
  [16730] = {.lex_state = 136, .external_lex_state = 2},
  [16731] = {.lex_state = 136, .external_lex_state = 2},
  [16732] = {.lex_state = 28, .external_lex_state = 2},
  [16733] = {.lex_state = 420, .external_lex_state = 2},
  [16734] = {.lex_state = 18, .external_lex_state = 2},
  [16735] = {.lex_state = 18, .external_lex_state = 2},
  [16736] = {.lex_state = 420, .external_lex_state = 2},
  [16737] = {.lex_state = 18, .external_lex_state = 2},
  [16738] = {.lex_state = 420, .external_lex_state = 2},
  [16739] = {.lex_state = 28, .external_lex_state = 2},
  [16740] = {.lex_state = 8, .external_lex_state = 2},
  [16741] = {.lex_state = 28, .external_lex_state = 2},
  [16742] = {.lex_state = 28, .external_lex_state = 2},
  [16743] = {.lex_state = 28, .external_lex_state = 2},
  [16744] = {.lex_state = 18, .external_lex_state = 2},
  [16745] = {.lex_state = 420, .external_lex_state = 2},
  [16746] = {.lex_state = 420, .external_lex_state = 2},
  [16747] = {.lex_state = 420, .external_lex_state = 2},
  [16748] = {.lex_state = 28, .external_lex_state = 2},
  [16749] = {.lex_state = 28, .external_lex_state = 2},
  [16750] = {.lex_state = 18, .external_lex_state = 2},
  [16751] = {.lex_state = 18, .external_lex_state = 2},
  [16752] = {.lex_state = 18, .external_lex_state = 2},
  [16753] = {.lex_state = 420, .external_lex_state = 2},
  [16754] = {.lex_state = 420, .external_lex_state = 2},
  [16755] = {.lex_state = 18, .external_lex_state = 2},
  [16756] = {.lex_state = 420, .external_lex_state = 2},
  [16757] = {.lex_state = 420, .external_lex_state = 2},
  [16758] = {.lex_state = 420, .external_lex_state = 2},
  [16759] = {.lex_state = 28, .external_lex_state = 2},
  [16760] = {.lex_state = 28, .external_lex_state = 2},
  [16761] = {.lex_state = 18, .external_lex_state = 2},
  [16762] = {.lex_state = 18, .external_lex_state = 2},
  [16763] = {.lex_state = 420, .external_lex_state = 8},
  [16764] = {.lex_state = 18, .external_lex_state = 2},
  [16765] = {.lex_state = 136, .external_lex_state = 2},
  [16766] = {.lex_state = 28, .external_lex_state = 2},
  [16767] = {.lex_state = 136, .external_lex_state = 2},
  [16768] = {.lex_state = 18, .external_lex_state = 2},
  [16769] = {.lex_state = 18, .external_lex_state = 2},
  [16770] = {.lex_state = 420, .external_lex_state = 8},
  [16771] = {.lex_state = 18, .external_lex_state = 2},
  [16772] = {.lex_state = 136, .external_lex_state = 2},
  [16773] = {.lex_state = 136, .external_lex_state = 2},
  [16774] = {.lex_state = 420, .external_lex_state = 2},
  [16775] = {.lex_state = 18, .external_lex_state = 2},
  [16776] = {.lex_state = 28, .external_lex_state = 2},
  [16777] = {.lex_state = 420, .external_lex_state = 2},
  [16778] = {.lex_state = 420, .external_lex_state = 2},
  [16779] = {.lex_state = 420, .external_lex_state = 2},
  [16780] = {.lex_state = 18, .external_lex_state = 2},
  [16781] = {.lex_state = 18, .external_lex_state = 2},
  [16782] = {.lex_state = 28, .external_lex_state = 2},
  [16783] = {.lex_state = 28, .external_lex_state = 2},
  [16784] = {.lex_state = 28, .external_lex_state = 2},
  [16785] = {.lex_state = 28, .external_lex_state = 2},
  [16786] = {.lex_state = 18, .external_lex_state = 2},
  [16787] = {.lex_state = 420, .external_lex_state = 2},
  [16788] = {.lex_state = 420, .external_lex_state = 2},
  [16789] = {.lex_state = 18, .external_lex_state = 2},
  [16790] = {.lex_state = 420, .external_lex_state = 2},
  [16791] = {.lex_state = 28, .external_lex_state = 2},
  [16792] = {.lex_state = 18, .external_lex_state = 2},
  [16793] = {.lex_state = 420, .external_lex_state = 2},
  [16794] = {.lex_state = 18, .external_lex_state = 2},
  [16795] = {.lex_state = 28, .external_lex_state = 2},
  [16796] = {.lex_state = 28, .external_lex_state = 2},
  [16797] = {.lex_state = 420, .external_lex_state = 2},
  [16798] = {.lex_state = 136, .external_lex_state = 2},
  [16799] = {.lex_state = 136, .external_lex_state = 2},
  [16800] = {.lex_state = 136, .external_lex_state = 2},
  [16801] = {.lex_state = 28, .external_lex_state = 2},
  [16802] = {.lex_state = 18, .external_lex_state = 2},
  [16803] = {.lex_state = 18, .external_lex_state = 2},
  [16804] = {.lex_state = 28, .external_lex_state = 2},
  [16805] = {.lex_state = 420, .external_lex_state = 2},
  [16806] = {.lex_state = 18, .external_lex_state = 2},
  [16807] = {.lex_state = 18, .external_lex_state = 2},
  [16808] = {.lex_state = 28, .external_lex_state = 2},
  [16809] = {.lex_state = 136, .external_lex_state = 2},
  [16810] = {.lex_state = 18, .external_lex_state = 2},
  [16811] = {.lex_state = 18, .external_lex_state = 2},
  [16812] = {.lex_state = 136, .external_lex_state = 2},
  [16813] = {.lex_state = 420, .external_lex_state = 2},
  [16814] = {.lex_state = 18, .external_lex_state = 2},
  [16815] = {.lex_state = 136, .external_lex_state = 2},
  [16816] = {.lex_state = 420, .external_lex_state = 2},
  [16817] = {.lex_state = 18, .external_lex_state = 2},
  [16818] = {.lex_state = 420, .external_lex_state = 2},
  [16819] = {.lex_state = 420, .external_lex_state = 2},
  [16820] = {.lex_state = 420, .external_lex_state = 2},
  [16821] = {.lex_state = 18, .external_lex_state = 2},
  [16822] = {.lex_state = 28, .external_lex_state = 2},
  [16823] = {.lex_state = 28, .external_lex_state = 2},
  [16824] = {.lex_state = 18, .external_lex_state = 2},
  [16825] = {.lex_state = 28, .external_lex_state = 2},
  [16826] = {.lex_state = 18, .external_lex_state = 2},
  [16827] = {.lex_state = 28, .external_lex_state = 2},
  [16828] = {.lex_state = 420, .external_lex_state = 2},
  [16829] = {.lex_state = 420, .external_lex_state = 2},
  [16830] = {.lex_state = 420, .external_lex_state = 2},
  [16831] = {.lex_state = 28, .external_lex_state = 2},
  [16832] = {.lex_state = 420, .external_lex_state = 2},
  [16833] = {.lex_state = 18, .external_lex_state = 2},
  [16834] = {.lex_state = 420, .external_lex_state = 2},
  [16835] = {.lex_state = 420, .external_lex_state = 2},
  [16836] = {.lex_state = 28, .external_lex_state = 2},
  [16837] = {.lex_state = 28, .external_lex_state = 2},
  [16838] = {.lex_state = 28, .external_lex_state = 2},
  [16839] = {.lex_state = 28, .external_lex_state = 2},
  [16840] = {.lex_state = 18, .external_lex_state = 2},
  [16841] = {.lex_state = 18, .external_lex_state = 2},
  [16842] = {.lex_state = 420, .external_lex_state = 2},
  [16843] = {.lex_state = 18, .external_lex_state = 2},
  [16844] = {.lex_state = 18, .external_lex_state = 2},
  [16845] = {.lex_state = 136, .external_lex_state = 2},
  [16846] = {.lex_state = 136, .external_lex_state = 2},
  [16847] = {.lex_state = 136, .external_lex_state = 2},
  [16848] = {.lex_state = 136, .external_lex_state = 2},
  [16849] = {.lex_state = 18, .external_lex_state = 2},
  [16850] = {.lex_state = 420, .external_lex_state = 2},
  [16851] = {.lex_state = 420, .external_lex_state = 2},
  [16852] = {.lex_state = 28, .external_lex_state = 2},
  [16853] = {.lex_state = 28, .external_lex_state = 2},
  [16854] = {.lex_state = 18, .external_lex_state = 2},
  [16855] = {.lex_state = 28, .external_lex_state = 2},
  [16856] = {.lex_state = 18, .external_lex_state = 2},
  [16857] = {.lex_state = 28, .external_lex_state = 2},
  [16858] = {.lex_state = 28, .external_lex_state = 2},
  [16859] = {.lex_state = 420, .external_lex_state = 2},
  [16860] = {.lex_state = 420, .external_lex_state = 2},
  [16861] = {.lex_state = 420, .external_lex_state = 2},
  [16862] = {.lex_state = 28, .external_lex_state = 2},
  [16863] = {.lex_state = 11, .external_lex_state = 2},
  [16864] = {.lex_state = 420, .external_lex_state = 2},
  [16865] = {.lex_state = 28, .external_lex_state = 2},
  [16866] = {.lex_state = 18, .external_lex_state = 2},
  [16867] = {.lex_state = 18, .external_lex_state = 2},
  [16868] = {.lex_state = 420, .external_lex_state = 2},
  [16869] = {.lex_state = 18, .external_lex_state = 2},
  [16870] = {.lex_state = 28, .external_lex_state = 2},
  [16871] = {.lex_state = 28, .external_lex_state = 2},
  [16872] = {.lex_state = 11, .external_lex_state = 2},
  [16873] = {.lex_state = 18, .external_lex_state = 2},
  [16874] = {.lex_state = 136, .external_lex_state = 2},
  [16875] = {.lex_state = 136, .external_lex_state = 2},
  [16876] = {.lex_state = 136, .external_lex_state = 2},
  [16877] = {.lex_state = 136, .external_lex_state = 2},
  [16878] = {.lex_state = 18, .external_lex_state = 2},
  [16879] = {.lex_state = 28, .external_lex_state = 2},
  [16880] = {.lex_state = 420, .external_lex_state = 2},
  [16881] = {.lex_state = 18, .external_lex_state = 2},
  [16882] = {.lex_state = 28, .external_lex_state = 2},
  [16883] = {.lex_state = 18, .external_lex_state = 2},
  [16884] = {.lex_state = 28, .external_lex_state = 2},
  [16885] = {.lex_state = 28, .external_lex_state = 2},
  [16886] = {.lex_state = 28, .external_lex_state = 2},
  [16887] = {.lex_state = 28, .external_lex_state = 2},
  [16888] = {.lex_state = 420, .external_lex_state = 2},
  [16889] = {.lex_state = 420, .external_lex_state = 2},
  [16890] = {.lex_state = 420, .external_lex_state = 2},
  [16891] = {.lex_state = 11, .external_lex_state = 2},
  [16892] = {.lex_state = 28, .external_lex_state = 2},
  [16893] = {.lex_state = 11, .external_lex_state = 2},
  [16894] = {.lex_state = 420, .external_lex_state = 2},
  [16895] = {.lex_state = 18, .external_lex_state = 2},
  [16896] = {.lex_state = 420, .external_lex_state = 2},
  [16897] = {.lex_state = 28, .external_lex_state = 2},
  [16898] = {.lex_state = 28, .external_lex_state = 2},
  [16899] = {.lex_state = 28, .external_lex_state = 2},
  [16900] = {.lex_state = 420, .external_lex_state = 2},
  [16901] = {.lex_state = 18, .external_lex_state = 2},
  [16902] = {.lex_state = 420, .external_lex_state = 2},
  [16903] = {.lex_state = 28, .external_lex_state = 2},
  [16904] = {.lex_state = 136, .external_lex_state = 2},
  [16905] = {.lex_state = 136, .external_lex_state = 2},
  [16906] = {.lex_state = 18, .external_lex_state = 2},
  [16907] = {.lex_state = 420, .external_lex_state = 2},
  [16908] = {.lex_state = 18, .external_lex_state = 2},
  [16909] = {.lex_state = 28, .external_lex_state = 2},
  [16910] = {.lex_state = 28, .external_lex_state = 2},
  [16911] = {.lex_state = 18, .external_lex_state = 2},
  [16912] = {.lex_state = 28, .external_lex_state = 2},
  [16913] = {.lex_state = 420, .external_lex_state = 2},
  [16914] = {.lex_state = 420, .external_lex_state = 2},
  [16915] = {.lex_state = 420, .external_lex_state = 2},
  [16916] = {.lex_state = 28, .external_lex_state = 2},
  [16917] = {.lex_state = 420, .external_lex_state = 2},
  [16918] = {.lex_state = 18, .external_lex_state = 2},
  [16919] = {.lex_state = 420, .external_lex_state = 2},
  [16920] = {.lex_state = 28, .external_lex_state = 2},
  [16921] = {.lex_state = 28, .external_lex_state = 2},
  [16922] = {.lex_state = 11, .external_lex_state = 2},
  [16923] = {.lex_state = 28, .external_lex_state = 2},
  [16924] = {.lex_state = 11, .external_lex_state = 2},
  [16925] = {.lex_state = 420, .external_lex_state = 2},
  [16926] = {.lex_state = 18, .external_lex_state = 2},
  [16927] = {.lex_state = 28, .external_lex_state = 2},
  [16928] = {.lex_state = 18, .external_lex_state = 2},
  [16929] = {.lex_state = 420, .external_lex_state = 2},
  [16930] = {.lex_state = 28, .external_lex_state = 2},
  [16931] = {.lex_state = 28, .external_lex_state = 2},
  [16932] = {.lex_state = 28, .external_lex_state = 2},
  [16933] = {.lex_state = 420, .external_lex_state = 8},
  [16934] = {.lex_state = 420, .external_lex_state = 2},
  [16935] = {.lex_state = 420, .external_lex_state = 8},
  [16936] = {.lex_state = 28, .external_lex_state = 2},
  [16937] = {.lex_state = 420, .external_lex_state = 2},
  [16938] = {.lex_state = 18, .external_lex_state = 2},
  [16939] = {.lex_state = 28, .external_lex_state = 2},
  [16940] = {.lex_state = 420, .external_lex_state = 2},
  [16941] = {.lex_state = 420, .external_lex_state = 2},
  [16942] = {.lex_state = 420, .external_lex_state = 2},
  [16943] = {.lex_state = 28, .external_lex_state = 2},
  [16944] = {.lex_state = 18, .external_lex_state = 2},
  [16945] = {.lex_state = 420, .external_lex_state = 2},
  [16946] = {.lex_state = 28, .external_lex_state = 2},
  [16947] = {.lex_state = 420, .external_lex_state = 8},
  [16948] = {.lex_state = 420, .external_lex_state = 2},
  [16949] = {.lex_state = 18, .external_lex_state = 2},
  [16950] = {.lex_state = 420, .external_lex_state = 8},
  [16951] = {.lex_state = 420, .external_lex_state = 8},
  [16952] = {.lex_state = 18, .external_lex_state = 2},
  [16953] = {.lex_state = 420, .external_lex_state = 8},
  [16954] = {.lex_state = 28, .external_lex_state = 2},
  [16955] = {.lex_state = 420, .external_lex_state = 8},
  [16956] = {.lex_state = 28, .external_lex_state = 2},
  [16957] = {.lex_state = 28, .external_lex_state = 2},
  [16958] = {.lex_state = 136, .external_lex_state = 2},
  [16959] = {.lex_state = 136, .external_lex_state = 2},
  [16960] = {.lex_state = 136, .external_lex_state = 2},
  [16961] = {.lex_state = 18, .external_lex_state = 2},
  [16962] = {.lex_state = 420, .external_lex_state = 8},
  [16963] = {.lex_state = 420, .external_lex_state = 8},
  [16964] = {.lex_state = 28, .external_lex_state = 2},
  [16965] = {.lex_state = 420, .external_lex_state = 8},
  [16966] = {.lex_state = 28, .external_lex_state = 2},
  [16967] = {.lex_state = 420, .external_lex_state = 8},
  [16968] = {.lex_state = 420, .external_lex_state = 8},
  [16969] = {.lex_state = 420, .external_lex_state = 8},
  [16970] = {.lex_state = 420, .external_lex_state = 2},
  [16971] = {.lex_state = 420, .external_lex_state = 8},
  [16972] = {.lex_state = 28, .external_lex_state = 2},
  [16973] = {.lex_state = 420, .external_lex_state = 2},
  [16974] = {.lex_state = 420, .external_lex_state = 8},
  [16975] = {.lex_state = 420, .external_lex_state = 2},
  [16976] = {.lex_state = 420, .external_lex_state = 2},
  [16977] = {.lex_state = 420, .external_lex_state = 8},
  [16978] = {.lex_state = 420, .external_lex_state = 8},
  [16979] = {.lex_state = 28, .external_lex_state = 2},
  [16980] = {.lex_state = 420, .external_lex_state = 8},
  [16981] = {.lex_state = 420, .external_lex_state = 8},
  [16982] = {.lex_state = 420, .external_lex_state = 8},
  [16983] = {.lex_state = 420, .external_lex_state = 2},
  [16984] = {.lex_state = 18, .external_lex_state = 2},
  [16985] = {.lex_state = 420, .external_lex_state = 8},
  [16986] = {.lex_state = 420, .external_lex_state = 2},
  [16987] = {.lex_state = 420, .external_lex_state = 8},
  [16988] = {.lex_state = 420, .external_lex_state = 2},
  [16989] = {.lex_state = 420, .external_lex_state = 8},
  [16990] = {.lex_state = 28, .external_lex_state = 2},
  [16991] = {.lex_state = 420, .external_lex_state = 8},
  [16992] = {.lex_state = 420, .external_lex_state = 8},
  [16993] = {.lex_state = 28, .external_lex_state = 2},
  [16994] = {.lex_state = 136, .external_lex_state = 2},
  [16995] = {.lex_state = 136, .external_lex_state = 2},
  [16996] = {.lex_state = 28, .external_lex_state = 2},
  [16997] = {.lex_state = 136, .external_lex_state = 2},
  [16998] = {.lex_state = 18, .external_lex_state = 2},
  [16999] = {.lex_state = 420, .external_lex_state = 8},
  [17000] = {.lex_state = 136, .external_lex_state = 2},
  [17001] = {.lex_state = 136, .external_lex_state = 2},
  [17002] = {.lex_state = 136, .external_lex_state = 2},
  [17003] = {.lex_state = 420, .external_lex_state = 8},
  [17004] = {.lex_state = 18, .external_lex_state = 2},
  [17005] = {.lex_state = 18, .external_lex_state = 2},
  [17006] = {.lex_state = 136, .external_lex_state = 2},
  [17007] = {.lex_state = 136, .external_lex_state = 2},
  [17008] = {.lex_state = 136, .external_lex_state = 2},
  [17009] = {.lex_state = 420, .external_lex_state = 8},
  [17010] = {.lex_state = 136, .external_lex_state = 2},
  [17011] = {.lex_state = 136, .external_lex_state = 2},
  [17012] = {.lex_state = 136, .external_lex_state = 2},
  [17013] = {.lex_state = 28, .external_lex_state = 2},
  [17014] = {.lex_state = 420, .external_lex_state = 8},
  [17015] = {.lex_state = 420, .external_lex_state = 2},
  [17016] = {.lex_state = 136, .external_lex_state = 2},
  [17017] = {.lex_state = 136, .external_lex_state = 2},
  [17018] = {.lex_state = 136, .external_lex_state = 2},
  [17019] = {.lex_state = 420, .external_lex_state = 8},
  [17020] = {.lex_state = 136, .external_lex_state = 2},
  [17021] = {.lex_state = 136, .external_lex_state = 2},
  [17022] = {.lex_state = 136, .external_lex_state = 2},
  [17023] = {.lex_state = 28, .external_lex_state = 2},
  [17024] = {.lex_state = 420, .external_lex_state = 8},
  [17025] = {.lex_state = 136, .external_lex_state = 2},
  [17026] = {.lex_state = 136, .external_lex_state = 2},
  [17027] = {.lex_state = 136, .external_lex_state = 2},
  [17028] = {.lex_state = 420, .external_lex_state = 8},
  [17029] = {.lex_state = 18, .external_lex_state = 2},
  [17030] = {.lex_state = 136, .external_lex_state = 2},
  [17031] = {.lex_state = 28, .external_lex_state = 2},
  [17032] = {.lex_state = 136, .external_lex_state = 2},
  [17033] = {.lex_state = 18, .external_lex_state = 2},
  [17034] = {.lex_state = 136, .external_lex_state = 2},
  [17035] = {.lex_state = 420, .external_lex_state = 8},
  [17036] = {.lex_state = 420, .external_lex_state = 2},
  [17037] = {.lex_state = 420, .external_lex_state = 2},
  [17038] = {.lex_state = 28, .external_lex_state = 2},
  [17039] = {.lex_state = 136, .external_lex_state = 2},
  [17040] = {.lex_state = 18, .external_lex_state = 2},
  [17041] = {.lex_state = 136, .external_lex_state = 2},
  [17042] = {.lex_state = 136, .external_lex_state = 2},
  [17043] = {.lex_state = 420, .external_lex_state = 8},
  [17044] = {.lex_state = 28, .external_lex_state = 2},
  [17045] = {.lex_state = 136, .external_lex_state = 2},
  [17046] = {.lex_state = 136, .external_lex_state = 2},
  [17047] = {.lex_state = 136, .external_lex_state = 2},
  [17048] = {.lex_state = 420, .external_lex_state = 8},
  [17049] = {.lex_state = 136, .external_lex_state = 2},
  [17050] = {.lex_state = 136, .external_lex_state = 2},
  [17051] = {.lex_state = 136, .external_lex_state = 2},
  [17052] = {.lex_state = 420, .external_lex_state = 8},
  [17053] = {.lex_state = 136, .external_lex_state = 2},
  [17054] = {.lex_state = 420, .external_lex_state = 2},
  [17055] = {.lex_state = 136, .external_lex_state = 2},
  [17056] = {.lex_state = 136, .external_lex_state = 2},
  [17057] = {.lex_state = 420, .external_lex_state = 8},
  [17058] = {.lex_state = 420, .external_lex_state = 2},
  [17059] = {.lex_state = 420, .external_lex_state = 2},
  [17060] = {.lex_state = 420, .external_lex_state = 2},
  [17061] = {.lex_state = 136, .external_lex_state = 2},
  [17062] = {.lex_state = 136, .external_lex_state = 2},
  [17063] = {.lex_state = 136, .external_lex_state = 2},
  [17064] = {.lex_state = 420, .external_lex_state = 8},
  [17065] = {.lex_state = 28, .external_lex_state = 2},
  [17066] = {.lex_state = 136, .external_lex_state = 2},
  [17067] = {.lex_state = 420, .external_lex_state = 8},
  [17068] = {.lex_state = 136, .external_lex_state = 2},
  [17069] = {.lex_state = 420, .external_lex_state = 8},
  [17070] = {.lex_state = 136, .external_lex_state = 2},
  [17071] = {.lex_state = 420, .external_lex_state = 8},
  [17072] = {.lex_state = 28, .external_lex_state = 2},
  [17073] = {.lex_state = 420, .external_lex_state = 2},
  [17074] = {.lex_state = 18, .external_lex_state = 2},
  [17075] = {.lex_state = 420, .external_lex_state = 2},
  [17076] = {.lex_state = 28, .external_lex_state = 2},
  [17077] = {.lex_state = 28, .external_lex_state = 2},
  [17078] = {.lex_state = 28, .external_lex_state = 2},
  [17079] = {.lex_state = 420, .external_lex_state = 2},
  [17080] = {.lex_state = 136, .external_lex_state = 2},
  [17081] = {.lex_state = 18, .external_lex_state = 2},
  [17082] = {.lex_state = 136, .external_lex_state = 2},
  [17083] = {.lex_state = 136, .external_lex_state = 2},
  [17084] = {.lex_state = 28, .external_lex_state = 2},
  [17085] = {.lex_state = 18, .external_lex_state = 2},
  [17086] = {.lex_state = 420, .external_lex_state = 8},
  [17087] = {.lex_state = 18, .external_lex_state = 2},
  [17088] = {.lex_state = 136, .external_lex_state = 2},
  [17089] = {.lex_state = 136, .external_lex_state = 2},
  [17090] = {.lex_state = 136, .external_lex_state = 2},
  [17091] = {.lex_state = 136, .external_lex_state = 2},
  [17092] = {.lex_state = 136, .external_lex_state = 2},
  [17093] = {.lex_state = 136, .external_lex_state = 2},
  [17094] = {.lex_state = 18, .external_lex_state = 2},
  [17095] = {.lex_state = 28, .external_lex_state = 2},
  [17096] = {.lex_state = 420, .external_lex_state = 2},
  [17097] = {.lex_state = 28, .external_lex_state = 2},
  [17098] = {.lex_state = 28, .external_lex_state = 2},
  [17099] = {.lex_state = 28, .external_lex_state = 2},
  [17100] = {.lex_state = 420, .external_lex_state = 8},
  [17101] = {.lex_state = 420, .external_lex_state = 2},
  [17102] = {.lex_state = 136, .external_lex_state = 2},
  [17103] = {.lex_state = 136, .external_lex_state = 2},
  [17104] = {.lex_state = 420, .external_lex_state = 2},
  [17105] = {.lex_state = 136, .external_lex_state = 2},
  [17106] = {.lex_state = 28, .external_lex_state = 2},
  [17107] = {.lex_state = 28, .external_lex_state = 2},
  [17108] = {.lex_state = 420, .external_lex_state = 2},
  [17109] = {.lex_state = 420, .external_lex_state = 8},
  [17110] = {.lex_state = 420, .external_lex_state = 2},
  [17111] = {.lex_state = 18, .external_lex_state = 2},
  [17112] = {.lex_state = 28, .external_lex_state = 2},
  [17113] = {.lex_state = 28, .external_lex_state = 2},
  [17114] = {.lex_state = 136, .external_lex_state = 2},
  [17115] = {.lex_state = 136, .external_lex_state = 2},
  [17116] = {.lex_state = 136, .external_lex_state = 2},
  [17117] = {.lex_state = 18, .external_lex_state = 2},
  [17118] = {.lex_state = 420, .external_lex_state = 2},
  [17119] = {.lex_state = 420, .external_lex_state = 8},
  [17120] = {.lex_state = 18, .external_lex_state = 2},
  [17121] = {.lex_state = 420, .external_lex_state = 2},
  [17122] = {.lex_state = 28, .external_lex_state = 2},
  [17123] = {.lex_state = 136, .external_lex_state = 2},
  [17124] = {.lex_state = 136, .external_lex_state = 2},
  [17125] = {.lex_state = 136, .external_lex_state = 2},
  [17126] = {.lex_state = 28, .external_lex_state = 2},
  [17127] = {.lex_state = 420, .external_lex_state = 8},
  [17128] = {.lex_state = 28, .external_lex_state = 2},
  [17129] = {.lex_state = 420, .external_lex_state = 2},
  [17130] = {.lex_state = 18, .external_lex_state = 2},
  [17131] = {.lex_state = 420, .external_lex_state = 2},
  [17132] = {.lex_state = 28, .external_lex_state = 2},
  [17133] = {.lex_state = 420, .external_lex_state = 2},
  [17134] = {.lex_state = 136, .external_lex_state = 2},
  [17135] = {.lex_state = 136, .external_lex_state = 2},
  [17136] = {.lex_state = 136, .external_lex_state = 2},
  [17137] = {.lex_state = 18, .external_lex_state = 2},
  [17138] = {.lex_state = 420, .external_lex_state = 2},
  [17139] = {.lex_state = 18, .external_lex_state = 2},
  [17140] = {.lex_state = 28, .external_lex_state = 2},
  [17141] = {.lex_state = 420, .external_lex_state = 8},
  [17142] = {.lex_state = 28, .external_lex_state = 2},
  [17143] = {.lex_state = 420, .external_lex_state = 2},
  [17144] = {.lex_state = 28, .external_lex_state = 2},
  [17145] = {.lex_state = 18, .external_lex_state = 2},
  [17146] = {.lex_state = 420, .external_lex_state = 2},
  [17147] = {.lex_state = 28, .external_lex_state = 2},
  [17148] = {.lex_state = 18, .external_lex_state = 2},
  [17149] = {.lex_state = 420, .external_lex_state = 2},
  [17150] = {.lex_state = 136, .external_lex_state = 2},
  [17151] = {.lex_state = 136, .external_lex_state = 2},
  [17152] = {.lex_state = 136, .external_lex_state = 2},
  [17153] = {.lex_state = 18, .external_lex_state = 2},
  [17154] = {.lex_state = 28, .external_lex_state = 2},
  [17155] = {.lex_state = 420, .external_lex_state = 2},
  [17156] = {.lex_state = 28, .external_lex_state = 2},
  [17157] = {.lex_state = 420, .external_lex_state = 8},
  [17158] = {.lex_state = 28, .external_lex_state = 2},
  [17159] = {.lex_state = 28, .external_lex_state = 2},
  [17160] = {.lex_state = 420, .external_lex_state = 2},
  [17161] = {.lex_state = 420, .external_lex_state = 2},
  [17162] = {.lex_state = 420, .external_lex_state = 2},
  [17163] = {.lex_state = 136, .external_lex_state = 2},
  [17164] = {.lex_state = 136, .external_lex_state = 2},
  [17165] = {.lex_state = 420, .external_lex_state = 2},
  [17166] = {.lex_state = 136, .external_lex_state = 2},
  [17167] = {.lex_state = 28, .external_lex_state = 2},
  [17168] = {.lex_state = 420, .external_lex_state = 8},
  [17169] = {.lex_state = 420, .external_lex_state = 2},
  [17170] = {.lex_state = 18, .external_lex_state = 2},
  [17171] = {.lex_state = 28, .external_lex_state = 2},
  [17172] = {.lex_state = 420, .external_lex_state = 2},
  [17173] = {.lex_state = 420, .external_lex_state = 8},
  [17174] = {.lex_state = 28, .external_lex_state = 2},
  [17175] = {.lex_state = 420, .external_lex_state = 8},
  [17176] = {.lex_state = 136, .external_lex_state = 2},
  [17177] = {.lex_state = 136, .external_lex_state = 2},
  [17178] = {.lex_state = 136, .external_lex_state = 2},
  [17179] = {.lex_state = 18, .external_lex_state = 2},
  [17180] = {.lex_state = 420, .external_lex_state = 8},
  [17181] = {.lex_state = 18, .external_lex_state = 2},
  [17182] = {.lex_state = 420, .external_lex_state = 2},
  [17183] = {.lex_state = 420, .external_lex_state = 2},
  [17184] = {.lex_state = 28, .external_lex_state = 2},
  [17185] = {.lex_state = 28, .external_lex_state = 2},
  [17186] = {.lex_state = 28, .external_lex_state = 2},
  [17187] = {.lex_state = 18, .external_lex_state = 2},
  [17188] = {.lex_state = 420, .external_lex_state = 2},
  [17189] = {.lex_state = 136, .external_lex_state = 2},
  [17190] = {.lex_state = 136, .external_lex_state = 2},
  [17191] = {.lex_state = 136, .external_lex_state = 2},
  [17192] = {.lex_state = 420, .external_lex_state = 2},
  [17193] = {.lex_state = 136, .external_lex_state = 2},
  [17194] = {.lex_state = 136, .external_lex_state = 2},
  [17195] = {.lex_state = 136, .external_lex_state = 2},
  [17196] = {.lex_state = 420, .external_lex_state = 2},
  [17197] = {.lex_state = 420, .external_lex_state = 8},
  [17198] = {.lex_state = 28, .external_lex_state = 2},
  [17199] = {.lex_state = 28, .external_lex_state = 2},
  [17200] = {.lex_state = 28, .external_lex_state = 2},
  [17201] = {.lex_state = 18, .external_lex_state = 2},
  [17202] = {.lex_state = 28, .external_lex_state = 2},
  [17203] = {.lex_state = 28, .external_lex_state = 2},
  [17204] = {.lex_state = 420, .external_lex_state = 2},
  [17205] = {.lex_state = 420, .external_lex_state = 2},
  [17206] = {.lex_state = 420, .external_lex_state = 2},
  [17207] = {.lex_state = 420, .external_lex_state = 2},
  [17208] = {.lex_state = 136, .external_lex_state = 2},
  [17209] = {.lex_state = 136, .external_lex_state = 2},
  [17210] = {.lex_state = 136, .external_lex_state = 2},
  [17211] = {.lex_state = 28, .external_lex_state = 2},
  [17212] = {.lex_state = 18, .external_lex_state = 2},
  [17213] = {.lex_state = 420, .external_lex_state = 8},
  [17214] = {.lex_state = 18, .external_lex_state = 2},
  [17215] = {.lex_state = 420, .external_lex_state = 2},
  [17216] = {.lex_state = 420, .external_lex_state = 2},
  [17217] = {.lex_state = 28, .external_lex_state = 2},
  [17218] = {.lex_state = 28, .external_lex_state = 2},
  [17219] = {.lex_state = 420, .external_lex_state = 2},
  [17220] = {.lex_state = 28, .external_lex_state = 2},
  [17221] = {.lex_state = 136, .external_lex_state = 2},
  [17222] = {.lex_state = 136, .external_lex_state = 2},
  [17223] = {.lex_state = 136, .external_lex_state = 2},
  [17224] = {.lex_state = 420, .external_lex_state = 2},
  [17225] = {.lex_state = 420, .external_lex_state = 8},
  [17226] = {.lex_state = 28, .external_lex_state = 2},
  [17227] = {.lex_state = 28, .external_lex_state = 2},
  [17228] = {.lex_state = 28, .external_lex_state = 2},
  [17229] = {.lex_state = 420, .external_lex_state = 2},
  [17230] = {.lex_state = 420, .external_lex_state = 2},
  [17231] = {.lex_state = 18, .external_lex_state = 2},
  [17232] = {.lex_state = 420, .external_lex_state = 2},
  [17233] = {.lex_state = 18, .external_lex_state = 2},
  [17234] = {.lex_state = 420, .external_lex_state = 2},
  [17235] = {.lex_state = 28, .external_lex_state = 2},
  [17236] = {.lex_state = 136, .external_lex_state = 2},
  [17237] = {.lex_state = 136, .external_lex_state = 2},
  [17238] = {.lex_state = 136, .external_lex_state = 2},
  [17239] = {.lex_state = 18, .external_lex_state = 2},
  [17240] = {.lex_state = 28, .external_lex_state = 2},
  [17241] = {.lex_state = 420, .external_lex_state = 8},
  [17242] = {.lex_state = 18, .external_lex_state = 2},
  [17243] = {.lex_state = 420, .external_lex_state = 2},
  [17244] = {.lex_state = 18, .external_lex_state = 2},
  [17245] = {.lex_state = 420, .external_lex_state = 2},
  [17246] = {.lex_state = 420, .external_lex_state = 2},
  [17247] = {.lex_state = 28, .external_lex_state = 2},
  [17248] = {.lex_state = 136, .external_lex_state = 2},
  [17249] = {.lex_state = 420, .external_lex_state = 2},
  [17250] = {.lex_state = 28, .external_lex_state = 2},
  [17251] = {.lex_state = 136, .external_lex_state = 2},
  [17252] = {.lex_state = 136, .external_lex_state = 2},
  [17253] = {.lex_state = 420, .external_lex_state = 2},
  [17254] = {.lex_state = 28, .external_lex_state = 2},
  [17255] = {.lex_state = 420, .external_lex_state = 2},
  [17256] = {.lex_state = 28, .external_lex_state = 2},
  [17257] = {.lex_state = 420, .external_lex_state = 8},
  [17258] = {.lex_state = 420, .external_lex_state = 8},
  [17259] = {.lex_state = 420, .external_lex_state = 8},
  [17260] = {.lex_state = 420, .external_lex_state = 2},
  [17261] = {.lex_state = 28, .external_lex_state = 2},
  [17262] = {.lex_state = 420, .external_lex_state = 2},
  [17263] = {.lex_state = 420, .external_lex_state = 2},
  [17264] = {.lex_state = 28, .external_lex_state = 2},
  [17265] = {.lex_state = 420, .external_lex_state = 2},
  [17266] = {.lex_state = 420, .external_lex_state = 2},
  [17267] = {.lex_state = 420, .external_lex_state = 2},
  [17268] = {.lex_state = 18, .external_lex_state = 2},
  [17269] = {.lex_state = 136, .external_lex_state = 2},
  [17270] = {.lex_state = 136, .external_lex_state = 2},
  [17271] = {.lex_state = 136, .external_lex_state = 2},
  [17272] = {.lex_state = 28, .external_lex_state = 2},
  [17273] = {.lex_state = 420, .external_lex_state = 8},
  [17274] = {.lex_state = 28, .external_lex_state = 2},
  [17275] = {.lex_state = 18, .external_lex_state = 2},
  [17276] = {.lex_state = 136, .external_lex_state = 2},
  [17277] = {.lex_state = 136, .external_lex_state = 2},
  [17278] = {.lex_state = 136, .external_lex_state = 2},
  [17279] = {.lex_state = 28, .external_lex_state = 2},
  [17280] = {.lex_state = 420, .external_lex_state = 2},
  [17281] = {.lex_state = 420, .external_lex_state = 2},
  [17282] = {.lex_state = 28, .external_lex_state = 2},
  [17283] = {.lex_state = 136, .external_lex_state = 2},
  [17284] = {.lex_state = 18, .external_lex_state = 2},
  [17285] = {.lex_state = 136, .external_lex_state = 2},
  [17286] = {.lex_state = 136, .external_lex_state = 2},
  [17287] = {.lex_state = 18, .external_lex_state = 2},
  [17288] = {.lex_state = 420, .external_lex_state = 2},
  [17289] = {.lex_state = 420, .external_lex_state = 2},
  [17290] = {.lex_state = 28, .external_lex_state = 2},
  [17291] = {.lex_state = 28, .external_lex_state = 2},
  [17292] = {.lex_state = 420, .external_lex_state = 8},
  [17293] = {.lex_state = 28, .external_lex_state = 2},
  [17294] = {.lex_state = 420, .external_lex_state = 2},
  [17295] = {.lex_state = 420, .external_lex_state = 2},
  [17296] = {.lex_state = 420, .external_lex_state = 2},
  [17297] = {.lex_state = 18, .external_lex_state = 2},
  [17298] = {.lex_state = 420, .external_lex_state = 2},
  [17299] = {.lex_state = 28, .external_lex_state = 2},
  [17300] = {.lex_state = 136, .external_lex_state = 2},
  [17301] = {.lex_state = 136, .external_lex_state = 2},
  [17302] = {.lex_state = 136, .external_lex_state = 2},
  [17303] = {.lex_state = 420, .external_lex_state = 2},
  [17304] = {.lex_state = 18, .external_lex_state = 2},
  [17305] = {.lex_state = 420, .external_lex_state = 8},
  [17306] = {.lex_state = 28, .external_lex_state = 2},
  [17307] = {.lex_state = 28, .external_lex_state = 2},
  [17308] = {.lex_state = 420, .external_lex_state = 2},
  [17309] = {.lex_state = 420, .external_lex_state = 2},
  [17310] = {.lex_state = 28, .external_lex_state = 2},
  [17311] = {.lex_state = 420, .external_lex_state = 2},
  [17312] = {.lex_state = 18, .external_lex_state = 2},
  [17313] = {.lex_state = 28, .external_lex_state = 2},
  [17314] = {.lex_state = 420, .external_lex_state = 2},
  [17315] = {.lex_state = 28, .external_lex_state = 2},
  [17316] = {.lex_state = 136, .external_lex_state = 2},
  [17317] = {.lex_state = 136, .external_lex_state = 2},
  [17318] = {.lex_state = 136, .external_lex_state = 2},
  [17319] = {.lex_state = 18, .external_lex_state = 2},
  [17320] = {.lex_state = 420, .external_lex_state = 2},
  [17321] = {.lex_state = 420, .external_lex_state = 8},
  [17322] = {.lex_state = 28, .external_lex_state = 2},
  [17323] = {.lex_state = 28, .external_lex_state = 2},
  [17324] = {.lex_state = 28, .external_lex_state = 2},
  [17325] = {.lex_state = 420, .external_lex_state = 2},
  [17326] = {.lex_state = 420, .external_lex_state = 2},
  [17327] = {.lex_state = 420, .external_lex_state = 2},
  [17328] = {.lex_state = 420, .external_lex_state = 2},
  [17329] = {.lex_state = 28, .external_lex_state = 2},
  [17330] = {.lex_state = 420, .external_lex_state = 2},
  [17331] = {.lex_state = 136, .external_lex_state = 2},
  [17332] = {.lex_state = 18, .external_lex_state = 2},
  [17333] = {.lex_state = 136, .external_lex_state = 2},
  [17334] = {.lex_state = 136, .external_lex_state = 2},
  [17335] = {.lex_state = 28, .external_lex_state = 2},
  [17336] = {.lex_state = 420, .external_lex_state = 2},
  [17337] = {.lex_state = 420, .external_lex_state = 8},
  [17338] = {.lex_state = 420, .external_lex_state = 8},
  [17339] = {.lex_state = 18, .external_lex_state = 2},
  [17340] = {.lex_state = 28, .external_lex_state = 2},
  [17341] = {.lex_state = 28, .external_lex_state = 2},
  [17342] = {.lex_state = 18, .external_lex_state = 2},
  [17343] = {.lex_state = 420, .external_lex_state = 2},
  [17344] = {.lex_state = 420, .external_lex_state = 2},
  [17345] = {.lex_state = 420, .external_lex_state = 2},
  [17346] = {.lex_state = 18, .external_lex_state = 2},
  [17347] = {.lex_state = 136, .external_lex_state = 2},
  [17348] = {.lex_state = 136, .external_lex_state = 2},
  [17349] = {.lex_state = 136, .external_lex_state = 2},
  [17350] = {.lex_state = 420, .external_lex_state = 8},
  [17351] = {.lex_state = 18, .external_lex_state = 2},
  [17352] = {.lex_state = 420, .external_lex_state = 2},
  [17353] = {.lex_state = 28, .external_lex_state = 2},
  [17354] = {.lex_state = 136, .external_lex_state = 2},
  [17355] = {.lex_state = 136, .external_lex_state = 2},
  [17356] = {.lex_state = 136, .external_lex_state = 2},
  [17357] = {.lex_state = 28, .external_lex_state = 2},
  [17358] = {.lex_state = 28, .external_lex_state = 2},
  [17359] = {.lex_state = 420, .external_lex_state = 2},
  [17360] = {.lex_state = 420, .external_lex_state = 2},
  [17361] = {.lex_state = 420, .external_lex_state = 2},
  [17362] = {.lex_state = 420, .external_lex_state = 2},
  [17363] = {.lex_state = 136, .external_lex_state = 2},
  [17364] = {.lex_state = 136, .external_lex_state = 2},
  [17365] = {.lex_state = 136, .external_lex_state = 2},
  [17366] = {.lex_state = 420, .external_lex_state = 2},
  [17367] = {.lex_state = 28, .external_lex_state = 2},
  [17368] = {.lex_state = 420, .external_lex_state = 2},
  [17369] = {.lex_state = 420, .external_lex_state = 2},
  [17370] = {.lex_state = 28, .external_lex_state = 2},
  [17371] = {.lex_state = 420, .external_lex_state = 8},
  [17372] = {.lex_state = 420, .external_lex_state = 2},
  [17373] = {.lex_state = 18, .external_lex_state = 2},
  [17374] = {.lex_state = 28, .external_lex_state = 2},
  [17375] = {.lex_state = 420, .external_lex_state = 2},
  [17376] = {.lex_state = 28, .external_lex_state = 2},
  [17377] = {.lex_state = 420, .external_lex_state = 2},
  [17378] = {.lex_state = 18, .external_lex_state = 2},
  [17379] = {.lex_state = 136, .external_lex_state = 2},
  [17380] = {.lex_state = 136, .external_lex_state = 2},
  [17381] = {.lex_state = 136, .external_lex_state = 2},
  [17382] = {.lex_state = 420, .external_lex_state = 2},
  [17383] = {.lex_state = 18, .external_lex_state = 2},
  [17384] = {.lex_state = 28, .external_lex_state = 2},
  [17385] = {.lex_state = 420, .external_lex_state = 2},
  [17386] = {.lex_state = 18, .external_lex_state = 2},
  [17387] = {.lex_state = 420, .external_lex_state = 2},
  [17388] = {.lex_state = 28, .external_lex_state = 2},
  [17389] = {.lex_state = 420, .external_lex_state = 8},
  [17390] = {.lex_state = 28, .external_lex_state = 2},
  [17391] = {.lex_state = 28, .external_lex_state = 2},
  [17392] = {.lex_state = 420, .external_lex_state = 2},
  [17393] = {.lex_state = 420, .external_lex_state = 2},
  [17394] = {.lex_state = 18, .external_lex_state = 2},
  [17395] = {.lex_state = 420, .external_lex_state = 2},
  [17396] = {.lex_state = 28, .external_lex_state = 2},
  [17397] = {.lex_state = 420, .external_lex_state = 2},
  [17398] = {.lex_state = 420, .external_lex_state = 2},
  [17399] = {.lex_state = 18, .external_lex_state = 2},
  [17400] = {.lex_state = 136, .external_lex_state = 2},
  [17401] = {.lex_state = 136, .external_lex_state = 2},
  [17402] = {.lex_state = 136, .external_lex_state = 2},
  [17403] = {.lex_state = 28, .external_lex_state = 2},
  [17404] = {.lex_state = 28, .external_lex_state = 2},
  [17405] = {.lex_state = 28, .external_lex_state = 2},
  [17406] = {.lex_state = 420, .external_lex_state = 2},
  [17407] = {.lex_state = 420, .external_lex_state = 2},
  [17408] = {.lex_state = 420, .external_lex_state = 8},
  [17409] = {.lex_state = 420, .external_lex_state = 2},
  [17410] = {.lex_state = 18, .external_lex_state = 2},
  [17411] = {.lex_state = 18, .external_lex_state = 2},
  [17412] = {.lex_state = 420, .external_lex_state = 2},
  [17413] = {.lex_state = 420, .external_lex_state = 2},
  [17414] = {.lex_state = 28, .external_lex_state = 2},
  [17415] = {.lex_state = 420, .external_lex_state = 8},
  [17416] = {.lex_state = 28, .external_lex_state = 2},
  [17417] = {.lex_state = 28, .external_lex_state = 2},
  [17418] = {.lex_state = 28, .external_lex_state = 2},
  [17419] = {.lex_state = 420, .external_lex_state = 2},
  [17420] = {.lex_state = 420, .external_lex_state = 2},
  [17421] = {.lex_state = 136, .external_lex_state = 2},
  [17422] = {.lex_state = 420, .external_lex_state = 2},
  [17423] = {.lex_state = 136, .external_lex_state = 2},
  [17424] = {.lex_state = 136, .external_lex_state = 2},
  [17425] = {.lex_state = 28, .external_lex_state = 2},
  [17426] = {.lex_state = 420, .external_lex_state = 2},
  [17427] = {.lex_state = 420, .external_lex_state = 2},
  [17428] = {.lex_state = 420, .external_lex_state = 8},
  [17429] = {.lex_state = 28, .external_lex_state = 2},
  [17430] = {.lex_state = 28, .external_lex_state = 2},
  [17431] = {.lex_state = 28, .external_lex_state = 2},
  [17432] = {.lex_state = 136, .external_lex_state = 2},
  [17433] = {.lex_state = 136, .external_lex_state = 2},
  [17434] = {.lex_state = 136, .external_lex_state = 2},
  [17435] = {.lex_state = 28, .external_lex_state = 2},
  [17436] = {.lex_state = 28, .external_lex_state = 2},
  [17437] = {.lex_state = 28, .external_lex_state = 2},
  [17438] = {.lex_state = 28, .external_lex_state = 2},
  [17439] = {.lex_state = 18, .external_lex_state = 2},
  [17440] = {.lex_state = 18, .external_lex_state = 2},
  [17441] = {.lex_state = 420, .external_lex_state = 2},
  [17442] = {.lex_state = 18, .external_lex_state = 2},
  [17443] = {.lex_state = 420, .external_lex_state = 2},
  [17444] = {.lex_state = 420, .external_lex_state = 2},
  [17445] = {.lex_state = 420, .external_lex_state = 2},
  [17446] = {.lex_state = 28, .external_lex_state = 2},
  [17447] = {.lex_state = 28, .external_lex_state = 2},
  [17448] = {.lex_state = 28, .external_lex_state = 2},
  [17449] = {.lex_state = 136, .external_lex_state = 2},
  [17450] = {.lex_state = 136, .external_lex_state = 2},
  [17451] = {.lex_state = 136, .external_lex_state = 2},
  [17452] = {.lex_state = 420, .external_lex_state = 2},
  [17453] = {.lex_state = 18, .external_lex_state = 2},
  [17454] = {.lex_state = 420, .external_lex_state = 2},
  [17455] = {.lex_state = 420, .external_lex_state = 8},
  [17456] = {.lex_state = 28, .external_lex_state = 2},
  [17457] = {.lex_state = 420, .external_lex_state = 2},
  [17458] = {.lex_state = 420, .external_lex_state = 2},
  [17459] = {.lex_state = 28, .external_lex_state = 2},
  [17460] = {.lex_state = 18, .external_lex_state = 2},
  [17461] = {.lex_state = 420, .external_lex_state = 2},
  [17462] = {.lex_state = 28, .external_lex_state = 2},
  [17463] = {.lex_state = 18, .external_lex_state = 2},
  [17464] = {.lex_state = 136, .external_lex_state = 2},
  [17465] = {.lex_state = 420, .external_lex_state = 2},
  [17466] = {.lex_state = 420, .external_lex_state = 2},
  [17467] = {.lex_state = 136, .external_lex_state = 2},
  [17468] = {.lex_state = 136, .external_lex_state = 2},
  [17469] = {.lex_state = 420, .external_lex_state = 2},
  [17470] = {.lex_state = 28, .external_lex_state = 2},
  [17471] = {.lex_state = 28, .external_lex_state = 2},
  [17472] = {.lex_state = 420, .external_lex_state = 2},
  [17473] = {.lex_state = 28, .external_lex_state = 2},
  [17474] = {.lex_state = 420, .external_lex_state = 8},
  [17475] = {.lex_state = 420, .external_lex_state = 2},
  [17476] = {.lex_state = 28, .external_lex_state = 2},
  [17477] = {.lex_state = 420, .external_lex_state = 2},
  [17478] = {.lex_state = 420, .external_lex_state = 2},
  [17479] = {.lex_state = 28, .external_lex_state = 2},
  [17480] = {.lex_state = 420, .external_lex_state = 2},
  [17481] = {.lex_state = 18, .external_lex_state = 2},
  [17482] = {.lex_state = 136, .external_lex_state = 2},
  [17483] = {.lex_state = 28, .external_lex_state = 2},
  [17484] = {.lex_state = 420, .external_lex_state = 2},
  [17485] = {.lex_state = 136, .external_lex_state = 2},
  [17486] = {.lex_state = 136, .external_lex_state = 2},
  [17487] = {.lex_state = 420, .external_lex_state = 2},
  [17488] = {.lex_state = 18, .external_lex_state = 2},
  [17489] = {.lex_state = 420, .external_lex_state = 2},
  [17490] = {.lex_state = 28, .external_lex_state = 2},
  [17491] = {.lex_state = 420, .external_lex_state = 8},
  [17492] = {.lex_state = 420, .external_lex_state = 8},
  [17493] = {.lex_state = 18, .external_lex_state = 2},
  [17494] = {.lex_state = 28, .external_lex_state = 2},
  [17495] = {.lex_state = 420, .external_lex_state = 2},
  [17496] = {.lex_state = 420, .external_lex_state = 2},
  [17497] = {.lex_state = 28, .external_lex_state = 2},
  [17498] = {.lex_state = 420, .external_lex_state = 2},
  [17499] = {.lex_state = 420, .external_lex_state = 2},
  [17500] = {.lex_state = 420, .external_lex_state = 2},
  [17501] = {.lex_state = 18, .external_lex_state = 2},
  [17502] = {.lex_state = 28, .external_lex_state = 2},
  [17503] = {.lex_state = 136, .external_lex_state = 2},
  [17504] = {.lex_state = 136, .external_lex_state = 2},
  [17505] = {.lex_state = 136, .external_lex_state = 2},
  [17506] = {.lex_state = 28, .external_lex_state = 2},
  [17507] = {.lex_state = 18, .external_lex_state = 2},
  [17508] = {.lex_state = 420, .external_lex_state = 2},
  [17509] = {.lex_state = 136, .external_lex_state = 2},
  [17510] = {.lex_state = 136, .external_lex_state = 2},
  [17511] = {.lex_state = 136, .external_lex_state = 2},
  [17512] = {.lex_state = 28, .external_lex_state = 2},
  [17513] = {.lex_state = 420, .external_lex_state = 8},
  [17514] = {.lex_state = 18, .external_lex_state = 2},
  [17515] = {.lex_state = 420, .external_lex_state = 2},
  [17516] = {.lex_state = 28, .external_lex_state = 2},
  [17517] = {.lex_state = 28, .external_lex_state = 2},
  [17518] = {.lex_state = 28, .external_lex_state = 2},
  [17519] = {.lex_state = 420, .external_lex_state = 2},
  [17520] = {.lex_state = 420, .external_lex_state = 2},
  [17521] = {.lex_state = 420, .external_lex_state = 2},
  [17522] = {.lex_state = 420, .external_lex_state = 2},
  [17523] = {.lex_state = 420, .external_lex_state = 2},
  [17524] = {.lex_state = 28, .external_lex_state = 2},
  [17525] = {.lex_state = 420, .external_lex_state = 2},
  [17526] = {.lex_state = 136, .external_lex_state = 2},
  [17527] = {.lex_state = 136, .external_lex_state = 2},
  [17528] = {.lex_state = 136, .external_lex_state = 2},
  [17529] = {.lex_state = 28, .external_lex_state = 2},
  [17530] = {.lex_state = 28, .external_lex_state = 2},
  [17531] = {.lex_state = 420, .external_lex_state = 2},
  [17532] = {.lex_state = 420, .external_lex_state = 8},
  [17533] = {.lex_state = 18, .external_lex_state = 2},
  [17534] = {.lex_state = 18, .external_lex_state = 2},
  [17535] = {.lex_state = 420, .external_lex_state = 2},
  [17536] = {.lex_state = 28, .external_lex_state = 2},
  [17537] = {.lex_state = 420, .external_lex_state = 2},
  [17538] = {.lex_state = 28, .external_lex_state = 2},
  [17539] = {.lex_state = 420, .external_lex_state = 2},
  [17540] = {.lex_state = 420, .external_lex_state = 2},
  [17541] = {.lex_state = 420, .external_lex_state = 2},
  [17542] = {.lex_state = 28, .external_lex_state = 2},
  [17543] = {.lex_state = 136, .external_lex_state = 2},
  [17544] = {.lex_state = 136, .external_lex_state = 2},
  [17545] = {.lex_state = 28, .external_lex_state = 2},
  [17546] = {.lex_state = 420, .external_lex_state = 2},
  [17547] = {.lex_state = 136, .external_lex_state = 2},
  [17548] = {.lex_state = 420, .external_lex_state = 2},
  [17549] = {.lex_state = 18, .external_lex_state = 2},
  [17550] = {.lex_state = 420, .external_lex_state = 2},
  [17551] = {.lex_state = 28, .external_lex_state = 2},
  [17552] = {.lex_state = 28, .external_lex_state = 2},
  [17553] = {.lex_state = 420, .external_lex_state = 8},
  [17554] = {.lex_state = 18, .external_lex_state = 2},
  [17555] = {.lex_state = 420, .external_lex_state = 2},
  [17556] = {.lex_state = 18, .external_lex_state = 2},
  [17557] = {.lex_state = 420, .external_lex_state = 2},
  [17558] = {.lex_state = 18, .external_lex_state = 2},
  [17559] = {.lex_state = 420, .external_lex_state = 2},
  [17560] = {.lex_state = 28, .external_lex_state = 2},
  [17561] = {.lex_state = 420, .external_lex_state = 2},
  [17562] = {.lex_state = 420, .external_lex_state = 2},
  [17563] = {.lex_state = 18, .external_lex_state = 2},
  [17564] = {.lex_state = 420, .external_lex_state = 2},
  [17565] = {.lex_state = 420, .external_lex_state = 8},
  [17566] = {.lex_state = 136, .external_lex_state = 2},
  [17567] = {.lex_state = 420, .external_lex_state = 2},
  [17568] = {.lex_state = 420, .external_lex_state = 2},
  [17569] = {.lex_state = 136, .external_lex_state = 2},
  [17570] = {.lex_state = 28, .external_lex_state = 2},
  [17571] = {.lex_state = 136, .external_lex_state = 2},
  [17572] = {.lex_state = 420, .external_lex_state = 2},
  [17573] = {.lex_state = 28, .external_lex_state = 2},
  [17574] = {.lex_state = 420, .external_lex_state = 2},
  [17575] = {.lex_state = 28, .external_lex_state = 2},
  [17576] = {.lex_state = 18, .external_lex_state = 2},
  [17577] = {.lex_state = 420, .external_lex_state = 2},
  [17578] = {.lex_state = 420, .external_lex_state = 2},
  [17579] = {.lex_state = 28, .external_lex_state = 2},
  [17580] = {.lex_state = 28, .external_lex_state = 2},
  [17581] = {.lex_state = 28, .external_lex_state = 2},
  [17582] = {.lex_state = 136, .external_lex_state = 2},
  [17583] = {.lex_state = 136, .external_lex_state = 2},
  [17584] = {.lex_state = 136, .external_lex_state = 2},
  [17585] = {.lex_state = 28, .external_lex_state = 2},
  [17586] = {.lex_state = 28, .external_lex_state = 2},
  [17587] = {.lex_state = 28, .external_lex_state = 2},
  [17588] = {.lex_state = 420, .external_lex_state = 2},
  [17589] = {.lex_state = 420, .external_lex_state = 2},
  [17590] = {.lex_state = 18, .external_lex_state = 2},
  [17591] = {.lex_state = 420, .external_lex_state = 2},
  [17592] = {.lex_state = 420, .external_lex_state = 2},
  [17593] = {.lex_state = 18, .external_lex_state = 2},
  [17594] = {.lex_state = 420, .external_lex_state = 2},
  [17595] = {.lex_state = 420, .external_lex_state = 2},
  [17596] = {.lex_state = 420, .external_lex_state = 2},
  [17597] = {.lex_state = 18, .external_lex_state = 2},
  [17598] = {.lex_state = 18, .external_lex_state = 2},
  [17599] = {.lex_state = 420, .external_lex_state = 2},
  [17600] = {.lex_state = 420, .external_lex_state = 2},
  [17601] = {.lex_state = 420, .external_lex_state = 2},
  [17602] = {.lex_state = 420, .external_lex_state = 2},
  [17603] = {.lex_state = 28, .external_lex_state = 2},
  [17604] = {.lex_state = 420, .external_lex_state = 2},
  [17605] = {.lex_state = 420, .external_lex_state = 3},
  [17606] = {.lex_state = 11, .external_lex_state = 2},
  [17607] = {.lex_state = 420, .external_lex_state = 2},
  [17608] = {.lex_state = 420, .external_lex_state = 2},
  [17609] = {.lex_state = 420, .external_lex_state = 2},
  [17610] = {.lex_state = 420, .external_lex_state = 2},
  [17611] = {.lex_state = 12, .external_lex_state = 2},
  [17612] = {.lex_state = 12, .external_lex_state = 2},
  [17613] = {.lex_state = 12, .external_lex_state = 2},
  [17614] = {.lex_state = 12, .external_lex_state = 2},
  [17615] = {.lex_state = 420, .external_lex_state = 2},
  [17616] = {.lex_state = 420, .external_lex_state = 2},
  [17617] = {.lex_state = 420, .external_lex_state = 2},
  [17618] = {.lex_state = 420, .external_lex_state = 2},
  [17619] = {.lex_state = 420, .external_lex_state = 2},
  [17620] = {.lex_state = 420, .external_lex_state = 2},
  [17621] = {.lex_state = 18, .external_lex_state = 2},
  [17622] = {.lex_state = 420, .external_lex_state = 2},
  [17623] = {.lex_state = 420, .external_lex_state = 2},
  [17624] = {.lex_state = 420, .external_lex_state = 2},
  [17625] = {.lex_state = 420, .external_lex_state = 2},
  [17626] = {.lex_state = 420, .external_lex_state = 2},
  [17627] = {.lex_state = 420, .external_lex_state = 2},
  [17628] = {.lex_state = 420, .external_lex_state = 2},
  [17629] = {.lex_state = 420, .external_lex_state = 2},
  [17630] = {.lex_state = 420, .external_lex_state = 2},
  [17631] = {.lex_state = 420, .external_lex_state = 2},
  [17632] = {.lex_state = 420, .external_lex_state = 2},
  [17633] = {.lex_state = 420, .external_lex_state = 2},
  [17634] = {.lex_state = 18, .external_lex_state = 2},
  [17635] = {.lex_state = 420, .external_lex_state = 2},
  [17636] = {.lex_state = 420, .external_lex_state = 2},
  [17637] = {.lex_state = 420, .external_lex_state = 2},
  [17638] = {.lex_state = 18, .external_lex_state = 2},
  [17639] = {.lex_state = 420, .external_lex_state = 2},
  [17640] = {.lex_state = 420, .external_lex_state = 2},
  [17641] = {.lex_state = 420, .external_lex_state = 2},
  [17642] = {.lex_state = 18, .external_lex_state = 2},
  [17643] = {.lex_state = 420, .external_lex_state = 2},
  [17644] = {.lex_state = 420, .external_lex_state = 2},
  [17645] = {.lex_state = 28, .external_lex_state = 2},
  [17646] = {.lex_state = 420, .external_lex_state = 3},
  [17647] = {.lex_state = 11, .external_lex_state = 2},
  [17648] = {.lex_state = 420, .external_lex_state = 2},
  [17649] = {.lex_state = 420, .external_lex_state = 2},
  [17650] = {.lex_state = 420, .external_lex_state = 2},
  [17651] = {.lex_state = 420, .external_lex_state = 2},
  [17652] = {.lex_state = 420, .external_lex_state = 2},
  [17653] = {.lex_state = 420, .external_lex_state = 2},
  [17654] = {.lex_state = 12, .external_lex_state = 2},
  [17655] = {.lex_state = 12, .external_lex_state = 2},
  [17656] = {.lex_state = 12, .external_lex_state = 2},
  [17657] = {.lex_state = 12, .external_lex_state = 2},
  [17658] = {.lex_state = 420, .external_lex_state = 2},
  [17659] = {.lex_state = 420, .external_lex_state = 2},
  [17660] = {.lex_state = 420, .external_lex_state = 2},
  [17661] = {.lex_state = 420, .external_lex_state = 2},
  [17662] = {.lex_state = 18, .external_lex_state = 2},
  [17663] = {.lex_state = 420, .external_lex_state = 2},
  [17664] = {.lex_state = 420, .external_lex_state = 2},
  [17665] = {.lex_state = 420, .external_lex_state = 2},
  [17666] = {.lex_state = 420, .external_lex_state = 2},
  [17667] = {.lex_state = 420, .external_lex_state = 2},
  [17668] = {.lex_state = 420, .external_lex_state = 2},
  [17669] = {.lex_state = 420, .external_lex_state = 2},
  [17670] = {.lex_state = 420, .external_lex_state = 2},
  [17671] = {.lex_state = 420, .external_lex_state = 2},
  [17672] = {.lex_state = 420, .external_lex_state = 2},
  [17673] = {.lex_state = 420, .external_lex_state = 2},
  [17674] = {.lex_state = 420, .external_lex_state = 2},
  [17675] = {.lex_state = 420, .external_lex_state = 2},
  [17676] = {.lex_state = 420, .external_lex_state = 2},
  [17677] = {.lex_state = 420, .external_lex_state = 2},
  [17678] = {.lex_state = 420, .external_lex_state = 2},
  [17679] = {.lex_state = 420, .external_lex_state = 2},
  [17680] = {.lex_state = 420, .external_lex_state = 2},
  [17681] = {.lex_state = 420, .external_lex_state = 2},
  [17682] = {.lex_state = 420, .external_lex_state = 2},
  [17683] = {.lex_state = 420, .external_lex_state = 2},
  [17684] = {.lex_state = 18, .external_lex_state = 2},
  [17685] = {.lex_state = 420, .external_lex_state = 2},
  [17686] = {.lex_state = 420, .external_lex_state = 2},
  [17687] = {.lex_state = 420, .external_lex_state = 2},
  [17688] = {.lex_state = 420, .external_lex_state = 2},
  [17689] = {.lex_state = 11, .external_lex_state = 2},
  [17690] = {.lex_state = 420, .external_lex_state = 2},
  [17691] = {.lex_state = 420, .external_lex_state = 2},
  [17692] = {.lex_state = 420, .external_lex_state = 2},
  [17693] = {.lex_state = 18, .external_lex_state = 2},
  [17694] = {.lex_state = 18, .external_lex_state = 2},
  [17695] = {.lex_state = 420, .external_lex_state = 2},
  [17696] = {.lex_state = 420, .external_lex_state = 2},
  [17697] = {.lex_state = 420, .external_lex_state = 2},
  [17698] = {.lex_state = 420, .external_lex_state = 2},
  [17699] = {.lex_state = 420, .external_lex_state = 2},
  [17700] = {.lex_state = 420, .external_lex_state = 2},
  [17701] = {.lex_state = 28, .external_lex_state = 2},
  [17702] = {.lex_state = 12, .external_lex_state = 2},
  [17703] = {.lex_state = 420, .external_lex_state = 2},
  [17704] = {.lex_state = 420, .external_lex_state = 2},
  [17705] = {.lex_state = 420, .external_lex_state = 2},
  [17706] = {.lex_state = 18, .external_lex_state = 2},
  [17707] = {.lex_state = 420, .external_lex_state = 3},
  [17708] = {.lex_state = 11, .external_lex_state = 2},
  [17709] = {.lex_state = 420, .external_lex_state = 2},
  [17710] = {.lex_state = 420, .external_lex_state = 2},
  [17711] = {.lex_state = 420, .external_lex_state = 2},
  [17712] = {.lex_state = 420, .external_lex_state = 2},
  [17713] = {.lex_state = 420, .external_lex_state = 2},
  [17714] = {.lex_state = 12, .external_lex_state = 2},
  [17715] = {.lex_state = 420, .external_lex_state = 2},
  [17716] = {.lex_state = 12, .external_lex_state = 2},
  [17717] = {.lex_state = 12, .external_lex_state = 2},
  [17718] = {.lex_state = 12, .external_lex_state = 2},
  [17719] = {.lex_state = 420, .external_lex_state = 2},
  [17720] = {.lex_state = 420, .external_lex_state = 2},
  [17721] = {.lex_state = 420, .external_lex_state = 2},
  [17722] = {.lex_state = 420, .external_lex_state = 2},
  [17723] = {.lex_state = 420, .external_lex_state = 2},
  [17724] = {.lex_state = 12, .external_lex_state = 2},
  [17725] = {.lex_state = 420, .external_lex_state = 2},
  [17726] = {.lex_state = 12, .external_lex_state = 2},
  [17727] = {.lex_state = 18, .external_lex_state = 2},
  [17728] = {.lex_state = 12, .external_lex_state = 2},
  [17729] = {.lex_state = 12, .external_lex_state = 2},
  [17730] = {.lex_state = 420, .external_lex_state = 2},
  [17731] = {.lex_state = 420, .external_lex_state = 2},
  [17732] = {.lex_state = 420, .external_lex_state = 2},
  [17733] = {.lex_state = 420, .external_lex_state = 2},
  [17734] = {.lex_state = 420, .external_lex_state = 2},
  [17735] = {.lex_state = 420, .external_lex_state = 2},
  [17736] = {.lex_state = 420, .external_lex_state = 2},
  [17737] = {.lex_state = 420, .external_lex_state = 2},
  [17738] = {.lex_state = 420, .external_lex_state = 2},
  [17739] = {.lex_state = 420, .external_lex_state = 2},
  [17740] = {.lex_state = 420, .external_lex_state = 2},
  [17741] = {.lex_state = 420, .external_lex_state = 2},
  [17742] = {.lex_state = 420, .external_lex_state = 2},
  [17743] = {.lex_state = 420, .external_lex_state = 2},
  [17744] = {.lex_state = 420, .external_lex_state = 2},
  [17745] = {.lex_state = 420, .external_lex_state = 2},
  [17746] = {.lex_state = 420, .external_lex_state = 2},
  [17747] = {.lex_state = 420, .external_lex_state = 2},
  [17748] = {.lex_state = 18, .external_lex_state = 2},
  [17749] = {.lex_state = 420, .external_lex_state = 2},
  [17750] = {.lex_state = 420, .external_lex_state = 2},
  [17751] = {.lex_state = 420, .external_lex_state = 2},
  [17752] = {.lex_state = 420, .external_lex_state = 2},
  [17753] = {.lex_state = 420, .external_lex_state = 2},
  [17754] = {.lex_state = 420, .external_lex_state = 2},
  [17755] = {.lex_state = 420, .external_lex_state = 3},
  [17756] = {.lex_state = 18, .external_lex_state = 2},
  [17757] = {.lex_state = 420, .external_lex_state = 2},
  [17758] = {.lex_state = 420, .external_lex_state = 2},
  [17759] = {.lex_state = 420, .external_lex_state = 2},
  [17760] = {.lex_state = 420, .external_lex_state = 2},
  [17761] = {.lex_state = 18, .external_lex_state = 2},
  [17762] = {.lex_state = 420, .external_lex_state = 2},
  [17763] = {.lex_state = 420, .external_lex_state = 2},
  [17764] = {.lex_state = 420, .external_lex_state = 2},
  [17765] = {.lex_state = 28, .external_lex_state = 2},
  [17766] = {.lex_state = 28, .external_lex_state = 2},
  [17767] = {.lex_state = 420, .external_lex_state = 2},
  [17768] = {.lex_state = 420, .external_lex_state = 3},
  [17769] = {.lex_state = 420, .external_lex_state = 2},
  [17770] = {.lex_state = 11, .external_lex_state = 2},
  [17771] = {.lex_state = 420, .external_lex_state = 2},
  [17772] = {.lex_state = 420, .external_lex_state = 2},
  [17773] = {.lex_state = 420, .external_lex_state = 2},
  [17774] = {.lex_state = 420, .external_lex_state = 2},
  [17775] = {.lex_state = 420, .external_lex_state = 2},
  [17776] = {.lex_state = 420, .external_lex_state = 2},
  [17777] = {.lex_state = 420, .external_lex_state = 2},
  [17778] = {.lex_state = 420, .external_lex_state = 2},
  [17779] = {.lex_state = 12, .external_lex_state = 2},
  [17780] = {.lex_state = 18, .external_lex_state = 2},
  [17781] = {.lex_state = 420, .external_lex_state = 2},
  [17782] = {.lex_state = 12, .external_lex_state = 2},
  [17783] = {.lex_state = 12, .external_lex_state = 2},
  [17784] = {.lex_state = 420, .external_lex_state = 2},
  [17785] = {.lex_state = 420, .external_lex_state = 2},
  [17786] = {.lex_state = 420, .external_lex_state = 2},
  [17787] = {.lex_state = 420, .external_lex_state = 2},
  [17788] = {.lex_state = 18, .external_lex_state = 2},
  [17789] = {.lex_state = 18, .external_lex_state = 2},
  [17790] = {.lex_state = 420, .external_lex_state = 2},
  [17791] = {.lex_state = 420, .external_lex_state = 2},
  [17792] = {.lex_state = 420, .external_lex_state = 2},
  [17793] = {.lex_state = 420, .external_lex_state = 2},
  [17794] = {.lex_state = 420, .external_lex_state = 2},
  [17795] = {.lex_state = 420, .external_lex_state = 2},
  [17796] = {.lex_state = 420, .external_lex_state = 2},
  [17797] = {.lex_state = 420, .external_lex_state = 2},
  [17798] = {.lex_state = 420, .external_lex_state = 2},
  [17799] = {.lex_state = 420, .external_lex_state = 2},
  [17800] = {.lex_state = 420, .external_lex_state = 2},
  [17801] = {.lex_state = 420, .external_lex_state = 2},
  [17802] = {.lex_state = 420, .external_lex_state = 2},
  [17803] = {.lex_state = 18, .external_lex_state = 2},
  [17804] = {.lex_state = 420, .external_lex_state = 2},
  [17805] = {.lex_state = 420, .external_lex_state = 2},
  [17806] = {.lex_state = 420, .external_lex_state = 2},
  [17807] = {.lex_state = 420, .external_lex_state = 2},
  [17808] = {.lex_state = 420, .external_lex_state = 2},
  [17809] = {.lex_state = 420, .external_lex_state = 2},
  [17810] = {.lex_state = 420, .external_lex_state = 2},
  [17811] = {.lex_state = 420, .external_lex_state = 2},
  [17812] = {.lex_state = 420, .external_lex_state = 2},
  [17813] = {.lex_state = 420, .external_lex_state = 2},
  [17814] = {.lex_state = 420, .external_lex_state = 2},
  [17815] = {.lex_state = 18, .external_lex_state = 2},
  [17816] = {.lex_state = 420, .external_lex_state = 2},
  [17817] = {.lex_state = 420, .external_lex_state = 2},
  [17818] = {.lex_state = 420, .external_lex_state = 2},
  [17819] = {.lex_state = 18, .external_lex_state = 2},
  [17820] = {.lex_state = 18, .external_lex_state = 2},
  [17821] = {.lex_state = 420, .external_lex_state = 2},
  [17822] = {.lex_state = 18, .external_lex_state = 2},
  [17823] = {.lex_state = 420, .external_lex_state = 2},
  [17824] = {.lex_state = 420, .external_lex_state = 2},
  [17825] = {.lex_state = 420, .external_lex_state = 2},
  [17826] = {.lex_state = 420, .external_lex_state = 2},
  [17827] = {.lex_state = 28, .external_lex_state = 2},
  [17828] = {.lex_state = 420, .external_lex_state = 2},
  [17829] = {.lex_state = 420, .external_lex_state = 2},
  [17830] = {.lex_state = 420, .external_lex_state = 2},
  [17831] = {.lex_state = 420, .external_lex_state = 2},
  [17832] = {.lex_state = 420, .external_lex_state = 2},
  [17833] = {.lex_state = 420, .external_lex_state = 3},
  [17834] = {.lex_state = 420, .external_lex_state = 2},
  [17835] = {.lex_state = 11, .external_lex_state = 2},
  [17836] = {.lex_state = 420, .external_lex_state = 2},
  [17837] = {.lex_state = 420, .external_lex_state = 2},
  [17838] = {.lex_state = 420, .external_lex_state = 2},
  [17839] = {.lex_state = 420, .external_lex_state = 2},
  [17840] = {.lex_state = 420, .external_lex_state = 2},
  [17841] = {.lex_state = 12, .external_lex_state = 2},
  [17842] = {.lex_state = 12, .external_lex_state = 2},
  [17843] = {.lex_state = 12, .external_lex_state = 2},
  [17844] = {.lex_state = 12, .external_lex_state = 2},
  [17845] = {.lex_state = 420, .external_lex_state = 2},
  [17846] = {.lex_state = 420, .external_lex_state = 2},
  [17847] = {.lex_state = 420, .external_lex_state = 2},
  [17848] = {.lex_state = 420, .external_lex_state = 2},
  [17849] = {.lex_state = 420, .external_lex_state = 2},
  [17850] = {.lex_state = 420, .external_lex_state = 2},
  [17851] = {.lex_state = 420, .external_lex_state = 2},
  [17852] = {.lex_state = 18, .external_lex_state = 2},
  [17853] = {.lex_state = 420, .external_lex_state = 2},
  [17854] = {.lex_state = 420, .external_lex_state = 2},
  [17855] = {.lex_state = 420, .external_lex_state = 2},
  [17856] = {.lex_state = 420, .external_lex_state = 2},
  [17857] = {.lex_state = 420, .external_lex_state = 2},
  [17858] = {.lex_state = 420, .external_lex_state = 2},
  [17859] = {.lex_state = 420, .external_lex_state = 2},
  [17860] = {.lex_state = 420, .external_lex_state = 2},
  [17861] = {.lex_state = 420, .external_lex_state = 2},
  [17862] = {.lex_state = 420, .external_lex_state = 2},
  [17863] = {.lex_state = 420, .external_lex_state = 2},
  [17864] = {.lex_state = 420, .external_lex_state = 2},
  [17865] = {.lex_state = 420, .external_lex_state = 2},
  [17866] = {.lex_state = 18, .external_lex_state = 2},
  [17867] = {.lex_state = 420, .external_lex_state = 2},
  [17868] = {.lex_state = 420, .external_lex_state = 2},
  [17869] = {.lex_state = 420, .external_lex_state = 2},
  [17870] = {.lex_state = 420, .external_lex_state = 2},
  [17871] = {.lex_state = 420, .external_lex_state = 2},
  [17872] = {.lex_state = 420, .external_lex_state = 2},
  [17873] = {.lex_state = 420, .external_lex_state = 2},
  [17874] = {.lex_state = 420, .external_lex_state = 2},
  [17875] = {.lex_state = 420, .external_lex_state = 2},
  [17876] = {.lex_state = 18, .external_lex_state = 2},
  [17877] = {.lex_state = 12, .external_lex_state = 2},
  [17878] = {.lex_state = 420, .external_lex_state = 2},
  [17879] = {.lex_state = 420, .external_lex_state = 2},
  [17880] = {.lex_state = 420, .external_lex_state = 2},
  [17881] = {.lex_state = 12, .external_lex_state = 2},
  [17882] = {.lex_state = 420, .external_lex_state = 2},
  [17883] = {.lex_state = 420, .external_lex_state = 2},
  [17884] = {.lex_state = 420, .external_lex_state = 2},
  [17885] = {.lex_state = 420, .external_lex_state = 2},
  [17886] = {.lex_state = 18, .external_lex_state = 2},
  [17887] = {.lex_state = 18, .external_lex_state = 2},
  [17888] = {.lex_state = 12, .external_lex_state = 2},
  [17889] = {.lex_state = 12, .external_lex_state = 2},
  [17890] = {.lex_state = 420, .external_lex_state = 2},
  [17891] = {.lex_state = 420, .external_lex_state = 2},
  [17892] = {.lex_state = 28, .external_lex_state = 2},
  [17893] = {.lex_state = 420, .external_lex_state = 2},
  [17894] = {.lex_state = 420, .external_lex_state = 2},
  [17895] = {.lex_state = 420, .external_lex_state = 3},
  [17896] = {.lex_state = 11, .external_lex_state = 2},
  [17897] = {.lex_state = 420, .external_lex_state = 2},
  [17898] = {.lex_state = 420, .external_lex_state = 2},
  [17899] = {.lex_state = 420, .external_lex_state = 2},
  [17900] = {.lex_state = 420, .external_lex_state = 2},
  [17901] = {.lex_state = 420, .external_lex_state = 2},
  [17902] = {.lex_state = 420, .external_lex_state = 2},
  [17903] = {.lex_state = 420, .external_lex_state = 2},
  [17904] = {.lex_state = 12, .external_lex_state = 2},
  [17905] = {.lex_state = 420, .external_lex_state = 2},
  [17906] = {.lex_state = 12, .external_lex_state = 2},
  [17907] = {.lex_state = 12, .external_lex_state = 2},
  [17908] = {.lex_state = 12, .external_lex_state = 2},
  [17909] = {.lex_state = 420, .external_lex_state = 2},
  [17910] = {.lex_state = 420, .external_lex_state = 2},
  [17911] = {.lex_state = 420, .external_lex_state = 2},
  [17912] = {.lex_state = 420, .external_lex_state = 2},
  [17913] = {.lex_state = 18, .external_lex_state = 2},
  [17914] = {.lex_state = 420, .external_lex_state = 2},
  [17915] = {.lex_state = 420, .external_lex_state = 2},
  [17916] = {.lex_state = 11, .external_lex_state = 2},
  [17917] = {.lex_state = 420, .external_lex_state = 3},
  [17918] = {.lex_state = 420, .external_lex_state = 2},
  [17919] = {.lex_state = 420, .external_lex_state = 2},
  [17920] = {.lex_state = 28, .external_lex_state = 2},
  [17921] = {.lex_state = 420, .external_lex_state = 2},
  [17922] = {.lex_state = 420, .external_lex_state = 2},
  [17923] = {.lex_state = 18, .external_lex_state = 2},
  [17924] = {.lex_state = 420, .external_lex_state = 2},
  [17925] = {.lex_state = 420, .external_lex_state = 2},
  [17926] = {.lex_state = 420, .external_lex_state = 2},
  [17927] = {.lex_state = 420, .external_lex_state = 2},
  [17928] = {.lex_state = 420, .external_lex_state = 2},
  [17929] = {.lex_state = 420, .external_lex_state = 2},
  [17930] = {.lex_state = 420, .external_lex_state = 2},
  [17931] = {.lex_state = 18, .external_lex_state = 2},
  [17932] = {.lex_state = 420, .external_lex_state = 2},
  [17933] = {.lex_state = 420, .external_lex_state = 2},
  [17934] = {.lex_state = 420, .external_lex_state = 2},
  [17935] = {.lex_state = 420, .external_lex_state = 2},
  [17936] = {.lex_state = 420, .external_lex_state = 2},
  [17937] = {.lex_state = 420, .external_lex_state = 2},
  [17938] = {.lex_state = 420, .external_lex_state = 2},
  [17939] = {.lex_state = 420, .external_lex_state = 2},
  [17940] = {.lex_state = 420, .external_lex_state = 2},
  [17941] = {.lex_state = 18, .external_lex_state = 2},
  [17942] = {.lex_state = 420, .external_lex_state = 2},
  [17943] = {.lex_state = 420, .external_lex_state = 2},
  [17944] = {.lex_state = 420, .external_lex_state = 2},
  [17945] = {.lex_state = 420, .external_lex_state = 2},
  [17946] = {.lex_state = 420, .external_lex_state = 2},
  [17947] = {.lex_state = 18, .external_lex_state = 2},
  [17948] = {.lex_state = 420, .external_lex_state = 2},
  [17949] = {.lex_state = 18, .external_lex_state = 2},
  [17950] = {.lex_state = 420, .external_lex_state = 2},
  [17951] = {.lex_state = 420, .external_lex_state = 2},
  [17952] = {.lex_state = 420, .external_lex_state = 2},
  [17953] = {.lex_state = 28, .external_lex_state = 2},
  [17954] = {.lex_state = 420, .external_lex_state = 2},
  [17955] = {.lex_state = 420, .external_lex_state = 2},
  [17956] = {.lex_state = 420, .external_lex_state = 2},
  [17957] = {.lex_state = 420, .external_lex_state = 2},
  [17958] = {.lex_state = 420, .external_lex_state = 3},
  [17959] = {.lex_state = 420, .external_lex_state = 2},
  [17960] = {.lex_state = 11, .external_lex_state = 2},
  [17961] = {.lex_state = 420, .external_lex_state = 2},
  [17962] = {.lex_state = 420, .external_lex_state = 2},
  [17963] = {.lex_state = 420, .external_lex_state = 2},
  [17964] = {.lex_state = 420, .external_lex_state = 2},
  [17965] = {.lex_state = 420, .external_lex_state = 2},
  [17966] = {.lex_state = 12, .external_lex_state = 2},
  [17967] = {.lex_state = 12, .external_lex_state = 2},
  [17968] = {.lex_state = 420, .external_lex_state = 2},
  [17969] = {.lex_state = 420, .external_lex_state = 2},
  [17970] = {.lex_state = 12, .external_lex_state = 2},
  [17971] = {.lex_state = 12, .external_lex_state = 2},
  [17972] = {.lex_state = 420, .external_lex_state = 2},
  [17973] = {.lex_state = 420, .external_lex_state = 2},
  [17974] = {.lex_state = 420, .external_lex_state = 2},
  [17975] = {.lex_state = 420, .external_lex_state = 2},
  [17976] = {.lex_state = 420, .external_lex_state = 2},
  [17977] = {.lex_state = 420, .external_lex_state = 2},
  [17978] = {.lex_state = 420, .external_lex_state = 2},
  [17979] = {.lex_state = 18, .external_lex_state = 2},
  [17980] = {.lex_state = 420, .external_lex_state = 2},
  [17981] = {.lex_state = 420, .external_lex_state = 2},
  [17982] = {.lex_state = 420, .external_lex_state = 2},
  [17983] = {.lex_state = 420, .external_lex_state = 2},
  [17984] = {.lex_state = 420, .external_lex_state = 2},
  [17985] = {.lex_state = 420, .external_lex_state = 2},
  [17986] = {.lex_state = 420, .external_lex_state = 2},
  [17987] = {.lex_state = 420, .external_lex_state = 2},
  [17988] = {.lex_state = 420, .external_lex_state = 2},
  [17989] = {.lex_state = 420, .external_lex_state = 2},
  [17990] = {.lex_state = 420, .external_lex_state = 2},
  [17991] = {.lex_state = 420, .external_lex_state = 2},
  [17992] = {.lex_state = 420, .external_lex_state = 2},
  [17993] = {.lex_state = 420, .external_lex_state = 2},
  [17994] = {.lex_state = 420, .external_lex_state = 2},
  [17995] = {.lex_state = 420, .external_lex_state = 2},
  [17996] = {.lex_state = 420, .external_lex_state = 2},
  [17997] = {.lex_state = 420, .external_lex_state = 2},
  [17998] = {.lex_state = 420, .external_lex_state = 2},
  [17999] = {.lex_state = 420, .external_lex_state = 2},
  [18000] = {.lex_state = 420, .external_lex_state = 2},
  [18001] = {.lex_state = 420, .external_lex_state = 2},
  [18002] = {.lex_state = 420, .external_lex_state = 2},
  [18003] = {.lex_state = 420, .external_lex_state = 2},
  [18004] = {.lex_state = 18, .external_lex_state = 2},
  [18005] = {.lex_state = 420, .external_lex_state = 2},
  [18006] = {.lex_state = 420, .external_lex_state = 2},
  [18007] = {.lex_state = 420, .external_lex_state = 2},
  [18008] = {.lex_state = 18, .external_lex_state = 2},
  [18009] = {.lex_state = 420, .external_lex_state = 2},
  [18010] = {.lex_state = 420, .external_lex_state = 2},
  [18011] = {.lex_state = 420, .external_lex_state = 2},
  [18012] = {.lex_state = 420, .external_lex_state = 2},
  [18013] = {.lex_state = 420, .external_lex_state = 2},
  [18014] = {.lex_state = 18, .external_lex_state = 2},
  [18015] = {.lex_state = 18, .external_lex_state = 2},
  [18016] = {.lex_state = 12, .external_lex_state = 2},
  [18017] = {.lex_state = 420, .external_lex_state = 2},
  [18018] = {.lex_state = 420, .external_lex_state = 2},
  [18019] = {.lex_state = 420, .external_lex_state = 2},
  [18020] = {.lex_state = 28, .external_lex_state = 2},
  [18021] = {.lex_state = 12, .external_lex_state = 2},
  [18022] = {.lex_state = 420, .external_lex_state = 2},
  [18023] = {.lex_state = 420, .external_lex_state = 2},
  [18024] = {.lex_state = 420, .external_lex_state = 3},
  [18025] = {.lex_state = 11, .external_lex_state = 2},
  [18026] = {.lex_state = 420, .external_lex_state = 2},
  [18027] = {.lex_state = 420, .external_lex_state = 2},
  [18028] = {.lex_state = 420, .external_lex_state = 2},
  [18029] = {.lex_state = 12, .external_lex_state = 2},
  [18030] = {.lex_state = 12, .external_lex_state = 2},
  [18031] = {.lex_state = 420, .external_lex_state = 2},
  [18032] = {.lex_state = 420, .external_lex_state = 2},
  [18033] = {.lex_state = 420, .external_lex_state = 2},
  [18034] = {.lex_state = 12, .external_lex_state = 2},
  [18035] = {.lex_state = 12, .external_lex_state = 2},
  [18036] = {.lex_state = 12, .external_lex_state = 2},
  [18037] = {.lex_state = 420, .external_lex_state = 2},
  [18038] = {.lex_state = 12, .external_lex_state = 2},
  [18039] = {.lex_state = 420, .external_lex_state = 2},
  [18040] = {.lex_state = 420, .external_lex_state = 2},
  [18041] = {.lex_state = 420, .external_lex_state = 2},
  [18042] = {.lex_state = 420, .external_lex_state = 2},
  [18043] = {.lex_state = 18, .external_lex_state = 2},
  [18044] = {.lex_state = 420, .external_lex_state = 2},
  [18045] = {.lex_state = 420, .external_lex_state = 2},
  [18046] = {.lex_state = 420, .external_lex_state = 2},
  [18047] = {.lex_state = 420, .external_lex_state = 2},
  [18048] = {.lex_state = 11, .external_lex_state = 2},
  [18049] = {.lex_state = 420, .external_lex_state = 3},
  [18050] = {.lex_state = 28, .external_lex_state = 2},
  [18051] = {.lex_state = 420, .external_lex_state = 2},
  [18052] = {.lex_state = 420, .external_lex_state = 2},
  [18053] = {.lex_state = 420, .external_lex_state = 2},
  [18054] = {.lex_state = 18, .external_lex_state = 2},
  [18055] = {.lex_state = 420, .external_lex_state = 2},
  [18056] = {.lex_state = 420, .external_lex_state = 2},
  [18057] = {.lex_state = 420, .external_lex_state = 2},
  [18058] = {.lex_state = 420, .external_lex_state = 2},
  [18059] = {.lex_state = 420, .external_lex_state = 2},
  [18060] = {.lex_state = 420, .external_lex_state = 2},
  [18061] = {.lex_state = 18, .external_lex_state = 2},
  [18062] = {.lex_state = 420, .external_lex_state = 2},
  [18063] = {.lex_state = 420, .external_lex_state = 2},
  [18064] = {.lex_state = 420, .external_lex_state = 2},
  [18065] = {.lex_state = 420, .external_lex_state = 2},
  [18066] = {.lex_state = 420, .external_lex_state = 2},
  [18067] = {.lex_state = 420, .external_lex_state = 2},
  [18068] = {.lex_state = 420, .external_lex_state = 2},
  [18069] = {.lex_state = 420, .external_lex_state = 2},
  [18070] = {.lex_state = 420, .external_lex_state = 2},
  [18071] = {.lex_state = 420, .external_lex_state = 2},
  [18072] = {.lex_state = 18, .external_lex_state = 2},
  [18073] = {.lex_state = 420, .external_lex_state = 2},
  [18074] = {.lex_state = 420, .external_lex_state = 2},
  [18075] = {.lex_state = 420, .external_lex_state = 2},
  [18076] = {.lex_state = 420, .external_lex_state = 2},
  [18077] = {.lex_state = 420, .external_lex_state = 2},
  [18078] = {.lex_state = 420, .external_lex_state = 2},
  [18079] = {.lex_state = 18, .external_lex_state = 2},
  [18080] = {.lex_state = 420, .external_lex_state = 2},
  [18081] = {.lex_state = 420, .external_lex_state = 2},
  [18082] = {.lex_state = 420, .external_lex_state = 2},
  [18083] = {.lex_state = 420, .external_lex_state = 2},
  [18084] = {.lex_state = 18, .external_lex_state = 2},
  [18085] = {.lex_state = 18, .external_lex_state = 2},
  [18086] = {.lex_state = 18, .external_lex_state = 2},
  [18087] = {.lex_state = 18, .external_lex_state = 2},
  [18088] = {.lex_state = 420, .external_lex_state = 2},
  [18089] = {.lex_state = 420, .external_lex_state = 2},
  [18090] = {.lex_state = 420, .external_lex_state = 2},
  [18091] = {.lex_state = 420, .external_lex_state = 2},
  [18092] = {.lex_state = 420, .external_lex_state = 2},
  [18093] = {.lex_state = 420, .external_lex_state = 2},
  [18094] = {.lex_state = 28, .external_lex_state = 2},
  [18095] = {.lex_state = 420, .external_lex_state = 2},
  [18096] = {.lex_state = 420, .external_lex_state = 3},
  [18097] = {.lex_state = 11, .external_lex_state = 2},
  [18098] = {.lex_state = 420, .external_lex_state = 2},
  [18099] = {.lex_state = 420, .external_lex_state = 2},
  [18100] = {.lex_state = 420, .external_lex_state = 2},
  [18101] = {.lex_state = 420, .external_lex_state = 2},
  [18102] = {.lex_state = 420, .external_lex_state = 2},
  [18103] = {.lex_state = 420, .external_lex_state = 2},
  [18104] = {.lex_state = 420, .external_lex_state = 2},
  [18105] = {.lex_state = 420, .external_lex_state = 2},
  [18106] = {.lex_state = 420, .external_lex_state = 2},
  [18107] = {.lex_state = 420, .external_lex_state = 2},
  [18108] = {.lex_state = 12, .external_lex_state = 2},
  [18109] = {.lex_state = 12, .external_lex_state = 2},
  [18110] = {.lex_state = 420, .external_lex_state = 2},
  [18111] = {.lex_state = 12, .external_lex_state = 2},
  [18112] = {.lex_state = 12, .external_lex_state = 2},
  [18113] = {.lex_state = 420, .external_lex_state = 2},
  [18114] = {.lex_state = 420, .external_lex_state = 2},
  [18115] = {.lex_state = 420, .external_lex_state = 2},
  [18116] = {.lex_state = 18, .external_lex_state = 2},
  [18117] = {.lex_state = 420, .external_lex_state = 2},
  [18118] = {.lex_state = 420, .external_lex_state = 2},
  [18119] = {.lex_state = 420, .external_lex_state = 2},
  [18120] = {.lex_state = 420, .external_lex_state = 2},
  [18121] = {.lex_state = 420, .external_lex_state = 2},
  [18122] = {.lex_state = 420, .external_lex_state = 2},
  [18123] = {.lex_state = 420, .external_lex_state = 2},
  [18124] = {.lex_state = 420, .external_lex_state = 2},
  [18125] = {.lex_state = 420, .external_lex_state = 2},
  [18126] = {.lex_state = 18, .external_lex_state = 2},
  [18127] = {.lex_state = 18, .external_lex_state = 2},
  [18128] = {.lex_state = 420, .external_lex_state = 2},
  [18129] = {.lex_state = 420, .external_lex_state = 2},
  [18130] = {.lex_state = 420, .external_lex_state = 2},
  [18131] = {.lex_state = 420, .external_lex_state = 2},
  [18132] = {.lex_state = 420, .external_lex_state = 2},
  [18133] = {.lex_state = 420, .external_lex_state = 2},
  [18134] = {.lex_state = 420, .external_lex_state = 2},
  [18135] = {.lex_state = 420, .external_lex_state = 2},
  [18136] = {.lex_state = 420, .external_lex_state = 2},
  [18137] = {.lex_state = 420, .external_lex_state = 2},
  [18138] = {.lex_state = 12, .external_lex_state = 2},
  [18139] = {.lex_state = 18, .external_lex_state = 2},
  [18140] = {.lex_state = 420, .external_lex_state = 2},
  [18141] = {.lex_state = 12, .external_lex_state = 2},
  [18142] = {.lex_state = 420, .external_lex_state = 2},
  [18143] = {.lex_state = 420, .external_lex_state = 2},
  [18144] = {.lex_state = 420, .external_lex_state = 2},
  [18145] = {.lex_state = 420, .external_lex_state = 2},
  [18146] = {.lex_state = 12, .external_lex_state = 2},
  [18147] = {.lex_state = 420, .external_lex_state = 2},
  [18148] = {.lex_state = 18, .external_lex_state = 2},
  [18149] = {.lex_state = 12, .external_lex_state = 2},
  [18150] = {.lex_state = 420, .external_lex_state = 2},
  [18151] = {.lex_state = 420, .external_lex_state = 2},
  [18152] = {.lex_state = 420, .external_lex_state = 2},
  [18153] = {.lex_state = 420, .external_lex_state = 2},
  [18154] = {.lex_state = 420, .external_lex_state = 2},
  [18155] = {.lex_state = 420, .external_lex_state = 2},
  [18156] = {.lex_state = 420, .external_lex_state = 2},
  [18157] = {.lex_state = 420, .external_lex_state = 2},
  [18158] = {.lex_state = 420, .external_lex_state = 2},
  [18159] = {.lex_state = 18, .external_lex_state = 2},
  [18160] = {.lex_state = 18, .external_lex_state = 2},
  [18161] = {.lex_state = 18, .external_lex_state = 2},
  [18162] = {.lex_state = 420, .external_lex_state = 2},
  [18163] = {.lex_state = 420, .external_lex_state = 2},
  [18164] = {.lex_state = 420, .external_lex_state = 2},
  [18165] = {.lex_state = 420, .external_lex_state = 2},
  [18166] = {.lex_state = 420, .external_lex_state = 2},
  [18167] = {.lex_state = 420, .external_lex_state = 2},
  [18168] = {.lex_state = 420, .external_lex_state = 2},
  [18169] = {.lex_state = 420, .external_lex_state = 2},
  [18170] = {.lex_state = 28, .external_lex_state = 2},
  [18171] = {.lex_state = 420, .external_lex_state = 2},
  [18172] = {.lex_state = 420, .external_lex_state = 2},
  [18173] = {.lex_state = 420, .external_lex_state = 3},
  [18174] = {.lex_state = 420, .external_lex_state = 2},
  [18175] = {.lex_state = 11, .external_lex_state = 2},
  [18176] = {.lex_state = 420, .external_lex_state = 2},
  [18177] = {.lex_state = 420, .external_lex_state = 2},
  [18178] = {.lex_state = 420, .external_lex_state = 2},
  [18179] = {.lex_state = 420, .external_lex_state = 2},
  [18180] = {.lex_state = 11, .external_lex_state = 2},
  [18181] = {.lex_state = 420, .external_lex_state = 2},
  [18182] = {.lex_state = 420, .external_lex_state = 2},
  [18183] = {.lex_state = 420, .external_lex_state = 3},
  [18184] = {.lex_state = 28, .external_lex_state = 2},
  [18185] = {.lex_state = 420, .external_lex_state = 2},
  [18186] = {.lex_state = 420, .external_lex_state = 2},
  [18187] = {.lex_state = 420, .external_lex_state = 2},
  [18188] = {.lex_state = 12, .external_lex_state = 2},
  [18189] = {.lex_state = 420, .external_lex_state = 2},
  [18190] = {.lex_state = 12, .external_lex_state = 2},
  [18191] = {.lex_state = 12, .external_lex_state = 2},
  [18192] = {.lex_state = 12, .external_lex_state = 2},
  [18193] = {.lex_state = 420, .external_lex_state = 2},
  [18194] = {.lex_state = 420, .external_lex_state = 2},
  [18195] = {.lex_state = 420, .external_lex_state = 2},
  [18196] = {.lex_state = 420, .external_lex_state = 2},
  [18197] = {.lex_state = 420, .external_lex_state = 2},
  [18198] = {.lex_state = 18, .external_lex_state = 2},
  [18199] = {.lex_state = 420, .external_lex_state = 2},
  [18200] = {.lex_state = 420, .external_lex_state = 2},
  [18201] = {.lex_state = 18, .external_lex_state = 2},
  [18202] = {.lex_state = 420, .external_lex_state = 2},
  [18203] = {.lex_state = 420, .external_lex_state = 2},
  [18204] = {.lex_state = 420, .external_lex_state = 2},
  [18205] = {.lex_state = 420, .external_lex_state = 2},
  [18206] = {.lex_state = 420, .external_lex_state = 2},
  [18207] = {.lex_state = 420, .external_lex_state = 2},
  [18208] = {.lex_state = 420, .external_lex_state = 2},
  [18209] = {.lex_state = 420, .external_lex_state = 2},
  [18210] = {.lex_state = 420, .external_lex_state = 2},
  [18211] = {.lex_state = 18, .external_lex_state = 2},
  [18212] = {.lex_state = 420, .external_lex_state = 2},
  [18213] = {.lex_state = 420, .external_lex_state = 2},
  [18214] = {.lex_state = 420, .external_lex_state = 2},
  [18215] = {.lex_state = 420, .external_lex_state = 2},
  [18216] = {.lex_state = 420, .external_lex_state = 2},
  [18217] = {.lex_state = 420, .external_lex_state = 2},
  [18218] = {.lex_state = 420, .external_lex_state = 2},
  [18219] = {.lex_state = 420, .external_lex_state = 2},
  [18220] = {.lex_state = 18, .external_lex_state = 2},
  [18221] = {.lex_state = 420, .external_lex_state = 2},
  [18222] = {.lex_state = 420, .external_lex_state = 2},
  [18223] = {.lex_state = 18, .external_lex_state = 2},
  [18224] = {.lex_state = 420, .external_lex_state = 2},
  [18225] = {.lex_state = 420, .external_lex_state = 2},
  [18226] = {.lex_state = 420, .external_lex_state = 2},
  [18227] = {.lex_state = 420, .external_lex_state = 2},
  [18228] = {.lex_state = 420, .external_lex_state = 2},
  [18229] = {.lex_state = 420, .external_lex_state = 2},
  [18230] = {.lex_state = 420, .external_lex_state = 2},
  [18231] = {.lex_state = 420, .external_lex_state = 2},
  [18232] = {.lex_state = 420, .external_lex_state = 2},
  [18233] = {.lex_state = 420, .external_lex_state = 2},
  [18234] = {.lex_state = 420, .external_lex_state = 2},
  [18235] = {.lex_state = 420, .external_lex_state = 2},
  [18236] = {.lex_state = 420, .external_lex_state = 2},
  [18237] = {.lex_state = 18, .external_lex_state = 2},
  [18238] = {.lex_state = 420, .external_lex_state = 2},
  [18239] = {.lex_state = 420, .external_lex_state = 2},
  [18240] = {.lex_state = 420, .external_lex_state = 2},
  [18241] = {.lex_state = 420, .external_lex_state = 2},
  [18242] = {.lex_state = 420, .external_lex_state = 2},
  [18243] = {.lex_state = 420, .external_lex_state = 2},
  [18244] = {.lex_state = 420, .external_lex_state = 2},
  [18245] = {.lex_state = 18, .external_lex_state = 2},
  [18246] = {.lex_state = 18, .external_lex_state = 2},
  [18247] = {.lex_state = 18, .external_lex_state = 2},
  [18248] = {.lex_state = 420, .external_lex_state = 2},
  [18249] = {.lex_state = 420, .external_lex_state = 2},
  [18250] = {.lex_state = 420, .external_lex_state = 2},
  [18251] = {.lex_state = 420, .external_lex_state = 2},
  [18252] = {.lex_state = 420, .external_lex_state = 2},
  [18253] = {.lex_state = 420, .external_lex_state = 2},
  [18254] = {.lex_state = 420, .external_lex_state = 2},
  [18255] = {.lex_state = 420, .external_lex_state = 2},
  [18256] = {.lex_state = 28, .external_lex_state = 2},
  [18257] = {.lex_state = 420, .external_lex_state = 2},
  [18258] = {.lex_state = 420, .external_lex_state = 2},
  [18259] = {.lex_state = 420, .external_lex_state = 2},
  [18260] = {.lex_state = 420, .external_lex_state = 3},
  [18261] = {.lex_state = 11, .external_lex_state = 2},
  [18262] = {.lex_state = 420, .external_lex_state = 2},
  [18263] = {.lex_state = 420, .external_lex_state = 2},
  [18264] = {.lex_state = 420, .external_lex_state = 2},
  [18265] = {.lex_state = 420, .external_lex_state = 2},
  [18266] = {.lex_state = 420, .external_lex_state = 2},
  [18267] = {.lex_state = 420, .external_lex_state = 2},
  [18268] = {.lex_state = 420, .external_lex_state = 2},
  [18269] = {.lex_state = 420, .external_lex_state = 2},
  [18270] = {.lex_state = 420, .external_lex_state = 2},
  [18271] = {.lex_state = 420, .external_lex_state = 2},
  [18272] = {.lex_state = 18, .external_lex_state = 2},
  [18273] = {.lex_state = 420, .external_lex_state = 2},
  [18274] = {.lex_state = 420, .external_lex_state = 2},
  [18275] = {.lex_state = 420, .external_lex_state = 2},
  [18276] = {.lex_state = 420, .external_lex_state = 2},
  [18277] = {.lex_state = 12, .external_lex_state = 2},
  [18278] = {.lex_state = 420, .external_lex_state = 2},
  [18279] = {.lex_state = 12, .external_lex_state = 2},
  [18280] = {.lex_state = 12, .external_lex_state = 2},
  [18281] = {.lex_state = 12, .external_lex_state = 2},
  [18282] = {.lex_state = 420, .external_lex_state = 2},
  [18283] = {.lex_state = 420, .external_lex_state = 2},
  [18284] = {.lex_state = 420, .external_lex_state = 2},
  [18285] = {.lex_state = 420, .external_lex_state = 2},
  [18286] = {.lex_state = 18, .external_lex_state = 2},
  [18287] = {.lex_state = 12, .external_lex_state = 2},
  [18288] = {.lex_state = 420, .external_lex_state = 2},
  [18289] = {.lex_state = 420, .external_lex_state = 2},
  [18290] = {.lex_state = 420, .external_lex_state = 2},
  [18291] = {.lex_state = 12, .external_lex_state = 2},
  [18292] = {.lex_state = 12, .external_lex_state = 2},
  [18293] = {.lex_state = 420, .external_lex_state = 2},
  [18294] = {.lex_state = 420, .external_lex_state = 2},
  [18295] = {.lex_state = 12, .external_lex_state = 2},
  [18296] = {.lex_state = 18, .external_lex_state = 2},
  [18297] = {.lex_state = 420, .external_lex_state = 2},
  [18298] = {.lex_state = 420, .external_lex_state = 2},
  [18299] = {.lex_state = 420, .external_lex_state = 2},
  [18300] = {.lex_state = 420, .external_lex_state = 2},
  [18301] = {.lex_state = 420, .external_lex_state = 2},
  [18302] = {.lex_state = 420, .external_lex_state = 2},
  [18303] = {.lex_state = 420, .external_lex_state = 2},
  [18304] = {.lex_state = 420, .external_lex_state = 2},
  [18305] = {.lex_state = 420, .external_lex_state = 2},
  [18306] = {.lex_state = 420, .external_lex_state = 2},
  [18307] = {.lex_state = 420, .external_lex_state = 2},
  [18308] = {.lex_state = 420, .external_lex_state = 2},
  [18309] = {.lex_state = 11, .external_lex_state = 2},
  [18310] = {.lex_state = 18, .external_lex_state = 2},
  [18311] = {.lex_state = 420, .external_lex_state = 2},
  [18312] = {.lex_state = 420, .external_lex_state = 3},
  [18313] = {.lex_state = 420, .external_lex_state = 2},
  [18314] = {.lex_state = 420, .external_lex_state = 2},
  [18315] = {.lex_state = 420, .external_lex_state = 2},
  [18316] = {.lex_state = 420, .external_lex_state = 2},
  [18317] = {.lex_state = 420, .external_lex_state = 2},
  [18318] = {.lex_state = 28, .external_lex_state = 2},
  [18319] = {.lex_state = 420, .external_lex_state = 2},
  [18320] = {.lex_state = 420, .external_lex_state = 2},
  [18321] = {.lex_state = 420, .external_lex_state = 2},
  [18322] = {.lex_state = 18, .external_lex_state = 2},
  [18323] = {.lex_state = 420, .external_lex_state = 2},
  [18324] = {.lex_state = 420, .external_lex_state = 2},
  [18325] = {.lex_state = 420, .external_lex_state = 2},
  [18326] = {.lex_state = 420, .external_lex_state = 2},
  [18327] = {.lex_state = 420, .external_lex_state = 2},
  [18328] = {.lex_state = 420, .external_lex_state = 2},
  [18329] = {.lex_state = 420, .external_lex_state = 2},
  [18330] = {.lex_state = 420, .external_lex_state = 2},
  [18331] = {.lex_state = 420, .external_lex_state = 2},
  [18332] = {.lex_state = 18, .external_lex_state = 2},
  [18333] = {.lex_state = 18, .external_lex_state = 2},
  [18334] = {.lex_state = 18, .external_lex_state = 2},
  [18335] = {.lex_state = 18, .external_lex_state = 2},
  [18336] = {.lex_state = 420, .external_lex_state = 2},
  [18337] = {.lex_state = 420, .external_lex_state = 2},
  [18338] = {.lex_state = 420, .external_lex_state = 2},
  [18339] = {.lex_state = 420, .external_lex_state = 2},
  [18340] = {.lex_state = 420, .external_lex_state = 2},
  [18341] = {.lex_state = 420, .external_lex_state = 2},
  [18342] = {.lex_state = 420, .external_lex_state = 2},
  [18343] = {.lex_state = 420, .external_lex_state = 2},
  [18344] = {.lex_state = 18, .external_lex_state = 2},
  [18345] = {.lex_state = 420, .external_lex_state = 2},
  [18346] = {.lex_state = 28, .external_lex_state = 2},
  [18347] = {.lex_state = 420, .external_lex_state = 2},
  [18348] = {.lex_state = 420, .external_lex_state = 2},
  [18349] = {.lex_state = 420, .external_lex_state = 2},
  [18350] = {.lex_state = 420, .external_lex_state = 3},
  [18351] = {.lex_state = 11, .external_lex_state = 2},
  [18352] = {.lex_state = 420, .external_lex_state = 2},
  [18353] = {.lex_state = 420, .external_lex_state = 2},
  [18354] = {.lex_state = 420, .external_lex_state = 2},
  [18355] = {.lex_state = 420, .external_lex_state = 2},
  [18356] = {.lex_state = 420, .external_lex_state = 2},
  [18357] = {.lex_state = 420, .external_lex_state = 2},
  [18358] = {.lex_state = 420, .external_lex_state = 2},
  [18359] = {.lex_state = 420, .external_lex_state = 2},
  [18360] = {.lex_state = 420, .external_lex_state = 2},
  [18361] = {.lex_state = 420, .external_lex_state = 2},
  [18362] = {.lex_state = 12, .external_lex_state = 2},
  [18363] = {.lex_state = 12, .external_lex_state = 2},
  [18364] = {.lex_state = 420, .external_lex_state = 2},
  [18365] = {.lex_state = 12, .external_lex_state = 2},
  [18366] = {.lex_state = 12, .external_lex_state = 2},
  [18367] = {.lex_state = 420, .external_lex_state = 2},
  [18368] = {.lex_state = 420, .external_lex_state = 2},
  [18369] = {.lex_state = 420, .external_lex_state = 2},
  [18370] = {.lex_state = 420, .external_lex_state = 2},
  [18371] = {.lex_state = 420, .external_lex_state = 2},
  [18372] = {.lex_state = 420, .external_lex_state = 2},
  [18373] = {.lex_state = 420, .external_lex_state = 2},
  [18374] = {.lex_state = 18, .external_lex_state = 2},
  [18375] = {.lex_state = 420, .external_lex_state = 2},
  [18376] = {.lex_state = 420, .external_lex_state = 2},
  [18377] = {.lex_state = 420, .external_lex_state = 2},
  [18378] = {.lex_state = 420, .external_lex_state = 2},
  [18379] = {.lex_state = 420, .external_lex_state = 2},
  [18380] = {.lex_state = 420, .external_lex_state = 2},
  [18381] = {.lex_state = 420, .external_lex_state = 2},
  [18382] = {.lex_state = 420, .external_lex_state = 2},
  [18383] = {.lex_state = 420, .external_lex_state = 2},
  [18384] = {.lex_state = 420, .external_lex_state = 2},
  [18385] = {.lex_state = 420, .external_lex_state = 2},
  [18386] = {.lex_state = 18, .external_lex_state = 2},
  [18387] = {.lex_state = 420, .external_lex_state = 2},
  [18388] = {.lex_state = 420, .external_lex_state = 2},
  [18389] = {.lex_state = 420, .external_lex_state = 2},
  [18390] = {.lex_state = 420, .external_lex_state = 2},
  [18391] = {.lex_state = 420, .external_lex_state = 2},
  [18392] = {.lex_state = 420, .external_lex_state = 2},
  [18393] = {.lex_state = 420, .external_lex_state = 2},
  [18394] = {.lex_state = 420, .external_lex_state = 2},
  [18395] = {.lex_state = 420, .external_lex_state = 2},
  [18396] = {.lex_state = 420, .external_lex_state = 2},
  [18397] = {.lex_state = 420, .external_lex_state = 2},
  [18398] = {.lex_state = 18, .external_lex_state = 2},
  [18399] = {.lex_state = 18, .external_lex_state = 2},
  [18400] = {.lex_state = 420, .external_lex_state = 2},
  [18401] = {.lex_state = 420, .external_lex_state = 2},
  [18402] = {.lex_state = 420, .external_lex_state = 2},
  [18403] = {.lex_state = 420, .external_lex_state = 2},
  [18404] = {.lex_state = 420, .external_lex_state = 2},
  [18405] = {.lex_state = 420, .external_lex_state = 2},
  [18406] = {.lex_state = 420, .external_lex_state = 2},
  [18407] = {.lex_state = 18, .external_lex_state = 2},
  [18408] = {.lex_state = 420, .external_lex_state = 2},
  [18409] = {.lex_state = 420, .external_lex_state = 2},
  [18410] = {.lex_state = 420, .external_lex_state = 2},
  [18411] = {.lex_state = 420, .external_lex_state = 2},
  [18412] = {.lex_state = 420, .external_lex_state = 2},
  [18413] = {.lex_state = 420, .external_lex_state = 2},
  [18414] = {.lex_state = 420, .external_lex_state = 2},
  [18415] = {.lex_state = 420, .external_lex_state = 2},
  [18416] = {.lex_state = 12, .external_lex_state = 2},
  [18417] = {.lex_state = 420, .external_lex_state = 2},
  [18418] = {.lex_state = 420, .external_lex_state = 2},
  [18419] = {.lex_state = 18, .external_lex_state = 2},
  [18420] = {.lex_state = 18, .external_lex_state = 2},
  [18421] = {.lex_state = 18, .external_lex_state = 2},
  [18422] = {.lex_state = 420, .external_lex_state = 2},
  [18423] = {.lex_state = 12, .external_lex_state = 2},
  [18424] = {.lex_state = 420, .external_lex_state = 2},
  [18425] = {.lex_state = 12, .external_lex_state = 2},
  [18426] = {.lex_state = 420, .external_lex_state = 2},
  [18427] = {.lex_state = 420, .external_lex_state = 2},
  [18428] = {.lex_state = 12, .external_lex_state = 2},
  [18429] = {.lex_state = 420, .external_lex_state = 2},
  [18430] = {.lex_state = 420, .external_lex_state = 2},
  [18431] = {.lex_state = 420, .external_lex_state = 2},
  [18432] = {.lex_state = 28, .external_lex_state = 2},
  [18433] = {.lex_state = 420, .external_lex_state = 2},
  [18434] = {.lex_state = 420, .external_lex_state = 2},
  [18435] = {.lex_state = 420, .external_lex_state = 2},
  [18436] = {.lex_state = 420, .external_lex_state = 2},
  [18437] = {.lex_state = 420, .external_lex_state = 2},
  [18438] = {.lex_state = 420, .external_lex_state = 2},
  [18439] = {.lex_state = 420, .external_lex_state = 3},
  [18440] = {.lex_state = 11, .external_lex_state = 2},
  [18441] = {.lex_state = 420, .external_lex_state = 2},
  [18442] = {.lex_state = 420, .external_lex_state = 2},
  [18443] = {.lex_state = 11, .external_lex_state = 2},
  [18444] = {.lex_state = 420, .external_lex_state = 2},
  [18445] = {.lex_state = 420, .external_lex_state = 2},
  [18446] = {.lex_state = 420, .external_lex_state = 3},
  [18447] = {.lex_state = 12, .external_lex_state = 2},
  [18448] = {.lex_state = 420, .external_lex_state = 2},
  [18449] = {.lex_state = 420, .external_lex_state = 2},
  [18450] = {.lex_state = 420, .external_lex_state = 2},
  [18451] = {.lex_state = 12, .external_lex_state = 2},
  [18452] = {.lex_state = 28, .external_lex_state = 2},
  [18453] = {.lex_state = 12, .external_lex_state = 2},
  [18454] = {.lex_state = 12, .external_lex_state = 2},
  [18455] = {.lex_state = 420, .external_lex_state = 2},
  [18456] = {.lex_state = 420, .external_lex_state = 2},
  [18457] = {.lex_state = 420, .external_lex_state = 2},
  [18458] = {.lex_state = 420, .external_lex_state = 2},
  [18459] = {.lex_state = 18, .external_lex_state = 2},
  [18460] = {.lex_state = 420, .external_lex_state = 2},
  [18461] = {.lex_state = 420, .external_lex_state = 2},
  [18462] = {.lex_state = 420, .external_lex_state = 2},
  [18463] = {.lex_state = 420, .external_lex_state = 2},
  [18464] = {.lex_state = 18, .external_lex_state = 2},
  [18465] = {.lex_state = 420, .external_lex_state = 2},
  [18466] = {.lex_state = 420, .external_lex_state = 2},
  [18467] = {.lex_state = 420, .external_lex_state = 2},
  [18468] = {.lex_state = 420, .external_lex_state = 2},
  [18469] = {.lex_state = 420, .external_lex_state = 2},
  [18470] = {.lex_state = 420, .external_lex_state = 2},
  [18471] = {.lex_state = 18, .external_lex_state = 2},
  [18472] = {.lex_state = 18, .external_lex_state = 2},
  [18473] = {.lex_state = 420, .external_lex_state = 2},
  [18474] = {.lex_state = 420, .external_lex_state = 2},
  [18475] = {.lex_state = 420, .external_lex_state = 2},
  [18476] = {.lex_state = 420, .external_lex_state = 2},
  [18477] = {.lex_state = 420, .external_lex_state = 2},
  [18478] = {.lex_state = 420, .external_lex_state = 2},
  [18479] = {.lex_state = 420, .external_lex_state = 2},
  [18480] = {.lex_state = 420, .external_lex_state = 2},
  [18481] = {.lex_state = 420, .external_lex_state = 2},
  [18482] = {.lex_state = 420, .external_lex_state = 2},
  [18483] = {.lex_state = 18, .external_lex_state = 2},
  [18484] = {.lex_state = 420, .external_lex_state = 2},
  [18485] = {.lex_state = 420, .external_lex_state = 2},
  [18486] = {.lex_state = 420, .external_lex_state = 2},
  [18487] = {.lex_state = 420, .external_lex_state = 2},
  [18488] = {.lex_state = 420, .external_lex_state = 2},
  [18489] = {.lex_state = 420, .external_lex_state = 2},
  [18490] = {.lex_state = 420, .external_lex_state = 2},
  [18491] = {.lex_state = 420, .external_lex_state = 2},
  [18492] = {.lex_state = 420, .external_lex_state = 2},
  [18493] = {.lex_state = 420, .external_lex_state = 2},
  [18494] = {.lex_state = 420, .external_lex_state = 2},
  [18495] = {.lex_state = 18, .external_lex_state = 2},
  [18496] = {.lex_state = 420, .external_lex_state = 2},
  [18497] = {.lex_state = 420, .external_lex_state = 2},
  [18498] = {.lex_state = 420, .external_lex_state = 2},
  [18499] = {.lex_state = 420, .external_lex_state = 2},
  [18500] = {.lex_state = 420, .external_lex_state = 2},
  [18501] = {.lex_state = 420, .external_lex_state = 2},
  [18502] = {.lex_state = 420, .external_lex_state = 2},
  [18503] = {.lex_state = 420, .external_lex_state = 2},
  [18504] = {.lex_state = 420, .external_lex_state = 2},
  [18505] = {.lex_state = 420, .external_lex_state = 2},
  [18506] = {.lex_state = 420, .external_lex_state = 2},
  [18507] = {.lex_state = 420, .external_lex_state = 2},
  [18508] = {.lex_state = 18, .external_lex_state = 2},
  [18509] = {.lex_state = 420, .external_lex_state = 2},
  [18510] = {.lex_state = 18, .external_lex_state = 2},
  [18511] = {.lex_state = 18, .external_lex_state = 2},
  [18512] = {.lex_state = 420, .external_lex_state = 2},
  [18513] = {.lex_state = 420, .external_lex_state = 2},
  [18514] = {.lex_state = 420, .external_lex_state = 2},
  [18515] = {.lex_state = 420, .external_lex_state = 2},
  [18516] = {.lex_state = 420, .external_lex_state = 2},
  [18517] = {.lex_state = 420, .external_lex_state = 2},
  [18518] = {.lex_state = 420, .external_lex_state = 2},
  [18519] = {.lex_state = 420, .external_lex_state = 2},
  [18520] = {.lex_state = 420, .external_lex_state = 2},
  [18521] = {.lex_state = 28, .external_lex_state = 2},
  [18522] = {.lex_state = 420, .external_lex_state = 2},
  [18523] = {.lex_state = 420, .external_lex_state = 3},
  [18524] = {.lex_state = 420, .external_lex_state = 2},
  [18525] = {.lex_state = 11, .external_lex_state = 2},
  [18526] = {.lex_state = 420, .external_lex_state = 2},
  [18527] = {.lex_state = 420, .external_lex_state = 2},
  [18528] = {.lex_state = 420, .external_lex_state = 2},
  [18529] = {.lex_state = 420, .external_lex_state = 2},
  [18530] = {.lex_state = 420, .external_lex_state = 2},
  [18531] = {.lex_state = 18, .external_lex_state = 2},
  [18532] = {.lex_state = 420, .external_lex_state = 2},
  [18533] = {.lex_state = 420, .external_lex_state = 2},
  [18534] = {.lex_state = 420, .external_lex_state = 2},
  [18535] = {.lex_state = 12, .external_lex_state = 2},
  [18536] = {.lex_state = 12, .external_lex_state = 2},
  [18537] = {.lex_state = 420, .external_lex_state = 2},
  [18538] = {.lex_state = 420, .external_lex_state = 2},
  [18539] = {.lex_state = 12, .external_lex_state = 2},
  [18540] = {.lex_state = 12, .external_lex_state = 2},
  [18541] = {.lex_state = 420, .external_lex_state = 2},
  [18542] = {.lex_state = 420, .external_lex_state = 2},
  [18543] = {.lex_state = 12, .external_lex_state = 2},
  [18544] = {.lex_state = 12, .external_lex_state = 2},
  [18545] = {.lex_state = 12, .external_lex_state = 2},
  [18546] = {.lex_state = 420, .external_lex_state = 2},
  [18547] = {.lex_state = 420, .external_lex_state = 2},
  [18548] = {.lex_state = 420, .external_lex_state = 2},
  [18549] = {.lex_state = 420, .external_lex_state = 2},
  [18550] = {.lex_state = 18, .external_lex_state = 2},
  [18551] = {.lex_state = 420, .external_lex_state = 2},
  [18552] = {.lex_state = 420, .external_lex_state = 2},
  [18553] = {.lex_state = 420, .external_lex_state = 2},
  [18554] = {.lex_state = 420, .external_lex_state = 2},
  [18555] = {.lex_state = 420, .external_lex_state = 2},
  [18556] = {.lex_state = 420, .external_lex_state = 2},
  [18557] = {.lex_state = 11, .external_lex_state = 2},
  [18558] = {.lex_state = 420, .external_lex_state = 3},
  [18559] = {.lex_state = 420, .external_lex_state = 2},
  [18560] = {.lex_state = 420, .external_lex_state = 2},
  [18561] = {.lex_state = 18, .external_lex_state = 2},
  [18562] = {.lex_state = 420, .external_lex_state = 2},
  [18563] = {.lex_state = 420, .external_lex_state = 2},
  [18564] = {.lex_state = 420, .external_lex_state = 2},
  [18565] = {.lex_state = 420, .external_lex_state = 2},
  [18566] = {.lex_state = 420, .external_lex_state = 2},
  [18567] = {.lex_state = 420, .external_lex_state = 2},
  [18568] = {.lex_state = 420, .external_lex_state = 2},
  [18569] = {.lex_state = 420, .external_lex_state = 2},
  [18570] = {.lex_state = 420, .external_lex_state = 2},
  [18571] = {.lex_state = 18, .external_lex_state = 2},
  [18572] = {.lex_state = 420, .external_lex_state = 2},
  [18573] = {.lex_state = 420, .external_lex_state = 2},
  [18574] = {.lex_state = 420, .external_lex_state = 2},
  [18575] = {.lex_state = 420, .external_lex_state = 2},
  [18576] = {.lex_state = 420, .external_lex_state = 2},
  [18577] = {.lex_state = 420, .external_lex_state = 2},
  [18578] = {.lex_state = 420, .external_lex_state = 2},
  [18579] = {.lex_state = 420, .external_lex_state = 2},
  [18580] = {.lex_state = 420, .external_lex_state = 2},
  [18581] = {.lex_state = 18, .external_lex_state = 2},
  [18582] = {.lex_state = 420, .external_lex_state = 2},
  [18583] = {.lex_state = 420, .external_lex_state = 2},
  [18584] = {.lex_state = 28, .external_lex_state = 2},
  [18585] = {.lex_state = 420, .external_lex_state = 2},
  [18586] = {.lex_state = 420, .external_lex_state = 2},
  [18587] = {.lex_state = 420, .external_lex_state = 2},
  [18588] = {.lex_state = 420, .external_lex_state = 2},
  [18589] = {.lex_state = 420, .external_lex_state = 2},
  [18590] = {.lex_state = 420, .external_lex_state = 2},
  [18591] = {.lex_state = 420, .external_lex_state = 2},
  [18592] = {.lex_state = 18, .external_lex_state = 2},
  [18593] = {.lex_state = 420, .external_lex_state = 2},
  [18594] = {.lex_state = 420, .external_lex_state = 2},
  [18595] = {.lex_state = 420, .external_lex_state = 2},
  [18596] = {.lex_state = 420, .external_lex_state = 2},
  [18597] = {.lex_state = 18, .external_lex_state = 2},
  [18598] = {.lex_state = 18, .external_lex_state = 2},
  [18599] = {.lex_state = 18, .external_lex_state = 2},
  [18600] = {.lex_state = 420, .external_lex_state = 2},
  [18601] = {.lex_state = 420, .external_lex_state = 2},
  [18602] = {.lex_state = 420, .external_lex_state = 2},
  [18603] = {.lex_state = 420, .external_lex_state = 2},
  [18604] = {.lex_state = 420, .external_lex_state = 2},
  [18605] = {.lex_state = 28, .external_lex_state = 2},
  [18606] = {.lex_state = 420, .external_lex_state = 2},
  [18607] = {.lex_state = 420, .external_lex_state = 2},
  [18608] = {.lex_state = 420, .external_lex_state = 2},
  [18609] = {.lex_state = 420, .external_lex_state = 2},
  [18610] = {.lex_state = 420, .external_lex_state = 3},
  [18611] = {.lex_state = 18, .external_lex_state = 2},
  [18612] = {.lex_state = 11, .external_lex_state = 2},
  [18613] = {.lex_state = 420, .external_lex_state = 2},
  [18614] = {.lex_state = 420, .external_lex_state = 2},
  [18615] = {.lex_state = 420, .external_lex_state = 2},
  [18616] = {.lex_state = 420, .external_lex_state = 2},
  [18617] = {.lex_state = 420, .external_lex_state = 2},
  [18618] = {.lex_state = 420, .external_lex_state = 2},
  [18619] = {.lex_state = 12, .external_lex_state = 2},
  [18620] = {.lex_state = 12, .external_lex_state = 2},
  [18621] = {.lex_state = 420, .external_lex_state = 2},
  [18622] = {.lex_state = 420, .external_lex_state = 2},
  [18623] = {.lex_state = 420, .external_lex_state = 2},
  [18624] = {.lex_state = 420, .external_lex_state = 2},
  [18625] = {.lex_state = 12, .external_lex_state = 2},
  [18626] = {.lex_state = 420, .external_lex_state = 2},
  [18627] = {.lex_state = 12, .external_lex_state = 2},
  [18628] = {.lex_state = 420, .external_lex_state = 2},
  [18629] = {.lex_state = 12, .external_lex_state = 2},
  [18630] = {.lex_state = 420, .external_lex_state = 2},
  [18631] = {.lex_state = 420, .external_lex_state = 2},
  [18632] = {.lex_state = 420, .external_lex_state = 2},
  [18633] = {.lex_state = 420, .external_lex_state = 2},
  [18634] = {.lex_state = 420, .external_lex_state = 2},
  [18635] = {.lex_state = 420, .external_lex_state = 2},
  [18636] = {.lex_state = 420, .external_lex_state = 2},
  [18637] = {.lex_state = 18, .external_lex_state = 2},
  [18638] = {.lex_state = 420, .external_lex_state = 2},
  [18639] = {.lex_state = 420, .external_lex_state = 2},
  [18640] = {.lex_state = 420, .external_lex_state = 2},
  [18641] = {.lex_state = 420, .external_lex_state = 2},
  [18642] = {.lex_state = 420, .external_lex_state = 2},
  [18643] = {.lex_state = 420, .external_lex_state = 2},
  [18644] = {.lex_state = 18, .external_lex_state = 2},
  [18645] = {.lex_state = 420, .external_lex_state = 2},
  [18646] = {.lex_state = 420, .external_lex_state = 2},
  [18647] = {.lex_state = 420, .external_lex_state = 2},
  [18648] = {.lex_state = 420, .external_lex_state = 2},
  [18649] = {.lex_state = 420, .external_lex_state = 2},
  [18650] = {.lex_state = 420, .external_lex_state = 2},
  [18651] = {.lex_state = 420, .external_lex_state = 2},
  [18652] = {.lex_state = 420, .external_lex_state = 2},
  [18653] = {.lex_state = 420, .external_lex_state = 2},
  [18654] = {.lex_state = 18, .external_lex_state = 2},
  [18655] = {.lex_state = 420, .external_lex_state = 2},
  [18656] = {.lex_state = 420, .external_lex_state = 2},
  [18657] = {.lex_state = 420, .external_lex_state = 2},
  [18658] = {.lex_state = 420, .external_lex_state = 2},
  [18659] = {.lex_state = 420, .external_lex_state = 2},
  [18660] = {.lex_state = 420, .external_lex_state = 2},
  [18661] = {.lex_state = 420, .external_lex_state = 2},
  [18662] = {.lex_state = 12, .external_lex_state = 2},
  [18663] = {.lex_state = 420, .external_lex_state = 2},
  [18664] = {.lex_state = 420, .external_lex_state = 2},
  [18665] = {.lex_state = 420, .external_lex_state = 2},
  [18666] = {.lex_state = 420, .external_lex_state = 2},
  [18667] = {.lex_state = 12, .external_lex_state = 2},
  [18668] = {.lex_state = 420, .external_lex_state = 2},
  [18669] = {.lex_state = 18, .external_lex_state = 2},
  [18670] = {.lex_state = 18, .external_lex_state = 2},
  [18671] = {.lex_state = 420, .external_lex_state = 2},
  [18672] = {.lex_state = 420, .external_lex_state = 2},
  [18673] = {.lex_state = 420, .external_lex_state = 2},
  [18674] = {.lex_state = 420, .external_lex_state = 2},
  [18675] = {.lex_state = 420, .external_lex_state = 2},
  [18676] = {.lex_state = 420, .external_lex_state = 2},
  [18677] = {.lex_state = 420, .external_lex_state = 2},
  [18678] = {.lex_state = 12, .external_lex_state = 2},
  [18679] = {.lex_state = 18, .external_lex_state = 2},
  [18680] = {.lex_state = 420, .external_lex_state = 2},
  [18681] = {.lex_state = 18, .external_lex_state = 2},
  [18682] = {.lex_state = 18, .external_lex_state = 2},
  [18683] = {.lex_state = 420, .external_lex_state = 2},
  [18684] = {.lex_state = 420, .external_lex_state = 2},
  [18685] = {.lex_state = 420, .external_lex_state = 2},
  [18686] = {.lex_state = 420, .external_lex_state = 2},
  [18687] = {.lex_state = 420, .external_lex_state = 2},
  [18688] = {.lex_state = 420, .external_lex_state = 2},
  [18689] = {.lex_state = 420, .external_lex_state = 2},
  [18690] = {.lex_state = 420, .external_lex_state = 2},
  [18691] = {.lex_state = 28, .external_lex_state = 2},
  [18692] = {.lex_state = 420, .external_lex_state = 2},
  [18693] = {.lex_state = 420, .external_lex_state = 2},
  [18694] = {.lex_state = 420, .external_lex_state = 2},
  [18695] = {.lex_state = 420, .external_lex_state = 3},
  [18696] = {.lex_state = 11, .external_lex_state = 2},
  [18697] = {.lex_state = 420, .external_lex_state = 2},
  [18698] = {.lex_state = 420, .external_lex_state = 2},
  [18699] = {.lex_state = 420, .external_lex_state = 2},
  [18700] = {.lex_state = 12, .external_lex_state = 2},
  [18701] = {.lex_state = 12, .external_lex_state = 2},
  [18702] = {.lex_state = 420, .external_lex_state = 2},
  [18703] = {.lex_state = 420, .external_lex_state = 2},
  [18704] = {.lex_state = 12, .external_lex_state = 2},
  [18705] = {.lex_state = 12, .external_lex_state = 2},
  [18706] = {.lex_state = 420, .external_lex_state = 2},
  [18707] = {.lex_state = 420, .external_lex_state = 2},
  [18708] = {.lex_state = 18, .external_lex_state = 2},
  [18709] = {.lex_state = 420, .external_lex_state = 2},
  [18710] = {.lex_state = 420, .external_lex_state = 2},
  [18711] = {.lex_state = 420, .external_lex_state = 2},
  [18712] = {.lex_state = 420, .external_lex_state = 2},
  [18713] = {.lex_state = 12, .external_lex_state = 2},
  [18714] = {.lex_state = 420, .external_lex_state = 2},
  [18715] = {.lex_state = 12, .external_lex_state = 2},
  [18716] = {.lex_state = 12, .external_lex_state = 2},
  [18717] = {.lex_state = 420, .external_lex_state = 2},
  [18718] = {.lex_state = 420, .external_lex_state = 2},
  [18719] = {.lex_state = 420, .external_lex_state = 2},
  [18720] = {.lex_state = 420, .external_lex_state = 2},
  [18721] = {.lex_state = 18, .external_lex_state = 2},
  [18722] = {.lex_state = 420, .external_lex_state = 2},
  [18723] = {.lex_state = 420, .external_lex_state = 2},
  [18724] = {.lex_state = 420, .external_lex_state = 2},
  [18725] = {.lex_state = 420, .external_lex_state = 2},
  [18726] = {.lex_state = 420, .external_lex_state = 2},
  [18727] = {.lex_state = 11, .external_lex_state = 2},
  [18728] = {.lex_state = 420, .external_lex_state = 2},
  [18729] = {.lex_state = 420, .external_lex_state = 2},
  [18730] = {.lex_state = 420, .external_lex_state = 3},
  [18731] = {.lex_state = 420, .external_lex_state = 2},
  [18732] = {.lex_state = 420, .external_lex_state = 2},
  [18733] = {.lex_state = 18, .external_lex_state = 2},
  [18734] = {.lex_state = 420, .external_lex_state = 2},
  [18735] = {.lex_state = 420, .external_lex_state = 2},
  [18736] = {.lex_state = 420, .external_lex_state = 2},
  [18737] = {.lex_state = 28, .external_lex_state = 2},
  [18738] = {.lex_state = 420, .external_lex_state = 2},
  [18739] = {.lex_state = 420, .external_lex_state = 2},
  [18740] = {.lex_state = 420, .external_lex_state = 2},
  [18741] = {.lex_state = 420, .external_lex_state = 2},
  [18742] = {.lex_state = 420, .external_lex_state = 2},
  [18743] = {.lex_state = 420, .external_lex_state = 2},
  [18744] = {.lex_state = 420, .external_lex_state = 2},
  [18745] = {.lex_state = 18, .external_lex_state = 2},
  [18746] = {.lex_state = 420, .external_lex_state = 2},
  [18747] = {.lex_state = 420, .external_lex_state = 2},
  [18748] = {.lex_state = 420, .external_lex_state = 2},
  [18749] = {.lex_state = 420, .external_lex_state = 2},
  [18750] = {.lex_state = 420, .external_lex_state = 2},
  [18751] = {.lex_state = 420, .external_lex_state = 2},
  [18752] = {.lex_state = 420, .external_lex_state = 2},
  [18753] = {.lex_state = 420, .external_lex_state = 2},
  [18754] = {.lex_state = 420, .external_lex_state = 2},
  [18755] = {.lex_state = 420, .external_lex_state = 2},
  [18756] = {.lex_state = 420, .external_lex_state = 2},
  [18757] = {.lex_state = 18, .external_lex_state = 2},
  [18758] = {.lex_state = 420, .external_lex_state = 2},
  [18759] = {.lex_state = 420, .external_lex_state = 2},
  [18760] = {.lex_state = 420, .external_lex_state = 2},
  [18761] = {.lex_state = 420, .external_lex_state = 2},
  [18762] = {.lex_state = 420, .external_lex_state = 2},
  [18763] = {.lex_state = 420, .external_lex_state = 2},
  [18764] = {.lex_state = 18, .external_lex_state = 2},
  [18765] = {.lex_state = 420, .external_lex_state = 2},
  [18766] = {.lex_state = 420, .external_lex_state = 2},
  [18767] = {.lex_state = 18, .external_lex_state = 2},
  [18768] = {.lex_state = 18, .external_lex_state = 2},
  [18769] = {.lex_state = 420, .external_lex_state = 2},
  [18770] = {.lex_state = 420, .external_lex_state = 2},
  [18771] = {.lex_state = 18, .external_lex_state = 2},
  [18772] = {.lex_state = 420, .external_lex_state = 2},
  [18773] = {.lex_state = 420, .external_lex_state = 2},
  [18774] = {.lex_state = 420, .external_lex_state = 2},
  [18775] = {.lex_state = 420, .external_lex_state = 2},
  [18776] = {.lex_state = 420, .external_lex_state = 2},
  [18777] = {.lex_state = 420, .external_lex_state = 2},
  [18778] = {.lex_state = 420, .external_lex_state = 2},
  [18779] = {.lex_state = 420, .external_lex_state = 2},
  [18780] = {.lex_state = 420, .external_lex_state = 2},
  [18781] = {.lex_state = 420, .external_lex_state = 2},
  [18782] = {.lex_state = 28, .external_lex_state = 2},
  [18783] = {.lex_state = 420, .external_lex_state = 2},
  [18784] = {.lex_state = 420, .external_lex_state = 3},
  [18785] = {.lex_state = 420, .external_lex_state = 2},
  [18786] = {.lex_state = 420, .external_lex_state = 2},
  [18787] = {.lex_state = 420, .external_lex_state = 2},
  [18788] = {.lex_state = 420, .external_lex_state = 2},
  [18789] = {.lex_state = 11, .external_lex_state = 2},
  [18790] = {.lex_state = 420, .external_lex_state = 2},
  [18791] = {.lex_state = 420, .external_lex_state = 2},
  [18792] = {.lex_state = 420, .external_lex_state = 2},
  [18793] = {.lex_state = 420, .external_lex_state = 2},
  [18794] = {.lex_state = 420, .external_lex_state = 2},
  [18795] = {.lex_state = 420, .external_lex_state = 2},
  [18796] = {.lex_state = 18, .external_lex_state = 2},
  [18797] = {.lex_state = 12, .external_lex_state = 2},
  [18798] = {.lex_state = 420, .external_lex_state = 2},
  [18799] = {.lex_state = 420, .external_lex_state = 2},
  [18800] = {.lex_state = 420, .external_lex_state = 2},
  [18801] = {.lex_state = 12, .external_lex_state = 2},
  [18802] = {.lex_state = 420, .external_lex_state = 2},
  [18803] = {.lex_state = 12, .external_lex_state = 2},
  [18804] = {.lex_state = 12, .external_lex_state = 2},
  [18805] = {.lex_state = 420, .external_lex_state = 2},
  [18806] = {.lex_state = 420, .external_lex_state = 2},
  [18807] = {.lex_state = 420, .external_lex_state = 2},
  [18808] = {.lex_state = 420, .external_lex_state = 2},
  [18809] = {.lex_state = 18, .external_lex_state = 2},
  [18810] = {.lex_state = 420, .external_lex_state = 2},
  [18811] = {.lex_state = 18, .external_lex_state = 2},
  [18812] = {.lex_state = 420, .external_lex_state = 2},
  [18813] = {.lex_state = 420, .external_lex_state = 2},
  [18814] = {.lex_state = 420, .external_lex_state = 2},
  [18815] = {.lex_state = 12, .external_lex_state = 2},
  [18816] = {.lex_state = 12, .external_lex_state = 2},
  [18817] = {.lex_state = 420, .external_lex_state = 2},
  [18818] = {.lex_state = 18, .external_lex_state = 2},
  [18819] = {.lex_state = 12, .external_lex_state = 2},
  [18820] = {.lex_state = 420, .external_lex_state = 2},
  [18821] = {.lex_state = 12, .external_lex_state = 2},
  [18822] = {.lex_state = 420, .external_lex_state = 2},
  [18823] = {.lex_state = 420, .external_lex_state = 2},
  [18824] = {.lex_state = 420, .external_lex_state = 2},
  [18825] = {.lex_state = 420, .external_lex_state = 2},
  [18826] = {.lex_state = 18, .external_lex_state = 2},
  [18827] = {.lex_state = 420, .external_lex_state = 2},
  [18828] = {.lex_state = 18, .external_lex_state = 2},
  [18829] = {.lex_state = 420, .external_lex_state = 2},
  [18830] = {.lex_state = 420, .external_lex_state = 2},
  [18831] = {.lex_state = 420, .external_lex_state = 2},
  [18832] = {.lex_state = 420, .external_lex_state = 2},
  [18833] = {.lex_state = 420, .external_lex_state = 2},
  [18834] = {.lex_state = 420, .external_lex_state = 2},
  [18835] = {.lex_state = 420, .external_lex_state = 2},
  [18836] = {.lex_state = 420, .external_lex_state = 2},
  [18837] = {.lex_state = 420, .external_lex_state = 2},
  [18838] = {.lex_state = 18, .external_lex_state = 2},
  [18839] = {.lex_state = 420, .external_lex_state = 2},
  [18840] = {.lex_state = 420, .external_lex_state = 2},
  [18841] = {.lex_state = 420, .external_lex_state = 2},
  [18842] = {.lex_state = 18, .external_lex_state = 2},
  [18843] = {.lex_state = 18, .external_lex_state = 2},
  [18844] = {.lex_state = 420, .external_lex_state = 2},
  [18845] = {.lex_state = 420, .external_lex_state = 2},
  [18846] = {.lex_state = 420, .external_lex_state = 2},
  [18847] = {.lex_state = 420, .external_lex_state = 2},
  [18848] = {.lex_state = 420, .external_lex_state = 2},
  [18849] = {.lex_state = 420, .external_lex_state = 2},
  [18850] = {.lex_state = 11, .external_lex_state = 2},
  [18851] = {.lex_state = 420, .external_lex_state = 3},
  [18852] = {.lex_state = 28, .external_lex_state = 2},
  [18853] = {.lex_state = 420, .external_lex_state = 2},
  [18854] = {.lex_state = 420, .external_lex_state = 2},
  [18855] = {.lex_state = 420, .external_lex_state = 2},
  [18856] = {.lex_state = 18, .external_lex_state = 2},
  [18857] = {.lex_state = 420, .external_lex_state = 2},
  [18858] = {.lex_state = 420, .external_lex_state = 2},
  [18859] = {.lex_state = 420, .external_lex_state = 2},
  [18860] = {.lex_state = 420, .external_lex_state = 2},
  [18861] = {.lex_state = 420, .external_lex_state = 2},
  [18862] = {.lex_state = 420, .external_lex_state = 2},
  [18863] = {.lex_state = 420, .external_lex_state = 2},
  [18864] = {.lex_state = 18, .external_lex_state = 2},
  [18865] = {.lex_state = 420, .external_lex_state = 2},
  [18866] = {.lex_state = 420, .external_lex_state = 2},
  [18867] = {.lex_state = 18, .external_lex_state = 2},
  [18868] = {.lex_state = 420, .external_lex_state = 2},
  [18869] = {.lex_state = 18, .external_lex_state = 2},
  [18870] = {.lex_state = 18, .external_lex_state = 2},
  [18871] = {.lex_state = 420, .external_lex_state = 2},
  [18872] = {.lex_state = 420, .external_lex_state = 2},
  [18873] = {.lex_state = 420, .external_lex_state = 2},
  [18874] = {.lex_state = 420, .external_lex_state = 2},
  [18875] = {.lex_state = 420, .external_lex_state = 2},
  [18876] = {.lex_state = 420, .external_lex_state = 2},
  [18877] = {.lex_state = 420, .external_lex_state = 2},
  [18878] = {.lex_state = 420, .external_lex_state = 2},
  [18879] = {.lex_state = 18, .external_lex_state = 2},
  [18880] = {.lex_state = 18, .external_lex_state = 2},
  [18881] = {.lex_state = 420, .external_lex_state = 2},
  [18882] = {.lex_state = 420, .external_lex_state = 2},
  [18883] = {.lex_state = 28, .external_lex_state = 2},
  [18884] = {.lex_state = 420, .external_lex_state = 2},
  [18885] = {.lex_state = 420, .external_lex_state = 3},
  [18886] = {.lex_state = 420, .external_lex_state = 2},
  [18887] = {.lex_state = 18, .external_lex_state = 2},
  [18888] = {.lex_state = 420, .external_lex_state = 2},
  [18889] = {.lex_state = 420, .external_lex_state = 2},
  [18890] = {.lex_state = 11, .external_lex_state = 2},
  [18891] = {.lex_state = 420, .external_lex_state = 2},
  [18892] = {.lex_state = 420, .external_lex_state = 2},
  [18893] = {.lex_state = 420, .external_lex_state = 2},
  [18894] = {.lex_state = 420, .external_lex_state = 2},
  [18895] = {.lex_state = 420, .external_lex_state = 2},
  [18896] = {.lex_state = 420, .external_lex_state = 2},
  [18897] = {.lex_state = 420, .external_lex_state = 2},
  [18898] = {.lex_state = 420, .external_lex_state = 2},
  [18899] = {.lex_state = 420, .external_lex_state = 2},
  [18900] = {.lex_state = 420, .external_lex_state = 2},
  [18901] = {.lex_state = 18, .external_lex_state = 2},
  [18902] = {.lex_state = 12, .external_lex_state = 2},
  [18903] = {.lex_state = 12, .external_lex_state = 2},
  [18904] = {.lex_state = 12, .external_lex_state = 2},
  [18905] = {.lex_state = 420, .external_lex_state = 2},
  [18906] = {.lex_state = 12, .external_lex_state = 2},
  [18907] = {.lex_state = 420, .external_lex_state = 2},
  [18908] = {.lex_state = 420, .external_lex_state = 2},
  [18909] = {.lex_state = 420, .external_lex_state = 2},
  [18910] = {.lex_state = 420, .external_lex_state = 2},
  [18911] = {.lex_state = 420, .external_lex_state = 2},
  [18912] = {.lex_state = 420, .external_lex_state = 2},
  [18913] = {.lex_state = 420, .external_lex_state = 2},
  [18914] = {.lex_state = 18, .external_lex_state = 2},
  [18915] = {.lex_state = 420, .external_lex_state = 2},
  [18916] = {.lex_state = 18, .external_lex_state = 2},
  [18917] = {.lex_state = 420, .external_lex_state = 2},
  [18918] = {.lex_state = 420, .external_lex_state = 2},
  [18919] = {.lex_state = 420, .external_lex_state = 2},
  [18920] = {.lex_state = 420, .external_lex_state = 2},
  [18921] = {.lex_state = 420, .external_lex_state = 2},
  [18922] = {.lex_state = 420, .external_lex_state = 2},
  [18923] = {.lex_state = 420, .external_lex_state = 2},
  [18924] = {.lex_state = 420, .external_lex_state = 2},
  [18925] = {.lex_state = 420, .external_lex_state = 2},
  [18926] = {.lex_state = 12, .external_lex_state = 2},
  [18927] = {.lex_state = 420, .external_lex_state = 2},
  [18928] = {.lex_state = 420, .external_lex_state = 2},
  [18929] = {.lex_state = 18, .external_lex_state = 2},
  [18930] = {.lex_state = 420, .external_lex_state = 2},
  [18931] = {.lex_state = 18, .external_lex_state = 2},
  [18932] = {.lex_state = 420, .external_lex_state = 2},
  [18933] = {.lex_state = 420, .external_lex_state = 2},
  [18934] = {.lex_state = 420, .external_lex_state = 2},
  [18935] = {.lex_state = 420, .external_lex_state = 2},
  [18936] = {.lex_state = 420, .external_lex_state = 2},
  [18937] = {.lex_state = 420, .external_lex_state = 2},
  [18938] = {.lex_state = 420, .external_lex_state = 2},
  [18939] = {.lex_state = 420, .external_lex_state = 2},
  [18940] = {.lex_state = 420, .external_lex_state = 2},
  [18941] = {.lex_state = 18, .external_lex_state = 2},
  [18942] = {.lex_state = 420, .external_lex_state = 2},
  [18943] = {.lex_state = 420, .external_lex_state = 2},
  [18944] = {.lex_state = 18, .external_lex_state = 2},
  [18945] = {.lex_state = 420, .external_lex_state = 2},
  [18946] = {.lex_state = 420, .external_lex_state = 2},
  [18947] = {.lex_state = 420, .external_lex_state = 2},
  [18948] = {.lex_state = 18, .external_lex_state = 2},
  [18949] = {.lex_state = 18, .external_lex_state = 2},
  [18950] = {.lex_state = 420, .external_lex_state = 2},
  [18951] = {.lex_state = 18, .external_lex_state = 2},
  [18952] = {.lex_state = 420, .external_lex_state = 2},
  [18953] = {.lex_state = 420, .external_lex_state = 2},
  [18954] = {.lex_state = 420, .external_lex_state = 2},
  [18955] = {.lex_state = 420, .external_lex_state = 2},
  [18956] = {.lex_state = 420, .external_lex_state = 2},
  [18957] = {.lex_state = 18, .external_lex_state = 2},
  [18958] = {.lex_state = 420, .external_lex_state = 2},
  [18959] = {.lex_state = 420, .external_lex_state = 2},
  [18960] = {.lex_state = 420, .external_lex_state = 2},
  [18961] = {.lex_state = 420, .external_lex_state = 2},
  [18962] = {.lex_state = 420, .external_lex_state = 2},
  [18963] = {.lex_state = 420, .external_lex_state = 2},
  [18964] = {.lex_state = 420, .external_lex_state = 2},
  [18965] = {.lex_state = 420, .external_lex_state = 2},
  [18966] = {.lex_state = 18, .external_lex_state = 2},
  [18967] = {.lex_state = 420, .external_lex_state = 2},
  [18968] = {.lex_state = 420, .external_lex_state = 2},
  [18969] = {.lex_state = 420, .external_lex_state = 2},
  [18970] = {.lex_state = 420, .external_lex_state = 2},
  [18971] = {.lex_state = 420, .external_lex_state = 2},
  [18972] = {.lex_state = 420, .external_lex_state = 2},
  [18973] = {.lex_state = 11, .external_lex_state = 2},
  [18974] = {.lex_state = 420, .external_lex_state = 2},
  [18975] = {.lex_state = 18, .external_lex_state = 2},
  [18976] = {.lex_state = 18, .external_lex_state = 2},
  [18977] = {.lex_state = 420, .external_lex_state = 2},
  [18978] = {.lex_state = 12, .external_lex_state = 2},
  [18979] = {.lex_state = 420, .external_lex_state = 2},
  [18980] = {.lex_state = 420, .external_lex_state = 2},
  [18981] = {.lex_state = 420, .external_lex_state = 2},
  [18982] = {.lex_state = 420, .external_lex_state = 2},
  [18983] = {.lex_state = 12, .external_lex_state = 2},
  [18984] = {.lex_state = 420, .external_lex_state = 2},
  [18985] = {.lex_state = 420, .external_lex_state = 2},
  [18986] = {.lex_state = 420, .external_lex_state = 2},
  [18987] = {.lex_state = 420, .external_lex_state = 2},
  [18988] = {.lex_state = 12, .external_lex_state = 2},
  [18989] = {.lex_state = 12, .external_lex_state = 2},
  [18990] = {.lex_state = 12, .external_lex_state = 2},
  [18991] = {.lex_state = 420, .external_lex_state = 2},
  [18992] = {.lex_state = 18, .external_lex_state = 2},
  [18993] = {.lex_state = 420, .external_lex_state = 2},
  [18994] = {.lex_state = 420, .external_lex_state = 2},
  [18995] = {.lex_state = 420, .external_lex_state = 2},
  [18996] = {.lex_state = 420, .external_lex_state = 2},
  [18997] = {.lex_state = 18, .external_lex_state = 2},
  [18998] = {.lex_state = 28, .external_lex_state = 2},
  [18999] = {.lex_state = 420, .external_lex_state = 2},
  [19000] = {.lex_state = 420, .external_lex_state = 3},
  [19001] = {.lex_state = 11, .external_lex_state = 2},
  [19002] = {.lex_state = 420, .external_lex_state = 2},
  [19003] = {.lex_state = 420, .external_lex_state = 2},
  [19004] = {.lex_state = 420, .external_lex_state = 2},
  [19005] = {.lex_state = 420, .external_lex_state = 2},
  [19006] = {.lex_state = 420, .external_lex_state = 2},
  [19007] = {.lex_state = 420, .external_lex_state = 2},
  [19008] = {.lex_state = 420, .external_lex_state = 2},
  [19009] = {.lex_state = 420, .external_lex_state = 2},
  [19010] = {.lex_state = 420, .external_lex_state = 2},
  [19011] = {.lex_state = 420, .external_lex_state = 2},
  [19012] = {.lex_state = 420, .external_lex_state = 2},
  [19013] = {.lex_state = 420, .external_lex_state = 2},
  [19014] = {.lex_state = 420, .external_lex_state = 2},
  [19015] = {.lex_state = 420, .external_lex_state = 2},
  [19016] = {.lex_state = 11, .external_lex_state = 2},
  [19017] = {.lex_state = 18, .external_lex_state = 2},
  [19018] = {.lex_state = 12, .external_lex_state = 2},
  [19019] = {.lex_state = 420, .external_lex_state = 3},
  [19020] = {.lex_state = 28, .external_lex_state = 2},
  [19021] = {.lex_state = 420, .external_lex_state = 2},
  [19022] = {.lex_state = 420, .external_lex_state = 2},
  [19023] = {.lex_state = 420, .external_lex_state = 2},
  [19024] = {.lex_state = 420, .external_lex_state = 2},
  [19025] = {.lex_state = 420, .external_lex_state = 2},
  [19026] = {.lex_state = 12, .external_lex_state = 2},
  [19027] = {.lex_state = 12, .external_lex_state = 2},
  [19028] = {.lex_state = 12, .external_lex_state = 2},
  [19029] = {.lex_state = 18, .external_lex_state = 2},
  [19030] = {.lex_state = 420, .external_lex_state = 2},
  [19031] = {.lex_state = 420, .external_lex_state = 2},
  [19032] = {.lex_state = 420, .external_lex_state = 2},
  [19033] = {.lex_state = 420, .external_lex_state = 2},
  [19034] = {.lex_state = 420, .external_lex_state = 2},
  [19035] = {.lex_state = 420, .external_lex_state = 2},
  [19036] = {.lex_state = 420, .external_lex_state = 2},
  [19037] = {.lex_state = 420, .external_lex_state = 2},
  [19038] = {.lex_state = 420, .external_lex_state = 2},
  [19039] = {.lex_state = 420, .external_lex_state = 2},
  [19040] = {.lex_state = 420, .external_lex_state = 2},
  [19041] = {.lex_state = 420, .external_lex_state = 2},
  [19042] = {.lex_state = 420, .external_lex_state = 2},
  [19043] = {.lex_state = 420, .external_lex_state = 2},
  [19044] = {.lex_state = 420, .external_lex_state = 2},
  [19045] = {.lex_state = 420, .external_lex_state = 2},
  [19046] = {.lex_state = 18, .external_lex_state = 2},
  [19047] = {.lex_state = 420, .external_lex_state = 2},
  [19048] = {.lex_state = 420, .external_lex_state = 2},
  [19049] = {.lex_state = 420, .external_lex_state = 2},
  [19050] = {.lex_state = 420, .external_lex_state = 2},
  [19051] = {.lex_state = 420, .external_lex_state = 2},
  [19052] = {.lex_state = 420, .external_lex_state = 2},
  [19053] = {.lex_state = 420, .external_lex_state = 2},
  [19054] = {.lex_state = 420, .external_lex_state = 2},
  [19055] = {.lex_state = 420, .external_lex_state = 2},
  [19056] = {.lex_state = 420, .external_lex_state = 2},
  [19057] = {.lex_state = 420, .external_lex_state = 2},
  [19058] = {.lex_state = 420, .external_lex_state = 2},
  [19059] = {.lex_state = 420, .external_lex_state = 2},
  [19060] = {.lex_state = 420, .external_lex_state = 2},
  [19061] = {.lex_state = 420, .external_lex_state = 2},
  [19062] = {.lex_state = 420, .external_lex_state = 2},
  [19063] = {.lex_state = 420, .external_lex_state = 2},
  [19064] = {.lex_state = 420, .external_lex_state = 2},
  [19065] = {.lex_state = 420, .external_lex_state = 2},
  [19066] = {.lex_state = 420, .external_lex_state = 2},
  [19067] = {.lex_state = 18, .external_lex_state = 2},
  [19068] = {.lex_state = 18, .external_lex_state = 2},
  [19069] = {.lex_state = 420, .external_lex_state = 2},
  [19070] = {.lex_state = 420, .external_lex_state = 2},
  [19071] = {.lex_state = 12, .external_lex_state = 2},
  [19072] = {.lex_state = 12, .external_lex_state = 2},
  [19073] = {.lex_state = 420, .external_lex_state = 2},
  [19074] = {.lex_state = 420, .external_lex_state = 2},
  [19075] = {.lex_state = 420, .external_lex_state = 2},
  [19076] = {.lex_state = 420, .external_lex_state = 2},
  [19077] = {.lex_state = 18, .external_lex_state = 2},
  [19078] = {.lex_state = 420, .external_lex_state = 2},
  [19079] = {.lex_state = 12, .external_lex_state = 2},
  [19080] = {.lex_state = 12, .external_lex_state = 2},
  [19081] = {.lex_state = 420, .external_lex_state = 2},
  [19082] = {.lex_state = 420, .external_lex_state = 2},
  [19083] = {.lex_state = 420, .external_lex_state = 2},
  [19084] = {.lex_state = 420, .external_lex_state = 2},
  [19085] = {.lex_state = 420, .external_lex_state = 2},
  [19086] = {.lex_state = 420, .external_lex_state = 2},
  [19087] = {.lex_state = 420, .external_lex_state = 2},
  [19088] = {.lex_state = 420, .external_lex_state = 2},
  [19089] = {.lex_state = 420, .external_lex_state = 2},
  [19090] = {.lex_state = 420, .external_lex_state = 3},
  [19091] = {.lex_state = 28, .external_lex_state = 2},
  [19092] = {.lex_state = 420, .external_lex_state = 2},
  [19093] = {.lex_state = 420, .external_lex_state = 2},
  [19094] = {.lex_state = 420, .external_lex_state = 2},
  [19095] = {.lex_state = 420, .external_lex_state = 2},
  [19096] = {.lex_state = 420, .external_lex_state = 2},
  [19097] = {.lex_state = 18, .external_lex_state = 2},
  [19098] = {.lex_state = 18, .external_lex_state = 2},
  [19099] = {.lex_state = 12, .external_lex_state = 2},
  [19100] = {.lex_state = 18, .external_lex_state = 2},
  [19101] = {.lex_state = 420, .external_lex_state = 2},
  [19102] = {.lex_state = 420, .external_lex_state = 2},
  [19103] = {.lex_state = 420, .external_lex_state = 2},
  [19104] = {.lex_state = 420, .external_lex_state = 2},
  [19105] = {.lex_state = 420, .external_lex_state = 2},
  [19106] = {.lex_state = 420, .external_lex_state = 2},
  [19107] = {.lex_state = 18, .external_lex_state = 2},
  [19108] = {.lex_state = 18, .external_lex_state = 2},
  [19109] = {.lex_state = 420, .external_lex_state = 2},
  [19110] = {.lex_state = 18, .external_lex_state = 2},
  [19111] = {.lex_state = 420, .external_lex_state = 2},
  [19112] = {.lex_state = 420, .external_lex_state = 2},
  [19113] = {.lex_state = 420, .external_lex_state = 2},
  [19114] = {.lex_state = 420, .external_lex_state = 2},
  [19115] = {.lex_state = 420, .external_lex_state = 2},
  [19116] = {.lex_state = 420, .external_lex_state = 2},
  [19117] = {.lex_state = 420, .external_lex_state = 2},
  [19118] = {.lex_state = 420, .external_lex_state = 2},
  [19119] = {.lex_state = 420, .external_lex_state = 2},
  [19120] = {.lex_state = 420, .external_lex_state = 2},
  [19121] = {.lex_state = 420, .external_lex_state = 2},
  [19122] = {.lex_state = 420, .external_lex_state = 2},
  [19123] = {.lex_state = 420, .external_lex_state = 2},
  [19124] = {.lex_state = 420, .external_lex_state = 2},
  [19125] = {.lex_state = 420, .external_lex_state = 2},
  [19126] = {.lex_state = 420, .external_lex_state = 2},
  [19127] = {.lex_state = 420, .external_lex_state = 2},
  [19128] = {.lex_state = 18, .external_lex_state = 2},
  [19129] = {.lex_state = 420, .external_lex_state = 2},
  [19130] = {.lex_state = 420, .external_lex_state = 2},
  [19131] = {.lex_state = 420, .external_lex_state = 2},
  [19132] = {.lex_state = 18, .external_lex_state = 2},
  [19133] = {.lex_state = 420, .external_lex_state = 2},
  [19134] = {.lex_state = 420, .external_lex_state = 2},
  [19135] = {.lex_state = 420, .external_lex_state = 2},
  [19136] = {.lex_state = 420, .external_lex_state = 2},
  [19137] = {.lex_state = 420, .external_lex_state = 2},
  [19138] = {.lex_state = 420, .external_lex_state = 2},
  [19139] = {.lex_state = 420, .external_lex_state = 2},
  [19140] = {.lex_state = 18, .external_lex_state = 2},
  [19141] = {.lex_state = 12, .external_lex_state = 2},
  [19142] = {.lex_state = 420, .external_lex_state = 2},
  [19143] = {.lex_state = 12, .external_lex_state = 2},
  [19144] = {.lex_state = 12, .external_lex_state = 2},
  [19145] = {.lex_state = 18, .external_lex_state = 2},
  [19146] = {.lex_state = 420, .external_lex_state = 2},
  [19147] = {.lex_state = 420, .external_lex_state = 2},
  [19148] = {.lex_state = 420, .external_lex_state = 2},
  [19149] = {.lex_state = 18, .external_lex_state = 2},
  [19150] = {.lex_state = 420, .external_lex_state = 2},
  [19151] = {.lex_state = 12, .external_lex_state = 2},
  [19152] = {.lex_state = 420, .external_lex_state = 2},
  [19153] = {.lex_state = 420, .external_lex_state = 2},
  [19154] = {.lex_state = 420, .external_lex_state = 2},
  [19155] = {.lex_state = 420, .external_lex_state = 2},
  [19156] = {.lex_state = 420, .external_lex_state = 2},
  [19157] = {.lex_state = 18, .external_lex_state = 2},
  [19158] = {.lex_state = 18, .external_lex_state = 2},
  [19159] = {.lex_state = 11, .external_lex_state = 2},
  [19160] = {.lex_state = 28, .external_lex_state = 2},
  [19161] = {.lex_state = 420, .external_lex_state = 3},
  [19162] = {.lex_state = 28, .external_lex_state = 2},
  [19163] = {.lex_state = 420, .external_lex_state = 3},
  [19164] = {.lex_state = 11, .external_lex_state = 2},
  [19165] = {.lex_state = 420, .external_lex_state = 2},
  [19166] = {.lex_state = 420, .external_lex_state = 2},
  [19167] = {.lex_state = 420, .external_lex_state = 2},
  [19168] = {.lex_state = 420, .external_lex_state = 2},
  [19169] = {.lex_state = 420, .external_lex_state = 2},
  [19170] = {.lex_state = 420, .external_lex_state = 2},
  [19171] = {.lex_state = 18, .external_lex_state = 2},
  [19172] = {.lex_state = 420, .external_lex_state = 2},
  [19173] = {.lex_state = 18, .external_lex_state = 2},
  [19174] = {.lex_state = 420, .external_lex_state = 2},
  [19175] = {.lex_state = 12, .external_lex_state = 2},
  [19176] = {.lex_state = 12, .external_lex_state = 2},
  [19177] = {.lex_state = 420, .external_lex_state = 2},
  [19178] = {.lex_state = 12, .external_lex_state = 2},
  [19179] = {.lex_state = 12, .external_lex_state = 2},
  [19180] = {.lex_state = 18, .external_lex_state = 2},
  [19181] = {.lex_state = 420, .external_lex_state = 2},
  [19182] = {.lex_state = 420, .external_lex_state = 2},
  [19183] = {.lex_state = 420, .external_lex_state = 2},
  [19184] = {.lex_state = 420, .external_lex_state = 2},
  [19185] = {.lex_state = 420, .external_lex_state = 2},
  [19186] = {.lex_state = 420, .external_lex_state = 2},
  [19187] = {.lex_state = 420, .external_lex_state = 2},
  [19188] = {.lex_state = 18, .external_lex_state = 2},
  [19189] = {.lex_state = 12, .external_lex_state = 2},
  [19190] = {.lex_state = 420, .external_lex_state = 2},
  [19191] = {.lex_state = 420, .external_lex_state = 2},
  [19192] = {.lex_state = 420, .external_lex_state = 2},
  [19193] = {.lex_state = 420, .external_lex_state = 2},
  [19194] = {.lex_state = 420, .external_lex_state = 2},
  [19195] = {.lex_state = 420, .external_lex_state = 2},
  [19196] = {.lex_state = 420, .external_lex_state = 2},
  [19197] = {.lex_state = 18, .external_lex_state = 2},
  [19198] = {.lex_state = 420, .external_lex_state = 2},
  [19199] = {.lex_state = 420, .external_lex_state = 2},
  [19200] = {.lex_state = 18, .external_lex_state = 2},
  [19201] = {.lex_state = 420, .external_lex_state = 2},
  [19202] = {.lex_state = 420, .external_lex_state = 2},
  [19203] = {.lex_state = 420, .external_lex_state = 2},
  [19204] = {.lex_state = 420, .external_lex_state = 2},
  [19205] = {.lex_state = 420, .external_lex_state = 2},
  [19206] = {.lex_state = 420, .external_lex_state = 2},
  [19207] = {.lex_state = 420, .external_lex_state = 2},
  [19208] = {.lex_state = 18, .external_lex_state = 2},
  [19209] = {.lex_state = 420, .external_lex_state = 2},
  [19210] = {.lex_state = 420, .external_lex_state = 2},
  [19211] = {.lex_state = 18, .external_lex_state = 2},
  [19212] = {.lex_state = 420, .external_lex_state = 2},
  [19213] = {.lex_state = 420, .external_lex_state = 2},
  [19214] = {.lex_state = 18, .external_lex_state = 2},
  [19215] = {.lex_state = 420, .external_lex_state = 2},
  [19216] = {.lex_state = 420, .external_lex_state = 2},
  [19217] = {.lex_state = 420, .external_lex_state = 2},
  [19218] = {.lex_state = 420, .external_lex_state = 2},
  [19219] = {.lex_state = 420, .external_lex_state = 2},
  [19220] = {.lex_state = 18, .external_lex_state = 2},
  [19221] = {.lex_state = 420, .external_lex_state = 2},
  [19222] = {.lex_state = 420, .external_lex_state = 2},
  [19223] = {.lex_state = 420, .external_lex_state = 2},
  [19224] = {.lex_state = 18, .external_lex_state = 2},
  [19225] = {.lex_state = 420, .external_lex_state = 2},
  [19226] = {.lex_state = 420, .external_lex_state = 2},
  [19227] = {.lex_state = 18, .external_lex_state = 2},
  [19228] = {.lex_state = 12, .external_lex_state = 2},
  [19229] = {.lex_state = 18, .external_lex_state = 2},
  [19230] = {.lex_state = 18, .external_lex_state = 2},
  [19231] = {.lex_state = 12, .external_lex_state = 2},
  [19232] = {.lex_state = 12, .external_lex_state = 2},
  [19233] = {.lex_state = 420, .external_lex_state = 2},
  [19234] = {.lex_state = 420, .external_lex_state = 2},
  [19235] = {.lex_state = 18, .external_lex_state = 2},
  [19236] = {.lex_state = 18, .external_lex_state = 2},
  [19237] = {.lex_state = 12, .external_lex_state = 2},
  [19238] = {.lex_state = 28, .external_lex_state = 2},
  [19239] = {.lex_state = 12, .external_lex_state = 2},
  [19240] = {.lex_state = 420, .external_lex_state = 3},
  [19241] = {.lex_state = 11, .external_lex_state = 2},
  [19242] = {.lex_state = 420, .external_lex_state = 2},
  [19243] = {.lex_state = 420, .external_lex_state = 2},
  [19244] = {.lex_state = 18, .external_lex_state = 2},
  [19245] = {.lex_state = 420, .external_lex_state = 2},
  [19246] = {.lex_state = 420, .external_lex_state = 2},
  [19247] = {.lex_state = 18, .external_lex_state = 2},
  [19248] = {.lex_state = 12, .external_lex_state = 2},
  [19249] = {.lex_state = 12, .external_lex_state = 2},
  [19250] = {.lex_state = 12, .external_lex_state = 2},
  [19251] = {.lex_state = 12, .external_lex_state = 2},
  [19252] = {.lex_state = 420, .external_lex_state = 2},
  [19253] = {.lex_state = 420, .external_lex_state = 2},
  [19254] = {.lex_state = 28, .external_lex_state = 2},
  [19255] = {.lex_state = 420, .external_lex_state = 2},
  [19256] = {.lex_state = 420, .external_lex_state = 2},
  [19257] = {.lex_state = 420, .external_lex_state = 2},
  [19258] = {.lex_state = 18, .external_lex_state = 2},
  [19259] = {.lex_state = 420, .external_lex_state = 2},
  [19260] = {.lex_state = 420, .external_lex_state = 2},
  [19261] = {.lex_state = 420, .external_lex_state = 2},
  [19262] = {.lex_state = 18, .external_lex_state = 2},
  [19263] = {.lex_state = 420, .external_lex_state = 2},
  [19264] = {.lex_state = 28, .external_lex_state = 2},
  [19265] = {.lex_state = 11, .external_lex_state = 2},
  [19266] = {.lex_state = 18, .external_lex_state = 2},
  [19267] = {.lex_state = 420, .external_lex_state = 2},
  [19268] = {.lex_state = 18, .external_lex_state = 2},
  [19269] = {.lex_state = 420, .external_lex_state = 2},
  [19270] = {.lex_state = 420, .external_lex_state = 2},
  [19271] = {.lex_state = 420, .external_lex_state = 2},
  [19272] = {.lex_state = 420, .external_lex_state = 2},
  [19273] = {.lex_state = 420, .external_lex_state = 2},
  [19274] = {.lex_state = 18, .external_lex_state = 2},
  [19275] = {.lex_state = 420, .external_lex_state = 2},
  [19276] = {.lex_state = 420, .external_lex_state = 2},
  [19277] = {.lex_state = 18, .external_lex_state = 2},
  [19278] = {.lex_state = 28, .external_lex_state = 2},
  [19279] = {.lex_state = 420, .external_lex_state = 2},
  [19280] = {.lex_state = 420, .external_lex_state = 3},
  [19281] = {.lex_state = 420, .external_lex_state = 2},
  [19282] = {.lex_state = 420, .external_lex_state = 2},
  [19283] = {.lex_state = 28, .external_lex_state = 2},
  [19284] = {.lex_state = 48, .external_lex_state = 2},
  [19285] = {.lex_state = 48, .external_lex_state = 2},
  [19286] = {.lex_state = 48, .external_lex_state = 2},
  [19287] = {.lex_state = 420, .external_lex_state = 2},
  [19288] = {.lex_state = 420, .external_lex_state = 2},
  [19289] = {.lex_state = 420, .external_lex_state = 2},
  [19290] = {.lex_state = 18, .external_lex_state = 2},
  [19291] = {.lex_state = 420, .external_lex_state = 2},
  [19292] = {.lex_state = 420, .external_lex_state = 2},
  [19293] = {.lex_state = 420, .external_lex_state = 2},
  [19294] = {.lex_state = 18, .external_lex_state = 2},
  [19295] = {.lex_state = 28, .external_lex_state = 2},
  [19296] = {.lex_state = 420, .external_lex_state = 2},
  [19297] = {.lex_state = 420, .external_lex_state = 2},
  [19298] = {.lex_state = 420, .external_lex_state = 2},
  [19299] = {.lex_state = 18, .external_lex_state = 2},
  [19300] = {.lex_state = 18, .external_lex_state = 2},
  [19301] = {.lex_state = 18, .external_lex_state = 2},
  [19302] = {.lex_state = 18, .external_lex_state = 2},
  [19303] = {.lex_state = 420, .external_lex_state = 2},
  [19304] = {.lex_state = 420, .external_lex_state = 2},
  [19305] = {.lex_state = 420, .external_lex_state = 2},
  [19306] = {.lex_state = 420, .external_lex_state = 2},
  [19307] = {.lex_state = 18, .external_lex_state = 2},
  [19308] = {.lex_state = 18, .external_lex_state = 2},
  [19309] = {.lex_state = 28, .external_lex_state = 2},
  [19310] = {.lex_state = 420, .external_lex_state = 2},
  [19311] = {.lex_state = 420, .external_lex_state = 3},
  [19312] = {.lex_state = 11, .external_lex_state = 2},
  [19313] = {.lex_state = 420, .external_lex_state = 2},
  [19314] = {.lex_state = 420, .external_lex_state = 2},
  [19315] = {.lex_state = 420, .external_lex_state = 2},
  [19316] = {.lex_state = 420, .external_lex_state = 2},
  [19317] = {.lex_state = 420, .external_lex_state = 2},
  [19318] = {.lex_state = 18, .external_lex_state = 2},
  [19319] = {.lex_state = 12, .external_lex_state = 2},
  [19320] = {.lex_state = 12, .external_lex_state = 2},
  [19321] = {.lex_state = 12, .external_lex_state = 2},
  [19322] = {.lex_state = 12, .external_lex_state = 2},
  [19323] = {.lex_state = 420, .external_lex_state = 2},
  [19324] = {.lex_state = 420, .external_lex_state = 2},
  [19325] = {.lex_state = 18, .external_lex_state = 2},
  [19326] = {.lex_state = 420, .external_lex_state = 2},
  [19327] = {.lex_state = 420, .external_lex_state = 2},
  [19328] = {.lex_state = 420, .external_lex_state = 2},
  [19329] = {.lex_state = 420, .external_lex_state = 2},
  [19330] = {.lex_state = 18, .external_lex_state = 2},
  [19331] = {.lex_state = 420, .external_lex_state = 2},
  [19332] = {.lex_state = 420, .external_lex_state = 2},
  [19333] = {.lex_state = 420, .external_lex_state = 2},
  [19334] = {.lex_state = 420, .external_lex_state = 2},
  [19335] = {.lex_state = 420, .external_lex_state = 2},
  [19336] = {.lex_state = 420, .external_lex_state = 2},
  [19337] = {.lex_state = 420, .external_lex_state = 2},
  [19338] = {.lex_state = 18, .external_lex_state = 2},
  [19339] = {.lex_state = 420, .external_lex_state = 2},
  [19340] = {.lex_state = 420, .external_lex_state = 2},
  [19341] = {.lex_state = 420, .external_lex_state = 2},
  [19342] = {.lex_state = 18, .external_lex_state = 2},
  [19343] = {.lex_state = 420, .external_lex_state = 2},
  [19344] = {.lex_state = 420, .external_lex_state = 2},
  [19345] = {.lex_state = 420, .external_lex_state = 2},
  [19346] = {.lex_state = 420, .external_lex_state = 2},
  [19347] = {.lex_state = 420, .external_lex_state = 2},
  [19348] = {.lex_state = 18, .external_lex_state = 2},
  [19349] = {.lex_state = 420, .external_lex_state = 2},
  [19350] = {.lex_state = 420, .external_lex_state = 2},
  [19351] = {.lex_state = 420, .external_lex_state = 2},
  [19352] = {.lex_state = 18, .external_lex_state = 2},
  [19353] = {.lex_state = 18, .external_lex_state = 2},
  [19354] = {.lex_state = 420, .external_lex_state = 2},
  [19355] = {.lex_state = 420, .external_lex_state = 2},
  [19356] = {.lex_state = 420, .external_lex_state = 2},
  [19357] = {.lex_state = 420, .external_lex_state = 2},
  [19358] = {.lex_state = 420, .external_lex_state = 2},
  [19359] = {.lex_state = 18, .external_lex_state = 2},
  [19360] = {.lex_state = 18, .external_lex_state = 2},
  [19361] = {.lex_state = 28, .external_lex_state = 2},
  [19362] = {.lex_state = 420, .external_lex_state = 2},
  [19363] = {.lex_state = 420, .external_lex_state = 2},
  [19364] = {.lex_state = 420, .external_lex_state = 2},
  [19365] = {.lex_state = 420, .external_lex_state = 2},
  [19366] = {.lex_state = 18, .external_lex_state = 2},
  [19367] = {.lex_state = 420, .external_lex_state = 2},
  [19368] = {.lex_state = 420, .external_lex_state = 2},
  [19369] = {.lex_state = 18, .external_lex_state = 2},
  [19370] = {.lex_state = 420, .external_lex_state = 2},
  [19371] = {.lex_state = 18, .external_lex_state = 2},
  [19372] = {.lex_state = 18, .external_lex_state = 2},
  [19373] = {.lex_state = 12, .external_lex_state = 2},
  [19374] = {.lex_state = 12, .external_lex_state = 2},
  [19375] = {.lex_state = 420, .external_lex_state = 2},
  [19376] = {.lex_state = 420, .external_lex_state = 2},
  [19377] = {.lex_state = 12, .external_lex_state = 2},
  [19378] = {.lex_state = 48, .external_lex_state = 2},
  [19379] = {.lex_state = 48, .external_lex_state = 2},
  [19380] = {.lex_state = 48, .external_lex_state = 2},
  [19381] = {.lex_state = 420, .external_lex_state = 2},
  [19382] = {.lex_state = 18, .external_lex_state = 2},
  [19383] = {.lex_state = 18, .external_lex_state = 2},
  [19384] = {.lex_state = 28, .external_lex_state = 2},
  [19385] = {.lex_state = 12, .external_lex_state = 2},
  [19386] = {.lex_state = 420, .external_lex_state = 3},
  [19387] = {.lex_state = 11, .external_lex_state = 2},
  [19388] = {.lex_state = 420, .external_lex_state = 2},
  [19389] = {.lex_state = 420, .external_lex_state = 2},
  [19390] = {.lex_state = 420, .external_lex_state = 2},
  [19391] = {.lex_state = 11, .external_lex_state = 2},
  [19392] = {.lex_state = 420, .external_lex_state = 2},
  [19393] = {.lex_state = 420, .external_lex_state = 3},
  [19394] = {.lex_state = 18, .external_lex_state = 2},
  [19395] = {.lex_state = 12, .external_lex_state = 2},
  [19396] = {.lex_state = 12, .external_lex_state = 2},
  [19397] = {.lex_state = 12, .external_lex_state = 2},
  [19398] = {.lex_state = 12, .external_lex_state = 2},
  [19399] = {.lex_state = 420, .external_lex_state = 2},
  [19400] = {.lex_state = 420, .external_lex_state = 2},
  [19401] = {.lex_state = 420, .external_lex_state = 2},
  [19402] = {.lex_state = 420, .external_lex_state = 2},
  [19403] = {.lex_state = 420, .external_lex_state = 2},
  [19404] = {.lex_state = 420, .external_lex_state = 2},
  [19405] = {.lex_state = 420, .external_lex_state = 2},
  [19406] = {.lex_state = 18, .external_lex_state = 2},
  [19407] = {.lex_state = 18, .external_lex_state = 2},
  [19408] = {.lex_state = 420, .external_lex_state = 2},
  [19409] = {.lex_state = 18, .external_lex_state = 2},
  [19410] = {.lex_state = 420, .external_lex_state = 2},
  [19411] = {.lex_state = 420, .external_lex_state = 2},
  [19412] = {.lex_state = 420, .external_lex_state = 2},
  [19413] = {.lex_state = 420, .external_lex_state = 2},
  [19414] = {.lex_state = 420, .external_lex_state = 2},
  [19415] = {.lex_state = 18, .external_lex_state = 2},
  [19416] = {.lex_state = 420, .external_lex_state = 2},
  [19417] = {.lex_state = 420, .external_lex_state = 2},
  [19418] = {.lex_state = 420, .external_lex_state = 2},
  [19419] = {.lex_state = 420, .external_lex_state = 2},
  [19420] = {.lex_state = 420, .external_lex_state = 2},
  [19421] = {.lex_state = 18, .external_lex_state = 2},
  [19422] = {.lex_state = 420, .external_lex_state = 2},
  [19423] = {.lex_state = 420, .external_lex_state = 2},
  [19424] = {.lex_state = 420, .external_lex_state = 2},
  [19425] = {.lex_state = 420, .external_lex_state = 2},
  [19426] = {.lex_state = 420, .external_lex_state = 2},
  [19427] = {.lex_state = 18, .external_lex_state = 2},
  [19428] = {.lex_state = 420, .external_lex_state = 2},
  [19429] = {.lex_state = 420, .external_lex_state = 2},
  [19430] = {.lex_state = 11, .external_lex_state = 2},
  [19431] = {.lex_state = 420, .external_lex_state = 2},
  [19432] = {.lex_state = 18, .external_lex_state = 2},
  [19433] = {.lex_state = 18, .external_lex_state = 2},
  [19434] = {.lex_state = 18, .external_lex_state = 2},
  [19435] = {.lex_state = 28, .external_lex_state = 2},
  [19436] = {.lex_state = 420, .external_lex_state = 3},
  [19437] = {.lex_state = 420, .external_lex_state = 2},
  [19438] = {.lex_state = 420, .external_lex_state = 2},
  [19439] = {.lex_state = 420, .external_lex_state = 2},
  [19440] = {.lex_state = 420, .external_lex_state = 2},
  [19441] = {.lex_state = 18, .external_lex_state = 2},
  [19442] = {.lex_state = 12, .external_lex_state = 2},
  [19443] = {.lex_state = 420, .external_lex_state = 2},
  [19444] = {.lex_state = 420, .external_lex_state = 2},
  [19445] = {.lex_state = 420, .external_lex_state = 2},
  [19446] = {.lex_state = 420, .external_lex_state = 2},
  [19447] = {.lex_state = 420, .external_lex_state = 2},
  [19448] = {.lex_state = 18, .external_lex_state = 2},
  [19449] = {.lex_state = 420, .external_lex_state = 2},
  [19450] = {.lex_state = 420, .external_lex_state = 2},
  [19451] = {.lex_state = 420, .external_lex_state = 2},
  [19452] = {.lex_state = 48, .external_lex_state = 2},
  [19453] = {.lex_state = 48, .external_lex_state = 2},
  [19454] = {.lex_state = 48, .external_lex_state = 2},
  [19455] = {.lex_state = 420, .external_lex_state = 2},
  [19456] = {.lex_state = 18, .external_lex_state = 2},
  [19457] = {.lex_state = 420, .external_lex_state = 2},
  [19458] = {.lex_state = 18, .external_lex_state = 2},
  [19459] = {.lex_state = 18, .external_lex_state = 2},
  [19460] = {.lex_state = 420, .external_lex_state = 2},
  [19461] = {.lex_state = 420, .external_lex_state = 2},
  [19462] = {.lex_state = 420, .external_lex_state = 2},
  [19463] = {.lex_state = 420, .external_lex_state = 2},
  [19464] = {.lex_state = 420, .external_lex_state = 2},
  [19465] = {.lex_state = 420, .external_lex_state = 2},
  [19466] = {.lex_state = 18, .external_lex_state = 2},
  [19467] = {.lex_state = 18, .external_lex_state = 2},
  [19468] = {.lex_state = 28, .external_lex_state = 2},
  [19469] = {.lex_state = 420, .external_lex_state = 2},
  [19470] = {.lex_state = 420, .external_lex_state = 2},
  [19471] = {.lex_state = 420, .external_lex_state = 2},
  [19472] = {.lex_state = 420, .external_lex_state = 3},
  [19473] = {.lex_state = 11, .external_lex_state = 2},
  [19474] = {.lex_state = 420, .external_lex_state = 2},
  [19475] = {.lex_state = 420, .external_lex_state = 2},
  [19476] = {.lex_state = 11, .external_lex_state = 2},
  [19477] = {.lex_state = 420, .external_lex_state = 2},
  [19478] = {.lex_state = 420, .external_lex_state = 3},
  [19479] = {.lex_state = 18, .external_lex_state = 2},
  [19480] = {.lex_state = 12, .external_lex_state = 2},
  [19481] = {.lex_state = 12, .external_lex_state = 2},
  [19482] = {.lex_state = 420, .external_lex_state = 2},
  [19483] = {.lex_state = 12, .external_lex_state = 2},
  [19484] = {.lex_state = 420, .external_lex_state = 2},
  [19485] = {.lex_state = 420, .external_lex_state = 2},
  [19486] = {.lex_state = 420, .external_lex_state = 2},
  [19487] = {.lex_state = 420, .external_lex_state = 2},
  [19488] = {.lex_state = 420, .external_lex_state = 2},
  [19489] = {.lex_state = 18, .external_lex_state = 2},
  [19490] = {.lex_state = 18, .external_lex_state = 2},
  [19491] = {.lex_state = 28, .external_lex_state = 2},
  [19492] = {.lex_state = 420, .external_lex_state = 2},
  [19493] = {.lex_state = 420, .external_lex_state = 2},
  [19494] = {.lex_state = 18, .external_lex_state = 2},
  [19495] = {.lex_state = 420, .external_lex_state = 2},
  [19496] = {.lex_state = 420, .external_lex_state = 2},
  [19497] = {.lex_state = 420, .external_lex_state = 2},
  [19498] = {.lex_state = 420, .external_lex_state = 2},
  [19499] = {.lex_state = 48, .external_lex_state = 2},
  [19500] = {.lex_state = 48, .external_lex_state = 2},
  [19501] = {.lex_state = 48, .external_lex_state = 2},
  [19502] = {.lex_state = 420, .external_lex_state = 2},
  [19503] = {.lex_state = 420, .external_lex_state = 2},
  [19504] = {.lex_state = 420, .external_lex_state = 2},
  [19505] = {.lex_state = 420, .external_lex_state = 2},
  [19506] = {.lex_state = 420, .external_lex_state = 2},
  [19507] = {.lex_state = 420, .external_lex_state = 2},
  [19508] = {.lex_state = 420, .external_lex_state = 2},
  [19509] = {.lex_state = 18, .external_lex_state = 2},
  [19510] = {.lex_state = 420, .external_lex_state = 2},
  [19511] = {.lex_state = 420, .external_lex_state = 2},
  [19512] = {.lex_state = 11, .external_lex_state = 2},
  [19513] = {.lex_state = 420, .external_lex_state = 2},
  [19514] = {.lex_state = 420, .external_lex_state = 2},
  [19515] = {.lex_state = 420, .external_lex_state = 2},
  [19516] = {.lex_state = 18, .external_lex_state = 2},
  [19517] = {.lex_state = 420, .external_lex_state = 2},
  [19518] = {.lex_state = 420, .external_lex_state = 2},
  [19519] = {.lex_state = 420, .external_lex_state = 2},
  [19520] = {.lex_state = 420, .external_lex_state = 2},
  [19521] = {.lex_state = 420, .external_lex_state = 2},
  [19522] = {.lex_state = 18, .external_lex_state = 2},
  [19523] = {.lex_state = 18, .external_lex_state = 2},
  [19524] = {.lex_state = 420, .external_lex_state = 2},
  [19525] = {.lex_state = 28, .external_lex_state = 2},
  [19526] = {.lex_state = 420, .external_lex_state = 3},
  [19527] = {.lex_state = 420, .external_lex_state = 2},
  [19528] = {.lex_state = 420, .external_lex_state = 2},
  [19529] = {.lex_state = 48, .external_lex_state = 2},
  [19530] = {.lex_state = 48, .external_lex_state = 2},
  [19531] = {.lex_state = 48, .external_lex_state = 2},
  [19532] = {.lex_state = 420, .external_lex_state = 2},
  [19533] = {.lex_state = 420, .external_lex_state = 2},
  [19534] = {.lex_state = 420, .external_lex_state = 2},
  [19535] = {.lex_state = 420, .external_lex_state = 2},
  [19536] = {.lex_state = 18, .external_lex_state = 2},
  [19537] = {.lex_state = 18, .external_lex_state = 2},
  [19538] = {.lex_state = 420, .external_lex_state = 2},
  [19539] = {.lex_state = 420, .external_lex_state = 2},
  [19540] = {.lex_state = 420, .external_lex_state = 2},
  [19541] = {.lex_state = 420, .external_lex_state = 2},
  [19542] = {.lex_state = 420, .external_lex_state = 2},
  [19543] = {.lex_state = 18, .external_lex_state = 2},
  [19544] = {.lex_state = 420, .external_lex_state = 2},
  [19545] = {.lex_state = 420, .external_lex_state = 2},
  [19546] = {.lex_state = 420, .external_lex_state = 2},
  [19547] = {.lex_state = 420, .external_lex_state = 2},
  [19548] = {.lex_state = 420, .external_lex_state = 2},
  [19549] = {.lex_state = 420, .external_lex_state = 2},
  [19550] = {.lex_state = 420, .external_lex_state = 2},
  [19551] = {.lex_state = 18, .external_lex_state = 2},
  [19552] = {.lex_state = 420, .external_lex_state = 2},
  [19553] = {.lex_state = 28, .external_lex_state = 2},
  [19554] = {.lex_state = 420, .external_lex_state = 2},
  [19555] = {.lex_state = 18, .external_lex_state = 2},
  [19556] = {.lex_state = 420, .external_lex_state = 2},
  [19557] = {.lex_state = 48, .external_lex_state = 2},
  [19558] = {.lex_state = 48, .external_lex_state = 2},
  [19559] = {.lex_state = 48, .external_lex_state = 2},
  [19560] = {.lex_state = 18, .external_lex_state = 2},
  [19561] = {.lex_state = 18, .external_lex_state = 2},
  [19562] = {.lex_state = 420, .external_lex_state = 2},
  [19563] = {.lex_state = 420, .external_lex_state = 2},
  [19564] = {.lex_state = 420, .external_lex_state = 2},
  [19565] = {.lex_state = 420, .external_lex_state = 2},
  [19566] = {.lex_state = 420, .external_lex_state = 2},
  [19567] = {.lex_state = 420, .external_lex_state = 2},
  [19568] = {.lex_state = 420, .external_lex_state = 2},
  [19569] = {.lex_state = 18, .external_lex_state = 2},
  [19570] = {.lex_state = 18, .external_lex_state = 2},
  [19571] = {.lex_state = 28, .external_lex_state = 2},
  [19572] = {.lex_state = 11, .external_lex_state = 2},
  [19573] = {.lex_state = 420, .external_lex_state = 3},
  [19574] = {.lex_state = 11, .external_lex_state = 2},
  [19575] = {.lex_state = 420, .external_lex_state = 2},
  [19576] = {.lex_state = 420, .external_lex_state = 2},
  [19577] = {.lex_state = 18, .external_lex_state = 2},
  [19578] = {.lex_state = 420, .external_lex_state = 2},
  [19579] = {.lex_state = 28, .external_lex_state = 2},
  [19580] = {.lex_state = 420, .external_lex_state = 2},
  [19581] = {.lex_state = 420, .external_lex_state = 3},
  [19582] = {.lex_state = 18, .external_lex_state = 2},
  [19583] = {.lex_state = 48, .external_lex_state = 2},
  [19584] = {.lex_state = 48, .external_lex_state = 2},
  [19585] = {.lex_state = 48, .external_lex_state = 2},
  [19586] = {.lex_state = 12, .external_lex_state = 2},
  [19587] = {.lex_state = 12, .external_lex_state = 2},
  [19588] = {.lex_state = 420, .external_lex_state = 2},
  [19589] = {.lex_state = 420, .external_lex_state = 2},
  [19590] = {.lex_state = 12, .external_lex_state = 2},
  [19591] = {.lex_state = 12, .external_lex_state = 2},
  [19592] = {.lex_state = 420, .external_lex_state = 2},
  [19593] = {.lex_state = 420, .external_lex_state = 2},
  [19594] = {.lex_state = 420, .external_lex_state = 2},
  [19595] = {.lex_state = 420, .external_lex_state = 2},
  [19596] = {.lex_state = 420, .external_lex_state = 2},
  [19597] = {.lex_state = 18, .external_lex_state = 2},
  [19598] = {.lex_state = 420, .external_lex_state = 2},
  [19599] = {.lex_state = 420, .external_lex_state = 2},
  [19600] = {.lex_state = 420, .external_lex_state = 2},
  [19601] = {.lex_state = 420, .external_lex_state = 2},
  [19602] = {.lex_state = 18, .external_lex_state = 2},
  [19603] = {.lex_state = 420, .external_lex_state = 2},
  [19604] = {.lex_state = 28, .external_lex_state = 2},
  [19605] = {.lex_state = 420, .external_lex_state = 2},
  [19606] = {.lex_state = 48, .external_lex_state = 2},
  [19607] = {.lex_state = 48, .external_lex_state = 2},
  [19608] = {.lex_state = 48, .external_lex_state = 2},
  [19609] = {.lex_state = 11, .external_lex_state = 2},
  [19610] = {.lex_state = 420, .external_lex_state = 2},
  [19611] = {.lex_state = 18, .external_lex_state = 2},
  [19612] = {.lex_state = 420, .external_lex_state = 2},
  [19613] = {.lex_state = 420, .external_lex_state = 2},
  [19614] = {.lex_state = 420, .external_lex_state = 2},
  [19615] = {.lex_state = 420, .external_lex_state = 2},
  [19616] = {.lex_state = 420, .external_lex_state = 2},
  [19617] = {.lex_state = 420, .external_lex_state = 2},
  [19618] = {.lex_state = 420, .external_lex_state = 2},
  [19619] = {.lex_state = 11, .external_lex_state = 2},
  [19620] = {.lex_state = 420, .external_lex_state = 2},
  [19621] = {.lex_state = 420, .external_lex_state = 3},
  [19622] = {.lex_state = 18, .external_lex_state = 2},
  [19623] = {.lex_state = 420, .external_lex_state = 2},
  [19624] = {.lex_state = 28, .external_lex_state = 2},
  [19625] = {.lex_state = 420, .external_lex_state = 2},
  [19626] = {.lex_state = 48, .external_lex_state = 2},
  [19627] = {.lex_state = 48, .external_lex_state = 2},
  [19628] = {.lex_state = 48, .external_lex_state = 2},
  [19629] = {.lex_state = 420, .external_lex_state = 2},
  [19630] = {.lex_state = 420, .external_lex_state = 2},
  [19631] = {.lex_state = 18, .external_lex_state = 2},
  [19632] = {.lex_state = 420, .external_lex_state = 2},
  [19633] = {.lex_state = 420, .external_lex_state = 2},
  [19634] = {.lex_state = 420, .external_lex_state = 2},
  [19635] = {.lex_state = 420, .external_lex_state = 2},
  [19636] = {.lex_state = 420, .external_lex_state = 2},
  [19637] = {.lex_state = 18, .external_lex_state = 2},
  [19638] = {.lex_state = 420, .external_lex_state = 2},
  [19639] = {.lex_state = 420, .external_lex_state = 2},
  [19640] = {.lex_state = 420, .external_lex_state = 2},
  [19641] = {.lex_state = 18, .external_lex_state = 2},
  [19642] = {.lex_state = 420, .external_lex_state = 2},
  [19643] = {.lex_state = 28, .external_lex_state = 2},
  [19644] = {.lex_state = 420, .external_lex_state = 2},
  [19645] = {.lex_state = 48, .external_lex_state = 2},
  [19646] = {.lex_state = 48, .external_lex_state = 2},
  [19647] = {.lex_state = 48, .external_lex_state = 2},
  [19648] = {.lex_state = 420, .external_lex_state = 2},
  [19649] = {.lex_state = 420, .external_lex_state = 2},
  [19650] = {.lex_state = 12, .external_lex_state = 2},
  [19651] = {.lex_state = 420, .external_lex_state = 2},
  [19652] = {.lex_state = 18, .external_lex_state = 2},
  [19653] = {.lex_state = 18, .external_lex_state = 2},
  [19654] = {.lex_state = 420, .external_lex_state = 2},
  [19655] = {.lex_state = 420, .external_lex_state = 2},
  [19656] = {.lex_state = 420, .external_lex_state = 2},
  [19657] = {.lex_state = 420, .external_lex_state = 2},
  [19658] = {.lex_state = 420, .external_lex_state = 2},
  [19659] = {.lex_state = 18, .external_lex_state = 2},
  [19660] = {.lex_state = 18, .external_lex_state = 2},
  [19661] = {.lex_state = 420, .external_lex_state = 2},
  [19662] = {.lex_state = 28, .external_lex_state = 2},
  [19663] = {.lex_state = 420, .external_lex_state = 2},
  [19664] = {.lex_state = 48, .external_lex_state = 2},
  [19665] = {.lex_state = 48, .external_lex_state = 2},
  [19666] = {.lex_state = 48, .external_lex_state = 2},
  [19667] = {.lex_state = 420, .external_lex_state = 2},
  [19668] = {.lex_state = 420, .external_lex_state = 2},
  [19669] = {.lex_state = 420, .external_lex_state = 2},
  [19670] = {.lex_state = 420, .external_lex_state = 2},
  [19671] = {.lex_state = 420, .external_lex_state = 2},
  [19672] = {.lex_state = 420, .external_lex_state = 2},
  [19673] = {.lex_state = 18, .external_lex_state = 2},
  [19674] = {.lex_state = 420, .external_lex_state = 2},
  [19675] = {.lex_state = 420, .external_lex_state = 2},
  [19676] = {.lex_state = 18, .external_lex_state = 2},
  [19677] = {.lex_state = 11, .external_lex_state = 2},
  [19678] = {.lex_state = 18, .external_lex_state = 2},
  [19679] = {.lex_state = 18, .external_lex_state = 2},
  [19680] = {.lex_state = 28, .external_lex_state = 2},
  [19681] = {.lex_state = 18, .external_lex_state = 2},
  [19682] = {.lex_state = 48, .external_lex_state = 2},
  [19683] = {.lex_state = 48, .external_lex_state = 2},
  [19684] = {.lex_state = 48, .external_lex_state = 2},
  [19685] = {.lex_state = 420, .external_lex_state = 3},
  [19686] = {.lex_state = 420, .external_lex_state = 2},
  [19687] = {.lex_state = 420, .external_lex_state = 2},
  [19688] = {.lex_state = 420, .external_lex_state = 2},
  [19689] = {.lex_state = 420, .external_lex_state = 2},
  [19690] = {.lex_state = 420, .external_lex_state = 2},
  [19691] = {.lex_state = 18, .external_lex_state = 2},
  [19692] = {.lex_state = 18, .external_lex_state = 2},
  [19693] = {.lex_state = 420, .external_lex_state = 2},
  [19694] = {.lex_state = 18, .external_lex_state = 2},
  [19695] = {.lex_state = 28, .external_lex_state = 2},
  [19696] = {.lex_state = 28, .external_lex_state = 2},
  [19697] = {.lex_state = 420, .external_lex_state = 2},
  [19698] = {.lex_state = 48, .external_lex_state = 2},
  [19699] = {.lex_state = 48, .external_lex_state = 2},
  [19700] = {.lex_state = 48, .external_lex_state = 2},
  [19701] = {.lex_state = 420, .external_lex_state = 3},
  [19702] = {.lex_state = 11, .external_lex_state = 2},
  [19703] = {.lex_state = 420, .external_lex_state = 2},
  [19704] = {.lex_state = 420, .external_lex_state = 2},
  [19705] = {.lex_state = 420, .external_lex_state = 2},
  [19706] = {.lex_state = 420, .external_lex_state = 2},
  [19707] = {.lex_state = 420, .external_lex_state = 2},
  [19708] = {.lex_state = 18, .external_lex_state = 2},
  [19709] = {.lex_state = 12, .external_lex_state = 2},
  [19710] = {.lex_state = 18, .external_lex_state = 2},
  [19711] = {.lex_state = 12, .external_lex_state = 2},
  [19712] = {.lex_state = 28, .external_lex_state = 2},
  [19713] = {.lex_state = 12, .external_lex_state = 2},
  [19714] = {.lex_state = 48, .external_lex_state = 2},
  [19715] = {.lex_state = 48, .external_lex_state = 2},
  [19716] = {.lex_state = 48, .external_lex_state = 2},
  [19717] = {.lex_state = 12, .external_lex_state = 2},
  [19718] = {.lex_state = 420, .external_lex_state = 2},
  [19719] = {.lex_state = 420, .external_lex_state = 2},
  [19720] = {.lex_state = 420, .external_lex_state = 2},
  [19721] = {.lex_state = 420, .external_lex_state = 2},
  [19722] = {.lex_state = 420, .external_lex_state = 2},
  [19723] = {.lex_state = 18, .external_lex_state = 2},
  [19724] = {.lex_state = 420, .external_lex_state = 2},
  [19725] = {.lex_state = 420, .external_lex_state = 2},
  [19726] = {.lex_state = 18, .external_lex_state = 2},
  [19727] = {.lex_state = 420, .external_lex_state = 2},
  [19728] = {.lex_state = 28, .external_lex_state = 2},
  [19729] = {.lex_state = 420, .external_lex_state = 2},
  [19730] = {.lex_state = 48, .external_lex_state = 2},
  [19731] = {.lex_state = 48, .external_lex_state = 2},
  [19732] = {.lex_state = 48, .external_lex_state = 2},
  [19733] = {.lex_state = 420, .external_lex_state = 2},
  [19734] = {.lex_state = 420, .external_lex_state = 2},
  [19735] = {.lex_state = 420, .external_lex_state = 2},
  [19736] = {.lex_state = 420, .external_lex_state = 2},
  [19737] = {.lex_state = 420, .external_lex_state = 2},
  [19738] = {.lex_state = 420, .external_lex_state = 2},
  [19739] = {.lex_state = 420, .external_lex_state = 2},
  [19740] = {.lex_state = 420, .external_lex_state = 2},
  [19741] = {.lex_state = 420, .external_lex_state = 3},
  [19742] = {.lex_state = 18, .external_lex_state = 2},
  [19743] = {.lex_state = 12, .external_lex_state = 2},
  [19744] = {.lex_state = 28, .external_lex_state = 2},
  [19745] = {.lex_state = 18, .external_lex_state = 2},
  [19746] = {.lex_state = 48, .external_lex_state = 2},
  [19747] = {.lex_state = 48, .external_lex_state = 2},
  [19748] = {.lex_state = 48, .external_lex_state = 2},
  [19749] = {.lex_state = 420, .external_lex_state = 2},
  [19750] = {.lex_state = 420, .external_lex_state = 2},
  [19751] = {.lex_state = 420, .external_lex_state = 2},
  [19752] = {.lex_state = 420, .external_lex_state = 2},
  [19753] = {.lex_state = 420, .external_lex_state = 2},
  [19754] = {.lex_state = 420, .external_lex_state = 2},
  [19755] = {.lex_state = 420, .external_lex_state = 2},
  [19756] = {.lex_state = 18, .external_lex_state = 2},
  [19757] = {.lex_state = 420, .external_lex_state = 2},
  [19758] = {.lex_state = 18, .external_lex_state = 2},
  [19759] = {.lex_state = 420, .external_lex_state = 2},
  [19760] = {.lex_state = 28, .external_lex_state = 2},
  [19761] = {.lex_state = 420, .external_lex_state = 2},
  [19762] = {.lex_state = 48, .external_lex_state = 2},
  [19763] = {.lex_state = 48, .external_lex_state = 2},
  [19764] = {.lex_state = 48, .external_lex_state = 2},
  [19765] = {.lex_state = 420, .external_lex_state = 2},
  [19766] = {.lex_state = 420, .external_lex_state = 2},
  [19767] = {.lex_state = 18, .external_lex_state = 2},
  [19768] = {.lex_state = 420, .external_lex_state = 2},
  [19769] = {.lex_state = 420, .external_lex_state = 2},
  [19770] = {.lex_state = 420, .external_lex_state = 2},
  [19771] = {.lex_state = 420, .external_lex_state = 2},
  [19772] = {.lex_state = 420, .external_lex_state = 2},
  [19773] = {.lex_state = 420, .external_lex_state = 2},
  [19774] = {.lex_state = 18, .external_lex_state = 2},
  [19775] = {.lex_state = 420, .external_lex_state = 2},
  [19776] = {.lex_state = 28, .external_lex_state = 2},
  [19777] = {.lex_state = 28, .external_lex_state = 2},
  [19778] = {.lex_state = 48, .external_lex_state = 2},
  [19779] = {.lex_state = 48, .external_lex_state = 2},
  [19780] = {.lex_state = 48, .external_lex_state = 2},
  [19781] = {.lex_state = 18, .external_lex_state = 2},
  [19782] = {.lex_state = 18, .external_lex_state = 2},
  [19783] = {.lex_state = 420, .external_lex_state = 2},
  [19784] = {.lex_state = 420, .external_lex_state = 2},
  [19785] = {.lex_state = 420, .external_lex_state = 2},
  [19786] = {.lex_state = 420, .external_lex_state = 2},
  [19787] = {.lex_state = 420, .external_lex_state = 2},
  [19788] = {.lex_state = 11, .external_lex_state = 2},
  [19789] = {.lex_state = 18, .external_lex_state = 2},
  [19790] = {.lex_state = 18, .external_lex_state = 2},
  [19791] = {.lex_state = 420, .external_lex_state = 2},
  [19792] = {.lex_state = 28, .external_lex_state = 2},
  [19793] = {.lex_state = 420, .external_lex_state = 2},
  [19794] = {.lex_state = 48, .external_lex_state = 2},
  [19795] = {.lex_state = 48, .external_lex_state = 2},
  [19796] = {.lex_state = 48, .external_lex_state = 2},
  [19797] = {.lex_state = 420, .external_lex_state = 2},
  [19798] = {.lex_state = 420, .external_lex_state = 2},
  [19799] = {.lex_state = 420, .external_lex_state = 2},
  [19800] = {.lex_state = 28, .external_lex_state = 2},
  [19801] = {.lex_state = 420, .external_lex_state = 2},
  [19802] = {.lex_state = 18, .external_lex_state = 2},
  [19803] = {.lex_state = 420, .external_lex_state = 2},
  [19804] = {.lex_state = 420, .external_lex_state = 2},
  [19805] = {.lex_state = 420, .external_lex_state = 2},
  [19806] = {.lex_state = 18, .external_lex_state = 2},
  [19807] = {.lex_state = 18, .external_lex_state = 2},
  [19808] = {.lex_state = 28, .external_lex_state = 2},
  [19809] = {.lex_state = 11, .external_lex_state = 2},
  [19810] = {.lex_state = 48, .external_lex_state = 2},
  [19811] = {.lex_state = 48, .external_lex_state = 2},
  [19812] = {.lex_state = 48, .external_lex_state = 2},
  [19813] = {.lex_state = 420, .external_lex_state = 3},
  [19814] = {.lex_state = 18, .external_lex_state = 2},
  [19815] = {.lex_state = 420, .external_lex_state = 2},
  [19816] = {.lex_state = 18, .external_lex_state = 2},
  [19817] = {.lex_state = 420, .external_lex_state = 2},
  [19818] = {.lex_state = 420, .external_lex_state = 2},
  [19819] = {.lex_state = 420, .external_lex_state = 2},
  [19820] = {.lex_state = 420, .external_lex_state = 2},
  [19821] = {.lex_state = 28, .external_lex_state = 2},
  [19822] = {.lex_state = 18, .external_lex_state = 2},
  [19823] = {.lex_state = 420, .external_lex_state = 2},
  [19824] = {.lex_state = 28, .external_lex_state = 2},
  [19825] = {.lex_state = 420, .external_lex_state = 2},
  [19826] = {.lex_state = 48, .external_lex_state = 2},
  [19827] = {.lex_state = 48, .external_lex_state = 2},
  [19828] = {.lex_state = 48, .external_lex_state = 2},
  [19829] = {.lex_state = 18, .external_lex_state = 2},
  [19830] = {.lex_state = 18, .external_lex_state = 2},
  [19831] = {.lex_state = 420, .external_lex_state = 2},
  [19832] = {.lex_state = 28, .external_lex_state = 2},
  [19833] = {.lex_state = 420, .external_lex_state = 2},
  [19834] = {.lex_state = 420, .external_lex_state = 3},
  [19835] = {.lex_state = 11, .external_lex_state = 2},
  [19836] = {.lex_state = 420, .external_lex_state = 2},
  [19837] = {.lex_state = 420, .external_lex_state = 2},
  [19838] = {.lex_state = 420, .external_lex_state = 2},
  [19839] = {.lex_state = 28, .external_lex_state = 2},
  [19840] = {.lex_state = 420, .external_lex_state = 2},
  [19841] = {.lex_state = 48, .external_lex_state = 2},
  [19842] = {.lex_state = 48, .external_lex_state = 2},
  [19843] = {.lex_state = 48, .external_lex_state = 2},
  [19844] = {.lex_state = 420, .external_lex_state = 2},
  [19845] = {.lex_state = 420, .external_lex_state = 2},
  [19846] = {.lex_state = 18, .external_lex_state = 2},
  [19847] = {.lex_state = 12, .external_lex_state = 2},
  [19848] = {.lex_state = 12, .external_lex_state = 2},
  [19849] = {.lex_state = 12, .external_lex_state = 2},
  [19850] = {.lex_state = 12, .external_lex_state = 2},
  [19851] = {.lex_state = 420, .external_lex_state = 2},
  [19852] = {.lex_state = 420, .external_lex_state = 2},
  [19853] = {.lex_state = 420, .external_lex_state = 2},
  [19854] = {.lex_state = 28, .external_lex_state = 2},
  [19855] = {.lex_state = 420, .external_lex_state = 2},
  [19856] = {.lex_state = 48, .external_lex_state = 2},
  [19857] = {.lex_state = 48, .external_lex_state = 2},
  [19858] = {.lex_state = 48, .external_lex_state = 2},
  [19859] = {.lex_state = 420, .external_lex_state = 2},
  [19860] = {.lex_state = 18, .external_lex_state = 2},
  [19861] = {.lex_state = 420, .external_lex_state = 2},
  [19862] = {.lex_state = 11, .external_lex_state = 2},
  [19863] = {.lex_state = 420, .external_lex_state = 3},
  [19864] = {.lex_state = 420, .external_lex_state = 2},
  [19865] = {.lex_state = 11, .external_lex_state = 2},
  [19866] = {.lex_state = 18, .external_lex_state = 2},
  [19867] = {.lex_state = 420, .external_lex_state = 2},
  [19868] = {.lex_state = 420, .external_lex_state = 2},
  [19869] = {.lex_state = 28, .external_lex_state = 2},
  [19870] = {.lex_state = 420, .external_lex_state = 2},
  [19871] = {.lex_state = 48, .external_lex_state = 2},
  [19872] = {.lex_state = 48, .external_lex_state = 2},
  [19873] = {.lex_state = 48, .external_lex_state = 2},
  [19874] = {.lex_state = 420, .external_lex_state = 2},
  [19875] = {.lex_state = 420, .external_lex_state = 2},
  [19876] = {.lex_state = 420, .external_lex_state = 2},
  [19877] = {.lex_state = 420, .external_lex_state = 2},
  [19878] = {.lex_state = 420, .external_lex_state = 2},
  [19879] = {.lex_state = 420, .external_lex_state = 2},
  [19880] = {.lex_state = 18, .external_lex_state = 2},
  [19881] = {.lex_state = 420, .external_lex_state = 2},
  [19882] = {.lex_state = 420, .external_lex_state = 2},
  [19883] = {.lex_state = 420, .external_lex_state = 2},
  [19884] = {.lex_state = 28, .external_lex_state = 2},
  [19885] = {.lex_state = 420, .external_lex_state = 2},
  [19886] = {.lex_state = 48, .external_lex_state = 2},
  [19887] = {.lex_state = 48, .external_lex_state = 2},
  [19888] = {.lex_state = 48, .external_lex_state = 2},
  [19889] = {.lex_state = 420, .external_lex_state = 2},
  [19890] = {.lex_state = 420, .external_lex_state = 2},
  [19891] = {.lex_state = 420, .external_lex_state = 2},
  [19892] = {.lex_state = 18, .external_lex_state = 2},
  [19893] = {.lex_state = 420, .external_lex_state = 2},
  [19894] = {.lex_state = 420, .external_lex_state = 2},
  [19895] = {.lex_state = 420, .external_lex_state = 2},
  [19896] = {.lex_state = 420, .external_lex_state = 2},
  [19897] = {.lex_state = 420, .external_lex_state = 2},
  [19898] = {.lex_state = 18, .external_lex_state = 2},
  [19899] = {.lex_state = 28, .external_lex_state = 2},
  [19900] = {.lex_state = 420, .external_lex_state = 2},
  [19901] = {.lex_state = 48, .external_lex_state = 2},
  [19902] = {.lex_state = 48, .external_lex_state = 2},
  [19903] = {.lex_state = 48, .external_lex_state = 2},
  [19904] = {.lex_state = 420, .external_lex_state = 2},
  [19905] = {.lex_state = 11, .external_lex_state = 2},
  [19906] = {.lex_state = 420, .external_lex_state = 3},
  [19907] = {.lex_state = 420, .external_lex_state = 2},
  [19908] = {.lex_state = 420, .external_lex_state = 2},
  [19909] = {.lex_state = 420, .external_lex_state = 2},
  [19910] = {.lex_state = 28, .external_lex_state = 2},
  [19911] = {.lex_state = 18, .external_lex_state = 2},
  [19912] = {.lex_state = 18, .external_lex_state = 2},
  [19913] = {.lex_state = 420, .external_lex_state = 2},
  [19914] = {.lex_state = 28, .external_lex_state = 2},
  [19915] = {.lex_state = 420, .external_lex_state = 2},
  [19916] = {.lex_state = 48, .external_lex_state = 2},
  [19917] = {.lex_state = 48, .external_lex_state = 2},
  [19918] = {.lex_state = 48, .external_lex_state = 2},
  [19919] = {.lex_state = 420, .external_lex_state = 2},
  [19920] = {.lex_state = 420, .external_lex_state = 2},
  [19921] = {.lex_state = 420, .external_lex_state = 2},
  [19922] = {.lex_state = 11, .external_lex_state = 2},
  [19923] = {.lex_state = 18, .external_lex_state = 2},
  [19924] = {.lex_state = 420, .external_lex_state = 2},
  [19925] = {.lex_state = 420, .external_lex_state = 2},
  [19926] = {.lex_state = 420, .external_lex_state = 2},
  [19927] = {.lex_state = 420, .external_lex_state = 2},
  [19928] = {.lex_state = 420, .external_lex_state = 2},
  [19929] = {.lex_state = 28, .external_lex_state = 2},
  [19930] = {.lex_state = 28, .external_lex_state = 2},
  [19931] = {.lex_state = 48, .external_lex_state = 2},
  [19932] = {.lex_state = 48, .external_lex_state = 2},
  [19933] = {.lex_state = 48, .external_lex_state = 2},
  [19934] = {.lex_state = 420, .external_lex_state = 2},
  [19935] = {.lex_state = 18, .external_lex_state = 2},
  [19936] = {.lex_state = 420, .external_lex_state = 2},
  [19937] = {.lex_state = 420, .external_lex_state = 2},
  [19938] = {.lex_state = 420, .external_lex_state = 2},
  [19939] = {.lex_state = 18, .external_lex_state = 2},
  [19940] = {.lex_state = 420, .external_lex_state = 2},
  [19941] = {.lex_state = 420, .external_lex_state = 2},
  [19942] = {.lex_state = 18, .external_lex_state = 2},
  [19943] = {.lex_state = 420, .external_lex_state = 2},
  [19944] = {.lex_state = 28, .external_lex_state = 2},
  [19945] = {.lex_state = 18, .external_lex_state = 2},
  [19946] = {.lex_state = 48, .external_lex_state = 2},
  [19947] = {.lex_state = 48, .external_lex_state = 2},
  [19948] = {.lex_state = 48, .external_lex_state = 2},
  [19949] = {.lex_state = 420, .external_lex_state = 2},
  [19950] = {.lex_state = 11, .external_lex_state = 2},
  [19951] = {.lex_state = 420, .external_lex_state = 3},
  [19952] = {.lex_state = 420, .external_lex_state = 2},
  [19953] = {.lex_state = 28, .external_lex_state = 2},
  [19954] = {.lex_state = 420, .external_lex_state = 2},
  [19955] = {.lex_state = 420, .external_lex_state = 2},
  [19956] = {.lex_state = 18, .external_lex_state = 2},
  [19957] = {.lex_state = 420, .external_lex_state = 2},
  [19958] = {.lex_state = 420, .external_lex_state = 2},
  [19959] = {.lex_state = 28, .external_lex_state = 2},
  [19960] = {.lex_state = 28, .external_lex_state = 2},
  [19961] = {.lex_state = 48, .external_lex_state = 2},
  [19962] = {.lex_state = 48, .external_lex_state = 2},
  [19963] = {.lex_state = 48, .external_lex_state = 2},
  [19964] = {.lex_state = 420, .external_lex_state = 2},
  [19965] = {.lex_state = 420, .external_lex_state = 3},
  [19966] = {.lex_state = 11, .external_lex_state = 2},
  [19967] = {.lex_state = 420, .external_lex_state = 2},
  [19968] = {.lex_state = 420, .external_lex_state = 2},
  [19969] = {.lex_state = 420, .external_lex_state = 2},
  [19970] = {.lex_state = 420, .external_lex_state = 2},
  [19971] = {.lex_state = 420, .external_lex_state = 2},
  [19972] = {.lex_state = 420, .external_lex_state = 2},
  [19973] = {.lex_state = 18, .external_lex_state = 2},
  [19974] = {.lex_state = 28, .external_lex_state = 2},
  [19975] = {.lex_state = 12, .external_lex_state = 2},
  [19976] = {.lex_state = 48, .external_lex_state = 2},
  [19977] = {.lex_state = 48, .external_lex_state = 2},
  [19978] = {.lex_state = 48, .external_lex_state = 2},
  [19979] = {.lex_state = 12, .external_lex_state = 2},
  [19980] = {.lex_state = 12, .external_lex_state = 2},
  [19981] = {.lex_state = 12, .external_lex_state = 2},
  [19982] = {.lex_state = 420, .external_lex_state = 2},
  [19983] = {.lex_state = 420, .external_lex_state = 2},
  [19984] = {.lex_state = 420, .external_lex_state = 2},
  [19985] = {.lex_state = 420, .external_lex_state = 2},
  [19986] = {.lex_state = 420, .external_lex_state = 2},
  [19987] = {.lex_state = 18, .external_lex_state = 2},
  [19988] = {.lex_state = 420, .external_lex_state = 2},
  [19989] = {.lex_state = 28, .external_lex_state = 2},
  [19990] = {.lex_state = 420, .external_lex_state = 2},
  [19991] = {.lex_state = 48, .external_lex_state = 2},
  [19992] = {.lex_state = 48, .external_lex_state = 2},
  [19993] = {.lex_state = 48, .external_lex_state = 2},
  [19994] = {.lex_state = 420, .external_lex_state = 2},
  [19995] = {.lex_state = 420, .external_lex_state = 3},
  [19996] = {.lex_state = 420, .external_lex_state = 2},
  [19997] = {.lex_state = 420, .external_lex_state = 2},
  [19998] = {.lex_state = 420, .external_lex_state = 2},
  [19999] = {.lex_state = 420, .external_lex_state = 2},
  [20000] = {.lex_state = 420, .external_lex_state = 2},
  [20001] = {.lex_state = 420, .external_lex_state = 2},
  [20002] = {.lex_state = 420, .external_lex_state = 2},
  [20003] = {.lex_state = 420, .external_lex_state = 2},
  [20004] = {.lex_state = 28, .external_lex_state = 2},
  [20005] = {.lex_state = 420, .external_lex_state = 2},
  [20006] = {.lex_state = 48, .external_lex_state = 2},
  [20007] = {.lex_state = 48, .external_lex_state = 2},
  [20008] = {.lex_state = 48, .external_lex_state = 2},
  [20009] = {.lex_state = 420, .external_lex_state = 2},
  [20010] = {.lex_state = 420, .external_lex_state = 2},
  [20011] = {.lex_state = 18, .external_lex_state = 2},
  [20012] = {.lex_state = 420, .external_lex_state = 2},
  [20013] = {.lex_state = 420, .external_lex_state = 2},
  [20014] = {.lex_state = 420, .external_lex_state = 2},
  [20015] = {.lex_state = 420, .external_lex_state = 2},
  [20016] = {.lex_state = 420, .external_lex_state = 2},
  [20017] = {.lex_state = 420, .external_lex_state = 2},
  [20018] = {.lex_state = 420, .external_lex_state = 2},
  [20019] = {.lex_state = 28, .external_lex_state = 2},
  [20020] = {.lex_state = 18, .external_lex_state = 2},
  [20021] = {.lex_state = 48, .external_lex_state = 2},
  [20022] = {.lex_state = 48, .external_lex_state = 2},
  [20023] = {.lex_state = 48, .external_lex_state = 2},
  [20024] = {.lex_state = 420, .external_lex_state = 2},
  [20025] = {.lex_state = 420, .external_lex_state = 2},
  [20026] = {.lex_state = 420, .external_lex_state = 2},
  [20027] = {.lex_state = 420, .external_lex_state = 2},
  [20028] = {.lex_state = 420, .external_lex_state = 2},
  [20029] = {.lex_state = 18, .external_lex_state = 2},
  [20030] = {.lex_state = 420, .external_lex_state = 2},
  [20031] = {.lex_state = 18, .external_lex_state = 2},
  [20032] = {.lex_state = 11, .external_lex_state = 2},
  [20033] = {.lex_state = 420, .external_lex_state = 3},
  [20034] = {.lex_state = 28, .external_lex_state = 2},
  [20035] = {.lex_state = 420, .external_lex_state = 2},
  [20036] = {.lex_state = 48, .external_lex_state = 2},
  [20037] = {.lex_state = 48, .external_lex_state = 2},
  [20038] = {.lex_state = 48, .external_lex_state = 2},
  [20039] = {.lex_state = 420, .external_lex_state = 2},
  [20040] = {.lex_state = 420, .external_lex_state = 2},
  [20041] = {.lex_state = 28, .external_lex_state = 2},
  [20042] = {.lex_state = 420, .external_lex_state = 2},
  [20043] = {.lex_state = 18, .external_lex_state = 2},
  [20044] = {.lex_state = 18, .external_lex_state = 2},
  [20045] = {.lex_state = 420, .external_lex_state = 2},
  [20046] = {.lex_state = 420, .external_lex_state = 2},
  [20047] = {.lex_state = 420, .external_lex_state = 2},
  [20048] = {.lex_state = 420, .external_lex_state = 2},
  [20049] = {.lex_state = 28, .external_lex_state = 2},
  [20050] = {.lex_state = 420, .external_lex_state = 2},
  [20051] = {.lex_state = 48, .external_lex_state = 2},
  [20052] = {.lex_state = 48, .external_lex_state = 2},
  [20053] = {.lex_state = 48, .external_lex_state = 2},
  [20054] = {.lex_state = 11, .external_lex_state = 2},
  [20055] = {.lex_state = 18, .external_lex_state = 2},
  [20056] = {.lex_state = 420, .external_lex_state = 2},
  [20057] = {.lex_state = 420, .external_lex_state = 2},
  [20058] = {.lex_state = 420, .external_lex_state = 2},
  [20059] = {.lex_state = 420, .external_lex_state = 2},
  [20060] = {.lex_state = 420, .external_lex_state = 2},
  [20061] = {.lex_state = 12, .external_lex_state = 2},
  [20062] = {.lex_state = 420, .external_lex_state = 2},
  [20063] = {.lex_state = 28, .external_lex_state = 2},
  [20064] = {.lex_state = 28, .external_lex_state = 2},
  [20065] = {.lex_state = 420, .external_lex_state = 2},
  [20066] = {.lex_state = 48, .external_lex_state = 2},
  [20067] = {.lex_state = 48, .external_lex_state = 2},
  [20068] = {.lex_state = 48, .external_lex_state = 2},
  [20069] = {.lex_state = 420, .external_lex_state = 2},
  [20070] = {.lex_state = 18, .external_lex_state = 2},
  [20071] = {.lex_state = 420, .external_lex_state = 2},
  [20072] = {.lex_state = 420, .external_lex_state = 2},
  [20073] = {.lex_state = 420, .external_lex_state = 3},
  [20074] = {.lex_state = 12, .external_lex_state = 2},
  [20075] = {.lex_state = 420, .external_lex_state = 2},
  [20076] = {.lex_state = 420, .external_lex_state = 2},
  [20077] = {.lex_state = 18, .external_lex_state = 2},
  [20078] = {.lex_state = 420, .external_lex_state = 2},
  [20079] = {.lex_state = 18, .external_lex_state = 2},
  [20080] = {.lex_state = 48, .external_lex_state = 2},
  [20081] = {.lex_state = 48, .external_lex_state = 2},
  [20082] = {.lex_state = 48, .external_lex_state = 2},
  [20083] = {.lex_state = 420, .external_lex_state = 2},
  [20084] = {.lex_state = 420, .external_lex_state = 2},
  [20085] = {.lex_state = 420, .external_lex_state = 2},
  [20086] = {.lex_state = 420, .external_lex_state = 2},
  [20087] = {.lex_state = 420, .external_lex_state = 2},
  [20088] = {.lex_state = 28, .external_lex_state = 2},
  [20089] = {.lex_state = 420, .external_lex_state = 2},
  [20090] = {.lex_state = 420, .external_lex_state = 2},
  [20091] = {.lex_state = 420, .external_lex_state = 2},
  [20092] = {.lex_state = 420, .external_lex_state = 2},
  [20093] = {.lex_state = 18, .external_lex_state = 2},
  [20094] = {.lex_state = 48, .external_lex_state = 2},
  [20095] = {.lex_state = 48, .external_lex_state = 2},
  [20096] = {.lex_state = 48, .external_lex_state = 2},
  [20097] = {.lex_state = 18, .external_lex_state = 2},
  [20098] = {.lex_state = 420, .external_lex_state = 2},
  [20099] = {.lex_state = 420, .external_lex_state = 2},
  [20100] = {.lex_state = 28, .external_lex_state = 2},
  [20101] = {.lex_state = 420, .external_lex_state = 2},
  [20102] = {.lex_state = 420, .external_lex_state = 3},
  [20103] = {.lex_state = 11, .external_lex_state = 2},
  [20104] = {.lex_state = 420, .external_lex_state = 2},
  [20105] = {.lex_state = 420, .external_lex_state = 2},
  [20106] = {.lex_state = 420, .external_lex_state = 2},
  [20107] = {.lex_state = 420, .external_lex_state = 2},
  [20108] = {.lex_state = 48, .external_lex_state = 2},
  [20109] = {.lex_state = 48, .external_lex_state = 2},
  [20110] = {.lex_state = 48, .external_lex_state = 2},
  [20111] = {.lex_state = 420, .external_lex_state = 2},
  [20112] = {.lex_state = 420, .external_lex_state = 2},
  [20113] = {.lex_state = 18, .external_lex_state = 2},
  [20114] = {.lex_state = 28, .external_lex_state = 2},
  [20115] = {.lex_state = 12, .external_lex_state = 2},
  [20116] = {.lex_state = 12, .external_lex_state = 2},
  [20117] = {.lex_state = 12, .external_lex_state = 2},
  [20118] = {.lex_state = 420, .external_lex_state = 2},
  [20119] = {.lex_state = 420, .external_lex_state = 2},
  [20120] = {.lex_state = 420, .external_lex_state = 2},
  [20121] = {.lex_state = 420, .external_lex_state = 2},
  [20122] = {.lex_state = 48, .external_lex_state = 2},
  [20123] = {.lex_state = 48, .external_lex_state = 2},
  [20124] = {.lex_state = 48, .external_lex_state = 2},
  [20125] = {.lex_state = 420, .external_lex_state = 2},
  [20126] = {.lex_state = 420, .external_lex_state = 2},
  [20127] = {.lex_state = 420, .external_lex_state = 2},
  [20128] = {.lex_state = 420, .external_lex_state = 2},
  [20129] = {.lex_state = 420, .external_lex_state = 2},
  [20130] = {.lex_state = 420, .external_lex_state = 2},
  [20131] = {.lex_state = 18, .external_lex_state = 2},
  [20132] = {.lex_state = 420, .external_lex_state = 2},
  [20133] = {.lex_state = 420, .external_lex_state = 2},
  [20134] = {.lex_state = 420, .external_lex_state = 2},
  [20135] = {.lex_state = 420, .external_lex_state = 2},
  [20136] = {.lex_state = 48, .external_lex_state = 2},
  [20137] = {.lex_state = 48, .external_lex_state = 2},
  [20138] = {.lex_state = 48, .external_lex_state = 2},
  [20139] = {.lex_state = 420, .external_lex_state = 2},
  [20140] = {.lex_state = 420, .external_lex_state = 2},
  [20141] = {.lex_state = 420, .external_lex_state = 2},
  [20142] = {.lex_state = 18, .external_lex_state = 2},
  [20143] = {.lex_state = 18, .external_lex_state = 2},
  [20144] = {.lex_state = 18, .external_lex_state = 2},
  [20145] = {.lex_state = 420, .external_lex_state = 2},
  [20146] = {.lex_state = 420, .external_lex_state = 2},
  [20147] = {.lex_state = 420, .external_lex_state = 2},
  [20148] = {.lex_state = 48, .external_lex_state = 2},
  [20149] = {.lex_state = 48, .external_lex_state = 2},
  [20150] = {.lex_state = 48, .external_lex_state = 2},
  [20151] = {.lex_state = 420, .external_lex_state = 2},
  [20152] = {.lex_state = 420, .external_lex_state = 2},
  [20153] = {.lex_state = 420, .external_lex_state = 2},
  [20154] = {.lex_state = 420, .external_lex_state = 2},
  [20155] = {.lex_state = 48, .external_lex_state = 2},
  [20156] = {.lex_state = 48, .external_lex_state = 2},
  [20157] = {.lex_state = 48, .external_lex_state = 2},
  [20158] = {.lex_state = 420, .external_lex_state = 2},
  [20159] = {.lex_state = 420, .external_lex_state = 2},
  [20160] = {.lex_state = 48, .external_lex_state = 2},
  [20161] = {.lex_state = 48, .external_lex_state = 2},
  [20162] = {.lex_state = 48, .external_lex_state = 2},
  [20163] = {.lex_state = 420, .external_lex_state = 2},
  [20164] = {.lex_state = 420, .external_lex_state = 2},
  [20165] = {.lex_state = 48, .external_lex_state = 2},
  [20166] = {.lex_state = 48, .external_lex_state = 2},
  [20167] = {.lex_state = 48, .external_lex_state = 2},
  [20168] = {.lex_state = 420, .external_lex_state = 2},
  [20169] = {.lex_state = 420, .external_lex_state = 2},
  [20170] = {.lex_state = 48, .external_lex_state = 2},
  [20171] = {.lex_state = 48, .external_lex_state = 2},
  [20172] = {.lex_state = 48, .external_lex_state = 2},
  [20173] = {.lex_state = 420, .external_lex_state = 2},
  [20174] = {.lex_state = 420, .external_lex_state = 2},
  [20175] = {.lex_state = 48, .external_lex_state = 2},
  [20176] = {.lex_state = 48, .external_lex_state = 2},
  [20177] = {.lex_state = 48, .external_lex_state = 2},
  [20178] = {.lex_state = 420, .external_lex_state = 2},
  [20179] = {.lex_state = 18, .external_lex_state = 2},
  [20180] = {.lex_state = 48, .external_lex_state = 2},
  [20181] = {.lex_state = 48, .external_lex_state = 2},
  [20182] = {.lex_state = 48, .external_lex_state = 2},
  [20183] = {.lex_state = 420, .external_lex_state = 2},
  [20184] = {.lex_state = 420, .external_lex_state = 2},
  [20185] = {.lex_state = 48, .external_lex_state = 2},
  [20186] = {.lex_state = 48, .external_lex_state = 2},
  [20187] = {.lex_state = 48, .external_lex_state = 2},
  [20188] = {.lex_state = 420, .external_lex_state = 2},
  [20189] = {.lex_state = 420, .external_lex_state = 2},
  [20190] = {.lex_state = 48, .external_lex_state = 2},
  [20191] = {.lex_state = 48, .external_lex_state = 2},
  [20192] = {.lex_state = 48, .external_lex_state = 2},
  [20193] = {.lex_state = 18, .external_lex_state = 2},
  [20194] = {.lex_state = 420, .external_lex_state = 2},
  [20195] = {.lex_state = 48, .external_lex_state = 2},
  [20196] = {.lex_state = 48, .external_lex_state = 2},
  [20197] = {.lex_state = 48, .external_lex_state = 2},
  [20198] = {.lex_state = 420, .external_lex_state = 2},
  [20199] = {.lex_state = 420, .external_lex_state = 2},
  [20200] = {.lex_state = 48, .external_lex_state = 2},
  [20201] = {.lex_state = 48, .external_lex_state = 2},
  [20202] = {.lex_state = 48, .external_lex_state = 2},
  [20203] = {.lex_state = 420, .external_lex_state = 2},
  [20204] = {.lex_state = 420, .external_lex_state = 2},
  [20205] = {.lex_state = 48, .external_lex_state = 2},
  [20206] = {.lex_state = 48, .external_lex_state = 2},
  [20207] = {.lex_state = 48, .external_lex_state = 2},
  [20208] = {.lex_state = 420, .external_lex_state = 2},
  [20209] = {.lex_state = 420, .external_lex_state = 2},
  [20210] = {.lex_state = 48, .external_lex_state = 2},
  [20211] = {.lex_state = 48, .external_lex_state = 2},
  [20212] = {.lex_state = 48, .external_lex_state = 2},
  [20213] = {.lex_state = 420, .external_lex_state = 2},
  [20214] = {.lex_state = 420, .external_lex_state = 2},
  [20215] = {.lex_state = 48, .external_lex_state = 2},
  [20216] = {.lex_state = 48, .external_lex_state = 2},
  [20217] = {.lex_state = 48, .external_lex_state = 2},
  [20218] = {.lex_state = 420, .external_lex_state = 2},
  [20219] = {.lex_state = 420, .external_lex_state = 2},
  [20220] = {.lex_state = 420, .external_lex_state = 2},
  [20221] = {.lex_state = 28, .external_lex_state = 2},
  [20222] = {.lex_state = 18, .external_lex_state = 2},
  [20223] = {.lex_state = 18, .external_lex_state = 2},
  [20224] = {.lex_state = 420, .external_lex_state = 2},
  [20225] = {.lex_state = 420, .external_lex_state = 2},
  [20226] = {.lex_state = 420, .external_lex_state = 2},
  [20227] = {.lex_state = 420, .external_lex_state = 2},
  [20228] = {.lex_state = 420, .external_lex_state = 2},
  [20229] = {.lex_state = 420, .external_lex_state = 2},
  [20230] = {.lex_state = 420, .external_lex_state = 2},
  [20231] = {.lex_state = 420, .external_lex_state = 2},
  [20232] = {.lex_state = 420, .external_lex_state = 2},
  [20233] = {.lex_state = 420, .external_lex_state = 2},
  [20234] = {.lex_state = 420, .external_lex_state = 2},
  [20235] = {.lex_state = 420, .external_lex_state = 2},
  [20236] = {.lex_state = 420, .external_lex_state = 2},
  [20237] = {.lex_state = 18, .external_lex_state = 2},
  [20238] = {.lex_state = 420, .external_lex_state = 2},
  [20239] = {.lex_state = 420, .external_lex_state = 2},
  [20240] = {.lex_state = 420, .external_lex_state = 2},
  [20241] = {.lex_state = 420, .external_lex_state = 2},
  [20242] = {.lex_state = 24, .external_lex_state = 2},
  [20243] = {.lex_state = 420, .external_lex_state = 2},
  [20244] = {.lex_state = 420, .external_lex_state = 2},
  [20245] = {.lex_state = 240, .external_lex_state = 2},
  [20246] = {.lex_state = 24, .external_lex_state = 2},
  [20247] = {.lex_state = 12, .external_lex_state = 2},
  [20248] = {.lex_state = 420, .external_lex_state = 2},
  [20249] = {.lex_state = 420, .external_lex_state = 2},
  [20250] = {.lex_state = 420, .external_lex_state = 2},
  [20251] = {.lex_state = 420, .external_lex_state = 2},
  [20252] = {.lex_state = 420, .external_lex_state = 2},
  [20253] = {.lex_state = 18, .external_lex_state = 2},
  [20254] = {.lex_state = 420, .external_lex_state = 2},
  [20255] = {.lex_state = 28, .external_lex_state = 2},
  [20256] = {.lex_state = 28, .external_lex_state = 2},
  [20257] = {.lex_state = 28, .external_lex_state = 2},
  [20258] = {.lex_state = 18, .external_lex_state = 2},
  [20259] = {.lex_state = 420, .external_lex_state = 2},
  [20260] = {.lex_state = 420, .external_lex_state = 2},
  [20261] = {.lex_state = 18, .external_lex_state = 2},
  [20262] = {.lex_state = 18, .external_lex_state = 2},
  [20263] = {.lex_state = 420, .external_lex_state = 2},
  [20264] = {.lex_state = 420, .external_lex_state = 2},
  [20265] = {.lex_state = 48, .external_lex_state = 2},
  [20266] = {.lex_state = 48, .external_lex_state = 2},
  [20267] = {.lex_state = 48, .external_lex_state = 2},
  [20268] = {.lex_state = 420, .external_lex_state = 2},
  [20269] = {.lex_state = 420, .external_lex_state = 2},
  [20270] = {.lex_state = 420, .external_lex_state = 2},
  [20271] = {.lex_state = 420, .external_lex_state = 2},
  [20272] = {.lex_state = 24, .external_lex_state = 2},
  [20273] = {.lex_state = 240, .external_lex_state = 2},
  [20274] = {.lex_state = 24, .external_lex_state = 2},
  [20275] = {.lex_state = 420, .external_lex_state = 2},
  [20276] = {.lex_state = 420, .external_lex_state = 2},
  [20277] = {.lex_state = 420, .external_lex_state = 2},
  [20278] = {.lex_state = 420, .external_lex_state = 2},
  [20279] = {.lex_state = 11, .external_lex_state = 2},
  [20280] = {.lex_state = 28, .external_lex_state = 2},
  [20281] = {.lex_state = 420, .external_lex_state = 2},
  [20282] = {.lex_state = 420, .external_lex_state = 2},
  [20283] = {.lex_state = 420, .external_lex_state = 2},
  [20284] = {.lex_state = 420, .external_lex_state = 2},
  [20285] = {.lex_state = 420, .external_lex_state = 2},
  [20286] = {.lex_state = 420, .external_lex_state = 2},
  [20287] = {.lex_state = 420, .external_lex_state = 2},
  [20288] = {.lex_state = 420, .external_lex_state = 2},
  [20289] = {.lex_state = 24, .external_lex_state = 2},
  [20290] = {.lex_state = 240, .external_lex_state = 2},
  [20291] = {.lex_state = 24, .external_lex_state = 2},
  [20292] = {.lex_state = 420, .external_lex_state = 2},
  [20293] = {.lex_state = 420, .external_lex_state = 2},
  [20294] = {.lex_state = 420, .external_lex_state = 2},
  [20295] = {.lex_state = 420, .external_lex_state = 2},
  [20296] = {.lex_state = 420, .external_lex_state = 2},
  [20297] = {.lex_state = 28, .external_lex_state = 2},
  [20298] = {.lex_state = 420, .external_lex_state = 2},
  [20299] = {.lex_state = 12, .external_lex_state = 2},
  [20300] = {.lex_state = 420, .external_lex_state = 2},
  [20301] = {.lex_state = 420, .external_lex_state = 2},
  [20302] = {.lex_state = 12, .external_lex_state = 2},
  [20303] = {.lex_state = 28, .external_lex_state = 2},
  [20304] = {.lex_state = 28, .external_lex_state = 2},
  [20305] = {.lex_state = 420, .external_lex_state = 2},
  [20306] = {.lex_state = 240, .external_lex_state = 2},
  [20307] = {.lex_state = 420, .external_lex_state = 2},
  [20308] = {.lex_state = 18, .external_lex_state = 2},
  [20309] = {.lex_state = 420, .external_lex_state = 2},
  [20310] = {.lex_state = 420, .external_lex_state = 2},
  [20311] = {.lex_state = 28, .external_lex_state = 2},
  [20312] = {.lex_state = 420, .external_lex_state = 2},
  [20313] = {.lex_state = 28, .external_lex_state = 2},
  [20314] = {.lex_state = 12, .external_lex_state = 2},
  [20315] = {.lex_state = 420, .external_lex_state = 2},
  [20316] = {.lex_state = 420, .external_lex_state = 2},
  [20317] = {.lex_state = 420, .external_lex_state = 2},
  [20318] = {.lex_state = 240, .external_lex_state = 2},
  [20319] = {.lex_state = 18, .external_lex_state = 2},
  [20320] = {.lex_state = 420, .external_lex_state = 2},
  [20321] = {.lex_state = 240, .external_lex_state = 2},
  [20322] = {.lex_state = 28, .external_lex_state = 2},
  [20323] = {.lex_state = 420, .external_lex_state = 2},
  [20324] = {.lex_state = 240, .external_lex_state = 2},
  [20325] = {.lex_state = 420, .external_lex_state = 2},
  [20326] = {.lex_state = 420, .external_lex_state = 2},
  [20327] = {.lex_state = 240, .external_lex_state = 2},
  [20328] = {.lex_state = 240, .external_lex_state = 2},
  [20329] = {.lex_state = 240, .external_lex_state = 2},
  [20330] = {.lex_state = 240, .external_lex_state = 2},
  [20331] = {.lex_state = 240, .external_lex_state = 2},
  [20332] = {.lex_state = 240, .external_lex_state = 2},
  [20333] = {.lex_state = 240, .external_lex_state = 2},
  [20334] = {.lex_state = 240, .external_lex_state = 2},
  [20335] = {.lex_state = 240, .external_lex_state = 2},
  [20336] = {.lex_state = 240, .external_lex_state = 2},
  [20337] = {.lex_state = 240, .external_lex_state = 2},
  [20338] = {.lex_state = 240, .external_lex_state = 2},
  [20339] = {.lex_state = 240, .external_lex_state = 2},
  [20340] = {.lex_state = 240, .external_lex_state = 2},
  [20341] = {.lex_state = 240, .external_lex_state = 2},
  [20342] = {.lex_state = 240, .external_lex_state = 2},
  [20343] = {.lex_state = 240, .external_lex_state = 2},
  [20344] = {.lex_state = 240, .external_lex_state = 2},
  [20345] = {.lex_state = 240, .external_lex_state = 2},
  [20346] = {.lex_state = 240, .external_lex_state = 2},
  [20347] = {.lex_state = 240, .external_lex_state = 2},
  [20348] = {.lex_state = 240, .external_lex_state = 2},
  [20349] = {.lex_state = 240, .external_lex_state = 2},
  [20350] = {.lex_state = 240, .external_lex_state = 2},
  [20351] = {.lex_state = 240, .external_lex_state = 2},
  [20352] = {.lex_state = 240, .external_lex_state = 2},
  [20353] = {.lex_state = 240, .external_lex_state = 2},
  [20354] = {.lex_state = 240, .external_lex_state = 2},
  [20355] = {.lex_state = 240, .external_lex_state = 2},
  [20356] = {.lex_state = 240, .external_lex_state = 2},
  [20357] = {.lex_state = 240, .external_lex_state = 2},
  [20358] = {.lex_state = 240, .external_lex_state = 2},
  [20359] = {.lex_state = 240, .external_lex_state = 2},
  [20360] = {.lex_state = 240, .external_lex_state = 2},
  [20361] = {.lex_state = 240, .external_lex_state = 2},
  [20362] = {.lex_state = 240, .external_lex_state = 2},
  [20363] = {.lex_state = 240, .external_lex_state = 2},
  [20364] = {.lex_state = 240, .external_lex_state = 2},
  [20365] = {.lex_state = 240, .external_lex_state = 2},
  [20366] = {.lex_state = 240, .external_lex_state = 2},
  [20367] = {.lex_state = 240, .external_lex_state = 2},
  [20368] = {.lex_state = 240, .external_lex_state = 2},
  [20369] = {.lex_state = 240, .external_lex_state = 2},
  [20370] = {.lex_state = 240, .external_lex_state = 2},
  [20371] = {.lex_state = 240, .external_lex_state = 2},
  [20372] = {.lex_state = 240, .external_lex_state = 2},
  [20373] = {.lex_state = 240, .external_lex_state = 2},
  [20374] = {.lex_state = 240, .external_lex_state = 2},
  [20375] = {.lex_state = 240, .external_lex_state = 2},
  [20376] = {.lex_state = 18, .external_lex_state = 2},
  [20377] = {.lex_state = 420, .external_lex_state = 2},
  [20378] = {.lex_state = 18, .external_lex_state = 2},
  [20379] = {.lex_state = 18, .external_lex_state = 2},
  [20380] = {.lex_state = 420, .external_lex_state = 2},
  [20381] = {.lex_state = 18, .external_lex_state = 2},
  [20382] = {.lex_state = 420, .external_lex_state = 2},
  [20383] = {.lex_state = 420, .external_lex_state = 2},
  [20384] = {.lex_state = 18, .external_lex_state = 2},
  [20385] = {.lex_state = 18, .external_lex_state = 2},
  [20386] = {.lex_state = 420, .external_lex_state = 2},
  [20387] = {.lex_state = 18, .external_lex_state = 2},
  [20388] = {.lex_state = 18, .external_lex_state = 2},
  [20389] = {.lex_state = 420, .external_lex_state = 2},
  [20390] = {.lex_state = 420, .external_lex_state = 2},
  [20391] = {.lex_state = 420, .external_lex_state = 2},
  [20392] = {.lex_state = 420, .external_lex_state = 2},
  [20393] = {.lex_state = 420, .external_lex_state = 2},
  [20394] = {.lex_state = 420, .external_lex_state = 2},
  [20395] = {.lex_state = 18, .external_lex_state = 2},
  [20396] = {.lex_state = 420, .external_lex_state = 9},
  [20397] = {.lex_state = 420, .external_lex_state = 2},
  [20398] = {.lex_state = 18, .external_lex_state = 2},
  [20399] = {.lex_state = 420, .external_lex_state = 2},
  [20400] = {.lex_state = 420, .external_lex_state = 2},
  [20401] = {.lex_state = 420, .external_lex_state = 2},
  [20402] = {.lex_state = 28, .external_lex_state = 2},
  [20403] = {.lex_state = 420, .external_lex_state = 2},
  [20404] = {.lex_state = 420, .external_lex_state = 2},
  [20405] = {.lex_state = 18, .external_lex_state = 2},
  [20406] = {.lex_state = 420, .external_lex_state = 2},
  [20407] = {.lex_state = 18, .external_lex_state = 2},
  [20408] = {.lex_state = 18, .external_lex_state = 2},
  [20409] = {.lex_state = 12, .external_lex_state = 2},
  [20410] = {.lex_state = 28, .external_lex_state = 2},
  [20411] = {.lex_state = 420, .external_lex_state = 2},
  [20412] = {.lex_state = 420, .external_lex_state = 2},
  [20413] = {.lex_state = 420, .external_lex_state = 2},
  [20414] = {.lex_state = 420, .external_lex_state = 2},
  [20415] = {.lex_state = 420, .external_lex_state = 2},
  [20416] = {.lex_state = 420, .external_lex_state = 2},
  [20417] = {.lex_state = 18, .external_lex_state = 2},
  [20418] = {.lex_state = 18, .external_lex_state = 2},
  [20419] = {.lex_state = 420, .external_lex_state = 2},
  [20420] = {.lex_state = 420, .external_lex_state = 2},
  [20421] = {.lex_state = 420, .external_lex_state = 2},
  [20422] = {.lex_state = 420, .external_lex_state = 2},
  [20423] = {.lex_state = 420, .external_lex_state = 2},
  [20424] = {.lex_state = 18, .external_lex_state = 2},
  [20425] = {.lex_state = 420, .external_lex_state = 2},
  [20426] = {.lex_state = 420, .external_lex_state = 2},
  [20427] = {.lex_state = 28, .external_lex_state = 2},
  [20428] = {.lex_state = 420, .external_lex_state = 2},
  [20429] = {.lex_state = 420, .external_lex_state = 3},
  [20430] = {.lex_state = 11, .external_lex_state = 2},
  [20431] = {.lex_state = 11, .external_lex_state = 2},
  [20432] = {.lex_state = 11, .external_lex_state = 2},
  [20433] = {.lex_state = 420, .external_lex_state = 2},
  [20434] = {.lex_state = 420, .external_lex_state = 2},
  [20435] = {.lex_state = 420, .external_lex_state = 2},
  [20436] = {.lex_state = 420, .external_lex_state = 2},
  [20437] = {.lex_state = 420, .external_lex_state = 2},
  [20438] = {.lex_state = 18, .external_lex_state = 2},
  [20439] = {.lex_state = 420, .external_lex_state = 2},
  [20440] = {.lex_state = 420, .external_lex_state = 2},
  [20441] = {.lex_state = 420, .external_lex_state = 2},
  [20442] = {.lex_state = 420, .external_lex_state = 2},
  [20443] = {.lex_state = 12, .external_lex_state = 2},
  [20444] = {.lex_state = 18, .external_lex_state = 2},
  [20445] = {.lex_state = 420, .external_lex_state = 2},
  [20446] = {.lex_state = 28, .external_lex_state = 2},
  [20447] = {.lex_state = 12, .external_lex_state = 2},
  [20448] = {.lex_state = 420, .external_lex_state = 2},
  [20449] = {.lex_state = 12, .external_lex_state = 2},
  [20450] = {.lex_state = 12, .external_lex_state = 2},
  [20451] = {.lex_state = 12, .external_lex_state = 2},
  [20452] = {.lex_state = 420, .external_lex_state = 2},
  [20453] = {.lex_state = 420, .external_lex_state = 2},
  [20454] = {.lex_state = 420, .external_lex_state = 2},
  [20455] = {.lex_state = 420, .external_lex_state = 2},
  [20456] = {.lex_state = 420, .external_lex_state = 2},
  [20457] = {.lex_state = 420, .external_lex_state = 2},
  [20458] = {.lex_state = 420, .external_lex_state = 2},
  [20459] = {.lex_state = 420, .external_lex_state = 2},
  [20460] = {.lex_state = 18, .external_lex_state = 2},
  [20461] = {.lex_state = 420, .external_lex_state = 2},
  [20462] = {.lex_state = 420, .external_lex_state = 2},
  [20463] = {.lex_state = 420, .external_lex_state = 2},
  [20464] = {.lex_state = 28, .external_lex_state = 2},
  [20465] = {.lex_state = 420, .external_lex_state = 2},
  [20466] = {.lex_state = 420, .external_lex_state = 2},
  [20467] = {.lex_state = 420, .external_lex_state = 2},
  [20468] = {.lex_state = 12, .external_lex_state = 2},
  [20469] = {.lex_state = 420, .external_lex_state = 2},
  [20470] = {.lex_state = 420, .external_lex_state = 2},
  [20471] = {.lex_state = 420, .external_lex_state = 2},
  [20472] = {.lex_state = 24, .external_lex_state = 2},
  [20473] = {.lex_state = 18, .external_lex_state = 2},
  [20474] = {.lex_state = 420, .external_lex_state = 2},
  [20475] = {.lex_state = 420, .external_lex_state = 2},
  [20476] = {.lex_state = 420, .external_lex_state = 2},
  [20477] = {.lex_state = 420, .external_lex_state = 2},
  [20478] = {.lex_state = 240, .external_lex_state = 2},
  [20479] = {.lex_state = 18, .external_lex_state = 2},
  [20480] = {.lex_state = 420, .external_lex_state = 2},
  [20481] = {.lex_state = 18, .external_lex_state = 2},
  [20482] = {.lex_state = 420, .external_lex_state = 2},
  [20483] = {.lex_state = 420, .external_lex_state = 2},
  [20484] = {.lex_state = 420, .external_lex_state = 2},
  [20485] = {.lex_state = 18, .external_lex_state = 2},
  [20486] = {.lex_state = 18, .external_lex_state = 2},
  [20487] = {.lex_state = 18, .external_lex_state = 2},
  [20488] = {.lex_state = 420, .external_lex_state = 2},
  [20489] = {.lex_state = 12, .external_lex_state = 2},
  [20490] = {.lex_state = 12, .external_lex_state = 2},
  [20491] = {.lex_state = 12, .external_lex_state = 2},
  [20492] = {.lex_state = 12, .external_lex_state = 2},
  [20493] = {.lex_state = 18, .external_lex_state = 2},
  [20494] = {.lex_state = 420, .external_lex_state = 2},
  [20495] = {.lex_state = 18, .external_lex_state = 2},
  [20496] = {.lex_state = 420, .external_lex_state = 2},
  [20497] = {.lex_state = 420, .external_lex_state = 2},
  [20498] = {.lex_state = 420, .external_lex_state = 2},
  [20499] = {.lex_state = 12, .external_lex_state = 2},
  [20500] = {.lex_state = 24, .external_lex_state = 2},
  [20501] = {.lex_state = 12, .external_lex_state = 2},
  [20502] = {.lex_state = 18, .external_lex_state = 2},
  [20503] = {.lex_state = 12, .external_lex_state = 2},
  [20504] = {(TSStateId)(-1)},
  [20505] = {(TSStateId)(-1)},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [sym_attribute] = STATE(0),
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym__lowercase_identifier] = ACTIONS(1),
    [sym_shebang] = ACTIONS(1),
    [anon_sym_SEMI_SEMI] = ACTIONS(1),
    [anon_sym_let] = ACTIONS(1),
    [anon_sym_rec] = ACTIONS(1),
    [anon_sym_and] = ACTIONS(1),
    [anon_sym_COLON_GT] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_external] = ACTIONS(1),
    [anon_sym_type] = ACTIONS(1),
    [anon_sym_nonrec] = ACTIONS(1),
    [anon_sym_private] = ACTIONS(1),
    [anon_sym_DOT_DOT] = ACTIONS(1),
    [anon_sym_PLUS_EQ] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym__] = ACTIONS(1),
    [anon_sym_COLON_EQ] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_true] = ACTIONS(1),
    [anon_sym_false] = ACTIONS(1),
    [anon_sym_of] = ACTIONS(1),
    [anon_sym_COLON2] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_DASH_GT] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_mutable] = ACTIONS(1),
    [anon_sym_constraint] = ACTIONS(1),
    [anon_sym_exception] = ACTIONS(1),
    [anon_sym_module] = ACTIONS(1),
    [anon_sym_open] = ACTIONS(1),
    [anon_sym_include] = ACTIONS(1),
    [anon_sym_class] = ACTIONS(1),
    [anon_sym_virtual] = ACTIONS(1),
    [anon_sym_val] = ACTIONS(1),
    [anon_sym_sig] = ACTIONS(1),
    [anon_sym_end] = ACTIONS(1),
    [anon_sym_with] = ACTIONS(1),
    [anon_sym_functor] = ACTIONS(1),
    [anon_sym_struct] = ACTIONS(1),
    [anon_sym_object] = ACTIONS(1),
    [anon_sym_method] = ACTIONS(1),
    [anon_sym_in] = ACTIONS(1),
    [anon_sym_fun] = ACTIONS(1),
    [anon_sym_as] = ACTIONS(1),
    [anon_sym_LBRACK_GT] = ACTIONS(1),
    [anon_sym_LBRACK_LT] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_POUND] = ACTIONS(1),
    [anon_sym_COLON_COLON] = ACTIONS(1),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1),
    [anon_sym_PIPE_RBRACK] = ACTIONS(1),
    [anon_sym_LT_DASH] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_then] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_do] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_to] = ACTIONS(1),
    [anon_sym_match] = ACTIONS(1),
    [anon_sym_when] = ACTIONS(1),
    [anon_sym_function] = ACTIONS(1),
    [anon_sym_try] = ACTIONS(1),
    [anon_sym_assert] = ACTIONS(1),
    [anon_sym_lazy] = ACTIONS(1),
    [anon_sym_new] = ACTIONS(1),
    [anon_sym_LBRACE_LT] = ACTIONS(1),
    [anon_sym_begin] = ACTIONS(1),
    [sym_ocamlyacc_value] = ACTIONS(1),
    [anon_sym_effect] = ACTIONS(1),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(1),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [aux_sym_number_token1] = ACTIONS(1),
    [aux_sym_signed_number_token1] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [anon_sym_SQUOTE2] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [aux_sym_string_content_token2] = ACTIONS(1),
    [aux_sym_string_content_token4] = ACTIONS(1),
    [aux_sym_string_content_token5] = ACTIONS(1),
    [aux_sym_escape_sequence_token1] = ACTIONS(1),
    [aux_sym_escape_sequence_token2] = ACTIONS(1),
    [aux_sym_escape_sequence_token3] = ACTIONS(1),
    [aux_sym_escape_sequence_token4] = ACTIONS(1),
    [sym_pretty_printing_indication] = ACTIONS(1),
    [aux_sym_sign_operator_token1] = ACTIONS(1),
    [sym_hash_operator] = ACTIONS(1),
    [sym_concat_operator] = ACTIONS(1),
    [sym_and_operator] = ACTIONS(1),
    [sym_or_operator] = ACTIONS(1),
    [sym_assign_operator] = ACTIONS(1),
    [sym_let_operator] = ACTIONS(1),
    [sym_let_and_operator] = ACTIONS(1),
    [sym_match_operator] = ACTIONS(1),
    [sym__uppercase_identifier] = ACTIONS(1),
    [aux_sym_directive_token1] = ACTIONS(1),
    [aux_sym_type_variable_token1] = ACTIONS(1),
    [aux_sym_tag_token1] = ACTIONS(1),
    [aux_sym_attribute_id_token1] = ACTIONS(1),
    [sym_comment] = ACTIONS(5),
    [sym__left_quoted_string_delimiter] = ACTIONS(1),
    [sym__right_quoted_string_delimiter] = ACTIONS(1),
    [sym_line_number_directive] = ACTIONS(5),
    [sym__null] = ACTIONS(1),
  },
  [1] = {
    [sym_compilation_unit] = STATE(20483),
    [sym__signature] = STATE(20426),
    [sym_external] = STATE(12649),
    [sym_type_definition] = STATE(12649),
    [sym_exception_definition] = STATE(12649),
    [sym_module_definition] = STATE(12649),
    [sym_module_type_definition] = STATE(12649),
    [sym_open_module] = STATE(12649),
    [sym_class_definition] = STATE(12649),
    [sym_class_type_definition] = STATE(12649),
    [sym__signature_item] = STATE(12650),
    [sym_value_specification] = STATE(12649),
    [sym_include_module_type] = STATE(12649),
    [sym_attribute] = STATE(1),
    [sym_floating_attribute] = STATE(12649),
    [sym_item_extension] = STATE(12649),
    [sym_quoted_item_extension] = STATE(12649),
    [aux_sym__structure_repeat1] = STATE(8993),
    [aux_sym__signature_repeat1] = STATE(8957),
    [ts_builtin_sym_end] = ACTIONS(7),
    [anon_sym_SEMI_SEMI] = ACTIONS(9),
    [anon_sym_external] = ACTIONS(11),
    [anon_sym_type] = ACTIONS(13),
    [anon_sym_exception] = ACTIONS(15),
    [anon_sym_module] = ACTIONS(17),
    [anon_sym_open] = ACTIONS(19),
    [anon_sym_include] = ACTIONS(21),
    [anon_sym_class] = ACTIONS(23),
    [anon_sym_val] = ACTIONS(25),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(2),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19690),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(3),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19629),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [4] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(4),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(17764),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(125),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [5] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(5),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19588),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(127),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [6] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(6),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(18323),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(129),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [7] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(7),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(18186),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(131),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [8] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(8),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19527),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(133),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [9] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(9),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19390),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(135),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [10] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(10),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19021),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(137),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [11] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(11),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19234),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(139),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [12] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(12),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(18166),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(141),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [13] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(13),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19092),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(143),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [14] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(14),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19451),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(145),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [15] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(15),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19936),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(147),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [16] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(16),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(18690),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(149),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [17] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(17),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19568),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(151),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [18] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(18),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19825),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(153),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [19] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(19),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19400),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(155),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [20] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(20),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(18255),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(157),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [21] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(21),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20310),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [22] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(22),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20452),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(161),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [23] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(23),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(17826),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [24] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(24),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20069),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(165),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [25] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(25),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19749),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(167),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [26] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(26),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19817),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(169),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [27] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(27),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(18092),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(171),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [28] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(28),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(17700),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(173),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [29] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(29),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(17891),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(175),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [30] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(30),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19864),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(177),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [31] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(31),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19740),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(179),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [32] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(32),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19908),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(181),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [33] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(33),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(18604),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(183),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [34] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(34),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20071),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(185),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [35] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(35),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(18739),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(187),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [36] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(36),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19957),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(189),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [37] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(37),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19955),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(191),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [38] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(38),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19465),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(193),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [39] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(39),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19155),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(195),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [40] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(40),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19996),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(197),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [41] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(41),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(18780),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(199),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [42] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(42),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19306),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(201),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [43] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(43),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(17644),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(203),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [44] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(44),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19291),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(205),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [45] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(45),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20039),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(207),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [46] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(46),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20075),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(209),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [47] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(47),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20084),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(211),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [48] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(48),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20101),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(213),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [49] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(49),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20403),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(215),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [50] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(50),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20129),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(217),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [51] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(51),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(18520),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(219),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [52] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(52),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20135),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(221),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [53] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(53),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20145),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(223),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [54] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(54),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(18456),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(225),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [55] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(55),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20154),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(227),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [56] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(56),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20194),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(229),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [57] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(57),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20168),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(231),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [58] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(58),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(17602),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(233),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [59] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(59),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(18051),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(235),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [60] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(60),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(18878),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(237),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [61] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(61),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19165),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(239),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [62] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(62),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(18460),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(241),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [63] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(63),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20208),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(243),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [64] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(64),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(17952),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [65] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(65),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(18018),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(247),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [66] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(66),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20125),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(249),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [67] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(67),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20235),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(251),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [68] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(68),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20239),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(253),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [69] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(69),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(18431),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(255),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [70] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(70),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(17921),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(257),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [71] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(71),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20244),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(259),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [72] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(72),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20250),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(261),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [73] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(73),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20415),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(263),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [74] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(74),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(19381),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(265),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [75] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(75),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20263),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(267),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [76] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(76),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20278),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(269),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [77] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(77),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20284),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(271),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [78] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(78),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20288),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(273),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [79] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(79),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20307),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(275),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [80] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(80),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20316),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(277),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [81] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(81),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20380),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(279),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [82] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(82),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(18341),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(281),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [83] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(83),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20454),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(283),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [84] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(84),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(18876),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(285),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [85] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(85),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(18984),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [86] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(86),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20455),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(289),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [87] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(87),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(20091),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(291),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [88] = {
    [sym__structure] = STATE(20484),
    [sym_expression_item] = STATE(8386),
    [sym_toplevel_directive] = STATE(8386),
    [sym__structure_item] = STATE(8386),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(88),
    [sym_floating_attribute] = STATE(12427),
    [sym_attribute_payload] = STATE(17769),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_QMARK] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(293),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_COLON2] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [89] = {
    [sym_value_definition] = STATE(18030),
    [sym__simple_expression] = STATE(301),
    [sym__expression] = STATE(8264),
    [sym__sequence_expression] = STATE(7547),
    [sym_typed_expression] = STATE(3052),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3052),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3052),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2963),
    [sym_array_get_expression] = STATE(2963),
    [sym_string_get_expression] = STATE(2963),
    [sym_bigarray_get_expression] = STATE(2963),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3052),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(89),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__attribute] = STATE(1134),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym_sign_operator] = STATE(1958),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__instance_variable_name] = STATE(18008),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [sym__lowercase_identifier] = ACTIONS(295),
    [anon_sym_SEMI_SEMI] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(299),
    [anon_sym_and] = ACTIONS(301),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_external] = ACTIONS(301),
    [anon_sym_type] = ACTIONS(301),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_SEMI] = ACTIONS(301),
    [anon_sym_exception] = ACTIONS(301),
    [anon_sym_module] = ACTIONS(301),
    [anon_sym_open] = ACTIONS(301),
    [anon_sym_include] = ACTIONS(301),
    [anon_sym_class] = ACTIONS(301),
    [anon_sym_end] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_in] = ACTIONS(301),
    [anon_sym_fun] = ACTIONS(313),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_if] = ACTIONS(317),
    [anon_sym_else] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(319),
    [anon_sym_function] = ACTIONS(321),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(301),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(335),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_let_and_operator] = ACTIONS(297),
    [sym_match_operator] = ACTIONS(349),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_directive_token1] = ACTIONS(297),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [90] = {
    [sym_value_definition] = STATE(17611),
    [sym__simple_expression] = STATE(323),
    [sym__expression] = STATE(8239),
    [sym__sequence_expression] = STATE(7547),
    [sym_typed_expression] = STATE(3176),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3176),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3176),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2957),
    [sym_array_get_expression] = STATE(2957),
    [sym_string_get_expression] = STATE(2957),
    [sym_bigarray_get_expression] = STATE(2957),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3176),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(90),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__attribute] = STATE(1003),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym_sign_operator] = STATE(1905),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__instance_variable_name] = STATE(17621),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [sym__lowercase_identifier] = ACTIONS(355),
    [anon_sym_SEMI_SEMI] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(357),
    [anon_sym_and] = ACTIONS(301),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_external] = ACTIONS(301),
    [anon_sym_type] = ACTIONS(301),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_RBRACK] = ACTIONS(297),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_SEMI] = ACTIONS(301),
    [anon_sym_exception] = ACTIONS(301),
    [anon_sym_module] = ACTIONS(301),
    [anon_sym_open] = ACTIONS(301),
    [anon_sym_include] = ACTIONS(301),
    [anon_sym_class] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_in] = ACTIONS(301),
    [anon_sym_fun] = ACTIONS(369),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_if] = ACTIONS(373),
    [anon_sym_else] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(375),
    [anon_sym_function] = ACTIONS(377),
    [anon_sym_try] = ACTIONS(379),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(301),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(389),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(391),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_let_and_operator] = ACTIONS(297),
    [sym_match_operator] = ACTIONS(401),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_directive_token1] = ACTIONS(297),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [91] = {
    [sym__structure] = STATE(20467),
    [sym_expression_item] = STATE(8408),
    [sym_toplevel_directive] = STATE(8408),
    [sym__structure_item] = STATE(8408),
    [sym_value_definition] = STATE(12570),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8877),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(91),
    [sym_floating_attribute] = STATE(12427),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_directive] = STATE(7860),
    [sym_tag] = STATE(4413),
    [aux_sym__structure_repeat1] = STATE(101),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_SEMI_SEMI] = ACTIONS(409),
    [anon_sym_let] = ACTIONS(411),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(415),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_exception] = ACTIONS(423),
    [anon_sym_module] = ACTIONS(425),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(427),
    [anon_sym_end] = ACTIONS(429),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(453),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(455),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(465),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_directive_token1] = ACTIONS(471),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [92] = {
    [sym_value_definition] = STATE(19080),
    [sym__simple_expression] = STATE(506),
    [sym__expression] = STATE(8293),
    [sym__sequence_expression] = STATE(5390),
    [sym_typed_expression] = STATE(3532),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3532),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3532),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3084),
    [sym_array_get_expression] = STATE(3084),
    [sym_string_get_expression] = STATE(3084),
    [sym_bigarray_get_expression] = STATE(3084),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3532),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(92),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__attribute] = STATE(1230),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym_sign_operator] = STATE(2274),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__instance_variable_name] = STATE(18842),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [sym__lowercase_identifier] = ACTIONS(475),
    [anon_sym_SEMI_SEMI] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(477),
    [anon_sym_and] = ACTIONS(301),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_external] = ACTIONS(301),
    [anon_sym_type] = ACTIONS(301),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_RBRACK] = ACTIONS(297),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_SEMI] = ACTIONS(301),
    [anon_sym_exception] = ACTIONS(301),
    [anon_sym_module] = ACTIONS(301),
    [anon_sym_open] = ACTIONS(301),
    [anon_sym_include] = ACTIONS(301),
    [anon_sym_class] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_fun] = ACTIONS(489),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_else] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(495),
    [anon_sym_function] = ACTIONS(497),
    [anon_sym_try] = ACTIONS(499),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(301),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(509),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(511),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_let_and_operator] = ACTIONS(297),
    [sym_match_operator] = ACTIONS(521),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_directive_token1] = ACTIONS(297),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [93] = {
    [sym_value_definition] = STATE(19151),
    [sym__simple_expression] = STATE(549),
    [sym__expression] = STATE(8333),
    [sym__sequence_expression] = STATE(5390),
    [sym_typed_expression] = STATE(3704),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3704),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3704),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3058),
    [sym_array_get_expression] = STATE(3058),
    [sym_string_get_expression] = STATE(3058),
    [sym_bigarray_get_expression] = STATE(3058),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3704),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(93),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__attribute] = STATE(1288),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym_sign_operator] = STATE(1807),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__instance_variable_name] = STATE(19067),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [sym__lowercase_identifier] = ACTIONS(527),
    [anon_sym_SEMI_SEMI] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(529),
    [anon_sym_and] = ACTIONS(301),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_external] = ACTIONS(301),
    [anon_sym_type] = ACTIONS(301),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_SEMI] = ACTIONS(301),
    [anon_sym_exception] = ACTIONS(301),
    [anon_sym_module] = ACTIONS(301),
    [anon_sym_open] = ACTIONS(301),
    [anon_sym_include] = ACTIONS(301),
    [anon_sym_class] = ACTIONS(301),
    [anon_sym_end] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_fun] = ACTIONS(541),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(545),
    [anon_sym_else] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(547),
    [anon_sym_function] = ACTIONS(549),
    [anon_sym_try] = ACTIONS(551),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(301),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(561),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(563),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_let_and_operator] = ACTIONS(297),
    [sym_match_operator] = ACTIONS(573),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_directive_token1] = ACTIONS(297),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [94] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8306),
    [sym__sequence_expression] = STATE(7547),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(94),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__attribute] = STATE(1363),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_SEMI_SEMI] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_and] = ACTIONS(301),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_external] = ACTIONS(301),
    [anon_sym_type] = ACTIONS(301),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_RBRACK] = ACTIONS(297),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_SEMI] = ACTIONS(301),
    [anon_sym_exception] = ACTIONS(301),
    [anon_sym_module] = ACTIONS(301),
    [anon_sym_open] = ACTIONS(301),
    [anon_sym_include] = ACTIONS(301),
    [anon_sym_class] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_in] = ACTIONS(301),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(301),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(613),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(615),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_let_and_operator] = ACTIONS(297),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_directive_token1] = ACTIONS(297),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [95] = {
    [sym__structure] = STATE(20127),
    [sym_expression_item] = STATE(8408),
    [sym_toplevel_directive] = STATE(8408),
    [sym__structure_item] = STATE(8408),
    [sym_value_definition] = STATE(12570),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8877),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(95),
    [sym_floating_attribute] = STATE(12427),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_directive] = STATE(7860),
    [sym_tag] = STATE(4413),
    [aux_sym__structure_repeat1] = STATE(101),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_SEMI_SEMI] = ACTIONS(409),
    [anon_sym_let] = ACTIONS(411),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(415),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_exception] = ACTIONS(423),
    [anon_sym_module] = ACTIONS(425),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(427),
    [anon_sym_end] = ACTIONS(631),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(453),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(455),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(465),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_directive_token1] = ACTIONS(471),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [96] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8299),
    [sym__sequence_expression] = STATE(7547),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(96),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__attribute] = STATE(1282),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_SEMI_SEMI] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_and] = ACTIONS(301),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_external] = ACTIONS(301),
    [anon_sym_type] = ACTIONS(301),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_SEMI] = ACTIONS(301),
    [anon_sym_exception] = ACTIONS(301),
    [anon_sym_module] = ACTIONS(301),
    [anon_sym_open] = ACTIONS(301),
    [anon_sym_include] = ACTIONS(301),
    [anon_sym_class] = ACTIONS(301),
    [anon_sym_end] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_in] = ACTIONS(301),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(301),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(667),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(669),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_let_and_operator] = ACTIONS(297),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_directive_token1] = ACTIONS(297),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [97] = {
    [sym_expression_item] = STATE(12532),
    [sym_toplevel_directive] = STATE(12532),
    [sym__structure_item] = STATE(12532),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(97),
    [sym_floating_attribute] = STATE(12427),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(5085),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(685),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [98] = {
    [sym_expression_item] = STATE(12532),
    [sym_toplevel_directive] = STATE(12532),
    [sym__structure_item] = STATE(12532),
    [sym_value_definition] = STATE(12570),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8877),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(98),
    [sym_floating_attribute] = STATE(12427),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_directive] = STATE(7860),
    [sym_tag] = STATE(4413),
    [aux_sym__structure_repeat1] = STATE(5050),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_SEMI_SEMI] = ACTIONS(409),
    [anon_sym_let] = ACTIONS(411),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(415),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_exception] = ACTIONS(423),
    [anon_sym_module] = ACTIONS(425),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(427),
    [anon_sym_end] = ACTIONS(687),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(453),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(455),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(465),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_directive_token1] = ACTIONS(471),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [99] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8389),
    [sym__sequence_expression] = STATE(5390),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(99),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__attribute] = STATE(654),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_SEMI_SEMI] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_and] = ACTIONS(301),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_external] = ACTIONS(301),
    [anon_sym_type] = ACTIONS(301),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_RBRACK] = ACTIONS(297),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_SEMI] = ACTIONS(301),
    [anon_sym_exception] = ACTIONS(301),
    [anon_sym_module] = ACTIONS(301),
    [anon_sym_open] = ACTIONS(301),
    [anon_sym_include] = ACTIONS(301),
    [anon_sym_class] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(301),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(723),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(725),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_let_and_operator] = ACTIONS(297),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_directive_token1] = ACTIONS(297),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [100] = {
    [sym_expression_item] = STATE(12532),
    [sym_toplevel_directive] = STATE(12532),
    [sym__structure_item] = STATE(12532),
    [sym_value_definition] = STATE(12570),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8877),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(100),
    [sym_floating_attribute] = STATE(12427),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_directive] = STATE(7860),
    [sym_tag] = STATE(4413),
    [aux_sym__structure_repeat1] = STATE(5050),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_SEMI_SEMI] = ACTIONS(409),
    [anon_sym_let] = ACTIONS(411),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(415),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_exception] = ACTIONS(423),
    [anon_sym_module] = ACTIONS(425),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(427),
    [anon_sym_end] = ACTIONS(741),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(453),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(455),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(465),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_directive_token1] = ACTIONS(471),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [101] = {
    [sym_expression_item] = STATE(8379),
    [sym_toplevel_directive] = STATE(8379),
    [sym__structure_item] = STATE(8379),
    [sym_value_definition] = STATE(12570),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8877),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(101),
    [sym_floating_attribute] = STATE(12427),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_directive] = STATE(7860),
    [sym_tag] = STATE(4413),
    [aux_sym__structure_repeat1] = STATE(5050),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_SEMI_SEMI] = ACTIONS(409),
    [anon_sym_let] = ACTIONS(411),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(415),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_exception] = ACTIONS(423),
    [anon_sym_module] = ACTIONS(425),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(427),
    [anon_sym_end] = ACTIONS(743),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(453),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(455),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(465),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_directive_token1] = ACTIONS(471),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [102] = {
    [sym_expression_item] = STATE(12532),
    [sym_toplevel_directive] = STATE(12532),
    [sym__structure_item] = STATE(12532),
    [sym_value_definition] = STATE(12570),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8877),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(102),
    [sym_floating_attribute] = STATE(12427),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_directive] = STATE(7860),
    [sym_tag] = STATE(4413),
    [aux_sym__structure_repeat1] = STATE(5050),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_SEMI_SEMI] = ACTIONS(409),
    [anon_sym_let] = ACTIONS(411),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(415),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_exception] = ACTIONS(423),
    [anon_sym_module] = ACTIONS(425),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(427),
    [anon_sym_end] = ACTIONS(745),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(453),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(455),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(465),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_directive_token1] = ACTIONS(471),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [103] = {
    [sym_expression_item] = STATE(8382),
    [sym_toplevel_directive] = STATE(8382),
    [sym__structure_item] = STATE(8382),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(103),
    [sym_floating_attribute] = STATE(12427),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(5085),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(747),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [104] = {
    [sym_expression_item] = STATE(12532),
    [sym_toplevel_directive] = STATE(12532),
    [sym__structure_item] = STATE(12532),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(104),
    [sym_floating_attribute] = STATE(12427),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(5085),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(749),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [105] = {
    [sym_expression_item] = STATE(12532),
    [sym_toplevel_directive] = STATE(12532),
    [sym__structure_item] = STATE(12532),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(105),
    [sym_floating_attribute] = STATE(12427),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(5085),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(751),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [106] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8387),
    [sym__sequence_expression] = STATE(5390),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(106),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__attribute] = STATE(577),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_SEMI_SEMI] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_and] = ACTIONS(301),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_external] = ACTIONS(301),
    [anon_sym_type] = ACTIONS(301),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_SEMI] = ACTIONS(301),
    [anon_sym_exception] = ACTIONS(301),
    [anon_sym_module] = ACTIONS(301),
    [anon_sym_open] = ACTIONS(301),
    [anon_sym_include] = ACTIONS(301),
    [anon_sym_class] = ACTIONS(301),
    [anon_sym_end] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(301),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(787),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(789),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_let_and_operator] = ACTIONS(297),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_directive_token1] = ACTIONS(297),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [107] = {
    [sym_expression_item] = STATE(12532),
    [sym_toplevel_directive] = STATE(12532),
    [sym__structure_item] = STATE(12532),
    [sym_value_definition] = STATE(12429),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(107),
    [sym_floating_attribute] = STATE(12427),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_directive] = STATE(7923),
    [sym_tag] = STATE(4315),
    [aux_sym__structure_repeat1] = STATE(5085),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(57),
    [anon_sym_module] = ACTIONS(59),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(65),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(113),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [108] = {
    [sym_value_definition] = STATE(18797),
    [sym__simple_expression] = STATE(1527),
    [sym__expression] = STATE(8505),
    [sym__sequence_expression] = STATE(5390),
    [sym_typed_expression] = STATE(4161),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4161),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4161),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3909),
    [sym_array_get_expression] = STATE(3909),
    [sym_string_get_expression] = STATE(3909),
    [sym_bigarray_get_expression] = STATE(3909),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4161),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(108),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__attribute] = STATE(859),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym_sign_operator] = STATE(2091),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__instance_variable_name] = STATE(18811),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [sym__lowercase_identifier] = ACTIONS(805),
    [anon_sym_SEMI_SEMI] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_external] = ACTIONS(301),
    [anon_sym_type] = ACTIONS(301),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_SEMI] = ACTIONS(301),
    [anon_sym_exception] = ACTIONS(301),
    [anon_sym_module] = ACTIONS(301),
    [anon_sym_open] = ACTIONS(301),
    [anon_sym_include] = ACTIONS(301),
    [anon_sym_class] = ACTIONS(301),
    [anon_sym_end] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_fun] = ACTIONS(819),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_if] = ACTIONS(823),
    [anon_sym_else] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(825),
    [anon_sym_function] = ACTIONS(827),
    [anon_sym_try] = ACTIONS(829),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(301),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(839),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(841),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(851),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_directive_token1] = ACTIONS(297),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [109] = {
    [sym_value_definition] = STATE(19248),
    [sym__simple_expression] = STATE(1582),
    [sym__expression] = STATE(8468),
    [sym__sequence_expression] = STATE(5390),
    [sym_typed_expression] = STATE(4041),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4041),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4041),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3928),
    [sym_array_get_expression] = STATE(3928),
    [sym_string_get_expression] = STATE(3928),
    [sym_bigarray_get_expression] = STATE(3928),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4041),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(109),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__attribute] = STATE(1386),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__instance_variable_name] = STATE(19258),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [sym__lowercase_identifier] = ACTIONS(857),
    [anon_sym_SEMI_SEMI] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(859),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_external] = ACTIONS(301),
    [anon_sym_type] = ACTIONS(301),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_RBRACK] = ACTIONS(297),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_SEMI] = ACTIONS(301),
    [anon_sym_exception] = ACTIONS(301),
    [anon_sym_module] = ACTIONS(301),
    [anon_sym_open] = ACTIONS(301),
    [anon_sym_include] = ACTIONS(301),
    [anon_sym_class] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_fun] = ACTIONS(871),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_else] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(877),
    [anon_sym_function] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(881),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(301),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(891),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(893),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(903),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_directive_token1] = ACTIONS(297),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [110] = {
    [sym_expression_item] = STATE(12532),
    [sym_toplevel_directive] = STATE(12532),
    [sym__structure_item] = STATE(12532),
    [sym_value_definition] = STATE(12570),
    [sym_external] = STATE(12427),
    [sym_type_definition] = STATE(12427),
    [sym_exception_definition] = STATE(12427),
    [sym_module_definition] = STATE(12427),
    [sym_module_type_definition] = STATE(12427),
    [sym_open_module] = STATE(12427),
    [sym_include_module] = STATE(12427),
    [sym_class_definition] = STATE(12427),
    [sym_class_type_definition] = STATE(12427),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8877),
    [sym__sequence_expression] = STATE(11363),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(110),
    [sym_floating_attribute] = STATE(12427),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym_item_extension] = STATE(12427),
    [sym_quoted_item_extension] = STATE(12427),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_directive] = STATE(7860),
    [sym_tag] = STATE(4413),
    [aux_sym__structure_repeat1] = STATE(5085),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(411),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(415),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_exception] = ACTIONS(423),
    [anon_sym_module] = ACTIONS(425),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(63),
    [anon_sym_class] = ACTIONS(427),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(453),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(455),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(465),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_directive_token1] = ACTIONS(471),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [111] = {
    [sym_value_definition] = STATE(19480),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8574),
    [sym__sequence_expression] = STATE(5390),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(111),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__attribute] = STATE(1406),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_SEMI_SEMI] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_external] = ACTIONS(301),
    [anon_sym_type] = ACTIONS(301),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_SEMI] = ACTIONS(301),
    [anon_sym_exception] = ACTIONS(301),
    [anon_sym_module] = ACTIONS(301),
    [anon_sym_open] = ACTIONS(301),
    [anon_sym_include] = ACTIONS(301),
    [anon_sym_class] = ACTIONS(301),
    [anon_sym_end] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(301),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(453),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(455),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_directive_token1] = ACTIONS(297),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [112] = {
    [sym_value_definition] = STATE(19586),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8712),
    [sym__sequence_expression] = STATE(5390),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(112),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__attribute] = STATE(1109),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(301),
    [anon_sym_type] = ACTIONS(301),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(297),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(301),
    [anon_sym_exception] = ACTIONS(301),
    [anon_sym_module] = ACTIONS(301),
    [anon_sym_open] = ACTIONS(301),
    [anon_sym_include] = ACTIONS(301),
    [anon_sym_class] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(301),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(297),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [113] = {
    [sym_value_definition] = STATE(19239),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9434),
    [sym__sequence_expression] = STATE(8177),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4721),
    [sym_array_get_expression] = STATE(4721),
    [sym_string_get_expression] = STATE(4721),
    [sym_bigarray_get_expression] = STATE(4721),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(113),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__attribute] = STATE(1391),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(1935),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(19132),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_constraint] = ACTIONS(301),
    [anon_sym_val] = ACTIONS(301),
    [anon_sym_end] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_inherit] = ACTIONS(301),
    [anon_sym_method] = ACTIONS(301),
    [anon_sym_fun] = ACTIONS(927),
    [anon_sym_initializer] = ACTIONS(301),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(931),
    [anon_sym_else] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(937),
    [anon_sym_function] = ACTIONS(939),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(301),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(955),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(957),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(967),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [114] = {
    [sym_value_definition] = STATE(17714),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9726),
    [sym__sequence_expression] = STATE(8177),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4836),
    [sym_array_get_expression] = STATE(4836),
    [sym_string_get_expression] = STATE(4836),
    [sym_bigarray_get_expression] = STATE(4836),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(114),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__attribute] = STATE(716),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(2151),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(17727),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(973),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_constraint] = ACTIONS(301),
    [anon_sym_val] = ACTIONS(301),
    [anon_sym_end] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_inherit] = ACTIONS(301),
    [anon_sym_method] = ACTIONS(301),
    [anon_sym_fun] = ACTIONS(975),
    [anon_sym_initializer] = ACTIONS(301),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_else] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(983),
    [anon_sym_function] = ACTIONS(985),
    [anon_sym_try] = ACTIONS(987),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(301),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(955),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(957),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(993),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [115] = {
    [sym_value_definition] = STATE(17654),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9605),
    [sym__sequence_expression] = STATE(8177),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4841),
    [sym_array_get_expression] = STATE(4841),
    [sym_string_get_expression] = STATE(4841),
    [sym_bigarray_get_expression] = STATE(4841),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(115),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__attribute] = STATE(681),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2276),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(17662),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(997),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_constraint] = ACTIONS(301),
    [anon_sym_val] = ACTIONS(301),
    [anon_sym_end] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_inherit] = ACTIONS(301),
    [anon_sym_method] = ACTIONS(301),
    [anon_sym_fun] = ACTIONS(1009),
    [anon_sym_initializer] = ACTIONS(301),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1013),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1015),
    [anon_sym_function] = ACTIONS(1017),
    [anon_sym_try] = ACTIONS(1019),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(301),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1029),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1031),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1041),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [116] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10042),
    [sym__sequence_expression] = STATE(8177),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(116),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__attribute] = STATE(775),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_constraint] = ACTIONS(301),
    [anon_sym_val] = ACTIONS(301),
    [anon_sym_end] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_inherit] = ACTIONS(301),
    [anon_sym_method] = ACTIONS(301),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_initializer] = ACTIONS(301),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(301),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1029),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1031),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [117] = {
    [sym_value_definition] = STATE(18428),
    [sym__simple_expression] = STATE(2428),
    [sym__expression] = STATE(10224),
    [sym__sequence_expression] = STATE(8177),
    [sym_typed_expression] = STATE(5216),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5216),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5216),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4994),
    [sym_array_get_expression] = STATE(4994),
    [sym_string_get_expression] = STATE(4994),
    [sym_bigarray_get_expression] = STATE(4994),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5216),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(117),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__attribute] = STATE(623),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym_sign_operator] = STATE(2366),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__instance_variable_name] = STATE(18272),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [sym__lowercase_identifier] = ACTIONS(1061),
    [anon_sym_let] = ACTIONS(1063),
    [anon_sym_COLON_GT] = ACTIONS(297),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_RPAREN] = ACTIONS(297),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_RBRACK] = ACTIONS(297),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_COLON2] = ACTIONS(301),
    [anon_sym_DASH_GT] = ACTIONS(301),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_RBRACE] = ACTIONS(297),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_fun] = ACTIONS(1075),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_if] = ACTIONS(1079),
    [anon_sym_else] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1081),
    [anon_sym_function] = ACTIONS(1083),
    [anon_sym_try] = ACTIONS(1085),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_GT_RBRACE] = ACTIONS(297),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1109),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [118] = {
    [sym_value_definition] = STATE(18620),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(10491),
    [sym__sequence_expression] = STATE(8851),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5197),
    [sym_array_get_expression] = STATE(5197),
    [sym_string_get_expression] = STATE(5197),
    [sym_bigarray_get_expression] = STATE(5197),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(118),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__attribute] = STATE(1225),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(2020),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(18637),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(1117),
    [anon_sym_COLON_GT] = ACTIONS(297),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_RPAREN] = ACTIONS(297),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_RBRACK] = ACTIONS(297),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_COLON2] = ACTIONS(301),
    [anon_sym_DASH_GT] = ACTIONS(301),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_RBRACE] = ACTIONS(297),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(1129),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(1133),
    [anon_sym_else] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1135),
    [anon_sym_function] = ACTIONS(1137),
    [anon_sym_try] = ACTIONS(1139),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_GT_RBRACE] = ACTIONS(297),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1165),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [119] = {
    [sym_value_definition] = STATE(18535),
    [sym__simple_expression] = STATE(2430),
    [sym__expression] = STATE(10576),
    [sym__sequence_expression] = STATE(8177),
    [sym_typed_expression] = STATE(5411),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5411),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5411),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(5160),
    [sym_array_get_expression] = STATE(5160),
    [sym_string_get_expression] = STATE(5160),
    [sym_bigarray_get_expression] = STATE(5160),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5411),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(119),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__attribute] = STATE(854),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym_sign_operator] = STATE(1986),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__instance_variable_name] = STATE(18550),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [sym__lowercase_identifier] = ACTIONS(1171),
    [anon_sym_let] = ACTIONS(1173),
    [anon_sym_COLON_GT] = ACTIONS(297),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_RPAREN] = ACTIONS(297),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(1177),
    [anon_sym_RBRACK] = ACTIONS(297),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_COLON2] = ACTIONS(301),
    [anon_sym_DASH_GT] = ACTIONS(301),
    [anon_sym_LBRACE] = ACTIONS(1181),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_RBRACE] = ACTIONS(297),
    [anon_sym_object] = ACTIONS(1183),
    [anon_sym_fun] = ACTIONS(1185),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1187),
    [anon_sym_if] = ACTIONS(1189),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1191),
    [anon_sym_function] = ACTIONS(1193),
    [anon_sym_try] = ACTIONS(1195),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1197),
    [anon_sym_LBRACE_LT] = ACTIONS(1199),
    [anon_sym_GT_RBRACE] = ACTIONS(297),
    [anon_sym_begin] = ACTIONS(1201),
    [sym_ocamlyacc_value] = ACTIONS(1203),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1205),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1207),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(1209),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_prefix_operator] = ACTIONS(1215),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1217),
    [sym__uppercase_identifier] = ACTIONS(1219),
    [aux_sym_tag_token1] = ACTIONS(1221),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [120] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(10965),
    [sym__sequence_expression] = STATE(8851),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(120),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__attribute] = STATE(990),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_COLON_GT] = ACTIONS(297),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(297),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(297),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_COLON2] = ACTIONS(301),
    [anon_sym_DASH_GT] = ACTIONS(301),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_RBRACE] = ACTIONS(297),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_GT_RBRACE] = ACTIONS(297),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [121] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8383),
    [sym__sequence_expression] = STATE(7547),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(121),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__attribute] = STATE(1345),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_SEMI_SEMI] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_and] = ACTIONS(301),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_external] = ACTIONS(301),
    [anon_sym_type] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_exception] = ACTIONS(301),
    [anon_sym_module] = ACTIONS(301),
    [anon_sym_open] = ACTIONS(301),
    [anon_sym_include] = ACTIONS(301),
    [anon_sym_class] = ACTIONS(301),
    [anon_sym_end] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_in] = ACTIONS(301),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(301),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(667),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(669),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_let_and_operator] = ACTIONS(297),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_directive_token1] = ACTIONS(297),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [122] = {
    [sym_value_definition] = STATE(19385),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11179),
    [sym__sequence_expression] = STATE(10648),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5503),
    [sym_array_get_expression] = STATE(5503),
    [sym_string_get_expression] = STATE(5503),
    [sym_bigarray_get_expression] = STATE(5503),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(122),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__attribute] = STATE(1176),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(1823),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(20481),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1279),
    [anon_sym_and] = ACTIONS(301),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_in] = ACTIONS(301),
    [anon_sym_fun] = ACTIONS(1291),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1295),
    [anon_sym_else] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_let_and_operator] = ACTIONS(297),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [123] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8410),
    [sym__sequence_expression] = STATE(7547),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(123),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__attribute] = STATE(1099),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_SEMI_SEMI] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_and] = ACTIONS(301),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_external] = ACTIONS(301),
    [anon_sym_type] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_RBRACK] = ACTIONS(297),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_exception] = ACTIONS(301),
    [anon_sym_module] = ACTIONS(301),
    [anon_sym_open] = ACTIONS(301),
    [anon_sym_include] = ACTIONS(301),
    [anon_sym_class] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_in] = ACTIONS(301),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(301),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(613),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(615),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_let_and_operator] = ACTIONS(297),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_directive_token1] = ACTIONS(297),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [124] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8452),
    [sym__sequence_expression] = STATE(5390),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(124),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__attribute] = STATE(684),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_SEMI_SEMI] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_and] = ACTIONS(301),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_external] = ACTIONS(301),
    [anon_sym_type] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_exception] = ACTIONS(301),
    [anon_sym_module] = ACTIONS(301),
    [anon_sym_open] = ACTIONS(301),
    [anon_sym_include] = ACTIONS(301),
    [anon_sym_class] = ACTIONS(301),
    [anon_sym_end] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(301),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(787),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(789),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_let_and_operator] = ACTIONS(297),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_directive_token1] = ACTIONS(297),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [125] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8534),
    [sym__sequence_expression] = STATE(5390),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(125),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__attribute] = STATE(751),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_SEMI_SEMI] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_and] = ACTIONS(301),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_external] = ACTIONS(301),
    [anon_sym_type] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_RBRACK] = ACTIONS(297),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_exception] = ACTIONS(301),
    [anon_sym_module] = ACTIONS(301),
    [anon_sym_open] = ACTIONS(301),
    [anon_sym_include] = ACTIONS(301),
    [anon_sym_class] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(301),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(723),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(725),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_let_and_operator] = ACTIONS(297),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_directive_token1] = ACTIONS(297),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [126] = {
    [sym_value_definition] = STATE(18295),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11460),
    [sym__sequence_expression] = STATE(10648),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5598),
    [sym_array_get_expression] = STATE(5598),
    [sym_string_get_expression] = STATE(5598),
    [sym_bigarray_get_expression] = STATE(5598),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(126),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__attribute] = STATE(873),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(1999),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(20495),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_and] = ACTIONS(301),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_in] = ACTIONS(301),
    [anon_sym_fun] = ACTIONS(1351),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1355),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_let_and_operator] = ACTIONS(297),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [127] = {
    [sym_value_definition] = STATE(18149),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11677),
    [sym__sequence_expression] = STATE(8851),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5662),
    [sym_array_get_expression] = STATE(5662),
    [sym_string_get_expression] = STATE(5662),
    [sym_bigarray_get_expression] = STATE(5662),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(127),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__attribute] = STATE(1229),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(2277),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(18127),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1389),
    [anon_sym_and] = ACTIONS(301),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_in] = ACTIONS(301),
    [anon_sym_fun] = ACTIONS(1391),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1393),
    [anon_sym_else] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_let_and_operator] = ACTIONS(297),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [128] = {
    [sym_value_definition] = STATE(17889),
    [sym__simple_expression] = STATE(2457),
    [sym__expression] = STATE(11791),
    [sym__sequence_expression] = STATE(10648),
    [sym_typed_expression] = STATE(6138),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6138),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6138),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5776),
    [sym_array_get_expression] = STATE(5776),
    [sym_string_get_expression] = STATE(5776),
    [sym_bigarray_get_expression] = STATE(5776),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6138),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(128),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__attribute] = STATE(1279),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym_sign_operator] = STATE(1969),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__instance_variable_name] = STATE(17866),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [sym__lowercase_identifier] = ACTIONS(1395),
    [anon_sym_let] = ACTIONS(1397),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_fun] = ACTIONS(1409),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_else] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_to] = ACTIONS(301),
    [anon_sym_downto] = ACTIONS(301),
    [anon_sym_match] = ACTIONS(1415),
    [anon_sym_function] = ACTIONS(1417),
    [anon_sym_try] = ACTIONS(1419),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1441),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [129] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11900),
    [sym__sequence_expression] = STATE(8851),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(129),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__attribute] = STATE(579),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_and] = ACTIONS(301),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_in] = ACTIONS(301),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_let_and_operator] = ACTIONS(297),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [130] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(15025),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(130),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19771),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1453),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1455),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1457),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1459),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1463),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1465),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1473),
    [sym_let_and_operator] = ACTIONS(1465),
    [sym_match_operator] = ACTIONS(1475),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [131] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18847),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(131),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(17850),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1477),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1481),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1483),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1485),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1487),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1489),
    [sym_let_and_operator] = ACTIONS(1487),
    [sym_match_operator] = ACTIONS(1491),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [132] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14920),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(132),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(18974),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1493),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1495),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1497),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1499),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1501),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1503),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1505),
    [sym_let_and_operator] = ACTIONS(1503),
    [sym_match_operator] = ACTIONS(1507),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [133] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19282),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(133),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(18548),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1509),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1511),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1513),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1515),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1517),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1519),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1521),
    [sym_let_and_operator] = ACTIONS(1519),
    [sym_match_operator] = ACTIONS(1523),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [134] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14759),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(134),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(20130),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1525),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1527),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1529),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1531),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1533),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1535),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1537),
    [sym_let_and_operator] = ACTIONS(1535),
    [sym_match_operator] = ACTIONS(1539),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [135] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(11902),
    [sym__sequence_expression] = STATE(10648),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(135),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__attribute] = STATE(1133),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_to] = ACTIONS(301),
    [anon_sym_downto] = ACTIONS(301),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [136] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14725),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(136),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(18136),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1593),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1595),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1597),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1599),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1601),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1603),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1605),
    [sym_let_and_operator] = ACTIONS(1603),
    [sym_match_operator] = ACTIONS(1607),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [137] = {
    [sym_value_definition] = STATE(19480),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8877),
    [sym__sequence_expression] = STATE(5390),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(137),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__attribute] = STATE(808),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_SEMI_SEMI] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_external] = ACTIONS(301),
    [anon_sym_type] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_exception] = ACTIONS(301),
    [anon_sym_module] = ACTIONS(301),
    [anon_sym_open] = ACTIONS(301),
    [anon_sym_include] = ACTIONS(301),
    [anon_sym_class] = ACTIONS(301),
    [anon_sym_end] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(301),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(453),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(455),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_directive_token1] = ACTIONS(297),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [138] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19539),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(138),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19329),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1609),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1613),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1615),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1617),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1619),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1621),
    [sym_let_and_operator] = ACTIONS(1619),
    [sym_match_operator] = ACTIONS(1623),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [139] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(20046),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(139),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19986),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1625),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1627),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1629),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1631),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1633),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1635),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1637),
    [sym_let_and_operator] = ACTIONS(1635),
    [sym_match_operator] = ACTIONS(1639),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [140] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17871),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(140),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(18813),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1641),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1643),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1645),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1649),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1651),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1653),
    [sym_let_and_operator] = ACTIONS(1651),
    [sym_match_operator] = ACTIONS(1655),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [141] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14953),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(141),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19883),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1657),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1659),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1661),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1663),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1665),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1667),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1669),
    [sym_let_and_operator] = ACTIONS(1667),
    [sym_match_operator] = ACTIONS(1671),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [142] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18503),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(142),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19654),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1675),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1677),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1679),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1681),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1683),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1685),
    [sym_let_and_operator] = ACTIONS(1683),
    [sym_match_operator] = ACTIONS(1687),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [143] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18105),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(143),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19505),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1689),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1691),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1693),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1695),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1697),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1699),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1701),
    [sym_let_and_operator] = ACTIONS(1699),
    [sym_match_operator] = ACTIONS(1703),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [144] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18924),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(144),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19845),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1705),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1707),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1709),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1711),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1713),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1715),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1717),
    [sym_let_and_operator] = ACTIONS(1715),
    [sym_match_operator] = ACTIONS(1719),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [145] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14486),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(145),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(18548),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1721),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1511),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1513),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1515),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1517),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1519),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1521),
    [sym_let_and_operator] = ACTIONS(1519),
    [sym_match_operator] = ACTIONS(1523),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [146] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14992),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(146),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19845),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1723),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1707),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1709),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1711),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1713),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1715),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1717),
    [sym_let_and_operator] = ACTIONS(1715),
    [sym_match_operator] = ACTIONS(1719),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [147] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18239),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(147),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19550),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1725),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1727),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1729),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1731),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1733),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1735),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1737),
    [sym_let_and_operator] = ACTIONS(1735),
    [sym_match_operator] = ACTIONS(1739),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [148] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19334),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(148),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(20012),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1741),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1743),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1745),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1747),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1749),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1751),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1753),
    [sym_let_and_operator] = ACTIONS(1751),
    [sym_match_operator] = ACTIONS(1755),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [149] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17805),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(149),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(18974),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1757),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1495),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1497),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1499),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1501),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1503),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1505),
    [sym_let_and_operator] = ACTIONS(1503),
    [sym_match_operator] = ACTIONS(1507),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [150] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14929),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(150),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19603),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1759),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1761),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1763),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1765),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1767),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1769),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1771),
    [sym_let_and_operator] = ACTIONS(1769),
    [sym_match_operator] = ACTIONS(1773),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [151] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14687),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(151),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(18373),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1775),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1777),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1779),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1781),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1783),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1785),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1787),
    [sym_let_and_operator] = ACTIONS(1785),
    [sym_match_operator] = ACTIONS(1789),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [152] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(15024),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(152),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19329),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1791),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1613),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1615),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1617),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1619),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1621),
    [sym_let_and_operator] = ACTIONS(1619),
    [sym_match_operator] = ACTIONS(1623),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [153] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14731),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(153),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19505),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1793),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1691),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1693),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1695),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1697),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1699),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1701),
    [sym_let_and_operator] = ACTIONS(1699),
    [sym_match_operator] = ACTIONS(1703),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [154] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14800),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(154),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19069),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1795),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1797),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1799),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1801),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1803),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1805),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1807),
    [sym_let_and_operator] = ACTIONS(1805),
    [sym_match_operator] = ACTIONS(1809),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [155] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14799),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(155),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(18278),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1811),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1813),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1815),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1817),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1819),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1821),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1823),
    [sym_let_and_operator] = ACTIONS(1821),
    [sym_match_operator] = ACTIONS(1825),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [156] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(15074),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(156),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(17725),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1827),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1829),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1831),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1833),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1835),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1837),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1839),
    [sym_let_and_operator] = ACTIONS(1837),
    [sym_match_operator] = ACTIONS(1841),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [157] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19355),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(157),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19047),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1843),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1845),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1847),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1849),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1851),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1853),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1855),
    [sym_let_and_operator] = ACTIONS(1853),
    [sym_match_operator] = ACTIONS(1857),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [158] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18752),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(158),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(17725),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1859),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1829),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1831),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1833),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1835),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1837),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1839),
    [sym_let_and_operator] = ACTIONS(1837),
    [sym_match_operator] = ACTIONS(1841),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [159] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14830),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(159),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19550),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1861),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1727),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1729),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1731),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1733),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1735),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1737),
    [sym_let_and_operator] = ACTIONS(1735),
    [sym_match_operator] = ACTIONS(1739),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [160] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14840),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(160),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(20012),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1863),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1743),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1745),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1747),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1749),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1751),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1753),
    [sym_let_and_operator] = ACTIONS(1751),
    [sym_match_operator] = ACTIONS(1755),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [161] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(15031),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(161),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(18813),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1865),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1643),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1645),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1649),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1651),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1653),
    [sym_let_and_operator] = ACTIONS(1651),
    [sym_match_operator] = ACTIONS(1655),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [162] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14627),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(162),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(18039),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1867),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1869),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1871),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1875),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1877),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1879),
    [sym_let_and_operator] = ACTIONS(1877),
    [sym_match_operator] = ACTIONS(1881),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [163] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17933),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(163),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(18688),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1883),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1885),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1887),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1889),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1891),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1893),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1895),
    [sym_let_and_operator] = ACTIONS(1893),
    [sym_match_operator] = ACTIONS(1897),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [164] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17965),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(164),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19464),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1899),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1901),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1903),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1907),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1909),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1911),
    [sym_let_and_operator] = ACTIONS(1909),
    [sym_match_operator] = ACTIONS(1913),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [165] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(20269),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(165),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(20130),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1915),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1527),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1529),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1531),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1533),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1535),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1537),
    [sym_let_and_operator] = ACTIONS(1535),
    [sym_match_operator] = ACTIONS(1539),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [166] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(15050),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(166),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19257),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1917),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1919),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1921),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1923),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1925),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1927),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1929),
    [sym_let_and_operator] = ACTIONS(1927),
    [sym_match_operator] = ACTIONS(1931),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [167] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14580),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(167),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19047),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1933),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1845),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1847),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1849),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1851),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1853),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1855),
    [sym_let_and_operator] = ACTIONS(1853),
    [sym_match_operator] = ACTIONS(1857),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [168] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19052),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(168),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19883),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1935),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1659),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1661),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1663),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1665),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1667),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1669),
    [sym_let_and_operator] = ACTIONS(1667),
    [sym_match_operator] = ACTIONS(1671),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [169] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17744),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(169),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19069),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1937),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1797),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1799),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1801),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1803),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1805),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1807),
    [sym_let_and_operator] = ACTIONS(1805),
    [sym_match_operator] = ACTIONS(1809),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [170] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19784),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(170),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(20476),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1939),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1941),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1943),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1945),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1947),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1949),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1951),
    [sym_let_and_operator] = ACTIONS(1949),
    [sym_match_operator] = ACTIONS(1953),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [171] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18142),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(171),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(18278),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1955),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1813),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1815),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1817),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1819),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1821),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1823),
    [sym_let_and_operator] = ACTIONS(1821),
    [sym_match_operator] = ACTIONS(1825),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [172] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(15026),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(172),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19654),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1957),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1675),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1677),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1679),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1681),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1683),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1685),
    [sym_let_and_operator] = ACTIONS(1683),
    [sym_match_operator] = ACTIONS(1687),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [173] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14910),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(173),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19941),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1959),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1961),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1963),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1965),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1967),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1969),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1971),
    [sym_let_and_operator] = ACTIONS(1969),
    [sym_match_operator] = ACTIONS(1973),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [174] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(15068),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(174),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19725),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1975),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1977),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1979),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1981),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1983),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1985),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1987),
    [sym_let_and_operator] = ACTIONS(1985),
    [sym_match_operator] = ACTIONS(1989),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [175] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14628),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(175),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19464),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1991),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1901),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1903),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1907),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1909),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1911),
    [sym_let_and_operator] = ACTIONS(1909),
    [sym_match_operator] = ACTIONS(1913),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [176] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19216),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(176),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(18373),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1993),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1777),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1779),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1781),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1783),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1785),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1787),
    [sym_let_and_operator] = ACTIONS(1785),
    [sym_match_operator] = ACTIONS(1789),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [177] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14954),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(177),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19986),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1995),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1627),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1629),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1631),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1633),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1635),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1637),
    [sym_let_and_operator] = ACTIONS(1635),
    [sym_match_operator] = ACTIONS(1639),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [178] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14683),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(178),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(17660),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1997),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1999),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2001),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2003),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2005),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2007),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2009),
    [sym_let_and_operator] = ACTIONS(2007),
    [sym_match_operator] = ACTIONS(2011),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [179] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18775),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(179),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19771),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2013),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1455),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1457),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1459),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1463),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1465),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1473),
    [sym_let_and_operator] = ACTIONS(1465),
    [sym_match_operator] = ACTIONS(1475),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [180] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17749),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(180),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19416),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2015),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2017),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2019),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2021),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2023),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2025),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2027),
    [sym_let_and_operator] = ACTIONS(2025),
    [sym_match_operator] = ACTIONS(2029),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [181] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14893),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(181),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(18331),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2031),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2033),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2035),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2037),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2039),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2041),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2043),
    [sym_let_and_operator] = ACTIONS(2041),
    [sym_match_operator] = ACTIONS(2045),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [182] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19190),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(182),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19985),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2047),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2049),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2051),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2053),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2055),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2057),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2059),
    [sym_let_and_operator] = ACTIONS(2057),
    [sym_match_operator] = ACTIONS(2061),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [183] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(15057),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(183),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(18688),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2063),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1885),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1887),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1889),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1891),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1893),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1895),
    [sym_let_and_operator] = ACTIONS(1893),
    [sym_match_operator] = ACTIONS(1897),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [184] = {
    [sym_value_definition] = STATE(20489),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(12039),
    [sym__sequence_expression] = STATE(8851),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6050),
    [sym_array_get_expression] = STATE(6050),
    [sym_string_get_expression] = STATE(6050),
    [sym_bigarray_get_expression] = STATE(6050),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(184),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__attribute] = STATE(1286),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(1961),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(20493),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(2065),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(2067),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_PIPE_RBRACK] = ACTIONS(297),
    [anon_sym_if] = ACTIONS(2069),
    [anon_sym_else] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2071),
    [anon_sym_function] = ACTIONS(2073),
    [anon_sym_try] = ACTIONS(2075),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2077),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [185] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19784),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(185),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19187),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1939),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2079),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1943),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1945),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2081),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2083),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2085),
    [sym_let_and_operator] = ACTIONS(2083),
    [sym_match_operator] = ACTIONS(2087),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [186] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14649),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(186),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19136),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2089),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2093),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2095),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2097),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2099),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2101),
    [sym_let_and_operator] = ACTIONS(2099),
    [sym_match_operator] = ACTIONS(2103),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [187] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14998),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(187),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(20476),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2105),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1941),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1943),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1945),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1947),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1949),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1951),
    [sym_let_and_operator] = ACTIONS(1949),
    [sym_match_operator] = ACTIONS(1953),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [188] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18358),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(188),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19603),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2107),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1761),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1763),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1765),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1767),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1769),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1771),
    [sym_let_and_operator] = ACTIONS(1769),
    [sym_match_operator] = ACTIONS(1773),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [189] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14524),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(189),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19416),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2109),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2017),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2019),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2021),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2023),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2025),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2027),
    [sym_let_and_operator] = ACTIONS(2025),
    [sym_match_operator] = ACTIONS(2029),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [190] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17857),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(190),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19368),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2111),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2115),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2117),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2119),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2121),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2123),
    [sym_let_and_operator] = ACTIONS(2121),
    [sym_match_operator] = ACTIONS(2125),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [191] = {
    [sym_value_definition] = STATE(19586),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(5390),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(191),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__attribute] = STATE(764),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(301),
    [anon_sym_type] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(297),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_exception] = ACTIONS(301),
    [anon_sym_module] = ACTIONS(301),
    [anon_sym_open] = ACTIONS(301),
    [anon_sym_include] = ACTIONS(301),
    [anon_sym_class] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(301),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(297),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [192] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18402),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(192),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(17868),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2127),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2131),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2133),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2135),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2137),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2139),
    [sym_let_and_operator] = ACTIONS(2137),
    [sym_match_operator] = ACTIONS(2141),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [193] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18068),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(193),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(18331),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2143),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2033),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2035),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2037),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2039),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2041),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2043),
    [sym_let_and_operator] = ACTIONS(2041),
    [sym_match_operator] = ACTIONS(2045),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [194] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14879),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(194),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(17978),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2145),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2147),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2149),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2151),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2153),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2155),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2157),
    [sym_let_and_operator] = ACTIONS(2155),
    [sym_match_operator] = ACTIONS(2159),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [195] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17680),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(195),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19136),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2161),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2093),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2095),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2097),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2099),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2101),
    [sym_let_and_operator] = ACTIONS(2099),
    [sym_match_operator] = ACTIONS(2103),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [196] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14523),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(196),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(17850),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2163),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1481),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1483),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1485),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1487),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1489),
    [sym_let_and_operator] = ACTIONS(1487),
    [sym_match_operator] = ACTIONS(1491),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [197] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14419),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(197),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19368),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2165),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2115),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2117),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2119),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2121),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2123),
    [sym_let_and_operator] = ACTIONS(2121),
    [sym_match_operator] = ACTIONS(2125),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [198] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19915),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(198),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19596),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2167),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2169),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2171),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2173),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2175),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2177),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2179),
    [sym_let_and_operator] = ACTIONS(2177),
    [sym_match_operator] = ACTIONS(2181),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [199] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18659),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(199),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(17660),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2183),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1999),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2001),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2003),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2005),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2007),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2009),
    [sym_let_and_operator] = ACTIONS(2007),
    [sym_match_operator] = ACTIONS(2011),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [200] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14675),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(200),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19405),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2185),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2187),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2189),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2193),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2195),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2197),
    [sym_let_and_operator] = ACTIONS(2195),
    [sym_match_operator] = ACTIONS(2199),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [201] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19655),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(201),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19405),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2201),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2187),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2189),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2193),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2195),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2197),
    [sym_let_and_operator] = ACTIONS(2195),
    [sym_match_operator] = ACTIONS(2199),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [202] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14566),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(202),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19596),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2203),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2169),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2171),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2173),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2175),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2177),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2179),
    [sym_let_and_operator] = ACTIONS(2177),
    [sym_match_operator] = ACTIONS(2181),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [203] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14570),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(203),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(17868),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2205),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2131),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2133),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2135),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2137),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2139),
    [sym_let_and_operator] = ACTIONS(2137),
    [sym_match_operator] = ACTIONS(2141),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [204] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14998),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(204),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19187),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2207),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2079),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1943),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1945),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2081),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2083),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2085),
    [sym_let_and_operator] = ACTIONS(2083),
    [sym_match_operator] = ACTIONS(2087),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [205] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14985),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(205),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(18532),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2211),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2213),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2215),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2217),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2219),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2221),
    [sym_let_and_operator] = ACTIONS(2219),
    [sym_match_operator] = ACTIONS(2223),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [206] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19117),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(206),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(17978),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2225),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2147),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2149),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2151),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2153),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2155),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2157),
    [sym_let_and_operator] = ACTIONS(2155),
    [sym_match_operator] = ACTIONS(2159),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [207] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18317),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(207),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(18039),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1869),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1871),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1875),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1877),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1879),
    [sym_let_and_operator] = ACTIONS(1877),
    [sym_match_operator] = ACTIONS(1881),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [208] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18487),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(208),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(17711),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2229),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2237),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2239),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2241),
    [sym_let_and_operator] = ACTIONS(2239),
    [sym_match_operator] = ACTIONS(2243),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [209] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17629),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(209),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19215),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2245),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2247),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2249),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2251),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2253),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2255),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2257),
    [sym_let_and_operator] = ACTIONS(2255),
    [sym_match_operator] = ACTIONS(2259),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [210] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18894),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(210),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(17912),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2261),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2263),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2265),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2267),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2269),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2271),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2273),
    [sym_let_and_operator] = ACTIONS(2271),
    [sym_match_operator] = ACTIONS(2275),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [211] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14413),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(211),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(17620),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2277),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2279),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2281),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2283),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2285),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2287),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2289),
    [sym_let_and_operator] = ACTIONS(2287),
    [sym_match_operator] = ACTIONS(2291),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [212] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17999),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(212),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(18532),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2293),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2211),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2213),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2215),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2217),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2219),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2221),
    [sym_let_and_operator] = ACTIONS(2219),
    [sym_match_operator] = ACTIONS(2223),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [213] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18228),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(213),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(18136),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2295),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1595),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1597),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1599),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1601),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1603),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1605),
    [sym_let_and_operator] = ACTIONS(1603),
    [sym_match_operator] = ACTIONS(1607),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [214] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14877),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(214),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19985),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2297),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2049),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2051),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2053),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2055),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2057),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2059),
    [sym_let_and_operator] = ACTIONS(2057),
    [sym_match_operator] = ACTIONS(2061),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [215] = {
    [sym_value_definition] = STATE(18662),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(11961),
    [sym__sequence_expression] = STATE(8177),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6146),
    [sym_array_get_expression] = STATE(6146),
    [sym_string_get_expression] = STATE(6146),
    [sym_bigarray_get_expression] = STATE(6146),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(215),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__attribute] = STATE(976),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(2139),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18398),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_then] = ACTIONS(301),
    [anon_sym_else] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [216] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19119),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(216),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19941),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2351),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1961),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1963),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1965),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1967),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1969),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1971),
    [sym_let_and_operator] = ACTIONS(1969),
    [sym_match_operator] = ACTIONS(1973),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [217] = {
    [sym_value_definition] = STATE(18705),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(11969),
    [sym__sequence_expression] = STATE(8177),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6123),
    [sym_array_get_expression] = STATE(6123),
    [sym_string_get_expression] = STATE(6123),
    [sym_bigarray_get_expression] = STATE(6123),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(217),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__attribute] = STATE(1221),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2250),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18531),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2355),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2367),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_else] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_do] = ACTIONS(301),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2373),
    [anon_sym_function] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2399),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [218] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18628),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(218),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19725),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2405),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1977),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1979),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1981),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1983),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1985),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1987),
    [sym_let_and_operator] = ACTIONS(1985),
    [sym_match_operator] = ACTIONS(1989),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [219] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14501),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(219),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(17711),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2407),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2237),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2239),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2241),
    [sym_let_and_operator] = ACTIONS(2239),
    [sym_match_operator] = ACTIONS(2243),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [220] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14502),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(220),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19215),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2409),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2247),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2249),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2251),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2253),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2255),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2257),
    [sym_let_and_operator] = ACTIONS(2255),
    [sym_match_operator] = ACTIONS(2259),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [221] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(14904),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(221),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(17912),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2411),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2263),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2265),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2267),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2269),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2271),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2273),
    [sym_let_and_operator] = ACTIONS(2271),
    [sym_match_operator] = ACTIONS(2275),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [222] = {
    [sym_value_definition] = STATE(18821),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12001),
    [sym__sequence_expression] = STATE(8177),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6118),
    [sym_array_get_expression] = STATE(6118),
    [sym_string_get_expression] = STATE(6118),
    [sym_bigarray_get_expression] = STATE(6118),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(222),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__attribute] = STATE(1471),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(2170),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18670),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2415),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_with] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2427),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_else] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2433),
    [anon_sym_function] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2437),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2459),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [223] = {
    [sym_value_definition] = STATE(17729),
    [sym__simple_expression] = STATE(2474),
    [sym__expression] = STATE(11972),
    [sym__sequence_expression] = STATE(10648),
    [sym_typed_expression] = STATE(6258),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6258),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6258),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6104),
    [sym_array_get_expression] = STATE(6104),
    [sym_string_get_expression] = STATE(6104),
    [sym_bigarray_get_expression] = STATE(6104),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6258),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(223),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__attribute] = STATE(1338),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym_sign_operator] = STATE(1847),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__instance_variable_name] = STATE(17706),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [sym__lowercase_identifier] = ACTIONS(2465),
    [anon_sym_let] = ACTIONS(2467),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_fun] = ACTIONS(2479),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_if] = ACTIONS(2483),
    [anon_sym_else] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_done] = ACTIONS(301),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2485),
    [anon_sym_function] = ACTIONS(2487),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2511),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [224] = {
    [sym_value_definition] = STATE(18990),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12014),
    [sym__sequence_expression] = STATE(8177),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6117),
    [sym_array_get_expression] = STATE(6117),
    [sym_string_get_expression] = STATE(6117),
    [sym_bigarray_get_expression] = STATE(6117),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(224),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__attribute] = STATE(1457),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2049),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(18809),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2519),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_end] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2531),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2535),
    [anon_sym_else] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2537),
    [anon_sym_function] = ACTIONS(2539),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2563),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [225] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18575),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(225),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(17620),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2569),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(2279),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(2281),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(2283),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(2285),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(2287),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(2289),
    [sym_let_and_operator] = ACTIONS(2287),
    [sym_match_operator] = ACTIONS(2291),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [226] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19437),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(226),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__infix_operator] = STATE(19257),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(2571),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(1919),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_module] = ACTIONS(1921),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(1923),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(1461),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1925),
    [aux_sym_sign_operator_token1] = ACTIONS(1461),
    [sym_hash_operator] = ACTIONS(1927),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1929),
    [sym_let_and_operator] = ACTIONS(1927),
    [sym_match_operator] = ACTIONS(1931),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [227] = {
    [sym_value_definition] = STATE(18108),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12418),
    [sym__sequence_expression] = STATE(8851),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6582),
    [sym_array_get_expression] = STATE(6582),
    [sym_string_get_expression] = STATE(6582),
    [sym_bigarray_get_expression] = STATE(6582),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(227),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__attribute] = STATE(1478),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(1808),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18116),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_with] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2575),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_else] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2579),
    [anon_sym_function] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2583),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2585),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [228] = {
    [sym_value_definition] = STATE(17904),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12622),
    [sym__sequence_expression] = STATE(8177),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6329),
    [sym_array_get_expression] = STATE(6329),
    [sym_string_get_expression] = STATE(6329),
    [sym_bigarray_get_expression] = STATE(6329),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(228),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(679),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(2362),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(17913),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_end] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2601),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2607),
    [anon_sym_function] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2611),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2633),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [229] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12276),
    [sym__sequence_expression] = STATE(10648),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(229),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__attribute] = STATE(1001),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_done] = ACTIONS(301),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [230] = {
    [sym_value_definition] = STATE(18034),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12470),
    [sym__sequence_expression] = STATE(8177),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6443),
    [sym_array_get_expression] = STATE(6443),
    [sym_string_get_expression] = STATE(6443),
    [sym_bigarray_get_expression] = STATE(6443),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(230),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(677),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2397),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(18043),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2693),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_with] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2705),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2709),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2711),
    [anon_sym_function] = ACTIONS(2713),
    [anon_sym_try] = ACTIONS(2715),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2737),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [231] = {
    [sym_value_definition] = STATE(18188),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12346),
    [sym__sequence_expression] = STATE(8177),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6417),
    [sym_array_get_expression] = STATE(6417),
    [sym_string_get_expression] = STATE(6417),
    [sym_bigarray_get_expression] = STATE(6417),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(231),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__attribute] = STATE(672),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(18201),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2745),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2757),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2761),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_do] = ACTIONS(301),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2763),
    [anon_sym_function] = ACTIONS(2765),
    [anon_sym_try] = ACTIONS(2767),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2789),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [232] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12619),
    [sym__sequence_expression] = STATE(8851),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(232),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__attribute] = STATE(667),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(297),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [233] = {
    [sym_value_definition] = STATE(18362),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12297),
    [sym__sequence_expression] = STATE(8177),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6385),
    [sym_array_get_expression] = STATE(6385),
    [sym_string_get_expression] = STATE(6385),
    [sym_bigarray_get_expression] = STATE(6385),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(233),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(669),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2336),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(18374),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_PIPE] = ACTIONS(301),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_then] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [234] = {
    [sym_value_definition] = STATE(18447),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12466),
    [sym__sequence_expression] = STATE(8851),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6602),
    [sym_array_get_expression] = STATE(6602),
    [sym_string_get_expression] = STATE(6602),
    [sym_bigarray_get_expression] = STATE(6602),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(234),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__attribute] = STATE(1354),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(1952),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18459),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_then] = ACTIONS(301),
    [anon_sym_else] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [235] = {
    [sym_value_definition] = STATE(18277),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(12620),
    [sym__sequence_expression] = STATE(8851),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6588),
    [sym_array_get_expression] = STATE(6588),
    [sym_string_get_expression] = STATE(6588),
    [sym_bigarray_get_expression] = STATE(6588),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(235),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__attribute] = STATE(1425),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2201),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18286),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_else] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_do] = ACTIONS(301),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [236] = {
    [sym_value_definition] = STATE(17966),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12567),
    [sym__sequence_expression] = STATE(8851),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(236),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__attribute] = STATE(1264),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2141),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(17979),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_end] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_else] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [237] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12712),
    [sym__sequence_expression] = STATE(8851),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(237),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(837),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_end] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [238] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12682),
    [sym__sequence_expression] = STATE(8851),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(238),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(862),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_with] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [239] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12659),
    [sym__sequence_expression] = STATE(8851),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(239),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(961),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_then] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [240] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12751),
    [sym__sequence_expression] = STATE(8851),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(240),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__attribute] = STATE(918),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_COMMA] = ACTIONS(297),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_SEMI] = ACTIONS(297),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_do] = ACTIONS(301),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [anon_sym_PERCENT] = ACTIONS(337),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(103),
    [sym_pow_operator] = ACTIONS(301),
    [sym_mult_operator] = ACTIONS(301),
    [aux_sym_add_operator_token1] = ACTIONS(301),
    [sym_concat_operator] = ACTIONS(297),
    [sym_rel_operator] = ACTIONS(301),
    [sym_and_operator] = ACTIONS(301),
    [sym_or_operator] = ACTIONS(301),
    [sym_assign_operator] = ACTIONS(297),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [241] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10108),
    [sym__sequence_expression] = STATE(5390),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(241),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__attribute] = STATE(849),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_constraint] = ACTIONS(301),
    [anon_sym_val] = ACTIONS(301),
    [anon_sym_end] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_inherit] = ACTIONS(301),
    [anon_sym_method] = ACTIONS(301),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_initializer] = ACTIONS(301),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(301),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1029),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1031),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(297),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [242] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(5390),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(242),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__attribute] = STATE(1364),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_COLON_GT] = ACTIONS(297),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(297),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(297),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_COLON2] = ACTIONS(301),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_RBRACE] = ACTIONS(297),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [243] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11810),
    [sym__sequence_expression] = STATE(8851),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(243),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__attribute] = STATE(682),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_and] = ACTIONS(301),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_in] = ACTIONS(301),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(297),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_let_and_operator] = ACTIONS(297),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [244] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(12568),
    [sym__sequence_expression] = STATE(7547),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(244),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__attribute] = STATE(757),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_to] = ACTIONS(301),
    [anon_sym_downto] = ACTIONS(301),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [245] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(17911),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(245),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(1041),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(2959),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [246] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(17897),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(246),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(1428),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(2961),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [247] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12672),
    [sym__sequence_expression] = STATE(5390),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(247),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__attribute] = STATE(930),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_do] = ACTIONS(301),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [248] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18892),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(248),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(958),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(2963),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [249] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(17743),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(249),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(1141),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(2965),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [250] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(17709),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(250),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(1480),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(2967),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [251] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(5390),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(251),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(587),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [252] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19967),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(252),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(1246),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(2969),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [253] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12674),
    [sym__sequence_expression] = STATE(7547),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(253),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__attribute] = STATE(1310),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_done] = ACTIONS(301),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [254] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(20104),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(254),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(1283),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(2971),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [255] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18552),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(255),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(588),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(2973),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [256] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19474),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(256),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(560),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(2975),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [257] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18697),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(257),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(1037),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(2977),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [258] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12757),
    [sym__sequence_expression] = STATE(20142),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(20144),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(258),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__attribute] = STATE(843),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DASH_GT] = ACTIONS(297),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [259] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(17961),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(259),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(1396),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(2979),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [260] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(5390),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(260),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(743),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_with] = ACTIONS(301),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [261] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19082),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(261),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(1002),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(2981),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [262] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18102),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(262),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(1337),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(2983),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [263] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19388),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(263),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(634),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(2985),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [264] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19004),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(264),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(891),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(2987),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [265] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(17607),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(265),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(1256),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(2989),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [266] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19242),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(266),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(785),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(2991),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [267] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19156),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(267),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(1101),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(2993),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [268] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(17771),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(268),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(1488),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(2995),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [269] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19836),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(269),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(1160),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(2997),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [270] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19166),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(270),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(840),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(2999),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [271] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18725),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(271),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(673),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(3001),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [272] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18441),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(272),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(1168),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(3003),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [273] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18352),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(273),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(1205),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(3005),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [274] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19259),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(274),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(1368),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(3007),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [275] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18176),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(275),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(1289),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(3009),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [276] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18308),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(276),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(671),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(3011),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [277] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(277),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(974),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(3013),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [278] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18026),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(278),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(1365),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(3015),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [279] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18790),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(279),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(996),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(3017),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [280] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19007),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(280),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(902),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(3019),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [281] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19575),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(281),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(678),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(3021),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [282] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18041),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(282),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(933),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(3023),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [283] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19313),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(283),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(697),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(3025),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [284] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18846),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(284),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(796),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(3027),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [285] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18613),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(285),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(1096),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(3029),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [286] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19836),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(286),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(1160),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(3031),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [287] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18526),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(287),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(1128),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(3033),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [288] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(5390),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(288),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(1167),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_then] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [289] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18438),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(289),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(885),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(3035),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [290] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18174),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(290),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(774),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(3037),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [291] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18266),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(291),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(1253),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(3039),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [292] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(20433),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(292),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(922),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(3041),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [293] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(17836),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(293),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(1463),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(3043),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [294] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(17648),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(294),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__attribute] = STATE(1387),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_end] = ACTIONS(3045),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [295] = {
    [sym_value_definition] = STATE(19385),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11179),
    [sym__sequence_expression] = STATE(10605),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5503),
    [sym_array_get_expression] = STATE(5503),
    [sym_string_get_expression] = STATE(5503),
    [sym_bigarray_get_expression] = STATE(5503),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_refutation_case] = STATE(10605),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(295),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(1823),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(20481),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1279),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_DOT] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1291),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1295),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [296] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16942),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(296),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(1385),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [297] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17131),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(297),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(768),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [298] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18687),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(298),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1080),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [299] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18699),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(299),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1086),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [300] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17165),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(300),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(558),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [301] = {
    [sym__simple_expression] = STATE(3046),
    [sym_typed_expression] = STATE(3052),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_labeled_argument] = STATE(4042),
    [sym_prefix_expression] = STATE(3052),
    [sym_hash_expression] = STATE(3052),
    [sym_field_get_expression] = STATE(3052),
    [sym_array_get_expression] = STATE(3052),
    [sym_string_get_expression] = STATE(3052),
    [sym_bigarray_get_expression] = STATE(3052),
    [sym_coercion_expression] = STATE(3052),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(301),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [aux_sym_class_application_repeat1] = STATE(1771),
    [sym__lowercase_identifier] = ACTIONS(3049),
    [anon_sym_SEMI_SEMI] = ACTIONS(3051),
    [anon_sym_let] = ACTIONS(3053),
    [anon_sym_and] = ACTIONS(3053),
    [anon_sym_TILDE] = ACTIONS(3055),
    [anon_sym_QMARK] = ACTIONS(3055),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_external] = ACTIONS(3053),
    [anon_sym_type] = ACTIONS(3053),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_DOT] = ACTIONS(3057),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_SEMI] = ACTIONS(3053),
    [anon_sym_exception] = ACTIONS(3053),
    [anon_sym_module] = ACTIONS(3053),
    [anon_sym_open] = ACTIONS(3053),
    [anon_sym_include] = ACTIONS(3053),
    [anon_sym_class] = ACTIONS(3053),
    [anon_sym_end] = ACTIONS(3053),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_in] = ACTIONS(3053),
    [anon_sym_POUND] = ACTIONS(3059),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_else] = ACTIONS(3053),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3053),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3051),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(335),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3051),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(3061),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym_let_operator] = ACTIONS(3051),
    [sym_let_and_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_directive_token1] = ACTIONS(3053),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [302] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12619),
    [sym__sequence_expression] = STATE(12590),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_refutation_case] = STATE(12590),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(302),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(3063),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [303] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17249),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(303),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(626),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [304] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18465),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(304),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1068),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [305] = {
    [sym_value_definition] = STATE(20489),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(12039),
    [sym__sequence_expression] = STATE(12531),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6050),
    [sym_array_get_expression] = STATE(6050),
    [sym_string_get_expression] = STATE(6050),
    [sym_bigarray_get_expression] = STATE(6050),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_refutation_case] = STATE(12531),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(305),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(1961),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(20493),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(2065),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_DOT] = ACTIONS(3063),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(2067),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(2069),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2071),
    [anon_sym_function] = ACTIONS(2073),
    [anon_sym_try] = ACTIONS(2075),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2077),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [306] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18760),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(306),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1100),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [307] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18463),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(307),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [308] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18798),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(308),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1121),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [309] = {
    [sym_value_definition] = STATE(19586),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8712),
    [sym__sequence_expression] = STATE(8215),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_refutation_case] = STATE(8215),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(309),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_DOT] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [310] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18488),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(310),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(576),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [311] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18489),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(311),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(575),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [312] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18799),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(312),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1123),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [313] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17328),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(313),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(695),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [314] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18270),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(314),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1039),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [315] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(19005),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(315),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1104),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [316] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(19014),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(316),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1107),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [317] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18723),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(317),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1066),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [318] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18722),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(318),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1060),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [319] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17059),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(319),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(687),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [320] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18265),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(320),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1038),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [321] = {
    [sym_value_definition] = STATE(17654),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9605),
    [sym__sequence_expression] = STATE(8217),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4841),
    [sym_array_get_expression] = STATE(4841),
    [sym_string_get_expression] = STATE(4841),
    [sym_bigarray_get_expression] = STATE(4841),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_refutation_case] = STATE(8217),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(321),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2276),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(17662),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(997),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_DOT] = ACTIONS(3071),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1009),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1013),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1015),
    [anon_sym_function] = ACTIONS(1017),
    [anon_sym_try] = ACTIONS(1019),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1041),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [322] = {
    [sym_value_definition] = STATE(17654),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9605),
    [sym__sequence_expression] = STATE(8104),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4841),
    [sym_array_get_expression] = STATE(4841),
    [sym_string_get_expression] = STATE(4841),
    [sym_bigarray_get_expression] = STATE(4841),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_refutation_case] = STATE(8104),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(322),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2276),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(17662),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(997),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_DOT] = ACTIONS(3071),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1009),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1013),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1015),
    [anon_sym_function] = ACTIONS(1017),
    [anon_sym_try] = ACTIONS(1019),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1041),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [323] = {
    [sym__simple_expression] = STATE(3167),
    [sym_typed_expression] = STATE(3176),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_labeled_argument] = STATE(4052),
    [sym_prefix_expression] = STATE(3176),
    [sym_hash_expression] = STATE(3176),
    [sym_field_get_expression] = STATE(3176),
    [sym_array_get_expression] = STATE(3176),
    [sym_string_get_expression] = STATE(3176),
    [sym_bigarray_get_expression] = STATE(3176),
    [sym_coercion_expression] = STATE(3176),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(323),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [aux_sym_class_application_repeat1] = STATE(1767),
    [sym__lowercase_identifier] = ACTIONS(3077),
    [anon_sym_SEMI_SEMI] = ACTIONS(3051),
    [anon_sym_let] = ACTIONS(3053),
    [anon_sym_and] = ACTIONS(3053),
    [anon_sym_TILDE] = ACTIONS(3079),
    [anon_sym_QMARK] = ACTIONS(3079),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_external] = ACTIONS(3053),
    [anon_sym_type] = ACTIONS(3053),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_RBRACK] = ACTIONS(3051),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_DOT] = ACTIONS(3081),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_SEMI] = ACTIONS(3053),
    [anon_sym_exception] = ACTIONS(3053),
    [anon_sym_module] = ACTIONS(3053),
    [anon_sym_open] = ACTIONS(3053),
    [anon_sym_include] = ACTIONS(3053),
    [anon_sym_class] = ACTIONS(3053),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_in] = ACTIONS(3053),
    [anon_sym_POUND] = ACTIONS(3083),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_else] = ACTIONS(3053),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3053),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3051),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(389),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(391),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3051),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(3085),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym_let_operator] = ACTIONS(3051),
    [sym_let_and_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_directive_token1] = ACTIONS(3053),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [324] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8387),
    [sym__sequence_expression] = STATE(8176),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_refutation_case] = STATE(8176),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(324),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_DOT] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [325] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18685),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(325),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1053),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [326] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18684),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(326),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1051),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [327] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16533),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(327),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(1352),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [328] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18528),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(328),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(556),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [329] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17118),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(329),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(1049),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [330] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8387),
    [sym__sequence_expression] = STATE(8215),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_refutation_case] = STATE(8215),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(330),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_DOT] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [331] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17162),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(331),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(569),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [332] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18529),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(332),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(555),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [333] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17562),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(333),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(860),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [334] = {
    [sym_value_definition] = STATE(19385),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11179),
    [sym__sequence_expression] = STATE(10458),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5503),
    [sym_array_get_expression] = STATE(5503),
    [sym_string_get_expression] = STATE(5503),
    [sym_bigarray_get_expression] = STATE(5503),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_refutation_case] = STATE(10458),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(334),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(1823),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(20481),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1279),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_DOT] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1291),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1295),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [335] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18647),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(335),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1040),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [336] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18835),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(336),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1175),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [337] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16746),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(337),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(741),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [338] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18646),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(338),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1033),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [339] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18568),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(339),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(584),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [340] = {
    [sym_value_definition] = STATE(17889),
    [sym__simple_expression] = STATE(2457),
    [sym__expression] = STATE(11791),
    [sym__sequence_expression] = STATE(10458),
    [sym_typed_expression] = STATE(6138),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6138),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6138),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5776),
    [sym_array_get_expression] = STATE(5776),
    [sym_string_get_expression] = STATE(5776),
    [sym_bigarray_get_expression] = STATE(5776),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_refutation_case] = STATE(10458),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6138),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(340),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym_sign_operator] = STATE(1969),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__instance_variable_name] = STATE(17866),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [sym__lowercase_identifier] = ACTIONS(1395),
    [anon_sym_let] = ACTIONS(1397),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_DOT] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_fun] = ACTIONS(1409),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1415),
    [anon_sym_function] = ACTIONS(1417),
    [anon_sym_try] = ACTIONS(1419),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1441),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [341] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17196),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(341),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(771),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [342] = {
    [sym_value_definition] = STATE(17889),
    [sym__simple_expression] = STATE(2457),
    [sym__expression] = STATE(11791),
    [sym__sequence_expression] = STATE(10605),
    [sym_typed_expression] = STATE(6138),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6138),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6138),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5776),
    [sym_array_get_expression] = STATE(5776),
    [sym_string_get_expression] = STATE(5776),
    [sym_bigarray_get_expression] = STATE(5776),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_refutation_case] = STATE(10605),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6138),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(342),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym_sign_operator] = STATE(1969),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__instance_variable_name] = STATE(17866),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [sym__lowercase_identifier] = ACTIONS(1395),
    [anon_sym_let] = ACTIONS(1397),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_DOT] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_fun] = ACTIONS(1409),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1415),
    [anon_sym_function] = ACTIONS(1417),
    [anon_sym_try] = ACTIONS(1419),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1441),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [343] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8389),
    [sym__sequence_expression] = STATE(8215),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_refutation_case] = STATE(8215),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(343),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_DOT] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [344] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8389),
    [sym__sequence_expression] = STATE(8176),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_refutation_case] = STATE(8176),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(344),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_DOT] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [345] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18608),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(345),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1018),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [346] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18569),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(346),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(583),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [347] = {
    [sym_value_definition] = STATE(17904),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12622),
    [sym__sequence_expression] = STATE(8104),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6329),
    [sym_array_get_expression] = STATE(6329),
    [sym_string_get_expression] = STATE(6329),
    [sym_bigarray_get_expression] = STATE(6329),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_refutation_case] = STATE(8104),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(347),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(2362),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(17913),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_DOT] = ACTIONS(3071),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2601),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2607),
    [anon_sym_function] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2611),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2633),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [348] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18607),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(348),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(999),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [349] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18836),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(349),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1177),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [350] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16518),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(350),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(1299),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [351] = {
    [sym_value_definition] = STATE(18362),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12297),
    [sym__sequence_expression] = STATE(8217),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6385),
    [sym_array_get_expression] = STATE(6385),
    [sym_string_get_expression] = STATE(6385),
    [sym_bigarray_get_expression] = STATE(6385),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_refutation_case] = STATE(8217),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(351),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2336),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(18374),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_DOT] = ACTIONS(3071),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [352] = {
    [sym_value_definition] = STATE(17904),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12622),
    [sym__sequence_expression] = STATE(8217),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6329),
    [sym_array_get_expression] = STATE(6329),
    [sym_string_get_expression] = STATE(6329),
    [sym_bigarray_get_expression] = STATE(6329),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_refutation_case] = STATE(8217),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(352),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(2362),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(17913),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_DOT] = ACTIONS(3071),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2601),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2607),
    [anon_sym_function] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2611),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2633),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [353] = {
    [sym_value_definition] = STATE(18362),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12297),
    [sym__sequence_expression] = STATE(8104),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6385),
    [sym_array_get_expression] = STATE(6385),
    [sym_string_get_expression] = STATE(6385),
    [sym_bigarray_get_expression] = STATE(6385),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_refutation_case] = STATE(8104),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(353),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2336),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(18374),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_DOT] = ACTIONS(3071),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [354] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17406),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(354),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(783),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [355] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17950),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(355),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(980),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [356] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18066),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(356),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(979),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [357] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12672),
    [sym__sequence_expression] = STATE(16747),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(357),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__attribute] = STATE(1165),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [358] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16706),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(358),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(559),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [359] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18872),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(359),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1188),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [360] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17484),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(360),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(831),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [361] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18873),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(361),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1192),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [362] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17867),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(362),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(965),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [363] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17856),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(363),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(962),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [364] = {
    [sym_value_definition] = STATE(20489),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(12039),
    [sym__sequence_expression] = STATE(12590),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6050),
    [sym_array_get_expression] = STATE(6050),
    [sym_string_get_expression] = STATE(6050),
    [sym_bigarray_get_expression] = STATE(6050),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_refutation_case] = STATE(12590),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(364),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(1961),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(20493),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(2065),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_DOT] = ACTIONS(3063),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(2067),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(2069),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2071),
    [anon_sym_function] = ACTIONS(2073),
    [anon_sym_try] = ACTIONS(2075),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2077),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [365] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12619),
    [sym__sequence_expression] = STATE(12531),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_refutation_case] = STATE(12531),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(365),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_DOT] = ACTIONS(3063),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [366] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16830),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(366),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(1063),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [367] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17557),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(367),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(551),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [368] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17670),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(368),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(952),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [369] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(19048),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(369),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(950),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [370] = {
    [sym_value_definition] = STATE(19480),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8574),
    [sym__sequence_expression] = STATE(8176),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_refutation_case] = STATE(8176),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(370),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_let] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_DOT] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3095),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3097),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [371] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(19261),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(371),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1179),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [372] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17639),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(372),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(937),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [373] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18909),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(373),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1244),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [374] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17640),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(374),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(934),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [375] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18910),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(375),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1249),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [376] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8306),
    [sym__sequence_expression] = STATE(8176),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_refutation_case] = STATE(8176),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(376),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_DOT] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [377] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17060),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(377),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(1483),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [378] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17685),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(378),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(926),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [379] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17577),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(379),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(907),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [380] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17686),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(380),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(925),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [381] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17739),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(381),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(913),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [382] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17740),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(382),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(911),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [383] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(19281),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(383),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1180),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [384] = {
    [sym_value_definition] = STATE(19248),
    [sym__simple_expression] = STATE(1582),
    [sym__expression] = STATE(8468),
    [sym__sequence_expression] = STATE(8176),
    [sym_typed_expression] = STATE(4041),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4041),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4041),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3928),
    [sym_array_get_expression] = STATE(3928),
    [sym_string_get_expression] = STATE(3928),
    [sym_bigarray_get_expression] = STATE(3928),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_refutation_case] = STATE(8176),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4041),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(384),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__instance_variable_name] = STATE(19258),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [sym__lowercase_identifier] = ACTIONS(857),
    [anon_sym_let] = ACTIONS(859),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_DOT] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_fun] = ACTIONS(871),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(877),
    [anon_sym_function] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(881),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3103),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3105),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(903),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [385] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16925),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(385),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(981),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [386] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17255),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(386),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(1045),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [387] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17541),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(387),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(960),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [388] = {
    [sym_value_definition] = STATE(19480),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8574),
    [sym__sequence_expression] = STATE(8215),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_refutation_case] = STATE(8215),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(388),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_let] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_DOT] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3095),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3097),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [389] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17793),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(389),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(898),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [390] = {
    [sym_value_definition] = STATE(19248),
    [sym__simple_expression] = STATE(1582),
    [sym__expression] = STATE(8468),
    [sym__sequence_expression] = STATE(8215),
    [sym_typed_expression] = STATE(4041),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4041),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4041),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3928),
    [sym_array_get_expression] = STATE(3928),
    [sym_string_get_expression] = STATE(3928),
    [sym_bigarray_get_expression] = STATE(3928),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_refutation_case] = STATE(8215),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4041),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(390),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__instance_variable_name] = STATE(19258),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [sym__lowercase_identifier] = ACTIONS(857),
    [anon_sym_let] = ACTIONS(859),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_DOT] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_fun] = ACTIONS(871),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(877),
    [anon_sym_function] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(881),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3103),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3105),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(903),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [391] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17520),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(391),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(1010),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [392] = {
    [sym_value_definition] = STATE(18428),
    [sym__simple_expression] = STATE(2428),
    [sym__expression] = STATE(10224),
    [sym__sequence_expression] = STATE(8217),
    [sym_typed_expression] = STATE(5216),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5216),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5216),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4994),
    [sym_array_get_expression] = STATE(4994),
    [sym_string_get_expression] = STATE(4994),
    [sym_bigarray_get_expression] = STATE(4994),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_refutation_case] = STATE(8217),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5216),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(392),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym_sign_operator] = STATE(2366),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__instance_variable_name] = STATE(18272),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [sym__lowercase_identifier] = ACTIONS(1061),
    [anon_sym_let] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_DOT] = ACTIONS(3071),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_fun] = ACTIONS(1075),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_if] = ACTIONS(1079),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1081),
    [anon_sym_function] = ACTIONS(1083),
    [anon_sym_try] = ACTIONS(1085),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1109),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [393] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17794),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(393),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(886),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [394] = {
    [sym_value_definition] = STATE(18428),
    [sym__simple_expression] = STATE(2428),
    [sym__expression] = STATE(10224),
    [sym__sequence_expression] = STATE(8104),
    [sym_typed_expression] = STATE(5216),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5216),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5216),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4994),
    [sym_array_get_expression] = STATE(4994),
    [sym_string_get_expression] = STATE(4994),
    [sym_bigarray_get_expression] = STATE(4994),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_refutation_case] = STATE(8104),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5216),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(394),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym_sign_operator] = STATE(2366),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__instance_variable_name] = STATE(18272),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [sym__lowercase_identifier] = ACTIONS(1061),
    [anon_sym_let] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_DOT] = ACTIONS(3071),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_fun] = ACTIONS(1075),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_if] = ACTIONS(1079),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1081),
    [anon_sym_function] = ACTIONS(1083),
    [anon_sym_try] = ACTIONS(1085),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1109),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [395] = {
    [sym_value_definition] = STATE(17611),
    [sym__simple_expression] = STATE(323),
    [sym__expression] = STATE(8239),
    [sym__sequence_expression] = STATE(8176),
    [sym_typed_expression] = STATE(3176),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3176),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3176),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2957),
    [sym_array_get_expression] = STATE(2957),
    [sym_string_get_expression] = STATE(2957),
    [sym_bigarray_get_expression] = STATE(2957),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_refutation_case] = STATE(8176),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3176),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(395),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym_sign_operator] = STATE(1905),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__instance_variable_name] = STATE(17621),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [sym__lowercase_identifier] = ACTIONS(355),
    [anon_sym_let] = ACTIONS(357),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_DOT] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_fun] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_if] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(375),
    [anon_sym_function] = ACTIONS(377),
    [anon_sym_try] = ACTIONS(379),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3107),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3109),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(401),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [396] = {
    [sym_value_definition] = STATE(17611),
    [sym__simple_expression] = STATE(323),
    [sym__expression] = STATE(8239),
    [sym__sequence_expression] = STATE(8215),
    [sym_typed_expression] = STATE(3176),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3176),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3176),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2957),
    [sym_array_get_expression] = STATE(2957),
    [sym_string_get_expression] = STATE(2957),
    [sym_bigarray_get_expression] = STATE(2957),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_refutation_case] = STATE(8215),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3176),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(396),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym_sign_operator] = STATE(1905),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__instance_variable_name] = STATE(17621),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [sym__lowercase_identifier] = ACTIONS(355),
    [anon_sym_let] = ACTIONS(357),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_DOT] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_fun] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_if] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(375),
    [anon_sym_function] = ACTIONS(377),
    [anon_sym_try] = ACTIONS(379),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3107),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3109),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(401),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [397] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8306),
    [sym__sequence_expression] = STATE(8215),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_refutation_case] = STATE(8215),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(397),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_DOT] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [398] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17262),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(398),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(1276),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [399] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16973),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(399),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(1461),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [400] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(19805),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(400),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1212),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [401] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16666),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(401),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(1193),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [402] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12672),
    [sym__sequence_expression] = STATE(16667),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(402),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__attribute] = STATE(1281),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [403] = {
    [sym_value_definition] = STATE(19239),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9434),
    [sym__sequence_expression] = STATE(8104),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4721),
    [sym_array_get_expression] = STATE(4721),
    [sym_string_get_expression] = STATE(4721),
    [sym_bigarray_get_expression] = STATE(4721),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_refutation_case] = STATE(8104),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(403),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(1935),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(19132),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_DOT] = ACTIONS(3071),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(927),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(931),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(937),
    [anon_sym_function] = ACTIONS(939),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(967),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [404] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(11902),
    [sym__sequence_expression] = STATE(10605),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_refutation_case] = STATE(10605),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(404),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_DOT] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [405] = {
    [sym_value_definition] = STATE(17729),
    [sym__simple_expression] = STATE(2474),
    [sym__expression] = STATE(11972),
    [sym__sequence_expression] = STATE(10458),
    [sym_typed_expression] = STATE(6258),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6258),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6258),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6104),
    [sym_array_get_expression] = STATE(6104),
    [sym_string_get_expression] = STATE(6104),
    [sym_bigarray_get_expression] = STATE(6104),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_refutation_case] = STATE(10458),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6258),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(405),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym_sign_operator] = STATE(1847),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__instance_variable_name] = STATE(17706),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [sym__lowercase_identifier] = ACTIONS(2465),
    [anon_sym_let] = ACTIONS(2467),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_DOT] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_fun] = ACTIONS(2479),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_if] = ACTIONS(2483),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2485),
    [anon_sym_function] = ACTIONS(2487),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2511),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [406] = {
    [sym_value_definition] = STATE(17729),
    [sym__simple_expression] = STATE(2474),
    [sym__expression] = STATE(11972),
    [sym__sequence_expression] = STATE(10605),
    [sym_typed_expression] = STATE(6258),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6258),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6258),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6104),
    [sym_array_get_expression] = STATE(6104),
    [sym_string_get_expression] = STATE(6104),
    [sym_bigarray_get_expression] = STATE(6104),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_refutation_case] = STATE(10605),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6258),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(406),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym_sign_operator] = STATE(1847),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__instance_variable_name] = STATE(17706),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [sym__lowercase_identifier] = ACTIONS(2465),
    [anon_sym_let] = ACTIONS(2467),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_DOT] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_fun] = ACTIONS(2479),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_if] = ACTIONS(2483),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2485),
    [anon_sym_function] = ACTIONS(2487),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2511),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [407] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(11902),
    [sym__sequence_expression] = STATE(10458),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_refutation_case] = STATE(10458),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(407),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_DOT] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [408] = {
    [sym_value_definition] = STATE(18797),
    [sym__simple_expression] = STATE(1527),
    [sym__expression] = STATE(8505),
    [sym__sequence_expression] = STATE(8215),
    [sym_typed_expression] = STATE(4161),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4161),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4161),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3909),
    [sym_array_get_expression] = STATE(3909),
    [sym_string_get_expression] = STATE(3909),
    [sym_bigarray_get_expression] = STATE(3909),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_refutation_case] = STATE(8215),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4161),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(408),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym_sign_operator] = STATE(2091),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__instance_variable_name] = STATE(18811),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [sym__lowercase_identifier] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_DOT] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_fun] = ACTIONS(819),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_if] = ACTIONS(823),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(825),
    [anon_sym_function] = ACTIONS(827),
    [anon_sym_try] = ACTIONS(829),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3115),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3117),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(851),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [409] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18945),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(409),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1255),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [410] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(19815),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(410),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1213),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [411] = {
    [sym_value_definition] = STATE(18797),
    [sym__simple_expression] = STATE(1527),
    [sym__expression] = STATE(8505),
    [sym__sequence_expression] = STATE(8176),
    [sym_typed_expression] = STATE(4161),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4161),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4161),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3909),
    [sym_array_get_expression] = STATE(3909),
    [sym_string_get_expression] = STATE(3909),
    [sym_bigarray_get_expression] = STATE(3909),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_refutation_case] = STATE(8176),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4161),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(411),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym_sign_operator] = STATE(2091),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__instance_variable_name] = STATE(18811),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [sym__lowercase_identifier] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_DOT] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_fun] = ACTIONS(819),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_if] = ACTIONS(823),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(825),
    [anon_sym_function] = ACTIONS(827),
    [anon_sym_try] = ACTIONS(829),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3115),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3117),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(851),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [412] = {
    [sym_value_definition] = STATE(18034),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12470),
    [sym__sequence_expression] = STATE(8104),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6443),
    [sym_array_get_expression] = STATE(6443),
    [sym_string_get_expression] = STATE(6443),
    [sym_bigarray_get_expression] = STATE(6443),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_refutation_case] = STATE(8104),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(412),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2397),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(18043),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2693),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_DOT] = ACTIONS(3071),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2705),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2709),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2711),
    [anon_sym_function] = ACTIONS(2713),
    [anon_sym_try] = ACTIONS(2715),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2737),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [413] = {
    [sym_value_definition] = STATE(18034),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12470),
    [sym__sequence_expression] = STATE(8217),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6443),
    [sym_array_get_expression] = STATE(6443),
    [sym_string_get_expression] = STATE(6443),
    [sym_bigarray_get_expression] = STATE(6443),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_refutation_case] = STATE(8217),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(413),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2397),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(18043),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2693),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_DOT] = ACTIONS(3071),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2705),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2709),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2711),
    [anon_sym_function] = ACTIONS(2713),
    [anon_sym_try] = ACTIONS(2715),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2737),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [414] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17847),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(414),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(828),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [415] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17848),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(415),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(827),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [416] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18946),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(416),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1274),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [417] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16754),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(417),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(1170),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [418] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17495),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(418),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(1064),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [419] = {
    [sym_value_definition] = STATE(19239),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9434),
    [sym__sequence_expression] = STATE(8217),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4721),
    [sym_array_get_expression] = STATE(4721),
    [sym_string_get_expression] = STATE(4721),
    [sym_bigarray_get_expression] = STATE(4721),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_refutation_case] = STATE(8217),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(419),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(1935),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(19132),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_DOT] = ACTIONS(3071),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(927),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(931),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(937),
    [anon_sym_function] = ACTIONS(939),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(967),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [420] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17901),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(420),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(820),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [421] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17902),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(421),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(818),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [422] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18761),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(422),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1106),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [423] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17955),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(423),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(812),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [424] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17956),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(424),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(810),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [425] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16520),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(425),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(1119),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [426] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17393),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(426),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(1321),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [427] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18009),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(427),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(801),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [428] = {
    [sym_value_definition] = STATE(18662),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(11961),
    [sym__sequence_expression] = STATE(8217),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6146),
    [sym_array_get_expression] = STATE(6146),
    [sym_string_get_expression] = STATE(6146),
    [sym_bigarray_get_expression] = STATE(6146),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_refutation_case] = STATE(8217),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(428),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(2139),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18398),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_DOT] = ACTIONS(3071),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [429] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18010),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(429),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(799),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [430] = {
    [sym_value_definition] = STATE(18662),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(11961),
    [sym__sequence_expression] = STATE(8104),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6146),
    [sym_array_get_expression] = STATE(6146),
    [sym_string_get_expression] = STATE(6146),
    [sym_bigarray_get_expression] = STATE(6146),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_refutation_case] = STATE(8104),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(430),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(2139),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18398),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_DOT] = ACTIONS(3071),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [431] = {
    [sym_value_definition] = STATE(18030),
    [sym__simple_expression] = STATE(301),
    [sym__expression] = STATE(8264),
    [sym__sequence_expression] = STATE(8176),
    [sym_typed_expression] = STATE(3052),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3052),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3052),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2963),
    [sym_array_get_expression] = STATE(2963),
    [sym_string_get_expression] = STATE(2963),
    [sym_bigarray_get_expression] = STATE(2963),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_refutation_case] = STATE(8176),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3052),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(431),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym_sign_operator] = STATE(1958),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__instance_variable_name] = STATE(18008),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [sym__lowercase_identifier] = ACTIONS(295),
    [anon_sym_let] = ACTIONS(299),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_DOT] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_fun] = ACTIONS(313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_if] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(319),
    [anon_sym_function] = ACTIONS(321),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3119),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3121),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(349),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [432] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18980),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(432),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1000),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [433] = {
    [sym_value_definition] = STATE(18030),
    [sym__simple_expression] = STATE(301),
    [sym__expression] = STATE(8264),
    [sym__sequence_expression] = STATE(8215),
    [sym_typed_expression] = STATE(3052),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3052),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3052),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2963),
    [sym_array_get_expression] = STATE(2963),
    [sym_string_get_expression] = STATE(2963),
    [sym_bigarray_get_expression] = STATE(2963),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_refutation_case] = STATE(8215),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3052),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(433),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym_sign_operator] = STATE(1958),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__instance_variable_name] = STATE(18008),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [sym__lowercase_identifier] = ACTIONS(295),
    [anon_sym_let] = ACTIONS(299),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_DOT] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_fun] = ACTIONS(313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_if] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(319),
    [anon_sym_function] = ACTIONS(321),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3119),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3121),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(349),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [434] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18981),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(434),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1484),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [435] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16514),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(435),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(949),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [436] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18063),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(436),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(780),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [437] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18064),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(437),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(778),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [438] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17295),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(438),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(1501),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [439] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20393),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(439),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1273),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [440] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16860),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(440),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(1194),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [441] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12672),
    [sym__sequence_expression] = STATE(16708),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(441),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__attribute] = STATE(1251),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [442] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16519),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(442),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(720),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [443] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18117),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(443),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(760),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [444] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18118),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(444),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(759),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [445] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(445),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1280),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [446] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16571),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(446),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(1252),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [447] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18449),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(447),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(590),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [448] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16915),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(448),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(1325),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [449] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18167),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(449),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(748),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [450] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12276),
    [sym__sequence_expression] = STATE(10605),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_refutation_case] = STATE(10605),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(450),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_DOT] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [451] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18168),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(451),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(744),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [452] = {
    [sym_value_definition] = STATE(18535),
    [sym__simple_expression] = STATE(2430),
    [sym__expression] = STATE(10576),
    [sym__sequence_expression] = STATE(8104),
    [sym_typed_expression] = STATE(5411),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5411),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5411),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(5160),
    [sym_array_get_expression] = STATE(5160),
    [sym_string_get_expression] = STATE(5160),
    [sym_bigarray_get_expression] = STATE(5160),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_refutation_case] = STATE(8104),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5411),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(452),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym_sign_operator] = STATE(1986),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__instance_variable_name] = STATE(18550),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [sym__lowercase_identifier] = ACTIONS(1171),
    [anon_sym_let] = ACTIONS(1173),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_LBRACK] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_DOT] = ACTIONS(3071),
    [anon_sym_LBRACE] = ACTIONS(1181),
    [anon_sym_object] = ACTIONS(1183),
    [anon_sym_fun] = ACTIONS(1185),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1187),
    [anon_sym_if] = ACTIONS(1189),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1191),
    [anon_sym_function] = ACTIONS(1193),
    [anon_sym_try] = ACTIONS(1195),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1197),
    [anon_sym_LBRACE_LT] = ACTIONS(1199),
    [anon_sym_begin] = ACTIONS(1201),
    [sym_ocamlyacc_value] = ACTIONS(1203),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1205),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1207),
    [aux_sym_number_token1] = ACTIONS(1209),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_prefix_operator] = ACTIONS(1215),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1217),
    [sym__uppercase_identifier] = ACTIONS(1219),
    [aux_sym_tag_token1] = ACTIONS(1221),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [453] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17475),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(453),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(552),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [454] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18448),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(454),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(598),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [455] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17327),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(455),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(1433),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [456] = {
    [sym_value_definition] = STATE(18705),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(11969),
    [sym__sequence_expression] = STATE(8217),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6123),
    [sym_array_get_expression] = STATE(6123),
    [sym_string_get_expression] = STATE(6123),
    [sym_bigarray_get_expression] = STATE(6123),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_refutation_case] = STATE(8217),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(456),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2250),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18531),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2355),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_DOT] = ACTIONS(3071),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2367),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2373),
    [anon_sym_function] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2399),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [457] = {
    [sym_value_definition] = STATE(18705),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(11969),
    [sym__sequence_expression] = STATE(8104),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6123),
    [sym_array_get_expression] = STATE(6123),
    [sym_string_get_expression] = STATE(6123),
    [sym_bigarray_get_expression] = STATE(6123),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_refutation_case] = STATE(8104),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(457),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2250),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18531),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2355),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_DOT] = ACTIONS(3071),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2367),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2373),
    [anon_sym_function] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2399),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [458] = {
    [sym_value_definition] = STATE(19080),
    [sym__simple_expression] = STATE(506),
    [sym__expression] = STATE(8293),
    [sym__sequence_expression] = STATE(8176),
    [sym_typed_expression] = STATE(3532),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3532),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3532),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3084),
    [sym_array_get_expression] = STATE(3084),
    [sym_string_get_expression] = STATE(3084),
    [sym_bigarray_get_expression] = STATE(3084),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_refutation_case] = STATE(8176),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3532),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(458),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym_sign_operator] = STATE(2274),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__instance_variable_name] = STATE(18842),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [sym__lowercase_identifier] = ACTIONS(475),
    [anon_sym_let] = ACTIONS(477),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_DOT] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_fun] = ACTIONS(489),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(495),
    [anon_sym_function] = ACTIONS(497),
    [anon_sym_try] = ACTIONS(499),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3123),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3125),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(521),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [459] = {
    [sym_value_definition] = STATE(19080),
    [sym__simple_expression] = STATE(506),
    [sym__expression] = STATE(8293),
    [sym__sequence_expression] = STATE(8215),
    [sym_typed_expression] = STATE(3532),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3532),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3532),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3084),
    [sym_array_get_expression] = STATE(3084),
    [sym_string_get_expression] = STATE(3084),
    [sym_bigarray_get_expression] = STATE(3084),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_refutation_case] = STATE(8215),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3532),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(459),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym_sign_operator] = STATE(2274),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__instance_variable_name] = STATE(18842),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [sym__lowercase_identifier] = ACTIONS(475),
    [anon_sym_let] = ACTIONS(477),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_DOT] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_fun] = ACTIONS(489),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(495),
    [anon_sym_function] = ACTIONS(497),
    [anon_sym_try] = ACTIONS(499),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3123),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3125),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(521),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [460] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17368),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(460),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(1369),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [461] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18208),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(461),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(735),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [462] = {
    [sym_value_definition] = STATE(18990),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12014),
    [sym__sequence_expression] = STATE(8104),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6117),
    [sym_array_get_expression] = STATE(6117),
    [sym_string_get_expression] = STATE(6117),
    [sym_bigarray_get_expression] = STATE(6117),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_refutation_case] = STATE(8104),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(462),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2049),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(18809),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2519),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_DOT] = ACTIONS(3071),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2531),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2535),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2537),
    [anon_sym_function] = ACTIONS(2539),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2563),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [463] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18209),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(463),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(733),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [464] = {
    [sym_value_definition] = STATE(18990),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12014),
    [sym__sequence_expression] = STATE(8217),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6117),
    [sym_array_get_expression] = STATE(6117),
    [sym_string_get_expression] = STATE(6117),
    [sym_bigarray_get_expression] = STATE(6117),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_refutation_case] = STATE(8217),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(464),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2049),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(18809),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2519),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_DOT] = ACTIONS(3071),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2531),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2535),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2537),
    [anon_sym_function] = ACTIONS(2539),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2563),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [465] = {
    [sym_value_definition] = STATE(18535),
    [sym__simple_expression] = STATE(2430),
    [sym__expression] = STATE(10576),
    [sym__sequence_expression] = STATE(8217),
    [sym_typed_expression] = STATE(5411),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5411),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5411),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(5160),
    [sym_array_get_expression] = STATE(5160),
    [sym_string_get_expression] = STATE(5160),
    [sym_bigarray_get_expression] = STATE(5160),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_refutation_case] = STATE(8217),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5411),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(465),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym_sign_operator] = STATE(1986),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__instance_variable_name] = STATE(18550),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [sym__lowercase_identifier] = ACTIONS(1171),
    [anon_sym_let] = ACTIONS(1173),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_LBRACK] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_DOT] = ACTIONS(3071),
    [anon_sym_LBRACE] = ACTIONS(1181),
    [anon_sym_object] = ACTIONS(1183),
    [anon_sym_fun] = ACTIONS(1185),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1187),
    [anon_sym_if] = ACTIONS(1189),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1191),
    [anon_sym_function] = ACTIONS(1193),
    [anon_sym_try] = ACTIONS(1195),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1197),
    [anon_sym_LBRACE_LT] = ACTIONS(1199),
    [anon_sym_begin] = ACTIONS(1201),
    [sym_ocamlyacc_value] = ACTIONS(1203),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1205),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1207),
    [aux_sym_number_token1] = ACTIONS(1209),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_prefix_operator] = ACTIONS(1215),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1217),
    [sym__uppercase_identifier] = ACTIONS(1219),
    [aux_sym_tag_token1] = ACTIONS(1221),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [466] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18409),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(466),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(610),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [467] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16790),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(467),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(919),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [468] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18248),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(468),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(664),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [469] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18408),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(469),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(616),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [470] = {
    [sym_value_definition] = STATE(19586),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8712),
    [sym__sequence_expression] = STATE(8176),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_refutation_case] = STATE(8176),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(470),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_DOT] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [471] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18369),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(471),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(627),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [472] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20414),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(472),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1392),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [473] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20411),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(473),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(1393),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [474] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18368),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(474),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(628),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [475] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18329),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(475),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(635),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [476] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18249),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(476),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(661),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [477] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12276),
    [sym__sequence_expression] = STATE(10458),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_refutation_case] = STATE(10458),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(477),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_DOT] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [478] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16567),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(478),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(1277),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [479] = {
    [sym_value_definition] = STATE(18821),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12001),
    [sym__sequence_expression] = STATE(8217),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6118),
    [sym_array_get_expression] = STATE(6118),
    [sym_string_get_expression] = STATE(6118),
    [sym_bigarray_get_expression] = STATE(6118),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_refutation_case] = STATE(8217),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(479),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(2170),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18670),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2415),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_DOT] = ACTIONS(3071),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2433),
    [anon_sym_function] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2437),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2459),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [480] = {
    [sym_value_definition] = STATE(18821),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12001),
    [sym__sequence_expression] = STATE(8104),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6118),
    [sym_array_get_expression] = STATE(6118),
    [sym_string_get_expression] = STATE(6118),
    [sym_bigarray_get_expression] = STATE(6118),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_refutation_case] = STATE(8104),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(480),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(2170),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18670),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2415),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_DOT] = ACTIONS(3071),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2433),
    [anon_sym_function] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2437),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2459),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [481] = {
    [sym_value_definition] = STATE(19151),
    [sym__simple_expression] = STATE(549),
    [sym__expression] = STATE(8333),
    [sym__sequence_expression] = STATE(8176),
    [sym_typed_expression] = STATE(3704),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3704),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3704),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3058),
    [sym_array_get_expression] = STATE(3058),
    [sym_string_get_expression] = STATE(3058),
    [sym_bigarray_get_expression] = STATE(3058),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_refutation_case] = STATE(8176),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3704),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(481),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym_sign_operator] = STATE(1807),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__instance_variable_name] = STATE(19067),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [sym__lowercase_identifier] = ACTIONS(527),
    [anon_sym_let] = ACTIONS(529),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_DOT] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_fun] = ACTIONS(541),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(545),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(547),
    [anon_sym_function] = ACTIONS(549),
    [anon_sym_try] = ACTIONS(551),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3129),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(573),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [482] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18328),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(482),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(636),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [483] = {
    [sym_value_definition] = STATE(18295),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11460),
    [sym__sequence_expression] = STATE(10458),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5598),
    [sym_array_get_expression] = STATE(5598),
    [sym_string_get_expression] = STATE(5598),
    [sym_bigarray_get_expression] = STATE(5598),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_refutation_case] = STATE(10458),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(483),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(1999),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(20495),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_DOT] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1351),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1355),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [484] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17420),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(484),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(1263),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [485] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16890),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(485),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(1257),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [486] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17454),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(486),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(1208),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [487] = {
    [sym_value_definition] = STATE(18295),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11460),
    [sym__sequence_expression] = STATE(10605),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5598),
    [sym_array_get_expression] = STATE(5598),
    [sym_string_get_expression] = STATE(5598),
    [sym_bigarray_get_expression] = STATE(5598),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_refutation_case] = STATE(10605),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(487),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(1999),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(20495),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_DOT] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1351),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1355),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [488] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8299),
    [sym__sequence_expression] = STATE(8215),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_refutation_case] = STATE(8215),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(488),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_DOT] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [489] = {
    [sym_value_definition] = STATE(19151),
    [sym__simple_expression] = STATE(549),
    [sym__expression] = STATE(8333),
    [sym__sequence_expression] = STATE(8215),
    [sym_typed_expression] = STATE(3704),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3704),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3704),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3058),
    [sym_array_get_expression] = STATE(3058),
    [sym_string_get_expression] = STATE(3058),
    [sym_bigarray_get_expression] = STATE(3058),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_refutation_case] = STATE(8215),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3704),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(489),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym_sign_operator] = STATE(1807),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__instance_variable_name] = STATE(19067),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [sym__lowercase_identifier] = ACTIONS(527),
    [anon_sym_let] = ACTIONS(529),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_DOT] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_fun] = ACTIONS(541),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(545),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(547),
    [anon_sym_function] = ACTIONS(549),
    [anon_sym_try] = ACTIONS(551),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3129),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(573),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [490] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20436),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(490),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(954),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [491] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8299),
    [sym__sequence_expression] = STATE(8176),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_refutation_case] = STATE(8176),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(491),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_DOT] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [492] = {
    [sym_value_definition] = STATE(18188),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12346),
    [sym__sequence_expression] = STATE(8104),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6417),
    [sym_array_get_expression] = STATE(6417),
    [sym_string_get_expression] = STATE(6417),
    [sym_bigarray_get_expression] = STATE(6417),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_refutation_case] = STATE(8104),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(492),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(18201),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2745),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_DOT] = ACTIONS(3071),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2761),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2763),
    [anon_sym_function] = ACTIONS(2765),
    [anon_sym_try] = ACTIONS(2767),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2789),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [493] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20437),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(493),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(971),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [494] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12672),
    [sym__sequence_expression] = STATE(16559),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(494),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__attribute] = STATE(978),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [495] = {
    [sym_value_definition] = STATE(18188),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12346),
    [sym__sequence_expression] = STATE(8217),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6417),
    [sym_array_get_expression] = STATE(6417),
    [sym_string_get_expression] = STATE(6417),
    [sym_bigarray_get_expression] = STATE(6417),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_refutation_case] = STATE(8217),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(495),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(18201),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2745),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_DOT] = ACTIONS(3071),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2761),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2763),
    [anon_sym_function] = ACTIONS(2765),
    [anon_sym_try] = ACTIONS(2767),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2789),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [496] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18288),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(496),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(643),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [497] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16557),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(497),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__attribute] = STATE(984),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [498] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18289),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(498),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__attribute] = STATE(641),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [anon_sym_PERCENT] = ACTIONS(1275),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [499] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(499),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3135),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [500] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(500),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3137),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [501] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(501),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3139),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [502] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(502),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3141),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [503] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(503),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3143),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [504] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12674),
    [sym__sequence_expression] = STATE(20279),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(504),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_done] = ACTIONS(3145),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [505] = {
    [sym__simple_expression] = STATE(3427),
    [sym_typed_expression] = STATE(3727),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_labeled_argument] = STATE(4280),
    [sym_prefix_expression] = STATE(3727),
    [sym_hash_expression] = STATE(3727),
    [sym_field_get_expression] = STATE(3727),
    [sym_array_get_expression] = STATE(3727),
    [sym_string_get_expression] = STATE(3727),
    [sym_bigarray_get_expression] = STATE(3727),
    [sym_coercion_expression] = STATE(3727),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(505),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [aux_sym_class_application_repeat1] = STATE(2118),
    [sym__lowercase_identifier] = ACTIONS(3147),
    [anon_sym_SEMI_SEMI] = ACTIONS(3051),
    [anon_sym_let] = ACTIONS(3053),
    [anon_sym_and] = ACTIONS(3053),
    [anon_sym_TILDE] = ACTIONS(3149),
    [anon_sym_QMARK] = ACTIONS(3149),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_external] = ACTIONS(3053),
    [anon_sym_type] = ACTIONS(3053),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_DOT] = ACTIONS(3151),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_SEMI] = ACTIONS(3053),
    [anon_sym_exception] = ACTIONS(3053),
    [anon_sym_module] = ACTIONS(3053),
    [anon_sym_open] = ACTIONS(3053),
    [anon_sym_include] = ACTIONS(3053),
    [anon_sym_class] = ACTIONS(3053),
    [anon_sym_end] = ACTIONS(3053),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_in] = ACTIONS(3053),
    [anon_sym_POUND] = ACTIONS(3153),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3053),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3051),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(667),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(669),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3051),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(3155),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym_let_operator] = ACTIONS(3051),
    [sym_let_and_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_directive_token1] = ACTIONS(3053),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [506] = {
    [sym__simple_expression] = STATE(3605),
    [sym_typed_expression] = STATE(3532),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_labeled_argument] = STATE(4220),
    [sym_prefix_expression] = STATE(3532),
    [sym_hash_expression] = STATE(3532),
    [sym_field_get_expression] = STATE(3532),
    [sym_array_get_expression] = STATE(3532),
    [sym_string_get_expression] = STATE(3532),
    [sym_bigarray_get_expression] = STATE(3532),
    [sym_coercion_expression] = STATE(3532),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(506),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [aux_sym_class_application_repeat1] = STATE(1793),
    [sym__lowercase_identifier] = ACTIONS(3157),
    [anon_sym_SEMI_SEMI] = ACTIONS(3051),
    [anon_sym_let] = ACTIONS(3053),
    [anon_sym_and] = ACTIONS(3053),
    [anon_sym_TILDE] = ACTIONS(3159),
    [anon_sym_QMARK] = ACTIONS(3159),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_external] = ACTIONS(3053),
    [anon_sym_type] = ACTIONS(3053),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_RBRACK] = ACTIONS(3051),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_DOT] = ACTIONS(3161),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_SEMI] = ACTIONS(3053),
    [anon_sym_exception] = ACTIONS(3053),
    [anon_sym_module] = ACTIONS(3053),
    [anon_sym_open] = ACTIONS(3053),
    [anon_sym_include] = ACTIONS(3053),
    [anon_sym_class] = ACTIONS(3053),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_POUND] = ACTIONS(3163),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_else] = ACTIONS(3053),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3053),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3051),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(509),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(511),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3051),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(3165),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym_let_operator] = ACTIONS(3051),
    [sym_let_and_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_directive_token1] = ACTIONS(3053),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [507] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(507),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3167),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [508] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(508),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3169),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [509] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(509),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3171),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [510] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(510),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3173),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [511] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(511),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3175),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [512] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(512),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3177),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [513] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(513),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3179),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [514] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12674),
    [sym__sequence_expression] = STATE(19788),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(514),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_done] = ACTIONS(3181),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [515] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(515),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3183),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [516] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(516),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3185),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [517] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(517),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3187),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [518] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(518),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3189),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [519] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(519),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3191),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [520] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(520),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [521] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(521),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3195),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [522] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(522),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3197),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [523] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(523),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3199),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [524] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(524),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3201),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [525] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(525),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3203),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [526] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(526),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3205),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [527] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(527),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3207),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [528] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(528),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3209),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [529] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(529),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3211),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [530] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(530),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3213),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [531] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(531),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3215),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [532] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(532),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3217),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [533] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(533),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3219),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [534] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(534),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3221),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [535] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(535),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3223),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [536] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(536),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3225),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [537] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12674),
    [sym__sequence_expression] = STATE(19922),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(537),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_done] = ACTIONS(3227),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [538] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(538),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3229),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [539] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(539),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3231),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [540] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(540),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3233),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [541] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(541),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3235),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [542] = {
    [sym__simple_expression] = STATE(3334),
    [sym_typed_expression] = STATE(3461),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_labeled_argument] = STATE(4439),
    [sym_prefix_expression] = STATE(3461),
    [sym_hash_expression] = STATE(3461),
    [sym_field_get_expression] = STATE(3461),
    [sym_array_get_expression] = STATE(3461),
    [sym_string_get_expression] = STATE(3461),
    [sym_bigarray_get_expression] = STATE(3461),
    [sym_coercion_expression] = STATE(3461),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(542),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [aux_sym_class_application_repeat1] = STATE(2318),
    [sym__lowercase_identifier] = ACTIONS(3237),
    [anon_sym_SEMI_SEMI] = ACTIONS(3051),
    [anon_sym_let] = ACTIONS(3053),
    [anon_sym_and] = ACTIONS(3053),
    [anon_sym_TILDE] = ACTIONS(3239),
    [anon_sym_QMARK] = ACTIONS(3239),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_external] = ACTIONS(3053),
    [anon_sym_type] = ACTIONS(3053),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_RBRACK] = ACTIONS(3051),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_DOT] = ACTIONS(3241),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_SEMI] = ACTIONS(3053),
    [anon_sym_exception] = ACTIONS(3053),
    [anon_sym_module] = ACTIONS(3053),
    [anon_sym_open] = ACTIONS(3053),
    [anon_sym_include] = ACTIONS(3053),
    [anon_sym_class] = ACTIONS(3053),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_in] = ACTIONS(3053),
    [anon_sym_POUND] = ACTIONS(3243),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3053),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3051),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(613),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(615),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3051),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(3245),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym_let_operator] = ACTIONS(3051),
    [sym_let_and_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_directive_token1] = ACTIONS(3053),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [543] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12674),
    [sym__sequence_expression] = STATE(20054),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(543),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_done] = ACTIONS(3247),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [544] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(544),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3249),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [545] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(545),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3251),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [546] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(546),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3253),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [547] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(547),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3255),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [548] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(548),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3257),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [549] = {
    [sym__simple_expression] = STATE(3675),
    [sym_typed_expression] = STATE(3704),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_labeled_argument] = STATE(4252),
    [sym_prefix_expression] = STATE(3704),
    [sym_hash_expression] = STATE(3704),
    [sym_field_get_expression] = STATE(3704),
    [sym_array_get_expression] = STATE(3704),
    [sym_string_get_expression] = STATE(3704),
    [sym_bigarray_get_expression] = STATE(3704),
    [sym_coercion_expression] = STATE(3704),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(549),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [aux_sym_class_application_repeat1] = STATE(1815),
    [sym__lowercase_identifier] = ACTIONS(3259),
    [anon_sym_SEMI_SEMI] = ACTIONS(3051),
    [anon_sym_let] = ACTIONS(3053),
    [anon_sym_and] = ACTIONS(3053),
    [anon_sym_TILDE] = ACTIONS(3261),
    [anon_sym_QMARK] = ACTIONS(3261),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_external] = ACTIONS(3053),
    [anon_sym_type] = ACTIONS(3053),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_DOT] = ACTIONS(3263),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_SEMI] = ACTIONS(3053),
    [anon_sym_exception] = ACTIONS(3053),
    [anon_sym_module] = ACTIONS(3053),
    [anon_sym_open] = ACTIONS(3053),
    [anon_sym_include] = ACTIONS(3053),
    [anon_sym_class] = ACTIONS(3053),
    [anon_sym_end] = ACTIONS(3053),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_POUND] = ACTIONS(3265),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_else] = ACTIONS(3053),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3053),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3051),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(561),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(563),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3051),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(3267),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym_let_operator] = ACTIONS(3051),
    [sym_let_and_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_directive_token1] = ACTIONS(3053),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [550] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(550),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3269),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [551] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17075),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(551),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [552] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17469),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(552),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [553] = {
    [sym_value_definition] = STATE(19480),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8574),
    [sym__sequence_expression] = STATE(8203),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(553),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_let] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3095),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3097),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [554] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8387),
    [sym__sequence_expression] = STATE(8185),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(554),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [555] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18538),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(555),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [556] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18537),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(556),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [557] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8387),
    [sym__sequence_expression] = STATE(8188),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(557),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [558] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16868),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(558),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [559] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16697),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(559),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [560] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19450),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(560),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [561] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12712),
    [sym__sequence_expression] = STATE(8017),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(561),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [562] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18478),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(562),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [563] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18486),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(563),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [564] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18496),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(564),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [565] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19440),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(565),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [566] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19439),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(566),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [567] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19438),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(567),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [568] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18528),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(568),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [569] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17155),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(569),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [570] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18509),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(570),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [571] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18512),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(571),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [572] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18517),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(572),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [573] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8387),
    [sym__sequence_expression] = STATE(8127),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(573),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [574] = {
    [sym__simple_expression] = STATE(3797),
    [sym_typed_expression] = STATE(3838),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_labeled_argument] = STATE(4506),
    [sym_prefix_expression] = STATE(3838),
    [sym_hash_expression] = STATE(3838),
    [sym_field_get_expression] = STATE(3838),
    [sym_array_get_expression] = STATE(3838),
    [sym_string_get_expression] = STATE(3838),
    [sym_bigarray_get_expression] = STATE(3838),
    [sym_coercion_expression] = STATE(3838),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(574),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [aux_sym_class_application_repeat1] = STATE(2413),
    [sym__lowercase_identifier] = ACTIONS(3271),
    [anon_sym_SEMI_SEMI] = ACTIONS(3051),
    [anon_sym_let] = ACTIONS(3053),
    [anon_sym_and] = ACTIONS(3053),
    [anon_sym_TILDE] = ACTIONS(3273),
    [anon_sym_QMARK] = ACTIONS(3273),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_external] = ACTIONS(3053),
    [anon_sym_type] = ACTIONS(3053),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_DOT] = ACTIONS(3275),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_SEMI] = ACTIONS(3053),
    [anon_sym_exception] = ACTIONS(3053),
    [anon_sym_module] = ACTIONS(3053),
    [anon_sym_open] = ACTIONS(3053),
    [anon_sym_include] = ACTIONS(3053),
    [anon_sym_class] = ACTIONS(3053),
    [anon_sym_end] = ACTIONS(3053),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_POUND] = ACTIONS(3277),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3053),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3051),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(787),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(789),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3051),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(3279),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym_let_operator] = ACTIONS(3051),
    [sym_let_and_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_directive_token1] = ACTIONS(3053),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [575] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18498),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(575),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [576] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18497),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(576),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [577] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8387),
    [sym__sequence_expression] = STATE(5419),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(577),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [578] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18488),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(578),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [579] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11900),
    [sym__sequence_expression] = STATE(8757),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(579),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [580] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19425),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(580),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [581] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19424),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(581),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [582] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19423),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(582),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [583] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18578),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(583),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [584] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18577),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(584),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [585] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8387),
    [sym__sequence_expression] = STATE(8116),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(585),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [586] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8534),
    [sym__sequence_expression] = STATE(10551),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(586),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [587] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(5419),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(587),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [588] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18600),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(588),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [589] = {
    [sym_value_definition] = STATE(19385),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11179),
    [sym__sequence_expression] = STATE(10371),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5503),
    [sym_array_get_expression] = STATE(5503),
    [sym_string_get_expression] = STATE(5503),
    [sym_bigarray_get_expression] = STATE(5503),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(589),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(1823),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(20481),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1279),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1291),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1295),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [590] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18458),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(590),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [591] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18568),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(591),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [592] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12712),
    [sym__sequence_expression] = STATE(7951),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(592),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [593] = {
    [sym__simple_expression] = STATE(3859),
    [sym_typed_expression] = STATE(3957),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_labeled_argument] = STATE(4546),
    [sym_prefix_expression] = STATE(3957),
    [sym_hash_expression] = STATE(3957),
    [sym_field_get_expression] = STATE(3957),
    [sym_array_get_expression] = STATE(3957),
    [sym_string_get_expression] = STATE(3957),
    [sym_bigarray_get_expression] = STATE(3957),
    [sym_coercion_expression] = STATE(3957),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(593),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [aux_sym_class_application_repeat1] = STATE(2414),
    [sym__lowercase_identifier] = ACTIONS(3281),
    [anon_sym_SEMI_SEMI] = ACTIONS(3051),
    [anon_sym_let] = ACTIONS(3053),
    [anon_sym_and] = ACTIONS(3053),
    [anon_sym_TILDE] = ACTIONS(3283),
    [anon_sym_QMARK] = ACTIONS(3283),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_external] = ACTIONS(3053),
    [anon_sym_type] = ACTIONS(3053),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_RBRACK] = ACTIONS(3051),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_DOT] = ACTIONS(3285),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_SEMI] = ACTIONS(3053),
    [anon_sym_exception] = ACTIONS(3053),
    [anon_sym_module] = ACTIONS(3053),
    [anon_sym_open] = ACTIONS(3053),
    [anon_sym_include] = ACTIONS(3053),
    [anon_sym_class] = ACTIONS(3053),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_POUND] = ACTIONS(3287),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3053),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3051),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(723),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(725),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3051),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(3289),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym_let_operator] = ACTIONS(3051),
    [sym_let_and_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_directive_token1] = ACTIONS(3053),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [594] = {
    [sym_value_definition] = STATE(19385),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11179),
    [sym__sequence_expression] = STATE(10474),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5503),
    [sym_array_get_expression] = STATE(5503),
    [sym_string_get_expression] = STATE(5503),
    [sym_bigarray_get_expression] = STATE(5503),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(594),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(1823),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(20481),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1279),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1291),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1295),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [595] = {
    [sym_value_definition] = STATE(19385),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11179),
    [sym__sequence_expression] = STATE(10659),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5503),
    [sym_array_get_expression] = STATE(5503),
    [sym_string_get_expression] = STATE(5503),
    [sym_bigarray_get_expression] = STATE(5503),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(595),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(1823),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(20481),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1279),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1291),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1295),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [596] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18383),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(596),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [597] = {
    [sym_value_definition] = STATE(19385),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11179),
    [sym__sequence_expression] = STATE(10678),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5503),
    [sym_array_get_expression] = STATE(5503),
    [sym_string_get_expression] = STATE(5503),
    [sym_bigarray_get_expression] = STATE(5503),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(597),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(1823),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(20481),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1279),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1291),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1295),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [598] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18457),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(598),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [599] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12712),
    [sym__sequence_expression] = STATE(7976),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(599),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [600] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8387),
    [sym__sequence_expression] = STATE(8243),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(600),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [601] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18448),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(601),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [602] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19497),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(602),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [603] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19507),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(603),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [604] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12712),
    [sym__sequence_expression] = STATE(7948),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(604),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [605] = {
    [sym_value_definition] = STATE(19385),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11179),
    [sym__sequence_expression] = STATE(10679),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5503),
    [sym_array_get_expression] = STATE(5503),
    [sym_string_get_expression] = STATE(5503),
    [sym_bigarray_get_expression] = STATE(5503),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(605),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(1823),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(20481),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1279),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1291),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1295),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [606] = {
    [sym_value_definition] = STATE(19385),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11179),
    [sym__sequence_expression] = STATE(10680),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5503),
    [sym_array_get_expression] = STATE(5503),
    [sym_string_get_expression] = STATE(5503),
    [sym_bigarray_get_expression] = STATE(5503),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(606),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(1823),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(20481),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1279),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1291),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1295),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [607] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12712),
    [sym__sequence_expression] = STATE(7947),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(607),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [608] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12712),
    [sym__sequence_expression] = STATE(7937),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(608),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [609] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19515),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(609),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [610] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18418),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(610),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [611] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8534),
    [sym__sequence_expression] = STATE(10630),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(611),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [612] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19518),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(612),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [613] = {
    [sym_value_definition] = STATE(19586),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8712),
    [sym__sequence_expression] = STATE(8244),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(613),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [614] = {
    [sym_value_definition] = STATE(19586),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8712),
    [sym__sequence_expression] = STATE(8243),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(614),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [615] = {
    [sym_value_definition] = STATE(19586),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8712),
    [sym__sequence_expression] = STATE(8127),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(615),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [616] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18417),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(616),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [617] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8410),
    [sym__sequence_expression] = STATE(10551),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(617),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [618] = {
    [sym_value_definition] = STATE(19385),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11179),
    [sym__sequence_expression] = STATE(10565),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5503),
    [sym_array_get_expression] = STATE(5503),
    [sym_string_get_expression] = STATE(5503),
    [sym_bigarray_get_expression] = STATE(5503),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(618),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(1823),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(20481),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1279),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1291),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1295),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [619] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12712),
    [sym__sequence_expression] = STATE(7929),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(619),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [620] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18381),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(620),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [621] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18408),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(621),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [622] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18379),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(622),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [623] = {
    [sym_value_definition] = STATE(18428),
    [sym__simple_expression] = STATE(2428),
    [sym__expression] = STATE(10224),
    [sym__sequence_expression] = STATE(8207),
    [sym_typed_expression] = STATE(5216),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5216),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5216),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4994),
    [sym_array_get_expression] = STATE(4994),
    [sym_string_get_expression] = STATE(4994),
    [sym_bigarray_get_expression] = STATE(4994),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5216),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(623),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym_sign_operator] = STATE(2366),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__instance_variable_name] = STATE(18272),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [sym__lowercase_identifier] = ACTIONS(1061),
    [anon_sym_let] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_fun] = ACTIONS(1075),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_if] = ACTIONS(1079),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1081),
    [anon_sym_function] = ACTIONS(1083),
    [anon_sym_try] = ACTIONS(1085),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1109),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [624] = {
    [sym_value_definition] = STATE(18295),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11460),
    [sym__sequence_expression] = STATE(10565),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5598),
    [sym_array_get_expression] = STATE(5598),
    [sym_string_get_expression] = STATE(5598),
    [sym_bigarray_get_expression] = STATE(5598),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(624),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(1999),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(20495),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1351),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1355),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [625] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19519),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(625),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [626] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16896),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(626),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [627] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18378),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(627),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [628] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18377),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(628),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [629] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18368),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(629),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [630] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18615),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(630),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [631] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18623),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(631),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [632] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8387),
    [sym__sequence_expression] = STATE(8244),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(632),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [633] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8534),
    [sym__sequence_expression] = STATE(10500),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(633),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [634] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19367),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(634),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [635] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18338),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(635),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [636] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18337),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(636),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [637] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18328),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(637),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [638] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8387),
    [sym__sequence_expression] = STATE(8203),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(638),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [639] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(16601),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(639),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [640] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19520),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(640),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [641] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18298),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(641),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [642] = {
    [sym_value_definition] = STATE(18662),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(11961),
    [sym__sequence_expression] = STATE(8271),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6146),
    [sym_array_get_expression] = STATE(6146),
    [sym_string_get_expression] = STATE(6146),
    [sym_bigarray_get_expression] = STATE(6146),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(642),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(2139),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18398),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [643] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18297),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(643),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [644] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8534),
    [sym__sequence_expression] = STATE(10425),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(644),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [645] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19358),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(645),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [646] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18624),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(646),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [647] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18288),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(647),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [648] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19357),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(648),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [649] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19356),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(649),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [650] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18643),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(650),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [651] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18650),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(651),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [652] = {
    [sym_value_definition] = STATE(18662),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(11961),
    [sym__sequence_expression] = STATE(8277),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6146),
    [sym_array_get_expression] = STATE(6146),
    [sym_string_get_expression] = STATE(6146),
    [sym_bigarray_get_expression] = STATE(6146),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(652),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(2139),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18398),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [653] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18658),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(653),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [654] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8389),
    [sym__sequence_expression] = STATE(5419),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(654),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [655] = {
    [sym_value_definition] = STATE(18662),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(11961),
    [sym__sequence_expression] = STATE(8257),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6146),
    [sym_array_get_expression] = STATE(6146),
    [sym_string_get_expression] = STATE(6146),
    [sym_bigarray_get_expression] = STATE(6146),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(655),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(2139),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18398),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [656] = {
    [sym_value_definition] = STATE(18662),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(11961),
    [sym__sequence_expression] = STATE(8220),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6146),
    [sym_array_get_expression] = STATE(6146),
    [sym_string_get_expression] = STATE(6146),
    [sym_bigarray_get_expression] = STATE(6146),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(656),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(2139),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18398),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [657] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19346),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(657),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [658] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19345),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(658),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [659] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19344),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(659),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [660] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8534),
    [sym__sequence_expression] = STATE(10365),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(660),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [661] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18258),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(661),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [662] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18349),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(662),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [663] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18348),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(663),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [664] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18257),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(664),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [665] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19540),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(665),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [666] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19541),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(666),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [667] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12619),
    [sym__sequence_expression] = STATE(8757),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(667),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [668] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19542),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(668),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [669] = {
    [sym_value_definition] = STATE(18362),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12297),
    [sym__sequence_expression] = STATE(8207),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6385),
    [sym_array_get_expression] = STATE(6385),
    [sym_string_get_expression] = STATE(6385),
    [sym_bigarray_get_expression] = STATE(6385),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(669),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2336),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(18374),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [670] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18345),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(670),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [671] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18336),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(671),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [672] = {
    [sym_value_definition] = STATE(18188),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12346),
    [sym__sequence_expression] = STATE(8207),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6417),
    [sym_array_get_expression] = STATE(6417),
    [sym_string_get_expression] = STATE(6417),
    [sym_bigarray_get_expression] = STATE(6417),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(672),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(18201),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2745),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2761),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2763),
    [anon_sym_function] = ACTIONS(2765),
    [anon_sym_try] = ACTIONS(2767),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2789),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [673] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18751),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(673),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [674] = {
    [sym_value_definition] = STATE(19480),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8574),
    [sym__sequence_expression] = STATE(8244),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(674),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_let] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3095),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3097),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [675] = {
    [sym_value_definition] = STATE(18662),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(11961),
    [sym__sequence_expression] = STATE(8219),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6146),
    [sym_array_get_expression] = STATE(6146),
    [sym_string_get_expression] = STATE(6146),
    [sym_bigarray_get_expression] = STATE(6146),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(675),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(2139),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18398),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [676] = {
    [sym_value_definition] = STATE(18662),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(11961),
    [sym__sequence_expression] = STATE(8211),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6146),
    [sym_array_get_expression] = STATE(6146),
    [sym_string_get_expression] = STATE(6146),
    [sym_bigarray_get_expression] = STATE(6146),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(676),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(2139),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18398),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [677] = {
    [sym_value_definition] = STATE(18034),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12470),
    [sym__sequence_expression] = STATE(8207),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6443),
    [sym_array_get_expression] = STATE(6443),
    [sym_string_get_expression] = STATE(6443),
    [sym_bigarray_get_expression] = STATE(6443),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(677),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2397),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(18043),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2693),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2705),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2709),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2711),
    [anon_sym_function] = ACTIONS(2713),
    [anon_sym_try] = ACTIONS(2715),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2737),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [678] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19552),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(678),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [679] = {
    [sym_value_definition] = STATE(17904),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12622),
    [sym__sequence_expression] = STATE(8207),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6329),
    [sym_array_get_expression] = STATE(6329),
    [sym_string_get_expression] = STATE(6329),
    [sym_bigarray_get_expression] = STATE(6329),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(679),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(2362),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(17913),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2601),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2607),
    [anon_sym_function] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2611),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2633),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [680] = {
    [sym_value_definition] = STATE(18662),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(11961),
    [sym__sequence_expression] = STATE(8162),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6146),
    [sym_array_get_expression] = STATE(6146),
    [sym_string_get_expression] = STATE(6146),
    [sym_bigarray_get_expression] = STATE(6146),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(680),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(2139),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18398),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [681] = {
    [sym_value_definition] = STATE(17654),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9605),
    [sym__sequence_expression] = STATE(8207),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4841),
    [sym_array_get_expression] = STATE(4841),
    [sym_string_get_expression] = STATE(4841),
    [sym_bigarray_get_expression] = STATE(4841),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(681),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2276),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(17662),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(997),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1009),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1013),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1015),
    [anon_sym_function] = ACTIONS(1017),
    [anon_sym_try] = ACTIONS(1019),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1041),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [682] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11810),
    [sym__sequence_expression] = STATE(8757),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(682),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [683] = {
    [sym_value_definition] = STATE(18277),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(12620),
    [sym__sequence_expression] = STATE(8017),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6588),
    [sym_array_get_expression] = STATE(6588),
    [sym_string_get_expression] = STATE(6588),
    [sym_bigarray_get_expression] = STATE(6588),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(683),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2201),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18286),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [684] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8452),
    [sym__sequence_expression] = STATE(5419),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(684),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [685] = {
    [sym_value_definition] = STATE(18108),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12418),
    [sym__sequence_expression] = STATE(7929),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6582),
    [sym_array_get_expression] = STATE(6582),
    [sym_string_get_expression] = STATE(6582),
    [sym_bigarray_get_expression] = STATE(6582),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(685),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(1808),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18116),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2579),
    [anon_sym_function] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2583),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2585),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [686] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12682),
    [sym__sequence_expression] = STATE(8017),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(686),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [687] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16835),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(687),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [688] = {
    [sym_value_definition] = STATE(18108),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12418),
    [sym__sequence_expression] = STATE(7937),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6582),
    [sym_array_get_expression] = STATE(6582),
    [sym_string_get_expression] = STATE(6582),
    [sym_bigarray_get_expression] = STATE(6582),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(688),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(1808),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18116),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2579),
    [anon_sym_function] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2583),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2585),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [689] = {
    [sym_value_definition] = STATE(19480),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8574),
    [sym__sequence_expression] = STATE(8243),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(689),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_let] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3095),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3097),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [690] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8389),
    [sym__sequence_expression] = STATE(8185),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(690),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [691] = {
    [sym_value_definition] = STATE(18277),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(12620),
    [sym__sequence_expression] = STATE(7976),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6588),
    [sym_array_get_expression] = STATE(6588),
    [sym_string_get_expression] = STATE(6588),
    [sym_bigarray_get_expression] = STATE(6588),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(691),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2201),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18286),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [692] = {
    [sym_value_definition] = STATE(18108),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12418),
    [sym__sequence_expression] = STATE(7947),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6582),
    [sym_array_get_expression] = STATE(6582),
    [sym_string_get_expression] = STATE(6582),
    [sym_bigarray_get_expression] = STATE(6582),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(692),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(1808),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18116),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2579),
    [anon_sym_function] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2583),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2585),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [693] = {
    [sym_value_definition] = STATE(18108),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12418),
    [sym__sequence_expression] = STATE(7948),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6582),
    [sym_array_get_expression] = STATE(6582),
    [sym_string_get_expression] = STATE(6582),
    [sym_bigarray_get_expression] = STATE(6582),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(693),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(1808),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18116),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2579),
    [anon_sym_function] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2583),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2585),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [694] = {
    [sym_value_definition] = STATE(18108),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12418),
    [sym__sequence_expression] = STATE(7951),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6582),
    [sym_array_get_expression] = STATE(6582),
    [sym_string_get_expression] = STATE(6582),
    [sym_bigarray_get_expression] = STATE(6582),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(694),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(1808),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18116),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2579),
    [anon_sym_function] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2583),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2585),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [695] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16919),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(695),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [696] = {
    [sym_value_definition] = STATE(18108),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12418),
    [sym__sequence_expression] = STATE(7976),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6582),
    [sym_array_get_expression] = STATE(6582),
    [sym_string_get_expression] = STATE(6582),
    [sym_bigarray_get_expression] = STATE(6582),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(696),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(1808),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18116),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2579),
    [anon_sym_function] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2583),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2585),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [697] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19296),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(697),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [698] = {
    [sym_value_definition] = STATE(18108),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12418),
    [sym__sequence_expression] = STATE(8017),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6582),
    [sym_array_get_expression] = STATE(6582),
    [sym_string_get_expression] = STATE(6582),
    [sym_bigarray_get_expression] = STATE(6582),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(698),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(1808),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18116),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2579),
    [anon_sym_function] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2583),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2585),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [699] = {
    [sym_value_definition] = STATE(17611),
    [sym__simple_expression] = STATE(323),
    [sym__expression] = STATE(8239),
    [sym__sequence_expression] = STATE(8203),
    [sym_typed_expression] = STATE(3176),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3176),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3176),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2957),
    [sym_array_get_expression] = STATE(2957),
    [sym_string_get_expression] = STATE(2957),
    [sym_bigarray_get_expression] = STATE(2957),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3176),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(699),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym_sign_operator] = STATE(1905),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__instance_variable_name] = STATE(17621),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [sym__lowercase_identifier] = ACTIONS(355),
    [anon_sym_let] = ACTIONS(357),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_fun] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_if] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(375),
    [anon_sym_function] = ACTIONS(377),
    [anon_sym_try] = ACTIONS(379),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3107),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3109),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(401),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [700] = {
    [sym_value_definition] = STATE(19480),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8574),
    [sym__sequence_expression] = STATE(8127),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(700),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_let] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3095),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3097),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [701] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11810),
    [sym__sequence_expression] = STATE(14051),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(701),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [702] = {
    [sym_value_definition] = STATE(17611),
    [sym__simple_expression] = STATE(323),
    [sym__expression] = STATE(8239),
    [sym__sequence_expression] = STATE(8244),
    [sym_typed_expression] = STATE(3176),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3176),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3176),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2957),
    [sym_array_get_expression] = STATE(2957),
    [sym_string_get_expression] = STATE(2957),
    [sym_bigarray_get_expression] = STATE(2957),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3176),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(702),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym_sign_operator] = STATE(1905),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__instance_variable_name] = STATE(17621),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [sym__lowercase_identifier] = ACTIONS(355),
    [anon_sym_let] = ACTIONS(357),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_fun] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_if] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(375),
    [anon_sym_function] = ACTIONS(377),
    [anon_sym_try] = ACTIONS(379),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3107),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3109),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(401),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [703] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19289),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(703),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [704] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19288),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(704),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [705] = {
    [sym_value_definition] = STATE(17611),
    [sym__simple_expression] = STATE(323),
    [sym__expression] = STATE(8239),
    [sym__sequence_expression] = STATE(8243),
    [sym_typed_expression] = STATE(3176),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3176),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3176),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2957),
    [sym_array_get_expression] = STATE(2957),
    [sym_string_get_expression] = STATE(2957),
    [sym_bigarray_get_expression] = STATE(2957),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3176),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(705),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym_sign_operator] = STATE(1905),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__instance_variable_name] = STATE(17621),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [sym__lowercase_identifier] = ACTIONS(355),
    [anon_sym_let] = ACTIONS(357),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_fun] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_if] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(375),
    [anon_sym_function] = ACTIONS(377),
    [anon_sym_try] = ACTIONS(379),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3107),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3109),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(401),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [706] = {
    [sym_value_definition] = STATE(17611),
    [sym__simple_expression] = STATE(323),
    [sym__expression] = STATE(8239),
    [sym__sequence_expression] = STATE(8127),
    [sym_typed_expression] = STATE(3176),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3176),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3176),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2957),
    [sym_array_get_expression] = STATE(2957),
    [sym_string_get_expression] = STATE(2957),
    [sym_bigarray_get_expression] = STATE(2957),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3176),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(706),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym_sign_operator] = STATE(1905),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__instance_variable_name] = STATE(17621),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [sym__lowercase_identifier] = ACTIONS(355),
    [anon_sym_let] = ACTIONS(357),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_fun] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_if] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(375),
    [anon_sym_function] = ACTIONS(377),
    [anon_sym_try] = ACTIONS(379),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3107),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3109),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(401),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [707] = {
    [sym_value_definition] = STATE(17611),
    [sym__simple_expression] = STATE(323),
    [sym__expression] = STATE(8239),
    [sym__sequence_expression] = STATE(8116),
    [sym_typed_expression] = STATE(3176),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3176),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3176),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2957),
    [sym_array_get_expression] = STATE(2957),
    [sym_string_get_expression] = STATE(2957),
    [sym_bigarray_get_expression] = STATE(2957),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3176),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(707),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym_sign_operator] = STATE(1905),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__instance_variable_name] = STATE(17621),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [sym__lowercase_identifier] = ACTIONS(355),
    [anon_sym_let] = ACTIONS(357),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_fun] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_if] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(375),
    [anon_sym_function] = ACTIONS(377),
    [anon_sym_try] = ACTIONS(379),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3107),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3109),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(401),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [708] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18766),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(708),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [709] = {
    [sym_value_definition] = STATE(17611),
    [sym__simple_expression] = STATE(323),
    [sym__expression] = STATE(8239),
    [sym__sequence_expression] = STATE(8188),
    [sym_typed_expression] = STATE(3176),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3176),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3176),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2957),
    [sym_array_get_expression] = STATE(2957),
    [sym_string_get_expression] = STATE(2957),
    [sym_bigarray_get_expression] = STATE(2957),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3176),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(709),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym_sign_operator] = STATE(1905),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__instance_variable_name] = STATE(17621),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [sym__lowercase_identifier] = ACTIONS(355),
    [anon_sym_let] = ACTIONS(357),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_fun] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_if] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(375),
    [anon_sym_function] = ACTIONS(377),
    [anon_sym_try] = ACTIONS(379),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3107),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3109),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(401),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [710] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19287),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(710),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [711] = {
    [sym_value_definition] = STATE(19586),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8712),
    [sym__sequence_expression] = STATE(8116),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(711),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [712] = {
    [sym_value_definition] = STATE(17611),
    [sym__simple_expression] = STATE(323),
    [sym__expression] = STATE(8239),
    [sym__sequence_expression] = STATE(8185),
    [sym_typed_expression] = STATE(3176),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3176),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3176),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2957),
    [sym_array_get_expression] = STATE(2957),
    [sym_string_get_expression] = STATE(2957),
    [sym_bigarray_get_expression] = STATE(2957),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3176),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(712),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym_sign_operator] = STATE(1905),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__instance_variable_name] = STATE(17621),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [sym__lowercase_identifier] = ACTIONS(355),
    [anon_sym_let] = ACTIONS(357),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_fun] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_if] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(375),
    [anon_sym_function] = ACTIONS(377),
    [anon_sym_try] = ACTIONS(379),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3107),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3109),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(401),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [713] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18772),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(713),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [714] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18248),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(714),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [715] = {
    [sym_value_definition] = STATE(18277),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(12620),
    [sym__sequence_expression] = STATE(7951),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6588),
    [sym_array_get_expression] = STATE(6588),
    [sym_string_get_expression] = STATE(6588),
    [sym_bigarray_get_expression] = STATE(6588),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(715),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2201),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18286),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [716] = {
    [sym_value_definition] = STATE(17714),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9726),
    [sym__sequence_expression] = STATE(8207),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4836),
    [sym_array_get_expression] = STATE(4836),
    [sym_string_get_expression] = STATE(4836),
    [sym_bigarray_get_expression] = STATE(4836),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(716),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(2151),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(17727),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(973),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(975),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(983),
    [anon_sym_function] = ACTIONS(985),
    [anon_sym_try] = ACTIONS(987),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(993),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [717] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18773),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(717),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [718] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12682),
    [sym__sequence_expression] = STATE(7976),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(718),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [719] = {
    [sym_value_definition] = STATE(18277),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(12620),
    [sym__sequence_expression] = STATE(7948),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6588),
    [sym_array_get_expression] = STATE(6588),
    [sym_string_get_expression] = STATE(6588),
    [sym_bigarray_get_expression] = STATE(6588),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(719),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2201),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18286),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [720] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16528),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(720),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [721] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19272),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(721),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [722] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19271),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(722),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [723] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(12568),
    [sym__sequence_expression] = STATE(16608),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(723),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [724] = {
    [sym_value_definition] = STATE(18277),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(12620),
    [sym__sequence_expression] = STATE(7947),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6588),
    [sym_array_get_expression] = STATE(6588),
    [sym_string_get_expression] = STATE(6588),
    [sym_bigarray_get_expression] = STATE(6588),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(724),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2201),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18286),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [725] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19270),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(725),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [726] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18781),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(726),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [727] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18259),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(727),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [728] = {
    [sym_value_definition] = STATE(18277),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(12620),
    [sym__sequence_expression] = STATE(7937),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6588),
    [sym_array_get_expression] = STATE(6588),
    [sym_string_get_expression] = STATE(6588),
    [sym_bigarray_get_expression] = STATE(6588),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(728),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2201),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18286),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [729] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18253),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(729),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [730] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18252),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(730),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [731] = {
    [sym_value_definition] = STATE(18277),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(12620),
    [sym__sequence_expression] = STATE(7929),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6588),
    [sym_array_get_expression] = STATE(6588),
    [sym_string_get_expression] = STATE(6588),
    [sym_bigarray_get_expression] = STATE(6588),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(731),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2201),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18286),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [732] = {
    [sym_value_definition] = STATE(18295),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11460),
    [sym__sequence_expression] = STATE(10371),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5598),
    [sym_array_get_expression] = STATE(5598),
    [sym_string_get_expression] = STATE(5598),
    [sym_bigarray_get_expression] = STATE(5598),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(732),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(1999),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(20495),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1351),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1355),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [733] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18218),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(733),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [734] = {
    [sym_value_definition] = STATE(18295),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11460),
    [sym__sequence_expression] = STATE(10474),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5598),
    [sym_array_get_expression] = STATE(5598),
    [sym_string_get_expression] = STATE(5598),
    [sym_bigarray_get_expression] = STATE(5598),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(734),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(1999),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(20495),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1351),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1355),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [735] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18217),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(735),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [736] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18208),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(736),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [737] = {
    [sym_value_definition] = STATE(18295),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11460),
    [sym__sequence_expression] = STATE(10659),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5598),
    [sym_array_get_expression] = STATE(5598),
    [sym_string_get_expression] = STATE(5598),
    [sym_bigarray_get_expression] = STATE(5598),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(737),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(1999),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(20495),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1351),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1355),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [738] = {
    [sym_value_definition] = STATE(18295),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11460),
    [sym__sequence_expression] = STATE(10678),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5598),
    [sym_array_get_expression] = STATE(5598),
    [sym_string_get_expression] = STATE(5598),
    [sym_bigarray_get_expression] = STATE(5598),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(738),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(1999),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(20495),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1351),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1355),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [739] = {
    [sym_value_definition] = STATE(18295),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11460),
    [sym__sequence_expression] = STATE(10679),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5598),
    [sym_array_get_expression] = STATE(5598),
    [sym_string_get_expression] = STATE(5598),
    [sym_bigarray_get_expression] = STATE(5598),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(739),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(1999),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(20495),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1351),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1355),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [740] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8389),
    [sym__sequence_expression] = STATE(8188),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(740),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [741] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16738),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(741),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [742] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18238),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(742),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [743] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(5419),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(743),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [744] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18178),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(744),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [745] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18783),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(745),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [746] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18792),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(746),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [747] = {
    [sym_value_definition] = STATE(18295),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11460),
    [sym__sequence_expression] = STATE(10680),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5598),
    [sym_array_get_expression] = STATE(5598),
    [sym_string_get_expression] = STATE(5598),
    [sym_bigarray_get_expression] = STATE(5598),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(747),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(1999),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(20495),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1351),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1355),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [748] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18177),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(748),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [749] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18167),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(749),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [750] = {
    [sym_value_definition] = STATE(19586),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8712),
    [sym__sequence_expression] = STATE(8203),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(750),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [751] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8534),
    [sym__sequence_expression] = STATE(5419),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(751),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [752] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(20275),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(752),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [753] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(20271),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(753),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [754] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(20270),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(754),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [755] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10042),
    [sym__sequence_expression] = STATE(7929),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(755),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [756] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12682),
    [sym__sequence_expression] = STATE(7951),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(756),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [757] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(12568),
    [sym__sequence_expression] = STATE(7482),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(757),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [758] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8389),
    [sym__sequence_expression] = STATE(8116),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(758),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [759] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18131),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(759),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [760] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18130),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(760),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [761] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8452),
    [sym__sequence_expression] = STATE(10551),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(761),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [762] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12682),
    [sym__sequence_expression] = STATE(7948),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(762),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [763] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12682),
    [sym__sequence_expression] = STATE(7947),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(763),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [764] = {
    [sym_value_definition] = STATE(19586),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8879),
    [sym__sequence_expression] = STATE(5419),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(764),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [765] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12682),
    [sym__sequence_expression] = STATE(7937),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(765),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [766] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18229),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(766),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [767] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18225),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(767),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [768] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17121),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(768),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [769] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18117),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(769),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [770] = {
    [sym_value_definition] = STATE(17654),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9605),
    [sym__sequence_expression] = STATE(8271),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4841),
    [sym_array_get_expression] = STATE(4841),
    [sym_string_get_expression] = STATE(4841),
    [sym_bigarray_get_expression] = STATE(4841),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(770),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2276),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(17662),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(997),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1009),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1013),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1015),
    [anon_sym_function] = ACTIONS(1017),
    [anon_sym_try] = ACTIONS(1019),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1041),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [771] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17182),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(771),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [772] = {
    [sym_value_definition] = STATE(17654),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9605),
    [sym__sequence_expression] = STATE(8277),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4841),
    [sym_array_get_expression] = STATE(4841),
    [sym_string_get_expression] = STATE(4841),
    [sym_bigarray_get_expression] = STATE(4841),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(772),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2276),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(17662),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(997),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1009),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1013),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1015),
    [anon_sym_function] = ACTIONS(1017),
    [anon_sym_try] = ACTIONS(1019),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1041),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [773] = {
    [sym_value_definition] = STATE(19480),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8574),
    [sym__sequence_expression] = STATE(8116),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(773),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_let] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3095),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3097),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [774] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18080),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(774),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [775] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10042),
    [sym__sequence_expression] = STATE(8207),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(775),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [776] = {
    [sym_value_definition] = STATE(17654),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9605),
    [sym__sequence_expression] = STATE(8257),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4841),
    [sym_array_get_expression] = STATE(4841),
    [sym_string_get_expression] = STATE(4841),
    [sym_bigarray_get_expression] = STATE(4841),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(776),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2276),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(17662),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(997),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1009),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1013),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1015),
    [anon_sym_function] = ACTIONS(1017),
    [anon_sym_try] = ACTIONS(1019),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1041),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [777] = {
    [sym_value_definition] = STATE(17654),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9605),
    [sym__sequence_expression] = STATE(8220),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4841),
    [sym_array_get_expression] = STATE(4841),
    [sym_string_get_expression] = STATE(4841),
    [sym_bigarray_get_expression] = STATE(4841),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(777),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2276),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(17662),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(997),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1009),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1013),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1015),
    [anon_sym_function] = ACTIONS(1017),
    [anon_sym_try] = ACTIONS(1019),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1041),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [778] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18077),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(778),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [779] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12682),
    [sym__sequence_expression] = STATE(7929),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(779),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [780] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18076),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(780),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [781] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8389),
    [sym__sequence_expression] = STATE(8127),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(781),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [782] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8389),
    [sym__sequence_expression] = STATE(8243),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(782),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [783] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16940),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(783),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [784] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18063),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(784),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [785] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19225),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(785),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [786] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8389),
    [sym__sequence_expression] = STATE(8244),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(786),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [787] = {
    [sym_value_definition] = STATE(17654),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9605),
    [sym__sequence_expression] = STATE(8219),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4841),
    [sym_array_get_expression] = STATE(4841),
    [sym_string_get_expression] = STATE(4841),
    [sym_bigarray_get_expression] = STATE(4841),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(787),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2276),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(17662),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(997),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1009),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1013),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1015),
    [anon_sym_function] = ACTIONS(1017),
    [anon_sym_try] = ACTIONS(1019),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1041),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [788] = {
    [sym_value_definition] = STATE(17654),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9605),
    [sym__sequence_expression] = STATE(8211),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4841),
    [sym_array_get_expression] = STATE(4841),
    [sym_string_get_expression] = STATE(4841),
    [sym_bigarray_get_expression] = STATE(4841),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(788),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2276),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(17662),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(997),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1009),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1013),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1015),
    [anon_sym_function] = ACTIONS(1017),
    [anon_sym_try] = ACTIONS(1019),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1041),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [789] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8452),
    [sym__sequence_expression] = STATE(10630),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(789),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [790] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8389),
    [sym__sequence_expression] = STATE(8203),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(790),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [791] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19605),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(791),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [792] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19219),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(792),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [793] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19218),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(793),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [794] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19217),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(794),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [795] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19598),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(795),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [796] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18888),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(796),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [797] = {
    [sym_value_definition] = STATE(20489),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(12039),
    [sym__sequence_expression] = STATE(8017),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6050),
    [sym_array_get_expression] = STATE(6050),
    [sym_string_get_expression] = STATE(6050),
    [sym_bigarray_get_expression] = STATE(6050),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(797),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(1961),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(20493),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(2065),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(2067),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(2069),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2071),
    [anon_sym_function] = ACTIONS(2073),
    [anon_sym_try] = ACTIONS(2075),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2077),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [798] = {
    [sym_value_definition] = STATE(20489),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(12039),
    [sym__sequence_expression] = STATE(7976),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6050),
    [sym_array_get_expression] = STATE(6050),
    [sym_string_get_expression] = STATE(6050),
    [sym_bigarray_get_expression] = STATE(6050),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(798),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(1961),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(20493),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(2065),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(2067),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(2069),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2071),
    [anon_sym_function] = ACTIONS(2073),
    [anon_sym_try] = ACTIONS(2075),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2077),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [799] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18023),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(799),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [800] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18917),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(800),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [801] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18022),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(801),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [802] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19206),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(802),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [803] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19205),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(803),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [804] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19203),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(804),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [805] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18009),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(805),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [806] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18920),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(806),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [807] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18921),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(807),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [808] = {
    [sym_value_definition] = STATE(19480),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8877),
    [sym__sequence_expression] = STATE(5419),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(808),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_let] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3095),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3097),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [809] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19615),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(809),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [810] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17969),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(810),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [811] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10042),
    [sym__sequence_expression] = STATE(7937),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(811),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [812] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17968),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(812),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [813] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17955),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(813),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [814] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8452),
    [sym__sequence_expression] = STATE(10500),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(814),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [815] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10042),
    [sym__sequence_expression] = STATE(7947),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(815),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [816] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19625),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(816),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [817] = {
    [sym_value_definition] = STATE(20489),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(12039),
    [sym__sequence_expression] = STATE(7951),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6050),
    [sym_array_get_expression] = STATE(6050),
    [sym_string_get_expression] = STATE(6050),
    [sym_bigarray_get_expression] = STATE(6050),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(817),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(1961),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(20493),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(2065),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(2067),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(2069),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2071),
    [anon_sym_function] = ACTIONS(2073),
    [anon_sym_try] = ACTIONS(2075),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2077),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [818] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17915),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(818),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [819] = {
    [sym_value_definition] = STATE(20489),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(12039),
    [sym__sequence_expression] = STATE(7948),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6050),
    [sym_array_get_expression] = STATE(6050),
    [sym_string_get_expression] = STATE(6050),
    [sym_bigarray_get_expression] = STATE(6050),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(819),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(1961),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(20493),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(2065),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(2067),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(2069),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2071),
    [anon_sym_function] = ACTIONS(2073),
    [anon_sym_try] = ACTIONS(2075),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2077),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [820] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17914),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(820),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [821] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17901),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(821),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [822] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10042),
    [sym__sequence_expression] = STATE(7948),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(822),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [823] = {
    [sym_value_definition] = STATE(17654),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9605),
    [sym__sequence_expression] = STATE(8162),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4841),
    [sym_array_get_expression] = STATE(4841),
    [sym_string_get_expression] = STATE(4841),
    [sym_bigarray_get_expression] = STATE(4841),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(823),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2276),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(17662),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(997),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1009),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1013),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1015),
    [anon_sym_function] = ACTIONS(1017),
    [anon_sym_try] = ACTIONS(1019),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1041),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [824] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19633),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(824),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [825] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8452),
    [sym__sequence_expression] = STATE(10425),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(825),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [826] = {
    [sym_value_definition] = STATE(17904),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12622),
    [sym__sequence_expression] = STATE(8271),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6329),
    [sym_array_get_expression] = STATE(6329),
    [sym_string_get_expression] = STATE(6329),
    [sym_bigarray_get_expression] = STATE(6329),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(826),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(2362),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(17913),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2601),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2607),
    [anon_sym_function] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2611),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2633),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [827] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17861),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(827),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [828] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17860),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(828),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [829] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19634),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(829),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [830] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8452),
    [sym__sequence_expression] = STATE(10365),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(830),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [831] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16988),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(831),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [832] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17847),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(832),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [833] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10042),
    [sym__sequence_expression] = STATE(7951),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(833),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [834] = {
    [sym_value_definition] = STATE(19239),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9434),
    [sym__sequence_expression] = STATE(8271),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4721),
    [sym_array_get_expression] = STATE(4721),
    [sym_string_get_expression] = STATE(4721),
    [sym_bigarray_get_expression] = STATE(4721),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(834),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(1935),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(19132),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(927),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(931),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(937),
    [anon_sym_function] = ACTIONS(939),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(967),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [835] = {
    [sym_value_definition] = STATE(19239),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9434),
    [sym__sequence_expression] = STATE(8277),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4721),
    [sym_array_get_expression] = STATE(4721),
    [sym_string_get_expression] = STATE(4721),
    [sym_bigarray_get_expression] = STATE(4721),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(835),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(1935),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(19132),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(927),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(931),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(937),
    [anon_sym_function] = ACTIONS(939),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(967),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [836] = {
    [sym_value_definition] = STATE(17904),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12622),
    [sym__sequence_expression] = STATE(8277),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6329),
    [sym_array_get_expression] = STATE(6329),
    [sym_string_get_expression] = STATE(6329),
    [sym_bigarray_get_expression] = STATE(6329),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(836),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(2362),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(17913),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2601),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2607),
    [anon_sym_function] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2611),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2633),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [837] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12712),
    [sym__sequence_expression] = STATE(8757),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(837),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [838] = {
    [sym_value_definition] = STATE(17904),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12622),
    [sym__sequence_expression] = STATE(8257),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6329),
    [sym_array_get_expression] = STATE(6329),
    [sym_string_get_expression] = STATE(6329),
    [sym_bigarray_get_expression] = STATE(6329),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(838),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(2362),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(17913),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2601),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2607),
    [anon_sym_function] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2611),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2633),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [839] = {
    [sym_value_definition] = STATE(17904),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12622),
    [sym__sequence_expression] = STATE(8220),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6329),
    [sym_array_get_expression] = STATE(6329),
    [sym_string_get_expression] = STATE(6329),
    [sym_bigarray_get_expression] = STATE(6329),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(839),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(2362),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(17913),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2601),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2607),
    [anon_sym_function] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2611),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2633),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [840] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19142),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(840),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [841] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19127),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(841),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [842] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19126),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(842),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [843] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12757),
    [sym__sequence_expression] = STATE(20143),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(20144),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(843),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [844] = {
    [sym_value_definition] = STATE(17904),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12622),
    [sym__sequence_expression] = STATE(8219),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6329),
    [sym_array_get_expression] = STATE(6329),
    [sym_string_get_expression] = STATE(6329),
    [sym_bigarray_get_expression] = STATE(6329),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(844),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(2362),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(17913),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2601),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2607),
    [anon_sym_function] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2611),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2633),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [845] = {
    [sym_value_definition] = STATE(19239),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9434),
    [sym__sequence_expression] = STATE(8257),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4721),
    [sym_array_get_expression] = STATE(4721),
    [sym_string_get_expression] = STATE(4721),
    [sym_bigarray_get_expression] = STATE(4721),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(845),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(1935),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(19132),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(927),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(931),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(937),
    [anon_sym_function] = ACTIONS(939),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(967),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [846] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19118),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(846),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [847] = {
    [sym_value_definition] = STATE(19239),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9434),
    [sym__sequence_expression] = STATE(8220),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4721),
    [sym_array_get_expression] = STATE(4721),
    [sym_string_get_expression] = STATE(4721),
    [sym_bigarray_get_expression] = STATE(4721),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(847),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(1935),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(19132),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(927),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(931),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(937),
    [anon_sym_function] = ACTIONS(939),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(967),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [848] = {
    [sym_value_definition] = STATE(17904),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12622),
    [sym__sequence_expression] = STATE(8211),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6329),
    [sym_array_get_expression] = STATE(6329),
    [sym_string_get_expression] = STATE(6329),
    [sym_bigarray_get_expression] = STATE(6329),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(848),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(2362),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(17913),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2601),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2607),
    [anon_sym_function] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2611),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2633),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [849] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10108),
    [sym__sequence_expression] = STATE(5419),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(849),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [850] = {
    [sym_value_definition] = STATE(17904),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12622),
    [sym__sequence_expression] = STATE(8162),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6329),
    [sym_array_get_expression] = STATE(6329),
    [sym_string_get_expression] = STATE(6329),
    [sym_bigarray_get_expression] = STATE(6329),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(850),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(2362),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(17913),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2601),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2607),
    [anon_sym_function] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2611),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2633),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [851] = {
    [sym_value_definition] = STATE(18034),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12470),
    [sym__sequence_expression] = STATE(8271),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6443),
    [sym_array_get_expression] = STATE(6443),
    [sym_string_get_expression] = STATE(6443),
    [sym_bigarray_get_expression] = STATE(6443),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(851),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2397),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(18043),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2693),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2705),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2709),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2711),
    [anon_sym_function] = ACTIONS(2713),
    [anon_sym_try] = ACTIONS(2715),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2737),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [852] = {
    [sym_value_definition] = STATE(18034),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12470),
    [sym__sequence_expression] = STATE(8277),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6443),
    [sym_array_get_expression] = STATE(6443),
    [sym_string_get_expression] = STATE(6443),
    [sym_bigarray_get_expression] = STATE(6443),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(852),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2397),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(18043),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2693),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2705),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2709),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2711),
    [anon_sym_function] = ACTIONS(2713),
    [anon_sym_try] = ACTIONS(2715),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2737),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [853] = {
    [sym_value_definition] = STATE(19239),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9434),
    [sym__sequence_expression] = STATE(8219),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4721),
    [sym_array_get_expression] = STATE(4721),
    [sym_string_get_expression] = STATE(4721),
    [sym_bigarray_get_expression] = STATE(4721),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(853),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(1935),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(19132),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(927),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(931),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(937),
    [anon_sym_function] = ACTIONS(939),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(967),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [854] = {
    [sym_value_definition] = STATE(18535),
    [sym__simple_expression] = STATE(2430),
    [sym__expression] = STATE(10576),
    [sym__sequence_expression] = STATE(8207),
    [sym_typed_expression] = STATE(5411),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5411),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5411),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(5160),
    [sym_array_get_expression] = STATE(5160),
    [sym_string_get_expression] = STATE(5160),
    [sym_bigarray_get_expression] = STATE(5160),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5411),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(854),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym_sign_operator] = STATE(1986),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__instance_variable_name] = STATE(18550),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [sym__lowercase_identifier] = ACTIONS(1171),
    [anon_sym_let] = ACTIONS(1173),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_LBRACK] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_LBRACE] = ACTIONS(1181),
    [anon_sym_object] = ACTIONS(1183),
    [anon_sym_fun] = ACTIONS(1185),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1187),
    [anon_sym_if] = ACTIONS(1189),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1191),
    [anon_sym_function] = ACTIONS(1193),
    [anon_sym_try] = ACTIONS(1195),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1197),
    [anon_sym_LBRACE_LT] = ACTIONS(1199),
    [anon_sym_begin] = ACTIONS(1201),
    [sym_ocamlyacc_value] = ACTIONS(1203),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1205),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1207),
    [aux_sym_number_token1] = ACTIONS(1209),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_prefix_operator] = ACTIONS(1215),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1217),
    [sym__uppercase_identifier] = ACTIONS(1219),
    [aux_sym_tag_token1] = ACTIONS(1221),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [855] = {
    [sym_value_definition] = STATE(19239),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9434),
    [sym__sequence_expression] = STATE(8211),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4721),
    [sym_array_get_expression] = STATE(4721),
    [sym_string_get_expression] = STATE(4721),
    [sym_bigarray_get_expression] = STATE(4721),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(855),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(1935),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(19132),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(927),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(931),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(937),
    [anon_sym_function] = ACTIONS(939),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(967),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [856] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19088),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(856),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [857] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19087),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(857),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [858] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19086),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(858),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [859] = {
    [sym_value_definition] = STATE(18797),
    [sym__simple_expression] = STATE(1527),
    [sym__expression] = STATE(8505),
    [sym__sequence_expression] = STATE(5419),
    [sym_typed_expression] = STATE(4161),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4161),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4161),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3909),
    [sym_array_get_expression] = STATE(3909),
    [sym_string_get_expression] = STATE(3909),
    [sym_bigarray_get_expression] = STATE(3909),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4161),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(859),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym_sign_operator] = STATE(2091),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__instance_variable_name] = STATE(18811),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [sym__lowercase_identifier] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_fun] = ACTIONS(819),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_if] = ACTIONS(823),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(825),
    [anon_sym_function] = ACTIONS(827),
    [anon_sym_try] = ACTIONS(829),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3115),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3117),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(851),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [860] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17546),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(860),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [861] = {
    [sym_value_definition] = STATE(17966),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12567),
    [sym__sequence_expression] = STATE(7929),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(861),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2141),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(17979),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [862] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12682),
    [sym__sequence_expression] = STATE(8757),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(862),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [863] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12751),
    [sym__sequence_expression] = STATE(8017),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(863),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [864] = {
    [sym_value_definition] = STATE(17966),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12567),
    [sym__sequence_expression] = STATE(7937),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(864),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2141),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(17979),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [865] = {
    [sym_value_definition] = STATE(17966),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12567),
    [sym__sequence_expression] = STATE(7947),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(865),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2141),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(17979),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [866] = {
    [sym_value_definition] = STATE(17966),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12567),
    [sym__sequence_expression] = STATE(7948),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(866),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2141),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(17979),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [867] = {
    [sym_value_definition] = STATE(17966),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12567),
    [sym__sequence_expression] = STATE(7951),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(867),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2141),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(17979),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [868] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19635),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(868),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [869] = {
    [sym_value_definition] = STATE(17966),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12567),
    [sym__sequence_expression] = STATE(7976),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(869),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2141),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(17979),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [870] = {
    [sym_value_definition] = STATE(17966),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12567),
    [sym__sequence_expression] = STATE(8017),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(870),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2141),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(17979),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [871] = {
    [sym_value_definition] = STATE(18030),
    [sym__simple_expression] = STATE(301),
    [sym__expression] = STATE(8264),
    [sym__sequence_expression] = STATE(8203),
    [sym_typed_expression] = STATE(3052),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3052),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3052),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2963),
    [sym_array_get_expression] = STATE(2963),
    [sym_string_get_expression] = STATE(2963),
    [sym_bigarray_get_expression] = STATE(2963),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3052),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(871),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym_sign_operator] = STATE(1958),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__instance_variable_name] = STATE(18008),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [sym__lowercase_identifier] = ACTIONS(295),
    [anon_sym_let] = ACTIONS(299),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_fun] = ACTIONS(313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_if] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(319),
    [anon_sym_function] = ACTIONS(321),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3119),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3121),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(349),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [872] = {
    [sym_value_definition] = STATE(19239),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9434),
    [sym__sequence_expression] = STATE(8162),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4721),
    [sym_array_get_expression] = STATE(4721),
    [sym_string_get_expression] = STATE(4721),
    [sym_bigarray_get_expression] = STATE(4721),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(872),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(1935),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(19132),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(927),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(931),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(937),
    [anon_sym_function] = ACTIONS(939),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(967),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [873] = {
    [sym_value_definition] = STATE(18295),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11460),
    [sym__sequence_expression] = STATE(10687),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5598),
    [sym_array_get_expression] = STATE(5598),
    [sym_string_get_expression] = STATE(5598),
    [sym_bigarray_get_expression] = STATE(5598),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(873),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(1999),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(20495),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1351),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1355),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [874] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19031),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(874),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [875] = {
    [sym_value_definition] = STATE(18034),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12470),
    [sym__sequence_expression] = STATE(8257),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6443),
    [sym_array_get_expression] = STATE(6443),
    [sym_string_get_expression] = STATE(6443),
    [sym_bigarray_get_expression] = STATE(6443),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(875),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2397),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(18043),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2693),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2705),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2709),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2711),
    [anon_sym_function] = ACTIONS(2713),
    [anon_sym_try] = ACTIONS(2715),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2737),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [876] = {
    [sym_value_definition] = STATE(18030),
    [sym__simple_expression] = STATE(301),
    [sym__expression] = STATE(8264),
    [sym__sequence_expression] = STATE(8244),
    [sym_typed_expression] = STATE(3052),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3052),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3052),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2963),
    [sym_array_get_expression] = STATE(2963),
    [sym_string_get_expression] = STATE(2963),
    [sym_bigarray_get_expression] = STATE(2963),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3052),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(876),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym_sign_operator] = STATE(1958),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__instance_variable_name] = STATE(18008),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [sym__lowercase_identifier] = ACTIONS(295),
    [anon_sym_let] = ACTIONS(299),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_fun] = ACTIONS(313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_if] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(319),
    [anon_sym_function] = ACTIONS(321),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3119),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3121),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(349),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [877] = {
    [sym_value_definition] = STATE(18030),
    [sym__simple_expression] = STATE(301),
    [sym__expression] = STATE(8264),
    [sym__sequence_expression] = STATE(8243),
    [sym_typed_expression] = STATE(3052),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3052),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3052),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2963),
    [sym_array_get_expression] = STATE(2963),
    [sym_string_get_expression] = STATE(2963),
    [sym_bigarray_get_expression] = STATE(2963),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3052),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(877),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym_sign_operator] = STATE(1958),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__instance_variable_name] = STATE(18008),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [sym__lowercase_identifier] = ACTIONS(295),
    [anon_sym_let] = ACTIONS(299),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_fun] = ACTIONS(313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_if] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(319),
    [anon_sym_function] = ACTIONS(321),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3119),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3121),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(349),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [878] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(12568),
    [sym__sequence_expression] = STATE(16863),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(878),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [879] = {
    [sym_value_definition] = STATE(18030),
    [sym__simple_expression] = STATE(301),
    [sym__expression] = STATE(8264),
    [sym__sequence_expression] = STATE(8127),
    [sym_typed_expression] = STATE(3052),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3052),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3052),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2963),
    [sym_array_get_expression] = STATE(2963),
    [sym_string_get_expression] = STATE(2963),
    [sym_bigarray_get_expression] = STATE(2963),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3052),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(879),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym_sign_operator] = STATE(1958),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__instance_variable_name] = STATE(18008),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [sym__lowercase_identifier] = ACTIONS(295),
    [anon_sym_let] = ACTIONS(299),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_fun] = ACTIONS(313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_if] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(319),
    [anon_sym_function] = ACTIONS(321),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3119),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3121),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(349),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [880] = {
    [sym_value_definition] = STATE(18188),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12346),
    [sym__sequence_expression] = STATE(8277),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6417),
    [sym_array_get_expression] = STATE(6417),
    [sym_string_get_expression] = STATE(6417),
    [sym_bigarray_get_expression] = STATE(6417),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(880),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(18201),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2745),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2761),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2763),
    [anon_sym_function] = ACTIONS(2765),
    [anon_sym_try] = ACTIONS(2767),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2789),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [881] = {
    [sym_value_definition] = STATE(18030),
    [sym__simple_expression] = STATE(301),
    [sym__expression] = STATE(8264),
    [sym__sequence_expression] = STATE(8116),
    [sym_typed_expression] = STATE(3052),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3052),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3052),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2963),
    [sym_array_get_expression] = STATE(2963),
    [sym_string_get_expression] = STATE(2963),
    [sym_bigarray_get_expression] = STATE(2963),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3052),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(881),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym_sign_operator] = STATE(1958),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__instance_variable_name] = STATE(18008),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [sym__lowercase_identifier] = ACTIONS(295),
    [anon_sym_let] = ACTIONS(299),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_fun] = ACTIONS(313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_if] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(319),
    [anon_sym_function] = ACTIONS(321),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3119),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3121),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(349),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [882] = {
    [sym_value_definition] = STATE(18030),
    [sym__simple_expression] = STATE(301),
    [sym__expression] = STATE(8264),
    [sym__sequence_expression] = STATE(8188),
    [sym_typed_expression] = STATE(3052),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3052),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3052),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2963),
    [sym_array_get_expression] = STATE(2963),
    [sym_string_get_expression] = STATE(2963),
    [sym_bigarray_get_expression] = STATE(2963),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3052),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(882),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym_sign_operator] = STATE(1958),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__instance_variable_name] = STATE(18008),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [sym__lowercase_identifier] = ACTIONS(295),
    [anon_sym_let] = ACTIONS(299),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_fun] = ACTIONS(313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_if] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(319),
    [anon_sym_function] = ACTIONS(321),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3119),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3121),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(349),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [883] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18980),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(883),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [884] = {
    [sym_value_definition] = STATE(18030),
    [sym__simple_expression] = STATE(301),
    [sym__expression] = STATE(8264),
    [sym__sequence_expression] = STATE(8185),
    [sym_typed_expression] = STATE(3052),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3052),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3052),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2963),
    [sym_array_get_expression] = STATE(2963),
    [sym_string_get_expression] = STATE(2963),
    [sym_bigarray_get_expression] = STATE(2963),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3052),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(884),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym_sign_operator] = STATE(1958),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__instance_variable_name] = STATE(18008),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [sym__lowercase_identifier] = ACTIONS(295),
    [anon_sym_let] = ACTIONS(299),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_fun] = ACTIONS(313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_if] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(319),
    [anon_sym_function] = ACTIONS(321),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3119),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3121),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(349),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [885] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18466),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(885),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [886] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17807),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(886),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [887] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18950),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(887),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [888] = {
    [sym_value_definition] = STATE(18034),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12470),
    [sym__sequence_expression] = STATE(8220),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6443),
    [sym_array_get_expression] = STATE(6443),
    [sym_string_get_expression] = STATE(6443),
    [sym_bigarray_get_expression] = STATE(6443),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(888),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2397),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(18043),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2693),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2705),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2709),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2711),
    [anon_sym_function] = ACTIONS(2713),
    [anon_sym_try] = ACTIONS(2715),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2737),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [889] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12751),
    [sym__sequence_expression] = STATE(7976),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(889),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [890] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18122),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(890),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [891] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18967),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(891),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [892] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18958),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(892),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [893] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18121),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(893),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [894] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18120),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(894),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [895] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(12568),
    [sym__sequence_expression] = STATE(16872),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(895),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [896] = {
    [sym_value_definition] = STATE(18034),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12470),
    [sym__sequence_expression] = STATE(8219),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6443),
    [sym_array_get_expression] = STATE(6443),
    [sym_string_get_expression] = STATE(6443),
    [sym_bigarray_get_expression] = STATE(6443),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(896),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2397),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(18043),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2693),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2705),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2709),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2711),
    [anon_sym_function] = ACTIONS(2713),
    [anon_sym_try] = ACTIONS(2715),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2737),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [897] = {
    [sym_value_definition] = STATE(18034),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12470),
    [sym__sequence_expression] = STATE(8211),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6443),
    [sym_array_get_expression] = STATE(6443),
    [sym_string_get_expression] = STATE(6443),
    [sym_bigarray_get_expression] = STATE(6443),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(897),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2397),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(18043),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2693),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2705),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2709),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2711),
    [anon_sym_function] = ACTIONS(2713),
    [anon_sym_try] = ACTIONS(2715),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2737),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [898] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17806),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(898),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [899] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17793),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(899),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [900] = {
    [sym_value_definition] = STATE(20489),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(12039),
    [sym__sequence_expression] = STATE(7947),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6050),
    [sym_array_get_expression] = STATE(6050),
    [sym_string_get_expression] = STATE(6050),
    [sym_bigarray_get_expression] = STATE(6050),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(900),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(1961),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(20493),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(2065),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(2067),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(2069),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2071),
    [anon_sym_function] = ACTIONS(2073),
    [anon_sym_try] = ACTIONS(2075),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2077),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [901] = {
    [sym_value_definition] = STATE(18034),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12470),
    [sym__sequence_expression] = STATE(8162),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6443),
    [sym_array_get_expression] = STATE(6443),
    [sym_string_get_expression] = STATE(6443),
    [sym_bigarray_get_expression] = STATE(6443),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(901),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2397),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(18043),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2693),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2705),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2709),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2711),
    [anon_sym_function] = ACTIONS(2713),
    [anon_sym_try] = ACTIONS(2715),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2737),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [902] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19039),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(902),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [903] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18956),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(903),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [904] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18953),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(904),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [905] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18952),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(905),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [906] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10042),
    [sym__sequence_expression] = STATE(7976),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(906),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [907] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17588),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(907),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [908] = {
    [sym_value_definition] = STATE(18188),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12346),
    [sym__sequence_expression] = STATE(8271),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6417),
    [sym_array_get_expression] = STATE(6417),
    [sym_string_get_expression] = STATE(6417),
    [sym_bigarray_get_expression] = STATE(6417),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(908),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(18201),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2745),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2761),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2763),
    [anon_sym_function] = ACTIONS(2765),
    [anon_sym_try] = ACTIONS(2767),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2789),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [909] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18095),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(909),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [910] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18093),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(910),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [911] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17753),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(911),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [912] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18939),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(912),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [913] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17752),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(913),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [914] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18938),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(914),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [915] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17739),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(915),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [916] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8383),
    [sym__sequence_expression] = STATE(10365),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(916),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [917] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18937),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(917),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [918] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12751),
    [sym__sequence_expression] = STATE(8757),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(918),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [919] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16779),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(919),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [920] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19049),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(920),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [921] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19050),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(921),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [922] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(20323),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(922),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [923] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19656),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(923),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [924] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19657),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(924),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [925] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17699),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(925),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [926] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17698),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(926),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [927] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17685),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(927),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [928] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19658),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(928),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [929] = {
    [sym_value_definition] = STATE(18188),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12346),
    [sym__sequence_expression] = STATE(8257),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6417),
    [sym_array_get_expression] = STATE(6417),
    [sym_string_get_expression] = STATE(6417),
    [sym_bigarray_get_expression] = STATE(6417),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(929),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(18201),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2745),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2761),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2763),
    [anon_sym_function] = ACTIONS(2765),
    [anon_sym_try] = ACTIONS(2767),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2789),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [930] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12672),
    [sym__sequence_expression] = STATE(5419),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(930),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [931] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18088),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(931),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [932] = {
    [sym_value_definition] = STATE(18188),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12346),
    [sym__sequence_expression] = STATE(8220),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6417),
    [sym_array_get_expression] = STATE(6417),
    [sym_string_get_expression] = STATE(6417),
    [sym_bigarray_get_expression] = STATE(6417),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(932),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(18201),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2745),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2761),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2763),
    [anon_sym_function] = ACTIONS(2765),
    [anon_sym_try] = ACTIONS(2767),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2789),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [933] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18073),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(933),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [934] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17650),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(934),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [935] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19051),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(935),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [936] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12751),
    [sym__sequence_expression] = STATE(7951),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(936),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [937] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17649),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(937),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [938] = {
    [sym_value_definition] = STATE(20489),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(12039),
    [sym__sequence_expression] = STATE(7937),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6050),
    [sym_array_get_expression] = STATE(6050),
    [sym_string_get_expression] = STATE(6050),
    [sym_bigarray_get_expression] = STATE(6050),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(938),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(1961),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(20493),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(2065),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(2067),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(2069),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2071),
    [anon_sym_function] = ACTIONS(2073),
    [anon_sym_try] = ACTIONS(2075),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2077),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [939] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19058),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(939),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [940] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19059),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(940),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [941] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17639),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(941),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [942] = {
    [sym_value_definition] = STATE(18188),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12346),
    [sym__sequence_expression] = STATE(8219),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6417),
    [sym_array_get_expression] = STATE(6417),
    [sym_string_get_expression] = STATE(6417),
    [sym_bigarray_get_expression] = STATE(6417),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(942),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(18201),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2745),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2761),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2763),
    [anon_sym_function] = ACTIONS(2765),
    [anon_sym_try] = ACTIONS(2767),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2789),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [943] = {
    [sym_value_definition] = STATE(18188),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12346),
    [sym__sequence_expression] = STATE(8211),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6417),
    [sym_array_get_expression] = STATE(6417),
    [sym_string_get_expression] = STATE(6417),
    [sym_bigarray_get_expression] = STATE(6417),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(943),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(18201),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2745),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2761),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2763),
    [anon_sym_function] = ACTIONS(2765),
    [anon_sym_try] = ACTIONS(2767),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2789),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [944] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12751),
    [sym__sequence_expression] = STATE(7948),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(944),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [945] = {
    [sym_value_definition] = STATE(18188),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12346),
    [sym__sequence_expression] = STATE(8162),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6417),
    [sym_array_get_expression] = STATE(6417),
    [sym_string_get_expression] = STATE(6417),
    [sym_bigarray_get_expression] = STATE(6417),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(945),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(18201),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2745),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2761),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2763),
    [anon_sym_function] = ACTIONS(2765),
    [anon_sym_try] = ACTIONS(2767),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2789),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [946] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12751),
    [sym__sequence_expression] = STATE(7947),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(946),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [947] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12751),
    [sym__sequence_expression] = STATE(7937),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(947),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [948] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19060),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(948),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [949] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16513),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(949),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [950] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17601),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(950),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [951] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17986),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(951),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [952] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17599),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(952),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [953] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17670),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(953),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [954] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20326),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(954),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [955] = {
    [sym_value_definition] = STATE(18362),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12297),
    [sym__sequence_expression] = STATE(8271),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6385),
    [sym_array_get_expression] = STATE(6385),
    [sym_string_get_expression] = STATE(6385),
    [sym_bigarray_get_expression] = STATE(6385),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(955),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2336),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(18374),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [956] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11810),
    [sym__sequence_expression] = STATE(14142),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(956),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [957] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8410),
    [sym__sequence_expression] = STATE(10630),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(957),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [958] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18865),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(958),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [959] = {
    [sym_value_definition] = STATE(18362),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12297),
    [sym__sequence_expression] = STATE(8277),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6385),
    [sym_array_get_expression] = STATE(6385),
    [sym_string_get_expression] = STATE(6385),
    [sym_bigarray_get_expression] = STATE(6385),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(959),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2336),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(18374),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [960] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17559),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(960),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [961] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12659),
    [sym__sequence_expression] = STATE(8757),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(961),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [962] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17814),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(962),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [963] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18855),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(963),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [964] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12751),
    [sym__sequence_expression] = STATE(7929),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(964),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [965] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17823),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(965),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [966] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18853),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(966),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [967] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17867),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(967),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [968] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18848),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(968),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [969] = {
    [sym_value_definition] = STATE(18362),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12297),
    [sym__sequence_expression] = STATE(8257),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6385),
    [sym_array_get_expression] = STATE(6385),
    [sym_string_get_expression] = STATE(6385),
    [sym_bigarray_get_expression] = STATE(6385),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(969),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2336),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(18374),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [970] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10042),
    [sym__sequence_expression] = STATE(8017),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(970),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [971] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20377),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(971),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [972] = {
    [sym_value_definition] = STATE(18362),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12297),
    [sym__sequence_expression] = STATE(8220),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6385),
    [sym_array_get_expression] = STATE(6385),
    [sym_string_get_expression] = STATE(6385),
    [sym_bigarray_get_expression] = STATE(6385),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(972),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2336),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(18374),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [973] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18833),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(973),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [974] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19674),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(974),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [975] = {
    [sym_value_definition] = STATE(18362),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12297),
    [sym__sequence_expression] = STATE(8219),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6385),
    [sym_array_get_expression] = STATE(6385),
    [sym_string_get_expression] = STATE(6385),
    [sym_bigarray_get_expression] = STATE(6385),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(975),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2336),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(18374),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [976] = {
    [sym_value_definition] = STATE(18662),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(11961),
    [sym__sequence_expression] = STATE(8207),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6146),
    [sym_array_get_expression] = STATE(6146),
    [sym_string_get_expression] = STATE(6146),
    [sym_bigarray_get_expression] = STATE(6146),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(976),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(2139),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18398),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [977] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17985),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(977),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [978] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12672),
    [sym__sequence_expression] = STATE(16586),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(978),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [979] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18019),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(979),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [980] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18028),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(980),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [981] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16816),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(981),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [982] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(17950),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(982),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [983] = {
    [sym_value_definition] = STATE(18447),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12466),
    [sym__sequence_expression] = STATE(7976),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6602),
    [sym_array_get_expression] = STATE(6602),
    [sym_string_get_expression] = STATE(6602),
    [sym_bigarray_get_expression] = STATE(6602),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(983),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(1952),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18459),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [984] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16585),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(984),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [985] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18832),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(985),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [986] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18830),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(986),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [987] = {
    [sym_value_definition] = STATE(18362),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12297),
    [sym__sequence_expression] = STATE(8211),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6385),
    [sym_array_get_expression] = STATE(6385),
    [sym_string_get_expression] = STATE(6385),
    [sym_bigarray_get_expression] = STATE(6385),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(987),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2336),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(18374),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [988] = {
    [sym_value_definition] = STATE(18447),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12466),
    [sym__sequence_expression] = STATE(7951),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6602),
    [sym_array_get_expression] = STATE(6602),
    [sym_string_get_expression] = STATE(6602),
    [sym_bigarray_get_expression] = STATE(6602),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(988),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(1952),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18459),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [989] = {
    [sym_value_definition] = STATE(18362),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12297),
    [sym__sequence_expression] = STATE(8162),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6385),
    [sym_array_get_expression] = STATE(6385),
    [sym_string_get_expression] = STATE(6385),
    [sym_bigarray_get_expression] = STATE(6385),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(989),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2336),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(18374),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [990] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(10965),
    [sym__sequence_expression] = STATE(8757),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(990),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [991] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17982),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(991),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [992] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10108),
    [sym__sequence_expression] = STATE(13045),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(992),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [993] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17963),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(993),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [994] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17959),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(994),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [995] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18607),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(995),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [996] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18765),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(996),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [997] = {
    [sym_value_definition] = STATE(18447),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12466),
    [sym__sequence_expression] = STATE(7948),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6602),
    [sym_array_get_expression] = STATE(6602),
    [sym_string_get_expression] = STATE(6602),
    [sym_bigarray_get_expression] = STATE(6602),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(997),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(1952),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18459),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [998] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17954),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(998),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [999] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18616),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(999),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1000] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18985),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1000),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1001] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12276),
    [sym__sequence_expression] = STATE(10687),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(1001),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1002] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19101),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1002),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1003] = {
    [sym_value_definition] = STATE(17611),
    [sym__simple_expression] = STATE(323),
    [sym__expression] = STATE(8239),
    [sym__sequence_expression] = STATE(7482),
    [sym_typed_expression] = STATE(3176),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3176),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3176),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2957),
    [sym_array_get_expression] = STATE(2957),
    [sym_string_get_expression] = STATE(2957),
    [sym_bigarray_get_expression] = STATE(2957),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3176),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(1003),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym_sign_operator] = STATE(1905),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__instance_variable_name] = STATE(17621),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [sym__lowercase_identifier] = ACTIONS(355),
    [anon_sym_let] = ACTIONS(357),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_fun] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_if] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(375),
    [anon_sym_function] = ACTIONS(377),
    [anon_sym_try] = ACTIONS(379),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3107),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3109),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(401),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1004] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(12568),
    [sym__sequence_expression] = STATE(16891),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(1004),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1005] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19111),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1005),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1006] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18755),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1006),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1007] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18714),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1007),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1008] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1008),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1009] = {
    [sym_value_definition] = STATE(17714),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9726),
    [sym__sequence_expression] = STATE(7929),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4836),
    [sym_array_get_expression] = STATE(4836),
    [sym_string_get_expression] = STATE(4836),
    [sym_bigarray_get_expression] = STATE(4836),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(1009),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(2151),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(17727),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(973),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(975),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(983),
    [anon_sym_function] = ACTIONS(985),
    [anon_sym_try] = ACTIONS(987),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(993),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1010] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17535),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1010),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1011] = {
    [sym_value_definition] = STATE(17714),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9726),
    [sym__sequence_expression] = STATE(7937),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4836),
    [sym_array_get_expression] = STATE(4836),
    [sym_string_get_expression] = STATE(4836),
    [sym_bigarray_get_expression] = STATE(4836),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(1011),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(2151),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(17727),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(973),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(975),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(983),
    [anon_sym_function] = ACTIONS(985),
    [anon_sym_try] = ACTIONS(987),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(993),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1012] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19786),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1012),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1013] = {
    [sym_value_definition] = STATE(17714),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9726),
    [sym__sequence_expression] = STATE(7947),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4836),
    [sym_array_get_expression] = STATE(4836),
    [sym_string_get_expression] = STATE(4836),
    [sym_bigarray_get_expression] = STATE(4836),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(1013),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(2151),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(17727),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(973),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(975),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(983),
    [anon_sym_function] = ACTIONS(985),
    [anon_sym_try] = ACTIONS(987),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(993),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1014] = {
    [sym_value_definition] = STATE(17714),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9726),
    [sym__sequence_expression] = STATE(7948),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4836),
    [sym_array_get_expression] = STATE(4836),
    [sym_string_get_expression] = STATE(4836),
    [sym_bigarray_get_expression] = STATE(4836),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(1014),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(2151),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(17727),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(973),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(975),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(983),
    [anon_sym_function] = ACTIONS(985),
    [anon_sym_try] = ACTIONS(987),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(993),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1015] = {
    [sym_value_definition] = STATE(17714),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9726),
    [sym__sequence_expression] = STATE(7951),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4836),
    [sym_array_get_expression] = STATE(4836),
    [sym_string_get_expression] = STATE(4836),
    [sym_bigarray_get_expression] = STATE(4836),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(1015),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(2151),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(17727),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(973),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(975),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(983),
    [anon_sym_function] = ACTIONS(985),
    [anon_sym_try] = ACTIONS(987),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(993),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1016] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18742),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1016),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1017] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18740),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1017),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1018] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18617),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1018),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1019] = {
    [sym_value_definition] = STATE(17714),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9726),
    [sym__sequence_expression] = STATE(7976),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4836),
    [sym_array_get_expression] = STATE(4836),
    [sym_string_get_expression] = STATE(4836),
    [sym_bigarray_get_expression] = STATE(4836),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(1019),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(2151),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(17727),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(973),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(975),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(983),
    [anon_sym_function] = ACTIONS(985),
    [anon_sym_try] = ACTIONS(987),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(993),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1020] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18735),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1020),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1021] = {
    [sym_value_definition] = STATE(17714),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9726),
    [sym__sequence_expression] = STATE(8017),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4836),
    [sym_array_get_expression] = STATE(4836),
    [sym_string_get_expression] = STATE(4836),
    [sym_bigarray_get_expression] = STATE(4836),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(1021),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(2151),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(17727),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(973),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(975),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(983),
    [anon_sym_function] = ACTIONS(985),
    [anon_sym_try] = ACTIONS(987),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(993),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1022] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(12568),
    [sym__sequence_expression] = STATE(16893),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(1022),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1023] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8383),
    [sym__sequence_expression] = STATE(10425),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(1023),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1024] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10108),
    [sym__sequence_expression] = STATE(12949),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(1024),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1025] = {
    [sym_value_definition] = STATE(18447),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12466),
    [sym__sequence_expression] = STATE(7947),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6602),
    [sym_array_get_expression] = STATE(6602),
    [sym_string_get_expression] = STATE(6602),
    [sym_bigarray_get_expression] = STATE(6602),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(1025),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(1952),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18459),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1026] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18646),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1026),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1027] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10108),
    [sym__sequence_expression] = STATE(13070),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(1027),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1028] = {
    [sym_value_definition] = STATE(19080),
    [sym__simple_expression] = STATE(506),
    [sym__expression] = STATE(8293),
    [sym__sequence_expression] = STATE(8203),
    [sym_typed_expression] = STATE(3532),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3532),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3532),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3084),
    [sym_array_get_expression] = STATE(3084),
    [sym_string_get_expression] = STATE(3084),
    [sym_bigarray_get_expression] = STATE(3084),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3532),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(1028),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym_sign_operator] = STATE(2274),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__instance_variable_name] = STATE(18842),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [sym__lowercase_identifier] = ACTIONS(475),
    [anon_sym_let] = ACTIONS(477),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_fun] = ACTIONS(489),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(495),
    [anon_sym_function] = ACTIONS(497),
    [anon_sym_try] = ACTIONS(499),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3123),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3125),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(521),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1029] = {
    [sym_value_definition] = STATE(19080),
    [sym__simple_expression] = STATE(506),
    [sym__expression] = STATE(8293),
    [sym__sequence_expression] = STATE(8244),
    [sym_typed_expression] = STATE(3532),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3532),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3532),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3084),
    [sym_array_get_expression] = STATE(3084),
    [sym_string_get_expression] = STATE(3084),
    [sym_bigarray_get_expression] = STATE(3084),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3532),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(1029),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym_sign_operator] = STATE(2274),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__instance_variable_name] = STATE(18842),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [sym__lowercase_identifier] = ACTIONS(475),
    [anon_sym_let] = ACTIONS(477),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_fun] = ACTIONS(489),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(495),
    [anon_sym_function] = ACTIONS(497),
    [anon_sym_try] = ACTIONS(499),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3123),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3125),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(521),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1030] = {
    [sym_value_definition] = STATE(19080),
    [sym__simple_expression] = STATE(506),
    [sym__expression] = STATE(8293),
    [sym__sequence_expression] = STATE(8243),
    [sym_typed_expression] = STATE(3532),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3532),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3532),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3084),
    [sym_array_get_expression] = STATE(3084),
    [sym_string_get_expression] = STATE(3084),
    [sym_bigarray_get_expression] = STATE(3084),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3532),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(1030),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym_sign_operator] = STATE(2274),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__instance_variable_name] = STATE(18842),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [sym__lowercase_identifier] = ACTIONS(475),
    [anon_sym_let] = ACTIONS(477),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_fun] = ACTIONS(489),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(495),
    [anon_sym_function] = ACTIONS(497),
    [anon_sym_try] = ACTIONS(499),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3123),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3125),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(521),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1031] = {
    [sym_value_definition] = STATE(19080),
    [sym__simple_expression] = STATE(506),
    [sym__expression] = STATE(8293),
    [sym__sequence_expression] = STATE(8127),
    [sym_typed_expression] = STATE(3532),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3532),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3532),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3084),
    [sym_array_get_expression] = STATE(3084),
    [sym_string_get_expression] = STATE(3084),
    [sym_bigarray_get_expression] = STATE(3084),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3532),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(1031),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym_sign_operator] = STATE(2274),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__instance_variable_name] = STATE(18842),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [sym__lowercase_identifier] = ACTIONS(475),
    [anon_sym_let] = ACTIONS(477),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_fun] = ACTIONS(489),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(495),
    [anon_sym_function] = ACTIONS(497),
    [anon_sym_try] = ACTIONS(499),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3123),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3125),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(521),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1032] = {
    [sym_value_definition] = STATE(19080),
    [sym__simple_expression] = STATE(506),
    [sym__expression] = STATE(8293),
    [sym__sequence_expression] = STATE(8116),
    [sym_typed_expression] = STATE(3532),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3532),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3532),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3084),
    [sym_array_get_expression] = STATE(3084),
    [sym_string_get_expression] = STATE(3084),
    [sym_bigarray_get_expression] = STATE(3084),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3532),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(1032),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym_sign_operator] = STATE(2274),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__instance_variable_name] = STATE(18842),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [sym__lowercase_identifier] = ACTIONS(475),
    [anon_sym_let] = ACTIONS(477),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_fun] = ACTIONS(489),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(495),
    [anon_sym_function] = ACTIONS(497),
    [anon_sym_try] = ACTIONS(499),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3123),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3125),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(521),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1033] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18655),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1033),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1034] = {
    [sym_value_definition] = STATE(19080),
    [sym__simple_expression] = STATE(506),
    [sym__expression] = STATE(8293),
    [sym__sequence_expression] = STATE(8188),
    [sym_typed_expression] = STATE(3532),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3532),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3532),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3084),
    [sym_array_get_expression] = STATE(3084),
    [sym_string_get_expression] = STATE(3084),
    [sym_bigarray_get_expression] = STATE(3084),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3532),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(1034),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym_sign_operator] = STATE(2274),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__instance_variable_name] = STATE(18842),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [sym__lowercase_identifier] = ACTIONS(475),
    [anon_sym_let] = ACTIONS(477),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_fun] = ACTIONS(489),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(495),
    [anon_sym_function] = ACTIONS(497),
    [anon_sym_try] = ACTIONS(499),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3123),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3125),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(521),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1035] = {
    [sym_value_definition] = STATE(19080),
    [sym__simple_expression] = STATE(506),
    [sym__expression] = STATE(8293),
    [sym__sequence_expression] = STATE(8185),
    [sym_typed_expression] = STATE(3532),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3532),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3532),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3084),
    [sym_array_get_expression] = STATE(3084),
    [sym_string_get_expression] = STATE(3084),
    [sym_bigarray_get_expression] = STATE(3084),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3532),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(1035),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym_sign_operator] = STATE(2274),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__instance_variable_name] = STATE(18842),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [sym__lowercase_identifier] = ACTIONS(475),
    [anon_sym_let] = ACTIONS(477),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_fun] = ACTIONS(489),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(495),
    [anon_sym_function] = ACTIONS(497),
    [anon_sym_try] = ACTIONS(499),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3123),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3125),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(521),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1036] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10108),
    [sym__sequence_expression] = STATE(13003),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(1036),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1037] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18677),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1037),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1038] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18224),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1038),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1039] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18226),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1039),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1040] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18656),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1040),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1041] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(17932),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1041),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1042] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19112),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1042),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1043] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19116),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1043),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1044] = {
    [sym_value_definition] = STATE(19586),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8712),
    [sym__sequence_expression] = STATE(8188),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(1044),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1045] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17216),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1045),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1046] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18684),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1046),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1047] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18668),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1047),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1048] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8383),
    [sym__sequence_expression] = STATE(10500),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(1048),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1049] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17096),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1049),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1050] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18270),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1050),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1051] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18693),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1051),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1052] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18666),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1052),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1053] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18694),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1053),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1054] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8306),
    [sym__sequence_expression] = STATE(8203),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(1054),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1055] = {
    [sym_value_definition] = STATE(18447),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12466),
    [sym__sequence_expression] = STATE(7937),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6602),
    [sym_array_get_expression] = STATE(6602),
    [sym_string_get_expression] = STATE(6602),
    [sym_bigarray_get_expression] = STATE(6602),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(1055),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(1952),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18459),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1056] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18664),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1056),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1057] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(12568),
    [sym__sequence_expression] = STATE(16633),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(1057),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1058] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18722),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1058),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1059] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19121),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1059),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1060] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18731),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1060),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1061] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18652),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1061),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1062] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18651),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1062),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1063] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16819),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1063),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1064] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17515),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1064),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1065] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18649),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1065),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1066] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18732),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1066),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1067] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18424),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1067),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1068] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18426),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1068),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1069] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18465),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1069),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1070] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19122),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1070),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1071] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19734),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1071),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1072] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8306),
    [sym__sequence_expression] = STATE(8244),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(1072),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1073] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8306),
    [sym__sequence_expression] = STATE(8243),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(1073),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1074] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12659),
    [sym__sequence_expression] = STATE(8017),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1074),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1075] = {
    [sym_value_definition] = STATE(19480),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8574),
    [sym__sequence_expression] = STATE(8188),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(1075),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_let] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3095),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3097),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1076] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19735),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1076),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1077] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17846),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1077),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1078] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12672),
    [sym__sequence_expression] = STATE(16777),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(1078),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1079] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19738),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1079),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1080] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18631),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1080),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1081] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8306),
    [sym__sequence_expression] = STATE(8127),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(1081),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1082] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(20232),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1082),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1083] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(20231),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1083),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1084] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(20230),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1084),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1085] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17838),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1085),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1086] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18638),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1086),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1087] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17834),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1087),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1088] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19129),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1088),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1089] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18760),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1089),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1090] = {
    [sym_value_definition] = STATE(18447),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12466),
    [sym__sequence_expression] = STATE(7929),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6602),
    [sym_array_get_expression] = STATE(6602),
    [sym_string_get_expression] = STATE(6602),
    [sym_bigarray_get_expression] = STATE(6602),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(1090),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(1952),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18459),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1091] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8383),
    [sym__sequence_expression] = STATE(10630),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(1091),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1092] = {
    [sym_value_definition] = STATE(18535),
    [sym__simple_expression] = STATE(2430),
    [sym__expression] = STATE(10576),
    [sym__sequence_expression] = STATE(8271),
    [sym_typed_expression] = STATE(5411),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5411),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5411),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(5160),
    [sym_array_get_expression] = STATE(5160),
    [sym_string_get_expression] = STATE(5160),
    [sym_bigarray_get_expression] = STATE(5160),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5411),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(1092),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym_sign_operator] = STATE(1986),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__instance_variable_name] = STATE(18550),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [sym__lowercase_identifier] = ACTIONS(1171),
    [anon_sym_let] = ACTIONS(1173),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_LBRACK] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_LBRACE] = ACTIONS(1181),
    [anon_sym_object] = ACTIONS(1183),
    [anon_sym_fun] = ACTIONS(1185),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1187),
    [anon_sym_if] = ACTIONS(1189),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1191),
    [anon_sym_function] = ACTIONS(1193),
    [anon_sym_try] = ACTIONS(1195),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1197),
    [anon_sym_LBRACE_LT] = ACTIONS(1199),
    [anon_sym_begin] = ACTIONS(1201),
    [sym_ocamlyacc_value] = ACTIONS(1203),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1205),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1207),
    [aux_sym_number_token1] = ACTIONS(1209),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_prefix_operator] = ACTIONS(1215),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1217),
    [sym__uppercase_identifier] = ACTIONS(1219),
    [aux_sym_tag_token1] = ACTIONS(1221),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1093] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18699),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1093),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1094] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8306),
    [sym__sequence_expression] = STATE(8116),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(1094),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1095] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12672),
    [sym__sequence_expression] = STATE(16774),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(1095),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1096] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18591),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1096),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1097] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18580),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1097),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1098] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18579),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1098),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1099] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8410),
    [sym__sequence_expression] = STATE(7482),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(1099),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1100] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18769),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1100),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1101] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19298),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1101),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1102] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18576),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1102),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1103] = {
    [sym_value_definition] = STATE(18535),
    [sym__simple_expression] = STATE(2430),
    [sym__expression] = STATE(10576),
    [sym__sequence_expression] = STATE(8277),
    [sym_typed_expression] = STATE(5411),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5411),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5411),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(5160),
    [sym_array_get_expression] = STATE(5160),
    [sym_string_get_expression] = STATE(5160),
    [sym_bigarray_get_expression] = STATE(5160),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5411),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(1103),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym_sign_operator] = STATE(1986),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__instance_variable_name] = STATE(18550),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [sym__lowercase_identifier] = ACTIONS(1171),
    [anon_sym_let] = ACTIONS(1173),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_LBRACK] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_LBRACE] = ACTIONS(1181),
    [anon_sym_object] = ACTIONS(1183),
    [anon_sym_fun] = ACTIONS(1185),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1187),
    [anon_sym_if] = ACTIONS(1189),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1191),
    [anon_sym_function] = ACTIONS(1193),
    [anon_sym_try] = ACTIONS(1195),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1197),
    [anon_sym_LBRACE_LT] = ACTIONS(1199),
    [anon_sym_begin] = ACTIONS(1201),
    [sym_ocamlyacc_value] = ACTIONS(1203),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1205),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1207),
    [aux_sym_number_token1] = ACTIONS(1209),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_prefix_operator] = ACTIONS(1215),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1217),
    [sym__uppercase_identifier] = ACTIONS(1219),
    [aux_sym_tag_token1] = ACTIONS(1221),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1104] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18960),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1104),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1105] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(12568),
    [sym__sequence_expression] = STATE(16922),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(1105),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1106] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18770),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1106),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1107] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18962),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1107),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1108] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(19014),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1108),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1109] = {
    [sym_value_definition] = STATE(19586),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8712),
    [sym__sequence_expression] = STATE(5419),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(1109),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1110] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10108),
    [sym__sequence_expression] = STATE(12985),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(1110),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1111] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19755),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1111),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1112] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17813),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1112),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1113] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18566),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1113),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1114] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18565),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1114),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1115] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18563),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1115),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1116] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19759),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1116),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1117] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19761),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1117),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1118] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19765),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1118),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1119] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17489),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1119),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1120] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18798),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1120),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1121] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18807),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1121),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1122] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17589),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1122),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1123] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18808),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1123),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1124] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12659),
    [sym__sequence_expression] = STATE(7976),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1124),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1125] = {
    [sym_value_definition] = STATE(20489),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(12039),
    [sym__sequence_expression] = STATE(7929),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6050),
    [sym_array_get_expression] = STATE(6050),
    [sym_string_get_expression] = STATE(6050),
    [sym_bigarray_get_expression] = STATE(6050),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(1125),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(1961),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(20493),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(2065),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(2067),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(2069),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2071),
    [anon_sym_function] = ACTIONS(2073),
    [anon_sym_try] = ACTIONS(2075),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2077),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1126] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8306),
    [sym__sequence_expression] = STATE(8188),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(1126),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1127] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12757),
    [sym__sequence_expression] = STATE(16601),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(20144),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1127),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1128] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18501),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1128),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1129] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19785),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1129),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1130] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17812),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1130),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1131] = {
    [sym_value_definition] = STATE(18535),
    [sym__simple_expression] = STATE(2430),
    [sym__expression] = STATE(10576),
    [sym__sequence_expression] = STATE(8257),
    [sym_typed_expression] = STATE(5411),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5411),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5411),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(5160),
    [sym_array_get_expression] = STATE(5160),
    [sym_string_get_expression] = STATE(5160),
    [sym_bigarray_get_expression] = STATE(5160),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5411),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(1131),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym_sign_operator] = STATE(1986),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__instance_variable_name] = STATE(18550),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [sym__lowercase_identifier] = ACTIONS(1171),
    [anon_sym_let] = ACTIONS(1173),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_LBRACK] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_LBRACE] = ACTIONS(1181),
    [anon_sym_object] = ACTIONS(1183),
    [anon_sym_fun] = ACTIONS(1185),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1187),
    [anon_sym_if] = ACTIONS(1189),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1191),
    [anon_sym_function] = ACTIONS(1193),
    [anon_sym_try] = ACTIONS(1195),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1197),
    [anon_sym_LBRACE_LT] = ACTIONS(1199),
    [anon_sym_begin] = ACTIONS(1201),
    [sym_ocamlyacc_value] = ACTIONS(1203),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1205),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1207),
    [aux_sym_number_token1] = ACTIONS(1209),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_prefix_operator] = ACTIONS(1215),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1217),
    [sym__uppercase_identifier] = ACTIONS(1219),
    [aux_sym_tag_token1] = ACTIONS(1221),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1132] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8383),
    [sym__sequence_expression] = STATE(10551),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(1132),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1133] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(11902),
    [sym__sequence_expression] = STATE(10687),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(1133),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1134] = {
    [sym_value_definition] = STATE(18030),
    [sym__simple_expression] = STATE(301),
    [sym__expression] = STATE(8264),
    [sym__sequence_expression] = STATE(7482),
    [sym_typed_expression] = STATE(3052),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3052),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3052),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2963),
    [sym_array_get_expression] = STATE(2963),
    [sym_string_get_expression] = STATE(2963),
    [sym_bigarray_get_expression] = STATE(2963),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3052),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(1134),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym_sign_operator] = STATE(1958),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__instance_variable_name] = STATE(18008),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [sym__lowercase_identifier] = ACTIONS(295),
    [anon_sym_let] = ACTIONS(299),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_fun] = ACTIONS(313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_if] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(319),
    [anon_sym_function] = ACTIONS(321),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3119),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3121),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(349),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1135] = {
    [sym_value_definition] = STATE(17729),
    [sym__simple_expression] = STATE(2474),
    [sym__expression] = STATE(11972),
    [sym__sequence_expression] = STATE(10565),
    [sym_typed_expression] = STATE(6258),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6258),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6258),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6104),
    [sym_array_get_expression] = STATE(6104),
    [sym_string_get_expression] = STATE(6104),
    [sym_bigarray_get_expression] = STATE(6104),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6258),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(1135),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym_sign_operator] = STATE(1847),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__instance_variable_name] = STATE(17706),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [sym__lowercase_identifier] = ACTIONS(2465),
    [anon_sym_let] = ACTIONS(2467),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_fun] = ACTIONS(2479),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_if] = ACTIONS(2483),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2485),
    [anon_sym_function] = ACTIONS(2487),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2511),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1136] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18494),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1136),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1137] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18493),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1137),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1138] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18491),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1138),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1139] = {
    [sym_value_definition] = STATE(17729),
    [sym__simple_expression] = STATE(2474),
    [sym__expression] = STATE(11972),
    [sym__sequence_expression] = STATE(10680),
    [sym_typed_expression] = STATE(6258),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6258),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6258),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6104),
    [sym_array_get_expression] = STATE(6104),
    [sym_string_get_expression] = STATE(6104),
    [sym_bigarray_get_expression] = STATE(6104),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6258),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(1139),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym_sign_operator] = STATE(1847),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__instance_variable_name] = STATE(17706),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [sym__lowercase_identifier] = ACTIONS(2465),
    [anon_sym_let] = ACTIONS(2467),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_fun] = ACTIONS(2479),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_if] = ACTIONS(2483),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2485),
    [anon_sym_function] = ACTIONS(2487),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2511),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1140] = {
    [sym_value_definition] = STATE(17729),
    [sym__simple_expression] = STATE(2474),
    [sym__expression] = STATE(11972),
    [sym__sequence_expression] = STATE(10679),
    [sym_typed_expression] = STATE(6258),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6258),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6258),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6104),
    [sym_array_get_expression] = STATE(6104),
    [sym_string_get_expression] = STATE(6104),
    [sym_bigarray_get_expression] = STATE(6104),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6258),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(1140),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym_sign_operator] = STATE(1847),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__instance_variable_name] = STATE(17706),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [sym__lowercase_identifier] = ACTIONS(2465),
    [anon_sym_let] = ACTIONS(2467),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_fun] = ACTIONS(2479),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_if] = ACTIONS(2483),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2485),
    [anon_sym_function] = ACTIONS(2487),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2511),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1141] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(17790),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1141),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1142] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10108),
    [sym__sequence_expression] = STATE(13087),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(1142),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1143] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18481),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1143),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1144] = {
    [sym_value_definition] = STATE(17729),
    [sym__simple_expression] = STATE(2474),
    [sym__expression] = STATE(11972),
    [sym__sequence_expression] = STATE(10678),
    [sym_typed_expression] = STATE(6258),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6258),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6258),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6104),
    [sym_array_get_expression] = STATE(6104),
    [sym_string_get_expression] = STATE(6104),
    [sym_bigarray_get_expression] = STATE(6104),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6258),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(1144),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym_sign_operator] = STATE(1847),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__instance_variable_name] = STATE(17706),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [sym__lowercase_identifier] = ACTIONS(2465),
    [anon_sym_let] = ACTIONS(2467),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_fun] = ACTIONS(2479),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_if] = ACTIONS(2483),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2485),
    [anon_sym_function] = ACTIONS(2487),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2511),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1145] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19787),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1145),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1146] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(12568),
    [sym__sequence_expression] = STATE(16924),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(1146),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1147] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18480),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1147),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1148] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18479),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1148),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1149] = {
    [sym_value_definition] = STATE(17729),
    [sym__simple_expression] = STATE(2474),
    [sym__expression] = STATE(11972),
    [sym__sequence_expression] = STATE(10659),
    [sym_typed_expression] = STATE(6258),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6258),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6258),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6104),
    [sym_array_get_expression] = STATE(6104),
    [sym_string_get_expression] = STATE(6104),
    [sym_bigarray_get_expression] = STATE(6104),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6258),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(1149),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym_sign_operator] = STATE(1847),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__instance_variable_name] = STATE(17706),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [sym__lowercase_identifier] = ACTIONS(2465),
    [anon_sym_let] = ACTIONS(2467),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_fun] = ACTIONS(2479),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_if] = ACTIONS(2483),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2485),
    [anon_sym_function] = ACTIONS(2487),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2511),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1150] = {
    [sym_value_definition] = STATE(17729),
    [sym__simple_expression] = STATE(2474),
    [sym__expression] = STATE(11972),
    [sym__sequence_expression] = STATE(10474),
    [sym_typed_expression] = STATE(6258),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6258),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6258),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6104),
    [sym_array_get_expression] = STATE(6104),
    [sym_string_get_expression] = STATE(6104),
    [sym_bigarray_get_expression] = STATE(6104),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6258),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(1150),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym_sign_operator] = STATE(1847),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__instance_variable_name] = STATE(17706),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [sym__lowercase_identifier] = ACTIONS(2465),
    [anon_sym_let] = ACTIONS(2467),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_fun] = ACTIONS(2479),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_if] = ACTIONS(2483),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2485),
    [anon_sym_function] = ACTIONS(2487),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2511),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1151] = {
    [sym_value_definition] = STATE(17729),
    [sym__simple_expression] = STATE(2474),
    [sym__expression] = STATE(11972),
    [sym__sequence_expression] = STATE(10371),
    [sym_typed_expression] = STATE(6258),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6258),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6258),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6104),
    [sym_array_get_expression] = STATE(6104),
    [sym_string_get_expression] = STATE(6104),
    [sym_bigarray_get_expression] = STATE(6104),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6258),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(1151),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym_sign_operator] = STATE(1847),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__instance_variable_name] = STATE(17706),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [sym__lowercase_identifier] = ACTIONS(2465),
    [anon_sym_let] = ACTIONS(2467),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_fun] = ACTIONS(2479),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_if] = ACTIONS(2483),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2485),
    [anon_sym_function] = ACTIONS(2487),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2511),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1152] = {
    [sym_value_definition] = STATE(18535),
    [sym__simple_expression] = STATE(2430),
    [sym__expression] = STATE(10576),
    [sym__sequence_expression] = STATE(8220),
    [sym_typed_expression] = STATE(5411),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5411),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5411),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(5160),
    [sym_array_get_expression] = STATE(5160),
    [sym_string_get_expression] = STATE(5160),
    [sym_bigarray_get_expression] = STATE(5160),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5411),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(1152),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym_sign_operator] = STATE(1986),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__instance_variable_name] = STATE(18550),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [sym__lowercase_identifier] = ACTIONS(1171),
    [anon_sym_let] = ACTIONS(1173),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_LBRACK] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_LBRACE] = ACTIONS(1181),
    [anon_sym_object] = ACTIONS(1183),
    [anon_sym_fun] = ACTIONS(1185),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1187),
    [anon_sym_if] = ACTIONS(1189),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1191),
    [anon_sym_function] = ACTIONS(1193),
    [anon_sym_try] = ACTIONS(1195),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1197),
    [anon_sym_LBRACE_LT] = ACTIONS(1199),
    [anon_sym_begin] = ACTIONS(1201),
    [sym_ocamlyacc_value] = ACTIONS(1203),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1205),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1207),
    [aux_sym_number_token1] = ACTIONS(1209),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_prefix_operator] = ACTIONS(1215),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1217),
    [sym__uppercase_identifier] = ACTIONS(1219),
    [aux_sym_tag_token1] = ACTIONS(1221),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1153] = {
    [sym_value_definition] = STATE(19151),
    [sym__simple_expression] = STATE(549),
    [sym__expression] = STATE(8333),
    [sym__sequence_expression] = STATE(8203),
    [sym_typed_expression] = STATE(3704),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3704),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3704),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3058),
    [sym_array_get_expression] = STATE(3058),
    [sym_string_get_expression] = STATE(3058),
    [sym_bigarray_get_expression] = STATE(3058),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3704),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(1153),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym_sign_operator] = STATE(1807),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__instance_variable_name] = STATE(19067),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [sym__lowercase_identifier] = ACTIONS(527),
    [anon_sym_let] = ACTIONS(529),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_fun] = ACTIONS(541),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(545),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(547),
    [anon_sym_function] = ACTIONS(549),
    [anon_sym_try] = ACTIONS(551),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3129),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(573),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1154] = {
    [sym_value_definition] = STATE(18535),
    [sym__simple_expression] = STATE(2430),
    [sym__expression] = STATE(10576),
    [sym__sequence_expression] = STATE(8219),
    [sym_typed_expression] = STATE(5411),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5411),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5411),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(5160),
    [sym_array_get_expression] = STATE(5160),
    [sym_string_get_expression] = STATE(5160),
    [sym_bigarray_get_expression] = STATE(5160),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5411),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(1154),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym_sign_operator] = STATE(1986),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__instance_variable_name] = STATE(18550),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [sym__lowercase_identifier] = ACTIONS(1171),
    [anon_sym_let] = ACTIONS(1173),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_LBRACK] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_LBRACE] = ACTIONS(1181),
    [anon_sym_object] = ACTIONS(1183),
    [anon_sym_fun] = ACTIONS(1185),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1187),
    [anon_sym_if] = ACTIONS(1189),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1191),
    [anon_sym_function] = ACTIONS(1193),
    [anon_sym_try] = ACTIONS(1195),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1197),
    [anon_sym_LBRACE_LT] = ACTIONS(1199),
    [anon_sym_begin] = ACTIONS(1201),
    [sym_ocamlyacc_value] = ACTIONS(1203),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1205),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1207),
    [aux_sym_number_token1] = ACTIONS(1209),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_prefix_operator] = ACTIONS(1215),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1217),
    [sym__uppercase_identifier] = ACTIONS(1219),
    [aux_sym_tag_token1] = ACTIONS(1221),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1155] = {
    [sym_value_definition] = STATE(19151),
    [sym__simple_expression] = STATE(549),
    [sym__expression] = STATE(8333),
    [sym__sequence_expression] = STATE(8244),
    [sym_typed_expression] = STATE(3704),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3704),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3704),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3058),
    [sym_array_get_expression] = STATE(3058),
    [sym_string_get_expression] = STATE(3058),
    [sym_bigarray_get_expression] = STATE(3058),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3704),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(1155),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym_sign_operator] = STATE(1807),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__instance_variable_name] = STATE(19067),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [sym__lowercase_identifier] = ACTIONS(527),
    [anon_sym_let] = ACTIONS(529),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_fun] = ACTIONS(541),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(545),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(547),
    [anon_sym_function] = ACTIONS(549),
    [anon_sym_try] = ACTIONS(551),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3129),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(573),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1156] = {
    [sym_value_definition] = STATE(19151),
    [sym__simple_expression] = STATE(549),
    [sym__expression] = STATE(8333),
    [sym__sequence_expression] = STATE(8243),
    [sym_typed_expression] = STATE(3704),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3704),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3704),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3058),
    [sym_array_get_expression] = STATE(3058),
    [sym_string_get_expression] = STATE(3058),
    [sym_bigarray_get_expression] = STATE(3058),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3704),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(1156),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym_sign_operator] = STATE(1807),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__instance_variable_name] = STATE(19067),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [sym__lowercase_identifier] = ACTIONS(527),
    [anon_sym_let] = ACTIONS(529),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_fun] = ACTIONS(541),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(545),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(547),
    [anon_sym_function] = ACTIONS(549),
    [anon_sym_try] = ACTIONS(551),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3129),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(573),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1157] = {
    [sym_value_definition] = STATE(19151),
    [sym__simple_expression] = STATE(549),
    [sym__expression] = STATE(8333),
    [sym__sequence_expression] = STATE(8127),
    [sym_typed_expression] = STATE(3704),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3704),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3704),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3058),
    [sym_array_get_expression] = STATE(3058),
    [sym_string_get_expression] = STATE(3058),
    [sym_bigarray_get_expression] = STATE(3058),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3704),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(1157),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym_sign_operator] = STATE(1807),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__instance_variable_name] = STATE(19067),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [sym__lowercase_identifier] = ACTIONS(527),
    [anon_sym_let] = ACTIONS(529),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_fun] = ACTIONS(541),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(545),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(547),
    [anon_sym_function] = ACTIONS(549),
    [anon_sym_try] = ACTIONS(551),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3129),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(573),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1158] = {
    [sym_value_definition] = STATE(19151),
    [sym__simple_expression] = STATE(549),
    [sym__expression] = STATE(8333),
    [sym__sequence_expression] = STATE(8116),
    [sym_typed_expression] = STATE(3704),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3704),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3704),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3058),
    [sym_array_get_expression] = STATE(3058),
    [sym_string_get_expression] = STATE(3058),
    [sym_bigarray_get_expression] = STATE(3058),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3704),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(1158),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym_sign_operator] = STATE(1807),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__instance_variable_name] = STATE(19067),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [sym__lowercase_identifier] = ACTIONS(527),
    [anon_sym_let] = ACTIONS(529),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_fun] = ACTIONS(541),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(545),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(547),
    [anon_sym_function] = ACTIONS(549),
    [anon_sym_try] = ACTIONS(551),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3129),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(573),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1159] = {
    [sym_value_definition] = STATE(19151),
    [sym__simple_expression] = STATE(549),
    [sym__expression] = STATE(8333),
    [sym__sequence_expression] = STATE(8188),
    [sym_typed_expression] = STATE(3704),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3704),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3704),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3058),
    [sym_array_get_expression] = STATE(3058),
    [sym_string_get_expression] = STATE(3058),
    [sym_bigarray_get_expression] = STATE(3058),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3704),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(1159),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym_sign_operator] = STATE(1807),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__instance_variable_name] = STATE(19067),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [sym__lowercase_identifier] = ACTIONS(527),
    [anon_sym_let] = ACTIONS(529),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_fun] = ACTIONS(541),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(545),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(547),
    [anon_sym_function] = ACTIONS(549),
    [anon_sym_try] = ACTIONS(551),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3129),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(573),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1160] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19804),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1160),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1161] = {
    [sym_value_definition] = STATE(19151),
    [sym__simple_expression] = STATE(549),
    [sym__expression] = STATE(8333),
    [sym__sequence_expression] = STATE(8185),
    [sym_typed_expression] = STATE(3704),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3704),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3704),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3058),
    [sym_array_get_expression] = STATE(3058),
    [sym_string_get_expression] = STATE(3058),
    [sym_bigarray_get_expression] = STATE(3058),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3704),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(1161),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym_sign_operator] = STATE(1807),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__instance_variable_name] = STATE(19067),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [sym__lowercase_identifier] = ACTIONS(527),
    [anon_sym_let] = ACTIONS(529),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_fun] = ACTIONS(541),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(545),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(547),
    [anon_sym_function] = ACTIONS(549),
    [anon_sym_try] = ACTIONS(551),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3129),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(573),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1162] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19496),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1162),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1163] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8306),
    [sym__sequence_expression] = STATE(8185),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(1163),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1164] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10108),
    [sym__sequence_expression] = STATE(13092),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(1164),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1165] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12672),
    [sym__sequence_expression] = STATE(16758),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(1165),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1166] = {
    [sym_value_definition] = STATE(18535),
    [sym__simple_expression] = STATE(2430),
    [sym__expression] = STATE(10576),
    [sym__sequence_expression] = STATE(8211),
    [sym_typed_expression] = STATE(5411),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5411),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5411),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(5160),
    [sym_array_get_expression] = STATE(5160),
    [sym_string_get_expression] = STATE(5160),
    [sym_bigarray_get_expression] = STATE(5160),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5411),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(1166),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym_sign_operator] = STATE(1986),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__instance_variable_name] = STATE(18550),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [sym__lowercase_identifier] = ACTIONS(1171),
    [anon_sym_let] = ACTIONS(1173),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_LBRACK] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_LBRACE] = ACTIONS(1181),
    [anon_sym_object] = ACTIONS(1183),
    [anon_sym_fun] = ACTIONS(1185),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1187),
    [anon_sym_if] = ACTIONS(1189),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1191),
    [anon_sym_function] = ACTIONS(1193),
    [anon_sym_try] = ACTIONS(1195),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1197),
    [anon_sym_LBRACE_LT] = ACTIONS(1199),
    [anon_sym_begin] = ACTIONS(1201),
    [sym_ocamlyacc_value] = ACTIONS(1203),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1205),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1207),
    [aux_sym_number_token1] = ACTIONS(1209),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_prefix_operator] = ACTIONS(1215),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1217),
    [sym__uppercase_identifier] = ACTIONS(1219),
    [aux_sym_tag_token1] = ACTIONS(1221),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1167] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(5419),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1167),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1168] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18415),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1168),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1169] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(20220),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1169),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1170] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16757),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1170),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1171] = {
    [sym_value_definition] = STATE(19248),
    [sym__simple_expression] = STATE(1582),
    [sym__expression] = STATE(8468),
    [sym__sequence_expression] = STATE(8244),
    [sym_typed_expression] = STATE(4041),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4041),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4041),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3928),
    [sym_array_get_expression] = STATE(3928),
    [sym_string_get_expression] = STATE(3928),
    [sym_bigarray_get_expression] = STATE(3928),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4041),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(1171),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__instance_variable_name] = STATE(19258),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [sym__lowercase_identifier] = ACTIONS(857),
    [anon_sym_let] = ACTIONS(859),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_fun] = ACTIONS(871),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(877),
    [anon_sym_function] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(881),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3103),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3105),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(903),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1172] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18835),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1172),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1173] = {
    [sym_value_definition] = STATE(18535),
    [sym__simple_expression] = STATE(2430),
    [sym__expression] = STATE(10576),
    [sym__sequence_expression] = STATE(8162),
    [sym_typed_expression] = STATE(5411),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5411),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5411),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(5160),
    [sym_array_get_expression] = STATE(5160),
    [sym_string_get_expression] = STATE(5160),
    [sym_bigarray_get_expression] = STATE(5160),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5411),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(1173),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym_sign_operator] = STATE(1986),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__instance_variable_name] = STATE(18550),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [sym__lowercase_identifier] = ACTIONS(1171),
    [anon_sym_let] = ACTIONS(1173),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_LBRACK] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_LBRACE] = ACTIONS(1181),
    [anon_sym_object] = ACTIONS(1183),
    [anon_sym_fun] = ACTIONS(1185),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1187),
    [anon_sym_if] = ACTIONS(1189),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1191),
    [anon_sym_function] = ACTIONS(1193),
    [anon_sym_try] = ACTIONS(1195),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1197),
    [anon_sym_LBRACE_LT] = ACTIONS(1199),
    [anon_sym_begin] = ACTIONS(1201),
    [sym_ocamlyacc_value] = ACTIONS(1203),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1205),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1207),
    [aux_sym_number_token1] = ACTIONS(1209),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_prefix_operator] = ACTIONS(1215),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1217),
    [sym__uppercase_identifier] = ACTIONS(1219),
    [aux_sym_tag_token1] = ACTIONS(1221),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1174] = {
    [sym_value_definition] = STATE(18990),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12014),
    [sym__sequence_expression] = STATE(8271),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6117),
    [sym_array_get_expression] = STATE(6117),
    [sym_string_get_expression] = STATE(6117),
    [sym_bigarray_get_expression] = STATE(6117),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(1174),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2049),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(18809),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2519),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2531),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2535),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2537),
    [anon_sym_function] = ACTIONS(2539),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2563),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1175] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18844),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1175),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1176] = {
    [sym_value_definition] = STATE(19385),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11179),
    [sym__sequence_expression] = STATE(10687),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5503),
    [sym_array_get_expression] = STATE(5503),
    [sym_string_get_expression] = STATE(5503),
    [sym_bigarray_get_expression] = STATE(5503),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(1176),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(1823),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(20481),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1279),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1291),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1295),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1177] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18845),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1177),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1178] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18872),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1178),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1179] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(19196),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1179),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1180] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(19201),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1180),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1181] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18406),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1181),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1182] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18405),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1182),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1183] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18403),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1183),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1184] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18392),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1184),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1185] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18391),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1185),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1186] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18390),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1186),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1187] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12659),
    [sym__sequence_expression] = STATE(7951),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1187),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1188] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18881),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1188),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1189] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17695),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1189),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1190] = {
    [sym_value_definition] = STATE(18990),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12014),
    [sym__sequence_expression] = STATE(8277),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6117),
    [sym_array_get_expression] = STATE(6117),
    [sym_string_get_expression] = STATE(6117),
    [sym_bigarray_get_expression] = STATE(6117),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(1190),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2049),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(18809),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2519),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2531),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2535),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2537),
    [anon_sym_function] = ACTIONS(2539),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2563),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1191] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(19281),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1191),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1192] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18882),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1192),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1193] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16649),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1193),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1194] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16851),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1194),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1195] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19867),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1195),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1196] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19868),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1196),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1197] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12672),
    [sym__sequence_expression] = STATE(16736),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(1197),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1198] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12659),
    [sym__sequence_expression] = STATE(7948),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1198),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1199] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12659),
    [sym__sequence_expression] = STATE(7947),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1199),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1200] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17692),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1200),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1201] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12659),
    [sym__sequence_expression] = STATE(7937),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1201),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1202] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1202),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1203] = {
    [sym_value_definition] = STATE(18990),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12014),
    [sym__sequence_expression] = STATE(8257),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6117),
    [sym_array_get_expression] = STATE(6117),
    [sym_string_get_expression] = STATE(6117),
    [sym_bigarray_get_expression] = STATE(6117),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(1203),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2049),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(18809),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2519),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2531),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2535),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2537),
    [anon_sym_function] = ACTIONS(2539),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2563),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1204] = {
    [sym_value_definition] = STATE(18990),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12014),
    [sym__sequence_expression] = STATE(8220),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6117),
    [sym_array_get_expression] = STATE(6117),
    [sym_string_get_expression] = STATE(6117),
    [sym_bigarray_get_expression] = STATE(6117),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(1204),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2049),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(18809),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2519),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2531),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2535),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2537),
    [anon_sym_function] = ACTIONS(2539),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2563),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1205] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18327),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1205),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1206] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19877),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1206),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1207] = {
    [sym_value_definition] = STATE(18990),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12014),
    [sym__sequence_expression] = STATE(8219),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6117),
    [sym_array_get_expression] = STATE(6117),
    [sym_string_get_expression] = STATE(6117),
    [sym_bigarray_get_expression] = STATE(6117),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(1207),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2049),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(18809),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2519),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2531),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2535),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2537),
    [anon_sym_function] = ACTIONS(2539),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2563),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1208] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17445),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1208),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1209] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(20173),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1209),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1210] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12672),
    [sym__sequence_expression] = STATE(16733),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(1210),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1211] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19891),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1211),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1212] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(19687),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1212),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1213] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(19705),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1213),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1214] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12659),
    [sym__sequence_expression] = STATE(7929),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1214),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1215] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19894),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1215),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1216] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18321),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1216),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1217] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19895),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1217),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1218] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19896),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1218),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1219] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18320),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1219),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1220] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18319),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1220),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1221] = {
    [sym_value_definition] = STATE(18705),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(11969),
    [sym__sequence_expression] = STATE(8207),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6123),
    [sym_array_get_expression] = STATE(6123),
    [sym_string_get_expression] = STATE(6123),
    [sym_bigarray_get_expression] = STATE(6123),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(1221),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2250),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18531),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2355),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2367),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2373),
    [anon_sym_function] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2399),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1222] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17664),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1222),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1223] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19919),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1223),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1224] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19920),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1224),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1225] = {
    [sym_value_definition] = STATE(18620),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(10491),
    [sym__sequence_expression] = STATE(8757),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5197),
    [sym_array_get_expression] = STATE(5197),
    [sym_string_get_expression] = STATE(5197),
    [sym_bigarray_get_expression] = STATE(5197),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(1225),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(2020),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(18637),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(1117),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(1129),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(1133),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1135),
    [anon_sym_function] = ACTIONS(1137),
    [anon_sym_try] = ACTIONS(1139),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1165),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1226] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8410),
    [sym__sequence_expression] = STATE(10500),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(1226),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1227] = {
    [sym_value_definition] = STATE(18620),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(10491),
    [sym__sequence_expression] = STATE(8017),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5197),
    [sym_array_get_expression] = STATE(5197),
    [sym_string_get_expression] = STATE(5197),
    [sym_bigarray_get_expression] = STATE(5197),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(1227),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(2020),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(18637),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(1117),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(1129),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(1133),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1135),
    [anon_sym_function] = ACTIONS(1137),
    [anon_sym_try] = ACTIONS(1139),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1165),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1228] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19921),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1228),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1229] = {
    [sym_value_definition] = STATE(18149),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11677),
    [sym__sequence_expression] = STATE(8757),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5662),
    [sym_array_get_expression] = STATE(5662),
    [sym_string_get_expression] = STATE(5662),
    [sym_bigarray_get_expression] = STATE(5662),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(1229),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(2277),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(18127),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1389),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1391),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1393),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1230] = {
    [sym_value_definition] = STATE(19080),
    [sym__simple_expression] = STATE(506),
    [sym__expression] = STATE(8293),
    [sym__sequence_expression] = STATE(5419),
    [sym_typed_expression] = STATE(3532),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3532),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3532),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3084),
    [sym_array_get_expression] = STATE(3084),
    [sym_string_get_expression] = STATE(3084),
    [sym_bigarray_get_expression] = STATE(3084),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3532),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(1230),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym_sign_operator] = STATE(2274),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__instance_variable_name] = STATE(18842),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [sym__lowercase_identifier] = ACTIONS(475),
    [anon_sym_let] = ACTIONS(477),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_fun] = ACTIONS(489),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(495),
    [anon_sym_function] = ACTIONS(497),
    [anon_sym_try] = ACTIONS(499),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3123),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3125),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(521),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1231] = {
    [sym_value_definition] = STATE(17889),
    [sym__simple_expression] = STATE(2457),
    [sym__expression] = STATE(11791),
    [sym__sequence_expression] = STATE(10565),
    [sym_typed_expression] = STATE(6138),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6138),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6138),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5776),
    [sym_array_get_expression] = STATE(5776),
    [sym_string_get_expression] = STATE(5776),
    [sym_bigarray_get_expression] = STATE(5776),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6138),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(1231),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym_sign_operator] = STATE(1969),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__instance_variable_name] = STATE(17866),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [sym__lowercase_identifier] = ACTIONS(1395),
    [anon_sym_let] = ACTIONS(1397),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_fun] = ACTIONS(1409),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1415),
    [anon_sym_function] = ACTIONS(1417),
    [anon_sym_try] = ACTIONS(1419),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1441),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1232] = {
    [sym_value_definition] = STATE(17889),
    [sym__simple_expression] = STATE(2457),
    [sym__expression] = STATE(11791),
    [sym__sequence_expression] = STATE(10680),
    [sym_typed_expression] = STATE(6138),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6138),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6138),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5776),
    [sym_array_get_expression] = STATE(5776),
    [sym_string_get_expression] = STATE(5776),
    [sym_bigarray_get_expression] = STATE(5776),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6138),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(1232),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym_sign_operator] = STATE(1969),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__instance_variable_name] = STATE(17866),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [sym__lowercase_identifier] = ACTIONS(1395),
    [anon_sym_let] = ACTIONS(1397),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_fun] = ACTIONS(1409),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1415),
    [anon_sym_function] = ACTIONS(1417),
    [anon_sym_try] = ACTIONS(1419),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1441),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1233] = {
    [sym_value_definition] = STATE(17889),
    [sym__simple_expression] = STATE(2457),
    [sym__expression] = STATE(11791),
    [sym__sequence_expression] = STATE(10679),
    [sym_typed_expression] = STATE(6138),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6138),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6138),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5776),
    [sym_array_get_expression] = STATE(5776),
    [sym_string_get_expression] = STATE(5776),
    [sym_bigarray_get_expression] = STATE(5776),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6138),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(1233),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym_sign_operator] = STATE(1969),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__instance_variable_name] = STATE(17866),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [sym__lowercase_identifier] = ACTIONS(1395),
    [anon_sym_let] = ACTIONS(1397),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_fun] = ACTIONS(1409),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1415),
    [anon_sym_function] = ACTIONS(1417),
    [anon_sym_try] = ACTIONS(1419),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1441),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1234] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18306),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1234),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1235] = {
    [sym_value_definition] = STATE(17889),
    [sym__simple_expression] = STATE(2457),
    [sym__expression] = STATE(11791),
    [sym__sequence_expression] = STATE(10678),
    [sym_typed_expression] = STATE(6138),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6138),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6138),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5776),
    [sym_array_get_expression] = STATE(5776),
    [sym_string_get_expression] = STATE(5776),
    [sym_bigarray_get_expression] = STATE(5776),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6138),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(1235),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym_sign_operator] = STATE(1969),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__instance_variable_name] = STATE(17866),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [sym__lowercase_identifier] = ACTIONS(1395),
    [anon_sym_let] = ACTIONS(1397),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_fun] = ACTIONS(1409),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1415),
    [anon_sym_function] = ACTIONS(1417),
    [anon_sym_try] = ACTIONS(1419),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1441),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1236] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18301),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1236),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1237] = {
    [sym_value_definition] = STATE(17889),
    [sym__simple_expression] = STATE(2457),
    [sym__expression] = STATE(11791),
    [sym__sequence_expression] = STATE(10659),
    [sym_typed_expression] = STATE(6138),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6138),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6138),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5776),
    [sym_array_get_expression] = STATE(5776),
    [sym_string_get_expression] = STATE(5776),
    [sym_bigarray_get_expression] = STATE(5776),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6138),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(1237),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym_sign_operator] = STATE(1969),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__instance_variable_name] = STATE(17866),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [sym__lowercase_identifier] = ACTIONS(1395),
    [anon_sym_let] = ACTIONS(1397),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_fun] = ACTIONS(1409),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1415),
    [anon_sym_function] = ACTIONS(1417),
    [anon_sym_try] = ACTIONS(1419),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1441),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1238] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18300),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1238),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1239] = {
    [sym_value_definition] = STATE(17889),
    [sym__simple_expression] = STATE(2457),
    [sym__expression] = STATE(11791),
    [sym__sequence_expression] = STATE(10474),
    [sym_typed_expression] = STATE(6138),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6138),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6138),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5776),
    [sym_array_get_expression] = STATE(5776),
    [sym_string_get_expression] = STATE(5776),
    [sym_bigarray_get_expression] = STATE(5776),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6138),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(1239),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym_sign_operator] = STATE(1969),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__instance_variable_name] = STATE(17866),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [sym__lowercase_identifier] = ACTIONS(1395),
    [anon_sym_let] = ACTIONS(1397),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_fun] = ACTIONS(1409),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1415),
    [anon_sym_function] = ACTIONS(1417),
    [anon_sym_try] = ACTIONS(1419),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1441),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1240] = {
    [sym_value_definition] = STATE(17889),
    [sym__simple_expression] = STATE(2457),
    [sym__expression] = STATE(11791),
    [sym__sequence_expression] = STATE(10371),
    [sym_typed_expression] = STATE(6138),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6138),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6138),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5776),
    [sym_array_get_expression] = STATE(5776),
    [sym_string_get_expression] = STATE(5776),
    [sym_bigarray_get_expression] = STATE(5776),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6138),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(1240),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym_sign_operator] = STATE(1969),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__instance_variable_name] = STATE(17866),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [sym__lowercase_identifier] = ACTIONS(1395),
    [anon_sym_let] = ACTIONS(1397),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_fun] = ACTIONS(1409),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1415),
    [anon_sym_function] = ACTIONS(1417),
    [anon_sym_try] = ACTIONS(1419),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1441),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1241] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(19815),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1241),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1242] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18909),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1242),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1243] = {
    [sym_value_definition] = STATE(18620),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(10491),
    [sym__sequence_expression] = STATE(7976),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5197),
    [sym_array_get_expression] = STATE(5197),
    [sym_string_get_expression] = STATE(5197),
    [sym_bigarray_get_expression] = STATE(5197),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(1243),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(2020),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(18637),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(1117),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(1129),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(1133),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1135),
    [anon_sym_function] = ACTIONS(1137),
    [anon_sym_try] = ACTIONS(1139),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1165),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1244] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18918),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1244),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1245] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17663),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1245),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1246] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19937),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1246),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1247] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17672),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1247),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1248] = {
    [sym_value_definition] = STATE(18620),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(10491),
    [sym__sequence_expression] = STATE(7951),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5197),
    [sym_array_get_expression] = STATE(5197),
    [sym_string_get_expression] = STATE(5197),
    [sym_bigarray_get_expression] = STATE(5197),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(1248),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(2020),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(18637),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(1117),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(1129),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(1133),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1135),
    [anon_sym_function] = ACTIONS(1137),
    [anon_sym_try] = ACTIONS(1139),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1165),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1249] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18919),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1249),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1250] = {
    [sym_value_definition] = STATE(19248),
    [sym__simple_expression] = STATE(1582),
    [sym__expression] = STATE(8468),
    [sym__sequence_expression] = STATE(8203),
    [sym_typed_expression] = STATE(4041),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4041),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4041),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3928),
    [sym_array_get_expression] = STATE(3928),
    [sym_string_get_expression] = STATE(3928),
    [sym_bigarray_get_expression] = STATE(3928),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4041),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(1250),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__instance_variable_name] = STATE(19258),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [sym__lowercase_identifier] = ACTIONS(857),
    [anon_sym_let] = ACTIONS(859),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_fun] = ACTIONS(871),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(877),
    [anon_sym_function] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(881),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3103),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3105),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(903),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1251] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12672),
    [sym__sequence_expression] = STATE(16717),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(1251),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1252] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16716),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1252),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1253] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18242),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1253),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1254] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18945),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1254),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1255] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18954),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1255),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1256] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(17596),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1256),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1257] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16880),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1257),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1258] = {
    [sym_value_definition] = STATE(18990),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12014),
    [sym__sequence_expression] = STATE(8211),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6117),
    [sym_array_get_expression] = STATE(6117),
    [sym_string_get_expression] = STATE(6117),
    [sym_bigarray_get_expression] = STATE(6117),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(1258),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2049),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(18809),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2519),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2531),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2535),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2537),
    [anon_sym_function] = ACTIONS(2539),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2563),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1259] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18232),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1259),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1260] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18231),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1260),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1261] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18202),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1261),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1262] = {
    [sym_value_definition] = STATE(18990),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12014),
    [sym__sequence_expression] = STATE(8162),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6117),
    [sym_array_get_expression] = STATE(6117),
    [sym_string_get_expression] = STATE(6117),
    [sym_bigarray_get_expression] = STATE(6117),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(1262),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2049),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(18809),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2519),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2531),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2535),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2537),
    [anon_sym_function] = ACTIONS(2539),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2563),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1263] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17412),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1263),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1264] = {
    [sym_value_definition] = STATE(17966),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12567),
    [sym__sequence_expression] = STATE(8757),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(1264),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2141),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(17979),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1265] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19999),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1265),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1266] = {
    [sym_value_definition] = STATE(19248),
    [sym__simple_expression] = STATE(1582),
    [sym__expression] = STATE(8468),
    [sym__sequence_expression] = STATE(8243),
    [sym_typed_expression] = STATE(4041),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4041),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4041),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3928),
    [sym_array_get_expression] = STATE(3928),
    [sym_string_get_expression] = STATE(3928),
    [sym_bigarray_get_expression] = STATE(3928),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4041),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(1266),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__instance_variable_name] = STATE(19258),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [sym__lowercase_identifier] = ACTIONS(857),
    [anon_sym_let] = ACTIONS(859),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_fun] = ACTIONS(871),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(877),
    [anon_sym_function] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(881),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3103),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3105),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(903),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1267] = {
    [sym_value_definition] = STATE(18620),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(10491),
    [sym__sequence_expression] = STATE(7948),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5197),
    [sym_array_get_expression] = STATE(5197),
    [sym_string_get_expression] = STATE(5197),
    [sym_bigarray_get_expression] = STATE(5197),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(1267),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(2020),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(18637),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(1117),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(1129),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(1133),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1135),
    [anon_sym_function] = ACTIONS(1137),
    [anon_sym_try] = ACTIONS(1139),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1165),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1268] = {
    [sym_value_definition] = STATE(19248),
    [sym__simple_expression] = STATE(1582),
    [sym__expression] = STATE(8468),
    [sym__sequence_expression] = STATE(8127),
    [sym_typed_expression] = STATE(4041),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4041),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4041),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3928),
    [sym_array_get_expression] = STATE(3928),
    [sym_string_get_expression] = STATE(3928),
    [sym_bigarray_get_expression] = STATE(3928),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4041),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(1268),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__instance_variable_name] = STATE(19258),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [sym__lowercase_identifier] = ACTIONS(857),
    [anon_sym_let] = ACTIONS(859),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_fun] = ACTIONS(871),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(877),
    [anon_sym_function] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(881),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3103),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3105),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(903),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1269] = {
    [sym_value_definition] = STATE(18620),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(10491),
    [sym__sequence_expression] = STATE(7947),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5197),
    [sym_array_get_expression] = STATE(5197),
    [sym_string_get_expression] = STATE(5197),
    [sym_bigarray_get_expression] = STATE(5197),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(1269),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(2020),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(18637),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(1117),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(1129),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(1133),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1135),
    [anon_sym_function] = ACTIONS(1137),
    [anon_sym_try] = ACTIONS(1139),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1165),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1270] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18216),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1270),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1271] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18215),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1271),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1272] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18214),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1272),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1273] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20268),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1273),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1274] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18955),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1274),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1275] = {
    [sym_value_definition] = STATE(18620),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(10491),
    [sym__sequence_expression] = STATE(7937),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5197),
    [sym_array_get_expression] = STATE(5197),
    [sym_string_get_expression] = STATE(5197),
    [sym_bigarray_get_expression] = STATE(5197),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(1275),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(2020),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(18637),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(1117),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(1129),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(1133),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1135),
    [anon_sym_function] = ACTIONS(1137),
    [anon_sym_try] = ACTIONS(1139),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1165),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1276] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17246),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1276),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1277] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16674),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1277),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1278] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10108),
    [sym__sequence_expression] = STATE(13102),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(1278),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1279] = {
    [sym_value_definition] = STATE(17889),
    [sym__simple_expression] = STATE(2457),
    [sym__expression] = STATE(11791),
    [sym__sequence_expression] = STATE(10687),
    [sym_typed_expression] = STATE(6138),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6138),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6138),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5776),
    [sym_array_get_expression] = STATE(5776),
    [sym_string_get_expression] = STATE(5776),
    [sym_bigarray_get_expression] = STATE(5776),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6138),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(1279),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym_sign_operator] = STATE(1969),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__instance_variable_name] = STATE(17866),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [sym__lowercase_identifier] = ACTIONS(1395),
    [anon_sym_let] = ACTIONS(1397),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_fun] = ACTIONS(1409),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1415),
    [anon_sym_function] = ACTIONS(1417),
    [anon_sym_try] = ACTIONS(1419),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1441),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1280] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20277),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1280),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1281] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12672),
    [sym__sequence_expression] = STATE(16675),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(1281),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1282] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8299),
    [sym__sequence_expression] = STATE(7482),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(1282),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1283] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(20072),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1283),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1284] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19183),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1284),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1285] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10108),
    [sym__sequence_expression] = STATE(13061),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(1285),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1286] = {
    [sym_value_definition] = STATE(20489),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(12039),
    [sym__sequence_expression] = STATE(8757),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6050),
    [sym_array_get_expression] = STATE(6050),
    [sym_string_get_expression] = STATE(6050),
    [sym_bigarray_get_expression] = STATE(6050),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(1286),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(1961),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(20493),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(2065),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(2067),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(2069),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2071),
    [anon_sym_function] = ACTIONS(2073),
    [anon_sym_try] = ACTIONS(2075),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2077),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1287] = {
    [sym_value_definition] = STATE(19248),
    [sym__simple_expression] = STATE(1582),
    [sym__expression] = STATE(8468),
    [sym__sequence_expression] = STATE(8116),
    [sym_typed_expression] = STATE(4041),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4041),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4041),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3928),
    [sym_array_get_expression] = STATE(3928),
    [sym_string_get_expression] = STATE(3928),
    [sym_bigarray_get_expression] = STATE(3928),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4041),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(1287),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__instance_variable_name] = STATE(19258),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [sym__lowercase_identifier] = ACTIONS(857),
    [anon_sym_let] = ACTIONS(859),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_fun] = ACTIONS(871),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(877),
    [anon_sym_function] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(881),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3103),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3105),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(903),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1288] = {
    [sym_value_definition] = STATE(19151),
    [sym__simple_expression] = STATE(549),
    [sym__expression] = STATE(8333),
    [sym__sequence_expression] = STATE(5419),
    [sym_typed_expression] = STATE(3704),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3704),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3704),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3058),
    [sym_array_get_expression] = STATE(3058),
    [sym_string_get_expression] = STATE(3058),
    [sym_bigarray_get_expression] = STATE(3058),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3704),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(1288),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym_sign_operator] = STATE(1807),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__instance_variable_name] = STATE(19067),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [sym__lowercase_identifier] = ACTIONS(527),
    [anon_sym_let] = ACTIONS(529),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_fun] = ACTIONS(541),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(545),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(547),
    [anon_sym_function] = ACTIONS(549),
    [anon_sym_try] = ACTIONS(551),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3129),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(573),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1289] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18156),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1289),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1290] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10108),
    [sym__sequence_expression] = STATE(13046),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(1290),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1291] = {
    [sym_value_definition] = STATE(18149),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11677),
    [sym__sequence_expression] = STATE(10565),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5662),
    [sym_array_get_expression] = STATE(5662),
    [sym_string_get_expression] = STATE(5662),
    [sym_bigarray_get_expression] = STATE(5662),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(1291),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(2277),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(18127),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1389),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1391),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1393),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1292] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(10965),
    [sym__sequence_expression] = STATE(8017),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1292),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1293] = {
    [sym_value_definition] = STATE(18149),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11677),
    [sym__sequence_expression] = STATE(10680),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5662),
    [sym_array_get_expression] = STATE(5662),
    [sym_string_get_expression] = STATE(5662),
    [sym_bigarray_get_expression] = STATE(5662),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(1293),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(2277),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(18127),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1389),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1391),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1393),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1294] = {
    [sym_value_definition] = STATE(18149),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11677),
    [sym__sequence_expression] = STATE(10679),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5662),
    [sym_array_get_expression] = STATE(5662),
    [sym_string_get_expression] = STATE(5662),
    [sym_bigarray_get_expression] = STATE(5662),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(1294),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(2277),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(18127),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1389),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1391),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1393),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1295] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19185),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1295),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1296] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10108),
    [sym__sequence_expression] = STATE(13011),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(1296),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1297] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19186),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1297),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1298] = {
    [sym_value_definition] = STATE(18149),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11677),
    [sym__sequence_expression] = STATE(10678),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5662),
    [sym_array_get_expression] = STATE(5662),
    [sym_string_get_expression] = STATE(5662),
    [sym_bigarray_get_expression] = STATE(5662),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(1298),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(2277),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(18127),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1389),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1391),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1393),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1299] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16516),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1299),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1300] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18147),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1300),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1301] = {
    [sym_value_definition] = STATE(19586),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8712),
    [sym__sequence_expression] = STATE(8185),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(1301),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1302] = {
    [sym_value_definition] = STATE(18149),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11677),
    [sym__sequence_expression] = STATE(10659),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5662),
    [sym_array_get_expression] = STATE(5662),
    [sym_string_get_expression] = STATE(5662),
    [sym_bigarray_get_expression] = STATE(5662),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(1302),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(2277),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(18127),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1389),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1391),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1393),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1303] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18145),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1303),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1304] = {
    [sym_value_definition] = STATE(18149),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11677),
    [sym__sequence_expression] = STATE(10474),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5662),
    [sym_array_get_expression] = STATE(5662),
    [sym_string_get_expression] = STATE(5662),
    [sym_bigarray_get_expression] = STATE(5662),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(1304),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(2277),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(18127),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1389),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1391),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1393),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1305] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18143),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1305),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1306] = {
    [sym_value_definition] = STATE(18149),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11677),
    [sym__sequence_expression] = STATE(10371),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5662),
    [sym_array_get_expression] = STATE(5662),
    [sym_string_get_expression] = STATE(5662),
    [sym_bigarray_get_expression] = STATE(5662),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(1306),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(2277),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(18127),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1389),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1391),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1393),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1307] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12672),
    [sym__sequence_expression] = STATE(16642),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(1307),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1308] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1308),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1309] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17624),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1309),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1310] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12674),
    [sym__sequence_expression] = STATE(7482),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(1310),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1311] = {
    [sym_value_definition] = STATE(19248),
    [sym__simple_expression] = STATE(1582),
    [sym__expression] = STATE(8468),
    [sym__sequence_expression] = STATE(8188),
    [sym_typed_expression] = STATE(4041),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4041),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4041),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3928),
    [sym_array_get_expression] = STATE(3928),
    [sym_string_get_expression] = STATE(3928),
    [sym_bigarray_get_expression] = STATE(3928),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4041),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(1311),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__instance_variable_name] = STATE(19258),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [sym__lowercase_identifier] = ACTIONS(857),
    [anon_sym_let] = ACTIONS(859),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_fun] = ACTIONS(871),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(877),
    [anon_sym_function] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(881),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3103),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3105),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(903),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1312] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17625),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1312),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1313] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18133),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1313),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1314] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17626),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1314),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1315] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17630),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1315),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1316] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(20050),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1316),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1317] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(20048),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1317),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1318] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18132),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1318),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1319] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18129),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1319),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1320] = {
    [sym_value_definition] = STATE(19248),
    [sym__simple_expression] = STATE(1582),
    [sym__expression] = STATE(8468),
    [sym__sequence_expression] = STATE(8185),
    [sym_typed_expression] = STATE(4041),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4041),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4041),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3928),
    [sym_array_get_expression] = STATE(3928),
    [sym_string_get_expression] = STATE(3928),
    [sym_bigarray_get_expression] = STATE(3928),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4041),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(1320),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__instance_variable_name] = STATE(19258),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [sym__lowercase_identifier] = ACTIONS(857),
    [anon_sym_let] = ACTIONS(859),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_fun] = ACTIONS(871),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(877),
    [anon_sym_function] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(881),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3103),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3105),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(903),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1321] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17385),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1321),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1322] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(20047),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1322),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1323] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12276),
    [sym__sequence_expression] = STATE(10565),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(1323),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1324] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12276),
    [sym__sequence_expression] = STATE(10680),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(1324),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1325] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16907),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1325),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1326] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(10965),
    [sym__sequence_expression] = STATE(7976),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1326),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1327] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12276),
    [sym__sequence_expression] = STATE(10679),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(1327),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1328] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10108),
    [sym__sequence_expression] = STATE(13064),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(1328),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1329] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17632),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1329),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1330] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(20027),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1330),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1331] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(20026),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1331),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1332] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(20025),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1332),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1333] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12276),
    [sym__sequence_expression] = STATE(10678),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(1333),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1334] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19193),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1334),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1335] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10108),
    [sym__sequence_expression] = STATE(13060),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(1335),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1336] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12276),
    [sym__sequence_expression] = STATE(10659),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(1336),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1337] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(18074),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1337),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1338] = {
    [sym_value_definition] = STATE(17729),
    [sym__simple_expression] = STATE(2474),
    [sym__expression] = STATE(11972),
    [sym__sequence_expression] = STATE(10687),
    [sym_typed_expression] = STATE(6258),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6258),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6258),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6104),
    [sym_array_get_expression] = STATE(6104),
    [sym_string_get_expression] = STATE(6104),
    [sym_bigarray_get_expression] = STATE(6104),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6258),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(1338),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym_sign_operator] = STATE(1847),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__instance_variable_name] = STATE(17706),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [sym__lowercase_identifier] = ACTIONS(2465),
    [anon_sym_let] = ACTIONS(2467),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_fun] = ACTIONS(2479),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_if] = ACTIONS(2483),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2485),
    [anon_sym_function] = ACTIONS(2487),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2511),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1339] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17633),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1339),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1340] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19195),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1340),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1341] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(20018),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1341),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1342] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18071),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1342),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1343] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18070),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1343),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1344] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18069),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1344),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1345] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8383),
    [sym__sequence_expression] = STATE(7482),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(1345),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1346] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12672),
    [sym__sequence_expression] = STATE(16691),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(1346),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1347] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11810),
    [sym__sequence_expression] = STATE(13994),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(1347),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1348] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18059),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1348),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1349] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18058),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1349),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1350] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19198),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1350),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1351] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18057),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1351),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1352] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16532),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1352),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1353] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12276),
    [sym__sequence_expression] = STATE(10474),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(1353),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1354] = {
    [sym_value_definition] = STATE(18447),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12466),
    [sym__sequence_expression] = STATE(8757),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6602),
    [sym_array_get_expression] = STATE(6602),
    [sym_string_get_expression] = STATE(6602),
    [sym_bigarray_get_expression] = STATE(6602),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(1354),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(1952),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18459),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1355] = {
    [sym_value_definition] = STATE(18428),
    [sym__simple_expression] = STATE(2428),
    [sym__expression] = STATE(10224),
    [sym__sequence_expression] = STATE(8162),
    [sym_typed_expression] = STATE(5216),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5216),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5216),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4994),
    [sym_array_get_expression] = STATE(4994),
    [sym_string_get_expression] = STATE(4994),
    [sym_bigarray_get_expression] = STATE(4994),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5216),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(1355),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym_sign_operator] = STATE(2366),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__instance_variable_name] = STATE(18272),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [sym__lowercase_identifier] = ACTIONS(1061),
    [anon_sym_let] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_fun] = ACTIONS(1075),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_if] = ACTIONS(1079),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1081),
    [anon_sym_function] = ACTIONS(1083),
    [anon_sym_try] = ACTIONS(1085),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1109),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1356] = {
    [sym_value_definition] = STATE(18428),
    [sym__simple_expression] = STATE(2428),
    [sym__expression] = STATE(10224),
    [sym__sequence_expression] = STATE(8211),
    [sym_typed_expression] = STATE(5216),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5216),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5216),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4994),
    [sym_array_get_expression] = STATE(4994),
    [sym_string_get_expression] = STATE(4994),
    [sym_bigarray_get_expression] = STATE(4994),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5216),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(1356),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym_sign_operator] = STATE(2366),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__instance_variable_name] = STATE(18272),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [sym__lowercase_identifier] = ACTIONS(1061),
    [anon_sym_let] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_fun] = ACTIONS(1075),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_if] = ACTIONS(1079),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1081),
    [anon_sym_function] = ACTIONS(1083),
    [anon_sym_try] = ACTIONS(1085),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1109),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1357] = {
    [sym_value_definition] = STATE(18428),
    [sym__simple_expression] = STATE(2428),
    [sym__expression] = STATE(10224),
    [sym__sequence_expression] = STATE(8219),
    [sym_typed_expression] = STATE(5216),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5216),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5216),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4994),
    [sym_array_get_expression] = STATE(4994),
    [sym_string_get_expression] = STATE(4994),
    [sym_bigarray_get_expression] = STATE(4994),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5216),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(1357),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym_sign_operator] = STATE(2366),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__instance_variable_name] = STATE(18272),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [sym__lowercase_identifier] = ACTIONS(1061),
    [anon_sym_let] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_fun] = ACTIONS(1075),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_if] = ACTIONS(1079),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1081),
    [anon_sym_function] = ACTIONS(1083),
    [anon_sym_try] = ACTIONS(1085),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1109),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1358] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10108),
    [sym__sequence_expression] = STATE(13030),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(1358),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1359] = {
    [sym_value_definition] = STATE(18428),
    [sym__simple_expression] = STATE(2428),
    [sym__expression] = STATE(10224),
    [sym__sequence_expression] = STATE(8220),
    [sym_typed_expression] = STATE(5216),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5216),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5216),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4994),
    [sym_array_get_expression] = STATE(4994),
    [sym_string_get_expression] = STATE(4994),
    [sym_bigarray_get_expression] = STATE(4994),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5216),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(1359),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym_sign_operator] = STATE(2366),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__instance_variable_name] = STATE(18272),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [sym__lowercase_identifier] = ACTIONS(1061),
    [anon_sym_let] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_fun] = ACTIONS(1075),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_if] = ACTIONS(1079),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1081),
    [anon_sym_function] = ACTIONS(1083),
    [anon_sym_try] = ACTIONS(1085),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1109),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1360] = {
    [sym_value_definition] = STATE(18428),
    [sym__simple_expression] = STATE(2428),
    [sym__expression] = STATE(10224),
    [sym__sequence_expression] = STATE(8257),
    [sym_typed_expression] = STATE(5216),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5216),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5216),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4994),
    [sym_array_get_expression] = STATE(4994),
    [sym_string_get_expression] = STATE(4994),
    [sym_bigarray_get_expression] = STATE(4994),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5216),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(1360),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym_sign_operator] = STATE(2366),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__instance_variable_name] = STATE(18272),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [sym__lowercase_identifier] = ACTIONS(1061),
    [anon_sym_let] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_fun] = ACTIONS(1075),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_if] = ACTIONS(1079),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1081),
    [anon_sym_function] = ACTIONS(1083),
    [anon_sym_try] = ACTIONS(1085),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1109),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1361] = {
    [sym_value_definition] = STATE(18428),
    [sym__simple_expression] = STATE(2428),
    [sym__expression] = STATE(10224),
    [sym__sequence_expression] = STATE(8277),
    [sym_typed_expression] = STATE(5216),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5216),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5216),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4994),
    [sym_array_get_expression] = STATE(4994),
    [sym_string_get_expression] = STATE(4994),
    [sym_bigarray_get_expression] = STATE(4994),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5216),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(1361),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym_sign_operator] = STATE(2366),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__instance_variable_name] = STATE(18272),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [sym__lowercase_identifier] = ACTIONS(1061),
    [anon_sym_let] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_fun] = ACTIONS(1075),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_if] = ACTIONS(1079),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1081),
    [anon_sym_function] = ACTIONS(1083),
    [anon_sym_try] = ACTIONS(1085),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1109),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1362] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12276),
    [sym__sequence_expression] = STATE(10371),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(1362),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1363] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8306),
    [sym__sequence_expression] = STATE(7482),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(1363),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1364] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(5419),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1364),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1365] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(17946),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1365),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1366] = {
    [sym_value_definition] = STATE(18428),
    [sym__simple_expression] = STATE(2428),
    [sym__expression] = STATE(10224),
    [sym__sequence_expression] = STATE(8271),
    [sym_typed_expression] = STATE(5216),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5216),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5216),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4994),
    [sym_array_get_expression] = STATE(4994),
    [sym_string_get_expression] = STATE(4994),
    [sym_bigarray_get_expression] = STATE(4994),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5216),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(1366),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym_sign_operator] = STATE(2366),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__instance_variable_name] = STATE(18272),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [sym__lowercase_identifier] = ACTIONS(1061),
    [anon_sym_let] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_fun] = ACTIONS(1075),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_if] = ACTIONS(1079),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1081),
    [anon_sym_function] = ACTIONS(1083),
    [anon_sym_try] = ACTIONS(1085),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1109),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1367] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(11902),
    [sym__sequence_expression] = STATE(10565),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(1367),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1368] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(19303),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1368),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1369] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17352),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1369),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1370] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18003),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1370),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1371] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10108),
    [sym__sequence_expression] = STATE(13005),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(1371),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1372] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18001),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1372),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1373] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(18000),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1373),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1374] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(11902),
    [sym__sequence_expression] = STATE(10680),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(1374),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1375] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(11902),
    [sym__sequence_expression] = STATE(10679),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(1375),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1376] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(20189),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1376),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1377] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(11902),
    [sym__sequence_expression] = STATE(10678),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(1377),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1378] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17994),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1378),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1379] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17989),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1379),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1380] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(11902),
    [sym__sequence_expression] = STATE(10659),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(1380),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1381] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17988),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1381),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1382] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(20005),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1382),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1383] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12672),
    [sym__sequence_expression] = STATE(16695),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(1383),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1384] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(10965),
    [sym__sequence_expression] = STATE(7951),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1384),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1385] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16929),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1385),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1386] = {
    [sym_value_definition] = STATE(19248),
    [sym__simple_expression] = STATE(1582),
    [sym__expression] = STATE(8468),
    [sym__sequence_expression] = STATE(5419),
    [sym_typed_expression] = STATE(4041),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4041),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4041),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3928),
    [sym_array_get_expression] = STATE(3928),
    [sym_string_get_expression] = STATE(3928),
    [sym_bigarray_get_expression] = STATE(3928),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4041),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(1386),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__instance_variable_name] = STATE(19258),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [sym__lowercase_identifier] = ACTIONS(857),
    [anon_sym_let] = ACTIONS(859),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_fun] = ACTIONS(871),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(877),
    [anon_sym_function] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(881),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3103),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3105),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(903),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1387] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(17592),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1387),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1388] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19328),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1388),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1389] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(11902),
    [sym__sequence_expression] = STATE(10474),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(1389),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1390] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19998),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1390),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1391] = {
    [sym_value_definition] = STATE(19239),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9434),
    [sym__sequence_expression] = STATE(8207),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4721),
    [sym_array_get_expression] = STATE(4721),
    [sym_string_get_expression] = STATE(4721),
    [sym_bigarray_get_expression] = STATE(4721),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(1391),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(1935),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(19132),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(927),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(931),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(937),
    [anon_sym_function] = ACTIONS(939),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(967),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1392] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20462),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1392),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1393] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20461),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1393),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1394] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19331),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1394),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1395] = {
    [sym_value_definition] = STATE(18620),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(10491),
    [sym__sequence_expression] = STATE(7929),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5197),
    [sym_array_get_expression] = STATE(5197),
    [sym_string_get_expression] = STATE(5197),
    [sym_bigarray_get_expression] = STATE(5197),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(1395),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(2020),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(18637),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(1117),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(1129),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(1133),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1135),
    [anon_sym_function] = ACTIONS(1137),
    [anon_sym_try] = ACTIONS(1139),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1165),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1396] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(17945),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1396),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1397] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17940),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1397),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1398] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17855),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1398),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1399] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17934),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1399),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1400] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17927),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1400),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1401] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17926),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1401),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1402] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(10965),
    [sym__sequence_expression] = STATE(7948),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1402),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1403] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(10965),
    [sym__sequence_expression] = STATE(7947),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1403),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1404] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(10965),
    [sym__sequence_expression] = STATE(7937),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1404),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1405] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20411),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1405),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1406] = {
    [sym_value_definition] = STATE(19480),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8574),
    [sym__sequence_expression] = STATE(5419),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(1406),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_let] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3095),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3097),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1407] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10108),
    [sym__sequence_expression] = STATE(12939),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(1407),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1408] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17925),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1408),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1409] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11900),
    [sym__sequence_expression] = STATE(10474),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(1409),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1410] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(11902),
    [sym__sequence_expression] = STATE(10371),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(10590),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(1410),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1411] = {
    [sym_value_definition] = STATE(19480),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8574),
    [sym__sequence_expression] = STATE(8185),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(1411),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_let] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3095),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3097),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1412] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8410),
    [sym__sequence_expression] = STATE(10425),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(1412),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1413] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(20437),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1413),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1414] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19333),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1414),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1415] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11900),
    [sym__sequence_expression] = STATE(10371),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(1415),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1416] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12619),
    [sym__sequence_expression] = STATE(7929),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1416),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1417] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8299),
    [sym__sequence_expression] = STATE(8203),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(1417),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1418] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8299),
    [sym__sequence_expression] = STATE(8244),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(1418),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1419] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8299),
    [sym__sequence_expression] = STATE(8243),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(1419),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1420] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8299),
    [sym__sequence_expression] = STATE(8127),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(1420),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1421] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8299),
    [sym__sequence_expression] = STATE(8116),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(1421),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1422] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8299),
    [sym__sequence_expression] = STATE(8188),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(1422),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1423] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(10965),
    [sym__sequence_expression] = STATE(7929),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1423),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1424] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19339),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1424),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1425] = {
    [sym_value_definition] = STATE(18277),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(12620),
    [sym__sequence_expression] = STATE(8757),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6588),
    [sym_array_get_expression] = STATE(6588),
    [sym_string_get_expression] = STATE(6588),
    [sym_bigarray_get_expression] = STATE(6588),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(1425),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2201),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18286),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1426] = {
    [sym_value_definition] = STATE(18705),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(11969),
    [sym__sequence_expression] = STATE(8162),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6123),
    [sym_array_get_expression] = STATE(6123),
    [sym_string_get_expression] = STATE(6123),
    [sym_bigarray_get_expression] = STATE(6123),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(1426),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2250),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18531),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2355),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2367),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2373),
    [anon_sym_function] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2399),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1427] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17673),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1427),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1428] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(17880),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1428),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1429] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17874),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1429),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1430] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17873),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1430),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1431] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17872),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1431),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1432] = {
    [sym_value_definition] = STATE(18705),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(11969),
    [sym__sequence_expression] = STATE(8211),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6123),
    [sym_array_get_expression] = STATE(6123),
    [sym_string_get_expression] = STATE(6123),
    [sym_bigarray_get_expression] = STATE(6123),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(1432),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2250),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18531),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2355),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2367),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2373),
    [anon_sym_function] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2399),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1433] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17320),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1433),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1434] = {
    [sym_value_definition] = STATE(18705),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(11969),
    [sym__sequence_expression] = STATE(8219),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6123),
    [sym_array_get_expression] = STATE(6123),
    [sym_string_get_expression] = STATE(6123),
    [sym_bigarray_get_expression] = STATE(6123),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(1434),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2250),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18531),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2355),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2367),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2373),
    [anon_sym_function] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2399),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1435] = {
    [sym_value_definition] = STATE(18705),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(11969),
    [sym__sequence_expression] = STATE(8220),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6123),
    [sym_array_get_expression] = STATE(6123),
    [sym_string_get_expression] = STATE(6123),
    [sym_bigarray_get_expression] = STATE(6123),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(1435),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2250),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18531),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2355),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2367),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2373),
    [anon_sym_function] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2399),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1436] = {
    [sym_value_definition] = STATE(18705),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(11969),
    [sym__sequence_expression] = STATE(8257),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6123),
    [sym_array_get_expression] = STATE(6123),
    [sym_string_get_expression] = STATE(6123),
    [sym_bigarray_get_expression] = STATE(6123),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(1436),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2250),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18531),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2355),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2367),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2373),
    [anon_sym_function] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2399),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1437] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17863),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1437),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1438] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17862),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1438),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1439] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17859),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1439),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1440] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8299),
    [sym__sequence_expression] = STATE(8185),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(1440),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1441] = {
    [sym_value_definition] = STATE(18705),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(11969),
    [sym__sequence_expression] = STATE(8277),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6123),
    [sym_array_get_expression] = STATE(6123),
    [sym_string_get_expression] = STATE(6123),
    [sym_bigarray_get_expression] = STATE(6123),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(1441),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2250),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18531),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2355),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2367),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2373),
    [anon_sym_function] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2399),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1442] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10108),
    [sym__sequence_expression] = STATE(13029),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(1442),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1443] = {
    [sym_value_definition] = STATE(18705),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(11969),
    [sym__sequence_expression] = STATE(8271),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6123),
    [sym_array_get_expression] = STATE(6123),
    [sym_string_get_expression] = STATE(6123),
    [sym_bigarray_get_expression] = STATE(6123),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(1443),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2250),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18531),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2355),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2367),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2373),
    [anon_sym_function] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2399),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1444] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17674),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1444),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1445] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10108),
    [sym__sequence_expression] = STATE(13023),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(1445),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1446] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17675),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1446),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1447] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17681),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1447),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1448] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10108),
    [sym__sequence_expression] = STATE(13010),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(1448),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1449] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8410),
    [sym__sequence_expression] = STATE(10365),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(7585),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(1449),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1450] = {
    [sym_value_definition] = STATE(18797),
    [sym__simple_expression] = STATE(1527),
    [sym__expression] = STATE(8505),
    [sym__sequence_expression] = STATE(8203),
    [sym_typed_expression] = STATE(4161),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4161),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4161),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3909),
    [sym_array_get_expression] = STATE(3909),
    [sym_string_get_expression] = STATE(3909),
    [sym_bigarray_get_expression] = STATE(3909),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4161),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(1450),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym_sign_operator] = STATE(2091),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__instance_variable_name] = STATE(18811),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [sym__lowercase_identifier] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_fun] = ACTIONS(819),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_if] = ACTIONS(823),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(825),
    [anon_sym_function] = ACTIONS(827),
    [anon_sym_try] = ACTIONS(829),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3115),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3117),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(851),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1451] = {
    [sym_value_definition] = STATE(18797),
    [sym__simple_expression] = STATE(1527),
    [sym__expression] = STATE(8505),
    [sym__sequence_expression] = STATE(8244),
    [sym_typed_expression] = STATE(4161),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4161),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4161),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3909),
    [sym_array_get_expression] = STATE(3909),
    [sym_string_get_expression] = STATE(3909),
    [sym_bigarray_get_expression] = STATE(3909),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4161),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(1451),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym_sign_operator] = STATE(2091),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__instance_variable_name] = STATE(18811),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [sym__lowercase_identifier] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_fun] = ACTIONS(819),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_if] = ACTIONS(823),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(825),
    [anon_sym_function] = ACTIONS(827),
    [anon_sym_try] = ACTIONS(829),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3115),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3117),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(851),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1452] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17682),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1452),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1453] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17683),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1453),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1454] = {
    [sym_value_definition] = STATE(18797),
    [sym__simple_expression] = STATE(1527),
    [sym__expression] = STATE(8505),
    [sym__sequence_expression] = STATE(8243),
    [sym_typed_expression] = STATE(4161),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4161),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4161),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3909),
    [sym_array_get_expression] = STATE(3909),
    [sym_string_get_expression] = STATE(3909),
    [sym_bigarray_get_expression] = STATE(3909),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4161),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(1454),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym_sign_operator] = STATE(2091),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__instance_variable_name] = STATE(18811),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [sym__lowercase_identifier] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_fun] = ACTIONS(819),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_if] = ACTIONS(823),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(825),
    [anon_sym_function] = ACTIONS(827),
    [anon_sym_try] = ACTIONS(829),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3115),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3117),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(851),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1455] = {
    [sym_value_definition] = STATE(18797),
    [sym__simple_expression] = STATE(1527),
    [sym__expression] = STATE(8505),
    [sym__sequence_expression] = STATE(8127),
    [sym_typed_expression] = STATE(4161),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4161),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4161),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3909),
    [sym_array_get_expression] = STATE(3909),
    [sym_string_get_expression] = STATE(3909),
    [sym_bigarray_get_expression] = STATE(3909),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4161),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(1455),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym_sign_operator] = STATE(2091),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__instance_variable_name] = STATE(18811),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [sym__lowercase_identifier] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_fun] = ACTIONS(819),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_if] = ACTIONS(823),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(825),
    [anon_sym_function] = ACTIONS(827),
    [anon_sym_try] = ACTIONS(829),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3115),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3117),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(851),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1456] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10108),
    [sym__sequence_expression] = STATE(12999),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(1456),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1457] = {
    [sym_value_definition] = STATE(18990),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12014),
    [sym__sequence_expression] = STATE(8207),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6117),
    [sym_array_get_expression] = STATE(6117),
    [sym_string_get_expression] = STATE(6117),
    [sym_bigarray_get_expression] = STATE(6117),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(1457),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2049),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(18809),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2519),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2531),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2535),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2537),
    [anon_sym_function] = ACTIONS(2539),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2563),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1458] = {
    [sym_value_definition] = STATE(18797),
    [sym__simple_expression] = STATE(1527),
    [sym__expression] = STATE(8505),
    [sym__sequence_expression] = STATE(8116),
    [sym_typed_expression] = STATE(4161),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4161),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4161),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3909),
    [sym_array_get_expression] = STATE(3909),
    [sym_string_get_expression] = STATE(3909),
    [sym_bigarray_get_expression] = STATE(3909),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4161),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(1458),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym_sign_operator] = STATE(2091),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__instance_variable_name] = STATE(18811),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [sym__lowercase_identifier] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_fun] = ACTIONS(819),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_if] = ACTIONS(823),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(825),
    [anon_sym_function] = ACTIONS(827),
    [anon_sym_try] = ACTIONS(829),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3115),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3117),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(851),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1459] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10108),
    [sym__sequence_expression] = STATE(12997),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(1459),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1460] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19350),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1460),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1461] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(16986),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1461),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1462] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(19226),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1462),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1463] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(17781),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1463),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1464] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17810),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1464),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1465] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10108),
    [sym__sequence_expression] = STATE(12981),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(1465),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1466] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17809),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1466),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1467] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17808),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1467),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1468] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17800),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1468),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1469] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12672),
    [sym__sequence_expression] = STATE(16645),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(1469),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1470] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17799),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1470),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1471] = {
    [sym_value_definition] = STATE(18821),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12001),
    [sym__sequence_expression] = STATE(8207),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6118),
    [sym_array_get_expression] = STATE(6118),
    [sym_string_get_expression] = STATE(6118),
    [sym_bigarray_get_expression] = STATE(6118),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(1471),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(2170),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18670),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2415),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2433),
    [anon_sym_function] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2437),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2459),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1472] = {
    [sym_value_definition] = STATE(18797),
    [sym__simple_expression] = STATE(1527),
    [sym__expression] = STATE(8505),
    [sym__sequence_expression] = STATE(8188),
    [sym_typed_expression] = STATE(4161),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4161),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4161),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3909),
    [sym_array_get_expression] = STATE(3909),
    [sym_string_get_expression] = STATE(3909),
    [sym_bigarray_get_expression] = STATE(3909),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4161),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(1472),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym_sign_operator] = STATE(2091),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__instance_variable_name] = STATE(18811),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [sym__lowercase_identifier] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_fun] = ACTIONS(819),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_if] = ACTIONS(823),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(825),
    [anon_sym_function] = ACTIONS(827),
    [anon_sym_try] = ACTIONS(829),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3115),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3117),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(851),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1473] = {
    [sym_value_definition] = STATE(18447),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12466),
    [sym__sequence_expression] = STATE(8017),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6602),
    [sym_array_get_expression] = STATE(6602),
    [sym_string_get_expression] = STATE(6602),
    [sym_bigarray_get_expression] = STATE(6602),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(1473),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(1952),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18459),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1474] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11900),
    [sym__sequence_expression] = STATE(10659),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(1474),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1475] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17798),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1475),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1476] = {
    [sym_value_definition] = STATE(18797),
    [sym__simple_expression] = STATE(1527),
    [sym__expression] = STATE(8505),
    [sym__sequence_expression] = STATE(8185),
    [sym_typed_expression] = STATE(4161),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4161),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4161),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3909),
    [sym_array_get_expression] = STATE(3909),
    [sym_string_get_expression] = STATE(3909),
    [sym_bigarray_get_expression] = STATE(3909),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4161),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(1476),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym_sign_operator] = STATE(2091),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__instance_variable_name] = STATE(18811),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [sym__lowercase_identifier] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_fun] = ACTIONS(819),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_if] = ACTIONS(823),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(825),
    [anon_sym_function] = ACTIONS(827),
    [anon_sym_try] = ACTIONS(829),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3115),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3117),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(851),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1477] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11900),
    [sym__sequence_expression] = STATE(10565),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(1477),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1478] = {
    [sym_value_definition] = STATE(18108),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12418),
    [sym__sequence_expression] = STATE(8757),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6582),
    [sym_array_get_expression] = STATE(6582),
    [sym_string_get_expression] = STATE(6582),
    [sym_bigarray_get_expression] = STATE(6582),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(1478),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(1808),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18116),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2579),
    [anon_sym_function] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2583),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2585),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1479] = {
    [sym_value_definition] = STATE(18821),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12001),
    [sym__sequence_expression] = STATE(8162),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6118),
    [sym_array_get_expression] = STATE(6118),
    [sym_string_get_expression] = STATE(6118),
    [sym_bigarray_get_expression] = STATE(6118),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(1479),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(2170),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18670),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2415),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2433),
    [anon_sym_function] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2437),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2459),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1480] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(17691),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1480),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1481] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11810),
    [sym__sequence_expression] = STATE(13840),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(1481),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1482] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12619),
    [sym__sequence_expression] = STATE(7937),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1482),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1483] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17036),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1483),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1484] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12669),
    [sym__sequence_expression] = STATE(18986),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(1484),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1485] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12619),
    [sym__sequence_expression] = STATE(7947),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1485),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1486] = {
    [sym_value_definition] = STATE(18821),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12001),
    [sym__sequence_expression] = STATE(8211),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6118),
    [sym_array_get_expression] = STATE(6118),
    [sym_string_get_expression] = STATE(6118),
    [sym_bigarray_get_expression] = STATE(6118),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(1486),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(2170),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18670),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2415),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2433),
    [anon_sym_function] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2437),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2459),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1487] = {
    [sym_value_definition] = STATE(18821),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12001),
    [sym__sequence_expression] = STATE(8219),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6118),
    [sym_array_get_expression] = STATE(6118),
    [sym_string_get_expression] = STATE(6118),
    [sym_bigarray_get_expression] = STATE(6118),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(1487),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(2170),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18670),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2415),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2433),
    [anon_sym_function] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2437),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2459),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1488] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12700),
    [sym__sequence_expression] = STATE(17754),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1488),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1489] = {
    [sym_value_definition] = STATE(18821),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12001),
    [sym__sequence_expression] = STATE(8220),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6118),
    [sym_array_get_expression] = STATE(6118),
    [sym_string_get_expression] = STATE(6118),
    [sym_bigarray_get_expression] = STATE(6118),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(1489),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(2170),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18670),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2415),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2433),
    [anon_sym_function] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2437),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2459),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1490] = {
    [sym_value_definition] = STATE(18821),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12001),
    [sym__sequence_expression] = STATE(8257),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6118),
    [sym_array_get_expression] = STATE(6118),
    [sym_string_get_expression] = STATE(6118),
    [sym_bigarray_get_expression] = STATE(6118),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(1490),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(2170),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18670),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2415),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2433),
    [anon_sym_function] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2437),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2459),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1491] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11900),
    [sym__sequence_expression] = STATE(10678),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(1491),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1492] = {
    [sym_value_definition] = STATE(18821),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12001),
    [sym__sequence_expression] = STATE(8277),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6118),
    [sym_array_get_expression] = STATE(6118),
    [sym_string_get_expression] = STATE(6118),
    [sym_bigarray_get_expression] = STATE(6118),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(1492),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(2170),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18670),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2415),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2433),
    [anon_sym_function] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2437),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2459),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1493] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11900),
    [sym__sequence_expression] = STATE(10679),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(1493),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1494] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17747),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1494),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1495] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17746),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1495),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1496] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17745),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1496),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1497] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17736),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1497),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1498] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17735),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1498),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1499] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(17734),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1499),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1500] = {
    [sym_value_definition] = STATE(18821),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12001),
    [sym__sequence_expression] = STATE(8271),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6118),
    [sym_array_get_expression] = STATE(6118),
    [sym_string_get_expression] = STATE(6118),
    [sym_bigarray_get_expression] = STATE(6118),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_sequence_expression] = STATE(8213),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(1500),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(2170),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18670),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2415),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2433),
    [anon_sym_function] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2437),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2459),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1501] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12792),
    [sym__sequence_expression] = STATE(17289),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1501),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1502] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12619),
    [sym__sequence_expression] = STATE(7948),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1502),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1503] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12619),
    [sym__sequence_expression] = STATE(8017),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1503),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1504] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11900),
    [sym__sequence_expression] = STATE(10680),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(1504),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1505] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12619),
    [sym__sequence_expression] = STATE(7951),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1505),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1506] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11810),
    [sym__sequence_expression] = STATE(13858),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(1506),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1507] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12619),
    [sym__sequence_expression] = STATE(7976),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(8769),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1507),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1508] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11228),
    [sym__sequence_expression] = STATE(20174),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_sequence_expression] = STATE(5386),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1508),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1509] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12589),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1509),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3291),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1510] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12512),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1510),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3293),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1511] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1511),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3295),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1512] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1512),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3297),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1513] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1513),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3299),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1514] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1514),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3301),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1515] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1515),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3303),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1516] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12562),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1516),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3305),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1517] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12526),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1517),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3307),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1518] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1518),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3309),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1519] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1519),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3311),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1520] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1520),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3313),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1521] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1521),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3315),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1522] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1522),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3317),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1523] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12216),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1523),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3319),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1524] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12495),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1524),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3321),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1525] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12490),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1525),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3323),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1526] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12420),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1526),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3325),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1527] = {
    [sym__simple_expression] = STATE(4053),
    [sym_typed_expression] = STATE(4161),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_labeled_argument] = STATE(4613),
    [sym_prefix_expression] = STATE(4161),
    [sym_hash_expression] = STATE(4161),
    [sym_field_get_expression] = STATE(4161),
    [sym_array_get_expression] = STATE(4161),
    [sym_string_get_expression] = STATE(4161),
    [sym_bigarray_get_expression] = STATE(4161),
    [sym_coercion_expression] = STATE(4161),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(1527),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [aux_sym_class_application_repeat1] = STATE(2418),
    [sym__lowercase_identifier] = ACTIONS(3327),
    [anon_sym_SEMI_SEMI] = ACTIONS(3051),
    [anon_sym_let] = ACTIONS(3053),
    [anon_sym_TILDE] = ACTIONS(3329),
    [anon_sym_QMARK] = ACTIONS(3329),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_external] = ACTIONS(3053),
    [anon_sym_type] = ACTIONS(3053),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_DOT] = ACTIONS(3331),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_SEMI] = ACTIONS(3053),
    [anon_sym_exception] = ACTIONS(3053),
    [anon_sym_module] = ACTIONS(3053),
    [anon_sym_open] = ACTIONS(3053),
    [anon_sym_include] = ACTIONS(3053),
    [anon_sym_class] = ACTIONS(3053),
    [anon_sym_end] = ACTIONS(3053),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_POUND] = ACTIONS(3333),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_else] = ACTIONS(3053),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3053),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3051),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(839),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(841),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3051),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(3335),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym_let_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_directive_token1] = ACTIONS(3053),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1528] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12384),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1528),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3337),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1529] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12264),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1529),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3339),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1530] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1530),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3341),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1531] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1531),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3343),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1532] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1532),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3345),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1533] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1533),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3347),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1534] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1534),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3349),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1535] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1535),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3351),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1536] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1536),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3353),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1537] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1537),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3355),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1538] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1538),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3357),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1539] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12442),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1539),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3359),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1540] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1540),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3361),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1541] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1541),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3363),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1542] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1542),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3365),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1543] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12438),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1543),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3367),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1544] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12267),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1544),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3369),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1545] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12271),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1545),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3371),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1546] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1546),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3373),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1547] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1547),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3375),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1548] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1548),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3377),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1549] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1549),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3379),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1550] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1550),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3381),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1551] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1551),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3383),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1552] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1552),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3385),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1553] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12415),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1553),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3387),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1554] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12412),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1554),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3389),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1555] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1555),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3391),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1556] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1556),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3393),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1557] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12519),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1557),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3395),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1558] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1558),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3397),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1559] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12541),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1559),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3399),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1560] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1560),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3401),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1561] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1561),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3403),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1562] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1562),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3405),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1563] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1563),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3407),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1564] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12560),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1564),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3409),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1565] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12565),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1565),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3411),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1566] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12391),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1566),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3413),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1567] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12389),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1567),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3415),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1568] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1568),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3417),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1569] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1569),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3419),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1570] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1570),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3421),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1571] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1571),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3423),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1572] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1572),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3425),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1573] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1573),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3427),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1574] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1574),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3429),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1575] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1575),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3431),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1576] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12584),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1576),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3433),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1577] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12371),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1577),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3435),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1578] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12553),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1578),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3437),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1579] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12559),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1579),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3439),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1580] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12367),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1580),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3441),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1581] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12365),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1581),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3443),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1582] = {
    [sym__simple_expression] = STATE(4094),
    [sym_typed_expression] = STATE(4041),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_labeled_argument] = STATE(4575),
    [sym_prefix_expression] = STATE(4041),
    [sym_hash_expression] = STATE(4041),
    [sym_field_get_expression] = STATE(4041),
    [sym_array_get_expression] = STATE(4041),
    [sym_string_get_expression] = STATE(4041),
    [sym_bigarray_get_expression] = STATE(4041),
    [sym_coercion_expression] = STATE(4041),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(1582),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [aux_sym_class_application_repeat1] = STATE(2415),
    [sym__lowercase_identifier] = ACTIONS(3445),
    [anon_sym_SEMI_SEMI] = ACTIONS(3051),
    [anon_sym_let] = ACTIONS(3053),
    [anon_sym_TILDE] = ACTIONS(3447),
    [anon_sym_QMARK] = ACTIONS(3447),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_external] = ACTIONS(3053),
    [anon_sym_type] = ACTIONS(3053),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_RBRACK] = ACTIONS(3051),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_DOT] = ACTIONS(3449),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_SEMI] = ACTIONS(3053),
    [anon_sym_exception] = ACTIONS(3053),
    [anon_sym_module] = ACTIONS(3053),
    [anon_sym_open] = ACTIONS(3053),
    [anon_sym_include] = ACTIONS(3053),
    [anon_sym_class] = ACTIONS(3053),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_POUND] = ACTIONS(3451),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_else] = ACTIONS(3053),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3053),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3051),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(891),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(893),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3051),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(3453),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym_let_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_directive_token1] = ACTIONS(3053),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1583] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1583),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3455),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1584] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1584),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3457),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1585] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1585),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3459),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1586] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1586),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3461),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1587] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1587),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3463),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1588] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1588),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3465),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1589] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1589),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3467),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1590] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1590),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3469),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1591] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12341),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1591),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3471),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1592] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12339),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1592),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3473),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1593] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12571),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1593),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3475),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1594] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12617),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1594),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3477),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1595] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1595),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3479),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1596] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1596),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3481),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1597] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1597),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3483),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1598] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1598),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3485),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1599] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12261),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1599),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3487),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1600] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12306),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1600),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3489),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1601] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1601),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3491),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1602] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1602),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3493),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1603] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12300),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1603),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3495),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1604] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12250),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1604),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3497),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1605] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1605),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3499),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1606] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1606),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3501),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1607] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1607),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3503),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1608] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1608),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3505),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1609] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1609),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3507),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1610] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1610),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3509),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1611] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1611),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3511),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1612] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12260),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1612),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3513),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1613] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1613),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3515),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1614] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12256),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1614),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3517),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1615] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1615),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3519),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1616] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1616),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3521),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1617] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1617),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3523),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1618] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1618),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3525),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1619] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1619),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3527),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1620] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1620),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3529),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1621] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1621),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3531),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1622] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1622),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3533),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1623] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1623),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3535),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1624] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12360),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1624),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3537),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1625] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12377),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1625),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3539),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1626] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1626),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3541),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1627] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1627),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3543),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1628] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12235),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1628),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3545),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1629] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12233),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1629),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3547),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1630] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1630),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3549),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1631] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1631),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3551),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1632] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1632),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3553),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1633] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1633),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3555),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1634] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1634),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3557),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1635] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1635),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3559),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1636] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1636),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3561),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1637] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1637),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3563),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1638] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12583),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1638),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3565),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1639] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1639),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3567),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1640] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12573),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1640),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3569),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1641] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12524),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1641),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3571),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1642] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12217),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1642),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3573),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1643] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1643),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3575),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1644] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1644),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3577),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1645] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1645),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3579),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1646] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1646),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3581),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1647] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1647),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3583),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1648] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1648),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3585),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1649] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1649),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3587),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1650] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1650),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3589),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1651] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12272),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1651),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3591),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1652] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1652),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3593),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1653] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1653),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3595),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1654] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12273),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1654),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3597),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1655] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1655),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3599),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1656] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1656),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3601),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1657] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12246),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1657),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3603),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1658] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12247),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1658),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3605),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1659] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1659),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3607),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1660] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1660),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3609),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1661] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1661),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3611),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1662] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1662),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3613),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1663] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1663),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3615),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1664] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1664),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3617),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1665] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12513),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1665),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3619),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1666] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12509),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1666),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3621),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1667] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1667),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3623),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1668] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1668),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3625),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1669] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1669),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3627),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1670] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12262),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1670),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3629),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1671] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12269),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1671),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3631),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1672] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1672),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3633),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1673] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1673),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3635),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1674] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1674),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3637),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1675] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1675),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3639),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1676] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1676),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3641),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1677] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1677),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3643),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1678] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12317),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1678),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3645),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1679] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12320),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1679),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3647),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1680] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1680),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3649),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1681] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12352),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1681),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3651),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1682] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12363),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1682),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3653),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1683] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1683),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3655),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1684] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1684),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3657),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1685] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1685),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3659),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1686] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12370),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1686),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3661),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1687] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1687),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3663),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1688] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12373),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1688),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3665),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1689] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12212),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1689),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3667),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1690] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12421),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1690),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3669),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1691] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1691),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3671),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1692] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1692),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3673),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1693] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1693),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3675),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1694] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1694),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3677),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1695] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1695),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3679),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1696] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1696),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3681),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1697] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1697),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3683),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1698] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1698),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3685),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1699] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1699),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3687),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1700] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1700),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3689),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1701] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1701),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3691),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1702] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1702),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3693),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1703] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12497),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1703),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3695),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1704] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12542),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1704),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3697),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1705] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12546),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1705),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3699),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1706] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1706),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3701),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1707] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12586),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1707),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3703),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1708] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1708),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3705),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1709] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12338),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1709),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3707),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1710] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12332),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1710),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3709),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1711] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1711),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3711),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1712] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12608),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1712),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3713),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1713] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12613),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1713),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3715),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1714] = {
    [sym__simple_expression] = STATE(3046),
    [sym_typed_expression] = STATE(3052),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_labeled_argument] = STATE(4042),
    [sym_prefix_expression] = STATE(3052),
    [sym_hash_expression] = STATE(3052),
    [sym_field_get_expression] = STATE(3052),
    [sym_array_get_expression] = STATE(3052),
    [sym_string_get_expression] = STATE(3052),
    [sym_bigarray_get_expression] = STATE(3052),
    [sym_coercion_expression] = STATE(3052),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(1714),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [aux_sym_class_application_repeat1] = STATE(1714),
    [sym__lowercase_identifier] = ACTIONS(3717),
    [anon_sym_SEMI_SEMI] = ACTIONS(3720),
    [anon_sym_let] = ACTIONS(3722),
    [anon_sym_and] = ACTIONS(3722),
    [anon_sym_TILDE] = ACTIONS(3724),
    [anon_sym_QMARK] = ACTIONS(3724),
    [anon_sym_LPAREN] = ACTIONS(3727),
    [anon_sym_external] = ACTIONS(3722),
    [anon_sym_type] = ACTIONS(3722),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(3730),
    [anon_sym_true] = ACTIONS(3733),
    [anon_sym_false] = ACTIONS(3733),
    [anon_sym_LBRACE] = ACTIONS(3736),
    [anon_sym_SEMI] = ACTIONS(3722),
    [anon_sym_exception] = ACTIONS(3722),
    [anon_sym_module] = ACTIONS(3722),
    [anon_sym_open] = ACTIONS(3722),
    [anon_sym_include] = ACTIONS(3722),
    [anon_sym_class] = ACTIONS(3722),
    [anon_sym_end] = ACTIONS(3722),
    [anon_sym_object] = ACTIONS(3739),
    [anon_sym_in] = ACTIONS(3722),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(3742),
    [anon_sym_else] = ACTIONS(3722),
    [anon_sym_new] = ACTIONS(3745),
    [anon_sym_LBRACE_LT] = ACTIONS(3748),
    [anon_sym_begin] = ACTIONS(3751),
    [sym_ocamlyacc_value] = ACTIONS(3754),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3722),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3720),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3757),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3760),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3720),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3720),
    [aux_sym_number_token1] = ACTIONS(3763),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(3766),
    [anon_sym_DQUOTE] = ACTIONS(3769),
    [sym_prefix_operator] = ACTIONS(3772),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym_let_operator] = ACTIONS(3720),
    [sym_let_and_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(3775),
    [aux_sym_directive_token1] = ACTIONS(3720),
    [aux_sym_tag_token1] = ACTIONS(3778),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1715] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1715),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3781),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1716] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1716),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3783),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1717] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1717),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3785),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1718] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1718),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3787),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1719] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1719),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3789),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1720] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1720),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3791),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1721] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1721),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3793),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1722] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1722),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3795),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1723] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12585),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1723),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3797),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1724] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12592),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1724),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3799),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1725] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12552),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1725),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3801),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1726] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1726),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3803),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1727] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1727),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3805),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1728] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12558),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1728),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3807),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1729] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1729),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3809),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1730] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1730),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3811),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1731] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12609),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1731),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3813),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1732] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1732),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3815),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1733] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1733),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3817),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1734] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12614),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1734),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3819),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1735] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1735),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3821),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1736] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1736),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3823),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1737] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1737),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3825),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1738] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1738),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3827),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1739] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1739),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3829),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1740] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1740),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3831),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1741] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1741),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3833),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1742] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1742),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3835),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1743] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1743),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3837),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1744] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1744),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3839),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1745] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1745),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3841),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1746] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1746),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3843),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1747] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1747),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3845),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1748] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1748),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3847),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1749] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1749),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3849),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1750] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12623),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1750),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3851),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1751] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12606),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1751),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3853),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1752] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12594),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1752),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3855),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1753] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12588),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1753),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3857),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1754] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1754),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3859),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1755] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1755),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3861),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1756] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12510),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1756),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3863),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1757] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12521),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1757),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3865),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1758] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1758),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3867),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1759] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1759),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3869),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1760] = {
    [sym__simple_expression] = STATE(3167),
    [sym_typed_expression] = STATE(3176),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_labeled_argument] = STATE(4052),
    [sym_prefix_expression] = STATE(3176),
    [sym_hash_expression] = STATE(3176),
    [sym_field_get_expression] = STATE(3176),
    [sym_array_get_expression] = STATE(3176),
    [sym_string_get_expression] = STATE(3176),
    [sym_bigarray_get_expression] = STATE(3176),
    [sym_coercion_expression] = STATE(3176),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(1760),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [aux_sym_class_application_repeat1] = STATE(1760),
    [sym__lowercase_identifier] = ACTIONS(3871),
    [anon_sym_SEMI_SEMI] = ACTIONS(3720),
    [anon_sym_let] = ACTIONS(3722),
    [anon_sym_and] = ACTIONS(3722),
    [anon_sym_TILDE] = ACTIONS(3874),
    [anon_sym_QMARK] = ACTIONS(3874),
    [anon_sym_LPAREN] = ACTIONS(3877),
    [anon_sym_external] = ACTIONS(3722),
    [anon_sym_type] = ACTIONS(3722),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(3880),
    [anon_sym_RBRACK] = ACTIONS(3720),
    [anon_sym_true] = ACTIONS(3883),
    [anon_sym_false] = ACTIONS(3883),
    [anon_sym_LBRACE] = ACTIONS(3886),
    [anon_sym_SEMI] = ACTIONS(3722),
    [anon_sym_exception] = ACTIONS(3722),
    [anon_sym_module] = ACTIONS(3722),
    [anon_sym_open] = ACTIONS(3722),
    [anon_sym_include] = ACTIONS(3722),
    [anon_sym_class] = ACTIONS(3722),
    [anon_sym_object] = ACTIONS(3889),
    [anon_sym_in] = ACTIONS(3722),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(3892),
    [anon_sym_else] = ACTIONS(3722),
    [anon_sym_new] = ACTIONS(3895),
    [anon_sym_LBRACE_LT] = ACTIONS(3898),
    [anon_sym_begin] = ACTIONS(3901),
    [sym_ocamlyacc_value] = ACTIONS(3904),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3722),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3720),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3907),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3910),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3720),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3720),
    [aux_sym_number_token1] = ACTIONS(3913),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(3916),
    [anon_sym_DQUOTE] = ACTIONS(3919),
    [sym_prefix_operator] = ACTIONS(3922),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym_let_operator] = ACTIONS(3720),
    [sym_let_and_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(3925),
    [aux_sym_directive_token1] = ACTIONS(3720),
    [aux_sym_tag_token1] = ACTIONS(3928),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1761] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1761),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3931),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1762] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12278),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1762),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3933),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1763] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1763),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3935),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1764] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1764),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3937),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1765] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1765),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3939),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1766] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12280),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1766),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3941),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1767] = {
    [sym__simple_expression] = STATE(3167),
    [sym_typed_expression] = STATE(3176),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_labeled_argument] = STATE(4052),
    [sym_prefix_expression] = STATE(3176),
    [sym_hash_expression] = STATE(3176),
    [sym_field_get_expression] = STATE(3176),
    [sym_array_get_expression] = STATE(3176),
    [sym_string_get_expression] = STATE(3176),
    [sym_bigarray_get_expression] = STATE(3176),
    [sym_coercion_expression] = STATE(3176),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(1767),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [aux_sym_class_application_repeat1] = STATE(1760),
    [sym__lowercase_identifier] = ACTIONS(3077),
    [anon_sym_SEMI_SEMI] = ACTIONS(3943),
    [anon_sym_let] = ACTIONS(3945),
    [anon_sym_and] = ACTIONS(3945),
    [anon_sym_TILDE] = ACTIONS(3079),
    [anon_sym_QMARK] = ACTIONS(3079),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_external] = ACTIONS(3945),
    [anon_sym_type] = ACTIONS(3945),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_RBRACK] = ACTIONS(3943),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_SEMI] = ACTIONS(3945),
    [anon_sym_exception] = ACTIONS(3945),
    [anon_sym_module] = ACTIONS(3945),
    [anon_sym_open] = ACTIONS(3945),
    [anon_sym_include] = ACTIONS(3945),
    [anon_sym_class] = ACTIONS(3945),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_in] = ACTIONS(3945),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_else] = ACTIONS(3945),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3945),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3943),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(389),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(391),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3943),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3943),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym_let_operator] = ACTIONS(3943),
    [sym_let_and_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_directive_token1] = ACTIONS(3943),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1768] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12618),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1768),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3947),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1769] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1769),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3949),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1770] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12602),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1770),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3951),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1771] = {
    [sym__simple_expression] = STATE(3046),
    [sym_typed_expression] = STATE(3052),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_labeled_argument] = STATE(4042),
    [sym_prefix_expression] = STATE(3052),
    [sym_hash_expression] = STATE(3052),
    [sym_field_get_expression] = STATE(3052),
    [sym_array_get_expression] = STATE(3052),
    [sym_string_get_expression] = STATE(3052),
    [sym_bigarray_get_expression] = STATE(3052),
    [sym_coercion_expression] = STATE(3052),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(1771),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [aux_sym_class_application_repeat1] = STATE(1714),
    [sym__lowercase_identifier] = ACTIONS(3049),
    [anon_sym_SEMI_SEMI] = ACTIONS(3943),
    [anon_sym_let] = ACTIONS(3945),
    [anon_sym_and] = ACTIONS(3945),
    [anon_sym_TILDE] = ACTIONS(3055),
    [anon_sym_QMARK] = ACTIONS(3055),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_external] = ACTIONS(3945),
    [anon_sym_type] = ACTIONS(3945),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_SEMI] = ACTIONS(3945),
    [anon_sym_exception] = ACTIONS(3945),
    [anon_sym_module] = ACTIONS(3945),
    [anon_sym_open] = ACTIONS(3945),
    [anon_sym_include] = ACTIONS(3945),
    [anon_sym_class] = ACTIONS(3945),
    [anon_sym_end] = ACTIONS(3945),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_in] = ACTIONS(3945),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_else] = ACTIONS(3945),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3945),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3943),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(335),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3943),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3943),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym_let_operator] = ACTIONS(3943),
    [sym_let_and_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_directive_token1] = ACTIONS(3943),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1772] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1772),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3953),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1773] = {
    [sym_value_definition] = STATE(17611),
    [sym__simple_expression] = STATE(323),
    [sym__expression] = STATE(8159),
    [sym_typed_expression] = STATE(3176),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3176),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3176),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2957),
    [sym_array_get_expression] = STATE(2957),
    [sym_string_get_expression] = STATE(2957),
    [sym_bigarray_get_expression] = STATE(2957),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3176),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(1773),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym_sign_operator] = STATE(1905),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__instance_variable_name] = STATE(17621),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [sym__lowercase_identifier] = ACTIONS(355),
    [anon_sym_let] = ACTIONS(357),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_fun] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_if] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(375),
    [anon_sym_function] = ACTIONS(377),
    [anon_sym_try] = ACTIONS(379),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3107),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3109),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(401),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1774] = {
    [sym_value_definition] = STATE(18705),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(11927),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6123),
    [sym_array_get_expression] = STATE(6123),
    [sym_string_get_expression] = STATE(6123),
    [sym_bigarray_get_expression] = STATE(6123),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(1774),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2250),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18531),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2355),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2367),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2373),
    [anon_sym_function] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2399),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1775] = {
    [sym_value_definition] = STATE(19151),
    [sym__simple_expression] = STATE(549),
    [sym__expression] = STATE(8324),
    [sym_typed_expression] = STATE(3704),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3704),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3704),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3058),
    [sym_array_get_expression] = STATE(3058),
    [sym_string_get_expression] = STATE(3058),
    [sym_bigarray_get_expression] = STATE(3058),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3704),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(1775),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym_sign_operator] = STATE(1807),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__instance_variable_name] = STATE(19067),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [sym__lowercase_identifier] = ACTIONS(527),
    [anon_sym_let] = ACTIONS(529),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_fun] = ACTIONS(541),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(545),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(547),
    [anon_sym_function] = ACTIONS(549),
    [anon_sym_try] = ACTIONS(551),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3129),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(573),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1776] = {
    [sym_value_definition] = STATE(19385),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11028),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5503),
    [sym_array_get_expression] = STATE(5503),
    [sym_string_get_expression] = STATE(5503),
    [sym_bigarray_get_expression] = STATE(5503),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(1776),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(1823),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(20481),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1279),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1291),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1295),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1777] = {
    [sym_value_definition] = STATE(19151),
    [sym__simple_expression] = STATE(549),
    [sym__expression] = STATE(8322),
    [sym_typed_expression] = STATE(3704),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3704),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3704),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3058),
    [sym_array_get_expression] = STATE(3058),
    [sym_string_get_expression] = STATE(3058),
    [sym_bigarray_get_expression] = STATE(3058),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3704),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(1777),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym_sign_operator] = STATE(1807),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__instance_variable_name] = STATE(19067),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [sym__lowercase_identifier] = ACTIONS(527),
    [anon_sym_let] = ACTIONS(529),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_fun] = ACTIONS(541),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(545),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(547),
    [anon_sym_function] = ACTIONS(549),
    [anon_sym_try] = ACTIONS(551),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3129),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(573),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1778] = {
    [sym_value_definition] = STATE(19385),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11204),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5503),
    [sym_array_get_expression] = STATE(5503),
    [sym_string_get_expression] = STATE(5503),
    [sym_bigarray_get_expression] = STATE(5503),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(1778),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(1823),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(20481),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1279),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1291),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1295),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1779] = {
    [sym_value_definition] = STATE(19151),
    [sym__simple_expression] = STATE(549),
    [sym__expression] = STATE(8321),
    [sym_typed_expression] = STATE(3704),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3704),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3704),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3058),
    [sym_array_get_expression] = STATE(3058),
    [sym_string_get_expression] = STATE(3058),
    [sym_bigarray_get_expression] = STATE(3058),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3704),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(1779),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym_sign_operator] = STATE(1807),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__instance_variable_name] = STATE(19067),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [sym__lowercase_identifier] = ACTIONS(527),
    [anon_sym_let] = ACTIONS(529),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_fun] = ACTIONS(541),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(545),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(547),
    [anon_sym_function] = ACTIONS(549),
    [anon_sym_try] = ACTIONS(551),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3129),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(573),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1780] = {
    [sym_value_definition] = STATE(19151),
    [sym__simple_expression] = STATE(549),
    [sym__expression] = STATE(8318),
    [sym_typed_expression] = STATE(3704),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3704),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3704),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3058),
    [sym_array_get_expression] = STATE(3058),
    [sym_string_get_expression] = STATE(3058),
    [sym_bigarray_get_expression] = STATE(3058),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3704),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(1780),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym_sign_operator] = STATE(1807),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__instance_variable_name] = STATE(19067),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [sym__lowercase_identifier] = ACTIONS(527),
    [anon_sym_let] = ACTIONS(529),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_fun] = ACTIONS(541),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(545),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(547),
    [anon_sym_function] = ACTIONS(549),
    [anon_sym_try] = ACTIONS(551),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3129),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(573),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1781] = {
    [sym_value_definition] = STATE(19480),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8853),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(1781),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_let] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3095),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3097),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1782] = {
    [sym_value_definition] = STATE(19480),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8846),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(1782),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_let] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3095),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3097),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1783] = {
    [sym_value_definition] = STATE(19480),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8845),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(1783),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_let] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3095),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3097),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1784] = {
    [sym_value_definition] = STATE(19480),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8843),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(1784),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_let] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3095),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3097),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1785] = {
    [sym_value_definition] = STATE(19480),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8842),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(1785),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_let] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3095),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3097),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1786] = {
    [sym_value_definition] = STATE(19480),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8837),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(1786),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_let] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3095),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3097),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1787] = {
    [sym_value_definition] = STATE(19480),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8834),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(1787),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_let] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3095),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3097),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1788] = {
    [sym_value_definition] = STATE(19480),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8832),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(1788),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_let] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3095),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3097),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1789] = {
    [sym_value_definition] = STATE(19480),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8831),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(1789),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_let] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3095),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3097),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1790] = {
    [sym_value_definition] = STATE(19480),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8830),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(1790),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_let] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3095),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3097),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1791] = {
    [sym_value_definition] = STATE(19480),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8829),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(1791),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_let] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3095),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3097),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1792] = {
    [sym_value_definition] = STATE(19151),
    [sym__simple_expression] = STATE(549),
    [sym__expression] = STATE(8317),
    [sym_typed_expression] = STATE(3704),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3704),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3704),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3058),
    [sym_array_get_expression] = STATE(3058),
    [sym_string_get_expression] = STATE(3058),
    [sym_bigarray_get_expression] = STATE(3058),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3704),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(1792),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym_sign_operator] = STATE(1807),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__instance_variable_name] = STATE(19067),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [sym__lowercase_identifier] = ACTIONS(527),
    [anon_sym_let] = ACTIONS(529),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_fun] = ACTIONS(541),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(545),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(547),
    [anon_sym_function] = ACTIONS(549),
    [anon_sym_try] = ACTIONS(551),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3129),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(573),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1793] = {
    [sym__simple_expression] = STATE(3605),
    [sym_typed_expression] = STATE(3532),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_labeled_argument] = STATE(4220),
    [sym_prefix_expression] = STATE(3532),
    [sym_hash_expression] = STATE(3532),
    [sym_field_get_expression] = STATE(3532),
    [sym_array_get_expression] = STATE(3532),
    [sym_string_get_expression] = STATE(3532),
    [sym_bigarray_get_expression] = STATE(3532),
    [sym_coercion_expression] = STATE(3532),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(1793),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [aux_sym_class_application_repeat1] = STATE(2018),
    [sym__lowercase_identifier] = ACTIONS(3157),
    [anon_sym_SEMI_SEMI] = ACTIONS(3943),
    [anon_sym_let] = ACTIONS(3945),
    [anon_sym_and] = ACTIONS(3945),
    [anon_sym_TILDE] = ACTIONS(3159),
    [anon_sym_QMARK] = ACTIONS(3159),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_external] = ACTIONS(3945),
    [anon_sym_type] = ACTIONS(3945),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_RBRACK] = ACTIONS(3943),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_SEMI] = ACTIONS(3945),
    [anon_sym_exception] = ACTIONS(3945),
    [anon_sym_module] = ACTIONS(3945),
    [anon_sym_open] = ACTIONS(3945),
    [anon_sym_include] = ACTIONS(3945),
    [anon_sym_class] = ACTIONS(3945),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_else] = ACTIONS(3945),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3945),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3943),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(509),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(511),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3943),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3943),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym_let_operator] = ACTIONS(3943),
    [sym_let_and_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_directive_token1] = ACTIONS(3943),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1794] = {
    [sym_value_definition] = STATE(19385),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11196),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5503),
    [sym_array_get_expression] = STATE(5503),
    [sym_string_get_expression] = STATE(5503),
    [sym_bigarray_get_expression] = STATE(5503),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(1794),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(1823),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(20481),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1279),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1291),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1295),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1795] = {
    [sym_value_definition] = STATE(19151),
    [sym__simple_expression] = STATE(549),
    [sym__expression] = STATE(8315),
    [sym_typed_expression] = STATE(3704),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3704),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3704),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3058),
    [sym_array_get_expression] = STATE(3058),
    [sym_string_get_expression] = STATE(3058),
    [sym_bigarray_get_expression] = STATE(3058),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3704),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(1795),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym_sign_operator] = STATE(1807),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__instance_variable_name] = STATE(19067),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [sym__lowercase_identifier] = ACTIONS(527),
    [anon_sym_let] = ACTIONS(529),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_fun] = ACTIONS(541),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(545),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(547),
    [anon_sym_function] = ACTIONS(549),
    [anon_sym_try] = ACTIONS(551),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3129),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(573),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1796] = {
    [sym_value_definition] = STATE(19385),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11195),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5503),
    [sym_array_get_expression] = STATE(5503),
    [sym_string_get_expression] = STATE(5503),
    [sym_bigarray_get_expression] = STATE(5503),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(1796),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(1823),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(20481),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1279),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1291),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1295),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1797] = {
    [sym_value_definition] = STATE(19385),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11190),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5503),
    [sym_array_get_expression] = STATE(5503),
    [sym_string_get_expression] = STATE(5503),
    [sym_bigarray_get_expression] = STATE(5503),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(1797),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(1823),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(20481),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1279),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1291),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1295),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1798] = {
    [sym_value_definition] = STATE(19151),
    [sym__simple_expression] = STATE(549),
    [sym__expression] = STATE(8326),
    [sym_typed_expression] = STATE(3704),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3704),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3704),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3058),
    [sym_array_get_expression] = STATE(3058),
    [sym_string_get_expression] = STATE(3058),
    [sym_bigarray_get_expression] = STATE(3058),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3704),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(1798),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym_sign_operator] = STATE(1807),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__instance_variable_name] = STATE(19067),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [sym__lowercase_identifier] = ACTIONS(527),
    [anon_sym_let] = ACTIONS(529),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_fun] = ACTIONS(541),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(545),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(547),
    [anon_sym_function] = ACTIONS(549),
    [anon_sym_try] = ACTIONS(551),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3129),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(573),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1799] = {
    [sym_value_definition] = STATE(19151),
    [sym__simple_expression] = STATE(549),
    [sym__expression] = STATE(8312),
    [sym_typed_expression] = STATE(3704),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3704),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3704),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3058),
    [sym_array_get_expression] = STATE(3058),
    [sym_string_get_expression] = STATE(3058),
    [sym_bigarray_get_expression] = STATE(3058),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3704),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(1799),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym_sign_operator] = STATE(1807),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__instance_variable_name] = STATE(19067),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [sym__lowercase_identifier] = ACTIONS(527),
    [anon_sym_let] = ACTIONS(529),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_fun] = ACTIONS(541),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(545),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(547),
    [anon_sym_function] = ACTIONS(549),
    [anon_sym_try] = ACTIONS(551),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3129),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(573),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1800] = {
    [sym_value_definition] = STATE(18277),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(12270),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6588),
    [sym_array_get_expression] = STATE(6588),
    [sym_string_get_expression] = STATE(6588),
    [sym_bigarray_get_expression] = STATE(6588),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(1800),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2201),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18286),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1801] = {
    [sym_value_definition] = STATE(19385),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11185),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5503),
    [sym_array_get_expression] = STATE(5503),
    [sym_string_get_expression] = STATE(5503),
    [sym_bigarray_get_expression] = STATE(5503),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(1801),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(1823),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(20481),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1279),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1291),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1295),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1802] = {
    [sym_value_definition] = STATE(19151),
    [sym__simple_expression] = STATE(549),
    [sym__expression] = STATE(8327),
    [sym_typed_expression] = STATE(3704),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3704),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3704),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3058),
    [sym_array_get_expression] = STATE(3058),
    [sym_string_get_expression] = STATE(3058),
    [sym_bigarray_get_expression] = STATE(3058),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3704),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(1802),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym_sign_operator] = STATE(1807),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__instance_variable_name] = STATE(19067),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [sym__lowercase_identifier] = ACTIONS(527),
    [anon_sym_let] = ACTIONS(529),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_fun] = ACTIONS(541),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(545),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(547),
    [anon_sym_function] = ACTIONS(549),
    [anon_sym_try] = ACTIONS(551),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3129),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(573),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1803] = {
    [sym_value_definition] = STATE(19151),
    [sym__simple_expression] = STATE(549),
    [sym__expression] = STATE(8328),
    [sym_typed_expression] = STATE(3704),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3704),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3704),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3058),
    [sym_array_get_expression] = STATE(3058),
    [sym_string_get_expression] = STATE(3058),
    [sym_bigarray_get_expression] = STATE(3058),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3704),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(1803),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym_sign_operator] = STATE(1807),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__instance_variable_name] = STATE(19067),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [sym__lowercase_identifier] = ACTIONS(527),
    [anon_sym_let] = ACTIONS(529),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_fun] = ACTIONS(541),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(545),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(547),
    [anon_sym_function] = ACTIONS(549),
    [anon_sym_try] = ACTIONS(551),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3129),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(573),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1804] = {
    [sym_value_definition] = STATE(19151),
    [sym__simple_expression] = STATE(549),
    [sym__expression] = STATE(8329),
    [sym_typed_expression] = STATE(3704),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3704),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3704),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3058),
    [sym_array_get_expression] = STATE(3058),
    [sym_string_get_expression] = STATE(3058),
    [sym_bigarray_get_expression] = STATE(3058),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3704),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(1804),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym_sign_operator] = STATE(1807),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__instance_variable_name] = STATE(19067),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [sym__lowercase_identifier] = ACTIONS(527),
    [anon_sym_let] = ACTIONS(529),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_fun] = ACTIONS(541),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(545),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(547),
    [anon_sym_function] = ACTIONS(549),
    [anon_sym_try] = ACTIONS(551),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3129),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(573),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1805] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12668),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1805),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1806] = {
    [sym_value_definition] = STATE(19151),
    [sym__simple_expression] = STATE(549),
    [sym__expression] = STATE(8330),
    [sym_typed_expression] = STATE(3704),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3704),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3704),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3058),
    [sym_array_get_expression] = STATE(3058),
    [sym_string_get_expression] = STATE(3058),
    [sym_bigarray_get_expression] = STATE(3058),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3704),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(1806),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym_sign_operator] = STATE(1807),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__instance_variable_name] = STATE(19067),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [sym__lowercase_identifier] = ACTIONS(527),
    [anon_sym_let] = ACTIONS(529),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_fun] = ACTIONS(541),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(545),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(547),
    [anon_sym_function] = ACTIONS(549),
    [anon_sym_try] = ACTIONS(551),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3129),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(573),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1807] = {
    [sym_value_definition] = STATE(19151),
    [sym__simple_expression] = STATE(549),
    [sym__expression] = STATE(8337),
    [sym_typed_expression] = STATE(3704),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3704),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3704),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3058),
    [sym_array_get_expression] = STATE(3058),
    [sym_string_get_expression] = STATE(3058),
    [sym_bigarray_get_expression] = STATE(3058),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3704),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(1807),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym_sign_operator] = STATE(1807),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__instance_variable_name] = STATE(19067),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [sym__lowercase_identifier] = ACTIONS(527),
    [anon_sym_let] = ACTIONS(529),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_fun] = ACTIONS(541),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(545),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(547),
    [anon_sym_function] = ACTIONS(549),
    [anon_sym_try] = ACTIONS(551),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3129),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(573),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1808] = {
    [sym_value_definition] = STATE(18108),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12252),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6582),
    [sym_array_get_expression] = STATE(6582),
    [sym_string_get_expression] = STATE(6582),
    [sym_bigarray_get_expression] = STATE(6582),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(1808),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(1808),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18116),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2579),
    [anon_sym_function] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2583),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2585),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1809] = {
    [sym_value_definition] = STATE(19385),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11167),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5503),
    [sym_array_get_expression] = STATE(5503),
    [sym_string_get_expression] = STATE(5503),
    [sym_bigarray_get_expression] = STATE(5503),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(1809),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(1823),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(20481),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1279),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1291),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1295),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1810] = {
    [sym_value_definition] = STATE(17729),
    [sym__simple_expression] = STATE(2474),
    [sym__expression] = STATE(12031),
    [sym_typed_expression] = STATE(6258),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6258),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6258),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6104),
    [sym_array_get_expression] = STATE(6104),
    [sym_string_get_expression] = STATE(6104),
    [sym_bigarray_get_expression] = STATE(6104),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6258),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(1810),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym_sign_operator] = STATE(1847),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__instance_variable_name] = STATE(17706),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [sym__lowercase_identifier] = ACTIONS(2465),
    [anon_sym_let] = ACTIONS(2467),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_fun] = ACTIONS(2479),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_if] = ACTIONS(2483),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2485),
    [anon_sym_function] = ACTIONS(2487),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2511),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1811] = {
    [sym_value_definition] = STATE(19385),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11166),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5503),
    [sym_array_get_expression] = STATE(5503),
    [sym_string_get_expression] = STATE(5503),
    [sym_bigarray_get_expression] = STATE(5503),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(1811),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(1823),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(20481),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1279),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1291),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1295),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1812] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12645),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1812),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1813] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12652),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1813),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1814] = {
    [sym_value_definition] = STATE(18108),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12329),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6582),
    [sym_array_get_expression] = STATE(6582),
    [sym_string_get_expression] = STATE(6582),
    [sym_bigarray_get_expression] = STATE(6582),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(1814),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(1808),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18116),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2579),
    [anon_sym_function] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2583),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2585),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1815] = {
    [sym__simple_expression] = STATE(3675),
    [sym_typed_expression] = STATE(3704),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_labeled_argument] = STATE(4252),
    [sym_prefix_expression] = STATE(3704),
    [sym_hash_expression] = STATE(3704),
    [sym_field_get_expression] = STATE(3704),
    [sym_array_get_expression] = STATE(3704),
    [sym_string_get_expression] = STATE(3704),
    [sym_bigarray_get_expression] = STATE(3704),
    [sym_coercion_expression] = STATE(3704),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(1815),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [aux_sym_class_application_repeat1] = STATE(2065),
    [sym__lowercase_identifier] = ACTIONS(3259),
    [anon_sym_SEMI_SEMI] = ACTIONS(3943),
    [anon_sym_let] = ACTIONS(3945),
    [anon_sym_and] = ACTIONS(3945),
    [anon_sym_TILDE] = ACTIONS(3261),
    [anon_sym_QMARK] = ACTIONS(3261),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_external] = ACTIONS(3945),
    [anon_sym_type] = ACTIONS(3945),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_SEMI] = ACTIONS(3945),
    [anon_sym_exception] = ACTIONS(3945),
    [anon_sym_module] = ACTIONS(3945),
    [anon_sym_open] = ACTIONS(3945),
    [anon_sym_include] = ACTIONS(3945),
    [anon_sym_class] = ACTIONS(3945),
    [anon_sym_end] = ACTIONS(3945),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_else] = ACTIONS(3945),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3945),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3943),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(561),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(563),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3943),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3943),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym_let_operator] = ACTIONS(3943),
    [sym_let_and_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_directive_token1] = ACTIONS(3943),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1816] = {
    [sym_value_definition] = STATE(19385),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11164),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5503),
    [sym_array_get_expression] = STATE(5503),
    [sym_string_get_expression] = STATE(5503),
    [sym_bigarray_get_expression] = STATE(5503),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(1816),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(1823),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(20481),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1279),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1291),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1295),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1817] = {
    [sym_value_definition] = STATE(19385),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11206),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5503),
    [sym_array_get_expression] = STATE(5503),
    [sym_string_get_expression] = STATE(5503),
    [sym_bigarray_get_expression] = STATE(5503),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(1817),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(1823),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(20481),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1279),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1291),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1295),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1818] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12655),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1818),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1819] = {
    [sym_value_definition] = STATE(19385),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11171),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5503),
    [sym_array_get_expression] = STATE(5503),
    [sym_string_get_expression] = STATE(5503),
    [sym_bigarray_get_expression] = STATE(5503),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(1819),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(1823),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(20481),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1279),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1291),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1295),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1820] = {
    [sym_value_definition] = STATE(19385),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11198),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5503),
    [sym_array_get_expression] = STATE(5503),
    [sym_string_get_expression] = STATE(5503),
    [sym_bigarray_get_expression] = STATE(5503),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(1820),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(1823),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(20481),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1279),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1291),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1295),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1821] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12663),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1821),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1822] = {
    [sym_value_definition] = STATE(18108),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12294),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6582),
    [sym_array_get_expression] = STATE(6582),
    [sym_string_get_expression] = STATE(6582),
    [sym_bigarray_get_expression] = STATE(6582),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(1822),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(1808),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18116),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2579),
    [anon_sym_function] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2583),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2585),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1823] = {
    [sym_value_definition] = STATE(19385),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11043),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5503),
    [sym_array_get_expression] = STATE(5503),
    [sym_string_get_expression] = STATE(5503),
    [sym_bigarray_get_expression] = STATE(5503),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(1823),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(1823),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(20481),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1279),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1291),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1295),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1824] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12673),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1824),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1825] = {
    [sym_value_definition] = STATE(19385),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11161),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5503),
    [sym_array_get_expression] = STATE(5503),
    [sym_string_get_expression] = STATE(5503),
    [sym_bigarray_get_expression] = STATE(5503),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(1825),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(1823),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(20481),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1279),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1291),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1295),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1826] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12635),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1826),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1827] = {
    [sym_value_definition] = STATE(18990),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12210),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6117),
    [sym_array_get_expression] = STATE(6117),
    [sym_string_get_expression] = STATE(6117),
    [sym_bigarray_get_expression] = STATE(6117),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(1827),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2049),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(18809),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2519),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2531),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2535),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2537),
    [anon_sym_function] = ACTIONS(2539),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2563),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1828] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12688),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1828),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1829] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12694),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1829),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1830] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12703),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1830),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1831] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12724),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1831),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1832] = {
    [sym_value_definition] = STATE(19080),
    [sym__simple_expression] = STATE(506),
    [sym__expression] = STATE(8349),
    [sym_typed_expression] = STATE(3532),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3532),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3532),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3084),
    [sym_array_get_expression] = STATE(3084),
    [sym_string_get_expression] = STATE(3084),
    [sym_bigarray_get_expression] = STATE(3084),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3532),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(1832),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym_sign_operator] = STATE(2274),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__instance_variable_name] = STATE(18842),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [sym__lowercase_identifier] = ACTIONS(475),
    [anon_sym_let] = ACTIONS(477),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_fun] = ACTIONS(489),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(495),
    [anon_sym_function] = ACTIONS(497),
    [anon_sym_try] = ACTIONS(499),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3123),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3125),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(521),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1833] = {
    [sym_value_definition] = STATE(17729),
    [sym__simple_expression] = STATE(2474),
    [sym__expression] = STATE(12033),
    [sym_typed_expression] = STATE(6258),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6258),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6258),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6104),
    [sym_array_get_expression] = STATE(6104),
    [sym_string_get_expression] = STATE(6104),
    [sym_bigarray_get_expression] = STATE(6104),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6258),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(1833),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym_sign_operator] = STATE(1847),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__instance_variable_name] = STATE(17706),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [sym__lowercase_identifier] = ACTIONS(2465),
    [anon_sym_let] = ACTIONS(2467),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_fun] = ACTIONS(2479),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_if] = ACTIONS(2483),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2485),
    [anon_sym_function] = ACTIONS(2487),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2511),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1834] = {
    [sym_value_definition] = STATE(17729),
    [sym__simple_expression] = STATE(2474),
    [sym__expression] = STATE(12040),
    [sym_typed_expression] = STATE(6258),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6258),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6258),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6104),
    [sym_array_get_expression] = STATE(6104),
    [sym_string_get_expression] = STATE(6104),
    [sym_bigarray_get_expression] = STATE(6104),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6258),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(1834),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym_sign_operator] = STATE(1847),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__instance_variable_name] = STATE(17706),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [sym__lowercase_identifier] = ACTIONS(2465),
    [anon_sym_let] = ACTIONS(2467),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_fun] = ACTIONS(2479),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_if] = ACTIONS(2483),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2485),
    [anon_sym_function] = ACTIONS(2487),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2511),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1835] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12740),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1835),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1836] = {
    [sym_value_definition] = STATE(17729),
    [sym__simple_expression] = STATE(2474),
    [sym__expression] = STATE(12041),
    [sym_typed_expression] = STATE(6258),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6258),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6258),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6104),
    [sym_array_get_expression] = STATE(6104),
    [sym_string_get_expression] = STATE(6104),
    [sym_bigarray_get_expression] = STATE(6104),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6258),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(1836),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym_sign_operator] = STATE(1847),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__instance_variable_name] = STATE(17706),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [sym__lowercase_identifier] = ACTIONS(2465),
    [anon_sym_let] = ACTIONS(2467),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_fun] = ACTIONS(2479),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_if] = ACTIONS(2483),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2485),
    [anon_sym_function] = ACTIONS(2487),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2511),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1837] = {
    [sym_value_definition] = STATE(17729),
    [sym__simple_expression] = STATE(2474),
    [sym__expression] = STATE(12042),
    [sym_typed_expression] = STATE(6258),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6258),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6258),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6104),
    [sym_array_get_expression] = STATE(6104),
    [sym_string_get_expression] = STATE(6104),
    [sym_bigarray_get_expression] = STATE(6104),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6258),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(1837),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym_sign_operator] = STATE(1847),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__instance_variable_name] = STATE(17706),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [sym__lowercase_identifier] = ACTIONS(2465),
    [anon_sym_let] = ACTIONS(2467),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_fun] = ACTIONS(2479),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_if] = ACTIONS(2483),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2485),
    [anon_sym_function] = ACTIONS(2487),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2511),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1838] = {
    [sym_value_definition] = STATE(17729),
    [sym__simple_expression] = STATE(2474),
    [sym__expression] = STATE(12043),
    [sym_typed_expression] = STATE(6258),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6258),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6258),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6104),
    [sym_array_get_expression] = STATE(6104),
    [sym_string_get_expression] = STATE(6104),
    [sym_bigarray_get_expression] = STATE(6104),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6258),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(1838),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym_sign_operator] = STATE(1847),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__instance_variable_name] = STATE(17706),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [sym__lowercase_identifier] = ACTIONS(2465),
    [anon_sym_let] = ACTIONS(2467),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_fun] = ACTIONS(2479),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_if] = ACTIONS(2483),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2485),
    [anon_sym_function] = ACTIONS(2487),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2511),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1839] = {
    [sym_value_definition] = STATE(17729),
    [sym__simple_expression] = STATE(2474),
    [sym__expression] = STATE(12044),
    [sym_typed_expression] = STATE(6258),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6258),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6258),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6104),
    [sym_array_get_expression] = STATE(6104),
    [sym_string_get_expression] = STATE(6104),
    [sym_bigarray_get_expression] = STATE(6104),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6258),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(1839),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym_sign_operator] = STATE(1847),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__instance_variable_name] = STATE(17706),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [sym__lowercase_identifier] = ACTIONS(2465),
    [anon_sym_let] = ACTIONS(2467),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_fun] = ACTIONS(2479),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_if] = ACTIONS(2483),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2485),
    [anon_sym_function] = ACTIONS(2487),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2511),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1840] = {
    [sym_value_definition] = STATE(17729),
    [sym__simple_expression] = STATE(2474),
    [sym__expression] = STATE(12046),
    [sym_typed_expression] = STATE(6258),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6258),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6258),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6104),
    [sym_array_get_expression] = STATE(6104),
    [sym_string_get_expression] = STATE(6104),
    [sym_bigarray_get_expression] = STATE(6104),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6258),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(1840),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym_sign_operator] = STATE(1847),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__instance_variable_name] = STATE(17706),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [sym__lowercase_identifier] = ACTIONS(2465),
    [anon_sym_let] = ACTIONS(2467),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_fun] = ACTIONS(2479),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_if] = ACTIONS(2483),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2485),
    [anon_sym_function] = ACTIONS(2487),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2511),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1841] = {
    [sym_value_definition] = STATE(17729),
    [sym__simple_expression] = STATE(2474),
    [sym__expression] = STATE(12050),
    [sym_typed_expression] = STATE(6258),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6258),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6258),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6104),
    [sym_array_get_expression] = STATE(6104),
    [sym_string_get_expression] = STATE(6104),
    [sym_bigarray_get_expression] = STATE(6104),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6258),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(1841),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym_sign_operator] = STATE(1847),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__instance_variable_name] = STATE(17706),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [sym__lowercase_identifier] = ACTIONS(2465),
    [anon_sym_let] = ACTIONS(2467),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_fun] = ACTIONS(2479),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_if] = ACTIONS(2483),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2485),
    [anon_sym_function] = ACTIONS(2487),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2511),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1842] = {
    [sym_value_definition] = STATE(17611),
    [sym__simple_expression] = STATE(323),
    [sym__expression] = STATE(8187),
    [sym_typed_expression] = STATE(3176),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3176),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3176),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2957),
    [sym_array_get_expression] = STATE(2957),
    [sym_string_get_expression] = STATE(2957),
    [sym_bigarray_get_expression] = STATE(2957),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3176),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(1842),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym_sign_operator] = STATE(1905),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__instance_variable_name] = STATE(17621),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [sym__lowercase_identifier] = ACTIONS(355),
    [anon_sym_let] = ACTIONS(357),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_fun] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_if] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(375),
    [anon_sym_function] = ACTIONS(377),
    [anon_sym_try] = ACTIONS(379),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3107),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3109),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(401),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1843] = {
    [sym_value_definition] = STATE(17729),
    [sym__simple_expression] = STATE(2474),
    [sym__expression] = STATE(12053),
    [sym_typed_expression] = STATE(6258),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6258),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6258),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6104),
    [sym_array_get_expression] = STATE(6104),
    [sym_string_get_expression] = STATE(6104),
    [sym_bigarray_get_expression] = STATE(6104),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6258),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(1843),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym_sign_operator] = STATE(1847),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__instance_variable_name] = STATE(17706),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [sym__lowercase_identifier] = ACTIONS(2465),
    [anon_sym_let] = ACTIONS(2467),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_fun] = ACTIONS(2479),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_if] = ACTIONS(2483),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2485),
    [anon_sym_function] = ACTIONS(2487),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2511),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1844] = {
    [sym_value_definition] = STATE(17729),
    [sym__simple_expression] = STATE(2474),
    [sym__expression] = STATE(12055),
    [sym_typed_expression] = STATE(6258),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6258),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6258),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6104),
    [sym_array_get_expression] = STATE(6104),
    [sym_string_get_expression] = STATE(6104),
    [sym_bigarray_get_expression] = STATE(6104),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6258),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(1844),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym_sign_operator] = STATE(1847),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__instance_variable_name] = STATE(17706),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [sym__lowercase_identifier] = ACTIONS(2465),
    [anon_sym_let] = ACTIONS(2467),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_fun] = ACTIONS(2479),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_if] = ACTIONS(2483),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2485),
    [anon_sym_function] = ACTIONS(2487),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2511),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1845] = {
    [sym_value_definition] = STATE(17729),
    [sym__simple_expression] = STATE(2474),
    [sym__expression] = STATE(12056),
    [sym_typed_expression] = STATE(6258),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6258),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6258),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6104),
    [sym_array_get_expression] = STATE(6104),
    [sym_string_get_expression] = STATE(6104),
    [sym_bigarray_get_expression] = STATE(6104),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6258),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(1845),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym_sign_operator] = STATE(1847),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__instance_variable_name] = STATE(17706),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [sym__lowercase_identifier] = ACTIONS(2465),
    [anon_sym_let] = ACTIONS(2467),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_fun] = ACTIONS(2479),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_if] = ACTIONS(2483),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2485),
    [anon_sym_function] = ACTIONS(2487),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2511),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1846] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12685),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(1846),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1847] = {
    [sym_value_definition] = STATE(17729),
    [sym__simple_expression] = STATE(2474),
    [sym__expression] = STATE(12143),
    [sym_typed_expression] = STATE(6258),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6258),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6258),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6104),
    [sym_array_get_expression] = STATE(6104),
    [sym_string_get_expression] = STATE(6104),
    [sym_bigarray_get_expression] = STATE(6104),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6258),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(1847),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym_sign_operator] = STATE(1847),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__instance_variable_name] = STATE(17706),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [sym__lowercase_identifier] = ACTIONS(2465),
    [anon_sym_let] = ACTIONS(2467),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_fun] = ACTIONS(2479),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_if] = ACTIONS(2483),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2485),
    [anon_sym_function] = ACTIONS(2487),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2511),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1848] = {
    [sym_value_definition] = STATE(18108),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12295),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6582),
    [sym_array_get_expression] = STATE(6582),
    [sym_string_get_expression] = STATE(6582),
    [sym_bigarray_get_expression] = STATE(6582),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(1848),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(1808),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18116),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2579),
    [anon_sym_function] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2583),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2585),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1849] = {
    [sym_value_definition] = STATE(18108),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12296),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6582),
    [sym_array_get_expression] = STATE(6582),
    [sym_string_get_expression] = STATE(6582),
    [sym_bigarray_get_expression] = STATE(6582),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(1849),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(1808),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18116),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2579),
    [anon_sym_function] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2583),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2585),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1850] = {
    [sym_value_definition] = STATE(18030),
    [sym__simple_expression] = STATE(301),
    [sym__expression] = STATE(8155),
    [sym_typed_expression] = STATE(3052),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3052),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3052),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2963),
    [sym_array_get_expression] = STATE(2963),
    [sym_string_get_expression] = STATE(2963),
    [sym_bigarray_get_expression] = STATE(2963),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3052),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(1850),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym_sign_operator] = STATE(1958),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__instance_variable_name] = STATE(18008),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [sym__lowercase_identifier] = ACTIONS(295),
    [anon_sym_let] = ACTIONS(299),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_fun] = ACTIONS(313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_if] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(319),
    [anon_sym_function] = ACTIONS(321),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3119),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3121),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(349),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1851] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12823),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(1851),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1852] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12816),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(1852),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1853] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12813),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(1853),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1854] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12782),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(1854),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1855] = {
    [sym_value_definition] = STATE(18108),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12298),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6582),
    [sym_array_get_expression] = STATE(6582),
    [sym_string_get_expression] = STATE(6582),
    [sym_bigarray_get_expression] = STATE(6582),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(1855),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(1808),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18116),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2579),
    [anon_sym_function] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2583),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2585),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1856] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12774),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(1856),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1857] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12771),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(1857),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1858] = {
    [sym_value_definition] = STATE(19239),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9425),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4721),
    [sym_array_get_expression] = STATE(4721),
    [sym_string_get_expression] = STATE(4721),
    [sym_bigarray_get_expression] = STATE(4721),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(1858),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(1935),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(19132),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(927),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(931),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(937),
    [anon_sym_function] = ACTIONS(939),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(967),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1859] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12768),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(1859),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1860] = {
    [sym_value_definition] = STATE(18108),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12299),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6582),
    [sym_array_get_expression] = STATE(6582),
    [sym_string_get_expression] = STATE(6582),
    [sym_bigarray_get_expression] = STATE(6582),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(1860),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(1808),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18116),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2579),
    [anon_sym_function] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2583),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2585),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1861] = {
    [sym_value_definition] = STATE(18108),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12301),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6582),
    [sym_array_get_expression] = STATE(6582),
    [sym_string_get_expression] = STATE(6582),
    [sym_bigarray_get_expression] = STATE(6582),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(1861),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(1808),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18116),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2579),
    [anon_sym_function] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2583),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2585),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1862] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12764),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(1862),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1863] = {
    [sym_value_definition] = STATE(18108),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12303),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6582),
    [sym_array_get_expression] = STATE(6582),
    [sym_string_get_expression] = STATE(6582),
    [sym_bigarray_get_expression] = STATE(6582),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(1863),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(1808),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18116),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2579),
    [anon_sym_function] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2583),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2585),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1864] = {
    [sym_value_definition] = STATE(18108),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12304),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6582),
    [sym_array_get_expression] = STATE(6582),
    [sym_string_get_expression] = STATE(6582),
    [sym_bigarray_get_expression] = STATE(6582),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(1864),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(1808),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18116),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2579),
    [anon_sym_function] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2583),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2585),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1865] = {
    [sym_value_definition] = STATE(18108),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12307),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6582),
    [sym_array_get_expression] = STATE(6582),
    [sym_string_get_expression] = STATE(6582),
    [sym_bigarray_get_expression] = STATE(6582),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(1865),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(1808),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18116),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2579),
    [anon_sym_function] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2583),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2585),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1866] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12780),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(1866),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1867] = {
    [sym_value_definition] = STATE(19709),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12791),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7071),
    [sym_array_get_expression] = STATE(7071),
    [sym_string_get_expression] = STATE(7071),
    [sym_bigarray_get_expression] = STATE(7071),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(1867),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(1805),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(19490),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1868] = {
    [sym_value_definition] = STATE(18108),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12309),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6582),
    [sym_array_get_expression] = STATE(6582),
    [sym_string_get_expression] = STATE(6582),
    [sym_bigarray_get_expression] = STATE(6582),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(1868),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(1808),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18116),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2579),
    [anon_sym_function] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2583),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2585),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1869] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12807),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1869),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1870] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12760),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(1870),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1871] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12754),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(1871),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1872] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12805),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1872),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1873] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12803),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1873),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1874] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12679),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1874),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1875] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12800),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1875),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1876] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8426),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(1876),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1877] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12795),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1877),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1878] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12728),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(1878),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1879] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12790),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1879),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1880] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8416),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(1880),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1881] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8437),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(1881),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1882] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8436),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(1882),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1883] = {
    [sym_value_definition] = STATE(18620),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(10531),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5197),
    [sym_array_get_expression] = STATE(5197),
    [sym_string_get_expression] = STATE(5197),
    [sym_bigarray_get_expression] = STATE(5197),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(1883),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(2020),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(18637),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(1117),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(1129),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(1133),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1135),
    [anon_sym_function] = ACTIONS(1137),
    [anon_sym_try] = ACTIONS(1139),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1165),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1884] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8435),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(1884),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1885] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8434),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(1885),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1886] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12742),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1886),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1887] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8433),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(1887),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1888] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8432),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(1888),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1889] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8431),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(1889),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1890] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8430),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(1890),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1891] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8429),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(1891),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1892] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8428),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(1892),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1893] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12739),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1893),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1894] = {
    [sym_value_definition] = STATE(20489),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(11943),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6050),
    [sym_array_get_expression] = STATE(6050),
    [sym_string_get_expression] = STATE(6050),
    [sym_bigarray_get_expression] = STATE(6050),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(1894),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(1961),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(20493),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(2065),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(2067),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(2069),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2071),
    [anon_sym_function] = ACTIONS(2073),
    [anon_sym_try] = ACTIONS(2075),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2077),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1895] = {
    [sym_value_definition] = STATE(17841),
    [sym__simple_expression] = STATE(593),
    [sym__expression] = STATE(8423),
    [sym_typed_expression] = STATE(3957),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3957),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3957),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3388),
    [sym_array_get_expression] = STATE(3388),
    [sym_string_get_expression] = STATE(3388),
    [sym_bigarray_get_expression] = STATE(3388),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3957),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(1895),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__instance_variable_name] = STATE(17852),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [sym__lowercase_identifier] = ACTIONS(689),
    [anon_sym_let] = ACTIONS(691),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_fun] = ACTIONS(703),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(735),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1896] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12738),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1896),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1897] = {
    [sym_value_definition] = STATE(20489),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(11947),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6050),
    [sym_array_get_expression] = STATE(6050),
    [sym_string_get_expression] = STATE(6050),
    [sym_bigarray_get_expression] = STATE(6050),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(1897),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(1961),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(20493),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(2065),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(2067),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(2069),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2071),
    [anon_sym_function] = ACTIONS(2073),
    [anon_sym_try] = ACTIONS(2075),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2077),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1898] = {
    [sym_value_definition] = STATE(19480),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8711),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(1898),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_let] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3095),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3097),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1899] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12736),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1899),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1900] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12726),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(1900),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1901] = {
    [sym_value_definition] = STATE(18447),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12410),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6602),
    [sym_array_get_expression] = STATE(6602),
    [sym_string_get_expression] = STATE(6602),
    [sym_bigarray_get_expression] = STATE(6602),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(1901),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(1952),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18459),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1902] = {
    [sym_value_definition] = STATE(17714),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9687),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4836),
    [sym_array_get_expression] = STATE(4836),
    [sym_string_get_expression] = STATE(4836),
    [sym_bigarray_get_expression] = STATE(4836),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(1902),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(2151),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(17727),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(973),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(975),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(983),
    [anon_sym_function] = ACTIONS(985),
    [anon_sym_try] = ACTIONS(987),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(993),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1903] = {
    [sym_value_definition] = STATE(18108),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12313),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6582),
    [sym_array_get_expression] = STATE(6582),
    [sym_string_get_expression] = STATE(6582),
    [sym_bigarray_get_expression] = STATE(6582),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(1903),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(1808),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18116),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2579),
    [anon_sym_function] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2583),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2585),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1904] = {
    [sym_value_definition] = STATE(20489),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(11949),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6050),
    [sym_array_get_expression] = STATE(6050),
    [sym_string_get_expression] = STATE(6050),
    [sym_bigarray_get_expression] = STATE(6050),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(1904),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(1961),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(20493),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(2065),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(2067),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(2069),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2071),
    [anon_sym_function] = ACTIONS(2073),
    [anon_sym_try] = ACTIONS(2075),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2077),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1905] = {
    [sym_value_definition] = STATE(17611),
    [sym__simple_expression] = STATE(323),
    [sym__expression] = STATE(8261),
    [sym_typed_expression] = STATE(3176),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3176),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3176),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2957),
    [sym_array_get_expression] = STATE(2957),
    [sym_string_get_expression] = STATE(2957),
    [sym_bigarray_get_expression] = STATE(2957),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3176),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(1905),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym_sign_operator] = STATE(1905),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__instance_variable_name] = STATE(17621),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [sym__lowercase_identifier] = ACTIONS(355),
    [anon_sym_let] = ACTIONS(357),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_fun] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_if] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(375),
    [anon_sym_function] = ACTIONS(377),
    [anon_sym_try] = ACTIONS(379),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3107),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3109),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(401),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1906] = {
    [sym_value_definition] = STATE(18030),
    [sym__simple_expression] = STATE(301),
    [sym__expression] = STATE(8129),
    [sym_typed_expression] = STATE(3052),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3052),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3052),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2963),
    [sym_array_get_expression] = STATE(2963),
    [sym_string_get_expression] = STATE(2963),
    [sym_bigarray_get_expression] = STATE(2963),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3052),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(1906),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym_sign_operator] = STATE(1958),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__instance_variable_name] = STATE(18008),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [sym__lowercase_identifier] = ACTIONS(295),
    [anon_sym_let] = ACTIONS(299),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_fun] = ACTIONS(313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_if] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(319),
    [anon_sym_function] = ACTIONS(321),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3119),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3121),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(349),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1907] = {
    [sym_value_definition] = STATE(18030),
    [sym__simple_expression] = STATE(301),
    [sym__expression] = STATE(8112),
    [sym_typed_expression] = STATE(3052),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3052),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3052),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2963),
    [sym_array_get_expression] = STATE(2963),
    [sym_string_get_expression] = STATE(2963),
    [sym_bigarray_get_expression] = STATE(2963),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3052),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(1907),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym_sign_operator] = STATE(1958),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__instance_variable_name] = STATE(18008),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [sym__lowercase_identifier] = ACTIONS(295),
    [anon_sym_let] = ACTIONS(299),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_fun] = ACTIONS(313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_if] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(319),
    [anon_sym_function] = ACTIONS(321),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3119),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3121),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(349),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1908] = {
    [sym_value_definition] = STATE(17729),
    [sym__simple_expression] = STATE(2474),
    [sym__expression] = STATE(11977),
    [sym_typed_expression] = STATE(6258),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6258),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6258),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6104),
    [sym_array_get_expression] = STATE(6104),
    [sym_string_get_expression] = STATE(6104),
    [sym_bigarray_get_expression] = STATE(6104),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6258),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(1908),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym_sign_operator] = STATE(1847),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__instance_variable_name] = STATE(17706),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [sym__lowercase_identifier] = ACTIONS(2465),
    [anon_sym_let] = ACTIONS(2467),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_fun] = ACTIONS(2479),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_if] = ACTIONS(2483),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2485),
    [anon_sym_function] = ACTIONS(2487),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2511),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1909] = {
    [sym__simple_expression] = STATE(4429),
    [sym_typed_expression] = STATE(4413),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_labeled_argument] = STATE(4638),
    [sym_prefix_expression] = STATE(4413),
    [sym_hash_expression] = STATE(4413),
    [sym_field_get_expression] = STATE(4413),
    [sym_array_get_expression] = STATE(4413),
    [sym_string_get_expression] = STATE(4413),
    [sym_bigarray_get_expression] = STATE(4413),
    [sym_coercion_expression] = STATE(4413),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(1909),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [aux_sym_class_application_repeat1] = STATE(2420),
    [sym__lowercase_identifier] = ACTIONS(3955),
    [anon_sym_SEMI_SEMI] = ACTIONS(3051),
    [anon_sym_let] = ACTIONS(3053),
    [anon_sym_TILDE] = ACTIONS(3957),
    [anon_sym_QMARK] = ACTIONS(3957),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_external] = ACTIONS(3053),
    [anon_sym_type] = ACTIONS(3053),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_DOT] = ACTIONS(3959),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_SEMI] = ACTIONS(3053),
    [anon_sym_exception] = ACTIONS(3053),
    [anon_sym_module] = ACTIONS(3053),
    [anon_sym_open] = ACTIONS(3053),
    [anon_sym_include] = ACTIONS(3053),
    [anon_sym_class] = ACTIONS(3053),
    [anon_sym_end] = ACTIONS(3053),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_POUND] = ACTIONS(3961),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3053),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3051),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(453),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(455),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3051),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(3963),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym_let_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_directive_token1] = ACTIONS(3053),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1910] = {
    [sym_value_definition] = STATE(18030),
    [sym__simple_expression] = STATE(301),
    [sym__expression] = STATE(8195),
    [sym_typed_expression] = STATE(3052),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3052),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3052),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2963),
    [sym_array_get_expression] = STATE(2963),
    [sym_string_get_expression] = STATE(2963),
    [sym_bigarray_get_expression] = STATE(2963),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3052),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(1910),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym_sign_operator] = STATE(1958),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__instance_variable_name] = STATE(18008),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [sym__lowercase_identifier] = ACTIONS(295),
    [anon_sym_let] = ACTIONS(299),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_fun] = ACTIONS(313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_if] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(319),
    [anon_sym_function] = ACTIONS(321),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3119),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3121),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(349),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1911] = {
    [sym_value_definition] = STATE(18030),
    [sym__simple_expression] = STATE(301),
    [sym__expression] = STATE(8106),
    [sym_typed_expression] = STATE(3052),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3052),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3052),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2963),
    [sym_array_get_expression] = STATE(2963),
    [sym_string_get_expression] = STATE(2963),
    [sym_bigarray_get_expression] = STATE(2963),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3052),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(1911),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym_sign_operator] = STATE(1958),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__instance_variable_name] = STATE(18008),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [sym__lowercase_identifier] = ACTIONS(295),
    [anon_sym_let] = ACTIONS(299),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_fun] = ACTIONS(313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_if] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(319),
    [anon_sym_function] = ACTIONS(321),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3119),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3121),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(349),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1912] = {
    [sym_value_definition] = STATE(19239),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9484),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4721),
    [sym_array_get_expression] = STATE(4721),
    [sym_string_get_expression] = STATE(4721),
    [sym_bigarray_get_expression] = STATE(4721),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(1912),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(1935),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(19132),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(927),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(931),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(937),
    [anon_sym_function] = ACTIONS(939),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(967),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1913] = {
    [sym_value_definition] = STATE(20489),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(11951),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6050),
    [sym_array_get_expression] = STATE(6050),
    [sym_string_get_expression] = STATE(6050),
    [sym_bigarray_get_expression] = STATE(6050),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(1913),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(1961),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(20493),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(2065),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(2067),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(2069),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2071),
    [anon_sym_function] = ACTIONS(2073),
    [anon_sym_try] = ACTIONS(2075),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2077),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1914] = {
    [sym_value_definition] = STATE(18030),
    [sym__simple_expression] = STATE(301),
    [sym__expression] = STATE(8124),
    [sym_typed_expression] = STATE(3052),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3052),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3052),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2963),
    [sym_array_get_expression] = STATE(2963),
    [sym_string_get_expression] = STATE(2963),
    [sym_bigarray_get_expression] = STATE(2963),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3052),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(1914),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym_sign_operator] = STATE(1958),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__instance_variable_name] = STATE(18008),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [sym__lowercase_identifier] = ACTIONS(295),
    [anon_sym_let] = ACTIONS(299),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_fun] = ACTIONS(313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_if] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(319),
    [anon_sym_function] = ACTIONS(321),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3119),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3121),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(349),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1915] = {
    [sym_value_definition] = STATE(18030),
    [sym__simple_expression] = STATE(301),
    [sym__expression] = STATE(8136),
    [sym_typed_expression] = STATE(3052),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3052),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3052),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2963),
    [sym_array_get_expression] = STATE(2963),
    [sym_string_get_expression] = STATE(2963),
    [sym_bigarray_get_expression] = STATE(2963),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3052),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(1915),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym_sign_operator] = STATE(1958),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__instance_variable_name] = STATE(18008),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [sym__lowercase_identifier] = ACTIONS(295),
    [anon_sym_let] = ACTIONS(299),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_fun] = ACTIONS(313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_if] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(319),
    [anon_sym_function] = ACTIONS(321),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3119),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3121),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(349),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1916] = {
    [sym_value_definition] = STATE(18030),
    [sym__simple_expression] = STATE(301),
    [sym__expression] = STATE(8164),
    [sym_typed_expression] = STATE(3052),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3052),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3052),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2963),
    [sym_array_get_expression] = STATE(2963),
    [sym_string_get_expression] = STATE(2963),
    [sym_bigarray_get_expression] = STATE(2963),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3052),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(1916),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym_sign_operator] = STATE(1958),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__instance_variable_name] = STATE(18008),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [sym__lowercase_identifier] = ACTIONS(295),
    [anon_sym_let] = ACTIONS(299),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_fun] = ACTIONS(313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_if] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(319),
    [anon_sym_function] = ACTIONS(321),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3119),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3121),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(349),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1917] = {
    [sym_value_definition] = STATE(20489),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(11952),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6050),
    [sym_array_get_expression] = STATE(6050),
    [sym_string_get_expression] = STATE(6050),
    [sym_bigarray_get_expression] = STATE(6050),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(1917),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(1961),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(20493),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(2065),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(2067),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(2069),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2071),
    [anon_sym_function] = ACTIONS(2073),
    [anon_sym_try] = ACTIONS(2075),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2077),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1918] = {
    [sym_value_definition] = STATE(20489),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(11953),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6050),
    [sym_array_get_expression] = STATE(6050),
    [sym_string_get_expression] = STATE(6050),
    [sym_bigarray_get_expression] = STATE(6050),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(1918),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(1961),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(20493),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(2065),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(2067),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(2069),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2071),
    [anon_sym_function] = ACTIONS(2073),
    [anon_sym_try] = ACTIONS(2075),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2077),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1919] = {
    [sym_value_definition] = STATE(20489),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(11954),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6050),
    [sym_array_get_expression] = STATE(6050),
    [sym_string_get_expression] = STATE(6050),
    [sym_bigarray_get_expression] = STATE(6050),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(1919),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(1961),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(20493),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(2065),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(2067),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(2069),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2071),
    [anon_sym_function] = ACTIONS(2073),
    [anon_sym_try] = ACTIONS(2075),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2077),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1920] = {
    [sym_value_definition] = STATE(18447),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12402),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6602),
    [sym_array_get_expression] = STATE(6602),
    [sym_string_get_expression] = STATE(6602),
    [sym_bigarray_get_expression] = STATE(6602),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(1920),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(1952),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18459),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1921] = {
    [sym_value_definition] = STATE(18447),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12401),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6602),
    [sym_array_get_expression] = STATE(6602),
    [sym_string_get_expression] = STATE(6602),
    [sym_bigarray_get_expression] = STATE(6602),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(1921),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(1952),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18459),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1922] = {
    [sym_value_definition] = STATE(19239),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9473),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4721),
    [sym_array_get_expression] = STATE(4721),
    [sym_string_get_expression] = STATE(4721),
    [sym_bigarray_get_expression] = STATE(4721),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(1922),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(1935),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(19132),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(927),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(931),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(937),
    [anon_sym_function] = ACTIONS(939),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(967),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1923] = {
    [sym_value_definition] = STATE(19239),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9465),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4721),
    [sym_array_get_expression] = STATE(4721),
    [sym_string_get_expression] = STATE(4721),
    [sym_bigarray_get_expression] = STATE(4721),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(1923),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(1935),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(19132),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(927),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(931),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(937),
    [anon_sym_function] = ACTIONS(939),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(967),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1924] = {
    [sym_value_definition] = STATE(19239),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9507),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4721),
    [sym_array_get_expression] = STATE(4721),
    [sym_string_get_expression] = STATE(4721),
    [sym_bigarray_get_expression] = STATE(4721),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(1924),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(1935),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(19132),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(927),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(931),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(937),
    [anon_sym_function] = ACTIONS(939),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(967),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1925] = {
    [sym_value_definition] = STATE(19239),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9458),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4721),
    [sym_array_get_expression] = STATE(4721),
    [sym_string_get_expression] = STATE(4721),
    [sym_bigarray_get_expression] = STATE(4721),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(1925),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(1935),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(19132),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(927),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(931),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(937),
    [anon_sym_function] = ACTIONS(939),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(967),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1926] = {
    [sym_value_definition] = STATE(18447),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12400),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6602),
    [sym_array_get_expression] = STATE(6602),
    [sym_string_get_expression] = STATE(6602),
    [sym_bigarray_get_expression] = STATE(6602),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(1926),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(1952),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18459),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1927] = {
    [sym_value_definition] = STATE(19239),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9455),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4721),
    [sym_array_get_expression] = STATE(4721),
    [sym_string_get_expression] = STATE(4721),
    [sym_bigarray_get_expression] = STATE(4721),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(1927),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(1935),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(19132),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(927),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(931),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(937),
    [anon_sym_function] = ACTIONS(939),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(967),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1928] = {
    [sym_value_definition] = STATE(19239),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9431),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4721),
    [sym_array_get_expression] = STATE(4721),
    [sym_string_get_expression] = STATE(4721),
    [sym_bigarray_get_expression] = STATE(4721),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(1928),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(1935),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(19132),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(927),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(931),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(937),
    [anon_sym_function] = ACTIONS(939),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(967),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1929] = {
    [sym_value_definition] = STATE(19239),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9421),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4721),
    [sym_array_get_expression] = STATE(4721),
    [sym_string_get_expression] = STATE(4721),
    [sym_bigarray_get_expression] = STATE(4721),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(1929),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(1935),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(19132),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(927),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(931),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(937),
    [anon_sym_function] = ACTIONS(939),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(967),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1930] = {
    [sym_value_definition] = STATE(19239),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9409),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4721),
    [sym_array_get_expression] = STATE(4721),
    [sym_string_get_expression] = STATE(4721),
    [sym_bigarray_get_expression] = STATE(4721),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(1930),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(1935),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(19132),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(927),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(931),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(937),
    [anon_sym_function] = ACTIONS(939),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(967),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1931] = {
    [sym_value_definition] = STATE(19239),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9408),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4721),
    [sym_array_get_expression] = STATE(4721),
    [sym_string_get_expression] = STATE(4721),
    [sym_bigarray_get_expression] = STATE(4721),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(1931),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(1935),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(19132),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(927),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(931),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(937),
    [anon_sym_function] = ACTIONS(939),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(967),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1932] = {
    [sym_value_definition] = STATE(19239),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9347),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4721),
    [sym_array_get_expression] = STATE(4721),
    [sym_string_get_expression] = STATE(4721),
    [sym_bigarray_get_expression] = STATE(4721),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(1932),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(1935),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(19132),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(927),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(931),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(937),
    [anon_sym_function] = ACTIONS(939),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(967),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1933] = {
    [sym_value_definition] = STATE(19239),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9433),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4721),
    [sym_array_get_expression] = STATE(4721),
    [sym_string_get_expression] = STATE(4721),
    [sym_bigarray_get_expression] = STATE(4721),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(1933),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(1935),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(19132),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(927),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(931),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(937),
    [anon_sym_function] = ACTIONS(939),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(967),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1934] = {
    [sym_value_definition] = STATE(18447),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12398),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6602),
    [sym_array_get_expression] = STATE(6602),
    [sym_string_get_expression] = STATE(6602),
    [sym_bigarray_get_expression] = STATE(6602),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(1934),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(1952),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18459),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1935] = {
    [sym_value_definition] = STATE(19239),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9525),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4721),
    [sym_array_get_expression] = STATE(4721),
    [sym_string_get_expression] = STATE(4721),
    [sym_bigarray_get_expression] = STATE(4721),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(1935),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(1935),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(19132),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(927),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(931),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(937),
    [anon_sym_function] = ACTIONS(939),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(967),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1936] = {
    [sym_value_definition] = STATE(18447),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12396),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6602),
    [sym_array_get_expression] = STATE(6602),
    [sym_string_get_expression] = STATE(6602),
    [sym_bigarray_get_expression] = STATE(6602),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(1936),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(1952),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18459),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1937] = {
    [sym_value_definition] = STATE(18447),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12393),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6602),
    [sym_array_get_expression] = STATE(6602),
    [sym_string_get_expression] = STATE(6602),
    [sym_bigarray_get_expression] = STATE(6602),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(1937),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(1952),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18459),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1938] = {
    [sym_value_definition] = STATE(18447),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12358),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6602),
    [sym_array_get_expression] = STATE(6602),
    [sym_string_get_expression] = STATE(6602),
    [sym_bigarray_get_expression] = STATE(6602),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(1938),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(1952),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18459),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1939] = {
    [sym_value_definition] = STATE(18447),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12390),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6602),
    [sym_array_get_expression] = STATE(6602),
    [sym_string_get_expression] = STATE(6602),
    [sym_bigarray_get_expression] = STATE(6602),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(1939),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(1952),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18459),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1940] = {
    [sym_value_definition] = STATE(18821),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12188),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6118),
    [sym_array_get_expression] = STATE(6118),
    [sym_string_get_expression] = STATE(6118),
    [sym_bigarray_get_expression] = STATE(6118),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(1940),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(2170),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18670),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2415),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2433),
    [anon_sym_function] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2437),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2459),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1941] = {
    [sym_value_definition] = STATE(18030),
    [sym__simple_expression] = STATE(301),
    [sym__expression] = STATE(8180),
    [sym_typed_expression] = STATE(3052),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3052),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3052),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2963),
    [sym_array_get_expression] = STATE(2963),
    [sym_string_get_expression] = STATE(2963),
    [sym_bigarray_get_expression] = STATE(2963),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3052),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(1941),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym_sign_operator] = STATE(1958),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__instance_variable_name] = STATE(18008),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [sym__lowercase_identifier] = ACTIONS(295),
    [anon_sym_let] = ACTIONS(299),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_fun] = ACTIONS(313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_if] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(319),
    [anon_sym_function] = ACTIONS(321),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3119),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3121),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(349),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1942] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8392),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(1942),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1943] = {
    [sym_value_definition] = STATE(18447),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12385),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6602),
    [sym_array_get_expression] = STATE(6602),
    [sym_string_get_expression] = STATE(6602),
    [sym_bigarray_get_expression] = STATE(6602),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(1943),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(1952),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18459),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1944] = {
    [sym_value_definition] = STATE(18447),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12382),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6602),
    [sym_array_get_expression] = STATE(6602),
    [sym_string_get_expression] = STATE(6602),
    [sym_bigarray_get_expression] = STATE(6602),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(1944),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(1952),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18459),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1945] = {
    [sym_value_definition] = STATE(20489),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(11956),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6050),
    [sym_array_get_expression] = STATE(6050),
    [sym_string_get_expression] = STATE(6050),
    [sym_bigarray_get_expression] = STATE(6050),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(1945),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(1961),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(20493),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(2065),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(2067),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(2069),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2071),
    [anon_sym_function] = ACTIONS(2073),
    [anon_sym_try] = ACTIONS(2075),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2077),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1946] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8394),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(1946),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1947] = {
    [sym_value_definition] = STATE(18447),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12375),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6602),
    [sym_array_get_expression] = STATE(6602),
    [sym_string_get_expression] = STATE(6602),
    [sym_bigarray_get_expression] = STATE(6602),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(1947),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(1952),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18459),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1948] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8395),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(1948),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1949] = {
    [sym_value_definition] = STATE(20489),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(11959),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6050),
    [sym_array_get_expression] = STATE(6050),
    [sym_string_get_expression] = STATE(6050),
    [sym_bigarray_get_expression] = STATE(6050),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(1949),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(1961),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(20493),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(2065),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(2067),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(2069),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2071),
    [anon_sym_function] = ACTIONS(2073),
    [anon_sym_try] = ACTIONS(2075),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2077),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1950] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8396),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(1950),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1951] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8397),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(1951),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1952] = {
    [sym_value_definition] = STATE(18447),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12611),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6602),
    [sym_array_get_expression] = STATE(6602),
    [sym_string_get_expression] = STATE(6602),
    [sym_bigarray_get_expression] = STATE(6602),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(1952),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(1952),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18459),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1953] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8398),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(1953),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1954] = {
    [sym_value_definition] = STATE(20489),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(11948),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6050),
    [sym_array_get_expression] = STATE(6050),
    [sym_string_get_expression] = STATE(6050),
    [sym_bigarray_get_expression] = STATE(6050),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(1954),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(1961),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(20493),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(2065),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(2067),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(2069),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2071),
    [anon_sym_function] = ACTIONS(2073),
    [anon_sym_try] = ACTIONS(2075),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2077),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1955] = {
    [sym_value_definition] = STATE(18030),
    [sym__simple_expression] = STATE(301),
    [sym__expression] = STATE(8210),
    [sym_typed_expression] = STATE(3052),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3052),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3052),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2963),
    [sym_array_get_expression] = STATE(2963),
    [sym_string_get_expression] = STATE(2963),
    [sym_bigarray_get_expression] = STATE(2963),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3052),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(1955),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym_sign_operator] = STATE(1958),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__instance_variable_name] = STATE(18008),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [sym__lowercase_identifier] = ACTIONS(295),
    [anon_sym_let] = ACTIONS(299),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_fun] = ACTIONS(313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_if] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(319),
    [anon_sym_function] = ACTIONS(321),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3119),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3121),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(349),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1956] = {
    [sym_value_definition] = STATE(18030),
    [sym__simple_expression] = STATE(301),
    [sym__expression] = STATE(8225),
    [sym_typed_expression] = STATE(3052),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3052),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3052),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2963),
    [sym_array_get_expression] = STATE(2963),
    [sym_string_get_expression] = STATE(2963),
    [sym_bigarray_get_expression] = STATE(2963),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3052),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(1956),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym_sign_operator] = STATE(1958),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__instance_variable_name] = STATE(18008),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [sym__lowercase_identifier] = ACTIONS(295),
    [anon_sym_let] = ACTIONS(299),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_fun] = ACTIONS(313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_if] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(319),
    [anon_sym_function] = ACTIONS(321),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3119),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3121),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(349),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1957] = {
    [sym_value_definition] = STATE(18030),
    [sym__simple_expression] = STATE(301),
    [sym__expression] = STATE(8227),
    [sym_typed_expression] = STATE(3052),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3052),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3052),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2963),
    [sym_array_get_expression] = STATE(2963),
    [sym_string_get_expression] = STATE(2963),
    [sym_bigarray_get_expression] = STATE(2963),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3052),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(1957),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym_sign_operator] = STATE(1958),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__instance_variable_name] = STATE(18008),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [sym__lowercase_identifier] = ACTIONS(295),
    [anon_sym_let] = ACTIONS(299),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_fun] = ACTIONS(313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_if] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(319),
    [anon_sym_function] = ACTIONS(321),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3119),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3121),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(349),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1958] = {
    [sym_value_definition] = STATE(18030),
    [sym__simple_expression] = STATE(301),
    [sym__expression] = STATE(8133),
    [sym_typed_expression] = STATE(3052),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3052),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3052),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2963),
    [sym_array_get_expression] = STATE(2963),
    [sym_string_get_expression] = STATE(2963),
    [sym_bigarray_get_expression] = STATE(2963),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3052),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(1958),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym_sign_operator] = STATE(1958),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__instance_variable_name] = STATE(18008),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [sym__lowercase_identifier] = ACTIONS(295),
    [anon_sym_let] = ACTIONS(299),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_fun] = ACTIONS(313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_if] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(319),
    [anon_sym_function] = ACTIONS(321),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3119),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3121),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(349),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1959] = {
    [sym_value_definition] = STATE(20489),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(11962),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6050),
    [sym_array_get_expression] = STATE(6050),
    [sym_string_get_expression] = STATE(6050),
    [sym_bigarray_get_expression] = STATE(6050),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(1959),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(1961),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(20493),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(2065),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(2067),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(2069),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2071),
    [anon_sym_function] = ACTIONS(2073),
    [anon_sym_try] = ACTIONS(2075),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2077),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1960] = {
    [sym_value_definition] = STATE(18535),
    [sym__simple_expression] = STATE(2430),
    [sym__expression] = STATE(10512),
    [sym_typed_expression] = STATE(5411),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5411),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5411),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(5160),
    [sym_array_get_expression] = STATE(5160),
    [sym_string_get_expression] = STATE(5160),
    [sym_bigarray_get_expression] = STATE(5160),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5411),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(1960),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym_sign_operator] = STATE(1986),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__instance_variable_name] = STATE(18550),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [sym__lowercase_identifier] = ACTIONS(1171),
    [anon_sym_let] = ACTIONS(1173),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_LBRACK] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_LBRACE] = ACTIONS(1181),
    [anon_sym_object] = ACTIONS(1183),
    [anon_sym_fun] = ACTIONS(1185),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1187),
    [anon_sym_if] = ACTIONS(1189),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1191),
    [anon_sym_function] = ACTIONS(1193),
    [anon_sym_try] = ACTIONS(1195),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1197),
    [anon_sym_LBRACE_LT] = ACTIONS(1199),
    [anon_sym_begin] = ACTIONS(1201),
    [sym_ocamlyacc_value] = ACTIONS(1203),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1205),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1207),
    [aux_sym_number_token1] = ACTIONS(1209),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_prefix_operator] = ACTIONS(1215),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1217),
    [sym__uppercase_identifier] = ACTIONS(1219),
    [aux_sym_tag_token1] = ACTIONS(1221),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1961] = {
    [sym_value_definition] = STATE(20489),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(11904),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6050),
    [sym_array_get_expression] = STATE(6050),
    [sym_string_get_expression] = STATE(6050),
    [sym_bigarray_get_expression] = STATE(6050),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(1961),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(1961),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(20493),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(2065),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(2067),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(2069),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2071),
    [anon_sym_function] = ACTIONS(2073),
    [anon_sym_try] = ACTIONS(2075),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2077),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1962] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8399),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(1962),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1963] = {
    [sym__simple_expression] = STATE(3427),
    [sym_typed_expression] = STATE(3727),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_labeled_argument] = STATE(4280),
    [sym_prefix_expression] = STATE(3727),
    [sym_hash_expression] = STATE(3727),
    [sym_field_get_expression] = STATE(3727),
    [sym_array_get_expression] = STATE(3727),
    [sym_string_get_expression] = STATE(3727),
    [sym_bigarray_get_expression] = STATE(3727),
    [sym_coercion_expression] = STATE(3727),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(1963),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [aux_sym_class_application_repeat1] = STATE(1963),
    [sym__lowercase_identifier] = ACTIONS(3965),
    [anon_sym_SEMI_SEMI] = ACTIONS(3720),
    [anon_sym_let] = ACTIONS(3722),
    [anon_sym_and] = ACTIONS(3722),
    [anon_sym_TILDE] = ACTIONS(3968),
    [anon_sym_QMARK] = ACTIONS(3968),
    [anon_sym_LPAREN] = ACTIONS(3971),
    [anon_sym_external] = ACTIONS(3722),
    [anon_sym_type] = ACTIONS(3722),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(3974),
    [anon_sym_true] = ACTIONS(3977),
    [anon_sym_false] = ACTIONS(3977),
    [anon_sym_LBRACE] = ACTIONS(3980),
    [anon_sym_SEMI] = ACTIONS(3722),
    [anon_sym_exception] = ACTIONS(3722),
    [anon_sym_module] = ACTIONS(3722),
    [anon_sym_open] = ACTIONS(3722),
    [anon_sym_include] = ACTIONS(3722),
    [anon_sym_class] = ACTIONS(3722),
    [anon_sym_end] = ACTIONS(3722),
    [anon_sym_object] = ACTIONS(3983),
    [anon_sym_in] = ACTIONS(3722),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(3986),
    [anon_sym_new] = ACTIONS(3989),
    [anon_sym_LBRACE_LT] = ACTIONS(3992),
    [anon_sym_begin] = ACTIONS(3995),
    [sym_ocamlyacc_value] = ACTIONS(3998),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3722),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3720),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4001),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4004),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3720),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3720),
    [aux_sym_number_token1] = ACTIONS(4007),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(4010),
    [anon_sym_DQUOTE] = ACTIONS(4013),
    [sym_prefix_operator] = ACTIONS(4016),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym_let_operator] = ACTIONS(3720),
    [sym_let_and_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(4019),
    [aux_sym_directive_token1] = ACTIONS(3720),
    [aux_sym_tag_token1] = ACTIONS(4022),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1964] = {
    [sym_value_definition] = STATE(18295),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11284),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5598),
    [sym_array_get_expression] = STATE(5598),
    [sym_string_get_expression] = STATE(5598),
    [sym_bigarray_get_expression] = STATE(5598),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(1964),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(1999),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(20495),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1351),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1355),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1965] = {
    [sym_value_definition] = STATE(18295),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11285),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5598),
    [sym_array_get_expression] = STATE(5598),
    [sym_string_get_expression] = STATE(5598),
    [sym_bigarray_get_expression] = STATE(5598),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(1965),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(1999),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(20495),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1351),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1355),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1966] = {
    [sym_value_definition] = STATE(18295),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11286),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5598),
    [sym_array_get_expression] = STATE(5598),
    [sym_string_get_expression] = STATE(5598),
    [sym_bigarray_get_expression] = STATE(5598),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(1966),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(1999),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(20495),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1351),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1355),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1967] = {
    [sym_value_definition] = STATE(18295),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11287),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5598),
    [sym_array_get_expression] = STATE(5598),
    [sym_string_get_expression] = STATE(5598),
    [sym_bigarray_get_expression] = STATE(5598),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(1967),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(1999),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(20495),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1351),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1355),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1968] = {
    [sym_value_definition] = STATE(18535),
    [sym__simple_expression] = STATE(2430),
    [sym__expression] = STATE(10523),
    [sym_typed_expression] = STATE(5411),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5411),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5411),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(5160),
    [sym_array_get_expression] = STATE(5160),
    [sym_string_get_expression] = STATE(5160),
    [sym_bigarray_get_expression] = STATE(5160),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5411),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(1968),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym_sign_operator] = STATE(1986),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__instance_variable_name] = STATE(18550),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [sym__lowercase_identifier] = ACTIONS(1171),
    [anon_sym_let] = ACTIONS(1173),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_LBRACK] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_LBRACE] = ACTIONS(1181),
    [anon_sym_object] = ACTIONS(1183),
    [anon_sym_fun] = ACTIONS(1185),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1187),
    [anon_sym_if] = ACTIONS(1189),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1191),
    [anon_sym_function] = ACTIONS(1193),
    [anon_sym_try] = ACTIONS(1195),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1197),
    [anon_sym_LBRACE_LT] = ACTIONS(1199),
    [anon_sym_begin] = ACTIONS(1201),
    [sym_ocamlyacc_value] = ACTIONS(1203),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1205),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1207),
    [aux_sym_number_token1] = ACTIONS(1209),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_prefix_operator] = ACTIONS(1215),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1217),
    [sym__uppercase_identifier] = ACTIONS(1219),
    [aux_sym_tag_token1] = ACTIONS(1221),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1969] = {
    [sym_value_definition] = STATE(17889),
    [sym__simple_expression] = STATE(2457),
    [sym__expression] = STATE(11896),
    [sym_typed_expression] = STATE(6138),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6138),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6138),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5776),
    [sym_array_get_expression] = STATE(5776),
    [sym_string_get_expression] = STATE(5776),
    [sym_bigarray_get_expression] = STATE(5776),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6138),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(1969),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym_sign_operator] = STATE(1969),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__instance_variable_name] = STATE(17866),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [sym__lowercase_identifier] = ACTIONS(1395),
    [anon_sym_let] = ACTIONS(1397),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_fun] = ACTIONS(1409),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1415),
    [anon_sym_function] = ACTIONS(1417),
    [anon_sym_try] = ACTIONS(1419),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1441),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1970] = {
    [sym_value_definition] = STATE(18535),
    [sym__simple_expression] = STATE(2430),
    [sym__expression] = STATE(10524),
    [sym_typed_expression] = STATE(5411),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5411),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5411),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(5160),
    [sym_array_get_expression] = STATE(5160),
    [sym_string_get_expression] = STATE(5160),
    [sym_bigarray_get_expression] = STATE(5160),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5411),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(1970),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym_sign_operator] = STATE(1986),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__instance_variable_name] = STATE(18550),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [sym__lowercase_identifier] = ACTIONS(1171),
    [anon_sym_let] = ACTIONS(1173),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_LBRACK] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_LBRACE] = ACTIONS(1181),
    [anon_sym_object] = ACTIONS(1183),
    [anon_sym_fun] = ACTIONS(1185),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1187),
    [anon_sym_if] = ACTIONS(1189),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1191),
    [anon_sym_function] = ACTIONS(1193),
    [anon_sym_try] = ACTIONS(1195),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1197),
    [anon_sym_LBRACE_LT] = ACTIONS(1199),
    [anon_sym_begin] = ACTIONS(1201),
    [sym_ocamlyacc_value] = ACTIONS(1203),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1205),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1207),
    [aux_sym_number_token1] = ACTIONS(1209),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_prefix_operator] = ACTIONS(1215),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1217),
    [sym__uppercase_identifier] = ACTIONS(1219),
    [aux_sym_tag_token1] = ACTIONS(1221),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1971] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8400),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(1971),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1972] = {
    [sym_value_definition] = STATE(18535),
    [sym__simple_expression] = STATE(2430),
    [sym__expression] = STATE(10530),
    [sym_typed_expression] = STATE(5411),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5411),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5411),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(5160),
    [sym_array_get_expression] = STATE(5160),
    [sym_string_get_expression] = STATE(5160),
    [sym_bigarray_get_expression] = STATE(5160),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5411),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(1972),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym_sign_operator] = STATE(1986),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__instance_variable_name] = STATE(18550),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [sym__lowercase_identifier] = ACTIONS(1171),
    [anon_sym_let] = ACTIONS(1173),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_LBRACK] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_LBRACE] = ACTIONS(1181),
    [anon_sym_object] = ACTIONS(1183),
    [anon_sym_fun] = ACTIONS(1185),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1187),
    [anon_sym_if] = ACTIONS(1189),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1191),
    [anon_sym_function] = ACTIONS(1193),
    [anon_sym_try] = ACTIONS(1195),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1197),
    [anon_sym_LBRACE_LT] = ACTIONS(1199),
    [anon_sym_begin] = ACTIONS(1201),
    [sym_ocamlyacc_value] = ACTIONS(1203),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1205),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1207),
    [aux_sym_number_token1] = ACTIONS(1209),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_prefix_operator] = ACTIONS(1215),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1217),
    [sym__uppercase_identifier] = ACTIONS(1219),
    [aux_sym_tag_token1] = ACTIONS(1221),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1973] = {
    [sym_value_definition] = STATE(18535),
    [sym__simple_expression] = STATE(2430),
    [sym__expression] = STATE(10532),
    [sym_typed_expression] = STATE(5411),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5411),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5411),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(5160),
    [sym_array_get_expression] = STATE(5160),
    [sym_string_get_expression] = STATE(5160),
    [sym_bigarray_get_expression] = STATE(5160),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5411),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(1973),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym_sign_operator] = STATE(1986),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__instance_variable_name] = STATE(18550),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [sym__lowercase_identifier] = ACTIONS(1171),
    [anon_sym_let] = ACTIONS(1173),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_LBRACK] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_LBRACE] = ACTIONS(1181),
    [anon_sym_object] = ACTIONS(1183),
    [anon_sym_fun] = ACTIONS(1185),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1187),
    [anon_sym_if] = ACTIONS(1189),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1191),
    [anon_sym_function] = ACTIONS(1193),
    [anon_sym_try] = ACTIONS(1195),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1197),
    [anon_sym_LBRACE_LT] = ACTIONS(1199),
    [anon_sym_begin] = ACTIONS(1201),
    [sym_ocamlyacc_value] = ACTIONS(1203),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1205),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1207),
    [aux_sym_number_token1] = ACTIONS(1209),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_prefix_operator] = ACTIONS(1215),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1217),
    [sym__uppercase_identifier] = ACTIONS(1219),
    [aux_sym_tag_token1] = ACTIONS(1221),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1974] = {
    [sym_value_definition] = STATE(18535),
    [sym__simple_expression] = STATE(2430),
    [sym__expression] = STATE(10508),
    [sym_typed_expression] = STATE(5411),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5411),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5411),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(5160),
    [sym_array_get_expression] = STATE(5160),
    [sym_string_get_expression] = STATE(5160),
    [sym_bigarray_get_expression] = STATE(5160),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5411),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(1974),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym_sign_operator] = STATE(1986),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__instance_variable_name] = STATE(18550),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [sym__lowercase_identifier] = ACTIONS(1171),
    [anon_sym_let] = ACTIONS(1173),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_LBRACK] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_LBRACE] = ACTIONS(1181),
    [anon_sym_object] = ACTIONS(1183),
    [anon_sym_fun] = ACTIONS(1185),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1187),
    [anon_sym_if] = ACTIONS(1189),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1191),
    [anon_sym_function] = ACTIONS(1193),
    [anon_sym_try] = ACTIONS(1195),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1197),
    [anon_sym_LBRACE_LT] = ACTIONS(1199),
    [anon_sym_begin] = ACTIONS(1201),
    [sym_ocamlyacc_value] = ACTIONS(1203),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1205),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1207),
    [aux_sym_number_token1] = ACTIONS(1209),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_prefix_operator] = ACTIONS(1215),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1217),
    [sym__uppercase_identifier] = ACTIONS(1219),
    [aux_sym_tag_token1] = ACTIONS(1221),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1975] = {
    [sym_value_definition] = STATE(18535),
    [sym__simple_expression] = STATE(2430),
    [sym__expression] = STATE(10541),
    [sym_typed_expression] = STATE(5411),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5411),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5411),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(5160),
    [sym_array_get_expression] = STATE(5160),
    [sym_string_get_expression] = STATE(5160),
    [sym_bigarray_get_expression] = STATE(5160),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5411),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(1975),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym_sign_operator] = STATE(1986),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__instance_variable_name] = STATE(18550),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [sym__lowercase_identifier] = ACTIONS(1171),
    [anon_sym_let] = ACTIONS(1173),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_LBRACK] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_LBRACE] = ACTIONS(1181),
    [anon_sym_object] = ACTIONS(1183),
    [anon_sym_fun] = ACTIONS(1185),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1187),
    [anon_sym_if] = ACTIONS(1189),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1191),
    [anon_sym_function] = ACTIONS(1193),
    [anon_sym_try] = ACTIONS(1195),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1197),
    [anon_sym_LBRACE_LT] = ACTIONS(1199),
    [anon_sym_begin] = ACTIONS(1201),
    [sym_ocamlyacc_value] = ACTIONS(1203),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1205),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1207),
    [aux_sym_number_token1] = ACTIONS(1209),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_prefix_operator] = ACTIONS(1215),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1217),
    [sym__uppercase_identifier] = ACTIONS(1219),
    [aux_sym_tag_token1] = ACTIONS(1221),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1976] = {
    [sym_value_definition] = STATE(18535),
    [sym__simple_expression] = STATE(2430),
    [sym__expression] = STATE(10543),
    [sym_typed_expression] = STATE(5411),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5411),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5411),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(5160),
    [sym_array_get_expression] = STATE(5160),
    [sym_string_get_expression] = STATE(5160),
    [sym_bigarray_get_expression] = STATE(5160),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5411),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(1976),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym_sign_operator] = STATE(1986),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__instance_variable_name] = STATE(18550),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [sym__lowercase_identifier] = ACTIONS(1171),
    [anon_sym_let] = ACTIONS(1173),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_LBRACK] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_LBRACE] = ACTIONS(1181),
    [anon_sym_object] = ACTIONS(1183),
    [anon_sym_fun] = ACTIONS(1185),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1187),
    [anon_sym_if] = ACTIONS(1189),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1191),
    [anon_sym_function] = ACTIONS(1193),
    [anon_sym_try] = ACTIONS(1195),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1197),
    [anon_sym_LBRACE_LT] = ACTIONS(1199),
    [anon_sym_begin] = ACTIONS(1201),
    [sym_ocamlyacc_value] = ACTIONS(1203),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1205),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1207),
    [aux_sym_number_token1] = ACTIONS(1209),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_prefix_operator] = ACTIONS(1215),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1217),
    [sym__uppercase_identifier] = ACTIONS(1219),
    [aux_sym_tag_token1] = ACTIONS(1221),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1977] = {
    [sym_value_definition] = STATE(18535),
    [sym__simple_expression] = STATE(2430),
    [sym__expression] = STATE(10546),
    [sym_typed_expression] = STATE(5411),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5411),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5411),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(5160),
    [sym_array_get_expression] = STATE(5160),
    [sym_string_get_expression] = STATE(5160),
    [sym_bigarray_get_expression] = STATE(5160),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5411),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(1977),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym_sign_operator] = STATE(1986),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__instance_variable_name] = STATE(18550),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [sym__lowercase_identifier] = ACTIONS(1171),
    [anon_sym_let] = ACTIONS(1173),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_LBRACK] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_LBRACE] = ACTIONS(1181),
    [anon_sym_object] = ACTIONS(1183),
    [anon_sym_fun] = ACTIONS(1185),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1187),
    [anon_sym_if] = ACTIONS(1189),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1191),
    [anon_sym_function] = ACTIONS(1193),
    [anon_sym_try] = ACTIONS(1195),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1197),
    [anon_sym_LBRACE_LT] = ACTIONS(1199),
    [anon_sym_begin] = ACTIONS(1201),
    [sym_ocamlyacc_value] = ACTIONS(1203),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1205),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1207),
    [aux_sym_number_token1] = ACTIONS(1209),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_prefix_operator] = ACTIONS(1215),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1217),
    [sym__uppercase_identifier] = ACTIONS(1219),
    [aux_sym_tag_token1] = ACTIONS(1221),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1978] = {
    [sym_value_definition] = STATE(17889),
    [sym__simple_expression] = STATE(2457),
    [sym__expression] = STATE(11870),
    [sym_typed_expression] = STATE(6138),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6138),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6138),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5776),
    [sym_array_get_expression] = STATE(5776),
    [sym_string_get_expression] = STATE(5776),
    [sym_bigarray_get_expression] = STATE(5776),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6138),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(1978),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym_sign_operator] = STATE(1969),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__instance_variable_name] = STATE(17866),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [sym__lowercase_identifier] = ACTIONS(1395),
    [anon_sym_let] = ACTIONS(1397),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_fun] = ACTIONS(1409),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1415),
    [anon_sym_function] = ACTIONS(1417),
    [anon_sym_try] = ACTIONS(1419),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1441),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1979] = {
    [sym_value_definition] = STATE(18535),
    [sym__simple_expression] = STATE(2430),
    [sym__expression] = STATE(10548),
    [sym_typed_expression] = STATE(5411),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5411),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5411),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(5160),
    [sym_array_get_expression] = STATE(5160),
    [sym_string_get_expression] = STATE(5160),
    [sym_bigarray_get_expression] = STATE(5160),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5411),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(1979),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym_sign_operator] = STATE(1986),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__instance_variable_name] = STATE(18550),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [sym__lowercase_identifier] = ACTIONS(1171),
    [anon_sym_let] = ACTIONS(1173),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_LBRACK] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_LBRACE] = ACTIONS(1181),
    [anon_sym_object] = ACTIONS(1183),
    [anon_sym_fun] = ACTIONS(1185),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1187),
    [anon_sym_if] = ACTIONS(1189),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1191),
    [anon_sym_function] = ACTIONS(1193),
    [anon_sym_try] = ACTIONS(1195),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1197),
    [anon_sym_LBRACE_LT] = ACTIONS(1199),
    [anon_sym_begin] = ACTIONS(1201),
    [sym_ocamlyacc_value] = ACTIONS(1203),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1205),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1207),
    [aux_sym_number_token1] = ACTIONS(1209),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_prefix_operator] = ACTIONS(1215),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1217),
    [sym__uppercase_identifier] = ACTIONS(1219),
    [aux_sym_tag_token1] = ACTIONS(1221),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1980] = {
    [sym_value_definition] = STATE(18535),
    [sym__simple_expression] = STATE(2430),
    [sym__expression] = STATE(10553),
    [sym_typed_expression] = STATE(5411),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5411),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5411),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(5160),
    [sym_array_get_expression] = STATE(5160),
    [sym_string_get_expression] = STATE(5160),
    [sym_bigarray_get_expression] = STATE(5160),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5411),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(1980),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym_sign_operator] = STATE(1986),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__instance_variable_name] = STATE(18550),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [sym__lowercase_identifier] = ACTIONS(1171),
    [anon_sym_let] = ACTIONS(1173),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_LBRACK] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_LBRACE] = ACTIONS(1181),
    [anon_sym_object] = ACTIONS(1183),
    [anon_sym_fun] = ACTIONS(1185),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1187),
    [anon_sym_if] = ACTIONS(1189),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1191),
    [anon_sym_function] = ACTIONS(1193),
    [anon_sym_try] = ACTIONS(1195),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1197),
    [anon_sym_LBRACE_LT] = ACTIONS(1199),
    [anon_sym_begin] = ACTIONS(1201),
    [sym_ocamlyacc_value] = ACTIONS(1203),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1205),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1207),
    [aux_sym_number_token1] = ACTIONS(1209),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_prefix_operator] = ACTIONS(1215),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1217),
    [sym__uppercase_identifier] = ACTIONS(1219),
    [aux_sym_tag_token1] = ACTIONS(1221),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1981] = {
    [sym_value_definition] = STATE(18295),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11289),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5598),
    [sym_array_get_expression] = STATE(5598),
    [sym_string_get_expression] = STATE(5598),
    [sym_bigarray_get_expression] = STATE(5598),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(1981),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(1999),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(20495),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1351),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1355),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1982] = {
    [sym_value_definition] = STATE(17966),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12486),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(1982),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2141),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(17979),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1983] = {
    [sym_value_definition] = STATE(18535),
    [sym__simple_expression] = STATE(2430),
    [sym__expression] = STATE(10554),
    [sym_typed_expression] = STATE(5411),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5411),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5411),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(5160),
    [sym_array_get_expression] = STATE(5160),
    [sym_string_get_expression] = STATE(5160),
    [sym_bigarray_get_expression] = STATE(5160),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5411),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(1983),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym_sign_operator] = STATE(1986),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__instance_variable_name] = STATE(18550),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [sym__lowercase_identifier] = ACTIONS(1171),
    [anon_sym_let] = ACTIONS(1173),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_LBRACK] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_LBRACE] = ACTIONS(1181),
    [anon_sym_object] = ACTIONS(1183),
    [anon_sym_fun] = ACTIONS(1185),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1187),
    [anon_sym_if] = ACTIONS(1189),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1191),
    [anon_sym_function] = ACTIONS(1193),
    [anon_sym_try] = ACTIONS(1195),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1197),
    [anon_sym_LBRACE_LT] = ACTIONS(1199),
    [anon_sym_begin] = ACTIONS(1201),
    [sym_ocamlyacc_value] = ACTIONS(1203),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1205),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1207),
    [aux_sym_number_token1] = ACTIONS(1209),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_prefix_operator] = ACTIONS(1215),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1217),
    [sym__uppercase_identifier] = ACTIONS(1219),
    [aux_sym_tag_token1] = ACTIONS(1221),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1984] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8401),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(1984),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1985] = {
    [sym_value_definition] = STATE(20489),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(11960),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6050),
    [sym_array_get_expression] = STATE(6050),
    [sym_string_get_expression] = STATE(6050),
    [sym_bigarray_get_expression] = STATE(6050),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(1985),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(1961),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(20493),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(2065),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(2067),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(2069),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2071),
    [anon_sym_function] = ACTIONS(2073),
    [anon_sym_try] = ACTIONS(2075),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2077),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1986] = {
    [sym_value_definition] = STATE(18535),
    [sym__simple_expression] = STATE(2430),
    [sym__expression] = STATE(10379),
    [sym_typed_expression] = STATE(5411),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5411),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5411),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(5160),
    [sym_array_get_expression] = STATE(5160),
    [sym_string_get_expression] = STATE(5160),
    [sym_bigarray_get_expression] = STATE(5160),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5411),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(1986),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym_sign_operator] = STATE(1986),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__instance_variable_name] = STATE(18550),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [sym__lowercase_identifier] = ACTIONS(1171),
    [anon_sym_let] = ACTIONS(1173),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_LBRACK] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_LBRACE] = ACTIONS(1181),
    [anon_sym_object] = ACTIONS(1183),
    [anon_sym_fun] = ACTIONS(1185),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1187),
    [anon_sym_if] = ACTIONS(1189),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1191),
    [anon_sym_function] = ACTIONS(1193),
    [anon_sym_try] = ACTIONS(1195),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1197),
    [anon_sym_LBRACE_LT] = ACTIONS(1199),
    [anon_sym_begin] = ACTIONS(1201),
    [sym_ocamlyacc_value] = ACTIONS(1203),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1205),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1207),
    [aux_sym_number_token1] = ACTIONS(1209),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_prefix_operator] = ACTIONS(1215),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1217),
    [sym__uppercase_identifier] = ACTIONS(1219),
    [aux_sym_tag_token1] = ACTIONS(1221),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1987] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8402),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(1987),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1988] = {
    [sym_value_definition] = STATE(18295),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11291),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5598),
    [sym_array_get_expression] = STATE(5598),
    [sym_string_get_expression] = STATE(5598),
    [sym_bigarray_get_expression] = STATE(5598),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(1988),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(1999),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(20495),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1351),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1355),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1989] = {
    [sym_value_definition] = STATE(18620),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(10589),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5197),
    [sym_array_get_expression] = STATE(5197),
    [sym_string_get_expression] = STATE(5197),
    [sym_bigarray_get_expression] = STATE(5197),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(1989),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(2020),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(18637),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(1117),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(1129),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(1133),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1135),
    [anon_sym_function] = ACTIONS(1137),
    [anon_sym_try] = ACTIONS(1139),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1165),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1990] = {
    [sym_value_definition] = STATE(18295),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11292),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5598),
    [sym_array_get_expression] = STATE(5598),
    [sym_string_get_expression] = STATE(5598),
    [sym_bigarray_get_expression] = STATE(5598),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(1990),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(1999),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(20495),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1351),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1355),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1991] = {
    [sym_value_definition] = STATE(18295),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11293),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5598),
    [sym_array_get_expression] = STATE(5598),
    [sym_string_get_expression] = STATE(5598),
    [sym_bigarray_get_expression] = STATE(5598),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(1991),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(1999),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(20495),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1351),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1355),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1992] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8403),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(1992),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1993] = {
    [sym_value_definition] = STATE(17889),
    [sym__simple_expression] = STATE(2457),
    [sym__expression] = STATE(11871),
    [sym_typed_expression] = STATE(6138),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6138),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6138),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5776),
    [sym_array_get_expression] = STATE(5776),
    [sym_string_get_expression] = STATE(5776),
    [sym_bigarray_get_expression] = STATE(5776),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6138),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(1993),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym_sign_operator] = STATE(1969),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__instance_variable_name] = STATE(17866),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [sym__lowercase_identifier] = ACTIONS(1395),
    [anon_sym_let] = ACTIONS(1397),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_fun] = ACTIONS(1409),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1415),
    [anon_sym_function] = ACTIONS(1417),
    [anon_sym_try] = ACTIONS(1419),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1441),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1994] = {
    [sym_value_definition] = STATE(17889),
    [sym__simple_expression] = STATE(2457),
    [sym__expression] = STATE(11874),
    [sym_typed_expression] = STATE(6138),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6138),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6138),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5776),
    [sym_array_get_expression] = STATE(5776),
    [sym_string_get_expression] = STATE(5776),
    [sym_bigarray_get_expression] = STATE(5776),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6138),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(1994),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym_sign_operator] = STATE(1969),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__instance_variable_name] = STATE(17866),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [sym__lowercase_identifier] = ACTIONS(1395),
    [anon_sym_let] = ACTIONS(1397),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_fun] = ACTIONS(1409),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1415),
    [anon_sym_function] = ACTIONS(1417),
    [anon_sym_try] = ACTIONS(1419),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1441),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1995] = {
    [sym_value_definition] = STATE(18295),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11294),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5598),
    [sym_array_get_expression] = STATE(5598),
    [sym_string_get_expression] = STATE(5598),
    [sym_bigarray_get_expression] = STATE(5598),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(1995),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(1999),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(20495),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1351),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1355),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1996] = {
    [sym_value_definition] = STATE(17889),
    [sym__simple_expression] = STATE(2457),
    [sym__expression] = STATE(11875),
    [sym_typed_expression] = STATE(6138),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6138),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6138),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5776),
    [sym_array_get_expression] = STATE(5776),
    [sym_string_get_expression] = STATE(5776),
    [sym_bigarray_get_expression] = STATE(5776),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6138),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(1996),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym_sign_operator] = STATE(1969),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__instance_variable_name] = STATE(17866),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [sym__lowercase_identifier] = ACTIONS(1395),
    [anon_sym_let] = ACTIONS(1397),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_fun] = ACTIONS(1409),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1415),
    [anon_sym_function] = ACTIONS(1417),
    [anon_sym_try] = ACTIONS(1419),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1441),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1997] = {
    [sym_value_definition] = STATE(18295),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11295),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5598),
    [sym_array_get_expression] = STATE(5598),
    [sym_string_get_expression] = STATE(5598),
    [sym_bigarray_get_expression] = STATE(5598),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(1997),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(1999),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(20495),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1351),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1355),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1998] = {
    [sym_value_definition] = STATE(18295),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11296),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5598),
    [sym_array_get_expression] = STATE(5598),
    [sym_string_get_expression] = STATE(5598),
    [sym_bigarray_get_expression] = STATE(5598),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(1998),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(1999),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(20495),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1351),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1355),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1999] = {
    [sym_value_definition] = STATE(18295),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11346),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5598),
    [sym_array_get_expression] = STATE(5598),
    [sym_string_get_expression] = STATE(5598),
    [sym_bigarray_get_expression] = STATE(5598),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(1999),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(1999),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(20495),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1351),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1355),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2000] = {
    [sym_value_definition] = STATE(18620),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(10598),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5197),
    [sym_array_get_expression] = STATE(5197),
    [sym_string_get_expression] = STATE(5197),
    [sym_bigarray_get_expression] = STATE(5197),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(2000),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(2020),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(18637),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(1117),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(1129),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(1133),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1135),
    [anon_sym_function] = ACTIONS(1137),
    [anon_sym_try] = ACTIONS(1139),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1165),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2001] = {
    [sym_value_definition] = STATE(18620),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(10599),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5197),
    [sym_array_get_expression] = STATE(5197),
    [sym_string_get_expression] = STATE(5197),
    [sym_bigarray_get_expression] = STATE(5197),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(2001),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(2020),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(18637),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(1117),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(1129),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(1133),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1135),
    [anon_sym_function] = ACTIONS(1137),
    [anon_sym_try] = ACTIONS(1139),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1165),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2002] = {
    [sym_value_definition] = STATE(17889),
    [sym__simple_expression] = STATE(2457),
    [sym__expression] = STATE(11876),
    [sym_typed_expression] = STATE(6138),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6138),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6138),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5776),
    [sym_array_get_expression] = STATE(5776),
    [sym_string_get_expression] = STATE(5776),
    [sym_bigarray_get_expression] = STATE(5776),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6138),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(2002),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym_sign_operator] = STATE(1969),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__instance_variable_name] = STATE(17866),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [sym__lowercase_identifier] = ACTIONS(1395),
    [anon_sym_let] = ACTIONS(1397),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_fun] = ACTIONS(1409),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1415),
    [anon_sym_function] = ACTIONS(1417),
    [anon_sym_try] = ACTIONS(1419),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1441),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2003] = {
    [sym_value_definition] = STATE(18620),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(10600),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5197),
    [sym_array_get_expression] = STATE(5197),
    [sym_string_get_expression] = STATE(5197),
    [sym_bigarray_get_expression] = STATE(5197),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(2003),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(2020),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(18637),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(1117),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(1129),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(1133),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1135),
    [anon_sym_function] = ACTIONS(1137),
    [anon_sym_try] = ACTIONS(1139),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1165),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2004] = {
    [sym_value_definition] = STATE(17889),
    [sym__simple_expression] = STATE(2457),
    [sym__expression] = STATE(11878),
    [sym_typed_expression] = STATE(6138),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6138),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6138),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5776),
    [sym_array_get_expression] = STATE(5776),
    [sym_string_get_expression] = STATE(5776),
    [sym_bigarray_get_expression] = STATE(5776),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6138),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(2004),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym_sign_operator] = STATE(1969),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__instance_variable_name] = STATE(17866),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [sym__lowercase_identifier] = ACTIONS(1395),
    [anon_sym_let] = ACTIONS(1397),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_fun] = ACTIONS(1409),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1415),
    [anon_sym_function] = ACTIONS(1417),
    [anon_sym_try] = ACTIONS(1419),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1441),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2005] = {
    [sym_value_definition] = STATE(19480),
    [sym__simple_expression] = STATE(1909),
    [sym__expression] = STATE(8636),
    [sym_typed_expression] = STATE(4413),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4413),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4413),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(4046),
    [sym_array_get_expression] = STATE(4046),
    [sym_string_get_expression] = STATE(4046),
    [sym_bigarray_get_expression] = STATE(4046),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4413),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(2005),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym_sign_operator] = STATE(1898),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__instance_variable_name] = STATE(20131),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [sym__lowercase_identifier] = ACTIONS(407),
    [anon_sym_let] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_fun] = ACTIONS(433),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(437),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(439),
    [anon_sym_function] = ACTIONS(441),
    [anon_sym_try] = ACTIONS(443),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3095),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3097),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(467),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2006] = {
    [sym_value_definition] = STATE(18620),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(10603),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5197),
    [sym_array_get_expression] = STATE(5197),
    [sym_string_get_expression] = STATE(5197),
    [sym_bigarray_get_expression] = STATE(5197),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(2006),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(2020),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(18637),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(1117),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(1129),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(1133),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1135),
    [anon_sym_function] = ACTIONS(1137),
    [anon_sym_try] = ACTIONS(1139),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1165),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2007] = {
    [sym_value_definition] = STATE(18620),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(10610),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5197),
    [sym_array_get_expression] = STATE(5197),
    [sym_string_get_expression] = STATE(5197),
    [sym_bigarray_get_expression] = STATE(5197),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(2007),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(2020),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(18637),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(1117),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(1129),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(1133),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1135),
    [anon_sym_function] = ACTIONS(1137),
    [anon_sym_try] = ACTIONS(1139),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1165),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2008] = {
    [sym_value_definition] = STATE(18620),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(10614),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5197),
    [sym_array_get_expression] = STATE(5197),
    [sym_string_get_expression] = STATE(5197),
    [sym_bigarray_get_expression] = STATE(5197),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(2008),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(2020),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(18637),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(1117),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(1129),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(1133),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1135),
    [anon_sym_function] = ACTIONS(1137),
    [anon_sym_try] = ACTIONS(1139),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1165),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2009] = {
    [sym_value_definition] = STATE(18620),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(10616),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5197),
    [sym_array_get_expression] = STATE(5197),
    [sym_string_get_expression] = STATE(5197),
    [sym_bigarray_get_expression] = STATE(5197),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(2009),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(2020),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(18637),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(1117),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(1129),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(1133),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1135),
    [anon_sym_function] = ACTIONS(1137),
    [anon_sym_try] = ACTIONS(1139),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1165),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2010] = {
    [sym_value_definition] = STATE(18620),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(10619),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5197),
    [sym_array_get_expression] = STATE(5197),
    [sym_string_get_expression] = STATE(5197),
    [sym_bigarray_get_expression] = STATE(5197),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(2010),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(2020),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(18637),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(1117),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(1129),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(1133),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1135),
    [anon_sym_function] = ACTIONS(1137),
    [anon_sym_try] = ACTIONS(1139),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1165),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2011] = {
    [sym_value_definition] = STATE(17889),
    [sym__simple_expression] = STATE(2457),
    [sym__expression] = STATE(11879),
    [sym_typed_expression] = STATE(6138),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6138),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6138),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5776),
    [sym_array_get_expression] = STATE(5776),
    [sym_string_get_expression] = STATE(5776),
    [sym_bigarray_get_expression] = STATE(5776),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6138),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(2011),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym_sign_operator] = STATE(1969),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__instance_variable_name] = STATE(17866),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [sym__lowercase_identifier] = ACTIONS(1395),
    [anon_sym_let] = ACTIONS(1397),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_fun] = ACTIONS(1409),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1415),
    [anon_sym_function] = ACTIONS(1417),
    [anon_sym_try] = ACTIONS(1419),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1441),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2012] = {
    [sym_value_definition] = STATE(18620),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(10621),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5197),
    [sym_array_get_expression] = STATE(5197),
    [sym_string_get_expression] = STATE(5197),
    [sym_bigarray_get_expression] = STATE(5197),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(2012),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(2020),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(18637),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(1117),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(1129),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(1133),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1135),
    [anon_sym_function] = ACTIONS(1137),
    [anon_sym_try] = ACTIONS(1139),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1165),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2013] = {
    [sym_value_definition] = STATE(18620),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(10622),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5197),
    [sym_array_get_expression] = STATE(5197),
    [sym_string_get_expression] = STATE(5197),
    [sym_bigarray_get_expression] = STATE(5197),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(2013),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(2020),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(18637),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(1117),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(1129),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(1133),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1135),
    [anon_sym_function] = ACTIONS(1137),
    [anon_sym_try] = ACTIONS(1139),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1165),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2014] = {
    [sym_value_definition] = STATE(18620),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(10623),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5197),
    [sym_array_get_expression] = STATE(5197),
    [sym_string_get_expression] = STATE(5197),
    [sym_bigarray_get_expression] = STATE(5197),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(2014),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(2020),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(18637),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(1117),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(1129),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(1133),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1135),
    [anon_sym_function] = ACTIONS(1137),
    [anon_sym_try] = ACTIONS(1139),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1165),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2015] = {
    [sym_value_definition] = STATE(17966),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12481),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2015),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2141),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(17979),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2016] = {
    [sym_value_definition] = STATE(17889),
    [sym__simple_expression] = STATE(2457),
    [sym__expression] = STATE(11882),
    [sym_typed_expression] = STATE(6138),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6138),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6138),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5776),
    [sym_array_get_expression] = STATE(5776),
    [sym_string_get_expression] = STATE(5776),
    [sym_bigarray_get_expression] = STATE(5776),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6138),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(2016),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym_sign_operator] = STATE(1969),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__instance_variable_name] = STATE(17866),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [sym__lowercase_identifier] = ACTIONS(1395),
    [anon_sym_let] = ACTIONS(1397),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_fun] = ACTIONS(1409),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1415),
    [anon_sym_function] = ACTIONS(1417),
    [anon_sym_try] = ACTIONS(1419),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1441),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2017] = {
    [sym_value_definition] = STATE(17966),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12508),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2017),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2141),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(17979),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2018] = {
    [sym__simple_expression] = STATE(3605),
    [sym_typed_expression] = STATE(3532),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_labeled_argument] = STATE(4220),
    [sym_prefix_expression] = STATE(3532),
    [sym_hash_expression] = STATE(3532),
    [sym_field_get_expression] = STATE(3532),
    [sym_array_get_expression] = STATE(3532),
    [sym_string_get_expression] = STATE(3532),
    [sym_bigarray_get_expression] = STATE(3532),
    [sym_coercion_expression] = STATE(3532),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(2018),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [aux_sym_class_application_repeat1] = STATE(2018),
    [sym__lowercase_identifier] = ACTIONS(4025),
    [anon_sym_SEMI_SEMI] = ACTIONS(3720),
    [anon_sym_let] = ACTIONS(3722),
    [anon_sym_and] = ACTIONS(3722),
    [anon_sym_TILDE] = ACTIONS(4028),
    [anon_sym_QMARK] = ACTIONS(4028),
    [anon_sym_LPAREN] = ACTIONS(4031),
    [anon_sym_external] = ACTIONS(3722),
    [anon_sym_type] = ACTIONS(3722),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(4034),
    [anon_sym_RBRACK] = ACTIONS(3720),
    [anon_sym_true] = ACTIONS(4037),
    [anon_sym_false] = ACTIONS(4037),
    [anon_sym_LBRACE] = ACTIONS(4040),
    [anon_sym_SEMI] = ACTIONS(3722),
    [anon_sym_exception] = ACTIONS(3722),
    [anon_sym_module] = ACTIONS(3722),
    [anon_sym_open] = ACTIONS(3722),
    [anon_sym_include] = ACTIONS(3722),
    [anon_sym_class] = ACTIONS(3722),
    [anon_sym_object] = ACTIONS(4043),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4046),
    [anon_sym_else] = ACTIONS(3722),
    [anon_sym_new] = ACTIONS(4049),
    [anon_sym_LBRACE_LT] = ACTIONS(4052),
    [anon_sym_begin] = ACTIONS(4055),
    [sym_ocamlyacc_value] = ACTIONS(4058),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3722),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3720),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4061),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4064),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3720),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3720),
    [aux_sym_number_token1] = ACTIONS(4067),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(4070),
    [anon_sym_DQUOTE] = ACTIONS(4073),
    [sym_prefix_operator] = ACTIONS(4076),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym_let_operator] = ACTIONS(3720),
    [sym_let_and_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(4079),
    [aux_sym_directive_token1] = ACTIONS(3720),
    [aux_sym_tag_token1] = ACTIONS(4082),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2019] = {
    [sym_value_definition] = STATE(18295),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11290),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5598),
    [sym_array_get_expression] = STATE(5598),
    [sym_string_get_expression] = STATE(5598),
    [sym_bigarray_get_expression] = STATE(5598),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(2019),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(1999),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(20495),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1351),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1355),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2020] = {
    [sym_value_definition] = STATE(18620),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(10482),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5197),
    [sym_array_get_expression] = STATE(5197),
    [sym_string_get_expression] = STATE(5197),
    [sym_bigarray_get_expression] = STATE(5197),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(2020),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(2020),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(18637),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(1117),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(1129),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(1133),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1135),
    [anon_sym_function] = ACTIONS(1137),
    [anon_sym_try] = ACTIONS(1139),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1165),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2021] = {
    [sym_value_definition] = STATE(17889),
    [sym__simple_expression] = STATE(2457),
    [sym__expression] = STATE(11884),
    [sym_typed_expression] = STATE(6138),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6138),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6138),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5776),
    [sym_array_get_expression] = STATE(5776),
    [sym_string_get_expression] = STATE(5776),
    [sym_bigarray_get_expression] = STATE(5776),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6138),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(2021),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym_sign_operator] = STATE(1969),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__instance_variable_name] = STATE(17866),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [sym__lowercase_identifier] = ACTIONS(1395),
    [anon_sym_let] = ACTIONS(1397),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_fun] = ACTIONS(1409),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1415),
    [anon_sym_function] = ACTIONS(1417),
    [anon_sym_try] = ACTIONS(1419),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1441),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2022] = {
    [sym_value_definition] = STATE(17889),
    [sym__simple_expression] = STATE(2457),
    [sym__expression] = STATE(11885),
    [sym_typed_expression] = STATE(6138),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6138),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6138),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5776),
    [sym_array_get_expression] = STATE(5776),
    [sym_string_get_expression] = STATE(5776),
    [sym_bigarray_get_expression] = STATE(5776),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6138),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(2022),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym_sign_operator] = STATE(1969),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__instance_variable_name] = STATE(17866),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [sym__lowercase_identifier] = ACTIONS(1395),
    [anon_sym_let] = ACTIONS(1397),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_fun] = ACTIONS(1409),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1415),
    [anon_sym_function] = ACTIONS(1417),
    [anon_sym_try] = ACTIONS(1419),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1441),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2023] = {
    [sym_value_definition] = STATE(17966),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12474),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2023),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2141),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(17979),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2024] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11840),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(2024),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2025] = {
    [sym_value_definition] = STATE(17889),
    [sym__simple_expression] = STATE(2457),
    [sym__expression] = STATE(11886),
    [sym_typed_expression] = STATE(6138),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6138),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6138),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5776),
    [sym_array_get_expression] = STATE(5776),
    [sym_string_get_expression] = STATE(5776),
    [sym_bigarray_get_expression] = STATE(5776),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6138),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(2025),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym_sign_operator] = STATE(1969),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__instance_variable_name] = STATE(17866),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [sym__lowercase_identifier] = ACTIONS(1395),
    [anon_sym_let] = ACTIONS(1397),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_fun] = ACTIONS(1409),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1415),
    [anon_sym_function] = ACTIONS(1417),
    [anon_sym_try] = ACTIONS(1419),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1441),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2026] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8404),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(2026),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2027] = {
    [sym_value_definition] = STATE(18990),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12170),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6117),
    [sym_array_get_expression] = STATE(6117),
    [sym_string_get_expression] = STATE(6117),
    [sym_bigarray_get_expression] = STATE(6117),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2027),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2049),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(18809),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2519),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2531),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2535),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2537),
    [anon_sym_function] = ACTIONS(2539),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2563),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2028] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12536),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2028),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2029] = {
    [sym_value_definition] = STATE(17779),
    [sym__simple_expression] = STATE(574),
    [sym__expression] = STATE(8381),
    [sym_typed_expression] = STATE(3838),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3838),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3838),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3325),
    [sym_array_get_expression] = STATE(3325),
    [sym_string_get_expression] = STATE(3325),
    [sym_bigarray_get_expression] = STATE(3325),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3838),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(2029),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym_sign_operator] = STATE(2029),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__instance_variable_name] = STATE(17788),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [sym__lowercase_identifier] = ACTIONS(753),
    [anon_sym_let] = ACTIONS(755),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_fun] = ACTIONS(767),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(799),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2030] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12511),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2030),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2031] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12507),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2031),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2032] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11836),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(2032),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2033] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11835),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(2033),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2034] = {
    [sym_value_definition] = STATE(18990),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12175),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6117),
    [sym_array_get_expression] = STATE(6117),
    [sym_string_get_expression] = STATE(6117),
    [sym_bigarray_get_expression] = STATE(6117),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2034),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2049),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(18809),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2519),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2531),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2535),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2537),
    [anon_sym_function] = ACTIONS(2539),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2563),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2035] = {
    [sym_value_definition] = STATE(18990),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12176),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6117),
    [sym_array_get_expression] = STATE(6117),
    [sym_string_get_expression] = STATE(6117),
    [sym_bigarray_get_expression] = STATE(6117),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2035),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2049),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(18809),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2519),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2531),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2535),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2537),
    [anon_sym_function] = ACTIONS(2539),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2563),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2036] = {
    [sym_value_definition] = STATE(18990),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12179),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6117),
    [sym_array_get_expression] = STATE(6117),
    [sym_string_get_expression] = STATE(6117),
    [sym_bigarray_get_expression] = STATE(6117),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2036),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2049),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(18809),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2519),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2531),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2535),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2537),
    [anon_sym_function] = ACTIONS(2539),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2563),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2037] = {
    [sym_value_definition] = STATE(18990),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12184),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6117),
    [sym_array_get_expression] = STATE(6117),
    [sym_string_get_expression] = STATE(6117),
    [sym_bigarray_get_expression] = STATE(6117),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2037),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2049),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(18809),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2519),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2531),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2535),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2537),
    [anon_sym_function] = ACTIONS(2539),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2563),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2038] = {
    [sym_value_definition] = STATE(18990),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12187),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6117),
    [sym_array_get_expression] = STATE(6117),
    [sym_string_get_expression] = STATE(6117),
    [sym_bigarray_get_expression] = STATE(6117),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2038),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2049),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(18809),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2519),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2531),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2535),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2537),
    [anon_sym_function] = ACTIONS(2539),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2563),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2039] = {
    [sym_value_definition] = STATE(18990),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12190),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6117),
    [sym_array_get_expression] = STATE(6117),
    [sym_string_get_expression] = STATE(6117),
    [sym_bigarray_get_expression] = STATE(6117),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2039),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2049),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(18809),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2519),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2531),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2535),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2537),
    [anon_sym_function] = ACTIONS(2539),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2563),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2040] = {
    [sym_value_definition] = STATE(18990),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12191),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6117),
    [sym_array_get_expression] = STATE(6117),
    [sym_string_get_expression] = STATE(6117),
    [sym_bigarray_get_expression] = STATE(6117),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2040),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2049),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(18809),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2519),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2531),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2535),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2537),
    [anon_sym_function] = ACTIONS(2539),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2563),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2041] = {
    [sym_value_definition] = STATE(18990),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12193),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6117),
    [sym_array_get_expression] = STATE(6117),
    [sym_string_get_expression] = STATE(6117),
    [sym_bigarray_get_expression] = STATE(6117),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2041),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2049),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(18809),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2519),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2531),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2535),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2537),
    [anon_sym_function] = ACTIONS(2539),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2563),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2042] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11834),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(2042),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2043] = {
    [sym_value_definition] = STATE(18990),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12195),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6117),
    [sym_array_get_expression] = STATE(6117),
    [sym_string_get_expression] = STATE(6117),
    [sym_bigarray_get_expression] = STATE(6117),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2043),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2049),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(18809),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2519),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2531),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2535),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2537),
    [anon_sym_function] = ACTIONS(2539),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2563),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2044] = {
    [sym_value_definition] = STATE(18990),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12196),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6117),
    [sym_array_get_expression] = STATE(6117),
    [sym_string_get_expression] = STATE(6117),
    [sym_bigarray_get_expression] = STATE(6117),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2044),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2049),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(18809),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2519),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2531),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2535),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2537),
    [anon_sym_function] = ACTIONS(2539),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2563),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2045] = {
    [sym_value_definition] = STATE(18990),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12197),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6117),
    [sym_array_get_expression] = STATE(6117),
    [sym_string_get_expression] = STATE(6117),
    [sym_bigarray_get_expression] = STATE(6117),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2045),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2049),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(18809),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2519),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2531),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2535),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2537),
    [anon_sym_function] = ACTIONS(2539),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2563),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2046] = {
    [sym_value_definition] = STATE(17966),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12473),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2046),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2141),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(17979),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2047] = {
    [sym_value_definition] = STATE(17611),
    [sym__simple_expression] = STATE(323),
    [sym__expression] = STATE(8241),
    [sym_typed_expression] = STATE(3176),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3176),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3176),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2957),
    [sym_array_get_expression] = STATE(2957),
    [sym_string_get_expression] = STATE(2957),
    [sym_bigarray_get_expression] = STATE(2957),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3176),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(2047),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym_sign_operator] = STATE(1905),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__instance_variable_name] = STATE(17621),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [sym__lowercase_identifier] = ACTIONS(355),
    [anon_sym_let] = ACTIONS(357),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_fun] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_if] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(375),
    [anon_sym_function] = ACTIONS(377),
    [anon_sym_try] = ACTIONS(379),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3107),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3109),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(401),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2048] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2048),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2049] = {
    [sym_value_definition] = STATE(18990),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12023),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6117),
    [sym_array_get_expression] = STATE(6117),
    [sym_string_get_expression] = STATE(6117),
    [sym_bigarray_get_expression] = STATE(6117),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2049),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2049),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(18809),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2519),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2531),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2535),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2537),
    [anon_sym_function] = ACTIONS(2539),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2563),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2050] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11833),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(2050),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2051] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11831),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(2051),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2052] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11830),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(2052),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2053] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11829),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(2053),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2054] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11828),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(2054),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2055] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11827),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(2055),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2056] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11826),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(2056),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2057] = {
    [sym_value_definition] = STATE(17889),
    [sym__simple_expression] = STATE(2457),
    [sym__expression] = STATE(11888),
    [sym_typed_expression] = STATE(6138),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6138),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6138),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5776),
    [sym_array_get_expression] = STATE(5776),
    [sym_string_get_expression] = STATE(5776),
    [sym_bigarray_get_expression] = STATE(5776),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6138),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(2057),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym_sign_operator] = STATE(1969),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__instance_variable_name] = STATE(17866),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [sym__lowercase_identifier] = ACTIONS(1395),
    [anon_sym_let] = ACTIONS(1397),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_fun] = ACTIONS(1409),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1415),
    [anon_sym_function] = ACTIONS(1417),
    [anon_sym_try] = ACTIONS(1419),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1441),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2058] = {
    [sym_value_definition] = STATE(18705),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(12011),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6123),
    [sym_array_get_expression] = STATE(6123),
    [sym_string_get_expression] = STATE(6123),
    [sym_bigarray_get_expression] = STATE(6123),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2058),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2250),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18531),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2355),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2367),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2373),
    [anon_sym_function] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2399),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2059] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12506),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2059),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2060] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11824),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(2060),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2061] = {
    [sym_value_definition] = STATE(18662),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12120),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6146),
    [sym_array_get_expression] = STATE(6146),
    [sym_string_get_expression] = STATE(6146),
    [sym_bigarray_get_expression] = STATE(6146),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(2061),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(2139),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18398),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2062] = {
    [sym_value_definition] = STATE(17611),
    [sym__simple_expression] = STATE(323),
    [sym__expression] = STATE(8242),
    [sym_typed_expression] = STATE(3176),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3176),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3176),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2957),
    [sym_array_get_expression] = STATE(2957),
    [sym_string_get_expression] = STATE(2957),
    [sym_bigarray_get_expression] = STATE(2957),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3176),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(2062),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym_sign_operator] = STATE(1905),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__instance_variable_name] = STATE(17621),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [sym__lowercase_identifier] = ACTIONS(355),
    [anon_sym_let] = ACTIONS(357),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_fun] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_if] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(375),
    [anon_sym_function] = ACTIONS(377),
    [anon_sym_try] = ACTIONS(379),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3107),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3109),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(401),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2063] = {
    [sym_value_definition] = STATE(18713),
    [sym__simple_expression] = STATE(2442),
    [sym__expression] = STATE(11899),
    [sym_typed_expression] = STATE(5778),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5778),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5778),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5788),
    [sym_array_get_expression] = STATE(5788),
    [sym_string_get_expression] = STATE(5788),
    [sym_bigarray_get_expression] = STATE(5788),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5778),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(2063),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym_sign_operator] = STATE(2063),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__instance_variable_name] = STATE(18721),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [sym__lowercase_identifier] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1447),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_fun] = ACTIONS(1449),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1451),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_try] = ACTIONS(1361),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1383),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2064] = {
    [sym_value_definition] = STATE(17611),
    [sym__simple_expression] = STATE(323),
    [sym__expression] = STATE(8246),
    [sym_typed_expression] = STATE(3176),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3176),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3176),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2957),
    [sym_array_get_expression] = STATE(2957),
    [sym_string_get_expression] = STATE(2957),
    [sym_bigarray_get_expression] = STATE(2957),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3176),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(2064),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym_sign_operator] = STATE(1905),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__instance_variable_name] = STATE(17621),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [sym__lowercase_identifier] = ACTIONS(355),
    [anon_sym_let] = ACTIONS(357),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_fun] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_if] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(375),
    [anon_sym_function] = ACTIONS(377),
    [anon_sym_try] = ACTIONS(379),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3107),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3109),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(401),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2065] = {
    [sym__simple_expression] = STATE(3675),
    [sym_typed_expression] = STATE(3704),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_labeled_argument] = STATE(4252),
    [sym_prefix_expression] = STATE(3704),
    [sym_hash_expression] = STATE(3704),
    [sym_field_get_expression] = STATE(3704),
    [sym_array_get_expression] = STATE(3704),
    [sym_string_get_expression] = STATE(3704),
    [sym_bigarray_get_expression] = STATE(3704),
    [sym_coercion_expression] = STATE(3704),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(2065),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [aux_sym_class_application_repeat1] = STATE(2065),
    [sym__lowercase_identifier] = ACTIONS(4085),
    [anon_sym_SEMI_SEMI] = ACTIONS(3720),
    [anon_sym_let] = ACTIONS(3722),
    [anon_sym_and] = ACTIONS(3722),
    [anon_sym_TILDE] = ACTIONS(4088),
    [anon_sym_QMARK] = ACTIONS(4088),
    [anon_sym_LPAREN] = ACTIONS(4091),
    [anon_sym_external] = ACTIONS(3722),
    [anon_sym_type] = ACTIONS(3722),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(4094),
    [anon_sym_true] = ACTIONS(4097),
    [anon_sym_false] = ACTIONS(4097),
    [anon_sym_LBRACE] = ACTIONS(4100),
    [anon_sym_SEMI] = ACTIONS(3722),
    [anon_sym_exception] = ACTIONS(3722),
    [anon_sym_module] = ACTIONS(3722),
    [anon_sym_open] = ACTIONS(3722),
    [anon_sym_include] = ACTIONS(3722),
    [anon_sym_class] = ACTIONS(3722),
    [anon_sym_end] = ACTIONS(3722),
    [anon_sym_object] = ACTIONS(4103),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4106),
    [anon_sym_else] = ACTIONS(3722),
    [anon_sym_new] = ACTIONS(4109),
    [anon_sym_LBRACE_LT] = ACTIONS(4112),
    [anon_sym_begin] = ACTIONS(4115),
    [sym_ocamlyacc_value] = ACTIONS(4118),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3722),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3720),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4121),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4124),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3720),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3720),
    [aux_sym_number_token1] = ACTIONS(4127),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(4130),
    [anon_sym_DQUOTE] = ACTIONS(4133),
    [sym_prefix_operator] = ACTIONS(4136),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym_let_operator] = ACTIONS(3720),
    [sym_let_and_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(4139),
    [aux_sym_directive_token1] = ACTIONS(3720),
    [aux_sym_tag_token1] = ACTIONS(4142),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2066] = {
    [sym_value_definition] = STATE(20074),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12779),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6811),
    [sym_array_get_expression] = STATE(6811),
    [sym_string_get_expression] = STATE(6811),
    [sym_bigarray_get_expression] = STATE(6811),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(2066),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2066),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(19860),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2067] = {
    [sym_value_definition] = STATE(18797),
    [sym__simple_expression] = STATE(1527),
    [sym__expression] = STATE(8519),
    [sym_typed_expression] = STATE(4161),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4161),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4161),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3909),
    [sym_array_get_expression] = STATE(3909),
    [sym_string_get_expression] = STATE(3909),
    [sym_bigarray_get_expression] = STATE(3909),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4161),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(2067),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym_sign_operator] = STATE(2091),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__instance_variable_name] = STATE(18811),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [sym__lowercase_identifier] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_fun] = ACTIONS(819),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_if] = ACTIONS(823),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(825),
    [anon_sym_function] = ACTIONS(827),
    [anon_sym_try] = ACTIONS(829),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3115),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3117),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(851),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2068] = {
    [sym_value_definition] = STATE(17966),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12471),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2068),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2141),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(17979),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2069] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12505),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2069),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2070] = {
    [sym_value_definition] = STATE(18662),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12118),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6146),
    [sym_array_get_expression] = STATE(6146),
    [sym_string_get_expression] = STATE(6146),
    [sym_bigarray_get_expression] = STATE(6146),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(2070),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(2139),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18398),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2071] = {
    [sym_value_definition] = STATE(17611),
    [sym__simple_expression] = STATE(323),
    [sym__expression] = STATE(8247),
    [sym_typed_expression] = STATE(3176),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3176),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3176),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2957),
    [sym_array_get_expression] = STATE(2957),
    [sym_string_get_expression] = STATE(2957),
    [sym_bigarray_get_expression] = STATE(2957),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3176),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(2071),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym_sign_operator] = STATE(1905),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__instance_variable_name] = STATE(17621),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [sym__lowercase_identifier] = ACTIONS(355),
    [anon_sym_let] = ACTIONS(357),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_fun] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_if] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(375),
    [anon_sym_function] = ACTIONS(377),
    [anon_sym_try] = ACTIONS(379),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3107),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3109),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(401),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2072] = {
    [sym_value_definition] = STATE(17966),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12564),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2072),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2141),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(17979),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2073] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12502),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2073),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2074] = {
    [sym_value_definition] = STATE(18797),
    [sym__simple_expression] = STATE(1527),
    [sym__expression] = STATE(8554),
    [sym_typed_expression] = STATE(4161),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4161),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4161),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3909),
    [sym_array_get_expression] = STATE(3909),
    [sym_string_get_expression] = STATE(3909),
    [sym_bigarray_get_expression] = STATE(3909),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4161),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(2074),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym_sign_operator] = STATE(2091),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__instance_variable_name] = STATE(18811),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [sym__lowercase_identifier] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_fun] = ACTIONS(819),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_if] = ACTIONS(823),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(825),
    [anon_sym_function] = ACTIONS(827),
    [anon_sym_try] = ACTIONS(829),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3115),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3117),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(851),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2075] = {
    [sym_value_definition] = STATE(18797),
    [sym__simple_expression] = STATE(1527),
    [sym__expression] = STATE(8552),
    [sym_typed_expression] = STATE(4161),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4161),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4161),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3909),
    [sym_array_get_expression] = STATE(3909),
    [sym_string_get_expression] = STATE(3909),
    [sym_bigarray_get_expression] = STATE(3909),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4161),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(2075),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym_sign_operator] = STATE(2091),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__instance_variable_name] = STATE(18811),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [sym__lowercase_identifier] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_fun] = ACTIONS(819),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_if] = ACTIONS(823),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(825),
    [anon_sym_function] = ACTIONS(827),
    [anon_sym_try] = ACTIONS(829),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3115),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3117),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(851),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2076] = {
    [sym_value_definition] = STATE(18797),
    [sym__simple_expression] = STATE(1527),
    [sym__expression] = STATE(8550),
    [sym_typed_expression] = STATE(4161),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4161),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4161),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3909),
    [sym_array_get_expression] = STATE(3909),
    [sym_string_get_expression] = STATE(3909),
    [sym_bigarray_get_expression] = STATE(3909),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4161),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(2076),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym_sign_operator] = STATE(2091),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__instance_variable_name] = STATE(18811),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [sym__lowercase_identifier] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_fun] = ACTIONS(819),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_if] = ACTIONS(823),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(825),
    [anon_sym_function] = ACTIONS(827),
    [anon_sym_try] = ACTIONS(829),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3115),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3117),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(851),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2077] = {
    [sym_value_definition] = STATE(18797),
    [sym__simple_expression] = STATE(1527),
    [sym__expression] = STATE(8548),
    [sym_typed_expression] = STATE(4161),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4161),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4161),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3909),
    [sym_array_get_expression] = STATE(3909),
    [sym_string_get_expression] = STATE(3909),
    [sym_bigarray_get_expression] = STATE(3909),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4161),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(2077),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym_sign_operator] = STATE(2091),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__instance_variable_name] = STATE(18811),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [sym__lowercase_identifier] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_fun] = ACTIONS(819),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_if] = ACTIONS(823),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(825),
    [anon_sym_function] = ACTIONS(827),
    [anon_sym_try] = ACTIONS(829),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3115),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3117),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(851),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2078] = {
    [sym_value_definition] = STATE(17966),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12467),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2078),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2141),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(17979),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2079] = {
    [sym_value_definition] = STATE(17966),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12463),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2079),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2141),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(17979),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2080] = {
    [sym_value_definition] = STATE(17966),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12462),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2080),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2141),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(17979),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2081] = {
    [sym_value_definition] = STATE(18797),
    [sym__simple_expression] = STATE(1527),
    [sym__expression] = STATE(8546),
    [sym_typed_expression] = STATE(4161),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4161),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4161),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3909),
    [sym_array_get_expression] = STATE(3909),
    [sym_string_get_expression] = STATE(3909),
    [sym_bigarray_get_expression] = STATE(3909),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4161),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(2081),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym_sign_operator] = STATE(2091),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__instance_variable_name] = STATE(18811),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [sym__lowercase_identifier] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_fun] = ACTIONS(819),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_if] = ACTIONS(823),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(825),
    [anon_sym_function] = ACTIONS(827),
    [anon_sym_try] = ACTIONS(829),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3115),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3117),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(851),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2082] = {
    [sym_value_definition] = STATE(18797),
    [sym__simple_expression] = STATE(1527),
    [sym__expression] = STATE(8545),
    [sym_typed_expression] = STATE(4161),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4161),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4161),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3909),
    [sym_array_get_expression] = STATE(3909),
    [sym_string_get_expression] = STATE(3909),
    [sym_bigarray_get_expression] = STATE(3909),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4161),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(2082),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym_sign_operator] = STATE(2091),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__instance_variable_name] = STATE(18811),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [sym__lowercase_identifier] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_fun] = ACTIONS(819),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_if] = ACTIONS(823),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(825),
    [anon_sym_function] = ACTIONS(827),
    [anon_sym_try] = ACTIONS(829),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3115),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3117),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(851),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2083] = {
    [sym_value_definition] = STATE(17966),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12459),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2083),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2141),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(17979),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2084] = {
    [sym_value_definition] = STATE(18797),
    [sym__simple_expression] = STATE(1527),
    [sym__expression] = STATE(8544),
    [sym_typed_expression] = STATE(4161),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4161),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4161),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3909),
    [sym_array_get_expression] = STATE(3909),
    [sym_string_get_expression] = STATE(3909),
    [sym_bigarray_get_expression] = STATE(3909),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4161),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(2084),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym_sign_operator] = STATE(2091),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__instance_variable_name] = STATE(18811),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [sym__lowercase_identifier] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_fun] = ACTIONS(819),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_if] = ACTIONS(823),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(825),
    [anon_sym_function] = ACTIONS(827),
    [anon_sym_try] = ACTIONS(829),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3115),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3117),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(851),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2085] = {
    [sym_value_definition] = STATE(18797),
    [sym__simple_expression] = STATE(1527),
    [sym__expression] = STATE(8542),
    [sym_typed_expression] = STATE(4161),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4161),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4161),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3909),
    [sym_array_get_expression] = STATE(3909),
    [sym_string_get_expression] = STATE(3909),
    [sym_bigarray_get_expression] = STATE(3909),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4161),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(2085),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym_sign_operator] = STATE(2091),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__instance_variable_name] = STATE(18811),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [sym__lowercase_identifier] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_fun] = ACTIONS(819),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_if] = ACTIONS(823),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(825),
    [anon_sym_function] = ACTIONS(827),
    [anon_sym_try] = ACTIONS(829),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3115),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3117),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(851),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2086] = {
    [sym_value_definition] = STATE(18797),
    [sym__simple_expression] = STATE(1527),
    [sym__expression] = STATE(8540),
    [sym_typed_expression] = STATE(4161),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4161),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4161),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3909),
    [sym_array_get_expression] = STATE(3909),
    [sym_string_get_expression] = STATE(3909),
    [sym_bigarray_get_expression] = STATE(3909),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4161),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(2086),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym_sign_operator] = STATE(2091),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__instance_variable_name] = STATE(18811),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [sym__lowercase_identifier] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_fun] = ACTIONS(819),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_if] = ACTIONS(823),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(825),
    [anon_sym_function] = ACTIONS(827),
    [anon_sym_try] = ACTIONS(829),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3115),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3117),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(851),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2087] = {
    [sym_value_definition] = STATE(18797),
    [sym__simple_expression] = STATE(1527),
    [sym__expression] = STATE(8538),
    [sym_typed_expression] = STATE(4161),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4161),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4161),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3909),
    [sym_array_get_expression] = STATE(3909),
    [sym_string_get_expression] = STATE(3909),
    [sym_bigarray_get_expression] = STATE(3909),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4161),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(2087),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym_sign_operator] = STATE(2091),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__instance_variable_name] = STATE(18811),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [sym__lowercase_identifier] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_fun] = ACTIONS(819),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_if] = ACTIONS(823),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(825),
    [anon_sym_function] = ACTIONS(827),
    [anon_sym_try] = ACTIONS(829),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3115),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3117),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(851),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2088] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12457),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2088),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2089] = {
    [sym_value_definition] = STATE(18797),
    [sym__simple_expression] = STATE(1527),
    [sym__expression] = STATE(8533),
    [sym_typed_expression] = STATE(4161),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4161),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4161),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3909),
    [sym_array_get_expression] = STATE(3909),
    [sym_string_get_expression] = STATE(3909),
    [sym_bigarray_get_expression] = STATE(3909),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4161),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(2089),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym_sign_operator] = STATE(2091),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__instance_variable_name] = STATE(18811),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [sym__lowercase_identifier] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_fun] = ACTIONS(819),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_if] = ACTIONS(823),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(825),
    [anon_sym_function] = ACTIONS(827),
    [anon_sym_try] = ACTIONS(829),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3115),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3117),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(851),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2090] = {
    [sym_value_definition] = STATE(18662),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12116),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6146),
    [sym_array_get_expression] = STATE(6146),
    [sym_string_get_expression] = STATE(6146),
    [sym_bigarray_get_expression] = STATE(6146),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(2090),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(2139),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18398),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2091] = {
    [sym_value_definition] = STATE(18797),
    [sym__simple_expression] = STATE(1527),
    [sym__expression] = STATE(8478),
    [sym_typed_expression] = STATE(4161),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4161),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4161),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3909),
    [sym_array_get_expression] = STATE(3909),
    [sym_string_get_expression] = STATE(3909),
    [sym_bigarray_get_expression] = STATE(3909),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4161),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(2091),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym_sign_operator] = STATE(2091),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__instance_variable_name] = STATE(18811),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [sym__lowercase_identifier] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_fun] = ACTIONS(819),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_if] = ACTIONS(823),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(825),
    [anon_sym_function] = ACTIONS(827),
    [anon_sym_try] = ACTIONS(829),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3115),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3117),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(851),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2092] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12492),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2092),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2093] = {
    [sym_value_definition] = STATE(18662),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12114),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6146),
    [sym_array_get_expression] = STATE(6146),
    [sym_string_get_expression] = STATE(6146),
    [sym_bigarray_get_expression] = STATE(6146),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(2093),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(2139),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18398),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2094] = {
    [sym_value_definition] = STATE(17966),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12456),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2094),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2141),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(17979),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2095] = {
    [sym_value_definition] = STATE(18662),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12113),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6146),
    [sym_array_get_expression] = STATE(6146),
    [sym_string_get_expression] = STATE(6146),
    [sym_bigarray_get_expression] = STATE(6146),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(2095),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(2139),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18398),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2096] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8356),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(2096),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2097] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12491),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2097),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2098] = {
    [sym_value_definition] = STATE(18662),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12110),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6146),
    [sym_array_get_expression] = STATE(6146),
    [sym_string_get_expression] = STATE(6146),
    [sym_bigarray_get_expression] = STATE(6146),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(2098),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(2139),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18398),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2099] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12483),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2099),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2100] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12482),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2100),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2101] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8360),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(2101),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2102] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8361),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(2102),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2103] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8286),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(2103),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2104] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8364),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(2104),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2105] = {
    [sym_value_definition] = STATE(17966),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12454),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2105),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2141),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(17979),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2106] = {
    [sym_value_definition] = STATE(18662),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12109),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6146),
    [sym_array_get_expression] = STATE(6146),
    [sym_string_get_expression] = STATE(6146),
    [sym_bigarray_get_expression] = STATE(6146),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(2106),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(2139),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18398),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2107] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8366),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(2107),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2108] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8370),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(2108),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2109] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8371),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(2109),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2110] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8372),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(2110),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2111] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8351),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(2111),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2112] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8373),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(2112),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2113] = {
    [sym_value_definition] = STATE(18662),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12108),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6146),
    [sym_array_get_expression] = STATE(6146),
    [sym_string_get_expression] = STATE(6146),
    [sym_bigarray_get_expression] = STATE(6146),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(2113),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(2139),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18398),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2114] = {
    [sym_value_definition] = STATE(18662),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12107),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6146),
    [sym_array_get_expression] = STATE(6146),
    [sym_string_get_expression] = STATE(6146),
    [sym_bigarray_get_expression] = STATE(6146),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(2114),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(2139),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18398),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2115] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12472),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2115),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2116] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8375),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(2116),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2117] = {
    [sym_value_definition] = STATE(19975),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12675),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7130),
    [sym_array_get_expression] = STATE(7130),
    [sym_string_get_expression] = STATE(7130),
    [sym_bigarray_get_expression] = STATE(7130),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(2117),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2117),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(19723),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2947),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2949),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2953),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2957),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2118] = {
    [sym__simple_expression] = STATE(3427),
    [sym_typed_expression] = STATE(3727),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_labeled_argument] = STATE(4280),
    [sym_prefix_expression] = STATE(3727),
    [sym_hash_expression] = STATE(3727),
    [sym_field_get_expression] = STATE(3727),
    [sym_array_get_expression] = STATE(3727),
    [sym_string_get_expression] = STATE(3727),
    [sym_bigarray_get_expression] = STATE(3727),
    [sym_coercion_expression] = STATE(3727),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(2118),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [aux_sym_class_application_repeat1] = STATE(1963),
    [sym__lowercase_identifier] = ACTIONS(3147),
    [anon_sym_SEMI_SEMI] = ACTIONS(3943),
    [anon_sym_let] = ACTIONS(3945),
    [anon_sym_and] = ACTIONS(3945),
    [anon_sym_TILDE] = ACTIONS(3149),
    [anon_sym_QMARK] = ACTIONS(3149),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_external] = ACTIONS(3945),
    [anon_sym_type] = ACTIONS(3945),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_SEMI] = ACTIONS(3945),
    [anon_sym_exception] = ACTIONS(3945),
    [anon_sym_module] = ACTIONS(3945),
    [anon_sym_open] = ACTIONS(3945),
    [anon_sym_include] = ACTIONS(3945),
    [anon_sym_class] = ACTIONS(3945),
    [anon_sym_end] = ACTIONS(3945),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_in] = ACTIONS(3945),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3945),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3943),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(667),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(669),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3943),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3943),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym_let_operator] = ACTIONS(3943),
    [sym_let_and_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_directive_token1] = ACTIONS(3943),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2119] = {
    [sym_value_definition] = STATE(18902),
    [sym__simple_expression] = STATE(505),
    [sym__expression] = STATE(8285),
    [sym_typed_expression] = STATE(3727),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3727),
    [sym_array_expression] = STATE(3727),
    [sym_record_expression] = STATE(3727),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3727),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3727),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3100),
    [sym_array_get_expression] = STATE(3100),
    [sym_string_get_expression] = STATE(3100),
    [sym_bigarray_get_expression] = STATE(3100),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3727),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3727),
    [sym_package_expression] = STATE(3727),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3727),
    [sym_object_copy_expression] = STATE(3727),
    [sym_method_invocation] = STATE(3727),
    [sym_object_expression] = STATE(3727),
    [sym_parenthesized_expression] = STATE(3727),
    [sym_attribute] = STATE(2119),
    [sym_extension] = STATE(3727),
    [sym_quoted_extension] = STATE(3727),
    [sym__constant] = STATE(3727),
    [sym_number] = STATE(3635),
    [sym_character] = STATE(3635),
    [sym_string] = STATE(3635),
    [sym_quoted_string] = STATE(3635),
    [sym_boolean] = STATE(3635),
    [sym_unit] = STATE(3635),
    [sym_sign_operator] = STATE(2119),
    [sym__value_name] = STATE(3457),
    [sym_parenthesized_operator] = STATE(3405),
    [sym_value_path] = STATE(3727),
    [sym_module_path] = STATE(17786),
    [sym_constructor_path] = STATE(3727),
    [sym__instance_variable_name] = STATE(18916),
    [sym__constructor_name] = STATE(3460),
    [sym_tag] = STATE(3727),
    [sym__lowercase_identifier] = ACTIONS(633),
    [anon_sym_let] = ACTIONS(635),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(639),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(645),
    [anon_sym_fun] = ACTIONS(647),
    [anon_sym_LBRACK_PIPE] = ACTIONS(649),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(655),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_LBRACE_LT] = ACTIONS(661),
    [anon_sym_begin] = ACTIONS(663),
    [sym_ocamlyacc_value] = ACTIONS(665),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3131),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3133),
    [aux_sym_number_token1] = ACTIONS(671),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE] = ACTIONS(675),
    [sym_prefix_operator] = ACTIONS(677),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(679),
    [sym__uppercase_identifier] = ACTIONS(681),
    [aux_sym_tag_token1] = ACTIONS(683),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2120] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12460),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2120),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2121] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(12123),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(2121),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2122] = {
    [sym_value_definition] = STATE(20489),
    [sym__simple_expression] = STATE(2425),
    [sym__expression] = STATE(12012),
    [sym_typed_expression] = STATE(5003),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5003),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5003),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6050),
    [sym_array_get_expression] = STATE(6050),
    [sym_string_get_expression] = STATE(6050),
    [sym_bigarray_get_expression] = STATE(6050),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5003),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(2122),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym_sign_operator] = STATE(1961),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__instance_variable_name] = STATE(20493),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [sym__lowercase_identifier] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(2065),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_fun] = ACTIONS(2067),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_if] = ACTIONS(2069),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2071),
    [anon_sym_function] = ACTIONS(2073),
    [anon_sym_try] = ACTIONS(2075),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2077),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2123] = {
    [sym_value_definition] = STATE(18662),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12106),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6146),
    [sym_array_get_expression] = STATE(6146),
    [sym_string_get_expression] = STATE(6146),
    [sym_bigarray_get_expression] = STATE(6146),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(2123),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(2139),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18398),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2124] = {
    [sym__simple_expression] = STATE(4403),
    [sym_typed_expression] = STATE(4315),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_labeled_argument] = STATE(4649),
    [sym_prefix_expression] = STATE(4315),
    [sym_hash_expression] = STATE(4315),
    [sym_field_get_expression] = STATE(4315),
    [sym_array_get_expression] = STATE(4315),
    [sym_string_get_expression] = STATE(4315),
    [sym_bigarray_get_expression] = STATE(4315),
    [sym_coercion_expression] = STATE(4315),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(2124),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [aux_sym_class_application_repeat1] = STATE(2419),
    [sym__lowercase_identifier] = ACTIONS(4145),
    [anon_sym_SEMI_SEMI] = ACTIONS(3051),
    [anon_sym_let] = ACTIONS(3053),
    [anon_sym_TILDE] = ACTIONS(4147),
    [anon_sym_QMARK] = ACTIONS(4147),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(3053),
    [anon_sym_type] = ACTIONS(3053),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(3051),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_DOT] = ACTIONS(4149),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(3053),
    [anon_sym_exception] = ACTIONS(3053),
    [anon_sym_module] = ACTIONS(3053),
    [anon_sym_open] = ACTIONS(3053),
    [anon_sym_include] = ACTIONS(3053),
    [anon_sym_class] = ACTIONS(3053),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_POUND] = ACTIONS(4151),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3053),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3051),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3051),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(4153),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym_let_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(3053),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2125] = {
    [sym_value_definition] = STATE(17611),
    [sym__simple_expression] = STATE(323),
    [sym__expression] = STATE(8248),
    [sym_typed_expression] = STATE(3176),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3176),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3176),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2957),
    [sym_array_get_expression] = STATE(2957),
    [sym_string_get_expression] = STATE(2957),
    [sym_bigarray_get_expression] = STATE(2957),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3176),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(2125),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym_sign_operator] = STATE(1905),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__instance_variable_name] = STATE(17621),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [sym__lowercase_identifier] = ACTIONS(355),
    [anon_sym_let] = ACTIONS(357),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_fun] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_if] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(375),
    [anon_sym_function] = ACTIONS(377),
    [anon_sym_try] = ACTIONS(379),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3107),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3109),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(401),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2126] = {
    [sym__simple_expression] = STATE(3334),
    [sym_typed_expression] = STATE(3461),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_labeled_argument] = STATE(4439),
    [sym_prefix_expression] = STATE(3461),
    [sym_hash_expression] = STATE(3461),
    [sym_field_get_expression] = STATE(3461),
    [sym_array_get_expression] = STATE(3461),
    [sym_string_get_expression] = STATE(3461),
    [sym_bigarray_get_expression] = STATE(3461),
    [sym_coercion_expression] = STATE(3461),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(2126),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [aux_sym_class_application_repeat1] = STATE(2126),
    [sym__lowercase_identifier] = ACTIONS(4155),
    [anon_sym_SEMI_SEMI] = ACTIONS(3720),
    [anon_sym_let] = ACTIONS(3722),
    [anon_sym_and] = ACTIONS(3722),
    [anon_sym_TILDE] = ACTIONS(4158),
    [anon_sym_QMARK] = ACTIONS(4158),
    [anon_sym_LPAREN] = ACTIONS(4161),
    [anon_sym_external] = ACTIONS(3722),
    [anon_sym_type] = ACTIONS(3722),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(4164),
    [anon_sym_RBRACK] = ACTIONS(3720),
    [anon_sym_true] = ACTIONS(4167),
    [anon_sym_false] = ACTIONS(4167),
    [anon_sym_LBRACE] = ACTIONS(4170),
    [anon_sym_SEMI] = ACTIONS(3722),
    [anon_sym_exception] = ACTIONS(3722),
    [anon_sym_module] = ACTIONS(3722),
    [anon_sym_open] = ACTIONS(3722),
    [anon_sym_include] = ACTIONS(3722),
    [anon_sym_class] = ACTIONS(3722),
    [anon_sym_object] = ACTIONS(4173),
    [anon_sym_in] = ACTIONS(3722),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4176),
    [anon_sym_new] = ACTIONS(4179),
    [anon_sym_LBRACE_LT] = ACTIONS(4182),
    [anon_sym_begin] = ACTIONS(4185),
    [sym_ocamlyacc_value] = ACTIONS(4188),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3722),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3720),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4191),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4194),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3720),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3720),
    [aux_sym_number_token1] = ACTIONS(4197),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(4200),
    [anon_sym_DQUOTE] = ACTIONS(4203),
    [sym_prefix_operator] = ACTIONS(4206),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym_let_operator] = ACTIONS(3720),
    [sym_let_and_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(4209),
    [aux_sym_directive_token1] = ACTIONS(3720),
    [aux_sym_tag_token1] = ACTIONS(4212),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2127] = {
    [sym_value_definition] = STATE(18662),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12105),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6146),
    [sym_array_get_expression] = STATE(6146),
    [sym_string_get_expression] = STATE(6146),
    [sym_bigarray_get_expression] = STATE(6146),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(2127),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(2139),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18398),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2128] = {
    [sym_value_definition] = STATE(19586),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8771),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(2128),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2129] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(12157),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(2129),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2130] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(12160),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(2130),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2131] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(12163),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(2131),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2132] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(12164),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(2132),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2133] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(12166),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(2133),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2134] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(12167),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(2134),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2135] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(12168),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(2135),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2136] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(12169),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(2136),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2137] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(12172),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(2137),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2138] = {
    [sym_value_definition] = STATE(18662),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12104),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6146),
    [sym_array_get_expression] = STATE(6146),
    [sym_string_get_expression] = STATE(6146),
    [sym_bigarray_get_expression] = STATE(6146),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(2138),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(2139),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18398),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2139] = {
    [sym_value_definition] = STATE(18662),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12121),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6146),
    [sym_array_get_expression] = STATE(6146),
    [sym_string_get_expression] = STATE(6146),
    [sym_bigarray_get_expression] = STATE(6146),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(2139),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(2139),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18398),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2140] = {
    [sym_value_definition] = STATE(18821),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12153),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6118),
    [sym_array_get_expression] = STATE(6118),
    [sym_string_get_expression] = STATE(6118),
    [sym_bigarray_get_expression] = STATE(6118),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(2140),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(2170),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18670),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2415),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2433),
    [anon_sym_function] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2437),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2459),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2141] = {
    [sym_value_definition] = STATE(17966),
    [sym__simple_expression] = STATE(2466),
    [sym__expression] = STATE(12607),
    [sym_typed_expression] = STATE(6255),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6255),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6255),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6255),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2141),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym_sign_operator] = STATE(2141),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__instance_variable_name] = STATE(17979),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [sym__lowercase_identifier] = ACTIONS(2517),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2142] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(12182),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(2142),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2143] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(12183),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(2143),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2144] = {
    [sym_value_definition] = STATE(17611),
    [sym__simple_expression] = STATE(323),
    [sym__expression] = STATE(8256),
    [sym_typed_expression] = STATE(3176),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3176),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3176),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2957),
    [sym_array_get_expression] = STATE(2957),
    [sym_string_get_expression] = STATE(2957),
    [sym_bigarray_get_expression] = STATE(2957),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3176),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(2144),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym_sign_operator] = STATE(1905),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__instance_variable_name] = STATE(17621),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [sym__lowercase_identifier] = ACTIONS(355),
    [anon_sym_let] = ACTIONS(357),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_fun] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_if] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(375),
    [anon_sym_function] = ACTIONS(377),
    [anon_sym_try] = ACTIONS(379),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3107),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3109),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(401),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2145] = {
    [sym_value_definition] = STATE(17611),
    [sym__simple_expression] = STATE(323),
    [sym__expression] = STATE(8272),
    [sym_typed_expression] = STATE(3176),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3176),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3176),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2957),
    [sym_array_get_expression] = STATE(2957),
    [sym_string_get_expression] = STATE(2957),
    [sym_bigarray_get_expression] = STATE(2957),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3176),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(2145),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym_sign_operator] = STATE(1905),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__instance_variable_name] = STATE(17621),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [sym__lowercase_identifier] = ACTIONS(355),
    [anon_sym_let] = ACTIONS(357),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_fun] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_if] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(375),
    [anon_sym_function] = ACTIONS(377),
    [anon_sym_try] = ACTIONS(379),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3107),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3109),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(401),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2146] = {
    [sym_value_definition] = STATE(19018),
    [sym__simple_expression] = STATE(2469),
    [sym__expression] = STATE(11970),
    [sym_typed_expression] = STATE(6303),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6303),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6303),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6009),
    [sym_array_get_expression] = STATE(6009),
    [sym_string_get_expression] = STATE(6009),
    [sym_bigarray_get_expression] = STATE(6009),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6303),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(2146),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym_sign_operator] = STATE(2146),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__instance_variable_name] = STATE(17590),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [sym__lowercase_identifier] = ACTIONS(1541),
    [anon_sym_let] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_fun] = ACTIONS(1555),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_try] = ACTIONS(1565),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1587),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2147] = {
    [sym_value_definition] = STATE(18277),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(12325),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6588),
    [sym_array_get_expression] = STATE(6588),
    [sym_string_get_expression] = STATE(6588),
    [sym_bigarray_get_expression] = STATE(6588),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2147),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2201),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18286),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2148] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12214),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(2148),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2149] = {
    [sym_value_definition] = STATE(19237),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6382),
    [sym_array_get_expression] = STATE(6382),
    [sym_string_get_expression] = STATE(6382),
    [sym_bigarray_get_expression] = STATE(6382),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2149),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2120),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(20487),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(2795),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(2797),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2801),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2805),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2807),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2150] = {
    [sym_value_definition] = STATE(17611),
    [sym__simple_expression] = STATE(323),
    [sym__expression] = STATE(8273),
    [sym_typed_expression] = STATE(3176),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3176),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3176),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2957),
    [sym_array_get_expression] = STATE(2957),
    [sym_string_get_expression] = STATE(2957),
    [sym_bigarray_get_expression] = STATE(2957),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3176),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(2150),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym_sign_operator] = STATE(1905),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__instance_variable_name] = STATE(17621),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [sym__lowercase_identifier] = ACTIONS(355),
    [anon_sym_let] = ACTIONS(357),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_fun] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_if] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(375),
    [anon_sym_function] = ACTIONS(377),
    [anon_sym_try] = ACTIONS(379),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3107),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3109),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(401),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2151] = {
    [sym_value_definition] = STATE(17714),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9782),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4836),
    [sym_array_get_expression] = STATE(4836),
    [sym_string_get_expression] = STATE(4836),
    [sym_bigarray_get_expression] = STATE(4836),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(2151),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(2151),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(17727),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(973),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(975),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(983),
    [anon_sym_function] = ACTIONS(985),
    [anon_sym_try] = ACTIONS(987),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(993),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2152] = {
    [sym_value_definition] = STATE(17714),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9552),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4836),
    [sym_array_get_expression] = STATE(4836),
    [sym_string_get_expression] = STATE(4836),
    [sym_bigarray_get_expression] = STATE(4836),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(2152),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(2151),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(17727),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(973),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(975),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(983),
    [anon_sym_function] = ACTIONS(985),
    [anon_sym_try] = ACTIONS(987),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(993),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2153] = {
    [sym_value_definition] = STATE(18821),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12147),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6118),
    [sym_array_get_expression] = STATE(6118),
    [sym_string_get_expression] = STATE(6118),
    [sym_bigarray_get_expression] = STATE(6118),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(2153),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(2170),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18670),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2415),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2433),
    [anon_sym_function] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2437),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2459),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2154] = {
    [sym_value_definition] = STATE(18821),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12146),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6118),
    [sym_array_get_expression] = STATE(6118),
    [sym_string_get_expression] = STATE(6118),
    [sym_bigarray_get_expression] = STATE(6118),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(2154),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(2170),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18670),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2415),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2433),
    [anon_sym_function] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2437),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2459),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2155] = {
    [sym_value_definition] = STATE(18821),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12145),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6118),
    [sym_array_get_expression] = STATE(6118),
    [sym_string_get_expression] = STATE(6118),
    [sym_bigarray_get_expression] = STATE(6118),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(2155),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(2170),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18670),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2415),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2433),
    [anon_sym_function] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2437),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2459),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2156] = {
    [sym_value_definition] = STATE(18821),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12141),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6118),
    [sym_array_get_expression] = STATE(6118),
    [sym_string_get_expression] = STATE(6118),
    [sym_bigarray_get_expression] = STATE(6118),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(2156),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(2170),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18670),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2415),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2433),
    [anon_sym_function] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2437),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2459),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2157] = {
    [sym_value_definition] = STATE(18821),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12140),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6118),
    [sym_array_get_expression] = STATE(6118),
    [sym_string_get_expression] = STATE(6118),
    [sym_bigarray_get_expression] = STATE(6118),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(2157),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(2170),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18670),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2415),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2433),
    [anon_sym_function] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2437),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2459),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2158] = {
    [sym_value_definition] = STATE(17611),
    [sym__simple_expression] = STATE(323),
    [sym__expression] = STATE(8274),
    [sym_typed_expression] = STATE(3176),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3176),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3176),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2957),
    [sym_array_get_expression] = STATE(2957),
    [sym_string_get_expression] = STATE(2957),
    [sym_bigarray_get_expression] = STATE(2957),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3176),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(2158),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym_sign_operator] = STATE(1905),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__instance_variable_name] = STATE(17621),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [sym__lowercase_identifier] = ACTIONS(355),
    [anon_sym_let] = ACTIONS(357),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_fun] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_if] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(375),
    [anon_sym_function] = ACTIONS(377),
    [anon_sym_try] = ACTIONS(379),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3107),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3109),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(401),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2159] = {
    [sym_value_definition] = STATE(18821),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12139),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6118),
    [sym_array_get_expression] = STATE(6118),
    [sym_string_get_expression] = STATE(6118),
    [sym_bigarray_get_expression] = STATE(6118),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(2159),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(2170),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18670),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2415),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2433),
    [anon_sym_function] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2437),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2459),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2160] = {
    [sym_value_definition] = STATE(18821),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12136),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6118),
    [sym_array_get_expression] = STATE(6118),
    [sym_string_get_expression] = STATE(6118),
    [sym_bigarray_get_expression] = STATE(6118),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(2160),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(2170),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18670),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2415),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2433),
    [anon_sym_function] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2437),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2459),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2161] = {
    [sym_value_definition] = STATE(18277),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(12328),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6588),
    [sym_array_get_expression] = STATE(6588),
    [sym_string_get_expression] = STATE(6588),
    [sym_bigarray_get_expression] = STATE(6588),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2161),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2201),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18286),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2162] = {
    [sym_value_definition] = STATE(18277),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(12330),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6588),
    [sym_array_get_expression] = STATE(6588),
    [sym_string_get_expression] = STATE(6588),
    [sym_bigarray_get_expression] = STATE(6588),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2162),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2201),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18286),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2163] = {
    [sym_value_definition] = STATE(18821),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12135),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6118),
    [sym_array_get_expression] = STATE(6118),
    [sym_string_get_expression] = STATE(6118),
    [sym_bigarray_get_expression] = STATE(6118),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(2163),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(2170),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18670),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2415),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2433),
    [anon_sym_function] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2437),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2459),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2164] = {
    [sym_value_definition] = STATE(18821),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12134),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6118),
    [sym_array_get_expression] = STATE(6118),
    [sym_string_get_expression] = STATE(6118),
    [sym_bigarray_get_expression] = STATE(6118),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(2164),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(2170),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18670),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2415),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2433),
    [anon_sym_function] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2437),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2459),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2165] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12219),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(2165),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2166] = {
    [sym_value_definition] = STATE(18821),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12130),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6118),
    [sym_array_get_expression] = STATE(6118),
    [sym_string_get_expression] = STATE(6118),
    [sym_bigarray_get_expression] = STATE(6118),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(2166),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(2170),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18670),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2415),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2433),
    [anon_sym_function] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2437),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2459),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2167] = {
    [sym_value_definition] = STATE(18821),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12129),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6118),
    [sym_array_get_expression] = STATE(6118),
    [sym_string_get_expression] = STATE(6118),
    [sym_bigarray_get_expression] = STATE(6118),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(2167),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(2170),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18670),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2415),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2433),
    [anon_sym_function] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2437),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2459),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2168] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12225),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(2168),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2169] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12228),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(2169),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2170] = {
    [sym_value_definition] = STATE(18821),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12205),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6118),
    [sym_array_get_expression] = STATE(6118),
    [sym_string_get_expression] = STATE(6118),
    [sym_bigarray_get_expression] = STATE(6118),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(2170),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(2170),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18670),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2415),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2433),
    [anon_sym_function] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2437),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2459),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2171] = {
    [sym_value_definition] = STATE(18108),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(12439),
    [sym_typed_expression] = STATE(6162),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6162),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6162),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6582),
    [sym_array_get_expression] = STATE(6582),
    [sym_string_get_expression] = STATE(6582),
    [sym_bigarray_get_expression] = STATE(6582),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6162),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(2171),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym_sign_operator] = STATE(1808),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__instance_variable_name] = STATE(18116),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [sym__lowercase_identifier] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_fun] = ACTIONS(2575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2579),
    [anon_sym_function] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2583),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2585),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2172] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12231),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(2172),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2173] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12236),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(2173),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2174] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12238),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(2174),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2175] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12239),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(2175),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2176] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12242),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(2176),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2177] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12248),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(2177),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2178] = {
    [sym_value_definition] = STATE(17714),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9551),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4836),
    [sym_array_get_expression] = STATE(4836),
    [sym_string_get_expression] = STATE(4836),
    [sym_bigarray_get_expression] = STATE(4836),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(2178),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(2151),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(17727),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(973),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(975),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(983),
    [anon_sym_function] = ACTIONS(985),
    [anon_sym_try] = ACTIONS(987),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(993),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2179] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12254),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(2179),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2180] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12257),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(2180),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2181] = {
    [sym_value_definition] = STATE(18662),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(11965),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6146),
    [sym_array_get_expression] = STATE(6146),
    [sym_string_get_expression] = STATE(6146),
    [sym_bigarray_get_expression] = STATE(6146),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(2181),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(2139),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18398),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2182] = {
    [sym_value_definition] = STATE(17714),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9550),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4836),
    [sym_array_get_expression] = STATE(4836),
    [sym_string_get_expression] = STATE(4836),
    [sym_bigarray_get_expression] = STATE(4836),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(2182),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(2151),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(17727),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(973),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(975),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(983),
    [anon_sym_function] = ACTIONS(985),
    [anon_sym_try] = ACTIONS(987),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(993),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2183] = {
    [sym_value_definition] = STATE(18277),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(12331),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6588),
    [sym_array_get_expression] = STATE(6588),
    [sym_string_get_expression] = STATE(6588),
    [sym_bigarray_get_expression] = STATE(6588),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2183),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2201),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18286),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2184] = {
    [sym_value_definition] = STATE(17714),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9549),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4836),
    [sym_array_get_expression] = STATE(4836),
    [sym_string_get_expression] = STATE(4836),
    [sym_bigarray_get_expression] = STATE(4836),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(2184),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(2151),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(17727),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(973),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(975),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(983),
    [anon_sym_function] = ACTIONS(985),
    [anon_sym_try] = ACTIONS(987),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(993),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2185] = {
    [sym_value_definition] = STATE(19175),
    [sym__simple_expression] = STATE(2484),
    [sym__expression] = STATE(12387),
    [sym_typed_expression] = STATE(7113),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(7113),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(7113),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(7113),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(2185),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym_sign_operator] = STATE(2185),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__instance_variable_name] = STATE(19188),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [sym__lowercase_identifier] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_fun] = ACTIONS(2653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2657),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2661),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2685),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2186] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9871),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2186),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2187] = {
    [sym_value_definition] = STATE(18277),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(12342),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6588),
    [sym_array_get_expression] = STATE(6588),
    [sym_string_get_expression] = STATE(6588),
    [sym_bigarray_get_expression] = STATE(6588),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2187),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2201),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18286),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2188] = {
    [sym_value_definition] = STATE(17611),
    [sym__simple_expression] = STATE(323),
    [sym__expression] = STATE(8275),
    [sym_typed_expression] = STATE(3176),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3176),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3176),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2957),
    [sym_array_get_expression] = STATE(2957),
    [sym_string_get_expression] = STATE(2957),
    [sym_bigarray_get_expression] = STATE(2957),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3176),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(2188),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym_sign_operator] = STATE(1905),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__instance_variable_name] = STATE(17621),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [sym__lowercase_identifier] = ACTIONS(355),
    [anon_sym_let] = ACTIONS(357),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_fun] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_if] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(375),
    [anon_sym_function] = ACTIONS(377),
    [anon_sym_try] = ACTIONS(379),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3107),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3109),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(401),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2189] = {
    [sym_value_definition] = STATE(19248),
    [sym__simple_expression] = STATE(1582),
    [sym__expression] = STATE(8462),
    [sym_typed_expression] = STATE(4041),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4041),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4041),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3928),
    [sym_array_get_expression] = STATE(3928),
    [sym_string_get_expression] = STATE(3928),
    [sym_bigarray_get_expression] = STATE(3928),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4041),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(2189),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__instance_variable_name] = STATE(19258),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [sym__lowercase_identifier] = ACTIONS(857),
    [anon_sym_let] = ACTIONS(859),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_fun] = ACTIONS(871),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(877),
    [anon_sym_function] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(881),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3103),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3105),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(903),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2190] = {
    [sym_value_definition] = STATE(18277),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(12344),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6588),
    [sym_array_get_expression] = STATE(6588),
    [sym_string_get_expression] = STATE(6588),
    [sym_bigarray_get_expression] = STATE(6588),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2190),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2201),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18286),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2191] = {
    [sym_value_definition] = STATE(18277),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(12349),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6588),
    [sym_array_get_expression] = STATE(6588),
    [sym_string_get_expression] = STATE(6588),
    [sym_bigarray_get_expression] = STATE(6588),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2191),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2201),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18286),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2192] = {
    [sym_value_definition] = STATE(18277),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(12351),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6588),
    [sym_array_get_expression] = STATE(6588),
    [sym_string_get_expression] = STATE(6588),
    [sym_bigarray_get_expression] = STATE(6588),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2192),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2201),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18286),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2193] = {
    [sym_value_definition] = STATE(18277),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(12357),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6588),
    [sym_array_get_expression] = STATE(6588),
    [sym_string_get_expression] = STATE(6588),
    [sym_bigarray_get_expression] = STATE(6588),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2193),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2201),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18286),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2194] = {
    [sym_value_definition] = STATE(17714),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9548),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4836),
    [sym_array_get_expression] = STATE(4836),
    [sym_string_get_expression] = STATE(4836),
    [sym_bigarray_get_expression] = STATE(4836),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(2194),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(2151),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(17727),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(973),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(975),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(983),
    [anon_sym_function] = ACTIONS(985),
    [anon_sym_try] = ACTIONS(987),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(993),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2195] = {
    [sym_value_definition] = STATE(18277),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(12359),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6588),
    [sym_array_get_expression] = STATE(6588),
    [sym_string_get_expression] = STATE(6588),
    [sym_bigarray_get_expression] = STATE(6588),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2195),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2201),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18286),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2196] = {
    [sym_value_definition] = STATE(18277),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(12364),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6588),
    [sym_array_get_expression] = STATE(6588),
    [sym_string_get_expression] = STATE(6588),
    [sym_bigarray_get_expression] = STATE(6588),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2196),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2201),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18286),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2197] = {
    [sym_value_definition] = STATE(17714),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9546),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4836),
    [sym_array_get_expression] = STATE(4836),
    [sym_string_get_expression] = STATE(4836),
    [sym_bigarray_get_expression] = STATE(4836),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(2197),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(2151),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(17727),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(973),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(975),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(983),
    [anon_sym_function] = ACTIONS(985),
    [anon_sym_try] = ACTIONS(987),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(993),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2198] = {
    [sym_value_definition] = STATE(18277),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(12372),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6588),
    [sym_array_get_expression] = STATE(6588),
    [sym_string_get_expression] = STATE(6588),
    [sym_bigarray_get_expression] = STATE(6588),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2198),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2201),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18286),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2199] = {
    [sym_value_definition] = STATE(17714),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9545),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4836),
    [sym_array_get_expression] = STATE(4836),
    [sym_string_get_expression] = STATE(4836),
    [sym_bigarray_get_expression] = STATE(4836),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(2199),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(2151),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(17727),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(973),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(975),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(983),
    [anon_sym_function] = ACTIONS(985),
    [anon_sym_try] = ACTIONS(987),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(993),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2200] = {
    [sym_value_definition] = STATE(17714),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9544),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4836),
    [sym_array_get_expression] = STATE(4836),
    [sym_string_get_expression] = STATE(4836),
    [sym_bigarray_get_expression] = STATE(4836),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(2200),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(2151),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(17727),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(973),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(975),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(983),
    [anon_sym_function] = ACTIONS(985),
    [anon_sym_try] = ACTIONS(987),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(993),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2201] = {
    [sym_value_definition] = STATE(18277),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(12348),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6588),
    [sym_array_get_expression] = STATE(6588),
    [sym_string_get_expression] = STATE(6588),
    [sym_bigarray_get_expression] = STATE(6588),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2201),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2201),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18286),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2202] = {
    [sym_value_definition] = STATE(17611),
    [sym__simple_expression] = STATE(323),
    [sym__expression] = STATE(8245),
    [sym_typed_expression] = STATE(3176),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3176),
    [sym_array_expression] = STATE(3176),
    [sym_record_expression] = STATE(3176),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3176),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3176),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2957),
    [sym_array_get_expression] = STATE(2957),
    [sym_string_get_expression] = STATE(2957),
    [sym_bigarray_get_expression] = STATE(2957),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3176),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3176),
    [sym_package_expression] = STATE(3176),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3176),
    [sym_object_copy_expression] = STATE(3176),
    [sym_method_invocation] = STATE(3176),
    [sym_object_expression] = STATE(3176),
    [sym_parenthesized_expression] = STATE(3176),
    [sym_attribute] = STATE(2202),
    [sym_extension] = STATE(3176),
    [sym_quoted_extension] = STATE(3176),
    [sym__constant] = STATE(3176),
    [sym_number] = STATE(3123),
    [sym_character] = STATE(3123),
    [sym_string] = STATE(3123),
    [sym_quoted_string] = STATE(3123),
    [sym_boolean] = STATE(3123),
    [sym_unit] = STATE(3123),
    [sym_sign_operator] = STATE(1905),
    [sym__value_name] = STATE(3103),
    [sym_parenthesized_operator] = STATE(2983),
    [sym_value_path] = STATE(3176),
    [sym_module_path] = STATE(18642),
    [sym_constructor_path] = STATE(3176),
    [sym__instance_variable_name] = STATE(17621),
    [sym__constructor_name] = STATE(3124),
    [sym_tag] = STATE(3176),
    [sym__lowercase_identifier] = ACTIONS(355),
    [anon_sym_let] = ACTIONS(357),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_object] = ACTIONS(367),
    [anon_sym_fun] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(371),
    [anon_sym_if] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(375),
    [anon_sym_function] = ACTIONS(377),
    [anon_sym_try] = ACTIONS(379),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(381),
    [anon_sym_LBRACE_LT] = ACTIONS(383),
    [anon_sym_begin] = ACTIONS(385),
    [sym_ocamlyacc_value] = ACTIONS(387),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3107),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3109),
    [aux_sym_number_token1] = ACTIONS(393),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [sym_prefix_operator] = ACTIONS(399),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(401),
    [sym__uppercase_identifier] = ACTIONS(403),
    [aux_sym_tag_token1] = ACTIONS(405),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2203] = {
    [sym_value_definition] = STATE(19248),
    [sym__simple_expression] = STATE(1582),
    [sym__expression] = STATE(8518),
    [sym_typed_expression] = STATE(4041),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4041),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4041),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3928),
    [sym_array_get_expression] = STATE(3928),
    [sym_string_get_expression] = STATE(3928),
    [sym_bigarray_get_expression] = STATE(3928),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4041),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(2203),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__instance_variable_name] = STATE(19258),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [sym__lowercase_identifier] = ACTIONS(857),
    [anon_sym_let] = ACTIONS(859),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_fun] = ACTIONS(871),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(877),
    [anon_sym_function] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(881),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3103),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3105),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(903),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2204] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11944),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2204),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2205] = {
    [sym_value_definition] = STATE(17714),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9543),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4836),
    [sym_array_get_expression] = STATE(4836),
    [sym_string_get_expression] = STATE(4836),
    [sym_bigarray_get_expression] = STATE(4836),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(2205),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(2151),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(17727),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(973),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(975),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(983),
    [anon_sym_function] = ACTIONS(985),
    [anon_sym_try] = ACTIONS(987),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(993),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2206] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12746),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2206),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2207] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9893),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2207),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2208] = {
    [sym_value_definition] = STATE(19248),
    [sym__simple_expression] = STATE(1582),
    [sym__expression] = STATE(8511),
    [sym_typed_expression] = STATE(4041),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4041),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4041),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3928),
    [sym_array_get_expression] = STATE(3928),
    [sym_string_get_expression] = STATE(3928),
    [sym_bigarray_get_expression] = STATE(3928),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4041),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(2208),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__instance_variable_name] = STATE(19258),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [sym__lowercase_identifier] = ACTIONS(857),
    [anon_sym_let] = ACTIONS(859),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_fun] = ACTIONS(871),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(877),
    [anon_sym_function] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(881),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3103),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3105),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(903),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2209] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(10834),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2209),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2210] = {
    [sym_value_definition] = STATE(19248),
    [sym__simple_expression] = STATE(1582),
    [sym__expression] = STATE(8510),
    [sym_typed_expression] = STATE(4041),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4041),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4041),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3928),
    [sym_array_get_expression] = STATE(3928),
    [sym_string_get_expression] = STATE(3928),
    [sym_bigarray_get_expression] = STATE(3928),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4041),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(2210),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__instance_variable_name] = STATE(19258),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [sym__lowercase_identifier] = ACTIONS(857),
    [anon_sym_let] = ACTIONS(859),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_fun] = ACTIONS(871),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(877),
    [anon_sym_function] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(881),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3103),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3105),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(903),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2211] = {
    [sym_value_definition] = STATE(19248),
    [sym__simple_expression] = STATE(1582),
    [sym__expression] = STATE(8503),
    [sym_typed_expression] = STATE(4041),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4041),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4041),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3928),
    [sym_array_get_expression] = STATE(3928),
    [sym_string_get_expression] = STATE(3928),
    [sym_bigarray_get_expression] = STATE(3928),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4041),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(2211),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__instance_variable_name] = STATE(19258),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [sym__lowercase_identifier] = ACTIONS(857),
    [anon_sym_let] = ACTIONS(859),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_fun] = ACTIONS(871),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(877),
    [anon_sym_function] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(881),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3103),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3105),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(903),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2212] = {
    [sym_value_definition] = STATE(19248),
    [sym__simple_expression] = STATE(1582),
    [sym__expression] = STATE(8502),
    [sym_typed_expression] = STATE(4041),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4041),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4041),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3928),
    [sym_array_get_expression] = STATE(3928),
    [sym_string_get_expression] = STATE(3928),
    [sym_bigarray_get_expression] = STATE(3928),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4041),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(2212),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__instance_variable_name] = STATE(19258),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [sym__lowercase_identifier] = ACTIONS(857),
    [anon_sym_let] = ACTIONS(859),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_fun] = ACTIONS(871),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(877),
    [anon_sym_function] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(881),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3103),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3105),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(903),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2213] = {
    [sym_value_definition] = STATE(19248),
    [sym__simple_expression] = STATE(1582),
    [sym__expression] = STATE(8501),
    [sym_typed_expression] = STATE(4041),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4041),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4041),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3928),
    [sym_array_get_expression] = STATE(3928),
    [sym_string_get_expression] = STATE(3928),
    [sym_bigarray_get_expression] = STATE(3928),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4041),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(2213),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__instance_variable_name] = STATE(19258),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [sym__lowercase_identifier] = ACTIONS(857),
    [anon_sym_let] = ACTIONS(859),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_fun] = ACTIONS(871),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(877),
    [anon_sym_function] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(881),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3103),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3105),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(903),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2214] = {
    [sym_value_definition] = STATE(19248),
    [sym__simple_expression] = STATE(1582),
    [sym__expression] = STATE(8500),
    [sym_typed_expression] = STATE(4041),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4041),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4041),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3928),
    [sym_array_get_expression] = STATE(3928),
    [sym_string_get_expression] = STATE(3928),
    [sym_bigarray_get_expression] = STATE(3928),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4041),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(2214),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__instance_variable_name] = STATE(19258),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [sym__lowercase_identifier] = ACTIONS(857),
    [anon_sym_let] = ACTIONS(859),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_fun] = ACTIONS(871),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(877),
    [anon_sym_function] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(881),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3103),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3105),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(903),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2215] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9891),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2215),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2216] = {
    [sym_value_definition] = STATE(19248),
    [sym__simple_expression] = STATE(1582),
    [sym__expression] = STATE(8499),
    [sym_typed_expression] = STATE(4041),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4041),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4041),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3928),
    [sym_array_get_expression] = STATE(3928),
    [sym_string_get_expression] = STATE(3928),
    [sym_bigarray_get_expression] = STATE(3928),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4041),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(2216),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__instance_variable_name] = STATE(19258),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [sym__lowercase_identifier] = ACTIONS(857),
    [anon_sym_let] = ACTIONS(859),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_fun] = ACTIONS(871),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(877),
    [anon_sym_function] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(881),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3103),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3105),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(903),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2217] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9886),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2217),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2218] = {
    [sym_value_definition] = STATE(19248),
    [sym__simple_expression] = STATE(1582),
    [sym__expression] = STATE(8498),
    [sym_typed_expression] = STATE(4041),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4041),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4041),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3928),
    [sym_array_get_expression] = STATE(3928),
    [sym_string_get_expression] = STATE(3928),
    [sym_bigarray_get_expression] = STATE(3928),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4041),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(2218),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__instance_variable_name] = STATE(19258),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [sym__lowercase_identifier] = ACTIONS(857),
    [anon_sym_let] = ACTIONS(859),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_fun] = ACTIONS(871),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(877),
    [anon_sym_function] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(881),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3103),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3105),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(903),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2219] = {
    [sym_value_definition] = STATE(19248),
    [sym__simple_expression] = STATE(1582),
    [sym__expression] = STATE(8477),
    [sym_typed_expression] = STATE(4041),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4041),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4041),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3928),
    [sym_array_get_expression] = STATE(3928),
    [sym_string_get_expression] = STATE(3928),
    [sym_bigarray_get_expression] = STATE(3928),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4041),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(2219),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__instance_variable_name] = STATE(19258),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [sym__lowercase_identifier] = ACTIONS(857),
    [anon_sym_let] = ACTIONS(859),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_fun] = ACTIONS(871),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(877),
    [anon_sym_function] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(881),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3103),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3105),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(903),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2220] = {
    [sym_value_definition] = STATE(19248),
    [sym__simple_expression] = STATE(1582),
    [sym__expression] = STATE(8476),
    [sym_typed_expression] = STATE(4041),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4041),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4041),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3928),
    [sym_array_get_expression] = STATE(3928),
    [sym_string_get_expression] = STATE(3928),
    [sym_bigarray_get_expression] = STATE(3928),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4041),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(2220),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__instance_variable_name] = STATE(19258),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [sym__lowercase_identifier] = ACTIONS(857),
    [anon_sym_let] = ACTIONS(859),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_fun] = ACTIONS(871),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(877),
    [anon_sym_function] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(881),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3103),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3105),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(903),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2221] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9885),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2221),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2222] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9883),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2222),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2223] = {
    [sym_value_definition] = STATE(18705),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(11905),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6123),
    [sym_array_get_expression] = STATE(6123),
    [sym_string_get_expression] = STATE(6123),
    [sym_bigarray_get_expression] = STATE(6123),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2223),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2250),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18531),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2355),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2367),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2373),
    [anon_sym_function] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2399),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2224] = {
    [sym_value_definition] = STATE(19248),
    [sym__simple_expression] = STATE(1582),
    [sym__expression] = STATE(8474),
    [sym_typed_expression] = STATE(4041),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4041),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4041),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3928),
    [sym_array_get_expression] = STATE(3928),
    [sym_string_get_expression] = STATE(3928),
    [sym_bigarray_get_expression] = STATE(3928),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4041),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(2224),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__instance_variable_name] = STATE(19258),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [sym__lowercase_identifier] = ACTIONS(857),
    [anon_sym_let] = ACTIONS(859),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_fun] = ACTIONS(871),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(877),
    [anon_sym_function] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(881),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3103),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3105),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(903),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2225] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10019),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2225),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2226] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(11945),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2226),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2227] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9880),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2227),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2228] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9875),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2228),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2229] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9917),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2229),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2230] = {
    [sym_value_definition] = STATE(18705),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(11912),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6123),
    [sym_array_get_expression] = STATE(6123),
    [sym_string_get_expression] = STATE(6123),
    [sym_bigarray_get_expression] = STATE(6123),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2230),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2250),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18531),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2355),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2367),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2373),
    [anon_sym_function] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2399),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2231] = {
    [sym_value_definition] = STATE(18705),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(11915),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6123),
    [sym_array_get_expression] = STATE(6123),
    [sym_string_get_expression] = STATE(6123),
    [sym_bigarray_get_expression] = STATE(6123),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2231),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2250),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18531),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2355),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2367),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2373),
    [anon_sym_function] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2399),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2232] = {
    [sym_value_definition] = STATE(18705),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(11916),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6123),
    [sym_array_get_expression] = STATE(6123),
    [sym_string_get_expression] = STATE(6123),
    [sym_bigarray_get_expression] = STATE(6123),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2232),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2250),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18531),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2355),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2367),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2373),
    [anon_sym_function] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2399),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2233] = {
    [sym_value_definition] = STATE(17714),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9539),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4836),
    [sym_array_get_expression] = STATE(4836),
    [sym_string_get_expression] = STATE(4836),
    [sym_bigarray_get_expression] = STATE(4836),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(2233),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(2151),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(17727),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(973),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(975),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(983),
    [anon_sym_function] = ACTIONS(985),
    [anon_sym_try] = ACTIONS(987),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(993),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2234] = {
    [sym_value_definition] = STATE(17714),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9536),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4836),
    [sym_array_get_expression] = STATE(4836),
    [sym_string_get_expression] = STATE(4836),
    [sym_bigarray_get_expression] = STATE(4836),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(2234),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(2151),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(17727),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(973),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(975),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(983),
    [anon_sym_function] = ACTIONS(985),
    [anon_sym_try] = ACTIONS(987),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(993),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2235] = {
    [sym_value_definition] = STATE(18705),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(11919),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6123),
    [sym_array_get_expression] = STATE(6123),
    [sym_string_get_expression] = STATE(6123),
    [sym_bigarray_get_expression] = STATE(6123),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2235),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2250),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18531),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2355),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2367),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2373),
    [anon_sym_function] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2399),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2236] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9923),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2236),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2237] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9926),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2237),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2238] = {
    [sym_value_definition] = STATE(18705),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(11928),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6123),
    [sym_array_get_expression] = STATE(6123),
    [sym_string_get_expression] = STATE(6123),
    [sym_bigarray_get_expression] = STATE(6123),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2238),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2250),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18531),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2355),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2367),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2373),
    [anon_sym_function] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2399),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2239] = {
    [sym_value_definition] = STATE(18705),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(11931),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6123),
    [sym_array_get_expression] = STATE(6123),
    [sym_string_get_expression] = STATE(6123),
    [sym_bigarray_get_expression] = STATE(6123),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2239),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2250),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18531),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2355),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2367),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2373),
    [anon_sym_function] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2399),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2240] = {
    [sym_value_definition] = STATE(19248),
    [sym__simple_expression] = STATE(1582),
    [sym__expression] = STATE(8536),
    [sym_typed_expression] = STATE(4041),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4041),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4041),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3928),
    [sym_array_get_expression] = STATE(3928),
    [sym_string_get_expression] = STATE(3928),
    [sym_bigarray_get_expression] = STATE(3928),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4041),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(2240),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__instance_variable_name] = STATE(19258),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [sym__lowercase_identifier] = ACTIONS(857),
    [anon_sym_let] = ACTIONS(859),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_fun] = ACTIONS(871),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(877),
    [anon_sym_function] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(881),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3103),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3105),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(903),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2241] = {
    [sym_value_definition] = STATE(17654),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9620),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4841),
    [sym_array_get_expression] = STATE(4841),
    [sym_string_get_expression] = STATE(4841),
    [sym_bigarray_get_expression] = STATE(4841),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2241),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2276),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(17662),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(997),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1009),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1013),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1015),
    [anon_sym_function] = ACTIONS(1017),
    [anon_sym_try] = ACTIONS(1019),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1041),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2242] = {
    [sym_value_definition] = STATE(18705),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(11934),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6123),
    [sym_array_get_expression] = STATE(6123),
    [sym_string_get_expression] = STATE(6123),
    [sym_bigarray_get_expression] = STATE(6123),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2242),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2250),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18531),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2355),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2367),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2373),
    [anon_sym_function] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2399),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2243] = {
    [sym_value_definition] = STATE(18705),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(11936),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6123),
    [sym_array_get_expression] = STATE(6123),
    [sym_string_get_expression] = STATE(6123),
    [sym_bigarray_get_expression] = STATE(6123),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2243),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2250),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18531),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2355),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2367),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2373),
    [anon_sym_function] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2399),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2244] = {
    [sym_value_definition] = STATE(18705),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(11937),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6123),
    [sym_array_get_expression] = STATE(6123),
    [sym_string_get_expression] = STATE(6123),
    [sym_bigarray_get_expression] = STATE(6123),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2244),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2250),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18531),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2355),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2367),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2373),
    [anon_sym_function] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2399),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2245] = {
    [sym_value_definition] = STATE(18705),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(11938),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6123),
    [sym_array_get_expression] = STATE(6123),
    [sym_string_get_expression] = STATE(6123),
    [sym_bigarray_get_expression] = STATE(6123),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2245),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2250),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18531),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2355),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2367),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2373),
    [anon_sym_function] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2399),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2246] = {
    [sym_value_definition] = STATE(17889),
    [sym__simple_expression] = STATE(2457),
    [sym__expression] = STATE(11864),
    [sym_typed_expression] = STATE(6138),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(6138),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(6138),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5776),
    [sym_array_get_expression] = STATE(5776),
    [sym_string_get_expression] = STATE(5776),
    [sym_bigarray_get_expression] = STATE(5776),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(6138),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(2246),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym_sign_operator] = STATE(1969),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__instance_variable_name] = STATE(17866),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [sym__lowercase_identifier] = ACTIONS(1395),
    [anon_sym_let] = ACTIONS(1397),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_fun] = ACTIONS(1409),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1415),
    [anon_sym_function] = ACTIONS(1417),
    [anon_sym_try] = ACTIONS(1419),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1441),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2247] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12696),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2247),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2248] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(12678),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2248),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2249] = {
    [sym_value_definition] = STATE(17654),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9617),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4841),
    [sym_array_get_expression] = STATE(4841),
    [sym_string_get_expression] = STATE(4841),
    [sym_bigarray_get_expression] = STATE(4841),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2249),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2276),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(17662),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(997),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1009),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1013),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1015),
    [anon_sym_function] = ACTIONS(1017),
    [anon_sym_try] = ACTIONS(1019),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1041),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2250] = {
    [sym_value_definition] = STATE(18705),
    [sym__simple_expression] = STATE(2467),
    [sym__expression] = STATE(12097),
    [sym_typed_expression] = STATE(6357),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(6357),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(6357),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6123),
    [sym_array_get_expression] = STATE(6123),
    [sym_string_get_expression] = STATE(6123),
    [sym_bigarray_get_expression] = STATE(6123),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(6357),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2250),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym_sign_operator] = STATE(2250),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__instance_variable_name] = STATE(18531),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [sym__lowercase_identifier] = ACTIONS(2353),
    [anon_sym_let] = ACTIONS(2355),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_fun] = ACTIONS(2367),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2373),
    [anon_sym_function] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2399),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2251] = {
    [sym_value_definition] = STATE(17654),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9613),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4841),
    [sym_array_get_expression] = STATE(4841),
    [sym_string_get_expression] = STATE(4841),
    [sym_bigarray_get_expression] = STATE(4841),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2251),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2276),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(17662),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(997),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1009),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1013),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1015),
    [anon_sym_function] = ACTIONS(1017),
    [anon_sym_try] = ACTIONS(1019),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1041),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2252] = {
    [sym_value_definition] = STATE(17654),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9612),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4841),
    [sym_array_get_expression] = STATE(4841),
    [sym_string_get_expression] = STATE(4841),
    [sym_bigarray_get_expression] = STATE(4841),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2252),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2276),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(17662),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(997),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1009),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1013),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1015),
    [anon_sym_function] = ACTIONS(1017),
    [anon_sym_try] = ACTIONS(1019),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1041),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2253] = {
    [sym_value_definition] = STATE(17654),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9611),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4841),
    [sym_array_get_expression] = STATE(4841),
    [sym_string_get_expression] = STATE(4841),
    [sym_bigarray_get_expression] = STATE(4841),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2253),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2276),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(17662),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(997),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1009),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1013),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1015),
    [anon_sym_function] = ACTIONS(1017),
    [anon_sym_try] = ACTIONS(1019),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1041),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2254] = {
    [sym_value_definition] = STATE(17654),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9606),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4841),
    [sym_array_get_expression] = STATE(4841),
    [sym_string_get_expression] = STATE(4841),
    [sym_bigarray_get_expression] = STATE(4841),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2254),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2276),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(17662),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(997),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1009),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1013),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1015),
    [anon_sym_function] = ACTIONS(1017),
    [anon_sym_try] = ACTIONS(1019),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1041),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2255] = {
    [sym_value_definition] = STATE(17654),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9603),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4841),
    [sym_array_get_expression] = STATE(4841),
    [sym_string_get_expression] = STATE(4841),
    [sym_bigarray_get_expression] = STATE(4841),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2255),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2276),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(17662),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(997),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1009),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1013),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1015),
    [anon_sym_function] = ACTIONS(1017),
    [anon_sym_try] = ACTIONS(1019),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1041),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2256] = {
    [sym_value_definition] = STATE(17654),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9602),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4841),
    [sym_array_get_expression] = STATE(4841),
    [sym_string_get_expression] = STATE(4841),
    [sym_bigarray_get_expression] = STATE(4841),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2256),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2276),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(17662),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(997),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1009),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1013),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1015),
    [anon_sym_function] = ACTIONS(1017),
    [anon_sym_try] = ACTIONS(1019),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1041),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2257] = {
    [sym_value_definition] = STATE(17654),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9601),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4841),
    [sym_array_get_expression] = STATE(4841),
    [sym_string_get_expression] = STATE(4841),
    [sym_bigarray_get_expression] = STATE(4841),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2257),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2276),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(17662),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(997),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1009),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1013),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1015),
    [anon_sym_function] = ACTIONS(1017),
    [anon_sym_try] = ACTIONS(1019),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1041),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2258] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(10962),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2258),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2259] = {
    [sym_value_definition] = STATE(17714),
    [sym__simple_expression] = STATE(2423),
    [sym__expression] = STATE(9532),
    [sym_typed_expression] = STATE(4865),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4865),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4865),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4836),
    [sym_array_get_expression] = STATE(4836),
    [sym_string_get_expression] = STATE(4836),
    [sym_bigarray_get_expression] = STATE(4836),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4865),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(2259),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym_sign_operator] = STATE(2151),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__instance_variable_name] = STATE(17727),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [sym__lowercase_identifier] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(973),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_fun] = ACTIONS(975),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(983),
    [anon_sym_function] = ACTIONS(985),
    [anon_sym_try] = ACTIONS(987),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3111),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3113),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(993),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2260] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(10967),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2260),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2261] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(10983),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2261),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2262] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(10984),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2262),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2263] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(10985),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2263),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2264] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(10986),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2264),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2265] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(10989),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2265),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2266] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(10990),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2266),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2267] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(10991),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2267),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2268] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(10992),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2268),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2269] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(10995),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2269),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2270] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8300),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(2270),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2271] = {
    [sym_value_definition] = STATE(17654),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9599),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4841),
    [sym_array_get_expression] = STATE(4841),
    [sym_string_get_expression] = STATE(4841),
    [sym_bigarray_get_expression] = STATE(4841),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2271),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2276),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(17662),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(997),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1009),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1013),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1015),
    [anon_sym_function] = ACTIONS(1017),
    [anon_sym_try] = ACTIONS(1019),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1041),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2272] = {
    [sym_value_definition] = STATE(18797),
    [sym__simple_expression] = STATE(1527),
    [sym__expression] = STATE(8506),
    [sym_typed_expression] = STATE(4161),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4161),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4161),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3909),
    [sym_array_get_expression] = STATE(3909),
    [sym_string_get_expression] = STATE(3909),
    [sym_bigarray_get_expression] = STATE(3909),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4161),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(2272),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym_sign_operator] = STATE(2091),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__instance_variable_name] = STATE(18811),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [sym__lowercase_identifier] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_fun] = ACTIONS(819),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_if] = ACTIONS(823),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(825),
    [anon_sym_function] = ACTIONS(827),
    [anon_sym_try] = ACTIONS(829),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3115),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3117),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(851),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2273] = {
    [sym_value_definition] = STATE(17654),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9595),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4841),
    [sym_array_get_expression] = STATE(4841),
    [sym_string_get_expression] = STATE(4841),
    [sym_bigarray_get_expression] = STATE(4841),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2273),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2276),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(17662),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(997),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1009),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1013),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1015),
    [anon_sym_function] = ACTIONS(1017),
    [anon_sym_try] = ACTIONS(1019),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1041),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2274] = {
    [sym_value_definition] = STATE(19080),
    [sym__simple_expression] = STATE(506),
    [sym__expression] = STATE(8298),
    [sym_typed_expression] = STATE(3532),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3532),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3532),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3084),
    [sym_array_get_expression] = STATE(3084),
    [sym_string_get_expression] = STATE(3084),
    [sym_bigarray_get_expression] = STATE(3084),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3532),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(2274),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym_sign_operator] = STATE(2274),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__instance_variable_name] = STATE(18842),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [sym__lowercase_identifier] = ACTIONS(475),
    [anon_sym_let] = ACTIONS(477),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_fun] = ACTIONS(489),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(495),
    [anon_sym_function] = ACTIONS(497),
    [anon_sym_try] = ACTIONS(499),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3123),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3125),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(521),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2275] = {
    [sym_value_definition] = STATE(17654),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9590),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4841),
    [sym_array_get_expression] = STATE(4841),
    [sym_string_get_expression] = STATE(4841),
    [sym_bigarray_get_expression] = STATE(4841),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2275),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2276),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(17662),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(997),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1009),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1013),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1015),
    [anon_sym_function] = ACTIONS(1017),
    [anon_sym_try] = ACTIONS(1019),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1041),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2276] = {
    [sym_value_definition] = STATE(17654),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(9648),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4841),
    [sym_array_get_expression] = STATE(4841),
    [sym_string_get_expression] = STATE(4841),
    [sym_bigarray_get_expression] = STATE(4841),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2276),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2276),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(17662),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(997),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1009),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1013),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1015),
    [anon_sym_function] = ACTIONS(1017),
    [anon_sym_try] = ACTIONS(1019),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1041),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2277] = {
    [sym_value_definition] = STATE(18149),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11628),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5662),
    [sym_array_get_expression] = STATE(5662),
    [sym_string_get_expression] = STATE(5662),
    [sym_bigarray_get_expression] = STATE(5662),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(2277),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(2277),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(18127),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1389),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1391),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1393),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2278] = {
    [sym_value_definition] = STATE(19151),
    [sym__simple_expression] = STATE(549),
    [sym__expression] = STATE(8331),
    [sym_typed_expression] = STATE(3704),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3704),
    [sym_array_expression] = STATE(3704),
    [sym_record_expression] = STATE(3704),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3704),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3704),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3058),
    [sym_array_get_expression] = STATE(3058),
    [sym_string_get_expression] = STATE(3058),
    [sym_bigarray_get_expression] = STATE(3058),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3704),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3704),
    [sym_package_expression] = STATE(3704),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3704),
    [sym_object_copy_expression] = STATE(3704),
    [sym_method_invocation] = STATE(3704),
    [sym_object_expression] = STATE(3704),
    [sym_parenthesized_expression] = STATE(3704),
    [sym_attribute] = STATE(2278),
    [sym_extension] = STATE(3704),
    [sym_quoted_extension] = STATE(3704),
    [sym__constant] = STATE(3704),
    [sym_number] = STATE(3432),
    [sym_character] = STATE(3432),
    [sym_string] = STATE(3432),
    [sym_quoted_string] = STATE(3432),
    [sym_boolean] = STATE(3432),
    [sym_unit] = STATE(3432),
    [sym_sign_operator] = STATE(1807),
    [sym__value_name] = STATE(3583),
    [sym_parenthesized_operator] = STATE(3337),
    [sym_value_path] = STATE(3704),
    [sym_module_path] = STATE(18905),
    [sym_constructor_path] = STATE(3704),
    [sym__instance_variable_name] = STATE(19067),
    [sym__constructor_name] = STATE(3434),
    [sym_tag] = STATE(3704),
    [sym__lowercase_identifier] = ACTIONS(527),
    [anon_sym_let] = ACTIONS(529),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(535),
    [anon_sym_false] = ACTIONS(535),
    [anon_sym_LBRACE] = ACTIONS(537),
    [anon_sym_object] = ACTIONS(539),
    [anon_sym_fun] = ACTIONS(541),
    [anon_sym_LBRACK_PIPE] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(545),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(547),
    [anon_sym_function] = ACTIONS(549),
    [anon_sym_try] = ACTIONS(551),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(553),
    [anon_sym_LBRACE_LT] = ACTIONS(555),
    [anon_sym_begin] = ACTIONS(557),
    [sym_ocamlyacc_value] = ACTIONS(559),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3129),
    [aux_sym_number_token1] = ACTIONS(565),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_DQUOTE] = ACTIONS(569),
    [sym_prefix_operator] = ACTIONS(571),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(573),
    [sym__uppercase_identifier] = ACTIONS(575),
    [aux_sym_tag_token1] = ACTIONS(577),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2279] = {
    [sym_value_definition] = STATE(18149),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11476),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5662),
    [sym_array_get_expression] = STATE(5662),
    [sym_string_get_expression] = STATE(5662),
    [sym_bigarray_get_expression] = STATE(5662),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(2279),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(2277),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(18127),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1389),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1391),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1393),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2280] = {
    [sym_value_definition] = STATE(19586),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8807),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(2280),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2281] = {
    [sym_value_definition] = STATE(17904),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12379),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6329),
    [sym_array_get_expression] = STATE(6329),
    [sym_string_get_expression] = STATE(6329),
    [sym_bigarray_get_expression] = STATE(6329),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(2281),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(2362),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(17913),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2601),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2607),
    [anon_sym_function] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2611),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2633),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2282] = {
    [sym_value_definition] = STATE(19080),
    [sym__simple_expression] = STATE(506),
    [sym__expression] = STATE(8292),
    [sym_typed_expression] = STATE(3532),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3532),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3532),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3084),
    [sym_array_get_expression] = STATE(3084),
    [sym_string_get_expression] = STATE(3084),
    [sym_bigarray_get_expression] = STATE(3084),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3532),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(2282),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym_sign_operator] = STATE(2274),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__instance_variable_name] = STATE(18842),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [sym__lowercase_identifier] = ACTIONS(475),
    [anon_sym_let] = ACTIONS(477),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_fun] = ACTIONS(489),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(495),
    [anon_sym_function] = ACTIONS(497),
    [anon_sym_try] = ACTIONS(499),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3123),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3125),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(521),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2283] = {
    [sym_value_definition] = STATE(19080),
    [sym__simple_expression] = STATE(506),
    [sym__expression] = STATE(8295),
    [sym_typed_expression] = STATE(3532),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3532),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3532),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3084),
    [sym_array_get_expression] = STATE(3084),
    [sym_string_get_expression] = STATE(3084),
    [sym_bigarray_get_expression] = STATE(3084),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3532),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(2283),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym_sign_operator] = STATE(2274),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__instance_variable_name] = STATE(18842),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [sym__lowercase_identifier] = ACTIONS(475),
    [anon_sym_let] = ACTIONS(477),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_fun] = ACTIONS(489),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(495),
    [anon_sym_function] = ACTIONS(497),
    [anon_sym_try] = ACTIONS(499),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3123),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3125),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(521),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2284] = {
    [sym_value_definition] = STATE(18428),
    [sym__simple_expression] = STATE(2428),
    [sym__expression] = STATE(10245),
    [sym_typed_expression] = STATE(5216),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5216),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5216),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4994),
    [sym_array_get_expression] = STATE(4994),
    [sym_string_get_expression] = STATE(4994),
    [sym_bigarray_get_expression] = STATE(4994),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5216),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(2284),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym_sign_operator] = STATE(2366),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__instance_variable_name] = STATE(18272),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [sym__lowercase_identifier] = ACTIONS(1061),
    [anon_sym_let] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_fun] = ACTIONS(1075),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_if] = ACTIONS(1079),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1081),
    [anon_sym_function] = ACTIONS(1083),
    [anon_sym_try] = ACTIONS(1085),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1109),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2285] = {
    [sym_value_definition] = STATE(18149),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11477),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5662),
    [sym_array_get_expression] = STATE(5662),
    [sym_string_get_expression] = STATE(5662),
    [sym_bigarray_get_expression] = STATE(5662),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(2285),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(2277),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(18127),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1389),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1391),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1393),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2286] = {
    [sym_value_definition] = STATE(19080),
    [sym__simple_expression] = STATE(506),
    [sym__expression] = STATE(8313),
    [sym_typed_expression] = STATE(3532),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3532),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3532),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3084),
    [sym_array_get_expression] = STATE(3084),
    [sym_string_get_expression] = STATE(3084),
    [sym_bigarray_get_expression] = STATE(3084),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3532),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(2286),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym_sign_operator] = STATE(2274),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__instance_variable_name] = STATE(18842),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [sym__lowercase_identifier] = ACTIONS(475),
    [anon_sym_let] = ACTIONS(477),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_fun] = ACTIONS(489),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(495),
    [anon_sym_function] = ACTIONS(497),
    [anon_sym_try] = ACTIONS(499),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3123),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3125),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(521),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2287] = {
    [sym_value_definition] = STATE(19080),
    [sym__simple_expression] = STATE(506),
    [sym__expression] = STATE(8319),
    [sym_typed_expression] = STATE(3532),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3532),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3532),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3084),
    [sym_array_get_expression] = STATE(3084),
    [sym_string_get_expression] = STATE(3084),
    [sym_bigarray_get_expression] = STATE(3084),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3532),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(2287),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym_sign_operator] = STATE(2274),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__instance_variable_name] = STATE(18842),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [sym__lowercase_identifier] = ACTIONS(475),
    [anon_sym_let] = ACTIONS(477),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_fun] = ACTIONS(489),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(495),
    [anon_sym_function] = ACTIONS(497),
    [anon_sym_try] = ACTIONS(499),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3123),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3125),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(521),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2288] = {
    [sym_value_definition] = STATE(18149),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11478),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5662),
    [sym_array_get_expression] = STATE(5662),
    [sym_string_get_expression] = STATE(5662),
    [sym_bigarray_get_expression] = STATE(5662),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(2288),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(2277),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(18127),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1389),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1391),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1393),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2289] = {
    [sym_value_definition] = STATE(18149),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11479),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5662),
    [sym_array_get_expression] = STATE(5662),
    [sym_string_get_expression] = STATE(5662),
    [sym_bigarray_get_expression] = STATE(5662),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(2289),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(2277),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(18127),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1389),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1391),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1393),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2290] = {
    [sym_value_definition] = STATE(19080),
    [sym__simple_expression] = STATE(506),
    [sym__expression] = STATE(8335),
    [sym_typed_expression] = STATE(3532),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3532),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3532),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3084),
    [sym_array_get_expression] = STATE(3084),
    [sym_string_get_expression] = STATE(3084),
    [sym_bigarray_get_expression] = STATE(3084),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3532),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(2290),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym_sign_operator] = STATE(2274),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__instance_variable_name] = STATE(18842),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [sym__lowercase_identifier] = ACTIONS(475),
    [anon_sym_let] = ACTIONS(477),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_fun] = ACTIONS(489),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(495),
    [anon_sym_function] = ACTIONS(497),
    [anon_sym_try] = ACTIONS(499),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3123),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3125),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(521),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2291] = {
    [sym_value_definition] = STATE(18149),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11480),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5662),
    [sym_array_get_expression] = STATE(5662),
    [sym_string_get_expression] = STATE(5662),
    [sym_bigarray_get_expression] = STATE(5662),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(2291),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(2277),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(18127),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1389),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1391),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1393),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2292] = {
    [sym_value_definition] = STATE(18149),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11481),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5662),
    [sym_array_get_expression] = STATE(5662),
    [sym_string_get_expression] = STATE(5662),
    [sym_bigarray_get_expression] = STATE(5662),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(2292),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(2277),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(18127),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1389),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1391),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1393),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2293] = {
    [sym_value_definition] = STATE(18149),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11482),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5662),
    [sym_array_get_expression] = STATE(5662),
    [sym_string_get_expression] = STATE(5662),
    [sym_bigarray_get_expression] = STATE(5662),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(2293),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(2277),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(18127),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1389),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1391),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1393),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2294] = {
    [sym_value_definition] = STATE(19586),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8810),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(2294),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2295] = {
    [sym_value_definition] = STATE(19586),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8812),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(2295),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2296] = {
    [sym_value_definition] = STATE(19586),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8826),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(2296),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2297] = {
    [sym_value_definition] = STATE(19080),
    [sym__simple_expression] = STATE(506),
    [sym__expression] = STATE(8336),
    [sym_typed_expression] = STATE(3532),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3532),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3532),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3084),
    [sym_array_get_expression] = STATE(3084),
    [sym_string_get_expression] = STATE(3084),
    [sym_bigarray_get_expression] = STATE(3084),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3532),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(2297),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym_sign_operator] = STATE(2274),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__instance_variable_name] = STATE(18842),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [sym__lowercase_identifier] = ACTIONS(475),
    [anon_sym_let] = ACTIONS(477),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_fun] = ACTIONS(489),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(495),
    [anon_sym_function] = ACTIONS(497),
    [anon_sym_try] = ACTIONS(499),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3123),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3125),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(521),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2298] = {
    [sym_value_definition] = STATE(19080),
    [sym__simple_expression] = STATE(506),
    [sym__expression] = STATE(8338),
    [sym_typed_expression] = STATE(3532),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3532),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3532),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3084),
    [sym_array_get_expression] = STATE(3084),
    [sym_string_get_expression] = STATE(3084),
    [sym_bigarray_get_expression] = STATE(3084),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3532),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(2298),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym_sign_operator] = STATE(2274),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__instance_variable_name] = STATE(18842),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [sym__lowercase_identifier] = ACTIONS(475),
    [anon_sym_let] = ACTIONS(477),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_fun] = ACTIONS(489),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(495),
    [anon_sym_function] = ACTIONS(497),
    [anon_sym_try] = ACTIONS(499),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3123),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3125),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(521),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2299] = {
    [sym_value_definition] = STATE(19080),
    [sym__simple_expression] = STATE(506),
    [sym__expression] = STATE(8340),
    [sym_typed_expression] = STATE(3532),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3532),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3532),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3084),
    [sym_array_get_expression] = STATE(3084),
    [sym_string_get_expression] = STATE(3084),
    [sym_bigarray_get_expression] = STATE(3084),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3532),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(2299),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym_sign_operator] = STATE(2274),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__instance_variable_name] = STATE(18842),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [sym__lowercase_identifier] = ACTIONS(475),
    [anon_sym_let] = ACTIONS(477),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_fun] = ACTIONS(489),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(495),
    [anon_sym_function] = ACTIONS(497),
    [anon_sym_try] = ACTIONS(499),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3123),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3125),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(521),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2300] = {
    [sym_value_definition] = STATE(19080),
    [sym__simple_expression] = STATE(506),
    [sym__expression] = STATE(8346),
    [sym_typed_expression] = STATE(3532),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3532),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3532),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3084),
    [sym_array_get_expression] = STATE(3084),
    [sym_string_get_expression] = STATE(3084),
    [sym_bigarray_get_expression] = STATE(3084),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3532),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(2300),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym_sign_operator] = STATE(2274),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__instance_variable_name] = STATE(18842),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [sym__lowercase_identifier] = ACTIONS(475),
    [anon_sym_let] = ACTIONS(477),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_fun] = ACTIONS(489),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(495),
    [anon_sym_function] = ACTIONS(497),
    [anon_sym_try] = ACTIONS(499),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3123),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3125),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(521),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2301] = {
    [sym_value_definition] = STATE(18149),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11483),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5662),
    [sym_array_get_expression] = STATE(5662),
    [sym_string_get_expression] = STATE(5662),
    [sym_bigarray_get_expression] = STATE(5662),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(2301),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(2277),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(18127),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1389),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1391),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1393),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2302] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8290),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(2302),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2303] = {
    [sym_value_definition] = STATE(19080),
    [sym__simple_expression] = STATE(506),
    [sym__expression] = STATE(8358),
    [sym_typed_expression] = STATE(3532),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3532),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3532),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3084),
    [sym_array_get_expression] = STATE(3084),
    [sym_string_get_expression] = STATE(3084),
    [sym_bigarray_get_expression] = STATE(3084),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3532),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(2303),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym_sign_operator] = STATE(2274),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__instance_variable_name] = STATE(18842),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [sym__lowercase_identifier] = ACTIONS(475),
    [anon_sym_let] = ACTIONS(477),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_fun] = ACTIONS(489),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(495),
    [anon_sym_function] = ACTIONS(497),
    [anon_sym_try] = ACTIONS(499),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3123),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3125),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(521),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2304] = {
    [sym_value_definition] = STATE(19080),
    [sym__simple_expression] = STATE(506),
    [sym__expression] = STATE(8368),
    [sym_typed_expression] = STATE(3532),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3532),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3532),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3084),
    [sym_array_get_expression] = STATE(3084),
    [sym_string_get_expression] = STATE(3084),
    [sym_bigarray_get_expression] = STATE(3084),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3532),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(2304),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym_sign_operator] = STATE(2274),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__instance_variable_name] = STATE(18842),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [sym__lowercase_identifier] = ACTIONS(475),
    [anon_sym_let] = ACTIONS(477),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_fun] = ACTIONS(489),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(495),
    [anon_sym_function] = ACTIONS(497),
    [anon_sym_try] = ACTIONS(499),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3123),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3125),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(521),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2305] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8289),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(2305),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2306] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8288),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(2306),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2307] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8296),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(2307),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2308] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8301),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(2308),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2309] = {
    [sym_value_definition] = STATE(18149),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11485),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5662),
    [sym_array_get_expression] = STATE(5662),
    [sym_string_get_expression] = STATE(5662),
    [sym_bigarray_get_expression] = STATE(5662),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(2309),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(2277),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(18127),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1389),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1391),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1393),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2310] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8302),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(2310),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2311] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8304),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(2311),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2312] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8305),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(2312),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2313] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8307),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(2313),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2314] = {
    [sym_value_definition] = STATE(18149),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11486),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5662),
    [sym_array_get_expression] = STATE(5662),
    [sym_string_get_expression] = STATE(5662),
    [sym_bigarray_get_expression] = STATE(5662),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(2314),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(2277),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(18127),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1389),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1391),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1393),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2315] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8308),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(2315),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2316] = {
    [sym_value_definition] = STATE(18149),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11487),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5662),
    [sym_array_get_expression] = STATE(5662),
    [sym_string_get_expression] = STATE(5662),
    [sym_bigarray_get_expression] = STATE(5662),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(2316),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(2277),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(18127),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1389),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1391),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1393),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2317] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8309),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(2317),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2318] = {
    [sym__simple_expression] = STATE(3334),
    [sym_typed_expression] = STATE(3461),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_labeled_argument] = STATE(4439),
    [sym_prefix_expression] = STATE(3461),
    [sym_hash_expression] = STATE(3461),
    [sym_field_get_expression] = STATE(3461),
    [sym_array_get_expression] = STATE(3461),
    [sym_string_get_expression] = STATE(3461),
    [sym_bigarray_get_expression] = STATE(3461),
    [sym_coercion_expression] = STATE(3461),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(2318),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [aux_sym_class_application_repeat1] = STATE(2126),
    [sym__lowercase_identifier] = ACTIONS(3237),
    [anon_sym_SEMI_SEMI] = ACTIONS(3943),
    [anon_sym_let] = ACTIONS(3945),
    [anon_sym_and] = ACTIONS(3945),
    [anon_sym_TILDE] = ACTIONS(3239),
    [anon_sym_QMARK] = ACTIONS(3239),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_external] = ACTIONS(3945),
    [anon_sym_type] = ACTIONS(3945),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_RBRACK] = ACTIONS(3943),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_SEMI] = ACTIONS(3945),
    [anon_sym_exception] = ACTIONS(3945),
    [anon_sym_module] = ACTIONS(3945),
    [anon_sym_open] = ACTIONS(3945),
    [anon_sym_include] = ACTIONS(3945),
    [anon_sym_class] = ACTIONS(3945),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_in] = ACTIONS(3945),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3945),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3943),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(613),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(615),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3943),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3943),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym_let_operator] = ACTIONS(3943),
    [sym_let_and_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_directive_token1] = ACTIONS(3943),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2319] = {
    [sym_value_definition] = STATE(19586),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8794),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(2319),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2320] = {
    [sym_value_definition] = STATE(19586),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8833),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(2320),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2321] = {
    [sym_value_definition] = STATE(19586),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8836),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(2321),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2322] = {
    [sym_value_definition] = STATE(17904),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12380),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6329),
    [sym_array_get_expression] = STATE(6329),
    [sym_string_get_expression] = STATE(6329),
    [sym_bigarray_get_expression] = STATE(6329),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(2322),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(2362),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(17913),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2601),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2607),
    [anon_sym_function] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2611),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2633),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2323] = {
    [sym_value_definition] = STATE(19080),
    [sym__simple_expression] = STATE(506),
    [sym__expression] = STATE(8365),
    [sym_typed_expression] = STATE(3532),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3532),
    [sym_array_expression] = STATE(3532),
    [sym_record_expression] = STATE(3532),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3532),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3532),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3084),
    [sym_array_get_expression] = STATE(3084),
    [sym_string_get_expression] = STATE(3084),
    [sym_bigarray_get_expression] = STATE(3084),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3532),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3532),
    [sym_package_expression] = STATE(3532),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3532),
    [sym_object_copy_expression] = STATE(3532),
    [sym_method_invocation] = STATE(3532),
    [sym_object_expression] = STATE(3532),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_attribute] = STATE(2323),
    [sym_extension] = STATE(3532),
    [sym_quoted_extension] = STATE(3532),
    [sym__constant] = STATE(3532),
    [sym_number] = STATE(3400),
    [sym_character] = STATE(3400),
    [sym_string] = STATE(3400),
    [sym_quoted_string] = STATE(3400),
    [sym_boolean] = STATE(3400),
    [sym_unit] = STATE(3400),
    [sym_sign_operator] = STATE(2274),
    [sym__value_name] = STATE(3691),
    [sym_parenthesized_operator] = STATE(3349),
    [sym_value_path] = STATE(3532),
    [sym_module_path] = STATE(18868),
    [sym_constructor_path] = STATE(3532),
    [sym__instance_variable_name] = STATE(18842),
    [sym__constructor_name] = STATE(3406),
    [sym_tag] = STATE(3532),
    [sym__lowercase_identifier] = ACTIONS(475),
    [anon_sym_let] = ACTIONS(477),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_true] = ACTIONS(483),
    [anon_sym_false] = ACTIONS(483),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_object] = ACTIONS(487),
    [anon_sym_fun] = ACTIONS(489),
    [anon_sym_LBRACK_PIPE] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(495),
    [anon_sym_function] = ACTIONS(497),
    [anon_sym_try] = ACTIONS(499),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(501),
    [anon_sym_LBRACE_LT] = ACTIONS(503),
    [anon_sym_begin] = ACTIONS(505),
    [sym_ocamlyacc_value] = ACTIONS(507),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3123),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3125),
    [aux_sym_number_token1] = ACTIONS(513),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_prefix_operator] = ACTIONS(519),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(521),
    [sym__uppercase_identifier] = ACTIONS(523),
    [aux_sym_tag_token1] = ACTIONS(525),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2324] = {
    [sym_value_definition] = STATE(18149),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11493),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5662),
    [sym_array_get_expression] = STATE(5662),
    [sym_string_get_expression] = STATE(5662),
    [sym_bigarray_get_expression] = STATE(5662),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(2324),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(2277),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(18127),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1389),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1391),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1393),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2325] = {
    [sym_value_definition] = STATE(18030),
    [sym__simple_expression] = STATE(301),
    [sym__expression] = STATE(8145),
    [sym_typed_expression] = STATE(3052),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3052),
    [sym_array_expression] = STATE(3052),
    [sym_record_expression] = STATE(3052),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3052),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3052),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(2963),
    [sym_array_get_expression] = STATE(2963),
    [sym_string_get_expression] = STATE(2963),
    [sym_bigarray_get_expression] = STATE(2963),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3052),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3052),
    [sym_package_expression] = STATE(3052),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3052),
    [sym_object_copy_expression] = STATE(3052),
    [sym_method_invocation] = STATE(3052),
    [sym_object_expression] = STATE(3052),
    [sym_parenthesized_expression] = STATE(3052),
    [sym_attribute] = STATE(2325),
    [sym_extension] = STATE(3052),
    [sym_quoted_extension] = STATE(3052),
    [sym__constant] = STATE(3052),
    [sym_number] = STATE(3188),
    [sym_character] = STATE(3188),
    [sym_string] = STATE(3188),
    [sym_quoted_string] = STATE(3188),
    [sym_boolean] = STATE(3188),
    [sym_unit] = STATE(3188),
    [sym_sign_operator] = STATE(1958),
    [sym__value_name] = STATE(2972),
    [sym_parenthesized_operator] = STATE(3089),
    [sym_value_path] = STATE(3052),
    [sym_module_path] = STATE(18756),
    [sym_constructor_path] = STATE(3052),
    [sym__instance_variable_name] = STATE(18008),
    [sym__constructor_name] = STATE(3189),
    [sym_tag] = STATE(3052),
    [sym__lowercase_identifier] = ACTIONS(295),
    [anon_sym_let] = ACTIONS(299),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [anon_sym_LBRACE] = ACTIONS(309),
    [anon_sym_object] = ACTIONS(311),
    [anon_sym_fun] = ACTIONS(313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(315),
    [anon_sym_if] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(319),
    [anon_sym_function] = ACTIONS(321),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_LBRACE_LT] = ACTIONS(327),
    [anon_sym_begin] = ACTIONS(329),
    [sym_ocamlyacc_value] = ACTIONS(331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3119),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3121),
    [aux_sym_number_token1] = ACTIONS(339),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(341),
    [anon_sym_DQUOTE] = ACTIONS(343),
    [sym_prefix_operator] = ACTIONS(345),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(349),
    [sym__uppercase_identifier] = ACTIONS(351),
    [aux_sym_tag_token1] = ACTIONS(353),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2326] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12670),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2326),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2327] = {
    [sym_value_definition] = STATE(19319),
    [sym__simple_expression] = STATE(542),
    [sym__expression] = STATE(8378),
    [sym_typed_expression] = STATE(3461),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(3461),
    [sym_array_expression] = STATE(3461),
    [sym_record_expression] = STATE(3461),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(3461),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(3461),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3242),
    [sym_array_get_expression] = STATE(3242),
    [sym_string_get_expression] = STATE(3242),
    [sym_bigarray_get_expression] = STATE(3242),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(3461),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(3461),
    [sym_package_expression] = STATE(3461),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(3461),
    [sym_object_copy_expression] = STATE(3461),
    [sym_method_invocation] = STATE(3461),
    [sym_object_expression] = STATE(3461),
    [sym_parenthesized_expression] = STATE(3461),
    [sym_attribute] = STATE(2327),
    [sym_extension] = STATE(3461),
    [sym_quoted_extension] = STATE(3461),
    [sym__constant] = STATE(3461),
    [sym_number] = STATE(3472),
    [sym_character] = STATE(3472),
    [sym_string] = STATE(3472),
    [sym_quoted_string] = STATE(3472),
    [sym_boolean] = STATE(3472),
    [sym_unit] = STATE(3472),
    [sym_sign_operator] = STATE(2327),
    [sym__value_name] = STATE(3340),
    [sym_parenthesized_operator] = STATE(3728),
    [sym_value_path] = STATE(3461),
    [sym_module_path] = STATE(17910),
    [sym_constructor_path] = STATE(3461),
    [sym__instance_variable_name] = STATE(19330),
    [sym__constructor_name] = STATE(3473),
    [sym_tag] = STATE(3461),
    [sym__lowercase_identifier] = ACTIONS(579),
    [anon_sym_let] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(583),
    [anon_sym_LBRACK] = ACTIONS(585),
    [anon_sym_true] = ACTIONS(587),
    [anon_sym_false] = ACTIONS(587),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(591),
    [anon_sym_fun] = ACTIONS(593),
    [anon_sym_LBRACK_PIPE] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(597),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(605),
    [anon_sym_LBRACE_LT] = ACTIONS(607),
    [anon_sym_begin] = ACTIONS(609),
    [sym_ocamlyacc_value] = ACTIONS(611),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3101),
    [aux_sym_number_token1] = ACTIONS(617),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(619),
    [anon_sym_DQUOTE] = ACTIONS(621),
    [sym_prefix_operator] = ACTIONS(623),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(625),
    [sym__uppercase_identifier] = ACTIONS(627),
    [aux_sym_tag_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2328] = {
    [sym_value_definition] = STATE(17904),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12381),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6329),
    [sym_array_get_expression] = STATE(6329),
    [sym_string_get_expression] = STATE(6329),
    [sym_bigarray_get_expression] = STATE(6329),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(2328),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(2362),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(17913),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2601),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2607),
    [anon_sym_function] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2611),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2633),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2329] = {
    [sym_value_definition] = STATE(19586),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8844),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(2329),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2330] = {
    [sym_value_definition] = STATE(17904),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12399),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6329),
    [sym_array_get_expression] = STATE(6329),
    [sym_string_get_expression] = STATE(6329),
    [sym_bigarray_get_expression] = STATE(6329),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(2330),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(2362),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(17913),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2601),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2607),
    [anon_sym_function] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2611),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2633),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2331] = {
    [sym_value_definition] = STATE(17904),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12403),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6329),
    [sym_array_get_expression] = STATE(6329),
    [sym_string_get_expression] = STATE(6329),
    [sym_bigarray_get_expression] = STATE(6329),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(2331),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(2362),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(17913),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2601),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2607),
    [anon_sym_function] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2611),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2633),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2332] = {
    [sym_value_definition] = STATE(17904),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12405),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6329),
    [sym_array_get_expression] = STATE(6329),
    [sym_string_get_expression] = STATE(6329),
    [sym_bigarray_get_expression] = STATE(6329),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(2332),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(2362),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(17913),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2601),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2607),
    [anon_sym_function] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2611),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2633),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2333] = {
    [sym_value_definition] = STATE(18447),
    [sym__simple_expression] = STATE(2473),
    [sym__expression] = STATE(12581),
    [sym_typed_expression] = STATE(6539),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(6539),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(6539),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(6602),
    [sym_array_get_expression] = STATE(6602),
    [sym_string_get_expression] = STATE(6602),
    [sym_bigarray_get_expression] = STATE(6602),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(6539),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(2333),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym_sign_operator] = STATE(1952),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__instance_variable_name] = STATE(18459),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2334] = {
    [sym_value_definition] = STATE(19586),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8640),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(2334),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2335] = {
    [sym_value_definition] = STATE(17904),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12407),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6329),
    [sym_array_get_expression] = STATE(6329),
    [sym_string_get_expression] = STATE(6329),
    [sym_bigarray_get_expression] = STATE(6329),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(2335),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(2362),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(17913),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2601),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2607),
    [anon_sym_function] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2611),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2633),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2336] = {
    [sym_value_definition] = STATE(18362),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12566),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6385),
    [sym_array_get_expression] = STATE(6385),
    [sym_string_get_expression] = STATE(6385),
    [sym_bigarray_get_expression] = STATE(6385),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(2336),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2336),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(18374),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2337] = {
    [sym_value_definition] = STATE(18362),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12416),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6385),
    [sym_array_get_expression] = STATE(6385),
    [sym_string_get_expression] = STATE(6385),
    [sym_bigarray_get_expression] = STATE(6385),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(2337),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2336),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(18374),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2338] = {
    [sym_value_definition] = STATE(17904),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12408),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6329),
    [sym_array_get_expression] = STATE(6329),
    [sym_string_get_expression] = STATE(6329),
    [sym_bigarray_get_expression] = STATE(6329),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(2338),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(2362),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(17913),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2601),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2607),
    [anon_sym_function] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2611),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2633),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2339] = {
    [sym_value_definition] = STATE(17904),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12409),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6329),
    [sym_array_get_expression] = STATE(6329),
    [sym_string_get_expression] = STATE(6329),
    [sym_bigarray_get_expression] = STATE(6329),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(2339),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(2362),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(17913),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2601),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2607),
    [anon_sym_function] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2611),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2633),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2340] = {
    [sym_value_definition] = STATE(17904),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12413),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6329),
    [sym_array_get_expression] = STATE(6329),
    [sym_string_get_expression] = STATE(6329),
    [sym_bigarray_get_expression] = STATE(6329),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(2340),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(2362),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(17913),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2601),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2607),
    [anon_sym_function] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2611),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2633),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2341] = {
    [sym_value_definition] = STATE(17904),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12414),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6329),
    [sym_array_get_expression] = STATE(6329),
    [sym_string_get_expression] = STATE(6329),
    [sym_bigarray_get_expression] = STATE(6329),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(2341),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(2362),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(17913),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2601),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2607),
    [anon_sym_function] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2611),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2633),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2342] = {
    [sym_value_definition] = STATE(18428),
    [sym__simple_expression] = STATE(2428),
    [sym__expression] = STATE(10334),
    [sym_typed_expression] = STATE(5216),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5216),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5216),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4994),
    [sym_array_get_expression] = STATE(4994),
    [sym_string_get_expression] = STATE(4994),
    [sym_bigarray_get_expression] = STATE(4994),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5216),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(2342),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym_sign_operator] = STATE(2366),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__instance_variable_name] = STATE(18272),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [sym__lowercase_identifier] = ACTIONS(1061),
    [anon_sym_let] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_fun] = ACTIONS(1075),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_if] = ACTIONS(1079),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1081),
    [anon_sym_function] = ACTIONS(1083),
    [anon_sym_try] = ACTIONS(1085),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1109),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2343] = {
    [sym_value_definition] = STATE(18362),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12556),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6385),
    [sym_array_get_expression] = STATE(6385),
    [sym_string_get_expression] = STATE(6385),
    [sym_bigarray_get_expression] = STATE(6385),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(2343),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2336),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(18374),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2344] = {
    [sym_value_definition] = STATE(18362),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12213),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6385),
    [sym_array_get_expression] = STATE(6385),
    [sym_string_get_expression] = STATE(6385),
    [sym_bigarray_get_expression] = STATE(6385),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(2344),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2336),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(18374),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2345] = {
    [sym_value_definition] = STATE(18362),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12550),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6385),
    [sym_array_get_expression] = STATE(6385),
    [sym_string_get_expression] = STATE(6385),
    [sym_bigarray_get_expression] = STATE(6385),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(2345),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2336),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(18374),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2346] = {
    [sym_value_definition] = STATE(18362),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12549),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6385),
    [sym_array_get_expression] = STATE(6385),
    [sym_string_get_expression] = STATE(6385),
    [sym_bigarray_get_expression] = STATE(6385),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(2346),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2336),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(18374),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2347] = {
    [sym_value_definition] = STATE(17904),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12557),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6329),
    [sym_array_get_expression] = STATE(6329),
    [sym_string_get_expression] = STATE(6329),
    [sym_bigarray_get_expression] = STATE(6329),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(2347),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(2362),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(17913),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2601),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2607),
    [anon_sym_function] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2611),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2633),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2348] = {
    [sym_value_definition] = STATE(18428),
    [sym__simple_expression] = STATE(2428),
    [sym__expression] = STATE(10315),
    [sym_typed_expression] = STATE(5216),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5216),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5216),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4994),
    [sym_array_get_expression] = STATE(4994),
    [sym_string_get_expression] = STATE(4994),
    [sym_bigarray_get_expression] = STATE(4994),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5216),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(2348),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym_sign_operator] = STATE(2366),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__instance_variable_name] = STATE(18272),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [sym__lowercase_identifier] = ACTIONS(1061),
    [anon_sym_let] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_fun] = ACTIONS(1075),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_if] = ACTIONS(1079),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1081),
    [anon_sym_function] = ACTIONS(1083),
    [anon_sym_try] = ACTIONS(1085),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1109),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2349] = {
    [sym_value_definition] = STATE(18428),
    [sym__simple_expression] = STATE(2428),
    [sym__expression] = STATE(10314),
    [sym_typed_expression] = STATE(5216),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5216),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5216),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4994),
    [sym_array_get_expression] = STATE(4994),
    [sym_string_get_expression] = STATE(4994),
    [sym_bigarray_get_expression] = STATE(4994),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5216),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(2349),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym_sign_operator] = STATE(2366),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__instance_variable_name] = STATE(18272),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [sym__lowercase_identifier] = ACTIONS(1061),
    [anon_sym_let] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_fun] = ACTIONS(1075),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_if] = ACTIONS(1079),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1081),
    [anon_sym_function] = ACTIONS(1083),
    [anon_sym_try] = ACTIONS(1085),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1109),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2350] = {
    [sym_value_definition] = STATE(18428),
    [sym__simple_expression] = STATE(2428),
    [sym__expression] = STATE(10310),
    [sym_typed_expression] = STATE(5216),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5216),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5216),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4994),
    [sym_array_get_expression] = STATE(4994),
    [sym_string_get_expression] = STATE(4994),
    [sym_bigarray_get_expression] = STATE(4994),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5216),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(2350),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym_sign_operator] = STATE(2366),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__instance_variable_name] = STATE(18272),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [sym__lowercase_identifier] = ACTIONS(1061),
    [anon_sym_let] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_fun] = ACTIONS(1075),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_if] = ACTIONS(1079),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1081),
    [anon_sym_function] = ACTIONS(1083),
    [anon_sym_try] = ACTIONS(1085),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1109),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2351] = {
    [sym_value_definition] = STATE(18428),
    [sym__simple_expression] = STATE(2428),
    [sym__expression] = STATE(10301),
    [sym_typed_expression] = STATE(5216),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5216),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5216),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4994),
    [sym_array_get_expression] = STATE(4994),
    [sym_string_get_expression] = STATE(4994),
    [sym_bigarray_get_expression] = STATE(4994),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5216),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(2351),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym_sign_operator] = STATE(2366),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__instance_variable_name] = STATE(18272),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [sym__lowercase_identifier] = ACTIONS(1061),
    [anon_sym_let] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_fun] = ACTIONS(1075),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_if] = ACTIONS(1079),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1081),
    [anon_sym_function] = ACTIONS(1083),
    [anon_sym_try] = ACTIONS(1085),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1109),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2352] = {
    [sym_value_definition] = STATE(18428),
    [sym__simple_expression] = STATE(2428),
    [sym__expression] = STATE(10300),
    [sym_typed_expression] = STATE(5216),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5216),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5216),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4994),
    [sym_array_get_expression] = STATE(4994),
    [sym_string_get_expression] = STATE(4994),
    [sym_bigarray_get_expression] = STATE(4994),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5216),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(2352),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym_sign_operator] = STATE(2366),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__instance_variable_name] = STATE(18272),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [sym__lowercase_identifier] = ACTIONS(1061),
    [anon_sym_let] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_fun] = ACTIONS(1075),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_if] = ACTIONS(1079),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1081),
    [anon_sym_function] = ACTIONS(1083),
    [anon_sym_try] = ACTIONS(1085),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1109),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2353] = {
    [sym_value_definition] = STATE(18362),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12548),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6385),
    [sym_array_get_expression] = STATE(6385),
    [sym_string_get_expression] = STATE(6385),
    [sym_bigarray_get_expression] = STATE(6385),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(2353),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2336),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(18374),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2354] = {
    [sym_value_definition] = STATE(18362),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12547),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6385),
    [sym_array_get_expression] = STATE(6385),
    [sym_string_get_expression] = STATE(6385),
    [sym_bigarray_get_expression] = STATE(6385),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(2354),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2336),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(18374),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2355] = {
    [sym_value_definition] = STATE(18428),
    [sym__simple_expression] = STATE(2428),
    [sym__expression] = STATE(10281),
    [sym_typed_expression] = STATE(5216),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5216),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5216),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4994),
    [sym_array_get_expression] = STATE(4994),
    [sym_string_get_expression] = STATE(4994),
    [sym_bigarray_get_expression] = STATE(4994),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5216),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(2355),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym_sign_operator] = STATE(2366),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__instance_variable_name] = STATE(18272),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [sym__lowercase_identifier] = ACTIONS(1061),
    [anon_sym_let] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_fun] = ACTIONS(1075),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_if] = ACTIONS(1079),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1081),
    [anon_sym_function] = ACTIONS(1083),
    [anon_sym_try] = ACTIONS(1085),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1109),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2356] = {
    [sym_value_definition] = STATE(18428),
    [sym__simple_expression] = STATE(2428),
    [sym__expression] = STATE(10276),
    [sym_typed_expression] = STATE(5216),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5216),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5216),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4994),
    [sym_array_get_expression] = STATE(4994),
    [sym_string_get_expression] = STATE(4994),
    [sym_bigarray_get_expression] = STATE(4994),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5216),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(2356),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym_sign_operator] = STATE(2366),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__instance_variable_name] = STATE(18272),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [sym__lowercase_identifier] = ACTIONS(1061),
    [anon_sym_let] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_fun] = ACTIONS(1075),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_if] = ACTIONS(1079),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1081),
    [anon_sym_function] = ACTIONS(1083),
    [anon_sym_try] = ACTIONS(1085),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1109),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2357] = {
    [sym_value_definition] = STATE(18428),
    [sym__simple_expression] = STATE(2428),
    [sym__expression] = STATE(10275),
    [sym_typed_expression] = STATE(5216),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5216),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5216),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4994),
    [sym_array_get_expression] = STATE(4994),
    [sym_string_get_expression] = STATE(4994),
    [sym_bigarray_get_expression] = STATE(4994),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5216),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(2357),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym_sign_operator] = STATE(2366),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__instance_variable_name] = STATE(18272),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [sym__lowercase_identifier] = ACTIONS(1061),
    [anon_sym_let] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_fun] = ACTIONS(1075),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_if] = ACTIONS(1079),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1081),
    [anon_sym_function] = ACTIONS(1083),
    [anon_sym_try] = ACTIONS(1085),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1109),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2358] = {
    [sym_value_definition] = STATE(18428),
    [sym__simple_expression] = STATE(2428),
    [sym__expression] = STATE(10273),
    [sym_typed_expression] = STATE(5216),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5216),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5216),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4994),
    [sym_array_get_expression] = STATE(4994),
    [sym_string_get_expression] = STATE(4994),
    [sym_bigarray_get_expression] = STATE(4994),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5216),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(2358),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym_sign_operator] = STATE(2366),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__instance_variable_name] = STATE(18272),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [sym__lowercase_identifier] = ACTIONS(1061),
    [anon_sym_let] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_fun] = ACTIONS(1075),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_if] = ACTIONS(1079),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1081),
    [anon_sym_function] = ACTIONS(1083),
    [anon_sym_try] = ACTIONS(1085),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1109),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2359] = {
    [sym_value_definition] = STATE(18362),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12523),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6385),
    [sym_array_get_expression] = STATE(6385),
    [sym_string_get_expression] = STATE(6385),
    [sym_bigarray_get_expression] = STATE(6385),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(2359),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2336),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(18374),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2360] = {
    [sym_value_definition] = STATE(18362),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12545),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6385),
    [sym_array_get_expression] = STATE(6385),
    [sym_string_get_expression] = STATE(6385),
    [sym_bigarray_get_expression] = STATE(6385),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(2360),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2336),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(18374),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2361] = {
    [sym_value_definition] = STATE(19586),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8847),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(2361),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2362] = {
    [sym_value_definition] = STATE(17904),
    [sym__simple_expression] = STATE(2482),
    [sym__expression] = STATE(12543),
    [sym_typed_expression] = STATE(7138),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7138),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7138),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6329),
    [sym_array_get_expression] = STATE(6329),
    [sym_string_get_expression] = STATE(6329),
    [sym_bigarray_get_expression] = STATE(6329),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7138),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(2362),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym_sign_operator] = STATE(2362),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__instance_variable_name] = STATE(17913),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [sym__lowercase_identifier] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_fun] = ACTIONS(2601),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2607),
    [anon_sym_function] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2611),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2633),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2363] = {
    [sym_value_definition] = STATE(18428),
    [sym__simple_expression] = STATE(2428),
    [sym__expression] = STATE(10272),
    [sym_typed_expression] = STATE(5216),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5216),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5216),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4994),
    [sym_array_get_expression] = STATE(4994),
    [sym_string_get_expression] = STATE(4994),
    [sym_bigarray_get_expression] = STATE(4994),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5216),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(2363),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym_sign_operator] = STATE(2366),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__instance_variable_name] = STATE(18272),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [sym__lowercase_identifier] = ACTIONS(1061),
    [anon_sym_let] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_fun] = ACTIONS(1075),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_if] = ACTIONS(1079),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1081),
    [anon_sym_function] = ACTIONS(1083),
    [anon_sym_try] = ACTIONS(1085),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1109),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2364] = {
    [sym_value_definition] = STATE(18428),
    [sym__simple_expression] = STATE(2428),
    [sym__expression] = STATE(10271),
    [sym_typed_expression] = STATE(5216),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5216),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5216),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4994),
    [sym_array_get_expression] = STATE(4994),
    [sym_string_get_expression] = STATE(4994),
    [sym_bigarray_get_expression] = STATE(4994),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5216),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(2364),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym_sign_operator] = STATE(2366),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__instance_variable_name] = STATE(18272),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [sym__lowercase_identifier] = ACTIONS(1061),
    [anon_sym_let] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_fun] = ACTIONS(1075),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_if] = ACTIONS(1079),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1081),
    [anon_sym_function] = ACTIONS(1083),
    [anon_sym_try] = ACTIONS(1085),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1109),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2365] = {
    [sym_value_definition] = STATE(18362),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12540),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6385),
    [sym_array_get_expression] = STATE(6385),
    [sym_string_get_expression] = STATE(6385),
    [sym_bigarray_get_expression] = STATE(6385),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(2365),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2336),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(18374),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2366] = {
    [sym_value_definition] = STATE(18428),
    [sym__simple_expression] = STATE(2428),
    [sym__expression] = STATE(10292),
    [sym_typed_expression] = STATE(5216),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(5216),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(5216),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(4994),
    [sym_array_get_expression] = STATE(4994),
    [sym_string_get_expression] = STATE(4994),
    [sym_bigarray_get_expression] = STATE(4994),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(5216),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(2366),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym_sign_operator] = STATE(2366),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__instance_variable_name] = STATE(18272),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [sym__lowercase_identifier] = ACTIONS(1061),
    [anon_sym_let] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_fun] = ACTIONS(1075),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_if] = ACTIONS(1079),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(1081),
    [anon_sym_function] = ACTIONS(1083),
    [anon_sym_try] = ACTIONS(1085),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1109),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2367] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12786),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2367),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2368] = {
    [sym_value_definition] = STATE(18362),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12539),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6385),
    [sym_array_get_expression] = STATE(6385),
    [sym_string_get_expression] = STATE(6385),
    [sym_bigarray_get_expression] = STATE(6385),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(2368),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2336),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(18374),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2369] = {
    [sym_value_definition] = STATE(19586),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8849),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(2369),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2370] = {
    [sym_value_definition] = STATE(19586),
    [sym__simple_expression] = STATE(2124),
    [sym__expression] = STATE(8852),
    [sym_typed_expression] = STATE(4315),
    [sym_product_expression] = STATE(8230),
    [sym_cons_expression] = STATE(8230),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_application_expression] = STATE(8230),
    [sym_prefix_expression] = STATE(4315),
    [sym_sign_expression] = STATE(8230),
    [sym_hash_expression] = STATE(4315),
    [sym_infix_expression] = STATE(8230),
    [sym_field_get_expression] = STATE(3978),
    [sym_array_get_expression] = STATE(3978),
    [sym_string_get_expression] = STATE(3978),
    [sym_bigarray_get_expression] = STATE(3978),
    [sym_set_expression] = STATE(8230),
    [sym_if_expression] = STATE(8230),
    [sym_while_expression] = STATE(8230),
    [sym_for_expression] = STATE(8230),
    [sym_match_expression] = STATE(8230),
    [sym_function_expression] = STATE(8230),
    [sym_fun_expression] = STATE(8230),
    [sym_try_expression] = STATE(8230),
    [sym_let_expression] = STATE(8230),
    [sym_coercion_expression] = STATE(4315),
    [sym_assert_expression] = STATE(8230),
    [sym_lazy_expression] = STATE(8230),
    [sym_let_module_expression] = STATE(8230),
    [sym_let_open_expression] = STATE(8230),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_let_exception_expression] = STATE(8230),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(2370),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym_sign_operator] = STATE(2128),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__instance_variable_name] = STATE(20479),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_fun] = ACTIONS(69),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_while] = ACTIONS(75),
    [anon_sym_for] = ACTIONS(77),
    [anon_sym_match] = ACTIONS(79),
    [anon_sym_function] = ACTIONS(81),
    [anon_sym_try] = ACTIONS(83),
    [anon_sym_assert] = ACTIONS(85),
    [anon_sym_lazy] = ACTIONS(87),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(115),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2371] = {
    [sym_value_definition] = STATE(18034),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12419),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6443),
    [sym_array_get_expression] = STATE(6443),
    [sym_string_get_expression] = STATE(6443),
    [sym_bigarray_get_expression] = STATE(6443),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2371),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2397),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(18043),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2693),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2705),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2709),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2711),
    [anon_sym_function] = ACTIONS(2713),
    [anon_sym_try] = ACTIONS(2715),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2737),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2372] = {
    [sym_value_definition] = STATE(18362),
    [sym__simple_expression] = STATE(2481),
    [sym__expression] = STATE(12528),
    [sym_typed_expression] = STATE(7128),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7128),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7128),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6385),
    [sym_array_get_expression] = STATE(6385),
    [sym_string_get_expression] = STATE(6385),
    [sym_bigarray_get_expression] = STATE(6385),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7128),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(2372),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym_sign_operator] = STATE(2336),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__instance_variable_name] = STATE(18374),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2373] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12784),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2373),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2374] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12787),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2374),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2375] = {
    [sym_value_definition] = STATE(18149),
    [sym__simple_expression] = STATE(2435),
    [sym__expression] = STATE(11603),
    [sym_typed_expression] = STATE(5700),
    [sym_product_expression] = STATE(10510),
    [sym_cons_expression] = STATE(10510),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_application_expression] = STATE(10510),
    [sym_prefix_expression] = STATE(5700),
    [sym_sign_expression] = STATE(10510),
    [sym_hash_expression] = STATE(5700),
    [sym_infix_expression] = STATE(10510),
    [sym_field_get_expression] = STATE(5662),
    [sym_array_get_expression] = STATE(5662),
    [sym_string_get_expression] = STATE(5662),
    [sym_bigarray_get_expression] = STATE(5662),
    [sym_set_expression] = STATE(10510),
    [sym_if_expression] = STATE(10510),
    [sym_while_expression] = STATE(10510),
    [sym_for_expression] = STATE(10510),
    [sym_match_expression] = STATE(10510),
    [sym_function_expression] = STATE(10510),
    [sym_fun_expression] = STATE(10510),
    [sym_try_expression] = STATE(10510),
    [sym_let_expression] = STATE(10510),
    [sym_coercion_expression] = STATE(5700),
    [sym_assert_expression] = STATE(10510),
    [sym_lazy_expression] = STATE(10510),
    [sym_let_module_expression] = STATE(10510),
    [sym_let_open_expression] = STATE(10510),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_let_exception_expression] = STATE(10510),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(2375),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym_sign_operator] = STATE(2277),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__instance_variable_name] = STATE(18127),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [sym__lowercase_identifier] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1389),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_fun] = ACTIONS(1391),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1393),
    [anon_sym_while] = ACTIONS(1297),
    [anon_sym_for] = ACTIONS(1299),
    [anon_sym_match] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1303),
    [anon_sym_try] = ACTIONS(1305),
    [anon_sym_assert] = ACTIONS(1307),
    [anon_sym_lazy] = ACTIONS(1309),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1331),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2376] = {
    [sym_value_definition] = STATE(18188),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12277),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6417),
    [sym_array_get_expression] = STATE(6417),
    [sym_string_get_expression] = STATE(6417),
    [sym_bigarray_get_expression] = STATE(6417),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(2376),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(18201),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2745),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2761),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2763),
    [anon_sym_function] = ACTIONS(2765),
    [anon_sym_try] = ACTIONS(2767),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2789),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2377] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12796),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2377),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2378] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12797),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2378),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2379] = {
    [sym_value_definition] = STATE(18188),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12516),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6417),
    [sym_array_get_expression] = STATE(6417),
    [sym_string_get_expression] = STATE(6417),
    [sym_bigarray_get_expression] = STATE(6417),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(2379),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(18201),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2745),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2761),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2763),
    [anon_sym_function] = ACTIONS(2765),
    [anon_sym_try] = ACTIONS(2767),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2789),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2380] = {
    [sym_value_definition] = STATE(18188),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12504),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6417),
    [sym_array_get_expression] = STATE(6417),
    [sym_string_get_expression] = STATE(6417),
    [sym_bigarray_get_expression] = STATE(6417),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(2380),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(18201),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2745),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2761),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2763),
    [anon_sym_function] = ACTIONS(2765),
    [anon_sym_try] = ACTIONS(2767),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2789),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2381] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12799),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2381),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2382] = {
    [sym_value_definition] = STATE(18188),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12501),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6417),
    [sym_array_get_expression] = STATE(6417),
    [sym_string_get_expression] = STATE(6417),
    [sym_bigarray_get_expression] = STATE(6417),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(2382),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(18201),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2745),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2761),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2763),
    [anon_sym_function] = ACTIONS(2765),
    [anon_sym_try] = ACTIONS(2767),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2789),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2383] = {
    [sym_value_definition] = STATE(18188),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12500),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6417),
    [sym_array_get_expression] = STATE(6417),
    [sym_string_get_expression] = STATE(6417),
    [sym_bigarray_get_expression] = STATE(6417),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(2383),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(18201),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2745),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2761),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2763),
    [anon_sym_function] = ACTIONS(2765),
    [anon_sym_try] = ACTIONS(2767),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2789),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2384] = {
    [sym_value_definition] = STATE(18188),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12485),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6417),
    [sym_array_get_expression] = STATE(6417),
    [sym_string_get_expression] = STATE(6417),
    [sym_bigarray_get_expression] = STATE(6417),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(2384),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(18201),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2745),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2761),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2763),
    [anon_sym_function] = ACTIONS(2765),
    [anon_sym_try] = ACTIONS(2767),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2789),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2385] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12806),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2385),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2386] = {
    [sym_value_definition] = STATE(18188),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12479),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6417),
    [sym_array_get_expression] = STATE(6417),
    [sym_string_get_expression] = STATE(6417),
    [sym_bigarray_get_expression] = STATE(6417),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(2386),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(18201),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2745),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2761),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2763),
    [anon_sym_function] = ACTIONS(2765),
    [anon_sym_try] = ACTIONS(2767),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2789),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2387] = {
    [sym_value_definition] = STATE(18188),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12469),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6417),
    [sym_array_get_expression] = STATE(6417),
    [sym_string_get_expression] = STATE(6417),
    [sym_bigarray_get_expression] = STATE(6417),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(2387),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(18201),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2745),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2761),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2763),
    [anon_sym_function] = ACTIONS(2765),
    [anon_sym_try] = ACTIONS(2767),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2789),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2388] = {
    [sym_value_definition] = STATE(18188),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12468),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6417),
    [sym_array_get_expression] = STATE(6417),
    [sym_string_get_expression] = STATE(6417),
    [sym_bigarray_get_expression] = STATE(6417),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(2388),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(18201),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2745),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2761),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2763),
    [anon_sym_function] = ACTIONS(2765),
    [anon_sym_try] = ACTIONS(2767),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2789),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2389] = {
    [sym_value_definition] = STATE(18188),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12464),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6417),
    [sym_array_get_expression] = STATE(6417),
    [sym_string_get_expression] = STATE(6417),
    [sym_bigarray_get_expression] = STATE(6417),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(2389),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(18201),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2745),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2761),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2763),
    [anon_sym_function] = ACTIONS(2765),
    [anon_sym_try] = ACTIONS(2767),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2789),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2390] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12812),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2390),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2391] = {
    [sym_value_definition] = STATE(18188),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12461),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6417),
    [sym_array_get_expression] = STATE(6417),
    [sym_string_get_expression] = STATE(6417),
    [sym_bigarray_get_expression] = STATE(6417),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(2391),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(18201),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2745),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2761),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2763),
    [anon_sym_function] = ACTIONS(2765),
    [anon_sym_try] = ACTIONS(2767),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2789),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2392] = {
    [sym_value_definition] = STATE(18188),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12453),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6417),
    [sym_array_get_expression] = STATE(6417),
    [sym_string_get_expression] = STATE(6417),
    [sym_bigarray_get_expression] = STATE(6417),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(2392),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(18201),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2745),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2761),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2763),
    [anon_sym_function] = ACTIONS(2765),
    [anon_sym_try] = ACTIONS(2767),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2789),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2393] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12817),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2393),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2394] = {
    [sym_value_definition] = STATE(18188),
    [sym__simple_expression] = STATE(2486),
    [sym__expression] = STATE(12452),
    [sym_typed_expression] = STATE(7193),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7193),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7193),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6417),
    [sym_array_get_expression] = STATE(6417),
    [sym_string_get_expression] = STATE(6417),
    [sym_bigarray_get_expression] = STATE(6417),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7193),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(2394),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__instance_variable_name] = STATE(18201),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [sym__lowercase_identifier] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2745),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_fun] = ACTIONS(2757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_if] = ACTIONS(2761),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2763),
    [anon_sym_function] = ACTIONS(2765),
    [anon_sym_try] = ACTIONS(2767),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2789),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2395] = {
    [sym_value_definition] = STATE(19395),
    [sym__simple_expression] = STATE(2424),
    [sym__expression] = STATE(10049),
    [sym_typed_expression] = STATE(4984),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(4984),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(4984),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(4954),
    [sym_array_get_expression] = STATE(4954),
    [sym_string_get_expression] = STATE(4954),
    [sym_bigarray_get_expression] = STATE(4954),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(4984),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2395),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym_sign_operator] = STATE(2186),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__instance_variable_name] = STATE(19406),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [sym__lowercase_identifier] = ACTIONS(995),
    [anon_sym_let] = ACTIONS(1047),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_fun] = ACTIONS(1049),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1053),
    [anon_sym_function] = ACTIONS(1055),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_lazy] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3073),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3075),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1059),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2396] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12818),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2396),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2397] = {
    [sym_value_definition] = STATE(18034),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12475),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6443),
    [sym_array_get_expression] = STATE(6443),
    [sym_string_get_expression] = STATE(6443),
    [sym_bigarray_get_expression] = STATE(6443),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2397),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2397),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(18043),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2693),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2705),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2709),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2711),
    [anon_sym_function] = ACTIONS(2713),
    [anon_sym_try] = ACTIONS(2715),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2737),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2398] = {
    [sym_value_definition] = STATE(18034),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12450),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6443),
    [sym_array_get_expression] = STATE(6443),
    [sym_string_get_expression] = STATE(6443),
    [sym_bigarray_get_expression] = STATE(6443),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2398),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2397),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(18043),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2693),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2705),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2709),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2711),
    [anon_sym_function] = ACTIONS(2713),
    [anon_sym_try] = ACTIONS(2715),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2737),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2399] = {
    [sym_value_definition] = STATE(18034),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12448),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6443),
    [sym_array_get_expression] = STATE(6443),
    [sym_string_get_expression] = STATE(6443),
    [sym_bigarray_get_expression] = STATE(6443),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2399),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2397),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(18043),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2693),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2705),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2709),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2711),
    [anon_sym_function] = ACTIONS(2713),
    [anon_sym_try] = ACTIONS(2715),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2737),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2400] = {
    [sym_value_definition] = STATE(18034),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12447),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6443),
    [sym_array_get_expression] = STATE(6443),
    [sym_string_get_expression] = STATE(6443),
    [sym_bigarray_get_expression] = STATE(6443),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2400),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2397),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(18043),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2693),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2705),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2709),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2711),
    [anon_sym_function] = ACTIONS(2713),
    [anon_sym_try] = ACTIONS(2715),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2737),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2401] = {
    [sym_value_definition] = STATE(18034),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12445),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6443),
    [sym_array_get_expression] = STATE(6443),
    [sym_string_get_expression] = STATE(6443),
    [sym_bigarray_get_expression] = STATE(6443),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2401),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2397),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(18043),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2693),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2705),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2709),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2711),
    [anon_sym_function] = ACTIONS(2713),
    [anon_sym_try] = ACTIONS(2715),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2737),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2402] = {
    [sym_value_definition] = STATE(20447),
    [sym__simple_expression] = STATE(2427),
    [sym__expression] = STATE(10747),
    [sym_typed_expression] = STATE(5299),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(5299),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(5299),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(5342),
    [sym_array_get_expression] = STATE(5342),
    [sym_string_get_expression] = STATE(5342),
    [sym_bigarray_get_expression] = STATE(5342),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(5299),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2402),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__instance_variable_name] = STATE(19987),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [sym__lowercase_identifier] = ACTIONS(1223),
    [anon_sym_let] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_fun] = ACTIONS(1237),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_if] = ACTIONS(1241),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(1243),
    [anon_sym_function] = ACTIONS(1245),
    [anon_sym_try] = ACTIONS(1247),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(1269),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2403] = {
    [sym_value_definition] = STATE(18034),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12444),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6443),
    [sym_array_get_expression] = STATE(6443),
    [sym_string_get_expression] = STATE(6443),
    [sym_bigarray_get_expression] = STATE(6443),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2403),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2397),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(18043),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2693),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2705),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2709),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2711),
    [anon_sym_function] = ACTIONS(2713),
    [anon_sym_try] = ACTIONS(2715),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2737),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2404] = {
    [sym_value_definition] = STATE(18034),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12428),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6443),
    [sym_array_get_expression] = STATE(6443),
    [sym_string_get_expression] = STATE(6443),
    [sym_bigarray_get_expression] = STATE(6443),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2404),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2397),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(18043),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2693),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2705),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2709),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2711),
    [anon_sym_function] = ACTIONS(2713),
    [anon_sym_try] = ACTIONS(2715),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2737),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2405] = {
    [sym_value_definition] = STATE(18034),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12426),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6443),
    [sym_array_get_expression] = STATE(6443),
    [sym_string_get_expression] = STATE(6443),
    [sym_bigarray_get_expression] = STATE(6443),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2405),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2397),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(18043),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2693),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2705),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2709),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2711),
    [anon_sym_function] = ACTIONS(2713),
    [anon_sym_try] = ACTIONS(2715),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2737),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2406] = {
    [sym_value_definition] = STATE(19847),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12821),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(7858),
    [sym_cons_expression] = STATE(7858),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(7858),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(7858),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(7858),
    [sym_field_get_expression] = STATE(7191),
    [sym_array_get_expression] = STATE(7191),
    [sym_string_get_expression] = STATE(7191),
    [sym_bigarray_get_expression] = STATE(7191),
    [sym_set_expression] = STATE(7858),
    [sym_if_expression] = STATE(7858),
    [sym_while_expression] = STATE(7858),
    [sym_for_expression] = STATE(7858),
    [sym_match_expression] = STATE(7858),
    [sym_function_expression] = STATE(7858),
    [sym_fun_expression] = STATE(7858),
    [sym_try_expression] = STATE(7858),
    [sym_let_expression] = STATE(7858),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(7858),
    [sym_lazy_expression] = STATE(7858),
    [sym_let_module_expression] = STATE(7858),
    [sym_let_open_expression] = STATE(7858),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(7858),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2406),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2326),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(19597),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(979),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_lazy] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2407] = {
    [sym_value_definition] = STATE(18034),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12425),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6443),
    [sym_array_get_expression] = STATE(6443),
    [sym_string_get_expression] = STATE(6443),
    [sym_bigarray_get_expression] = STATE(6443),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2407),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2397),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(18043),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2693),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2705),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2709),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2711),
    [anon_sym_function] = ACTIONS(2713),
    [anon_sym_try] = ACTIONS(2715),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2737),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2408] = {
    [sym_value_definition] = STATE(18034),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12424),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6443),
    [sym_array_get_expression] = STATE(6443),
    [sym_string_get_expression] = STATE(6443),
    [sym_bigarray_get_expression] = STATE(6443),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2408),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2397),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(18043),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2693),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2705),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2709),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2711),
    [anon_sym_function] = ACTIONS(2713),
    [anon_sym_try] = ACTIONS(2715),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2737),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2409] = {
    [sym_value_definition] = STATE(18034),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12423),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6443),
    [sym_array_get_expression] = STATE(6443),
    [sym_string_get_expression] = STATE(6443),
    [sym_bigarray_get_expression] = STATE(6443),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2409),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2397),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(18043),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2693),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2705),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2709),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2711),
    [anon_sym_function] = ACTIONS(2713),
    [anon_sym_try] = ACTIONS(2715),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2737),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2410] = {
    [sym_value_definition] = STATE(18034),
    [sym__simple_expression] = STATE(2485),
    [sym__expression] = STATE(12422),
    [sym_typed_expression] = STATE(7067),
    [sym_product_expression] = STATE(8117),
    [sym_cons_expression] = STATE(8117),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_application_expression] = STATE(8117),
    [sym_prefix_expression] = STATE(7067),
    [sym_sign_expression] = STATE(8117),
    [sym_hash_expression] = STATE(7067),
    [sym_infix_expression] = STATE(8117),
    [sym_field_get_expression] = STATE(6443),
    [sym_array_get_expression] = STATE(6443),
    [sym_string_get_expression] = STATE(6443),
    [sym_bigarray_get_expression] = STATE(6443),
    [sym_set_expression] = STATE(8117),
    [sym_if_expression] = STATE(8117),
    [sym_while_expression] = STATE(8117),
    [sym_for_expression] = STATE(8117),
    [sym_match_expression] = STATE(8117),
    [sym_function_expression] = STATE(8117),
    [sym_fun_expression] = STATE(8117),
    [sym_try_expression] = STATE(8117),
    [sym_let_expression] = STATE(8117),
    [sym_coercion_expression] = STATE(7067),
    [sym_assert_expression] = STATE(8117),
    [sym_lazy_expression] = STATE(8117),
    [sym_let_module_expression] = STATE(8117),
    [sym_let_open_expression] = STATE(8117),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_let_exception_expression] = STATE(8117),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2410),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym_sign_operator] = STATE(2397),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__instance_variable_name] = STATE(18043),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [sym__lowercase_identifier] = ACTIONS(2691),
    [anon_sym_let] = ACTIONS(2693),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_fun] = ACTIONS(2705),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_if] = ACTIONS(2709),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(935),
    [anon_sym_match] = ACTIONS(2711),
    [anon_sym_function] = ACTIONS(2713),
    [anon_sym_try] = ACTIONS(2715),
    [anon_sym_assert] = ACTIONS(943),
    [anon_sym_lazy] = ACTIONS(945),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(103),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(111),
    [sym_let_operator] = ACTIONS(347),
    [sym_match_operator] = ACTIONS(2737),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2411] = {
    [sym__simple_expression] = STATE(3797),
    [sym_typed_expression] = STATE(3838),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_labeled_argument] = STATE(4506),
    [sym_prefix_expression] = STATE(3838),
    [sym_hash_expression] = STATE(3838),
    [sym_field_get_expression] = STATE(3838),
    [sym_array_get_expression] = STATE(3838),
    [sym_string_get_expression] = STATE(3838),
    [sym_bigarray_get_expression] = STATE(3838),
    [sym_coercion_expression] = STATE(3838),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(2411),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [aux_sym_class_application_repeat1] = STATE(2411),
    [sym__lowercase_identifier] = ACTIONS(4215),
    [anon_sym_SEMI_SEMI] = ACTIONS(3720),
    [anon_sym_let] = ACTIONS(3722),
    [anon_sym_and] = ACTIONS(3722),
    [anon_sym_TILDE] = ACTIONS(4218),
    [anon_sym_QMARK] = ACTIONS(4218),
    [anon_sym_LPAREN] = ACTIONS(4221),
    [anon_sym_external] = ACTIONS(3722),
    [anon_sym_type] = ACTIONS(3722),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(4224),
    [anon_sym_true] = ACTIONS(4227),
    [anon_sym_false] = ACTIONS(4227),
    [anon_sym_LBRACE] = ACTIONS(4230),
    [anon_sym_SEMI] = ACTIONS(3722),
    [anon_sym_exception] = ACTIONS(3722),
    [anon_sym_module] = ACTIONS(3722),
    [anon_sym_open] = ACTIONS(3722),
    [anon_sym_include] = ACTIONS(3722),
    [anon_sym_class] = ACTIONS(3722),
    [anon_sym_end] = ACTIONS(3722),
    [anon_sym_object] = ACTIONS(4233),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4236),
    [anon_sym_new] = ACTIONS(4239),
    [anon_sym_LBRACE_LT] = ACTIONS(4242),
    [anon_sym_begin] = ACTIONS(4245),
    [sym_ocamlyacc_value] = ACTIONS(4248),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3722),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3720),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4251),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4254),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3720),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3720),
    [aux_sym_number_token1] = ACTIONS(4257),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(4260),
    [anon_sym_DQUOTE] = ACTIONS(4263),
    [sym_prefix_operator] = ACTIONS(4266),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym_let_operator] = ACTIONS(3720),
    [sym_let_and_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(4269),
    [aux_sym_directive_token1] = ACTIONS(3720),
    [aux_sym_tag_token1] = ACTIONS(4272),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2412] = {
    [sym__simple_expression] = STATE(3859),
    [sym_typed_expression] = STATE(3957),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_labeled_argument] = STATE(4546),
    [sym_prefix_expression] = STATE(3957),
    [sym_hash_expression] = STATE(3957),
    [sym_field_get_expression] = STATE(3957),
    [sym_array_get_expression] = STATE(3957),
    [sym_string_get_expression] = STATE(3957),
    [sym_bigarray_get_expression] = STATE(3957),
    [sym_coercion_expression] = STATE(3957),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(2412),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [aux_sym_class_application_repeat1] = STATE(2412),
    [sym__lowercase_identifier] = ACTIONS(4275),
    [anon_sym_SEMI_SEMI] = ACTIONS(3720),
    [anon_sym_let] = ACTIONS(3722),
    [anon_sym_and] = ACTIONS(3722),
    [anon_sym_TILDE] = ACTIONS(4278),
    [anon_sym_QMARK] = ACTIONS(4278),
    [anon_sym_LPAREN] = ACTIONS(4281),
    [anon_sym_external] = ACTIONS(3722),
    [anon_sym_type] = ACTIONS(3722),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(4284),
    [anon_sym_RBRACK] = ACTIONS(3720),
    [anon_sym_true] = ACTIONS(4287),
    [anon_sym_false] = ACTIONS(4287),
    [anon_sym_LBRACE] = ACTIONS(4290),
    [anon_sym_SEMI] = ACTIONS(3722),
    [anon_sym_exception] = ACTIONS(3722),
    [anon_sym_module] = ACTIONS(3722),
    [anon_sym_open] = ACTIONS(3722),
    [anon_sym_include] = ACTIONS(3722),
    [anon_sym_class] = ACTIONS(3722),
    [anon_sym_object] = ACTIONS(4293),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4296),
    [anon_sym_new] = ACTIONS(4299),
    [anon_sym_LBRACE_LT] = ACTIONS(4302),
    [anon_sym_begin] = ACTIONS(4305),
    [sym_ocamlyacc_value] = ACTIONS(4308),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3722),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3720),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4311),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4314),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3720),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3720),
    [aux_sym_number_token1] = ACTIONS(4317),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(4320),
    [anon_sym_DQUOTE] = ACTIONS(4323),
    [sym_prefix_operator] = ACTIONS(4326),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym_let_operator] = ACTIONS(3720),
    [sym_let_and_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(4329),
    [aux_sym_directive_token1] = ACTIONS(3720),
    [aux_sym_tag_token1] = ACTIONS(4332),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2413] = {
    [sym__simple_expression] = STATE(3797),
    [sym_typed_expression] = STATE(3838),
    [sym_list_expression] = STATE(3838),
    [sym_array_expression] = STATE(3838),
    [sym_record_expression] = STATE(3838),
    [sym_labeled_argument] = STATE(4506),
    [sym_prefix_expression] = STATE(3838),
    [sym_hash_expression] = STATE(3838),
    [sym_field_get_expression] = STATE(3838),
    [sym_array_get_expression] = STATE(3838),
    [sym_string_get_expression] = STATE(3838),
    [sym_bigarray_get_expression] = STATE(3838),
    [sym_coercion_expression] = STATE(3838),
    [sym_local_open_expression] = STATE(3838),
    [sym_package_expression] = STATE(3838),
    [sym_new_expression] = STATE(3838),
    [sym_object_copy_expression] = STATE(3838),
    [sym_method_invocation] = STATE(3838),
    [sym_object_expression] = STATE(3838),
    [sym_parenthesized_expression] = STATE(3838),
    [sym_attribute] = STATE(2413),
    [sym_extension] = STATE(3838),
    [sym_quoted_extension] = STATE(3838),
    [sym__constant] = STATE(3838),
    [sym_number] = STATE(3778),
    [sym_character] = STATE(3778),
    [sym_string] = STATE(3778),
    [sym_quoted_string] = STATE(3778),
    [sym_boolean] = STATE(3778),
    [sym_unit] = STATE(3778),
    [sym__value_name] = STATE(3924),
    [sym_parenthesized_operator] = STATE(3791),
    [sym_value_path] = STATE(3838),
    [sym_module_path] = STATE(18444),
    [sym_constructor_path] = STATE(3838),
    [sym__constructor_name] = STATE(3777),
    [sym_tag] = STATE(3838),
    [aux_sym_class_application_repeat1] = STATE(2411),
    [sym__lowercase_identifier] = ACTIONS(3271),
    [anon_sym_SEMI_SEMI] = ACTIONS(3943),
    [anon_sym_let] = ACTIONS(3945),
    [anon_sym_and] = ACTIONS(3945),
    [anon_sym_TILDE] = ACTIONS(3273),
    [anon_sym_QMARK] = ACTIONS(3273),
    [anon_sym_LPAREN] = ACTIONS(757),
    [anon_sym_external] = ACTIONS(3945),
    [anon_sym_type] = ACTIONS(3945),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_SEMI] = ACTIONS(3945),
    [anon_sym_exception] = ACTIONS(3945),
    [anon_sym_module] = ACTIONS(3945),
    [anon_sym_open] = ACTIONS(3945),
    [anon_sym_include] = ACTIONS(3945),
    [anon_sym_class] = ACTIONS(3945),
    [anon_sym_end] = ACTIONS(3945),
    [anon_sym_object] = ACTIONS(765),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(769),
    [anon_sym_new] = ACTIONS(779),
    [anon_sym_LBRACE_LT] = ACTIONS(781),
    [anon_sym_begin] = ACTIONS(783),
    [sym_ocamlyacc_value] = ACTIONS(785),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3945),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3943),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(787),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(789),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3943),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3943),
    [aux_sym_number_token1] = ACTIONS(791),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [sym_prefix_operator] = ACTIONS(797),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym_let_operator] = ACTIONS(3943),
    [sym_let_and_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(801),
    [aux_sym_directive_token1] = ACTIONS(3943),
    [aux_sym_tag_token1] = ACTIONS(803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2414] = {
    [sym__simple_expression] = STATE(3859),
    [sym_typed_expression] = STATE(3957),
    [sym_list_expression] = STATE(3957),
    [sym_array_expression] = STATE(3957),
    [sym_record_expression] = STATE(3957),
    [sym_labeled_argument] = STATE(4546),
    [sym_prefix_expression] = STATE(3957),
    [sym_hash_expression] = STATE(3957),
    [sym_field_get_expression] = STATE(3957),
    [sym_array_get_expression] = STATE(3957),
    [sym_string_get_expression] = STATE(3957),
    [sym_bigarray_get_expression] = STATE(3957),
    [sym_coercion_expression] = STATE(3957),
    [sym_local_open_expression] = STATE(3957),
    [sym_package_expression] = STATE(3957),
    [sym_new_expression] = STATE(3957),
    [sym_object_copy_expression] = STATE(3957),
    [sym_method_invocation] = STATE(3957),
    [sym_object_expression] = STATE(3957),
    [sym_parenthesized_expression] = STATE(3957),
    [sym_attribute] = STATE(2414),
    [sym_extension] = STATE(3957),
    [sym_quoted_extension] = STATE(3957),
    [sym__constant] = STATE(3957),
    [sym_number] = STATE(3886),
    [sym_character] = STATE(3886),
    [sym_string] = STATE(3886),
    [sym_quoted_string] = STATE(3886),
    [sym_boolean] = STATE(3886),
    [sym_unit] = STATE(3886),
    [sym__value_name] = STATE(3913),
    [sym_parenthesized_operator] = STATE(3822),
    [sym_value_path] = STATE(3957),
    [sym_module_path] = STATE(18364),
    [sym_constructor_path] = STATE(3957),
    [sym__constructor_name] = STATE(3881),
    [sym_tag] = STATE(3957),
    [aux_sym_class_application_repeat1] = STATE(2412),
    [sym__lowercase_identifier] = ACTIONS(3281),
    [anon_sym_SEMI_SEMI] = ACTIONS(3943),
    [anon_sym_let] = ACTIONS(3945),
    [anon_sym_and] = ACTIONS(3945),
    [anon_sym_TILDE] = ACTIONS(3283),
    [anon_sym_QMARK] = ACTIONS(3283),
    [anon_sym_LPAREN] = ACTIONS(693),
    [anon_sym_external] = ACTIONS(3945),
    [anon_sym_type] = ACTIONS(3945),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_RBRACK] = ACTIONS(3943),
    [anon_sym_true] = ACTIONS(697),
    [anon_sym_false] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_SEMI] = ACTIONS(3945),
    [anon_sym_exception] = ACTIONS(3945),
    [anon_sym_module] = ACTIONS(3945),
    [anon_sym_open] = ACTIONS(3945),
    [anon_sym_include] = ACTIONS(3945),
    [anon_sym_class] = ACTIONS(3945),
    [anon_sym_object] = ACTIONS(701),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(705),
    [anon_sym_new] = ACTIONS(715),
    [anon_sym_LBRACE_LT] = ACTIONS(717),
    [anon_sym_begin] = ACTIONS(719),
    [sym_ocamlyacc_value] = ACTIONS(721),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3945),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3943),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(723),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(725),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3943),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3943),
    [aux_sym_number_token1] = ACTIONS(727),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(731),
    [sym_prefix_operator] = ACTIONS(733),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym_let_operator] = ACTIONS(3943),
    [sym_let_and_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(737),
    [aux_sym_directive_token1] = ACTIONS(3943),
    [aux_sym_tag_token1] = ACTIONS(739),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2415] = {
    [sym__simple_expression] = STATE(4094),
    [sym_typed_expression] = STATE(4041),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_labeled_argument] = STATE(4575),
    [sym_prefix_expression] = STATE(4041),
    [sym_hash_expression] = STATE(4041),
    [sym_field_get_expression] = STATE(4041),
    [sym_array_get_expression] = STATE(4041),
    [sym_string_get_expression] = STATE(4041),
    [sym_bigarray_get_expression] = STATE(4041),
    [sym_coercion_expression] = STATE(4041),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(2415),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [aux_sym_class_application_repeat1] = STATE(2417),
    [sym__lowercase_identifier] = ACTIONS(3445),
    [anon_sym_SEMI_SEMI] = ACTIONS(3943),
    [anon_sym_let] = ACTIONS(3945),
    [anon_sym_TILDE] = ACTIONS(3447),
    [anon_sym_QMARK] = ACTIONS(3447),
    [anon_sym_LPAREN] = ACTIONS(861),
    [anon_sym_external] = ACTIONS(3945),
    [anon_sym_type] = ACTIONS(3945),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(863),
    [anon_sym_RBRACK] = ACTIONS(3943),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_SEMI] = ACTIONS(3945),
    [anon_sym_exception] = ACTIONS(3945),
    [anon_sym_module] = ACTIONS(3945),
    [anon_sym_open] = ACTIONS(3945),
    [anon_sym_include] = ACTIONS(3945),
    [anon_sym_class] = ACTIONS(3945),
    [anon_sym_object] = ACTIONS(869),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(873),
    [anon_sym_else] = ACTIONS(3945),
    [anon_sym_new] = ACTIONS(883),
    [anon_sym_LBRACE_LT] = ACTIONS(885),
    [anon_sym_begin] = ACTIONS(887),
    [sym_ocamlyacc_value] = ACTIONS(889),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3945),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3943),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(891),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(893),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3943),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3943),
    [aux_sym_number_token1] = ACTIONS(895),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE] = ACTIONS(899),
    [sym_prefix_operator] = ACTIONS(901),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym_let_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(905),
    [aux_sym_directive_token1] = ACTIONS(3943),
    [aux_sym_tag_token1] = ACTIONS(907),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2416] = {
    [sym__simple_expression] = STATE(4053),
    [sym_typed_expression] = STATE(4161),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_labeled_argument] = STATE(4613),
    [sym_prefix_expression] = STATE(4161),
    [sym_hash_expression] = STATE(4161),
    [sym_field_get_expression] = STATE(4161),
    [sym_array_get_expression] = STATE(4161),
    [sym_string_get_expression] = STATE(4161),
    [sym_bigarray_get_expression] = STATE(4161),
    [sym_coercion_expression] = STATE(4161),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(2416),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [aux_sym_class_application_repeat1] = STATE(2416),
    [sym__lowercase_identifier] = ACTIONS(4335),
    [anon_sym_SEMI_SEMI] = ACTIONS(3720),
    [anon_sym_let] = ACTIONS(3722),
    [anon_sym_TILDE] = ACTIONS(4338),
    [anon_sym_QMARK] = ACTIONS(4338),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_external] = ACTIONS(3722),
    [anon_sym_type] = ACTIONS(3722),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(4344),
    [anon_sym_true] = ACTIONS(4347),
    [anon_sym_false] = ACTIONS(4347),
    [anon_sym_LBRACE] = ACTIONS(4350),
    [anon_sym_SEMI] = ACTIONS(3722),
    [anon_sym_exception] = ACTIONS(3722),
    [anon_sym_module] = ACTIONS(3722),
    [anon_sym_open] = ACTIONS(3722),
    [anon_sym_include] = ACTIONS(3722),
    [anon_sym_class] = ACTIONS(3722),
    [anon_sym_end] = ACTIONS(3722),
    [anon_sym_object] = ACTIONS(4353),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4356),
    [anon_sym_else] = ACTIONS(3722),
    [anon_sym_new] = ACTIONS(4359),
    [anon_sym_LBRACE_LT] = ACTIONS(4362),
    [anon_sym_begin] = ACTIONS(4365),
    [sym_ocamlyacc_value] = ACTIONS(4368),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3722),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3720),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4374),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3720),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3720),
    [aux_sym_number_token1] = ACTIONS(4377),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(4380),
    [anon_sym_DQUOTE] = ACTIONS(4383),
    [sym_prefix_operator] = ACTIONS(4386),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym_let_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(4389),
    [aux_sym_directive_token1] = ACTIONS(3720),
    [aux_sym_tag_token1] = ACTIONS(4392),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2417] = {
    [sym__simple_expression] = STATE(4094),
    [sym_typed_expression] = STATE(4041),
    [sym_list_expression] = STATE(4041),
    [sym_array_expression] = STATE(4041),
    [sym_record_expression] = STATE(4041),
    [sym_labeled_argument] = STATE(4575),
    [sym_prefix_expression] = STATE(4041),
    [sym_hash_expression] = STATE(4041),
    [sym_field_get_expression] = STATE(4041),
    [sym_array_get_expression] = STATE(4041),
    [sym_string_get_expression] = STATE(4041),
    [sym_bigarray_get_expression] = STATE(4041),
    [sym_coercion_expression] = STATE(4041),
    [sym_local_open_expression] = STATE(4041),
    [sym_package_expression] = STATE(4041),
    [sym_new_expression] = STATE(4041),
    [sym_object_copy_expression] = STATE(4041),
    [sym_method_invocation] = STATE(4041),
    [sym_object_expression] = STATE(4041),
    [sym_parenthesized_expression] = STATE(4041),
    [sym_attribute] = STATE(2417),
    [sym_extension] = STATE(4041),
    [sym_quoted_extension] = STATE(4041),
    [sym__constant] = STATE(4041),
    [sym_number] = STATE(4047),
    [sym_character] = STATE(4047),
    [sym_string] = STATE(4047),
    [sym_quoted_string] = STATE(4047),
    [sym_boolean] = STATE(4047),
    [sym_unit] = STATE(4047),
    [sym__value_name] = STATE(4104),
    [sym_parenthesized_operator] = STATE(4160),
    [sym_value_path] = STATE(4041),
    [sym_module_path] = STATE(17631),
    [sym_constructor_path] = STATE(4041),
    [sym__constructor_name] = STATE(4054),
    [sym_tag] = STATE(4041),
    [aux_sym_class_application_repeat1] = STATE(2417),
    [sym__lowercase_identifier] = ACTIONS(4395),
    [anon_sym_SEMI_SEMI] = ACTIONS(3720),
    [anon_sym_let] = ACTIONS(3722),
    [anon_sym_TILDE] = ACTIONS(4398),
    [anon_sym_QMARK] = ACTIONS(4398),
    [anon_sym_LPAREN] = ACTIONS(4401),
    [anon_sym_external] = ACTIONS(3722),
    [anon_sym_type] = ACTIONS(3722),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(4404),
    [anon_sym_RBRACK] = ACTIONS(3720),
    [anon_sym_true] = ACTIONS(4407),
    [anon_sym_false] = ACTIONS(4407),
    [anon_sym_LBRACE] = ACTIONS(4410),
    [anon_sym_SEMI] = ACTIONS(3722),
    [anon_sym_exception] = ACTIONS(3722),
    [anon_sym_module] = ACTIONS(3722),
    [anon_sym_open] = ACTIONS(3722),
    [anon_sym_include] = ACTIONS(3722),
    [anon_sym_class] = ACTIONS(3722),
    [anon_sym_object] = ACTIONS(4413),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4416),
    [anon_sym_else] = ACTIONS(3722),
    [anon_sym_new] = ACTIONS(4419),
    [anon_sym_LBRACE_LT] = ACTIONS(4422),
    [anon_sym_begin] = ACTIONS(4425),
    [sym_ocamlyacc_value] = ACTIONS(4428),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3722),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3720),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4431),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4434),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3720),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3720),
    [aux_sym_number_token1] = ACTIONS(4437),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(4440),
    [anon_sym_DQUOTE] = ACTIONS(4443),
    [sym_prefix_operator] = ACTIONS(4446),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym_let_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(4449),
    [aux_sym_directive_token1] = ACTIONS(3720),
    [aux_sym_tag_token1] = ACTIONS(4452),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2418] = {
    [sym__simple_expression] = STATE(4053),
    [sym_typed_expression] = STATE(4161),
    [sym_list_expression] = STATE(4161),
    [sym_array_expression] = STATE(4161),
    [sym_record_expression] = STATE(4161),
    [sym_labeled_argument] = STATE(4613),
    [sym_prefix_expression] = STATE(4161),
    [sym_hash_expression] = STATE(4161),
    [sym_field_get_expression] = STATE(4161),
    [sym_array_get_expression] = STATE(4161),
    [sym_string_get_expression] = STATE(4161),
    [sym_bigarray_get_expression] = STATE(4161),
    [sym_coercion_expression] = STATE(4161),
    [sym_local_open_expression] = STATE(4161),
    [sym_package_expression] = STATE(4161),
    [sym_new_expression] = STATE(4161),
    [sym_object_copy_expression] = STATE(4161),
    [sym_method_invocation] = STATE(4161),
    [sym_object_expression] = STATE(4161),
    [sym_parenthesized_expression] = STATE(4161),
    [sym_attribute] = STATE(2418),
    [sym_extension] = STATE(4161),
    [sym_quoted_extension] = STATE(4161),
    [sym__constant] = STATE(4161),
    [sym_number] = STATE(3977),
    [sym_character] = STATE(3977),
    [sym_string] = STATE(3977),
    [sym_quoted_string] = STATE(3977),
    [sym_boolean] = STATE(3977),
    [sym_unit] = STATE(3977),
    [sym__value_name] = STATE(4164),
    [sym_parenthesized_operator] = STATE(3972),
    [sym_value_path] = STATE(4161),
    [sym_module_path] = STATE(17840),
    [sym_constructor_path] = STATE(4161),
    [sym__constructor_name] = STATE(3979),
    [sym_tag] = STATE(4161),
    [aux_sym_class_application_repeat1] = STATE(2416),
    [sym__lowercase_identifier] = ACTIONS(3327),
    [anon_sym_SEMI_SEMI] = ACTIONS(3943),
    [anon_sym_let] = ACTIONS(3945),
    [anon_sym_TILDE] = ACTIONS(3329),
    [anon_sym_QMARK] = ACTIONS(3329),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_external] = ACTIONS(3945),
    [anon_sym_type] = ACTIONS(3945),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_SEMI] = ACTIONS(3945),
    [anon_sym_exception] = ACTIONS(3945),
    [anon_sym_module] = ACTIONS(3945),
    [anon_sym_open] = ACTIONS(3945),
    [anon_sym_include] = ACTIONS(3945),
    [anon_sym_class] = ACTIONS(3945),
    [anon_sym_end] = ACTIONS(3945),
    [anon_sym_object] = ACTIONS(817),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(821),
    [anon_sym_else] = ACTIONS(3945),
    [anon_sym_new] = ACTIONS(831),
    [anon_sym_LBRACE_LT] = ACTIONS(833),
    [anon_sym_begin] = ACTIONS(835),
    [sym_ocamlyacc_value] = ACTIONS(837),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3945),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3943),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(839),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(841),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3943),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3943),
    [aux_sym_number_token1] = ACTIONS(843),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE] = ACTIONS(847),
    [sym_prefix_operator] = ACTIONS(849),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym_let_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(853),
    [aux_sym_directive_token1] = ACTIONS(3943),
    [aux_sym_tag_token1] = ACTIONS(855),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2419] = {
    [sym__simple_expression] = STATE(4403),
    [sym_typed_expression] = STATE(4315),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_labeled_argument] = STATE(4649),
    [sym_prefix_expression] = STATE(4315),
    [sym_hash_expression] = STATE(4315),
    [sym_field_get_expression] = STATE(4315),
    [sym_array_get_expression] = STATE(4315),
    [sym_string_get_expression] = STATE(4315),
    [sym_bigarray_get_expression] = STATE(4315),
    [sym_coercion_expression] = STATE(4315),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(2419),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [aux_sym_class_application_repeat1] = STATE(2422),
    [sym__lowercase_identifier] = ACTIONS(4145),
    [anon_sym_SEMI_SEMI] = ACTIONS(3943),
    [anon_sym_let] = ACTIONS(3945),
    [anon_sym_TILDE] = ACTIONS(4147),
    [anon_sym_QMARK] = ACTIONS(4147),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_external] = ACTIONS(3945),
    [anon_sym_type] = ACTIONS(3945),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(47),
    [anon_sym_RBRACK] = ACTIONS(3943),
    [anon_sym_true] = ACTIONS(51),
    [anon_sym_false] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(3945),
    [anon_sym_exception] = ACTIONS(3945),
    [anon_sym_module] = ACTIONS(3945),
    [anon_sym_open] = ACTIONS(3945),
    [anon_sym_include] = ACTIONS(3945),
    [anon_sym_class] = ACTIONS(3945),
    [anon_sym_object] = ACTIONS(67),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(89),
    [anon_sym_LBRACE_LT] = ACTIONS(91),
    [anon_sym_begin] = ACTIONS(93),
    [sym_ocamlyacc_value] = ACTIONS(95),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3945),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3943),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(97),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3943),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3943),
    [aux_sym_number_token1] = ACTIONS(101),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_prefix_operator] = ACTIONS(109),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym_let_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(117),
    [aux_sym_directive_token1] = ACTIONS(3943),
    [aux_sym_tag_token1] = ACTIONS(121),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2420] = {
    [sym__simple_expression] = STATE(4429),
    [sym_typed_expression] = STATE(4413),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_labeled_argument] = STATE(4638),
    [sym_prefix_expression] = STATE(4413),
    [sym_hash_expression] = STATE(4413),
    [sym_field_get_expression] = STATE(4413),
    [sym_array_get_expression] = STATE(4413),
    [sym_string_get_expression] = STATE(4413),
    [sym_bigarray_get_expression] = STATE(4413),
    [sym_coercion_expression] = STATE(4413),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(2420),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [aux_sym_class_application_repeat1] = STATE(2421),
    [sym__lowercase_identifier] = ACTIONS(3955),
    [anon_sym_SEMI_SEMI] = ACTIONS(3943),
    [anon_sym_let] = ACTIONS(3945),
    [anon_sym_TILDE] = ACTIONS(3957),
    [anon_sym_QMARK] = ACTIONS(3957),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_external] = ACTIONS(3945),
    [anon_sym_type] = ACTIONS(3945),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(417),
    [anon_sym_true] = ACTIONS(419),
    [anon_sym_false] = ACTIONS(419),
    [anon_sym_LBRACE] = ACTIONS(421),
    [anon_sym_SEMI] = ACTIONS(3945),
    [anon_sym_exception] = ACTIONS(3945),
    [anon_sym_module] = ACTIONS(3945),
    [anon_sym_open] = ACTIONS(3945),
    [anon_sym_include] = ACTIONS(3945),
    [anon_sym_class] = ACTIONS(3945),
    [anon_sym_end] = ACTIONS(3945),
    [anon_sym_object] = ACTIONS(431),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(435),
    [anon_sym_new] = ACTIONS(445),
    [anon_sym_LBRACE_LT] = ACTIONS(447),
    [anon_sym_begin] = ACTIONS(449),
    [sym_ocamlyacc_value] = ACTIONS(451),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3945),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3943),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(453),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(455),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3943),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3943),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(459),
    [anon_sym_DQUOTE] = ACTIONS(461),
    [sym_prefix_operator] = ACTIONS(463),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym_let_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(469),
    [aux_sym_directive_token1] = ACTIONS(3943),
    [aux_sym_tag_token1] = ACTIONS(473),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2421] = {
    [sym__simple_expression] = STATE(4429),
    [sym_typed_expression] = STATE(4413),
    [sym_list_expression] = STATE(4413),
    [sym_array_expression] = STATE(4413),
    [sym_record_expression] = STATE(4413),
    [sym_labeled_argument] = STATE(4638),
    [sym_prefix_expression] = STATE(4413),
    [sym_hash_expression] = STATE(4413),
    [sym_field_get_expression] = STATE(4413),
    [sym_array_get_expression] = STATE(4413),
    [sym_string_get_expression] = STATE(4413),
    [sym_bigarray_get_expression] = STATE(4413),
    [sym_coercion_expression] = STATE(4413),
    [sym_local_open_expression] = STATE(4413),
    [sym_package_expression] = STATE(4413),
    [sym_new_expression] = STATE(4413),
    [sym_object_copy_expression] = STATE(4413),
    [sym_method_invocation] = STATE(4413),
    [sym_object_expression] = STATE(4413),
    [sym_parenthesized_expression] = STATE(4413),
    [sym_attribute] = STATE(2421),
    [sym_extension] = STATE(4413),
    [sym_quoted_extension] = STATE(4413),
    [sym__constant] = STATE(4413),
    [sym_number] = STATE(4219),
    [sym_character] = STATE(4219),
    [sym_string] = STATE(4219),
    [sym_quoted_string] = STATE(4219),
    [sym_boolean] = STATE(4219),
    [sym_unit] = STATE(4219),
    [sym__value_name] = STATE(4287),
    [sym_parenthesized_operator] = STATE(4279),
    [sym_value_path] = STATE(4413),
    [sym_module_path] = STATE(20400),
    [sym_constructor_path] = STATE(4413),
    [sym__constructor_name] = STATE(4480),
    [sym_tag] = STATE(4413),
    [aux_sym_class_application_repeat1] = STATE(2421),
    [sym__lowercase_identifier] = ACTIONS(4455),
    [anon_sym_SEMI_SEMI] = ACTIONS(3720),
    [anon_sym_let] = ACTIONS(3722),
    [anon_sym_TILDE] = ACTIONS(4458),
    [anon_sym_QMARK] = ACTIONS(4458),
    [anon_sym_LPAREN] = ACTIONS(4461),
    [anon_sym_external] = ACTIONS(3722),
    [anon_sym_type] = ACTIONS(3722),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(4464),
    [anon_sym_true] = ACTIONS(4467),
    [anon_sym_false] = ACTIONS(4467),
    [anon_sym_LBRACE] = ACTIONS(4470),
    [anon_sym_SEMI] = ACTIONS(3722),
    [anon_sym_exception] = ACTIONS(3722),
    [anon_sym_module] = ACTIONS(3722),
    [anon_sym_open] = ACTIONS(3722),
    [anon_sym_include] = ACTIONS(3722),
    [anon_sym_class] = ACTIONS(3722),
    [anon_sym_end] = ACTIONS(3722),
    [anon_sym_object] = ACTIONS(4473),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4476),
    [anon_sym_new] = ACTIONS(4479),
    [anon_sym_LBRACE_LT] = ACTIONS(4482),
    [anon_sym_begin] = ACTIONS(4485),
    [sym_ocamlyacc_value] = ACTIONS(4488),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3722),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3720),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4491),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4494),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3720),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3720),
    [aux_sym_number_token1] = ACTIONS(4497),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(4500),
    [anon_sym_DQUOTE] = ACTIONS(4503),
    [sym_prefix_operator] = ACTIONS(4506),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym_let_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(4509),
    [aux_sym_directive_token1] = ACTIONS(3720),
    [aux_sym_tag_token1] = ACTIONS(4512),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2422] = {
    [sym__simple_expression] = STATE(4403),
    [sym_typed_expression] = STATE(4315),
    [sym_list_expression] = STATE(4315),
    [sym_array_expression] = STATE(4315),
    [sym_record_expression] = STATE(4315),
    [sym_labeled_argument] = STATE(4649),
    [sym_prefix_expression] = STATE(4315),
    [sym_hash_expression] = STATE(4315),
    [sym_field_get_expression] = STATE(4315),
    [sym_array_get_expression] = STATE(4315),
    [sym_string_get_expression] = STATE(4315),
    [sym_bigarray_get_expression] = STATE(4315),
    [sym_coercion_expression] = STATE(4315),
    [sym_local_open_expression] = STATE(4315),
    [sym_package_expression] = STATE(4315),
    [sym_new_expression] = STATE(4315),
    [sym_object_copy_expression] = STATE(4315),
    [sym_method_invocation] = STATE(4315),
    [sym_object_expression] = STATE(4315),
    [sym_parenthesized_expression] = STATE(4315),
    [sym_attribute] = STATE(2422),
    [sym_extension] = STATE(4315),
    [sym_quoted_extension] = STATE(4315),
    [sym__constant] = STATE(4315),
    [sym_number] = STATE(4466),
    [sym_character] = STATE(4466),
    [sym_string] = STATE(4466),
    [sym_quoted_string] = STATE(4466),
    [sym_boolean] = STATE(4466),
    [sym_unit] = STATE(4466),
    [sym__value_name] = STATE(4454),
    [sym_parenthesized_operator] = STATE(4302),
    [sym_value_path] = STATE(4315),
    [sym_module_path] = STATE(20480),
    [sym_constructor_path] = STATE(4315),
    [sym__constructor_name] = STATE(4257),
    [sym_tag] = STATE(4315),
    [aux_sym_class_application_repeat1] = STATE(2422),
    [sym__lowercase_identifier] = ACTIONS(4515),
    [anon_sym_SEMI_SEMI] = ACTIONS(3720),
    [anon_sym_let] = ACTIONS(3722),
    [anon_sym_TILDE] = ACTIONS(4518),
    [anon_sym_QMARK] = ACTIONS(4518),
    [anon_sym_LPAREN] = ACTIONS(4521),
    [anon_sym_external] = ACTIONS(3722),
    [anon_sym_type] = ACTIONS(3722),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(4524),
    [anon_sym_RBRACK] = ACTIONS(3720),
    [anon_sym_true] = ACTIONS(4527),
    [anon_sym_false] = ACTIONS(4527),
    [anon_sym_LBRACE] = ACTIONS(4530),
    [anon_sym_SEMI] = ACTIONS(3722),
    [anon_sym_exception] = ACTIONS(3722),
    [anon_sym_module] = ACTIONS(3722),
    [anon_sym_open] = ACTIONS(3722),
    [anon_sym_include] = ACTIONS(3722),
    [anon_sym_class] = ACTIONS(3722),
    [anon_sym_object] = ACTIONS(4533),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4536),
    [anon_sym_new] = ACTIONS(4539),
    [anon_sym_LBRACE_LT] = ACTIONS(4542),
    [anon_sym_begin] = ACTIONS(4545),
    [sym_ocamlyacc_value] = ACTIONS(4548),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3722),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3720),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4554),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3720),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3720),
    [aux_sym_number_token1] = ACTIONS(4557),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(4560),
    [anon_sym_DQUOTE] = ACTIONS(4563),
    [sym_prefix_operator] = ACTIONS(4566),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym_let_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(4569),
    [aux_sym_directive_token1] = ACTIONS(3720),
    [aux_sym_tag_token1] = ACTIONS(4572),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2423] = {
    [sym__simple_expression] = STATE(4877),
    [sym_typed_expression] = STATE(4865),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_labeled_argument] = STATE(5294),
    [sym_prefix_expression] = STATE(4865),
    [sym_hash_expression] = STATE(4865),
    [sym_field_get_expression] = STATE(4865),
    [sym_array_get_expression] = STATE(4865),
    [sym_string_get_expression] = STATE(4865),
    [sym_bigarray_get_expression] = STATE(4865),
    [sym_coercion_expression] = STATE(4865),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(2423),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [aux_sym_class_application_repeat1] = STATE(2426),
    [sym__lowercase_identifier] = ACTIONS(4575),
    [anon_sym_TILDE] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4577),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_DOT] = ACTIONS(4579),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_SEMI] = ACTIONS(3051),
    [anon_sym_constraint] = ACTIONS(3053),
    [anon_sym_val] = ACTIONS(3053),
    [anon_sym_end] = ACTIONS(3053),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_inherit] = ACTIONS(3053),
    [anon_sym_method] = ACTIONS(3053),
    [anon_sym_initializer] = ACTIONS(3053),
    [anon_sym_POUND] = ACTIONS(4581),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_else] = ACTIONS(3053),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3053),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3051),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(955),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(957),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3051),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(4583),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2424] = {
    [sym__simple_expression] = STATE(4912),
    [sym_typed_expression] = STATE(4984),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_labeled_argument] = STATE(5344),
    [sym_prefix_expression] = STATE(4984),
    [sym_hash_expression] = STATE(4984),
    [sym_field_get_expression] = STATE(4984),
    [sym_array_get_expression] = STATE(4984),
    [sym_string_get_expression] = STATE(4984),
    [sym_bigarray_get_expression] = STATE(4984),
    [sym_coercion_expression] = STATE(4984),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2424),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [aux_sym_class_application_repeat1] = STATE(2431),
    [sym__lowercase_identifier] = ACTIONS(4585),
    [anon_sym_TILDE] = ACTIONS(4587),
    [anon_sym_QMARK] = ACTIONS(4587),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_DOT] = ACTIONS(4589),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_SEMI] = ACTIONS(3051),
    [anon_sym_constraint] = ACTIONS(3053),
    [anon_sym_val] = ACTIONS(3053),
    [anon_sym_end] = ACTIONS(3053),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_inherit] = ACTIONS(3053),
    [anon_sym_method] = ACTIONS(3053),
    [anon_sym_initializer] = ACTIONS(3053),
    [anon_sym_POUND] = ACTIONS(4591),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3053),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3051),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1029),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1031),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3051),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(4593),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2425] = {
    [sym__simple_expression] = STATE(5030),
    [sym_typed_expression] = STATE(5003),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_labeled_argument] = STATE(5463),
    [sym_prefix_expression] = STATE(5003),
    [sym_hash_expression] = STATE(5003),
    [sym_field_get_expression] = STATE(5003),
    [sym_array_get_expression] = STATE(5003),
    [sym_string_get_expression] = STATE(5003),
    [sym_bigarray_get_expression] = STATE(5003),
    [sym_coercion_expression] = STATE(5003),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(2425),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [aux_sym_class_application_repeat1] = STATE(2433),
    [sym__lowercase_identifier] = ACTIONS(4595),
    [anon_sym_COLON_GT] = ACTIONS(3051),
    [anon_sym_TILDE] = ACTIONS(4597),
    [anon_sym_QMARK] = ACTIONS(4597),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_RPAREN] = ACTIONS(3051),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_RBRACK] = ACTIONS(3051),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_COLON2] = ACTIONS(3053),
    [anon_sym_DOT] = ACTIONS(4599),
    [anon_sym_DASH_GT] = ACTIONS(3053),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_SEMI] = ACTIONS(3051),
    [anon_sym_RBRACE] = ACTIONS(3051),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_POUND] = ACTIONS(4601),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3051),
    [anon_sym_else] = ACTIONS(3053),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_GT_RBRACE] = ACTIONS(3051),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(4603),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2426] = {
    [sym__simple_expression] = STATE(4877),
    [sym_typed_expression] = STATE(4865),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_labeled_argument] = STATE(5294),
    [sym_prefix_expression] = STATE(4865),
    [sym_hash_expression] = STATE(4865),
    [sym_field_get_expression] = STATE(4865),
    [sym_array_get_expression] = STATE(4865),
    [sym_string_get_expression] = STATE(4865),
    [sym_bigarray_get_expression] = STATE(4865),
    [sym_coercion_expression] = STATE(4865),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(2426),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [aux_sym_class_application_repeat1] = STATE(2429),
    [sym__lowercase_identifier] = ACTIONS(4575),
    [anon_sym_TILDE] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4577),
    [anon_sym_LPAREN] = ACTIONS(917),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_SEMI] = ACTIONS(3943),
    [anon_sym_constraint] = ACTIONS(3945),
    [anon_sym_val] = ACTIONS(3945),
    [anon_sym_end] = ACTIONS(3945),
    [anon_sym_object] = ACTIONS(925),
    [anon_sym_inherit] = ACTIONS(3945),
    [anon_sym_method] = ACTIONS(3945),
    [anon_sym_initializer] = ACTIONS(3945),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(929),
    [anon_sym_else] = ACTIONS(3945),
    [anon_sym_new] = ACTIONS(947),
    [anon_sym_LBRACE_LT] = ACTIONS(949),
    [anon_sym_begin] = ACTIONS(951),
    [sym_ocamlyacc_value] = ACTIONS(953),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3945),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3943),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(955),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(957),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3943),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3943),
    [aux_sym_number_token1] = ACTIONS(959),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [sym_prefix_operator] = ACTIONS(965),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(969),
    [aux_sym_tag_token1] = ACTIONS(971),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2427] = {
    [sym__simple_expression] = STATE(5199),
    [sym_typed_expression] = STATE(5299),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_labeled_argument] = STATE(5582),
    [sym_prefix_expression] = STATE(5299),
    [sym_hash_expression] = STATE(5299),
    [sym_field_get_expression] = STATE(5299),
    [sym_array_get_expression] = STATE(5299),
    [sym_string_get_expression] = STATE(5299),
    [sym_bigarray_get_expression] = STATE(5299),
    [sym_coercion_expression] = STATE(5299),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2427),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [aux_sym_class_application_repeat1] = STATE(2439),
    [sym__lowercase_identifier] = ACTIONS(4605),
    [anon_sym_COLON_GT] = ACTIONS(3051),
    [anon_sym_TILDE] = ACTIONS(4607),
    [anon_sym_QMARK] = ACTIONS(4607),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(3051),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3051),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_COLON2] = ACTIONS(3053),
    [anon_sym_DOT] = ACTIONS(4609),
    [anon_sym_DASH_GT] = ACTIONS(3053),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_SEMI] = ACTIONS(3051),
    [anon_sym_RBRACE] = ACTIONS(3051),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_POUND] = ACTIONS(4611),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3051),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_GT_RBRACE] = ACTIONS(3051),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(4613),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2428] = {
    [sym__simple_expression] = STATE(5244),
    [sym_typed_expression] = STATE(5216),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_labeled_argument] = STATE(5573),
    [sym_prefix_expression] = STATE(5216),
    [sym_hash_expression] = STATE(5216),
    [sym_field_get_expression] = STATE(5216),
    [sym_array_get_expression] = STATE(5216),
    [sym_string_get_expression] = STATE(5216),
    [sym_bigarray_get_expression] = STATE(5216),
    [sym_coercion_expression] = STATE(5216),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(2428),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [aux_sym_class_application_repeat1] = STATE(2436),
    [sym__lowercase_identifier] = ACTIONS(4615),
    [anon_sym_COLON_GT] = ACTIONS(3051),
    [anon_sym_TILDE] = ACTIONS(4617),
    [anon_sym_QMARK] = ACTIONS(4617),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_RPAREN] = ACTIONS(3051),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_RBRACK] = ACTIONS(3051),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_COLON2] = ACTIONS(3053),
    [anon_sym_DOT] = ACTIONS(4619),
    [anon_sym_DASH_GT] = ACTIONS(3053),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_SEMI] = ACTIONS(3051),
    [anon_sym_RBRACE] = ACTIONS(3051),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_POUND] = ACTIONS(4621),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_else] = ACTIONS(3053),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_GT_RBRACE] = ACTIONS(3051),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(4623),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2429] = {
    [sym__simple_expression] = STATE(4877),
    [sym_typed_expression] = STATE(4865),
    [sym_list_expression] = STATE(4865),
    [sym_array_expression] = STATE(4865),
    [sym_record_expression] = STATE(4865),
    [sym_labeled_argument] = STATE(5294),
    [sym_prefix_expression] = STATE(4865),
    [sym_hash_expression] = STATE(4865),
    [sym_field_get_expression] = STATE(4865),
    [sym_array_get_expression] = STATE(4865),
    [sym_string_get_expression] = STATE(4865),
    [sym_bigarray_get_expression] = STATE(4865),
    [sym_coercion_expression] = STATE(4865),
    [sym_local_open_expression] = STATE(4865),
    [sym_package_expression] = STATE(4865),
    [sym_new_expression] = STATE(4865),
    [sym_object_copy_expression] = STATE(4865),
    [sym_method_invocation] = STATE(4865),
    [sym_object_expression] = STATE(4865),
    [sym_parenthesized_expression] = STATE(4865),
    [sym_attribute] = STATE(2429),
    [sym_extension] = STATE(4865),
    [sym_quoted_extension] = STATE(4865),
    [sym__constant] = STATE(4865),
    [sym_number] = STATE(4787),
    [sym_character] = STATE(4787),
    [sym_string] = STATE(4787),
    [sym_quoted_string] = STATE(4787),
    [sym_boolean] = STATE(4787),
    [sym_unit] = STATE(4787),
    [sym__value_name] = STATE(4817),
    [sym_parenthesized_operator] = STATE(4812),
    [sym_value_path] = STATE(4865),
    [sym_module_path] = STATE(18603),
    [sym_constructor_path] = STATE(4865),
    [sym__constructor_name] = STATE(4786),
    [sym_tag] = STATE(4865),
    [aux_sym_class_application_repeat1] = STATE(2429),
    [sym__lowercase_identifier] = ACTIONS(4625),
    [anon_sym_TILDE] = ACTIONS(4628),
    [anon_sym_QMARK] = ACTIONS(4628),
    [anon_sym_LPAREN] = ACTIONS(4631),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(4634),
    [anon_sym_true] = ACTIONS(4637),
    [anon_sym_false] = ACTIONS(4637),
    [anon_sym_LBRACE] = ACTIONS(4640),
    [anon_sym_SEMI] = ACTIONS(3720),
    [anon_sym_constraint] = ACTIONS(3722),
    [anon_sym_val] = ACTIONS(3722),
    [anon_sym_end] = ACTIONS(3722),
    [anon_sym_object] = ACTIONS(4643),
    [anon_sym_inherit] = ACTIONS(3722),
    [anon_sym_method] = ACTIONS(3722),
    [anon_sym_initializer] = ACTIONS(3722),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4646),
    [anon_sym_else] = ACTIONS(3722),
    [anon_sym_new] = ACTIONS(4649),
    [anon_sym_LBRACE_LT] = ACTIONS(4652),
    [anon_sym_begin] = ACTIONS(4655),
    [sym_ocamlyacc_value] = ACTIONS(4658),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3722),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3720),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4661),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4664),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3720),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3720),
    [aux_sym_number_token1] = ACTIONS(4667),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(4670),
    [anon_sym_DQUOTE] = ACTIONS(4673),
    [sym_prefix_operator] = ACTIONS(4676),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(4679),
    [aux_sym_tag_token1] = ACTIONS(4682),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2430] = {
    [sym__simple_expression] = STATE(5371),
    [sym_typed_expression] = STATE(5411),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_labeled_argument] = STATE(5766),
    [sym_prefix_expression] = STATE(5411),
    [sym_hash_expression] = STATE(5411),
    [sym_field_get_expression] = STATE(5411),
    [sym_array_get_expression] = STATE(5411),
    [sym_string_get_expression] = STATE(5411),
    [sym_bigarray_get_expression] = STATE(5411),
    [sym_coercion_expression] = STATE(5411),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(2430),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [aux_sym_class_application_repeat1] = STATE(2452),
    [sym__lowercase_identifier] = ACTIONS(4685),
    [anon_sym_COLON_GT] = ACTIONS(3051),
    [anon_sym_TILDE] = ACTIONS(4687),
    [anon_sym_QMARK] = ACTIONS(4687),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_RPAREN] = ACTIONS(3051),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(1177),
    [anon_sym_RBRACK] = ACTIONS(3051),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_COLON2] = ACTIONS(3053),
    [anon_sym_DOT] = ACTIONS(4689),
    [anon_sym_DASH_GT] = ACTIONS(3053),
    [anon_sym_LBRACE] = ACTIONS(1181),
    [anon_sym_SEMI] = ACTIONS(3051),
    [anon_sym_RBRACE] = ACTIONS(3051),
    [anon_sym_object] = ACTIONS(1183),
    [anon_sym_POUND] = ACTIONS(4691),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1187),
    [anon_sym_new] = ACTIONS(1197),
    [anon_sym_LBRACE_LT] = ACTIONS(1199),
    [anon_sym_GT_RBRACE] = ACTIONS(3051),
    [anon_sym_begin] = ACTIONS(1201),
    [sym_ocamlyacc_value] = ACTIONS(1203),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1205),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1207),
    [aux_sym_number_token1] = ACTIONS(1209),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_prefix_operator] = ACTIONS(1215),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(4693),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(1219),
    [aux_sym_tag_token1] = ACTIONS(1221),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2431] = {
    [sym__simple_expression] = STATE(4912),
    [sym_typed_expression] = STATE(4984),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_labeled_argument] = STATE(5344),
    [sym_prefix_expression] = STATE(4984),
    [sym_hash_expression] = STATE(4984),
    [sym_field_get_expression] = STATE(4984),
    [sym_array_get_expression] = STATE(4984),
    [sym_string_get_expression] = STATE(4984),
    [sym_bigarray_get_expression] = STATE(4984),
    [sym_coercion_expression] = STATE(4984),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2431),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [aux_sym_class_application_repeat1] = STATE(2432),
    [sym__lowercase_identifier] = ACTIONS(4585),
    [anon_sym_TILDE] = ACTIONS(4587),
    [anon_sym_QMARK] = ACTIONS(4587),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_true] = ACTIONS(1003),
    [anon_sym_false] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(1005),
    [anon_sym_SEMI] = ACTIONS(3943),
    [anon_sym_constraint] = ACTIONS(3945),
    [anon_sym_val] = ACTIONS(3945),
    [anon_sym_end] = ACTIONS(3945),
    [anon_sym_object] = ACTIONS(1007),
    [anon_sym_inherit] = ACTIONS(3945),
    [anon_sym_method] = ACTIONS(3945),
    [anon_sym_initializer] = ACTIONS(3945),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1011),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_LBRACE_LT] = ACTIONS(1023),
    [anon_sym_begin] = ACTIONS(1025),
    [sym_ocamlyacc_value] = ACTIONS(1027),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3945),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3943),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1029),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1031),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3943),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3943),
    [aux_sym_number_token1] = ACTIONS(1033),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [sym_prefix_operator] = ACTIONS(1039),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(1043),
    [aux_sym_tag_token1] = ACTIONS(1045),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2432] = {
    [sym__simple_expression] = STATE(4912),
    [sym_typed_expression] = STATE(4984),
    [sym_list_expression] = STATE(4984),
    [sym_array_expression] = STATE(4984),
    [sym_record_expression] = STATE(4984),
    [sym_labeled_argument] = STATE(5344),
    [sym_prefix_expression] = STATE(4984),
    [sym_hash_expression] = STATE(4984),
    [sym_field_get_expression] = STATE(4984),
    [sym_array_get_expression] = STATE(4984),
    [sym_string_get_expression] = STATE(4984),
    [sym_bigarray_get_expression] = STATE(4984),
    [sym_coercion_expression] = STATE(4984),
    [sym_local_open_expression] = STATE(4984),
    [sym_package_expression] = STATE(4984),
    [sym_new_expression] = STATE(4984),
    [sym_object_copy_expression] = STATE(4984),
    [sym_method_invocation] = STATE(4984),
    [sym_object_expression] = STATE(4984),
    [sym_parenthesized_expression] = STATE(4984),
    [sym_attribute] = STATE(2432),
    [sym_extension] = STATE(4984),
    [sym_quoted_extension] = STATE(4984),
    [sym__constant] = STATE(4984),
    [sym_number] = STATE(4922),
    [sym_character] = STATE(4922),
    [sym_string] = STATE(4922),
    [sym_quoted_string] = STATE(4922),
    [sym_boolean] = STATE(4922),
    [sym_unit] = STATE(4922),
    [sym__value_name] = STATE(4959),
    [sym_parenthesized_operator] = STATE(4935),
    [sym_value_path] = STATE(4984),
    [sym_module_path] = STATE(18304),
    [sym_constructor_path] = STATE(4984),
    [sym__constructor_name] = STATE(4924),
    [sym_tag] = STATE(4984),
    [aux_sym_class_application_repeat1] = STATE(2432),
    [sym__lowercase_identifier] = ACTIONS(4695),
    [anon_sym_TILDE] = ACTIONS(4698),
    [anon_sym_QMARK] = ACTIONS(4698),
    [anon_sym_LPAREN] = ACTIONS(4701),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(4704),
    [anon_sym_true] = ACTIONS(4707),
    [anon_sym_false] = ACTIONS(4707),
    [anon_sym_LBRACE] = ACTIONS(4710),
    [anon_sym_SEMI] = ACTIONS(3720),
    [anon_sym_constraint] = ACTIONS(3722),
    [anon_sym_val] = ACTIONS(3722),
    [anon_sym_end] = ACTIONS(3722),
    [anon_sym_object] = ACTIONS(4713),
    [anon_sym_inherit] = ACTIONS(3722),
    [anon_sym_method] = ACTIONS(3722),
    [anon_sym_initializer] = ACTIONS(3722),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4716),
    [anon_sym_new] = ACTIONS(4719),
    [anon_sym_LBRACE_LT] = ACTIONS(4722),
    [anon_sym_begin] = ACTIONS(4725),
    [sym_ocamlyacc_value] = ACTIONS(4728),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3722),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3720),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4731),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4734),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3720),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3720),
    [aux_sym_number_token1] = ACTIONS(4737),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(4740),
    [anon_sym_DQUOTE] = ACTIONS(4743),
    [sym_prefix_operator] = ACTIONS(4746),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(4749),
    [aux_sym_tag_token1] = ACTIONS(4752),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2433] = {
    [sym__simple_expression] = STATE(5030),
    [sym_typed_expression] = STATE(5003),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_labeled_argument] = STATE(5463),
    [sym_prefix_expression] = STATE(5003),
    [sym_hash_expression] = STATE(5003),
    [sym_field_get_expression] = STATE(5003),
    [sym_array_get_expression] = STATE(5003),
    [sym_string_get_expression] = STATE(5003),
    [sym_bigarray_get_expression] = STATE(5003),
    [sym_coercion_expression] = STATE(5003),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(2433),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [aux_sym_class_application_repeat1] = STATE(2434),
    [sym__lowercase_identifier] = ACTIONS(4595),
    [anon_sym_COLON_GT] = ACTIONS(3943),
    [anon_sym_TILDE] = ACTIONS(4597),
    [anon_sym_QMARK] = ACTIONS(4597),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_RPAREN] = ACTIONS(3943),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(1121),
    [anon_sym_RBRACK] = ACTIONS(3943),
    [anon_sym_true] = ACTIONS(1123),
    [anon_sym_false] = ACTIONS(1123),
    [anon_sym_COLON2] = ACTIONS(3945),
    [anon_sym_DASH_GT] = ACTIONS(3945),
    [anon_sym_LBRACE] = ACTIONS(1125),
    [anon_sym_SEMI] = ACTIONS(3943),
    [anon_sym_RBRACE] = ACTIONS(3943),
    [anon_sym_object] = ACTIONS(1127),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1131),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3943),
    [anon_sym_else] = ACTIONS(3945),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_LBRACE_LT] = ACTIONS(1147),
    [anon_sym_GT_RBRACE] = ACTIONS(3943),
    [anon_sym_begin] = ACTIONS(1149),
    [sym_ocamlyacc_value] = ACTIONS(1151),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1153),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1155),
    [aux_sym_number_token1] = ACTIONS(1157),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [sym_prefix_operator] = ACTIONS(1163),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(1167),
    [aux_sym_tag_token1] = ACTIONS(1169),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2434] = {
    [sym__simple_expression] = STATE(5030),
    [sym_typed_expression] = STATE(5003),
    [sym_list_expression] = STATE(5003),
    [sym_array_expression] = STATE(5003),
    [sym_record_expression] = STATE(5003),
    [sym_labeled_argument] = STATE(5463),
    [sym_prefix_expression] = STATE(5003),
    [sym_hash_expression] = STATE(5003),
    [sym_field_get_expression] = STATE(5003),
    [sym_array_get_expression] = STATE(5003),
    [sym_string_get_expression] = STATE(5003),
    [sym_bigarray_get_expression] = STATE(5003),
    [sym_coercion_expression] = STATE(5003),
    [sym_local_open_expression] = STATE(5003),
    [sym_package_expression] = STATE(5003),
    [sym_new_expression] = STATE(5003),
    [sym_object_copy_expression] = STATE(5003),
    [sym_method_invocation] = STATE(5003),
    [sym_object_expression] = STATE(5003),
    [sym_parenthesized_expression] = STATE(5003),
    [sym_attribute] = STATE(2434),
    [sym_extension] = STATE(5003),
    [sym_quoted_extension] = STATE(5003),
    [sym__constant] = STATE(5003),
    [sym_number] = STATE(5096),
    [sym_character] = STATE(5096),
    [sym_string] = STATE(5096),
    [sym_quoted_string] = STATE(5096),
    [sym_boolean] = STATE(5096),
    [sym_unit] = STATE(5096),
    [sym__value_name] = STATE(5124),
    [sym_parenthesized_operator] = STATE(5044),
    [sym_value_path] = STATE(5003),
    [sym_module_path] = STATE(18002),
    [sym_constructor_path] = STATE(5003),
    [sym__constructor_name] = STATE(5072),
    [sym_tag] = STATE(5003),
    [aux_sym_class_application_repeat1] = STATE(2434),
    [sym__lowercase_identifier] = ACTIONS(4755),
    [anon_sym_COLON_GT] = ACTIONS(3720),
    [anon_sym_TILDE] = ACTIONS(4758),
    [anon_sym_QMARK] = ACTIONS(4758),
    [anon_sym_LPAREN] = ACTIONS(4761),
    [anon_sym_RPAREN] = ACTIONS(3720),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(4764),
    [anon_sym_RBRACK] = ACTIONS(3720),
    [anon_sym_true] = ACTIONS(4767),
    [anon_sym_false] = ACTIONS(4767),
    [anon_sym_COLON2] = ACTIONS(3722),
    [anon_sym_DASH_GT] = ACTIONS(3722),
    [anon_sym_LBRACE] = ACTIONS(4770),
    [anon_sym_SEMI] = ACTIONS(3720),
    [anon_sym_RBRACE] = ACTIONS(3720),
    [anon_sym_object] = ACTIONS(4773),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4776),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3720),
    [anon_sym_else] = ACTIONS(3722),
    [anon_sym_new] = ACTIONS(4779),
    [anon_sym_LBRACE_LT] = ACTIONS(4782),
    [anon_sym_GT_RBRACE] = ACTIONS(3720),
    [anon_sym_begin] = ACTIONS(4785),
    [sym_ocamlyacc_value] = ACTIONS(4788),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4794),
    [aux_sym_number_token1] = ACTIONS(4797),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(4800),
    [anon_sym_DQUOTE] = ACTIONS(4803),
    [sym_prefix_operator] = ACTIONS(4806),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(4809),
    [aux_sym_tag_token1] = ACTIONS(4812),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2435] = {
    [sym__simple_expression] = STATE(5734),
    [sym_typed_expression] = STATE(5700),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_labeled_argument] = STATE(6593),
    [sym_prefix_expression] = STATE(5700),
    [sym_hash_expression] = STATE(5700),
    [sym_field_get_expression] = STATE(5700),
    [sym_array_get_expression] = STATE(5700),
    [sym_string_get_expression] = STATE(5700),
    [sym_bigarray_get_expression] = STATE(5700),
    [sym_coercion_expression] = STATE(5700),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(2435),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [aux_sym_class_application_repeat1] = STATE(2463),
    [sym__lowercase_identifier] = ACTIONS(4815),
    [anon_sym_and] = ACTIONS(3053),
    [anon_sym_TILDE] = ACTIONS(4817),
    [anon_sym_QMARK] = ACTIONS(4817),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_DOT] = ACTIONS(4819),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_SEMI] = ACTIONS(3051),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_in] = ACTIONS(3053),
    [anon_sym_POUND] = ACTIONS(4821),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_else] = ACTIONS(3053),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3051),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(4823),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym_let_and_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2436] = {
    [sym__simple_expression] = STATE(5244),
    [sym_typed_expression] = STATE(5216),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_labeled_argument] = STATE(5573),
    [sym_prefix_expression] = STATE(5216),
    [sym_hash_expression] = STATE(5216),
    [sym_field_get_expression] = STATE(5216),
    [sym_array_get_expression] = STATE(5216),
    [sym_string_get_expression] = STATE(5216),
    [sym_bigarray_get_expression] = STATE(5216),
    [sym_coercion_expression] = STATE(5216),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(2436),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [aux_sym_class_application_repeat1] = STATE(2438),
    [sym__lowercase_identifier] = ACTIONS(4615),
    [anon_sym_COLON_GT] = ACTIONS(3943),
    [anon_sym_TILDE] = ACTIONS(4617),
    [anon_sym_QMARK] = ACTIONS(4617),
    [anon_sym_LPAREN] = ACTIONS(1065),
    [anon_sym_RPAREN] = ACTIONS(3943),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(1067),
    [anon_sym_RBRACK] = ACTIONS(3943),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_COLON2] = ACTIONS(3945),
    [anon_sym_DASH_GT] = ACTIONS(3945),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_SEMI] = ACTIONS(3943),
    [anon_sym_RBRACE] = ACTIONS(3943),
    [anon_sym_object] = ACTIONS(1073),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1077),
    [anon_sym_else] = ACTIONS(3945),
    [anon_sym_new] = ACTIONS(1087),
    [anon_sym_LBRACE_LT] = ACTIONS(1089),
    [anon_sym_GT_RBRACE] = ACTIONS(3943),
    [anon_sym_begin] = ACTIONS(1091),
    [sym_ocamlyacc_value] = ACTIONS(1093),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1099),
    [aux_sym_number_token1] = ACTIONS(1101),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [sym_prefix_operator] = ACTIONS(1107),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(1111),
    [aux_sym_tag_token1] = ACTIONS(1113),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2437] = {
    [sym__simple_expression] = STATE(5199),
    [sym_typed_expression] = STATE(5299),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_labeled_argument] = STATE(5582),
    [sym_prefix_expression] = STATE(5299),
    [sym_hash_expression] = STATE(5299),
    [sym_field_get_expression] = STATE(5299),
    [sym_array_get_expression] = STATE(5299),
    [sym_string_get_expression] = STATE(5299),
    [sym_bigarray_get_expression] = STATE(5299),
    [sym_coercion_expression] = STATE(5299),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2437),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [aux_sym_class_application_repeat1] = STATE(2437),
    [sym__lowercase_identifier] = ACTIONS(4825),
    [anon_sym_COLON_GT] = ACTIONS(3720),
    [anon_sym_TILDE] = ACTIONS(4828),
    [anon_sym_QMARK] = ACTIONS(4828),
    [anon_sym_LPAREN] = ACTIONS(4831),
    [anon_sym_RPAREN] = ACTIONS(3720),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(4834),
    [anon_sym_RBRACK] = ACTIONS(3720),
    [anon_sym_true] = ACTIONS(4837),
    [anon_sym_false] = ACTIONS(4837),
    [anon_sym_COLON2] = ACTIONS(3722),
    [anon_sym_DASH_GT] = ACTIONS(3722),
    [anon_sym_LBRACE] = ACTIONS(4840),
    [anon_sym_SEMI] = ACTIONS(3720),
    [anon_sym_RBRACE] = ACTIONS(3720),
    [anon_sym_object] = ACTIONS(4843),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4846),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3720),
    [anon_sym_new] = ACTIONS(4849),
    [anon_sym_LBRACE_LT] = ACTIONS(4852),
    [anon_sym_GT_RBRACE] = ACTIONS(3720),
    [anon_sym_begin] = ACTIONS(4855),
    [sym_ocamlyacc_value] = ACTIONS(4858),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4861),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4864),
    [aux_sym_number_token1] = ACTIONS(4867),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(4870),
    [anon_sym_DQUOTE] = ACTIONS(4873),
    [sym_prefix_operator] = ACTIONS(4876),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(4879),
    [aux_sym_tag_token1] = ACTIONS(4882),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2438] = {
    [sym__simple_expression] = STATE(5244),
    [sym_typed_expression] = STATE(5216),
    [sym_list_expression] = STATE(5216),
    [sym_array_expression] = STATE(5216),
    [sym_record_expression] = STATE(5216),
    [sym_labeled_argument] = STATE(5573),
    [sym_prefix_expression] = STATE(5216),
    [sym_hash_expression] = STATE(5216),
    [sym_field_get_expression] = STATE(5216),
    [sym_array_get_expression] = STATE(5216),
    [sym_string_get_expression] = STATE(5216),
    [sym_bigarray_get_expression] = STATE(5216),
    [sym_coercion_expression] = STATE(5216),
    [sym_local_open_expression] = STATE(5216),
    [sym_package_expression] = STATE(5216),
    [sym_new_expression] = STATE(5216),
    [sym_object_copy_expression] = STATE(5216),
    [sym_method_invocation] = STATE(5216),
    [sym_object_expression] = STATE(5216),
    [sym_parenthesized_expression] = STATE(5216),
    [sym_attribute] = STATE(2438),
    [sym_extension] = STATE(5216),
    [sym_quoted_extension] = STATE(5216),
    [sym__constant] = STATE(5216),
    [sym_number] = STATE(5233),
    [sym_character] = STATE(5233),
    [sym_string] = STATE(5233),
    [sym_quoted_string] = STATE(5233),
    [sym_boolean] = STATE(5233),
    [sym_unit] = STATE(5233),
    [sym__value_name] = STATE(5210),
    [sym_parenthesized_operator] = STATE(5203),
    [sym_value_path] = STATE(5216),
    [sym_module_path] = STATE(18831),
    [sym_constructor_path] = STATE(5216),
    [sym__constructor_name] = STATE(5248),
    [sym_tag] = STATE(5216),
    [aux_sym_class_application_repeat1] = STATE(2438),
    [sym__lowercase_identifier] = ACTIONS(4885),
    [anon_sym_COLON_GT] = ACTIONS(3720),
    [anon_sym_TILDE] = ACTIONS(4888),
    [anon_sym_QMARK] = ACTIONS(4888),
    [anon_sym_LPAREN] = ACTIONS(4891),
    [anon_sym_RPAREN] = ACTIONS(3720),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(4894),
    [anon_sym_RBRACK] = ACTIONS(3720),
    [anon_sym_true] = ACTIONS(4897),
    [anon_sym_false] = ACTIONS(4897),
    [anon_sym_COLON2] = ACTIONS(3722),
    [anon_sym_DASH_GT] = ACTIONS(3722),
    [anon_sym_LBRACE] = ACTIONS(4900),
    [anon_sym_SEMI] = ACTIONS(3720),
    [anon_sym_RBRACE] = ACTIONS(3720),
    [anon_sym_object] = ACTIONS(4903),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4906),
    [anon_sym_else] = ACTIONS(3722),
    [anon_sym_new] = ACTIONS(4909),
    [anon_sym_LBRACE_LT] = ACTIONS(4912),
    [anon_sym_GT_RBRACE] = ACTIONS(3720),
    [anon_sym_begin] = ACTIONS(4915),
    [sym_ocamlyacc_value] = ACTIONS(4918),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4921),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4924),
    [aux_sym_number_token1] = ACTIONS(4927),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(4930),
    [anon_sym_DQUOTE] = ACTIONS(4933),
    [sym_prefix_operator] = ACTIONS(4936),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(4939),
    [aux_sym_tag_token1] = ACTIONS(4942),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2439] = {
    [sym__simple_expression] = STATE(5199),
    [sym_typed_expression] = STATE(5299),
    [sym_list_expression] = STATE(5299),
    [sym_array_expression] = STATE(5299),
    [sym_record_expression] = STATE(5299),
    [sym_labeled_argument] = STATE(5582),
    [sym_prefix_expression] = STATE(5299),
    [sym_hash_expression] = STATE(5299),
    [sym_field_get_expression] = STATE(5299),
    [sym_array_get_expression] = STATE(5299),
    [sym_string_get_expression] = STATE(5299),
    [sym_bigarray_get_expression] = STATE(5299),
    [sym_coercion_expression] = STATE(5299),
    [sym_local_open_expression] = STATE(5299),
    [sym_package_expression] = STATE(5299),
    [sym_new_expression] = STATE(5299),
    [sym_object_copy_expression] = STATE(5299),
    [sym_method_invocation] = STATE(5299),
    [sym_object_expression] = STATE(5299),
    [sym_parenthesized_expression] = STATE(5299),
    [sym_attribute] = STATE(2439),
    [sym_extension] = STATE(5299),
    [sym_quoted_extension] = STATE(5299),
    [sym__constant] = STATE(5299),
    [sym_number] = STATE(5231),
    [sym_character] = STATE(5231),
    [sym_string] = STATE(5231),
    [sym_quoted_string] = STATE(5231),
    [sym_boolean] = STATE(5231),
    [sym_unit] = STATE(5231),
    [sym__value_name] = STATE(5269),
    [sym_parenthesized_operator] = STATE(5292),
    [sym_value_path] = STATE(5299),
    [sym_module_path] = STATE(20456),
    [sym_constructor_path] = STATE(5299),
    [sym__constructor_name] = STATE(5227),
    [sym_tag] = STATE(5299),
    [aux_sym_class_application_repeat1] = STATE(2437),
    [sym__lowercase_identifier] = ACTIONS(4605),
    [anon_sym_COLON_GT] = ACTIONS(3943),
    [anon_sym_TILDE] = ACTIONS(4607),
    [anon_sym_QMARK] = ACTIONS(4607),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(3943),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(3943),
    [anon_sym_true] = ACTIONS(1231),
    [anon_sym_false] = ACTIONS(1231),
    [anon_sym_COLON2] = ACTIONS(3945),
    [anon_sym_DASH_GT] = ACTIONS(3945),
    [anon_sym_LBRACE] = ACTIONS(1233),
    [anon_sym_SEMI] = ACTIONS(3943),
    [anon_sym_RBRACE] = ACTIONS(3943),
    [anon_sym_object] = ACTIONS(1235),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1239),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3943),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LBRACE_LT] = ACTIONS(1251),
    [anon_sym_GT_RBRACE] = ACTIONS(3943),
    [anon_sym_begin] = ACTIONS(1253),
    [sym_ocamlyacc_value] = ACTIONS(1255),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1259),
    [aux_sym_number_token1] = ACTIONS(1261),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [anon_sym_DQUOTE] = ACTIONS(1265),
    [sym_prefix_operator] = ACTIONS(1267),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(1271),
    [aux_sym_tag_token1] = ACTIONS(1273),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2440] = {
    [sym__abstract_type] = STATE(19566),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13541),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2440),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__infix_operator] = STATE(18042),
    [sym_add_operator] = STATE(20475),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_RPAREN] = ACTIONS(4949),
    [anon_sym_type] = ACTIONS(4951),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_DOT] = ACTIONS(4957),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_module] = ACTIONS(4963),
    [anon_sym_POUND] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(4967),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(4983),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym_prefix_operator] = ACTIONS(4989),
    [aux_sym_sign_operator_token1] = ACTIONS(1469),
    [sym_hash_operator] = ACTIONS(4989),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(4989),
    [sym_let_and_operator] = ACTIONS(4989),
    [sym_match_operator] = ACTIONS(4989),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2441] = {
    [sym__simple_expression] = STATE(5371),
    [sym_typed_expression] = STATE(5411),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_labeled_argument] = STATE(5766),
    [sym_prefix_expression] = STATE(5411),
    [sym_hash_expression] = STATE(5411),
    [sym_field_get_expression] = STATE(5411),
    [sym_array_get_expression] = STATE(5411),
    [sym_string_get_expression] = STATE(5411),
    [sym_bigarray_get_expression] = STATE(5411),
    [sym_coercion_expression] = STATE(5411),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(2441),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [aux_sym_class_application_repeat1] = STATE(2441),
    [sym__lowercase_identifier] = ACTIONS(4995),
    [anon_sym_COLON_GT] = ACTIONS(3720),
    [anon_sym_TILDE] = ACTIONS(4998),
    [anon_sym_QMARK] = ACTIONS(4998),
    [anon_sym_LPAREN] = ACTIONS(5001),
    [anon_sym_RPAREN] = ACTIONS(3720),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(5004),
    [anon_sym_RBRACK] = ACTIONS(3720),
    [anon_sym_true] = ACTIONS(5007),
    [anon_sym_false] = ACTIONS(5007),
    [anon_sym_COLON2] = ACTIONS(3722),
    [anon_sym_DASH_GT] = ACTIONS(3722),
    [anon_sym_LBRACE] = ACTIONS(5010),
    [anon_sym_SEMI] = ACTIONS(3720),
    [anon_sym_RBRACE] = ACTIONS(3720),
    [anon_sym_object] = ACTIONS(5013),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5016),
    [anon_sym_new] = ACTIONS(5019),
    [anon_sym_LBRACE_LT] = ACTIONS(5022),
    [anon_sym_GT_RBRACE] = ACTIONS(3720),
    [anon_sym_begin] = ACTIONS(5025),
    [sym_ocamlyacc_value] = ACTIONS(5028),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5031),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5034),
    [aux_sym_number_token1] = ACTIONS(5037),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(5040),
    [anon_sym_DQUOTE] = ACTIONS(5043),
    [sym_prefix_operator] = ACTIONS(5046),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(5049),
    [aux_sym_tag_token1] = ACTIONS(5052),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2442] = {
    [sym__simple_expression] = STATE(5846),
    [sym_typed_expression] = STATE(5778),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_labeled_argument] = STATE(7016),
    [sym_prefix_expression] = STATE(5778),
    [sym_hash_expression] = STATE(5778),
    [sym_field_get_expression] = STATE(5778),
    [sym_array_get_expression] = STATE(5778),
    [sym_string_get_expression] = STATE(5778),
    [sym_bigarray_get_expression] = STATE(5778),
    [sym_coercion_expression] = STATE(5778),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(2442),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [aux_sym_class_application_repeat1] = STATE(2487),
    [sym__lowercase_identifier] = ACTIONS(5055),
    [anon_sym_and] = ACTIONS(3053),
    [anon_sym_TILDE] = ACTIONS(5057),
    [anon_sym_QMARK] = ACTIONS(5057),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_DOT] = ACTIONS(5059),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_SEMI] = ACTIONS(3051),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_in] = ACTIONS(3053),
    [anon_sym_POUND] = ACTIONS(5061),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3051),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(5063),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym_let_and_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2443] = {
    [sym__abstract_type] = STATE(19688),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13793),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2443),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__infix_operator] = STATE(18200),
    [sym_add_operator] = STATE(20475),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_RPAREN] = ACTIONS(5065),
    [anon_sym_type] = ACTIONS(4951),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_DOT] = ACTIONS(5067),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_module] = ACTIONS(5069),
    [anon_sym_POUND] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(5071),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(4983),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym_prefix_operator] = ACTIONS(5073),
    [aux_sym_sign_operator_token1] = ACTIONS(1469),
    [sym_hash_operator] = ACTIONS(5073),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(5073),
    [sym_let_and_operator] = ACTIONS(5073),
    [sym_match_operator] = ACTIONS(5073),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2444] = {
    [sym__binding_pattern] = STATE(5471),
    [sym_alias_binding_pattern] = STATE(5483),
    [sym_typed_binding_pattern] = STATE(5483),
    [sym_or_binding_pattern] = STATE(5483),
    [sym_constructor_binding_pattern] = STATE(5483),
    [sym_tag_binding_pattern] = STATE(5483),
    [sym_polymorphic_variant_pattern] = STATE(5483),
    [sym_tuple_binding_pattern] = STATE(5483),
    [sym_record_binding_pattern] = STATE(5475),
    [sym_list_binding_pattern] = STATE(5538),
    [sym_cons_binding_pattern] = STATE(5483),
    [sym_array_binding_pattern] = STATE(5553),
    [sym_range_pattern] = STATE(5483),
    [sym_lazy_binding_pattern] = STATE(5483),
    [sym_local_open_binding_pattern] = STATE(5483),
    [sym_package_pattern] = STATE(5483),
    [sym_parenthesized_binding_pattern] = STATE(5483),
    [sym_attribute] = STATE(2444),
    [sym_extension] = STATE(5483),
    [sym_quoted_extension] = STATE(5483),
    [sym__constant] = STATE(5356),
    [sym__signed_constant] = STATE(5315),
    [sym_number] = STATE(5423),
    [sym_signed_number] = STATE(5356),
    [sym_character] = STATE(5423),
    [sym_string] = STATE(5423),
    [sym_quoted_string] = STATE(5423),
    [sym_boolean] = STATE(5423),
    [sym_unit] = STATE(5423),
    [sym__value_name] = STATE(5483),
    [sym_parenthesized_operator] = STATE(5534),
    [sym_module_path] = STATE(20406),
    [sym_constructor_path] = STATE(2444),
    [sym__constructor_name] = STATE(5376),
    [sym_tag] = STATE(2445),
    [sym__lowercase_identifier] = ACTIONS(5075),
    [anon_sym_SEMI_SEMI] = ACTIONS(5077),
    [anon_sym_let] = ACTIONS(5079),
    [anon_sym_and] = ACTIONS(5079),
    [anon_sym_COLON_GT] = ACTIONS(5077),
    [anon_sym_EQ] = ACTIONS(5077),
    [anon_sym_TILDE] = ACTIONS(5077),
    [anon_sym_QMARK] = ACTIONS(5077),
    [anon_sym_LPAREN] = ACTIONS(5081),
    [anon_sym_external] = ACTIONS(5079),
    [anon_sym_type] = ACTIONS(5079),
    [anon_sym_COMMA] = ACTIONS(5077),
    [anon_sym_PIPE] = ACTIONS(5077),
    [anon_sym_LBRACK] = ACTIONS(5083),
    [anon_sym_true] = ACTIONS(5085),
    [anon_sym_false] = ACTIONS(5085),
    [anon_sym_COLON2] = ACTIONS(5079),
    [anon_sym_LBRACE] = ACTIONS(5087),
    [anon_sym_exception] = ACTIONS(5079),
    [anon_sym_module] = ACTIONS(5079),
    [anon_sym_open] = ACTIONS(5079),
    [anon_sym_include] = ACTIONS(5079),
    [anon_sym_class] = ACTIONS(5079),
    [anon_sym_end] = ACTIONS(5079),
    [anon_sym_in] = ACTIONS(5079),
    [anon_sym_as] = ACTIONS(5079),
    [anon_sym_POUND] = ACTIONS(5089),
    [anon_sym_COLON_COLON] = ACTIONS(5077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5091),
    [anon_sym_lazy] = ACTIONS(5093),
    [anon_sym_begin] = ACTIONS(5095),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5079),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5077),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5099),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5077),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5077),
    [aux_sym_number_token1] = ACTIONS(5101),
    [aux_sym_signed_number_token1] = ACTIONS(5103),
    [anon_sym_SQUOTE] = ACTIONS(5105),
    [anon_sym_DQUOTE] = ACTIONS(5107),
    [sym_let_operator] = ACTIONS(5077),
    [sym_let_and_operator] = ACTIONS(5077),
    [sym__uppercase_identifier] = ACTIONS(5109),
    [aux_sym_directive_token1] = ACTIONS(5079),
    [aux_sym_tag_token1] = ACTIONS(5111),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2445] = {
    [sym__binding_pattern] = STATE(5428),
    [sym_alias_binding_pattern] = STATE(5483),
    [sym_typed_binding_pattern] = STATE(5483),
    [sym_or_binding_pattern] = STATE(5483),
    [sym_constructor_binding_pattern] = STATE(5483),
    [sym_tag_binding_pattern] = STATE(5483),
    [sym_polymorphic_variant_pattern] = STATE(5483),
    [sym_tuple_binding_pattern] = STATE(5483),
    [sym_record_binding_pattern] = STATE(5475),
    [sym_list_binding_pattern] = STATE(5538),
    [sym_cons_binding_pattern] = STATE(5483),
    [sym_array_binding_pattern] = STATE(5553),
    [sym_range_pattern] = STATE(5483),
    [sym_lazy_binding_pattern] = STATE(5483),
    [sym_local_open_binding_pattern] = STATE(5483),
    [sym_package_pattern] = STATE(5483),
    [sym_parenthesized_binding_pattern] = STATE(5483),
    [sym_attribute] = STATE(2445),
    [sym_extension] = STATE(5483),
    [sym_quoted_extension] = STATE(5483),
    [sym__constant] = STATE(5356),
    [sym__signed_constant] = STATE(5315),
    [sym_number] = STATE(5423),
    [sym_signed_number] = STATE(5356),
    [sym_character] = STATE(5423),
    [sym_string] = STATE(5423),
    [sym_quoted_string] = STATE(5423),
    [sym_boolean] = STATE(5423),
    [sym_unit] = STATE(5423),
    [sym__value_name] = STATE(5483),
    [sym_parenthesized_operator] = STATE(5534),
    [sym_module_path] = STATE(20406),
    [sym_constructor_path] = STATE(2444),
    [sym__constructor_name] = STATE(5376),
    [sym_tag] = STATE(2445),
    [sym__lowercase_identifier] = ACTIONS(5075),
    [anon_sym_SEMI_SEMI] = ACTIONS(5077),
    [anon_sym_let] = ACTIONS(5079),
    [anon_sym_and] = ACTIONS(5079),
    [anon_sym_COLON_GT] = ACTIONS(5077),
    [anon_sym_EQ] = ACTIONS(5077),
    [anon_sym_TILDE] = ACTIONS(5077),
    [anon_sym_QMARK] = ACTIONS(5077),
    [anon_sym_LPAREN] = ACTIONS(5081),
    [anon_sym_external] = ACTIONS(5079),
    [anon_sym_type] = ACTIONS(5079),
    [anon_sym_COMMA] = ACTIONS(5077),
    [anon_sym_PIPE] = ACTIONS(5077),
    [anon_sym_LBRACK] = ACTIONS(5083),
    [anon_sym_true] = ACTIONS(5085),
    [anon_sym_false] = ACTIONS(5085),
    [anon_sym_COLON2] = ACTIONS(5079),
    [anon_sym_LBRACE] = ACTIONS(5087),
    [anon_sym_exception] = ACTIONS(5079),
    [anon_sym_module] = ACTIONS(5079),
    [anon_sym_open] = ACTIONS(5079),
    [anon_sym_include] = ACTIONS(5079),
    [anon_sym_class] = ACTIONS(5079),
    [anon_sym_end] = ACTIONS(5079),
    [anon_sym_in] = ACTIONS(5079),
    [anon_sym_as] = ACTIONS(5079),
    [anon_sym_POUND] = ACTIONS(5089),
    [anon_sym_COLON_COLON] = ACTIONS(5077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5091),
    [anon_sym_lazy] = ACTIONS(5093),
    [anon_sym_begin] = ACTIONS(5095),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5079),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5077),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5097),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5099),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5077),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5077),
    [aux_sym_number_token1] = ACTIONS(5101),
    [aux_sym_signed_number_token1] = ACTIONS(5103),
    [anon_sym_SQUOTE] = ACTIONS(5105),
    [anon_sym_DQUOTE] = ACTIONS(5107),
    [sym_let_operator] = ACTIONS(5077),
    [sym_let_and_operator] = ACTIONS(5077),
    [sym__uppercase_identifier] = ACTIONS(5109),
    [aux_sym_directive_token1] = ACTIONS(5079),
    [aux_sym_tag_token1] = ACTIONS(5111),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2446] = {
    [sym__abstract_type] = STATE(19820),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13751),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2446),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__infix_operator] = STATE(18376),
    [sym_add_operator] = STATE(20475),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_RPAREN] = ACTIONS(5113),
    [anon_sym_type] = ACTIONS(4951),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_DOT] = ACTIONS(5115),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_module] = ACTIONS(5117),
    [anon_sym_POUND] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(5119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(4983),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym_prefix_operator] = ACTIONS(5121),
    [aux_sym_sign_operator_token1] = ACTIONS(1469),
    [sym_hash_operator] = ACTIONS(5121),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(5121),
    [sym_let_and_operator] = ACTIONS(5121),
    [sym_match_operator] = ACTIONS(5121),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2447] = {
    [sym__abstract_type] = STATE(19952),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13806),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2447),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__infix_operator] = STATE(18720),
    [sym_add_operator] = STATE(20475),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_RPAREN] = ACTIONS(5123),
    [anon_sym_type] = ACTIONS(4951),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_DOT] = ACTIONS(5125),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_module] = ACTIONS(5127),
    [anon_sym_POUND] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(5129),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(4983),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym_prefix_operator] = ACTIONS(5131),
    [aux_sym_sign_operator_token1] = ACTIONS(1469),
    [sym_hash_operator] = ACTIONS(5131),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(5131),
    [sym_let_and_operator] = ACTIONS(5131),
    [sym_match_operator] = ACTIONS(5131),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2448] = {
    [sym__abstract_type] = STATE(20087),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13536),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2448),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__infix_operator] = STATE(19488),
    [sym_add_operator] = STATE(20475),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_RPAREN] = ACTIONS(5133),
    [anon_sym_type] = ACTIONS(4951),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_DOT] = ACTIONS(5135),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_module] = ACTIONS(5137),
    [anon_sym_POUND] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(5139),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(4983),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym_prefix_operator] = ACTIONS(5141),
    [aux_sym_sign_operator_token1] = ACTIONS(1469),
    [sym_hash_operator] = ACTIONS(5141),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(5141),
    [sym_let_and_operator] = ACTIONS(5141),
    [sym_match_operator] = ACTIONS(5141),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2449] = {
    [sym__abstract_type] = STATE(19952),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13678),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2449),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__infix_operator] = STATE(20476),
    [sym_add_operator] = STATE(20475),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_RPAREN] = ACTIONS(2105),
    [anon_sym_type] = ACTIONS(4951),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_DOT] = ACTIONS(1941),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_module] = ACTIONS(5143),
    [anon_sym_POUND] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(5145),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(4983),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym_prefix_operator] = ACTIONS(1949),
    [aux_sym_sign_operator_token1] = ACTIONS(1469),
    [sym_hash_operator] = ACTIONS(1949),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1949),
    [sym_let_and_operator] = ACTIONS(1949),
    [sym_match_operator] = ACTIONS(1949),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2450] = {
    [sym__abstract_type] = STATE(20404),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13744),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2450),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__infix_operator] = STATE(19859),
    [sym_add_operator] = STATE(20475),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_RPAREN] = ACTIONS(5147),
    [anon_sym_type] = ACTIONS(4951),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_DOT] = ACTIONS(5149),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_module] = ACTIONS(5151),
    [anon_sym_POUND] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(5153),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(4983),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym_prefix_operator] = ACTIONS(5155),
    [aux_sym_sign_operator_token1] = ACTIONS(1469),
    [sym_hash_operator] = ACTIONS(5155),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(5155),
    [sym_let_and_operator] = ACTIONS(5155),
    [sym_match_operator] = ACTIONS(5155),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2451] = {
    [sym__binding_pattern] = STATE(5446),
    [sym_alias_binding_pattern] = STATE(5519),
    [sym_typed_binding_pattern] = STATE(5519),
    [sym_or_binding_pattern] = STATE(5519),
    [sym_constructor_binding_pattern] = STATE(5519),
    [sym_tag_binding_pattern] = STATE(5519),
    [sym_polymorphic_variant_pattern] = STATE(5519),
    [sym_tuple_binding_pattern] = STATE(5519),
    [sym_record_binding_pattern] = STATE(5506),
    [sym_list_binding_pattern] = STATE(5515),
    [sym_cons_binding_pattern] = STATE(5519),
    [sym_array_binding_pattern] = STATE(5514),
    [sym_range_pattern] = STATE(5519),
    [sym_lazy_binding_pattern] = STATE(5519),
    [sym_local_open_binding_pattern] = STATE(5519),
    [sym_package_pattern] = STATE(5519),
    [sym_parenthesized_binding_pattern] = STATE(5519),
    [sym_attribute] = STATE(2451),
    [sym_extension] = STATE(5519),
    [sym_quoted_extension] = STATE(5519),
    [sym__constant] = STATE(5408),
    [sym__signed_constant] = STATE(5363),
    [sym_number] = STATE(5367),
    [sym_signed_number] = STATE(5408),
    [sym_character] = STATE(5367),
    [sym_string] = STATE(5367),
    [sym_quoted_string] = STATE(5367),
    [sym_boolean] = STATE(5367),
    [sym_unit] = STATE(5367),
    [sym__value_name] = STATE(5519),
    [sym_parenthesized_operator] = STATE(5498),
    [sym_module_path] = STATE(20448),
    [sym_constructor_path] = STATE(2453),
    [sym__constructor_name] = STATE(5364),
    [sym_tag] = STATE(2451),
    [sym__lowercase_identifier] = ACTIONS(5157),
    [anon_sym_SEMI_SEMI] = ACTIONS(5077),
    [anon_sym_let] = ACTIONS(5079),
    [anon_sym_and] = ACTIONS(5079),
    [anon_sym_COLON_GT] = ACTIONS(5077),
    [anon_sym_EQ] = ACTIONS(5077),
    [anon_sym_TILDE] = ACTIONS(5077),
    [anon_sym_QMARK] = ACTIONS(5077),
    [anon_sym_LPAREN] = ACTIONS(5159),
    [anon_sym_external] = ACTIONS(5079),
    [anon_sym_type] = ACTIONS(5079),
    [anon_sym_COMMA] = ACTIONS(5077),
    [anon_sym_PIPE] = ACTIONS(5077),
    [anon_sym_LBRACK] = ACTIONS(5161),
    [anon_sym_RBRACK] = ACTIONS(5077),
    [anon_sym_true] = ACTIONS(5163),
    [anon_sym_false] = ACTIONS(5163),
    [anon_sym_COLON2] = ACTIONS(5079),
    [anon_sym_LBRACE] = ACTIONS(5165),
    [anon_sym_exception] = ACTIONS(5079),
    [anon_sym_module] = ACTIONS(5079),
    [anon_sym_open] = ACTIONS(5079),
    [anon_sym_include] = ACTIONS(5079),
    [anon_sym_class] = ACTIONS(5079),
    [anon_sym_in] = ACTIONS(5079),
    [anon_sym_as] = ACTIONS(5079),
    [anon_sym_POUND] = ACTIONS(5167),
    [anon_sym_COLON_COLON] = ACTIONS(5077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5169),
    [anon_sym_lazy] = ACTIONS(5171),
    [anon_sym_begin] = ACTIONS(5173),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5079),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5077),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5175),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5177),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5077),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5077),
    [aux_sym_number_token1] = ACTIONS(5179),
    [aux_sym_signed_number_token1] = ACTIONS(5181),
    [anon_sym_SQUOTE] = ACTIONS(5183),
    [anon_sym_DQUOTE] = ACTIONS(5185),
    [sym_let_operator] = ACTIONS(5077),
    [sym_let_and_operator] = ACTIONS(5077),
    [sym__uppercase_identifier] = ACTIONS(5187),
    [aux_sym_directive_token1] = ACTIONS(5079),
    [aux_sym_tag_token1] = ACTIONS(5189),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2452] = {
    [sym__simple_expression] = STATE(5371),
    [sym_typed_expression] = STATE(5411),
    [sym_list_expression] = STATE(5411),
    [sym_array_expression] = STATE(5411),
    [sym_record_expression] = STATE(5411),
    [sym_labeled_argument] = STATE(5766),
    [sym_prefix_expression] = STATE(5411),
    [sym_hash_expression] = STATE(5411),
    [sym_field_get_expression] = STATE(5411),
    [sym_array_get_expression] = STATE(5411),
    [sym_string_get_expression] = STATE(5411),
    [sym_bigarray_get_expression] = STATE(5411),
    [sym_coercion_expression] = STATE(5411),
    [sym_local_open_expression] = STATE(5411),
    [sym_package_expression] = STATE(5411),
    [sym_new_expression] = STATE(5411),
    [sym_object_copy_expression] = STATE(5411),
    [sym_method_invocation] = STATE(5411),
    [sym_object_expression] = STATE(5411),
    [sym_parenthesized_expression] = STATE(5411),
    [sym_attribute] = STATE(2452),
    [sym_extension] = STATE(5411),
    [sym_quoted_extension] = STATE(5411),
    [sym__constant] = STATE(5411),
    [sym_number] = STATE(5334),
    [sym_character] = STATE(5334),
    [sym_string] = STATE(5334),
    [sym_quoted_string] = STATE(5334),
    [sym_boolean] = STATE(5334),
    [sym_unit] = STATE(5334),
    [sym__value_name] = STATE(5382),
    [sym_parenthesized_operator] = STATE(5392),
    [sym_value_path] = STATE(5411),
    [sym_module_path] = STATE(18056),
    [sym_constructor_path] = STATE(5411),
    [sym__constructor_name] = STATE(5357),
    [sym_tag] = STATE(5411),
    [aux_sym_class_application_repeat1] = STATE(2441),
    [sym__lowercase_identifier] = ACTIONS(4685),
    [anon_sym_COLON_GT] = ACTIONS(3943),
    [anon_sym_TILDE] = ACTIONS(4687),
    [anon_sym_QMARK] = ACTIONS(4687),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_RPAREN] = ACTIONS(3943),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(1177),
    [anon_sym_RBRACK] = ACTIONS(3943),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_COLON2] = ACTIONS(3945),
    [anon_sym_DASH_GT] = ACTIONS(3945),
    [anon_sym_LBRACE] = ACTIONS(1181),
    [anon_sym_SEMI] = ACTIONS(3943),
    [anon_sym_RBRACE] = ACTIONS(3943),
    [anon_sym_object] = ACTIONS(1183),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1187),
    [anon_sym_new] = ACTIONS(1197),
    [anon_sym_LBRACE_LT] = ACTIONS(1199),
    [anon_sym_GT_RBRACE] = ACTIONS(3943),
    [anon_sym_begin] = ACTIONS(1201),
    [sym_ocamlyacc_value] = ACTIONS(1203),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1205),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1207),
    [aux_sym_number_token1] = ACTIONS(1209),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_prefix_operator] = ACTIONS(1215),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(1219),
    [aux_sym_tag_token1] = ACTIONS(1221),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2453] = {
    [sym__binding_pattern] = STATE(5448),
    [sym_alias_binding_pattern] = STATE(5519),
    [sym_typed_binding_pattern] = STATE(5519),
    [sym_or_binding_pattern] = STATE(5519),
    [sym_constructor_binding_pattern] = STATE(5519),
    [sym_tag_binding_pattern] = STATE(5519),
    [sym_polymorphic_variant_pattern] = STATE(5519),
    [sym_tuple_binding_pattern] = STATE(5519),
    [sym_record_binding_pattern] = STATE(5506),
    [sym_list_binding_pattern] = STATE(5515),
    [sym_cons_binding_pattern] = STATE(5519),
    [sym_array_binding_pattern] = STATE(5514),
    [sym_range_pattern] = STATE(5519),
    [sym_lazy_binding_pattern] = STATE(5519),
    [sym_local_open_binding_pattern] = STATE(5519),
    [sym_package_pattern] = STATE(5519),
    [sym_parenthesized_binding_pattern] = STATE(5519),
    [sym_attribute] = STATE(2453),
    [sym_extension] = STATE(5519),
    [sym_quoted_extension] = STATE(5519),
    [sym__constant] = STATE(5408),
    [sym__signed_constant] = STATE(5363),
    [sym_number] = STATE(5367),
    [sym_signed_number] = STATE(5408),
    [sym_character] = STATE(5367),
    [sym_string] = STATE(5367),
    [sym_quoted_string] = STATE(5367),
    [sym_boolean] = STATE(5367),
    [sym_unit] = STATE(5367),
    [sym__value_name] = STATE(5519),
    [sym_parenthesized_operator] = STATE(5498),
    [sym_module_path] = STATE(20448),
    [sym_constructor_path] = STATE(2453),
    [sym__constructor_name] = STATE(5364),
    [sym_tag] = STATE(2451),
    [sym__lowercase_identifier] = ACTIONS(5157),
    [anon_sym_SEMI_SEMI] = ACTIONS(5077),
    [anon_sym_let] = ACTIONS(5079),
    [anon_sym_and] = ACTIONS(5079),
    [anon_sym_COLON_GT] = ACTIONS(5077),
    [anon_sym_EQ] = ACTIONS(5077),
    [anon_sym_TILDE] = ACTIONS(5077),
    [anon_sym_QMARK] = ACTIONS(5077),
    [anon_sym_LPAREN] = ACTIONS(5159),
    [anon_sym_external] = ACTIONS(5079),
    [anon_sym_type] = ACTIONS(5079),
    [anon_sym_COMMA] = ACTIONS(5077),
    [anon_sym_PIPE] = ACTIONS(5077),
    [anon_sym_LBRACK] = ACTIONS(5161),
    [anon_sym_RBRACK] = ACTIONS(5077),
    [anon_sym_true] = ACTIONS(5163),
    [anon_sym_false] = ACTIONS(5163),
    [anon_sym_COLON2] = ACTIONS(5079),
    [anon_sym_LBRACE] = ACTIONS(5165),
    [anon_sym_exception] = ACTIONS(5079),
    [anon_sym_module] = ACTIONS(5079),
    [anon_sym_open] = ACTIONS(5079),
    [anon_sym_include] = ACTIONS(5079),
    [anon_sym_class] = ACTIONS(5079),
    [anon_sym_in] = ACTIONS(5079),
    [anon_sym_as] = ACTIONS(5079),
    [anon_sym_POUND] = ACTIONS(5167),
    [anon_sym_COLON_COLON] = ACTIONS(5077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5169),
    [anon_sym_lazy] = ACTIONS(5171),
    [anon_sym_begin] = ACTIONS(5173),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5079),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5077),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5175),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5177),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5077),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5077),
    [aux_sym_number_token1] = ACTIONS(5179),
    [aux_sym_signed_number_token1] = ACTIONS(5181),
    [anon_sym_SQUOTE] = ACTIONS(5183),
    [anon_sym_DQUOTE] = ACTIONS(5185),
    [sym_let_operator] = ACTIONS(5077),
    [sym_let_and_operator] = ACTIONS(5077),
    [sym__uppercase_identifier] = ACTIONS(5187),
    [aux_sym_directive_token1] = ACTIONS(5079),
    [aux_sym_tag_token1] = ACTIONS(5189),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2454] = {
    [sym__abstract_type] = STATE(19462),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13625),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2454),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__infix_operator] = STATE(17787),
    [sym_add_operator] = STATE(20475),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_RPAREN] = ACTIONS(5191),
    [anon_sym_type] = ACTIONS(4951),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_DOT] = ACTIONS(5193),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_module] = ACTIONS(5195),
    [anon_sym_POUND] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(5197),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(4983),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym_prefix_operator] = ACTIONS(5199),
    [aux_sym_sign_operator_token1] = ACTIONS(1469),
    [sym_hash_operator] = ACTIONS(5199),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(5199),
    [sym_let_and_operator] = ACTIONS(5199),
    [sym_match_operator] = ACTIONS(5199),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2455] = {
    [sym__binding_pattern] = STATE(5652),
    [sym_alias_binding_pattern] = STATE(5668),
    [sym_typed_binding_pattern] = STATE(5668),
    [sym_or_binding_pattern] = STATE(5668),
    [sym_constructor_binding_pattern] = STATE(5668),
    [sym_tag_binding_pattern] = STATE(5668),
    [sym_polymorphic_variant_pattern] = STATE(5668),
    [sym_tuple_binding_pattern] = STATE(5668),
    [sym_record_binding_pattern] = STATE(5664),
    [sym_list_binding_pattern] = STATE(5663),
    [sym_cons_binding_pattern] = STATE(5668),
    [sym_array_binding_pattern] = STATE(5626),
    [sym_range_pattern] = STATE(5668),
    [sym_lazy_binding_pattern] = STATE(5668),
    [sym_local_open_binding_pattern] = STATE(5668),
    [sym_package_pattern] = STATE(5668),
    [sym_parenthesized_binding_pattern] = STATE(5668),
    [sym_attribute] = STATE(2455),
    [sym_extension] = STATE(5668),
    [sym_quoted_extension] = STATE(5668),
    [sym__constant] = STATE(5523),
    [sym__signed_constant] = STATE(5443),
    [sym_number] = STATE(5445),
    [sym_signed_number] = STATE(5523),
    [sym_character] = STATE(5445),
    [sym_string] = STATE(5445),
    [sym_quoted_string] = STATE(5445),
    [sym_boolean] = STATE(5445),
    [sym_unit] = STATE(5445),
    [sym__value_name] = STATE(5668),
    [sym_parenthesized_operator] = STATE(5725),
    [sym_module_path] = STATE(18726),
    [sym_constructor_path] = STATE(2456),
    [sym__constructor_name] = STATE(5444),
    [sym_tag] = STATE(2455),
    [sym__lowercase_identifier] = ACTIONS(5201),
    [anon_sym_SEMI_SEMI] = ACTIONS(5077),
    [anon_sym_let] = ACTIONS(5079),
    [anon_sym_and] = ACTIONS(5079),
    [anon_sym_COLON_GT] = ACTIONS(5077),
    [anon_sym_EQ] = ACTIONS(5077),
    [anon_sym_TILDE] = ACTIONS(5077),
    [anon_sym_QMARK] = ACTIONS(5077),
    [anon_sym_LPAREN] = ACTIONS(5203),
    [anon_sym_external] = ACTIONS(5079),
    [anon_sym_type] = ACTIONS(5079),
    [anon_sym_COMMA] = ACTIONS(5077),
    [anon_sym_PIPE] = ACTIONS(5077),
    [anon_sym_LBRACK] = ACTIONS(5205),
    [anon_sym_true] = ACTIONS(5207),
    [anon_sym_false] = ACTIONS(5207),
    [anon_sym_COLON2] = ACTIONS(5079),
    [anon_sym_LBRACE] = ACTIONS(5209),
    [anon_sym_exception] = ACTIONS(5079),
    [anon_sym_module] = ACTIONS(5079),
    [anon_sym_open] = ACTIONS(5079),
    [anon_sym_include] = ACTIONS(5079),
    [anon_sym_class] = ACTIONS(5079),
    [anon_sym_end] = ACTIONS(5079),
    [anon_sym_as] = ACTIONS(5079),
    [anon_sym_POUND] = ACTIONS(5211),
    [anon_sym_COLON_COLON] = ACTIONS(5077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5213),
    [anon_sym_lazy] = ACTIONS(5215),
    [anon_sym_begin] = ACTIONS(5217),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5079),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5077),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5219),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5221),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5077),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5077),
    [aux_sym_number_token1] = ACTIONS(5223),
    [aux_sym_signed_number_token1] = ACTIONS(5225),
    [anon_sym_SQUOTE] = ACTIONS(5227),
    [anon_sym_DQUOTE] = ACTIONS(5229),
    [sym_let_operator] = ACTIONS(5077),
    [sym_let_and_operator] = ACTIONS(5077),
    [sym__uppercase_identifier] = ACTIONS(5231),
    [aux_sym_directive_token1] = ACTIONS(5079),
    [aux_sym_tag_token1] = ACTIONS(5233),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2456] = {
    [sym__binding_pattern] = STATE(5653),
    [sym_alias_binding_pattern] = STATE(5668),
    [sym_typed_binding_pattern] = STATE(5668),
    [sym_or_binding_pattern] = STATE(5668),
    [sym_constructor_binding_pattern] = STATE(5668),
    [sym_tag_binding_pattern] = STATE(5668),
    [sym_polymorphic_variant_pattern] = STATE(5668),
    [sym_tuple_binding_pattern] = STATE(5668),
    [sym_record_binding_pattern] = STATE(5664),
    [sym_list_binding_pattern] = STATE(5663),
    [sym_cons_binding_pattern] = STATE(5668),
    [sym_array_binding_pattern] = STATE(5626),
    [sym_range_pattern] = STATE(5668),
    [sym_lazy_binding_pattern] = STATE(5668),
    [sym_local_open_binding_pattern] = STATE(5668),
    [sym_package_pattern] = STATE(5668),
    [sym_parenthesized_binding_pattern] = STATE(5668),
    [sym_attribute] = STATE(2456),
    [sym_extension] = STATE(5668),
    [sym_quoted_extension] = STATE(5668),
    [sym__constant] = STATE(5523),
    [sym__signed_constant] = STATE(5443),
    [sym_number] = STATE(5445),
    [sym_signed_number] = STATE(5523),
    [sym_character] = STATE(5445),
    [sym_string] = STATE(5445),
    [sym_quoted_string] = STATE(5445),
    [sym_boolean] = STATE(5445),
    [sym_unit] = STATE(5445),
    [sym__value_name] = STATE(5668),
    [sym_parenthesized_operator] = STATE(5725),
    [sym_module_path] = STATE(18726),
    [sym_constructor_path] = STATE(2456),
    [sym__constructor_name] = STATE(5444),
    [sym_tag] = STATE(2455),
    [sym__lowercase_identifier] = ACTIONS(5201),
    [anon_sym_SEMI_SEMI] = ACTIONS(5077),
    [anon_sym_let] = ACTIONS(5079),
    [anon_sym_and] = ACTIONS(5079),
    [anon_sym_COLON_GT] = ACTIONS(5077),
    [anon_sym_EQ] = ACTIONS(5077),
    [anon_sym_TILDE] = ACTIONS(5077),
    [anon_sym_QMARK] = ACTIONS(5077),
    [anon_sym_LPAREN] = ACTIONS(5203),
    [anon_sym_external] = ACTIONS(5079),
    [anon_sym_type] = ACTIONS(5079),
    [anon_sym_COMMA] = ACTIONS(5077),
    [anon_sym_PIPE] = ACTIONS(5077),
    [anon_sym_LBRACK] = ACTIONS(5205),
    [anon_sym_true] = ACTIONS(5207),
    [anon_sym_false] = ACTIONS(5207),
    [anon_sym_COLON2] = ACTIONS(5079),
    [anon_sym_LBRACE] = ACTIONS(5209),
    [anon_sym_exception] = ACTIONS(5079),
    [anon_sym_module] = ACTIONS(5079),
    [anon_sym_open] = ACTIONS(5079),
    [anon_sym_include] = ACTIONS(5079),
    [anon_sym_class] = ACTIONS(5079),
    [anon_sym_end] = ACTIONS(5079),
    [anon_sym_as] = ACTIONS(5079),
    [anon_sym_POUND] = ACTIONS(5211),
    [anon_sym_COLON_COLON] = ACTIONS(5077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5213),
    [anon_sym_lazy] = ACTIONS(5215),
    [anon_sym_begin] = ACTIONS(5217),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5079),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5077),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5219),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5221),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5077),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5077),
    [aux_sym_number_token1] = ACTIONS(5223),
    [aux_sym_signed_number_token1] = ACTIONS(5225),
    [anon_sym_SQUOTE] = ACTIONS(5227),
    [anon_sym_DQUOTE] = ACTIONS(5229),
    [sym_let_operator] = ACTIONS(5077),
    [sym_let_and_operator] = ACTIONS(5077),
    [sym__uppercase_identifier] = ACTIONS(5231),
    [aux_sym_directive_token1] = ACTIONS(5079),
    [aux_sym_tag_token1] = ACTIONS(5233),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2457] = {
    [sym__simple_expression] = STATE(5915),
    [sym_typed_expression] = STATE(6138),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_labeled_argument] = STATE(7428),
    [sym_prefix_expression] = STATE(6138),
    [sym_hash_expression] = STATE(6138),
    [sym_field_get_expression] = STATE(6138),
    [sym_array_get_expression] = STATE(6138),
    [sym_string_get_expression] = STATE(6138),
    [sym_bigarray_get_expression] = STATE(6138),
    [sym_coercion_expression] = STATE(6138),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(2457),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [aux_sym_class_application_repeat1] = STATE(2489),
    [sym__lowercase_identifier] = ACTIONS(5235),
    [anon_sym_TILDE] = ACTIONS(5237),
    [anon_sym_QMARK] = ACTIONS(5237),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_SEMI] = ACTIONS(3051),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_POUND] = ACTIONS(5241),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_else] = ACTIONS(3053),
    [anon_sym_to] = ACTIONS(3053),
    [anon_sym_downto] = ACTIONS(3053),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(5243),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2458] = {
    [sym__binding_pattern] = STATE(5715),
    [sym_alias_binding_pattern] = STATE(5731),
    [sym_typed_binding_pattern] = STATE(5731),
    [sym_or_binding_pattern] = STATE(5731),
    [sym_constructor_binding_pattern] = STATE(5731),
    [sym_tag_binding_pattern] = STATE(5731),
    [sym_polymorphic_variant_pattern] = STATE(5731),
    [sym_tuple_binding_pattern] = STATE(5731),
    [sym_record_binding_pattern] = STATE(5729),
    [sym_list_binding_pattern] = STATE(5723),
    [sym_cons_binding_pattern] = STATE(5731),
    [sym_array_binding_pattern] = STATE(5721),
    [sym_range_pattern] = STATE(5731),
    [sym_lazy_binding_pattern] = STATE(5731),
    [sym_local_open_binding_pattern] = STATE(5731),
    [sym_package_pattern] = STATE(5731),
    [sym_parenthesized_binding_pattern] = STATE(5731),
    [sym_attribute] = STATE(2458),
    [sym_extension] = STATE(5731),
    [sym_quoted_extension] = STATE(5731),
    [sym__constant] = STATE(5522),
    [sym__signed_constant] = STATE(5482),
    [sym_number] = STATE(5551),
    [sym_signed_number] = STATE(5522),
    [sym_character] = STATE(5551),
    [sym_string] = STATE(5551),
    [sym_quoted_string] = STATE(5551),
    [sym_boolean] = STATE(5551),
    [sym_unit] = STATE(5551),
    [sym__value_name] = STATE(5731),
    [sym_parenthesized_operator] = STATE(5674),
    [sym_module_path] = STATE(19030),
    [sym_constructor_path] = STATE(2459),
    [sym__constructor_name] = STATE(5554),
    [sym_tag] = STATE(2458),
    [sym__lowercase_identifier] = ACTIONS(5245),
    [anon_sym_SEMI_SEMI] = ACTIONS(5077),
    [anon_sym_let] = ACTIONS(5079),
    [anon_sym_and] = ACTIONS(5079),
    [anon_sym_COLON_GT] = ACTIONS(5077),
    [anon_sym_EQ] = ACTIONS(5077),
    [anon_sym_TILDE] = ACTIONS(5077),
    [anon_sym_QMARK] = ACTIONS(5077),
    [anon_sym_LPAREN] = ACTIONS(5247),
    [anon_sym_external] = ACTIONS(5079),
    [anon_sym_type] = ACTIONS(5079),
    [anon_sym_COMMA] = ACTIONS(5077),
    [anon_sym_PIPE] = ACTIONS(5077),
    [anon_sym_LBRACK] = ACTIONS(5249),
    [anon_sym_RBRACK] = ACTIONS(5077),
    [anon_sym_true] = ACTIONS(5251),
    [anon_sym_false] = ACTIONS(5251),
    [anon_sym_COLON2] = ACTIONS(5079),
    [anon_sym_LBRACE] = ACTIONS(5253),
    [anon_sym_exception] = ACTIONS(5079),
    [anon_sym_module] = ACTIONS(5079),
    [anon_sym_open] = ACTIONS(5079),
    [anon_sym_include] = ACTIONS(5079),
    [anon_sym_class] = ACTIONS(5079),
    [anon_sym_as] = ACTIONS(5079),
    [anon_sym_POUND] = ACTIONS(5255),
    [anon_sym_COLON_COLON] = ACTIONS(5077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5257),
    [anon_sym_lazy] = ACTIONS(5259),
    [anon_sym_begin] = ACTIONS(5261),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5079),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5077),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5263),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5265),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5077),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5077),
    [aux_sym_number_token1] = ACTIONS(5267),
    [aux_sym_signed_number_token1] = ACTIONS(5269),
    [anon_sym_SQUOTE] = ACTIONS(5271),
    [anon_sym_DQUOTE] = ACTIONS(5273),
    [sym_let_operator] = ACTIONS(5077),
    [sym_let_and_operator] = ACTIONS(5077),
    [sym__uppercase_identifier] = ACTIONS(5275),
    [aux_sym_directive_token1] = ACTIONS(5079),
    [aux_sym_tag_token1] = ACTIONS(5277),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2459] = {
    [sym__binding_pattern] = STATE(5716),
    [sym_alias_binding_pattern] = STATE(5731),
    [sym_typed_binding_pattern] = STATE(5731),
    [sym_or_binding_pattern] = STATE(5731),
    [sym_constructor_binding_pattern] = STATE(5731),
    [sym_tag_binding_pattern] = STATE(5731),
    [sym_polymorphic_variant_pattern] = STATE(5731),
    [sym_tuple_binding_pattern] = STATE(5731),
    [sym_record_binding_pattern] = STATE(5729),
    [sym_list_binding_pattern] = STATE(5723),
    [sym_cons_binding_pattern] = STATE(5731),
    [sym_array_binding_pattern] = STATE(5721),
    [sym_range_pattern] = STATE(5731),
    [sym_lazy_binding_pattern] = STATE(5731),
    [sym_local_open_binding_pattern] = STATE(5731),
    [sym_package_pattern] = STATE(5731),
    [sym_parenthesized_binding_pattern] = STATE(5731),
    [sym_attribute] = STATE(2459),
    [sym_extension] = STATE(5731),
    [sym_quoted_extension] = STATE(5731),
    [sym__constant] = STATE(5522),
    [sym__signed_constant] = STATE(5482),
    [sym_number] = STATE(5551),
    [sym_signed_number] = STATE(5522),
    [sym_character] = STATE(5551),
    [sym_string] = STATE(5551),
    [sym_quoted_string] = STATE(5551),
    [sym_boolean] = STATE(5551),
    [sym_unit] = STATE(5551),
    [sym__value_name] = STATE(5731),
    [sym_parenthesized_operator] = STATE(5674),
    [sym_module_path] = STATE(19030),
    [sym_constructor_path] = STATE(2459),
    [sym__constructor_name] = STATE(5554),
    [sym_tag] = STATE(2458),
    [sym__lowercase_identifier] = ACTIONS(5245),
    [anon_sym_SEMI_SEMI] = ACTIONS(5077),
    [anon_sym_let] = ACTIONS(5079),
    [anon_sym_and] = ACTIONS(5079),
    [anon_sym_COLON_GT] = ACTIONS(5077),
    [anon_sym_EQ] = ACTIONS(5077),
    [anon_sym_TILDE] = ACTIONS(5077),
    [anon_sym_QMARK] = ACTIONS(5077),
    [anon_sym_LPAREN] = ACTIONS(5247),
    [anon_sym_external] = ACTIONS(5079),
    [anon_sym_type] = ACTIONS(5079),
    [anon_sym_COMMA] = ACTIONS(5077),
    [anon_sym_PIPE] = ACTIONS(5077),
    [anon_sym_LBRACK] = ACTIONS(5249),
    [anon_sym_RBRACK] = ACTIONS(5077),
    [anon_sym_true] = ACTIONS(5251),
    [anon_sym_false] = ACTIONS(5251),
    [anon_sym_COLON2] = ACTIONS(5079),
    [anon_sym_LBRACE] = ACTIONS(5253),
    [anon_sym_exception] = ACTIONS(5079),
    [anon_sym_module] = ACTIONS(5079),
    [anon_sym_open] = ACTIONS(5079),
    [anon_sym_include] = ACTIONS(5079),
    [anon_sym_class] = ACTIONS(5079),
    [anon_sym_as] = ACTIONS(5079),
    [anon_sym_POUND] = ACTIONS(5255),
    [anon_sym_COLON_COLON] = ACTIONS(5077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5257),
    [anon_sym_lazy] = ACTIONS(5259),
    [anon_sym_begin] = ACTIONS(5261),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5079),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5077),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5263),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5265),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5077),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5077),
    [aux_sym_number_token1] = ACTIONS(5267),
    [aux_sym_signed_number_token1] = ACTIONS(5269),
    [anon_sym_SQUOTE] = ACTIONS(5271),
    [anon_sym_DQUOTE] = ACTIONS(5273),
    [sym_let_operator] = ACTIONS(5077),
    [sym_let_and_operator] = ACTIONS(5077),
    [sym__uppercase_identifier] = ACTIONS(5275),
    [aux_sym_directive_token1] = ACTIONS(5079),
    [aux_sym_tag_token1] = ACTIONS(5277),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2460] = {
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13678),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2460),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__infix_operator] = STATE(20476),
    [sym_add_operator] = STATE(20475),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_RPAREN] = ACTIONS(2105),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_DOT] = ACTIONS(1941),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_module] = ACTIONS(5143),
    [anon_sym_POUND] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(5279),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(4983),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym_prefix_operator] = ACTIONS(1949),
    [aux_sym_sign_operator_token1] = ACTIONS(1469),
    [sym_hash_operator] = ACTIONS(1949),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1949),
    [sym_let_and_operator] = ACTIONS(1949),
    [sym_match_operator] = ACTIONS(1949),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2461] = {
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13428),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2461),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__infix_operator] = STATE(18376),
    [sym_add_operator] = STATE(20475),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_RPAREN] = ACTIONS(5113),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_DOT] = ACTIONS(5115),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_module] = ACTIONS(5117),
    [anon_sym_POUND] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(5119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(4983),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym_prefix_operator] = ACTIONS(5121),
    [aux_sym_sign_operator_token1] = ACTIONS(1469),
    [sym_hash_operator] = ACTIONS(5121),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(5121),
    [sym_let_and_operator] = ACTIONS(5121),
    [sym_match_operator] = ACTIONS(5121),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2462] = {
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13450),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2462),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__infix_operator] = STATE(18200),
    [sym_add_operator] = STATE(20475),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_RPAREN] = ACTIONS(5065),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_DOT] = ACTIONS(5067),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_module] = ACTIONS(5069),
    [anon_sym_POUND] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(5071),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(4983),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym_prefix_operator] = ACTIONS(5073),
    [aux_sym_sign_operator_token1] = ACTIONS(1469),
    [sym_hash_operator] = ACTIONS(5073),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(5073),
    [sym_let_and_operator] = ACTIONS(5073),
    [sym_match_operator] = ACTIONS(5073),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2463] = {
    [sym__simple_expression] = STATE(5734),
    [sym_typed_expression] = STATE(5700),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_labeled_argument] = STATE(6593),
    [sym_prefix_expression] = STATE(5700),
    [sym_hash_expression] = STATE(5700),
    [sym_field_get_expression] = STATE(5700),
    [sym_array_get_expression] = STATE(5700),
    [sym_string_get_expression] = STATE(5700),
    [sym_bigarray_get_expression] = STATE(5700),
    [sym_coercion_expression] = STATE(5700),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(2463),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [aux_sym_class_application_repeat1] = STATE(2464),
    [sym__lowercase_identifier] = ACTIONS(4815),
    [anon_sym_and] = ACTIONS(3945),
    [anon_sym_TILDE] = ACTIONS(4817),
    [anon_sym_QMARK] = ACTIONS(4817),
    [anon_sym_LPAREN] = ACTIONS(1281),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_SEMI] = ACTIONS(3943),
    [anon_sym_object] = ACTIONS(1289),
    [anon_sym_in] = ACTIONS(3945),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1293),
    [anon_sym_else] = ACTIONS(3945),
    [anon_sym_new] = ACTIONS(1311),
    [anon_sym_LBRACE_LT] = ACTIONS(1313),
    [anon_sym_begin] = ACTIONS(1315),
    [sym_ocamlyacc_value] = ACTIONS(1317),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3943),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1319),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1321),
    [aux_sym_number_token1] = ACTIONS(1323),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [sym_prefix_operator] = ACTIONS(1329),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym_let_and_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(1333),
    [aux_sym_tag_token1] = ACTIONS(1335),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2464] = {
    [sym__simple_expression] = STATE(5734),
    [sym_typed_expression] = STATE(5700),
    [sym_list_expression] = STATE(5700),
    [sym_array_expression] = STATE(5700),
    [sym_record_expression] = STATE(5700),
    [sym_labeled_argument] = STATE(6593),
    [sym_prefix_expression] = STATE(5700),
    [sym_hash_expression] = STATE(5700),
    [sym_field_get_expression] = STATE(5700),
    [sym_array_get_expression] = STATE(5700),
    [sym_string_get_expression] = STATE(5700),
    [sym_bigarray_get_expression] = STATE(5700),
    [sym_coercion_expression] = STATE(5700),
    [sym_local_open_expression] = STATE(5700),
    [sym_package_expression] = STATE(5700),
    [sym_new_expression] = STATE(5700),
    [sym_object_copy_expression] = STATE(5700),
    [sym_method_invocation] = STATE(5700),
    [sym_object_expression] = STATE(5700),
    [sym_parenthesized_expression] = STATE(5700),
    [sym_attribute] = STATE(2464),
    [sym_extension] = STATE(5700),
    [sym_quoted_extension] = STATE(5700),
    [sym__constant] = STATE(5700),
    [sym_number] = STATE(5617),
    [sym_character] = STATE(5617),
    [sym_string] = STATE(5617),
    [sym_quoted_string] = STATE(5617),
    [sym_boolean] = STATE(5617),
    [sym_unit] = STATE(5617),
    [sym__value_name] = STATE(5669),
    [sym_parenthesized_operator] = STATE(5713),
    [sym_value_path] = STATE(5700),
    [sym_module_path] = STATE(18794),
    [sym_constructor_path] = STATE(5700),
    [sym__constructor_name] = STATE(5616),
    [sym_tag] = STATE(5700),
    [aux_sym_class_application_repeat1] = STATE(2464),
    [sym__lowercase_identifier] = ACTIONS(5281),
    [anon_sym_and] = ACTIONS(3722),
    [anon_sym_TILDE] = ACTIONS(5284),
    [anon_sym_QMARK] = ACTIONS(5284),
    [anon_sym_LPAREN] = ACTIONS(5287),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(5290),
    [anon_sym_true] = ACTIONS(5293),
    [anon_sym_false] = ACTIONS(5293),
    [anon_sym_LBRACE] = ACTIONS(5296),
    [anon_sym_SEMI] = ACTIONS(3720),
    [anon_sym_object] = ACTIONS(5299),
    [anon_sym_in] = ACTIONS(3722),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5302),
    [anon_sym_else] = ACTIONS(3722),
    [anon_sym_new] = ACTIONS(5305),
    [anon_sym_LBRACE_LT] = ACTIONS(5308),
    [anon_sym_begin] = ACTIONS(5311),
    [sym_ocamlyacc_value] = ACTIONS(5314),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3720),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5317),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5320),
    [aux_sym_number_token1] = ACTIONS(5323),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(5326),
    [anon_sym_DQUOTE] = ACTIONS(5329),
    [sym_prefix_operator] = ACTIONS(5332),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym_let_and_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(5335),
    [aux_sym_tag_token1] = ACTIONS(5338),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2465] = {
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13447),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2465),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__infix_operator] = STATE(17787),
    [sym_add_operator] = STATE(20475),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_RPAREN] = ACTIONS(5191),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_DOT] = ACTIONS(5193),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_module] = ACTIONS(5195),
    [anon_sym_POUND] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(5197),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(4983),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym_prefix_operator] = ACTIONS(5199),
    [aux_sym_sign_operator_token1] = ACTIONS(1469),
    [sym_hash_operator] = ACTIONS(5199),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(5199),
    [sym_let_and_operator] = ACTIONS(5199),
    [sym_match_operator] = ACTIONS(5199),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2466] = {
    [sym__simple_expression] = STATE(6550),
    [sym_typed_expression] = STATE(6255),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_labeled_argument] = STATE(7518),
    [sym_prefix_expression] = STATE(6255),
    [sym_hash_expression] = STATE(6255),
    [sym_field_get_expression] = STATE(6255),
    [sym_array_get_expression] = STATE(6255),
    [sym_string_get_expression] = STATE(6255),
    [sym_bigarray_get_expression] = STATE(6255),
    [sym_coercion_expression] = STATE(6255),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2466),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [aux_sym_class_application_repeat1] = STATE(2499),
    [sym__lowercase_identifier] = ACTIONS(5341),
    [anon_sym_TILDE] = ACTIONS(5343),
    [anon_sym_QMARK] = ACTIONS(5343),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_DOT] = ACTIONS(5345),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_SEMI] = ACTIONS(3051),
    [anon_sym_end] = ACTIONS(3053),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_POUND] = ACTIONS(5347),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_else] = ACTIONS(3053),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(5349),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2467] = {
    [sym__simple_expression] = STATE(6366),
    [sym_typed_expression] = STATE(6357),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_labeled_argument] = STATE(7545),
    [sym_prefix_expression] = STATE(6357),
    [sym_hash_expression] = STATE(6357),
    [sym_field_get_expression] = STATE(6357),
    [sym_array_get_expression] = STATE(6357),
    [sym_string_get_expression] = STATE(6357),
    [sym_bigarray_get_expression] = STATE(6357),
    [sym_coercion_expression] = STATE(6357),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2467),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [aux_sym_class_application_repeat1] = STATE(2503),
    [sym__lowercase_identifier] = ACTIONS(5351),
    [anon_sym_TILDE] = ACTIONS(5353),
    [anon_sym_QMARK] = ACTIONS(5353),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_DOT] = ACTIONS(5355),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_SEMI] = ACTIONS(3051),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_POUND] = ACTIONS(5357),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_else] = ACTIONS(3053),
    [anon_sym_do] = ACTIONS(3053),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(5359),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2468] = {
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13424),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2468),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__infix_operator] = STATE(18042),
    [sym_add_operator] = STATE(20475),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_RPAREN] = ACTIONS(4949),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_DOT] = ACTIONS(4957),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_module] = ACTIONS(4963),
    [anon_sym_POUND] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(4967),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(4983),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym_prefix_operator] = ACTIONS(4989),
    [aux_sym_sign_operator_token1] = ACTIONS(1469),
    [sym_hash_operator] = ACTIONS(4989),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(4989),
    [sym_let_and_operator] = ACTIONS(4989),
    [sym_match_operator] = ACTIONS(4989),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2469] = {
    [sym__simple_expression] = STATE(6518),
    [sym_typed_expression] = STATE(6303),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_labeled_argument] = STATE(7569),
    [sym_prefix_expression] = STATE(6303),
    [sym_hash_expression] = STATE(6303),
    [sym_field_get_expression] = STATE(6303),
    [sym_array_get_expression] = STATE(6303),
    [sym_string_get_expression] = STATE(6303),
    [sym_bigarray_get_expression] = STATE(6303),
    [sym_coercion_expression] = STATE(6303),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(2469),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [aux_sym_class_application_repeat1] = STATE(2508),
    [sym__lowercase_identifier] = ACTIONS(5361),
    [anon_sym_TILDE] = ACTIONS(5363),
    [anon_sym_QMARK] = ACTIONS(5363),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_DOT] = ACTIONS(5365),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_SEMI] = ACTIONS(3051),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_POUND] = ACTIONS(5367),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_to] = ACTIONS(3053),
    [anon_sym_downto] = ACTIONS(3053),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(5369),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2470] = {
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13430),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2470),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__infix_operator] = STATE(19859),
    [sym_add_operator] = STATE(20475),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_RPAREN] = ACTIONS(5147),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_DOT] = ACTIONS(5149),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_module] = ACTIONS(5151),
    [anon_sym_POUND] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(5153),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(4983),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym_prefix_operator] = ACTIONS(5155),
    [aux_sym_sign_operator_token1] = ACTIONS(1469),
    [sym_hash_operator] = ACTIONS(5155),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(5155),
    [sym_let_and_operator] = ACTIONS(5155),
    [sym_match_operator] = ACTIONS(5155),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2471] = {
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13678),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2471),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__infix_operator] = STATE(20476),
    [sym_add_operator] = STATE(20475),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_RPAREN] = ACTIONS(2105),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_DOT] = ACTIONS(1941),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_module] = ACTIONS(5143),
    [anon_sym_POUND] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(5145),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(4983),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym_prefix_operator] = ACTIONS(1949),
    [aux_sym_sign_operator_token1] = ACTIONS(1469),
    [sym_hash_operator] = ACTIONS(1949),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1949),
    [sym_let_and_operator] = ACTIONS(1949),
    [sym_match_operator] = ACTIONS(1949),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2472] = {
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13423),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2472),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__infix_operator] = STATE(19488),
    [sym_add_operator] = STATE(20475),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_RPAREN] = ACTIONS(5133),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_DOT] = ACTIONS(5135),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_module] = ACTIONS(5137),
    [anon_sym_POUND] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(5139),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(4983),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym_prefix_operator] = ACTIONS(5141),
    [aux_sym_sign_operator_token1] = ACTIONS(1469),
    [sym_hash_operator] = ACTIONS(5141),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(5141),
    [sym_let_and_operator] = ACTIONS(5141),
    [sym_match_operator] = ACTIONS(5141),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2473] = {
    [sym__simple_expression] = STATE(6274),
    [sym_typed_expression] = STATE(6539),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_labeled_argument] = STATE(7553),
    [sym_prefix_expression] = STATE(6539),
    [sym_hash_expression] = STATE(6539),
    [sym_field_get_expression] = STATE(6539),
    [sym_array_get_expression] = STATE(6539),
    [sym_string_get_expression] = STATE(6539),
    [sym_bigarray_get_expression] = STATE(6539),
    [sym_coercion_expression] = STATE(6539),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(2473),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [aux_sym_class_application_repeat1] = STATE(2509),
    [sym__lowercase_identifier] = ACTIONS(5371),
    [anon_sym_TILDE] = ACTIONS(5373),
    [anon_sym_QMARK] = ACTIONS(5373),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_DOT] = ACTIONS(5375),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_SEMI] = ACTIONS(3051),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_POUND] = ACTIONS(5377),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_then] = ACTIONS(3053),
    [anon_sym_else] = ACTIONS(3053),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(5379),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2474] = {
    [sym__simple_expression] = STATE(6644),
    [sym_typed_expression] = STATE(6258),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_labeled_argument] = STATE(7533),
    [sym_prefix_expression] = STATE(6258),
    [sym_hash_expression] = STATE(6258),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_coercion_expression] = STATE(6258),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(2474),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [aux_sym_class_application_repeat1] = STATE(2505),
    [sym__lowercase_identifier] = ACTIONS(5381),
    [anon_sym_TILDE] = ACTIONS(5383),
    [anon_sym_QMARK] = ACTIONS(5383),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_DOT] = ACTIONS(5385),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_SEMI] = ACTIONS(3051),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_POUND] = ACTIONS(5387),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_else] = ACTIONS(3053),
    [anon_sym_done] = ACTIONS(3053),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(5389),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2475] = {
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13678),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2475),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__infix_operator] = STATE(20476),
    [sym_add_operator] = STATE(20475),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_RPAREN] = ACTIONS(2105),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_DOT] = ACTIONS(1941),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_module] = ACTIONS(5143),
    [anon_sym_POUND] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(5391),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(4983),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym_prefix_operator] = ACTIONS(1949),
    [aux_sym_sign_operator_token1] = ACTIONS(1469),
    [sym_hash_operator] = ACTIONS(1949),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1949),
    [sym_let_and_operator] = ACTIONS(1949),
    [sym_match_operator] = ACTIONS(1949),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2476] = {
    [sym__simple_expression] = STATE(6458),
    [sym_typed_expression] = STATE(6162),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_labeled_argument] = STATE(7502),
    [sym_prefix_expression] = STATE(6162),
    [sym_hash_expression] = STATE(6162),
    [sym_field_get_expression] = STATE(6162),
    [sym_array_get_expression] = STATE(6162),
    [sym_string_get_expression] = STATE(6162),
    [sym_bigarray_get_expression] = STATE(6162),
    [sym_coercion_expression] = STATE(6162),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(2476),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [aux_sym_class_application_repeat1] = STATE(2507),
    [sym__lowercase_identifier] = ACTIONS(5393),
    [anon_sym_TILDE] = ACTIONS(5395),
    [anon_sym_QMARK] = ACTIONS(5395),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_DOT] = ACTIONS(5397),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_SEMI] = ACTIONS(3051),
    [anon_sym_with] = ACTIONS(3053),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_POUND] = ACTIONS(5399),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_else] = ACTIONS(3053),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(5401),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2477] = {
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13806),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2477),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__infix_operator] = STATE(18720),
    [sym_add_operator] = STATE(20475),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_RPAREN] = ACTIONS(5123),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_DOT] = ACTIONS(5125),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_module] = ACTIONS(5127),
    [anon_sym_POUND] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(5403),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(4983),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym_prefix_operator] = ACTIONS(5131),
    [aux_sym_sign_operator_token1] = ACTIONS(1469),
    [sym_hash_operator] = ACTIONS(5131),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(5131),
    [sym_let_and_operator] = ACTIONS(5131),
    [sym_match_operator] = ACTIONS(5131),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2478] = {
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13806),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2478),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__infix_operator] = STATE(18720),
    [sym_add_operator] = STATE(20475),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_RPAREN] = ACTIONS(5123),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_DOT] = ACTIONS(5125),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_module] = ACTIONS(5127),
    [anon_sym_POUND] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(5129),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(4983),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym_prefix_operator] = ACTIONS(5131),
    [aux_sym_sign_operator_token1] = ACTIONS(1469),
    [sym_hash_operator] = ACTIONS(5131),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(5131),
    [sym_let_and_operator] = ACTIONS(5131),
    [sym_match_operator] = ACTIONS(5131),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2479] = {
    [sym__simple_expression] = STATE(5846),
    [sym_typed_expression] = STATE(5778),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_labeled_argument] = STATE(7016),
    [sym_prefix_expression] = STATE(5778),
    [sym_hash_expression] = STATE(5778),
    [sym_field_get_expression] = STATE(5778),
    [sym_array_get_expression] = STATE(5778),
    [sym_string_get_expression] = STATE(5778),
    [sym_bigarray_get_expression] = STATE(5778),
    [sym_coercion_expression] = STATE(5778),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(2479),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [aux_sym_class_application_repeat1] = STATE(2479),
    [sym__lowercase_identifier] = ACTIONS(5405),
    [anon_sym_and] = ACTIONS(3722),
    [anon_sym_TILDE] = ACTIONS(5408),
    [anon_sym_QMARK] = ACTIONS(5408),
    [anon_sym_LPAREN] = ACTIONS(5411),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(5414),
    [anon_sym_true] = ACTIONS(5417),
    [anon_sym_false] = ACTIONS(5417),
    [anon_sym_LBRACE] = ACTIONS(5420),
    [anon_sym_SEMI] = ACTIONS(3720),
    [anon_sym_object] = ACTIONS(5423),
    [anon_sym_in] = ACTIONS(3722),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5426),
    [anon_sym_new] = ACTIONS(5429),
    [anon_sym_LBRACE_LT] = ACTIONS(5432),
    [anon_sym_begin] = ACTIONS(5435),
    [sym_ocamlyacc_value] = ACTIONS(5438),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3720),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5441),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5444),
    [aux_sym_number_token1] = ACTIONS(5447),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(5450),
    [anon_sym_DQUOTE] = ACTIONS(5453),
    [sym_prefix_operator] = ACTIONS(5456),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym_let_and_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(5459),
    [aux_sym_tag_token1] = ACTIONS(5462),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2480] = {
    [sym_parameter] = STATE(10266),
    [sym__polymorphic_typed] = STATE(16576),
    [sym__parenthesized_abstract_type] = STATE(10266),
    [sym__simple_pattern] = STATE(10267),
    [sym_typed_pattern] = STATE(10147),
    [sym_polymorphic_variant_pattern] = STATE(10147),
    [sym_record_pattern] = STATE(10147),
    [sym_list_pattern] = STATE(10147),
    [sym_array_pattern] = STATE(10147),
    [sym_local_open_pattern] = STATE(10147),
    [sym_package_pattern] = STATE(10147),
    [sym_parenthesized_pattern] = STATE(10147),
    [sym_attribute] = STATE(2480),
    [sym_item_attribute] = STATE(11071),
    [sym_extension] = STATE(10147),
    [sym_quoted_extension] = STATE(10147),
    [sym__constant] = STATE(10250),
    [sym__signed_constant] = STATE(10147),
    [sym_number] = STATE(10120),
    [sym_signed_number] = STATE(10250),
    [sym_character] = STATE(10120),
    [sym_string] = STATE(10120),
    [sym_quoted_string] = STATE(10120),
    [sym_boolean] = STATE(10120),
    [sym_unit] = STATE(10120),
    [sym__simple_value_pattern] = STATE(10147),
    [sym_parenthesized_operator] = STATE(10147),
    [sym_module_path] = STATE(20425),
    [sym_constructor_path] = STATE(10147),
    [sym__constructor_name] = STATE(8440),
    [sym_tag] = STATE(10147),
    [aux_sym_expression_item_repeat1] = STATE(10609),
    [aux_sym_let_binding_repeat1] = STATE(4621),
    [sym__lowercase_identifier] = ACTIONS(5465),
    [anon_sym_SEMI_SEMI] = ACTIONS(5467),
    [anon_sym_let] = ACTIONS(5469),
    [anon_sym_and] = ACTIONS(5469),
    [anon_sym_COLON_GT] = ACTIONS(5471),
    [anon_sym_EQ] = ACTIONS(5473),
    [anon_sym_TILDE] = ACTIONS(5475),
    [anon_sym_QMARK] = ACTIONS(5475),
    [anon_sym_LPAREN] = ACTIONS(5477),
    [anon_sym_external] = ACTIONS(5469),
    [anon_sym_type] = ACTIONS(5469),
    [anon_sym_COMMA] = ACTIONS(5479),
    [anon_sym_PIPE] = ACTIONS(5481),
    [anon_sym_LBRACK] = ACTIONS(5483),
    [anon_sym_RBRACK] = ACTIONS(5467),
    [anon_sym_true] = ACTIONS(5485),
    [anon_sym_false] = ACTIONS(5485),
    [anon_sym_COLON2] = ACTIONS(5487),
    [anon_sym_LBRACE] = ACTIONS(5489),
    [anon_sym_exception] = ACTIONS(5469),
    [anon_sym_module] = ACTIONS(5469),
    [anon_sym_open] = ACTIONS(5469),
    [anon_sym_include] = ACTIONS(5469),
    [anon_sym_class] = ACTIONS(5469),
    [anon_sym_in] = ACTIONS(5469),
    [anon_sym_as] = ACTIONS(5491),
    [anon_sym_POUND] = ACTIONS(5493),
    [anon_sym_COLON_COLON] = ACTIONS(5495),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5497),
    [anon_sym_begin] = ACTIONS(5499),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5501),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5467),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5503),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5505),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5467),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5467),
    [aux_sym_number_token1] = ACTIONS(5507),
    [aux_sym_signed_number_token1] = ACTIONS(5509),
    [anon_sym_SQUOTE] = ACTIONS(5511),
    [anon_sym_DQUOTE] = ACTIONS(5513),
    [sym_let_operator] = ACTIONS(5467),
    [sym_let_and_operator] = ACTIONS(5467),
    [sym__uppercase_identifier] = ACTIONS(5515),
    [aux_sym_directive_token1] = ACTIONS(5469),
    [aux_sym_tag_token1] = ACTIONS(5517),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2481] = {
    [sym__simple_expression] = STATE(6881),
    [sym_typed_expression] = STATE(7128),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_labeled_argument] = STATE(7751),
    [sym_prefix_expression] = STATE(7128),
    [sym_hash_expression] = STATE(7128),
    [sym_field_get_expression] = STATE(7128),
    [sym_array_get_expression] = STATE(7128),
    [sym_string_get_expression] = STATE(7128),
    [sym_bigarray_get_expression] = STATE(7128),
    [sym_coercion_expression] = STATE(7128),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(2481),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [aux_sym_class_application_repeat1] = STATE(2521),
    [sym__lowercase_identifier] = ACTIONS(5519),
    [anon_sym_TILDE] = ACTIONS(5521),
    [anon_sym_QMARK] = ACTIONS(5521),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_DOT] = ACTIONS(5523),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_SEMI] = ACTIONS(3051),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_POUND] = ACTIONS(5525),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_then] = ACTIONS(3053),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(5527),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2482] = {
    [sym__simple_expression] = STATE(7222),
    [sym_typed_expression] = STATE(7138),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_labeled_argument] = STATE(7791),
    [sym_prefix_expression] = STATE(7138),
    [sym_hash_expression] = STATE(7138),
    [sym_field_get_expression] = STATE(7138),
    [sym_array_get_expression] = STATE(7138),
    [sym_string_get_expression] = STATE(7138),
    [sym_bigarray_get_expression] = STATE(7138),
    [sym_coercion_expression] = STATE(7138),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(2482),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [aux_sym_class_application_repeat1] = STATE(2524),
    [sym__lowercase_identifier] = ACTIONS(5529),
    [anon_sym_TILDE] = ACTIONS(5531),
    [anon_sym_QMARK] = ACTIONS(5531),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_DOT] = ACTIONS(5533),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_SEMI] = ACTIONS(3051),
    [anon_sym_end] = ACTIONS(3053),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_POUND] = ACTIONS(5535),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(5537),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2483] = {
    [sym_parameter] = STATE(10266),
    [sym__polymorphic_typed] = STATE(16553),
    [sym__parenthesized_abstract_type] = STATE(10266),
    [sym__simple_pattern] = STATE(10267),
    [sym_typed_pattern] = STATE(10147),
    [sym_polymorphic_variant_pattern] = STATE(10147),
    [sym_record_pattern] = STATE(10147),
    [sym_list_pattern] = STATE(10147),
    [sym_array_pattern] = STATE(10147),
    [sym_local_open_pattern] = STATE(10147),
    [sym_package_pattern] = STATE(10147),
    [sym_parenthesized_pattern] = STATE(10147),
    [sym_attribute] = STATE(2483),
    [sym_item_attribute] = STATE(11071),
    [sym_extension] = STATE(10147),
    [sym_quoted_extension] = STATE(10147),
    [sym__constant] = STATE(10250),
    [sym__signed_constant] = STATE(10147),
    [sym_number] = STATE(10120),
    [sym_signed_number] = STATE(10250),
    [sym_character] = STATE(10120),
    [sym_string] = STATE(10120),
    [sym_quoted_string] = STATE(10120),
    [sym_boolean] = STATE(10120),
    [sym_unit] = STATE(10120),
    [sym__simple_value_pattern] = STATE(10147),
    [sym_parenthesized_operator] = STATE(10147),
    [sym_module_path] = STATE(20425),
    [sym_constructor_path] = STATE(10147),
    [sym__constructor_name] = STATE(8440),
    [sym_tag] = STATE(10147),
    [aux_sym_expression_item_repeat1] = STATE(10609),
    [aux_sym_let_binding_repeat1] = STATE(4651),
    [sym__lowercase_identifier] = ACTIONS(5465),
    [anon_sym_SEMI_SEMI] = ACTIONS(5467),
    [anon_sym_let] = ACTIONS(5469),
    [anon_sym_and] = ACTIONS(5469),
    [anon_sym_COLON_GT] = ACTIONS(5539),
    [anon_sym_EQ] = ACTIONS(5541),
    [anon_sym_TILDE] = ACTIONS(5475),
    [anon_sym_QMARK] = ACTIONS(5475),
    [anon_sym_LPAREN] = ACTIONS(5477),
    [anon_sym_external] = ACTIONS(5469),
    [anon_sym_type] = ACTIONS(5469),
    [anon_sym_COMMA] = ACTIONS(5543),
    [anon_sym_PIPE] = ACTIONS(5545),
    [anon_sym_LBRACK] = ACTIONS(5483),
    [anon_sym_true] = ACTIONS(5485),
    [anon_sym_false] = ACTIONS(5485),
    [anon_sym_COLON2] = ACTIONS(5487),
    [anon_sym_LBRACE] = ACTIONS(5489),
    [anon_sym_exception] = ACTIONS(5469),
    [anon_sym_module] = ACTIONS(5469),
    [anon_sym_open] = ACTIONS(5469),
    [anon_sym_include] = ACTIONS(5469),
    [anon_sym_class] = ACTIONS(5469),
    [anon_sym_end] = ACTIONS(5469),
    [anon_sym_in] = ACTIONS(5469),
    [anon_sym_as] = ACTIONS(5547),
    [anon_sym_POUND] = ACTIONS(5493),
    [anon_sym_COLON_COLON] = ACTIONS(5549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5497),
    [anon_sym_begin] = ACTIONS(5499),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5501),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5467),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5503),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5505),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5467),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5467),
    [aux_sym_number_token1] = ACTIONS(5507),
    [aux_sym_signed_number_token1] = ACTIONS(5509),
    [anon_sym_SQUOTE] = ACTIONS(5511),
    [anon_sym_DQUOTE] = ACTIONS(5513),
    [sym_let_operator] = ACTIONS(5467),
    [sym_let_and_operator] = ACTIONS(5467),
    [sym__uppercase_identifier] = ACTIONS(5515),
    [aux_sym_directive_token1] = ACTIONS(5469),
    [aux_sym_tag_token1] = ACTIONS(5517),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2484] = {
    [sym__simple_expression] = STATE(6859),
    [sym_typed_expression] = STATE(7113),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_labeled_argument] = STATE(7731),
    [sym_prefix_expression] = STATE(7113),
    [sym_hash_expression] = STATE(7113),
    [sym_field_get_expression] = STATE(7113),
    [sym_array_get_expression] = STATE(7113),
    [sym_string_get_expression] = STATE(7113),
    [sym_bigarray_get_expression] = STATE(7113),
    [sym_coercion_expression] = STATE(7113),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(2484),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [aux_sym_class_application_repeat1] = STATE(2528),
    [sym__lowercase_identifier] = ACTIONS(5551),
    [anon_sym_TILDE] = ACTIONS(5553),
    [anon_sym_QMARK] = ACTIONS(5553),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_DOT] = ACTIONS(5555),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_SEMI] = ACTIONS(3051),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_POUND] = ACTIONS(5557),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_done] = ACTIONS(3053),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(5559),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2485] = {
    [sym__simple_expression] = STATE(7103),
    [sym_typed_expression] = STATE(7067),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_labeled_argument] = STATE(7762),
    [sym_prefix_expression] = STATE(7067),
    [sym_hash_expression] = STATE(7067),
    [sym_field_get_expression] = STATE(7067),
    [sym_array_get_expression] = STATE(7067),
    [sym_string_get_expression] = STATE(7067),
    [sym_bigarray_get_expression] = STATE(7067),
    [sym_coercion_expression] = STATE(7067),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2485),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [aux_sym_class_application_repeat1] = STATE(2515),
    [sym__lowercase_identifier] = ACTIONS(5561),
    [anon_sym_TILDE] = ACTIONS(5563),
    [anon_sym_QMARK] = ACTIONS(5563),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_DOT] = ACTIONS(5565),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_SEMI] = ACTIONS(3051),
    [anon_sym_with] = ACTIONS(3053),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_POUND] = ACTIONS(5567),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(5569),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2486] = {
    [sym__simple_expression] = STATE(7151),
    [sym_typed_expression] = STATE(7193),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_labeled_argument] = STATE(7826),
    [sym_prefix_expression] = STATE(7193),
    [sym_hash_expression] = STATE(7193),
    [sym_field_get_expression] = STATE(7193),
    [sym_array_get_expression] = STATE(7193),
    [sym_string_get_expression] = STATE(7193),
    [sym_bigarray_get_expression] = STATE(7193),
    [sym_coercion_expression] = STATE(7193),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(2486),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [aux_sym_class_application_repeat1] = STATE(2518),
    [sym__lowercase_identifier] = ACTIONS(5571),
    [anon_sym_TILDE] = ACTIONS(5573),
    [anon_sym_QMARK] = ACTIONS(5573),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_COMMA] = ACTIONS(3051),
    [anon_sym_PIPE] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_DOT] = ACTIONS(5575),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_SEMI] = ACTIONS(3051),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_POUND] = ACTIONS(5577),
    [anon_sym_COLON_COLON] = ACTIONS(3051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_do] = ACTIONS(3053),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(3053),
    [sym_hash_operator] = ACTIONS(5579),
    [sym_pow_operator] = ACTIONS(3053),
    [sym_mult_operator] = ACTIONS(3053),
    [aux_sym_add_operator_token1] = ACTIONS(3053),
    [sym_concat_operator] = ACTIONS(3051),
    [sym_rel_operator] = ACTIONS(3053),
    [sym_and_operator] = ACTIONS(3053),
    [sym_or_operator] = ACTIONS(3053),
    [sym_assign_operator] = ACTIONS(3051),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2487] = {
    [sym__simple_expression] = STATE(5846),
    [sym_typed_expression] = STATE(5778),
    [sym_list_expression] = STATE(5778),
    [sym_array_expression] = STATE(5778),
    [sym_record_expression] = STATE(5778),
    [sym_labeled_argument] = STATE(7016),
    [sym_prefix_expression] = STATE(5778),
    [sym_hash_expression] = STATE(5778),
    [sym_field_get_expression] = STATE(5778),
    [sym_array_get_expression] = STATE(5778),
    [sym_string_get_expression] = STATE(5778),
    [sym_bigarray_get_expression] = STATE(5778),
    [sym_coercion_expression] = STATE(5778),
    [sym_local_open_expression] = STATE(5778),
    [sym_package_expression] = STATE(5778),
    [sym_new_expression] = STATE(5778),
    [sym_object_copy_expression] = STATE(5778),
    [sym_method_invocation] = STATE(5778),
    [sym_object_expression] = STATE(5778),
    [sym_parenthesized_expression] = STATE(5778),
    [sym_attribute] = STATE(2487),
    [sym_extension] = STATE(5778),
    [sym_quoted_extension] = STATE(5778),
    [sym__constant] = STATE(5778),
    [sym_number] = STATE(5842),
    [sym_character] = STATE(5842),
    [sym_string] = STATE(5842),
    [sym_quoted_string] = STATE(5842),
    [sym_boolean] = STATE(5842),
    [sym_unit] = STATE(5842),
    [sym__value_name] = STATE(5832),
    [sym_parenthesized_operator] = STATE(5786),
    [sym_value_path] = STATE(5778),
    [sym_module_path] = STATE(17948),
    [sym_constructor_path] = STATE(5778),
    [sym__constructor_name] = STATE(5844),
    [sym_tag] = STATE(5778),
    [aux_sym_class_application_repeat1] = STATE(2479),
    [sym__lowercase_identifier] = ACTIONS(5055),
    [anon_sym_and] = ACTIONS(3945),
    [anon_sym_TILDE] = ACTIONS(5057),
    [anon_sym_QMARK] = ACTIONS(5057),
    [anon_sym_LPAREN] = ACTIONS(1341),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_SEMI] = ACTIONS(3943),
    [anon_sym_object] = ACTIONS(1349),
    [anon_sym_in] = ACTIONS(3945),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1353),
    [anon_sym_new] = ACTIONS(1363),
    [anon_sym_LBRACE_LT] = ACTIONS(1365),
    [anon_sym_begin] = ACTIONS(1367),
    [sym_ocamlyacc_value] = ACTIONS(1369),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3943),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1371),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1373),
    [aux_sym_number_token1] = ACTIONS(1375),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [anon_sym_DQUOTE] = ACTIONS(1379),
    [sym_prefix_operator] = ACTIONS(1381),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym_let_and_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(1385),
    [aux_sym_tag_token1] = ACTIONS(1387),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2488] = {
    [sym__simple_expression] = STATE(5854),
    [sym_typed_expression] = STATE(5961),
    [sym_list_expression] = STATE(5961),
    [sym_array_expression] = STATE(5961),
    [sym_record_expression] = STATE(5961),
    [sym_labeled_argument] = STATE(7319),
    [sym_prefix_expression] = STATE(5961),
    [sym_hash_expression] = STATE(5961),
    [sym_field_get_expression] = STATE(5961),
    [sym_array_get_expression] = STATE(5961),
    [sym_string_get_expression] = STATE(5961),
    [sym_bigarray_get_expression] = STATE(5961),
    [sym_coercion_expression] = STATE(5961),
    [sym_local_open_expression] = STATE(5961),
    [sym_package_expression] = STATE(5961),
    [sym_new_expression] = STATE(5961),
    [sym_object_copy_expression] = STATE(5961),
    [sym_method_invocation] = STATE(5961),
    [sym_object_expression] = STATE(5961),
    [sym_parenthesized_expression] = STATE(5961),
    [sym_attribute] = STATE(2488),
    [sym_extension] = STATE(5961),
    [sym_quoted_extension] = STATE(5961),
    [sym__constant] = STATE(5961),
    [sym_number] = STATE(6094),
    [sym_character] = STATE(6094),
    [sym_string] = STATE(6094),
    [sym_quoted_string] = STATE(6094),
    [sym_boolean] = STATE(6094),
    [sym_unit] = STATE(6094),
    [sym__value_name] = STATE(5955),
    [sym_parenthesized_operator] = STATE(6068),
    [sym_value_path] = STATE(5961),
    [sym_module_path] = STATE(18110),
    [sym_constructor_path] = STATE(5961),
    [sym__constructor_name] = STATE(6088),
    [sym_tag] = STATE(5961),
    [aux_sym_class_application_repeat1] = STATE(2497),
    [sym__lowercase_identifier] = ACTIONS(5581),
    [anon_sym_SEMI_SEMI] = ACTIONS(5583),
    [anon_sym_let] = ACTIONS(5585),
    [anon_sym_and] = ACTIONS(5585),
    [anon_sym_TILDE] = ACTIONS(5587),
    [anon_sym_QMARK] = ACTIONS(5587),
    [anon_sym_LPAREN] = ACTIONS(5589),
    [anon_sym_external] = ACTIONS(5585),
    [anon_sym_type] = ACTIONS(5585),
    [anon_sym_LBRACK] = ACTIONS(5591),
    [anon_sym_RBRACK] = ACTIONS(5583),
    [anon_sym_true] = ACTIONS(5593),
    [anon_sym_false] = ACTIONS(5593),
    [anon_sym_LBRACE] = ACTIONS(5595),
    [anon_sym_exception] = ACTIONS(5585),
    [anon_sym_module] = ACTIONS(5585),
    [anon_sym_open] = ACTIONS(5585),
    [anon_sym_include] = ACTIONS(5585),
    [anon_sym_class] = ACTIONS(5585),
    [anon_sym_object] = ACTIONS(5597),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5599),
    [anon_sym_new] = ACTIONS(5601),
    [anon_sym_LBRACE_LT] = ACTIONS(5603),
    [anon_sym_begin] = ACTIONS(5605),
    [sym_ocamlyacc_value] = ACTIONS(5607),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5585),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5583),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5609),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5611),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5583),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5583),
    [aux_sym_number_token1] = ACTIONS(5613),
    [anon_sym_SQUOTE] = ACTIONS(5615),
    [anon_sym_DQUOTE] = ACTIONS(5617),
    [sym_prefix_operator] = ACTIONS(5619),
    [sym_let_operator] = ACTIONS(5583),
    [sym__uppercase_identifier] = ACTIONS(5621),
    [aux_sym_directive_token1] = ACTIONS(5583),
    [aux_sym_tag_token1] = ACTIONS(5623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2489] = {
    [sym__simple_expression] = STATE(5915),
    [sym_typed_expression] = STATE(6138),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_labeled_argument] = STATE(7428),
    [sym_prefix_expression] = STATE(6138),
    [sym_hash_expression] = STATE(6138),
    [sym_field_get_expression] = STATE(6138),
    [sym_array_get_expression] = STATE(6138),
    [sym_string_get_expression] = STATE(6138),
    [sym_bigarray_get_expression] = STATE(6138),
    [sym_coercion_expression] = STATE(6138),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(2489),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [aux_sym_class_application_repeat1] = STATE(2496),
    [sym__lowercase_identifier] = ACTIONS(5235),
    [anon_sym_TILDE] = ACTIONS(5237),
    [anon_sym_QMARK] = ACTIONS(5237),
    [anon_sym_LPAREN] = ACTIONS(1399),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(1401),
    [anon_sym_true] = ACTIONS(1403),
    [anon_sym_false] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_SEMI] = ACTIONS(3943),
    [anon_sym_object] = ACTIONS(1407),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1411),
    [anon_sym_else] = ACTIONS(3945),
    [anon_sym_to] = ACTIONS(3945),
    [anon_sym_downto] = ACTIONS(3945),
    [anon_sym_new] = ACTIONS(1421),
    [anon_sym_LBRACE_LT] = ACTIONS(1423),
    [anon_sym_begin] = ACTIONS(1425),
    [sym_ocamlyacc_value] = ACTIONS(1427),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1429),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1431),
    [aux_sym_number_token1] = ACTIONS(1433),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(1435),
    [anon_sym_DQUOTE] = ACTIONS(1437),
    [sym_prefix_operator] = ACTIONS(1439),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(1443),
    [aux_sym_tag_token1] = ACTIONS(1445),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2490] = {
    [sym__simple_expression] = STATE(5931),
    [sym_typed_expression] = STATE(6030),
    [sym_list_expression] = STATE(6030),
    [sym_array_expression] = STATE(6030),
    [sym_record_expression] = STATE(6030),
    [sym_labeled_argument] = STATE(7322),
    [sym_prefix_expression] = STATE(6030),
    [sym_hash_expression] = STATE(6030),
    [sym_field_get_expression] = STATE(6030),
    [sym_array_get_expression] = STATE(6030),
    [sym_string_get_expression] = STATE(6030),
    [sym_bigarray_get_expression] = STATE(6030),
    [sym_coercion_expression] = STATE(6030),
    [sym_local_open_expression] = STATE(6030),
    [sym_package_expression] = STATE(6030),
    [sym_new_expression] = STATE(6030),
    [sym_object_copy_expression] = STATE(6030),
    [sym_method_invocation] = STATE(6030),
    [sym_object_expression] = STATE(6030),
    [sym_parenthesized_expression] = STATE(6030),
    [sym_attribute] = STATE(2490),
    [sym_extension] = STATE(6030),
    [sym_quoted_extension] = STATE(6030),
    [sym__constant] = STATE(6030),
    [sym_number] = STATE(6054),
    [sym_character] = STATE(6054),
    [sym_string] = STATE(6054),
    [sym_quoted_string] = STATE(6054),
    [sym_boolean] = STATE(6054),
    [sym_unit] = STATE(6054),
    [sym__value_name] = STATE(5950),
    [sym_parenthesized_operator] = STATE(6060),
    [sym_value_path] = STATE(6030),
    [sym_module_path] = STATE(18404),
    [sym_constructor_path] = STATE(6030),
    [sym__constructor_name] = STATE(6049),
    [sym_tag] = STATE(6030),
    [aux_sym_class_application_repeat1] = STATE(2490),
    [sym__lowercase_identifier] = ACTIONS(5625),
    [anon_sym_SEMI_SEMI] = ACTIONS(3720),
    [anon_sym_let] = ACTIONS(3722),
    [anon_sym_and] = ACTIONS(3722),
    [anon_sym_TILDE] = ACTIONS(5628),
    [anon_sym_QMARK] = ACTIONS(5628),
    [anon_sym_LPAREN] = ACTIONS(5631),
    [anon_sym_external] = ACTIONS(3722),
    [anon_sym_type] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(5634),
    [anon_sym_true] = ACTIONS(5637),
    [anon_sym_false] = ACTIONS(5637),
    [anon_sym_LBRACE] = ACTIONS(5640),
    [anon_sym_exception] = ACTIONS(3722),
    [anon_sym_module] = ACTIONS(3722),
    [anon_sym_open] = ACTIONS(3722),
    [anon_sym_include] = ACTIONS(3722),
    [anon_sym_class] = ACTIONS(3722),
    [anon_sym_end] = ACTIONS(3722),
    [anon_sym_object] = ACTIONS(5643),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5646),
    [anon_sym_new] = ACTIONS(5649),
    [anon_sym_LBRACE_LT] = ACTIONS(5652),
    [anon_sym_begin] = ACTIONS(5655),
    [sym_ocamlyacc_value] = ACTIONS(5658),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3722),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3720),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5661),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5664),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3720),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3720),
    [aux_sym_number_token1] = ACTIONS(5667),
    [anon_sym_SQUOTE] = ACTIONS(5670),
    [anon_sym_DQUOTE] = ACTIONS(5673),
    [sym_prefix_operator] = ACTIONS(5676),
    [sym_let_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(5679),
    [aux_sym_directive_token1] = ACTIONS(3720),
    [aux_sym_tag_token1] = ACTIONS(5682),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2491] = {
    [sym__simple_expression] = STATE(5931),
    [sym_typed_expression] = STATE(6030),
    [sym_list_expression] = STATE(6030),
    [sym_array_expression] = STATE(6030),
    [sym_record_expression] = STATE(6030),
    [sym_labeled_argument] = STATE(7322),
    [sym_prefix_expression] = STATE(6030),
    [sym_hash_expression] = STATE(6030),
    [sym_field_get_expression] = STATE(6030),
    [sym_array_get_expression] = STATE(6030),
    [sym_string_get_expression] = STATE(6030),
    [sym_bigarray_get_expression] = STATE(6030),
    [sym_coercion_expression] = STATE(6030),
    [sym_local_open_expression] = STATE(6030),
    [sym_package_expression] = STATE(6030),
    [sym_new_expression] = STATE(6030),
    [sym_object_copy_expression] = STATE(6030),
    [sym_method_invocation] = STATE(6030),
    [sym_object_expression] = STATE(6030),
    [sym_parenthesized_expression] = STATE(6030),
    [sym_attribute] = STATE(2491),
    [sym_extension] = STATE(6030),
    [sym_quoted_extension] = STATE(6030),
    [sym__constant] = STATE(6030),
    [sym_number] = STATE(6054),
    [sym_character] = STATE(6054),
    [sym_string] = STATE(6054),
    [sym_quoted_string] = STATE(6054),
    [sym_boolean] = STATE(6054),
    [sym_unit] = STATE(6054),
    [sym__value_name] = STATE(5950),
    [sym_parenthesized_operator] = STATE(6060),
    [sym_value_path] = STATE(6030),
    [sym_module_path] = STATE(18404),
    [sym_constructor_path] = STATE(6030),
    [sym__constructor_name] = STATE(6049),
    [sym_tag] = STATE(6030),
    [aux_sym_class_application_repeat1] = STATE(2490),
    [sym__lowercase_identifier] = ACTIONS(5685),
    [anon_sym_SEMI_SEMI] = ACTIONS(5687),
    [anon_sym_let] = ACTIONS(5689),
    [anon_sym_and] = ACTIONS(5689),
    [anon_sym_TILDE] = ACTIONS(5691),
    [anon_sym_QMARK] = ACTIONS(5691),
    [anon_sym_LPAREN] = ACTIONS(5693),
    [anon_sym_external] = ACTIONS(5689),
    [anon_sym_type] = ACTIONS(5689),
    [anon_sym_LBRACK] = ACTIONS(5695),
    [anon_sym_true] = ACTIONS(5697),
    [anon_sym_false] = ACTIONS(5697),
    [anon_sym_LBRACE] = ACTIONS(5699),
    [anon_sym_exception] = ACTIONS(5689),
    [anon_sym_module] = ACTIONS(5689),
    [anon_sym_open] = ACTIONS(5689),
    [anon_sym_include] = ACTIONS(5689),
    [anon_sym_class] = ACTIONS(5689),
    [anon_sym_end] = ACTIONS(5689),
    [anon_sym_object] = ACTIONS(5701),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5703),
    [anon_sym_new] = ACTIONS(5705),
    [anon_sym_LBRACE_LT] = ACTIONS(5707),
    [anon_sym_begin] = ACTIONS(5709),
    [sym_ocamlyacc_value] = ACTIONS(5711),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5689),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5687),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5713),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5715),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5687),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5687),
    [aux_sym_number_token1] = ACTIONS(5717),
    [anon_sym_SQUOTE] = ACTIONS(5719),
    [anon_sym_DQUOTE] = ACTIONS(5721),
    [sym_prefix_operator] = ACTIONS(5723),
    [sym_let_operator] = ACTIONS(5687),
    [sym__uppercase_identifier] = ACTIONS(5725),
    [aux_sym_directive_token1] = ACTIONS(5687),
    [aux_sym_tag_token1] = ACTIONS(5727),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2492] = {
    [sym_parameter] = STATE(10266),
    [sym__polymorphic_typed] = STATE(16781),
    [sym__parenthesized_abstract_type] = STATE(10266),
    [sym__simple_pattern] = STATE(10267),
    [sym_typed_pattern] = STATE(10147),
    [sym_polymorphic_variant_pattern] = STATE(10147),
    [sym_record_pattern] = STATE(10147),
    [sym_list_pattern] = STATE(10147),
    [sym_array_pattern] = STATE(10147),
    [sym_local_open_pattern] = STATE(10147),
    [sym_package_pattern] = STATE(10147),
    [sym_parenthesized_pattern] = STATE(10147),
    [sym_attribute] = STATE(2492),
    [sym_item_attribute] = STATE(11071),
    [sym_extension] = STATE(10147),
    [sym_quoted_extension] = STATE(10147),
    [sym__constant] = STATE(10250),
    [sym__signed_constant] = STATE(10147),
    [sym_number] = STATE(10120),
    [sym_signed_number] = STATE(10250),
    [sym_character] = STATE(10120),
    [sym_string] = STATE(10120),
    [sym_quoted_string] = STATE(10120),
    [sym_boolean] = STATE(10120),
    [sym_unit] = STATE(10120),
    [sym__simple_value_pattern] = STATE(10147),
    [sym_parenthesized_operator] = STATE(10147),
    [sym_module_path] = STATE(20425),
    [sym_constructor_path] = STATE(10147),
    [sym__constructor_name] = STATE(8440),
    [sym_tag] = STATE(10147),
    [aux_sym_expression_item_repeat1] = STATE(10609),
    [aux_sym_let_binding_repeat1] = STATE(4656),
    [sym__lowercase_identifier] = ACTIONS(5465),
    [anon_sym_SEMI_SEMI] = ACTIONS(5467),
    [anon_sym_let] = ACTIONS(5469),
    [anon_sym_and] = ACTIONS(5469),
    [anon_sym_COLON_GT] = ACTIONS(5729),
    [anon_sym_EQ] = ACTIONS(5731),
    [anon_sym_TILDE] = ACTIONS(5475),
    [anon_sym_QMARK] = ACTIONS(5475),
    [anon_sym_LPAREN] = ACTIONS(5477),
    [anon_sym_external] = ACTIONS(5469),
    [anon_sym_type] = ACTIONS(5469),
    [anon_sym_COMMA] = ACTIONS(5733),
    [anon_sym_PIPE] = ACTIONS(5735),
    [anon_sym_LBRACK] = ACTIONS(5483),
    [anon_sym_true] = ACTIONS(5485),
    [anon_sym_false] = ACTIONS(5485),
    [anon_sym_COLON2] = ACTIONS(5487),
    [anon_sym_LBRACE] = ACTIONS(5489),
    [anon_sym_exception] = ACTIONS(5469),
    [anon_sym_module] = ACTIONS(5469),
    [anon_sym_open] = ACTIONS(5469),
    [anon_sym_include] = ACTIONS(5469),
    [anon_sym_class] = ACTIONS(5469),
    [anon_sym_end] = ACTIONS(5469),
    [anon_sym_as] = ACTIONS(5737),
    [anon_sym_POUND] = ACTIONS(5493),
    [anon_sym_COLON_COLON] = ACTIONS(5739),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5497),
    [anon_sym_begin] = ACTIONS(5499),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5501),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5467),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5503),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5505),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5467),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5467),
    [aux_sym_number_token1] = ACTIONS(5507),
    [aux_sym_signed_number_token1] = ACTIONS(5509),
    [anon_sym_SQUOTE] = ACTIONS(5511),
    [anon_sym_DQUOTE] = ACTIONS(5513),
    [sym_let_operator] = ACTIONS(5467),
    [sym_let_and_operator] = ACTIONS(5467),
    [sym__uppercase_identifier] = ACTIONS(5515),
    [aux_sym_directive_token1] = ACTIONS(5469),
    [aux_sym_tag_token1] = ACTIONS(5517),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2493] = {
    [sym_parameter] = STATE(10266),
    [sym__polymorphic_typed] = STATE(16599),
    [sym__parenthesized_abstract_type] = STATE(10266),
    [sym__simple_pattern] = STATE(10267),
    [sym_typed_pattern] = STATE(10147),
    [sym_polymorphic_variant_pattern] = STATE(10147),
    [sym_record_pattern] = STATE(10147),
    [sym_list_pattern] = STATE(10147),
    [sym_array_pattern] = STATE(10147),
    [sym_local_open_pattern] = STATE(10147),
    [sym_package_pattern] = STATE(10147),
    [sym_parenthesized_pattern] = STATE(10147),
    [sym_attribute] = STATE(2493),
    [sym_item_attribute] = STATE(11071),
    [sym_extension] = STATE(10147),
    [sym_quoted_extension] = STATE(10147),
    [sym__constant] = STATE(10250),
    [sym__signed_constant] = STATE(10147),
    [sym_number] = STATE(10120),
    [sym_signed_number] = STATE(10250),
    [sym_character] = STATE(10120),
    [sym_string] = STATE(10120),
    [sym_quoted_string] = STATE(10120),
    [sym_boolean] = STATE(10120),
    [sym_unit] = STATE(10120),
    [sym__simple_value_pattern] = STATE(10147),
    [sym_parenthesized_operator] = STATE(10147),
    [sym_module_path] = STATE(20425),
    [sym_constructor_path] = STATE(10147),
    [sym__constructor_name] = STATE(8440),
    [sym_tag] = STATE(10147),
    [aux_sym_expression_item_repeat1] = STATE(10609),
    [aux_sym_let_binding_repeat1] = STATE(4650),
    [sym__lowercase_identifier] = ACTIONS(5465),
    [anon_sym_SEMI_SEMI] = ACTIONS(5467),
    [anon_sym_let] = ACTIONS(5469),
    [anon_sym_and] = ACTIONS(5469),
    [anon_sym_COLON_GT] = ACTIONS(5741),
    [anon_sym_EQ] = ACTIONS(5743),
    [anon_sym_TILDE] = ACTIONS(5475),
    [anon_sym_QMARK] = ACTIONS(5475),
    [anon_sym_LPAREN] = ACTIONS(5477),
    [anon_sym_external] = ACTIONS(5469),
    [anon_sym_type] = ACTIONS(5469),
    [anon_sym_COMMA] = ACTIONS(5745),
    [anon_sym_PIPE] = ACTIONS(5747),
    [anon_sym_LBRACK] = ACTIONS(5483),
    [anon_sym_RBRACK] = ACTIONS(5467),
    [anon_sym_true] = ACTIONS(5485),
    [anon_sym_false] = ACTIONS(5485),
    [anon_sym_COLON2] = ACTIONS(5487),
    [anon_sym_LBRACE] = ACTIONS(5489),
    [anon_sym_exception] = ACTIONS(5469),
    [anon_sym_module] = ACTIONS(5469),
    [anon_sym_open] = ACTIONS(5469),
    [anon_sym_include] = ACTIONS(5469),
    [anon_sym_class] = ACTIONS(5469),
    [anon_sym_as] = ACTIONS(5749),
    [anon_sym_POUND] = ACTIONS(5493),
    [anon_sym_COLON_COLON] = ACTIONS(5751),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5497),
    [anon_sym_begin] = ACTIONS(5499),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5501),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5467),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5503),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5505),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5467),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5467),
    [aux_sym_number_token1] = ACTIONS(5507),
    [aux_sym_signed_number_token1] = ACTIONS(5509),
    [anon_sym_SQUOTE] = ACTIONS(5511),
    [anon_sym_DQUOTE] = ACTIONS(5513),
    [sym_let_operator] = ACTIONS(5467),
    [sym_let_and_operator] = ACTIONS(5467),
    [sym__uppercase_identifier] = ACTIONS(5515),
    [aux_sym_directive_token1] = ACTIONS(5469),
    [aux_sym_tag_token1] = ACTIONS(5517),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2494] = {
    [sym__simple_expression] = STATE(5854),
    [sym_typed_expression] = STATE(5961),
    [sym_list_expression] = STATE(5961),
    [sym_array_expression] = STATE(5961),
    [sym_record_expression] = STATE(5961),
    [sym_labeled_argument] = STATE(7319),
    [sym_prefix_expression] = STATE(5961),
    [sym_hash_expression] = STATE(5961),
    [sym_field_get_expression] = STATE(5961),
    [sym_array_get_expression] = STATE(5961),
    [sym_string_get_expression] = STATE(5961),
    [sym_bigarray_get_expression] = STATE(5961),
    [sym_coercion_expression] = STATE(5961),
    [sym_local_open_expression] = STATE(5961),
    [sym_package_expression] = STATE(5961),
    [sym_new_expression] = STATE(5961),
    [sym_object_copy_expression] = STATE(5961),
    [sym_method_invocation] = STATE(5961),
    [sym_object_expression] = STATE(5961),
    [sym_parenthesized_expression] = STATE(5961),
    [sym_attribute] = STATE(2494),
    [sym_extension] = STATE(5961),
    [sym_quoted_extension] = STATE(5961),
    [sym__constant] = STATE(5961),
    [sym_number] = STATE(6094),
    [sym_character] = STATE(6094),
    [sym_string] = STATE(6094),
    [sym_quoted_string] = STATE(6094),
    [sym_boolean] = STATE(6094),
    [sym_unit] = STATE(6094),
    [sym__value_name] = STATE(5955),
    [sym_parenthesized_operator] = STATE(6068),
    [sym_value_path] = STATE(5961),
    [sym_module_path] = STATE(18110),
    [sym_constructor_path] = STATE(5961),
    [sym__constructor_name] = STATE(6088),
    [sym_tag] = STATE(5961),
    [aux_sym_class_application_repeat1] = STATE(2494),
    [sym__lowercase_identifier] = ACTIONS(5753),
    [anon_sym_SEMI_SEMI] = ACTIONS(3720),
    [anon_sym_let] = ACTIONS(3722),
    [anon_sym_and] = ACTIONS(3722),
    [anon_sym_TILDE] = ACTIONS(5756),
    [anon_sym_QMARK] = ACTIONS(5756),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_external] = ACTIONS(3722),
    [anon_sym_type] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(5762),
    [anon_sym_RBRACK] = ACTIONS(3720),
    [anon_sym_true] = ACTIONS(5765),
    [anon_sym_false] = ACTIONS(5765),
    [anon_sym_LBRACE] = ACTIONS(5768),
    [anon_sym_exception] = ACTIONS(3722),
    [anon_sym_module] = ACTIONS(3722),
    [anon_sym_open] = ACTIONS(3722),
    [anon_sym_include] = ACTIONS(3722),
    [anon_sym_class] = ACTIONS(3722),
    [anon_sym_object] = ACTIONS(5771),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5774),
    [anon_sym_new] = ACTIONS(5777),
    [anon_sym_LBRACE_LT] = ACTIONS(5780),
    [anon_sym_begin] = ACTIONS(5783),
    [sym_ocamlyacc_value] = ACTIONS(5786),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3722),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3720),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5789),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5792),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3720),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3720),
    [aux_sym_number_token1] = ACTIONS(5795),
    [anon_sym_SQUOTE] = ACTIONS(5798),
    [anon_sym_DQUOTE] = ACTIONS(5801),
    [sym_prefix_operator] = ACTIONS(5804),
    [sym_let_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(5807),
    [aux_sym_directive_token1] = ACTIONS(3720),
    [aux_sym_tag_token1] = ACTIONS(5810),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2495] = {
    [sym__simple_expression] = STATE(5931),
    [sym_typed_expression] = STATE(6030),
    [sym_list_expression] = STATE(6030),
    [sym_array_expression] = STATE(6030),
    [sym_record_expression] = STATE(6030),
    [sym_labeled_argument] = STATE(7322),
    [sym_prefix_expression] = STATE(6030),
    [sym_hash_expression] = STATE(6030),
    [sym_field_get_expression] = STATE(6030),
    [sym_array_get_expression] = STATE(6030),
    [sym_string_get_expression] = STATE(6030),
    [sym_bigarray_get_expression] = STATE(6030),
    [sym_coercion_expression] = STATE(6030),
    [sym_local_open_expression] = STATE(6030),
    [sym_package_expression] = STATE(6030),
    [sym_new_expression] = STATE(6030),
    [sym_object_copy_expression] = STATE(6030),
    [sym_method_invocation] = STATE(6030),
    [sym_object_expression] = STATE(6030),
    [sym_parenthesized_expression] = STATE(6030),
    [sym_attribute] = STATE(2495),
    [sym_extension] = STATE(6030),
    [sym_quoted_extension] = STATE(6030),
    [sym__constant] = STATE(6030),
    [sym_number] = STATE(6054),
    [sym_character] = STATE(6054),
    [sym_string] = STATE(6054),
    [sym_quoted_string] = STATE(6054),
    [sym_boolean] = STATE(6054),
    [sym_unit] = STATE(6054),
    [sym__value_name] = STATE(5950),
    [sym_parenthesized_operator] = STATE(6060),
    [sym_value_path] = STATE(6030),
    [sym_module_path] = STATE(18404),
    [sym_constructor_path] = STATE(6030),
    [sym__constructor_name] = STATE(6049),
    [sym_tag] = STATE(6030),
    [aux_sym_class_application_repeat1] = STATE(2491),
    [sym__lowercase_identifier] = ACTIONS(5685),
    [anon_sym_SEMI_SEMI] = ACTIONS(5583),
    [anon_sym_let] = ACTIONS(5585),
    [anon_sym_and] = ACTIONS(5585),
    [anon_sym_TILDE] = ACTIONS(5691),
    [anon_sym_QMARK] = ACTIONS(5691),
    [anon_sym_LPAREN] = ACTIONS(5693),
    [anon_sym_external] = ACTIONS(5585),
    [anon_sym_type] = ACTIONS(5585),
    [anon_sym_LBRACK] = ACTIONS(5695),
    [anon_sym_true] = ACTIONS(5697),
    [anon_sym_false] = ACTIONS(5697),
    [anon_sym_LBRACE] = ACTIONS(5699),
    [anon_sym_exception] = ACTIONS(5585),
    [anon_sym_module] = ACTIONS(5585),
    [anon_sym_open] = ACTIONS(5585),
    [anon_sym_include] = ACTIONS(5585),
    [anon_sym_class] = ACTIONS(5585),
    [anon_sym_end] = ACTIONS(5585),
    [anon_sym_object] = ACTIONS(5701),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5703),
    [anon_sym_new] = ACTIONS(5705),
    [anon_sym_LBRACE_LT] = ACTIONS(5707),
    [anon_sym_begin] = ACTIONS(5709),
    [sym_ocamlyacc_value] = ACTIONS(5711),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5585),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5583),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5713),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5715),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5583),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5583),
    [aux_sym_number_token1] = ACTIONS(5717),
    [anon_sym_SQUOTE] = ACTIONS(5719),
    [anon_sym_DQUOTE] = ACTIONS(5721),
    [sym_prefix_operator] = ACTIONS(5723),
    [sym_let_operator] = ACTIONS(5583),
    [sym__uppercase_identifier] = ACTIONS(5725),
    [aux_sym_directive_token1] = ACTIONS(5583),
    [aux_sym_tag_token1] = ACTIONS(5727),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2496] = {
    [sym__simple_expression] = STATE(5915),
    [sym_typed_expression] = STATE(6138),
    [sym_list_expression] = STATE(6138),
    [sym_array_expression] = STATE(6138),
    [sym_record_expression] = STATE(6138),
    [sym_labeled_argument] = STATE(7428),
    [sym_prefix_expression] = STATE(6138),
    [sym_hash_expression] = STATE(6138),
    [sym_field_get_expression] = STATE(6138),
    [sym_array_get_expression] = STATE(6138),
    [sym_string_get_expression] = STATE(6138),
    [sym_bigarray_get_expression] = STATE(6138),
    [sym_coercion_expression] = STATE(6138),
    [sym_local_open_expression] = STATE(6138),
    [sym_package_expression] = STATE(6138),
    [sym_new_expression] = STATE(6138),
    [sym_object_copy_expression] = STATE(6138),
    [sym_method_invocation] = STATE(6138),
    [sym_object_expression] = STATE(6138),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_attribute] = STATE(2496),
    [sym_extension] = STATE(6138),
    [sym_quoted_extension] = STATE(6138),
    [sym__constant] = STATE(6138),
    [sym_number] = STATE(6008),
    [sym_character] = STATE(6008),
    [sym_string] = STATE(6008),
    [sym_quoted_string] = STATE(6008),
    [sym_boolean] = STATE(6008),
    [sym_unit] = STATE(6008),
    [sym__value_name] = STATE(6089),
    [sym_parenthesized_operator] = STATE(5857),
    [sym_value_path] = STATE(6138),
    [sym_module_path] = STATE(18718),
    [sym_constructor_path] = STATE(6138),
    [sym__constructor_name] = STATE(6011),
    [sym_tag] = STATE(6138),
    [aux_sym_class_application_repeat1] = STATE(2496),
    [sym__lowercase_identifier] = ACTIONS(5813),
    [anon_sym_TILDE] = ACTIONS(5816),
    [anon_sym_QMARK] = ACTIONS(5816),
    [anon_sym_LPAREN] = ACTIONS(5819),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(5822),
    [anon_sym_true] = ACTIONS(5825),
    [anon_sym_false] = ACTIONS(5825),
    [anon_sym_LBRACE] = ACTIONS(5828),
    [anon_sym_SEMI] = ACTIONS(3720),
    [anon_sym_object] = ACTIONS(5831),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5834),
    [anon_sym_else] = ACTIONS(3722),
    [anon_sym_to] = ACTIONS(3722),
    [anon_sym_downto] = ACTIONS(3722),
    [anon_sym_new] = ACTIONS(5837),
    [anon_sym_LBRACE_LT] = ACTIONS(5840),
    [anon_sym_begin] = ACTIONS(5843),
    [sym_ocamlyacc_value] = ACTIONS(5846),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5849),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5852),
    [aux_sym_number_token1] = ACTIONS(5855),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(5858),
    [anon_sym_DQUOTE] = ACTIONS(5861),
    [sym_prefix_operator] = ACTIONS(5864),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(5867),
    [aux_sym_tag_token1] = ACTIONS(5870),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2497] = {
    [sym__simple_expression] = STATE(5854),
    [sym_typed_expression] = STATE(5961),
    [sym_list_expression] = STATE(5961),
    [sym_array_expression] = STATE(5961),
    [sym_record_expression] = STATE(5961),
    [sym_labeled_argument] = STATE(7319),
    [sym_prefix_expression] = STATE(5961),
    [sym_hash_expression] = STATE(5961),
    [sym_field_get_expression] = STATE(5961),
    [sym_array_get_expression] = STATE(5961),
    [sym_string_get_expression] = STATE(5961),
    [sym_bigarray_get_expression] = STATE(5961),
    [sym_coercion_expression] = STATE(5961),
    [sym_local_open_expression] = STATE(5961),
    [sym_package_expression] = STATE(5961),
    [sym_new_expression] = STATE(5961),
    [sym_object_copy_expression] = STATE(5961),
    [sym_method_invocation] = STATE(5961),
    [sym_object_expression] = STATE(5961),
    [sym_parenthesized_expression] = STATE(5961),
    [sym_attribute] = STATE(2497),
    [sym_extension] = STATE(5961),
    [sym_quoted_extension] = STATE(5961),
    [sym__constant] = STATE(5961),
    [sym_number] = STATE(6094),
    [sym_character] = STATE(6094),
    [sym_string] = STATE(6094),
    [sym_quoted_string] = STATE(6094),
    [sym_boolean] = STATE(6094),
    [sym_unit] = STATE(6094),
    [sym__value_name] = STATE(5955),
    [sym_parenthesized_operator] = STATE(6068),
    [sym_value_path] = STATE(5961),
    [sym_module_path] = STATE(18110),
    [sym_constructor_path] = STATE(5961),
    [sym__constructor_name] = STATE(6088),
    [sym_tag] = STATE(5961),
    [aux_sym_class_application_repeat1] = STATE(2494),
    [sym__lowercase_identifier] = ACTIONS(5581),
    [anon_sym_SEMI_SEMI] = ACTIONS(5687),
    [anon_sym_let] = ACTIONS(5689),
    [anon_sym_and] = ACTIONS(5689),
    [anon_sym_TILDE] = ACTIONS(5587),
    [anon_sym_QMARK] = ACTIONS(5587),
    [anon_sym_LPAREN] = ACTIONS(5589),
    [anon_sym_external] = ACTIONS(5689),
    [anon_sym_type] = ACTIONS(5689),
    [anon_sym_LBRACK] = ACTIONS(5591),
    [anon_sym_RBRACK] = ACTIONS(5687),
    [anon_sym_true] = ACTIONS(5593),
    [anon_sym_false] = ACTIONS(5593),
    [anon_sym_LBRACE] = ACTIONS(5595),
    [anon_sym_exception] = ACTIONS(5689),
    [anon_sym_module] = ACTIONS(5689),
    [anon_sym_open] = ACTIONS(5689),
    [anon_sym_include] = ACTIONS(5689),
    [anon_sym_class] = ACTIONS(5689),
    [anon_sym_object] = ACTIONS(5597),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5599),
    [anon_sym_new] = ACTIONS(5601),
    [anon_sym_LBRACE_LT] = ACTIONS(5603),
    [anon_sym_begin] = ACTIONS(5605),
    [sym_ocamlyacc_value] = ACTIONS(5607),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5689),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5687),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5609),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5611),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5687),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5687),
    [aux_sym_number_token1] = ACTIONS(5613),
    [anon_sym_SQUOTE] = ACTIONS(5615),
    [anon_sym_DQUOTE] = ACTIONS(5617),
    [sym_prefix_operator] = ACTIONS(5619),
    [sym_let_operator] = ACTIONS(5687),
    [sym__uppercase_identifier] = ACTIONS(5621),
    [aux_sym_directive_token1] = ACTIONS(5687),
    [aux_sym_tag_token1] = ACTIONS(5623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2498] = {
    [sym__simple_expression] = STATE(6518),
    [sym_typed_expression] = STATE(6303),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_labeled_argument] = STATE(7569),
    [sym_prefix_expression] = STATE(6303),
    [sym_hash_expression] = STATE(6303),
    [sym_field_get_expression] = STATE(6303),
    [sym_array_get_expression] = STATE(6303),
    [sym_string_get_expression] = STATE(6303),
    [sym_bigarray_get_expression] = STATE(6303),
    [sym_coercion_expression] = STATE(6303),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(2498),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [aux_sym_class_application_repeat1] = STATE(2498),
    [sym__lowercase_identifier] = ACTIONS(5873),
    [anon_sym_TILDE] = ACTIONS(5876),
    [anon_sym_QMARK] = ACTIONS(5876),
    [anon_sym_LPAREN] = ACTIONS(5879),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(5882),
    [anon_sym_true] = ACTIONS(5885),
    [anon_sym_false] = ACTIONS(5885),
    [anon_sym_LBRACE] = ACTIONS(5888),
    [anon_sym_SEMI] = ACTIONS(3720),
    [anon_sym_object] = ACTIONS(5891),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5894),
    [anon_sym_to] = ACTIONS(3722),
    [anon_sym_downto] = ACTIONS(3722),
    [anon_sym_new] = ACTIONS(5897),
    [anon_sym_LBRACE_LT] = ACTIONS(5900),
    [anon_sym_begin] = ACTIONS(5903),
    [sym_ocamlyacc_value] = ACTIONS(5906),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5909),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5912),
    [aux_sym_number_token1] = ACTIONS(5915),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(5918),
    [anon_sym_DQUOTE] = ACTIONS(5921),
    [sym_prefix_operator] = ACTIONS(5924),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(5927),
    [aux_sym_tag_token1] = ACTIONS(5930),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2499] = {
    [sym__simple_expression] = STATE(6550),
    [sym_typed_expression] = STATE(6255),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_labeled_argument] = STATE(7518),
    [sym_prefix_expression] = STATE(6255),
    [sym_hash_expression] = STATE(6255),
    [sym_field_get_expression] = STATE(6255),
    [sym_array_get_expression] = STATE(6255),
    [sym_string_get_expression] = STATE(6255),
    [sym_bigarray_get_expression] = STATE(6255),
    [sym_coercion_expression] = STATE(6255),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2499),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [aux_sym_class_application_repeat1] = STATE(2502),
    [sym__lowercase_identifier] = ACTIONS(5341),
    [anon_sym_TILDE] = ACTIONS(5343),
    [anon_sym_QMARK] = ACTIONS(5343),
    [anon_sym_LPAREN] = ACTIONS(2521),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [anon_sym_true] = ACTIONS(2525),
    [anon_sym_false] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_SEMI] = ACTIONS(3943),
    [anon_sym_end] = ACTIONS(3945),
    [anon_sym_object] = ACTIONS(2529),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2533),
    [anon_sym_else] = ACTIONS(3945),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_LBRACE_LT] = ACTIONS(2545),
    [anon_sym_begin] = ACTIONS(2547),
    [sym_ocamlyacc_value] = ACTIONS(2549),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2551),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2553),
    [aux_sym_number_token1] = ACTIONS(2555),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_prefix_operator] = ACTIONS(2561),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(2565),
    [aux_sym_tag_token1] = ACTIONS(2567),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2500] = {
    [sym__simple_expression] = STATE(6644),
    [sym_typed_expression] = STATE(6258),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_labeled_argument] = STATE(7533),
    [sym_prefix_expression] = STATE(6258),
    [sym_hash_expression] = STATE(6258),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_coercion_expression] = STATE(6258),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(2500),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [aux_sym_class_application_repeat1] = STATE(2500),
    [sym__lowercase_identifier] = ACTIONS(5933),
    [anon_sym_TILDE] = ACTIONS(5936),
    [anon_sym_QMARK] = ACTIONS(5936),
    [anon_sym_LPAREN] = ACTIONS(5939),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(5942),
    [anon_sym_true] = ACTIONS(5945),
    [anon_sym_false] = ACTIONS(5945),
    [anon_sym_LBRACE] = ACTIONS(5948),
    [anon_sym_SEMI] = ACTIONS(3720),
    [anon_sym_object] = ACTIONS(5951),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5954),
    [anon_sym_else] = ACTIONS(3722),
    [anon_sym_done] = ACTIONS(3722),
    [anon_sym_new] = ACTIONS(5957),
    [anon_sym_LBRACE_LT] = ACTIONS(5960),
    [anon_sym_begin] = ACTIONS(5963),
    [sym_ocamlyacc_value] = ACTIONS(5966),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5969),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5972),
    [aux_sym_number_token1] = ACTIONS(5975),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(5978),
    [anon_sym_DQUOTE] = ACTIONS(5981),
    [sym_prefix_operator] = ACTIONS(5984),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(5987),
    [aux_sym_tag_token1] = ACTIONS(5990),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2501] = {
    [sym__simple_expression] = STATE(6274),
    [sym_typed_expression] = STATE(6539),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_labeled_argument] = STATE(7553),
    [sym_prefix_expression] = STATE(6539),
    [sym_hash_expression] = STATE(6539),
    [sym_field_get_expression] = STATE(6539),
    [sym_array_get_expression] = STATE(6539),
    [sym_string_get_expression] = STATE(6539),
    [sym_bigarray_get_expression] = STATE(6539),
    [sym_coercion_expression] = STATE(6539),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(2501),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [aux_sym_class_application_repeat1] = STATE(2501),
    [sym__lowercase_identifier] = ACTIONS(5993),
    [anon_sym_TILDE] = ACTIONS(5996),
    [anon_sym_QMARK] = ACTIONS(5996),
    [anon_sym_LPAREN] = ACTIONS(5999),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(6002),
    [anon_sym_true] = ACTIONS(6005),
    [anon_sym_false] = ACTIONS(6005),
    [anon_sym_LBRACE] = ACTIONS(6008),
    [anon_sym_SEMI] = ACTIONS(3720),
    [anon_sym_object] = ACTIONS(6011),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6014),
    [anon_sym_then] = ACTIONS(3722),
    [anon_sym_else] = ACTIONS(3722),
    [anon_sym_new] = ACTIONS(6017),
    [anon_sym_LBRACE_LT] = ACTIONS(6020),
    [anon_sym_begin] = ACTIONS(6023),
    [sym_ocamlyacc_value] = ACTIONS(6026),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6029),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6032),
    [aux_sym_number_token1] = ACTIONS(6035),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(6038),
    [anon_sym_DQUOTE] = ACTIONS(6041),
    [sym_prefix_operator] = ACTIONS(6044),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(6047),
    [aux_sym_tag_token1] = ACTIONS(6050),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2502] = {
    [sym__simple_expression] = STATE(6550),
    [sym_typed_expression] = STATE(6255),
    [sym_list_expression] = STATE(6255),
    [sym_array_expression] = STATE(6255),
    [sym_record_expression] = STATE(6255),
    [sym_labeled_argument] = STATE(7518),
    [sym_prefix_expression] = STATE(6255),
    [sym_hash_expression] = STATE(6255),
    [sym_field_get_expression] = STATE(6255),
    [sym_array_get_expression] = STATE(6255),
    [sym_string_get_expression] = STATE(6255),
    [sym_bigarray_get_expression] = STATE(6255),
    [sym_coercion_expression] = STATE(6255),
    [sym_local_open_expression] = STATE(6255),
    [sym_package_expression] = STATE(6255),
    [sym_new_expression] = STATE(6255),
    [sym_object_copy_expression] = STATE(6255),
    [sym_method_invocation] = STATE(6255),
    [sym_object_expression] = STATE(6255),
    [sym_parenthesized_expression] = STATE(6255),
    [sym_attribute] = STATE(2502),
    [sym_extension] = STATE(6255),
    [sym_quoted_extension] = STATE(6255),
    [sym__constant] = STATE(6255),
    [sym_number] = STATE(6449),
    [sym_character] = STATE(6449),
    [sym_string] = STATE(6449),
    [sym_quoted_string] = STATE(6449),
    [sym_boolean] = STATE(6449),
    [sym_unit] = STATE(6449),
    [sym__value_name] = STATE(6354),
    [sym_parenthesized_operator] = STATE(6647),
    [sym_value_path] = STATE(6255),
    [sym_module_path] = STATE(18324),
    [sym_constructor_path] = STATE(6255),
    [sym__constructor_name] = STATE(6438),
    [sym_tag] = STATE(6255),
    [aux_sym_class_application_repeat1] = STATE(2502),
    [sym__lowercase_identifier] = ACTIONS(6053),
    [anon_sym_TILDE] = ACTIONS(6056),
    [anon_sym_QMARK] = ACTIONS(6056),
    [anon_sym_LPAREN] = ACTIONS(6059),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(6062),
    [anon_sym_true] = ACTIONS(6065),
    [anon_sym_false] = ACTIONS(6065),
    [anon_sym_LBRACE] = ACTIONS(6068),
    [anon_sym_SEMI] = ACTIONS(3720),
    [anon_sym_end] = ACTIONS(3722),
    [anon_sym_object] = ACTIONS(6071),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6074),
    [anon_sym_else] = ACTIONS(3722),
    [anon_sym_new] = ACTIONS(6077),
    [anon_sym_LBRACE_LT] = ACTIONS(6080),
    [anon_sym_begin] = ACTIONS(6083),
    [sym_ocamlyacc_value] = ACTIONS(6086),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6089),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6092),
    [aux_sym_number_token1] = ACTIONS(6095),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(6098),
    [anon_sym_DQUOTE] = ACTIONS(6101),
    [sym_prefix_operator] = ACTIONS(6104),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(6107),
    [aux_sym_tag_token1] = ACTIONS(6110),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2503] = {
    [sym__simple_expression] = STATE(6366),
    [sym_typed_expression] = STATE(6357),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_labeled_argument] = STATE(7545),
    [sym_prefix_expression] = STATE(6357),
    [sym_hash_expression] = STATE(6357),
    [sym_field_get_expression] = STATE(6357),
    [sym_array_get_expression] = STATE(6357),
    [sym_string_get_expression] = STATE(6357),
    [sym_bigarray_get_expression] = STATE(6357),
    [sym_coercion_expression] = STATE(6357),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2503),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [aux_sym_class_application_repeat1] = STATE(2504),
    [sym__lowercase_identifier] = ACTIONS(5351),
    [anon_sym_TILDE] = ACTIONS(5353),
    [anon_sym_QMARK] = ACTIONS(5353),
    [anon_sym_LPAREN] = ACTIONS(2357),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(2359),
    [anon_sym_true] = ACTIONS(2361),
    [anon_sym_false] = ACTIONS(2361),
    [anon_sym_LBRACE] = ACTIONS(2363),
    [anon_sym_SEMI] = ACTIONS(3943),
    [anon_sym_object] = ACTIONS(2365),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2369),
    [anon_sym_else] = ACTIONS(3945),
    [anon_sym_do] = ACTIONS(3945),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_LBRACE_LT] = ACTIONS(2381),
    [anon_sym_begin] = ACTIONS(2383),
    [sym_ocamlyacc_value] = ACTIONS(2385),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2387),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2389),
    [aux_sym_number_token1] = ACTIONS(2391),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(2393),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_prefix_operator] = ACTIONS(2397),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(2401),
    [aux_sym_tag_token1] = ACTIONS(2403),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2504] = {
    [sym__simple_expression] = STATE(6366),
    [sym_typed_expression] = STATE(6357),
    [sym_list_expression] = STATE(6357),
    [sym_array_expression] = STATE(6357),
    [sym_record_expression] = STATE(6357),
    [sym_labeled_argument] = STATE(7545),
    [sym_prefix_expression] = STATE(6357),
    [sym_hash_expression] = STATE(6357),
    [sym_field_get_expression] = STATE(6357),
    [sym_array_get_expression] = STATE(6357),
    [sym_string_get_expression] = STATE(6357),
    [sym_bigarray_get_expression] = STATE(6357),
    [sym_coercion_expression] = STATE(6357),
    [sym_local_open_expression] = STATE(6357),
    [sym_package_expression] = STATE(6357),
    [sym_new_expression] = STATE(6357),
    [sym_object_copy_expression] = STATE(6357),
    [sym_method_invocation] = STATE(6357),
    [sym_object_expression] = STATE(6357),
    [sym_parenthesized_expression] = STATE(6357),
    [sym_attribute] = STATE(2504),
    [sym_extension] = STATE(6357),
    [sym_quoted_extension] = STATE(6357),
    [sym__constant] = STATE(6357),
    [sym_number] = STATE(6548),
    [sym_character] = STATE(6548),
    [sym_string] = STATE(6548),
    [sym_quoted_string] = STATE(6548),
    [sym_boolean] = STATE(6548),
    [sym_unit] = STATE(6548),
    [sym__value_name] = STATE(6169),
    [sym_parenthesized_operator] = STATE(6529),
    [sym_value_path] = STATE(6357),
    [sym_module_path] = STATE(18204),
    [sym_constructor_path] = STATE(6357),
    [sym__constructor_name] = STATE(6547),
    [sym_tag] = STATE(6357),
    [aux_sym_class_application_repeat1] = STATE(2504),
    [sym__lowercase_identifier] = ACTIONS(6113),
    [anon_sym_TILDE] = ACTIONS(6116),
    [anon_sym_QMARK] = ACTIONS(6116),
    [anon_sym_LPAREN] = ACTIONS(6119),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(6122),
    [anon_sym_true] = ACTIONS(6125),
    [anon_sym_false] = ACTIONS(6125),
    [anon_sym_LBRACE] = ACTIONS(6128),
    [anon_sym_SEMI] = ACTIONS(3720),
    [anon_sym_object] = ACTIONS(6131),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6134),
    [anon_sym_else] = ACTIONS(3722),
    [anon_sym_do] = ACTIONS(3722),
    [anon_sym_new] = ACTIONS(6137),
    [anon_sym_LBRACE_LT] = ACTIONS(6140),
    [anon_sym_begin] = ACTIONS(6143),
    [sym_ocamlyacc_value] = ACTIONS(6146),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6149),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6152),
    [aux_sym_number_token1] = ACTIONS(6155),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(6158),
    [anon_sym_DQUOTE] = ACTIONS(6161),
    [sym_prefix_operator] = ACTIONS(6164),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(6167),
    [aux_sym_tag_token1] = ACTIONS(6170),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2505] = {
    [sym__simple_expression] = STATE(6644),
    [sym_typed_expression] = STATE(6258),
    [sym_list_expression] = STATE(6258),
    [sym_array_expression] = STATE(6258),
    [sym_record_expression] = STATE(6258),
    [sym_labeled_argument] = STATE(7533),
    [sym_prefix_expression] = STATE(6258),
    [sym_hash_expression] = STATE(6258),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_coercion_expression] = STATE(6258),
    [sym_local_open_expression] = STATE(6258),
    [sym_package_expression] = STATE(6258),
    [sym_new_expression] = STATE(6258),
    [sym_object_copy_expression] = STATE(6258),
    [sym_method_invocation] = STATE(6258),
    [sym_object_expression] = STATE(6258),
    [sym_parenthesized_expression] = STATE(6258),
    [sym_attribute] = STATE(2505),
    [sym_extension] = STATE(6258),
    [sym_quoted_extension] = STATE(6258),
    [sym__constant] = STATE(6258),
    [sym_number] = STATE(6519),
    [sym_character] = STATE(6519),
    [sym_string] = STATE(6519),
    [sym_quoted_string] = STATE(6519),
    [sym_boolean] = STATE(6519),
    [sym_unit] = STATE(6519),
    [sym__value_name] = STATE(6224),
    [sym_parenthesized_operator] = STATE(6398),
    [sym_value_path] = STATE(6258),
    [sym_module_path] = STATE(18680),
    [sym_constructor_path] = STATE(6258),
    [sym__constructor_name] = STATE(6510),
    [sym_tag] = STATE(6258),
    [aux_sym_class_application_repeat1] = STATE(2500),
    [sym__lowercase_identifier] = ACTIONS(5381),
    [anon_sym_TILDE] = ACTIONS(5383),
    [anon_sym_QMARK] = ACTIONS(5383),
    [anon_sym_LPAREN] = ACTIONS(2469),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_true] = ACTIONS(2473),
    [anon_sym_false] = ACTIONS(2473),
    [anon_sym_LBRACE] = ACTIONS(2475),
    [anon_sym_SEMI] = ACTIONS(3943),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2481),
    [anon_sym_else] = ACTIONS(3945),
    [anon_sym_done] = ACTIONS(3945),
    [anon_sym_new] = ACTIONS(2491),
    [anon_sym_LBRACE_LT] = ACTIONS(2493),
    [anon_sym_begin] = ACTIONS(2495),
    [sym_ocamlyacc_value] = ACTIONS(2497),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2499),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2501),
    [aux_sym_number_token1] = ACTIONS(2503),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(2505),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_prefix_operator] = ACTIONS(2509),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(2513),
    [aux_sym_tag_token1] = ACTIONS(2515),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2506] = {
    [sym__simple_expression] = STATE(6458),
    [sym_typed_expression] = STATE(6162),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_labeled_argument] = STATE(7502),
    [sym_prefix_expression] = STATE(6162),
    [sym_hash_expression] = STATE(6162),
    [sym_field_get_expression] = STATE(6162),
    [sym_array_get_expression] = STATE(6162),
    [sym_string_get_expression] = STATE(6162),
    [sym_bigarray_get_expression] = STATE(6162),
    [sym_coercion_expression] = STATE(6162),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(2506),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [aux_sym_class_application_repeat1] = STATE(2506),
    [sym__lowercase_identifier] = ACTIONS(6173),
    [anon_sym_TILDE] = ACTIONS(6176),
    [anon_sym_QMARK] = ACTIONS(6176),
    [anon_sym_LPAREN] = ACTIONS(6179),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(6182),
    [anon_sym_true] = ACTIONS(6185),
    [anon_sym_false] = ACTIONS(6185),
    [anon_sym_LBRACE] = ACTIONS(6188),
    [anon_sym_SEMI] = ACTIONS(3720),
    [anon_sym_with] = ACTIONS(3722),
    [anon_sym_object] = ACTIONS(6191),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6194),
    [anon_sym_else] = ACTIONS(3722),
    [anon_sym_new] = ACTIONS(6197),
    [anon_sym_LBRACE_LT] = ACTIONS(6200),
    [anon_sym_begin] = ACTIONS(6203),
    [sym_ocamlyacc_value] = ACTIONS(6206),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6209),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6212),
    [aux_sym_number_token1] = ACTIONS(6215),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(6218),
    [anon_sym_DQUOTE] = ACTIONS(6221),
    [sym_prefix_operator] = ACTIONS(6224),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(6227),
    [aux_sym_tag_token1] = ACTIONS(6230),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2507] = {
    [sym__simple_expression] = STATE(6458),
    [sym_typed_expression] = STATE(6162),
    [sym_list_expression] = STATE(6162),
    [sym_array_expression] = STATE(6162),
    [sym_record_expression] = STATE(6162),
    [sym_labeled_argument] = STATE(7502),
    [sym_prefix_expression] = STATE(6162),
    [sym_hash_expression] = STATE(6162),
    [sym_field_get_expression] = STATE(6162),
    [sym_array_get_expression] = STATE(6162),
    [sym_string_get_expression] = STATE(6162),
    [sym_bigarray_get_expression] = STATE(6162),
    [sym_coercion_expression] = STATE(6162),
    [sym_local_open_expression] = STATE(6162),
    [sym_package_expression] = STATE(6162),
    [sym_new_expression] = STATE(6162),
    [sym_object_copy_expression] = STATE(6162),
    [sym_method_invocation] = STATE(6162),
    [sym_object_expression] = STATE(6162),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_attribute] = STATE(2507),
    [sym_extension] = STATE(6162),
    [sym_quoted_extension] = STATE(6162),
    [sym__constant] = STATE(6162),
    [sym_number] = STATE(6373),
    [sym_character] = STATE(6373),
    [sym_string] = STATE(6373),
    [sym_quoted_string] = STATE(6373),
    [sym_boolean] = STATE(6373),
    [sym_unit] = STATE(6373),
    [sym__value_name] = STATE(6262),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6162),
    [sym_module_path] = STATE(18284),
    [sym_constructor_path] = STATE(6162),
    [sym__constructor_name] = STATE(6367),
    [sym_tag] = STATE(6162),
    [aux_sym_class_application_repeat1] = STATE(2506),
    [sym__lowercase_identifier] = ACTIONS(5393),
    [anon_sym_TILDE] = ACTIONS(5395),
    [anon_sym_QMARK] = ACTIONS(5395),
    [anon_sym_LPAREN] = ACTIONS(2417),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_true] = ACTIONS(2421),
    [anon_sym_false] = ACTIONS(2421),
    [anon_sym_LBRACE] = ACTIONS(2423),
    [anon_sym_SEMI] = ACTIONS(3943),
    [anon_sym_with] = ACTIONS(3945),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2429),
    [anon_sym_else] = ACTIONS(3945),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_LBRACE_LT] = ACTIONS(2441),
    [anon_sym_begin] = ACTIONS(2443),
    [sym_ocamlyacc_value] = ACTIONS(2445),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2447),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2449),
    [aux_sym_number_token1] = ACTIONS(2451),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [sym_prefix_operator] = ACTIONS(2457),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(2461),
    [aux_sym_tag_token1] = ACTIONS(2463),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2508] = {
    [sym__simple_expression] = STATE(6518),
    [sym_typed_expression] = STATE(6303),
    [sym_list_expression] = STATE(6303),
    [sym_array_expression] = STATE(6303),
    [sym_record_expression] = STATE(6303),
    [sym_labeled_argument] = STATE(7569),
    [sym_prefix_expression] = STATE(6303),
    [sym_hash_expression] = STATE(6303),
    [sym_field_get_expression] = STATE(6303),
    [sym_array_get_expression] = STATE(6303),
    [sym_string_get_expression] = STATE(6303),
    [sym_bigarray_get_expression] = STATE(6303),
    [sym_coercion_expression] = STATE(6303),
    [sym_local_open_expression] = STATE(6303),
    [sym_package_expression] = STATE(6303),
    [sym_new_expression] = STATE(6303),
    [sym_object_copy_expression] = STATE(6303),
    [sym_method_invocation] = STATE(6303),
    [sym_object_expression] = STATE(6303),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_attribute] = STATE(2508),
    [sym_extension] = STATE(6303),
    [sym_quoted_extension] = STATE(6303),
    [sym__constant] = STATE(6303),
    [sym_number] = STATE(6629),
    [sym_character] = STATE(6629),
    [sym_string] = STATE(6629),
    [sym_quoted_string] = STATE(6629),
    [sym_boolean] = STATE(6629),
    [sym_unit] = STATE(6629),
    [sym__value_name] = STATE(6487),
    [sym_parenthesized_operator] = STATE(6655),
    [sym_value_path] = STATE(6303),
    [sym_module_path] = STATE(17732),
    [sym_constructor_path] = STATE(6303),
    [sym__constructor_name] = STATE(6631),
    [sym_tag] = STATE(6303),
    [aux_sym_class_application_repeat1] = STATE(2498),
    [sym__lowercase_identifier] = ACTIONS(5361),
    [anon_sym_TILDE] = ACTIONS(5363),
    [anon_sym_QMARK] = ACTIONS(5363),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_true] = ACTIONS(1549),
    [anon_sym_false] = ACTIONS(1549),
    [anon_sym_LBRACE] = ACTIONS(1551),
    [anon_sym_SEMI] = ACTIONS(3943),
    [anon_sym_object] = ACTIONS(1553),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1557),
    [anon_sym_to] = ACTIONS(3945),
    [anon_sym_downto] = ACTIONS(3945),
    [anon_sym_new] = ACTIONS(1567),
    [anon_sym_LBRACE_LT] = ACTIONS(1569),
    [anon_sym_begin] = ACTIONS(1571),
    [sym_ocamlyacc_value] = ACTIONS(1573),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1575),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1577),
    [aux_sym_number_token1] = ACTIONS(1579),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(1581),
    [anon_sym_DQUOTE] = ACTIONS(1583),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(1589),
    [aux_sym_tag_token1] = ACTIONS(1591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2509] = {
    [sym__simple_expression] = STATE(6274),
    [sym_typed_expression] = STATE(6539),
    [sym_list_expression] = STATE(6539),
    [sym_array_expression] = STATE(6539),
    [sym_record_expression] = STATE(6539),
    [sym_labeled_argument] = STATE(7553),
    [sym_prefix_expression] = STATE(6539),
    [sym_hash_expression] = STATE(6539),
    [sym_field_get_expression] = STATE(6539),
    [sym_array_get_expression] = STATE(6539),
    [sym_string_get_expression] = STATE(6539),
    [sym_bigarray_get_expression] = STATE(6539),
    [sym_coercion_expression] = STATE(6539),
    [sym_local_open_expression] = STATE(6539),
    [sym_package_expression] = STATE(6539),
    [sym_new_expression] = STATE(6539),
    [sym_object_copy_expression] = STATE(6539),
    [sym_method_invocation] = STATE(6539),
    [sym_object_expression] = STATE(6539),
    [sym_parenthesized_expression] = STATE(6539),
    [sym_attribute] = STATE(2509),
    [sym_extension] = STATE(6539),
    [sym_quoted_extension] = STATE(6539),
    [sym__constant] = STATE(6539),
    [sym_number] = STATE(6584),
    [sym_character] = STATE(6584),
    [sym_string] = STATE(6584),
    [sym_quoted_string] = STATE(6584),
    [sym_boolean] = STATE(6584),
    [sym_unit] = STATE(6584),
    [sym__value_name] = STATE(6336),
    [sym_parenthesized_operator] = STATE(6437),
    [sym_value_path] = STATE(6539),
    [sym_module_path] = STATE(18163),
    [sym_constructor_path] = STATE(6539),
    [sym__constructor_name] = STATE(6592),
    [sym_tag] = STATE(6539),
    [aux_sym_class_application_repeat1] = STATE(2501),
    [sym__lowercase_identifier] = ACTIONS(5371),
    [anon_sym_TILDE] = ACTIONS(5373),
    [anon_sym_QMARK] = ACTIONS(5373),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_SEMI] = ACTIONS(3943),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_then] = ACTIONS(3945),
    [anon_sym_else] = ACTIONS(3945),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2510] = {
    [sym__simple_expression] = STATE(7089),
    [sym_typed_expression] = STATE(6724),
    [sym_list_expression] = STATE(6724),
    [sym_array_expression] = STATE(6724),
    [sym_record_expression] = STATE(6724),
    [sym_labeled_argument] = STATE(7804),
    [sym_prefix_expression] = STATE(6724),
    [sym_hash_expression] = STATE(6724),
    [sym_field_get_expression] = STATE(6724),
    [sym_array_get_expression] = STATE(6724),
    [sym_string_get_expression] = STATE(6724),
    [sym_bigarray_get_expression] = STATE(6724),
    [sym_coercion_expression] = STATE(6724),
    [sym_local_open_expression] = STATE(6724),
    [sym_package_expression] = STATE(6724),
    [sym_new_expression] = STATE(6724),
    [sym_object_copy_expression] = STATE(6724),
    [sym_method_invocation] = STATE(6724),
    [sym_object_expression] = STATE(6724),
    [sym_parenthesized_expression] = STATE(6724),
    [sym_attribute] = STATE(2510),
    [sym_extension] = STATE(6724),
    [sym_quoted_extension] = STATE(6724),
    [sym__constant] = STATE(6724),
    [sym_number] = STATE(7169),
    [sym_character] = STATE(7169),
    [sym_string] = STATE(7169),
    [sym_quoted_string] = STATE(7169),
    [sym_boolean] = STATE(7169),
    [sym_unit] = STATE(7169),
    [sym__value_name] = STATE(6722),
    [sym_parenthesized_operator] = STATE(7077),
    [sym_value_path] = STATE(6724),
    [sym_module_path] = STATE(18484),
    [sym_constructor_path] = STATE(6724),
    [sym__constructor_name] = STATE(7168),
    [sym_tag] = STATE(6724),
    [aux_sym_class_application_repeat1] = STATE(2514),
    [sym__lowercase_identifier] = ACTIONS(6233),
    [anon_sym_SEMI_SEMI] = ACTIONS(5687),
    [anon_sym_and] = ACTIONS(5689),
    [anon_sym_TILDE] = ACTIONS(6235),
    [anon_sym_QMARK] = ACTIONS(6235),
    [anon_sym_LPAREN] = ACTIONS(6237),
    [anon_sym_external] = ACTIONS(5689),
    [anon_sym_type] = ACTIONS(5689),
    [anon_sym_LBRACK] = ACTIONS(6239),
    [anon_sym_true] = ACTIONS(6241),
    [anon_sym_false] = ACTIONS(6241),
    [anon_sym_LBRACE] = ACTIONS(6243),
    [anon_sym_exception] = ACTIONS(5689),
    [anon_sym_module] = ACTIONS(5689),
    [anon_sym_open] = ACTIONS(5689),
    [anon_sym_include] = ACTIONS(5689),
    [anon_sym_class] = ACTIONS(5689),
    [anon_sym_val] = ACTIONS(5689),
    [anon_sym_end] = ACTIONS(5689),
    [anon_sym_object] = ACTIONS(6245),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6247),
    [anon_sym_new] = ACTIONS(6249),
    [anon_sym_LBRACE_LT] = ACTIONS(6251),
    [anon_sym_begin] = ACTIONS(6253),
    [sym_ocamlyacc_value] = ACTIONS(6255),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5689),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5687),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6259),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5687),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5687),
    [aux_sym_number_token1] = ACTIONS(6261),
    [anon_sym_SQUOTE] = ACTIONS(6263),
    [anon_sym_DQUOTE] = ACTIONS(6265),
    [sym_prefix_operator] = ACTIONS(6267),
    [sym__uppercase_identifier] = ACTIONS(6269),
    [aux_sym_tag_token1] = ACTIONS(6271),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2511] = {
    [sym__simple_expression] = STATE(6862),
    [sym_typed_expression] = STATE(6715),
    [sym_list_expression] = STATE(6715),
    [sym_array_expression] = STATE(6715),
    [sym_record_expression] = STATE(6715),
    [sym_labeled_argument] = STATE(7641),
    [sym_prefix_expression] = STATE(6715),
    [sym_hash_expression] = STATE(6715),
    [sym_field_get_expression] = STATE(6715),
    [sym_array_get_expression] = STATE(6715),
    [sym_string_get_expression] = STATE(6715),
    [sym_bigarray_get_expression] = STATE(6715),
    [sym_coercion_expression] = STATE(6715),
    [sym_local_open_expression] = STATE(6715),
    [sym_package_expression] = STATE(6715),
    [sym_new_expression] = STATE(6715),
    [sym_object_copy_expression] = STATE(6715),
    [sym_method_invocation] = STATE(6715),
    [sym_object_expression] = STATE(6715),
    [sym_parenthesized_expression] = STATE(6715),
    [sym_attribute] = STATE(2511),
    [sym_extension] = STATE(6715),
    [sym_quoted_extension] = STATE(6715),
    [sym__constant] = STATE(6715),
    [sym_number] = STATE(7075),
    [sym_character] = STATE(7075),
    [sym_string] = STATE(7075),
    [sym_quoted_string] = STATE(7075),
    [sym_boolean] = STATE(7075),
    [sym_unit] = STATE(7075),
    [sym__value_name] = STATE(6814),
    [sym_parenthesized_operator] = STATE(7163),
    [sym_value_path] = STATE(6715),
    [sym_module_path] = STATE(18564),
    [sym_constructor_path] = STATE(6715),
    [sym__constructor_name] = STATE(7074),
    [sym_tag] = STATE(6715),
    [aux_sym_class_application_repeat1] = STATE(2520),
    [sym__lowercase_identifier] = ACTIONS(6273),
    [anon_sym_SEMI_SEMI] = ACTIONS(5583),
    [anon_sym_and] = ACTIONS(5585),
    [anon_sym_TILDE] = ACTIONS(6275),
    [anon_sym_QMARK] = ACTIONS(6275),
    [anon_sym_LPAREN] = ACTIONS(6277),
    [anon_sym_external] = ACTIONS(5585),
    [anon_sym_type] = ACTIONS(5585),
    [anon_sym_LBRACK] = ACTIONS(6279),
    [anon_sym_RBRACK] = ACTIONS(5583),
    [anon_sym_true] = ACTIONS(6281),
    [anon_sym_false] = ACTIONS(6281),
    [anon_sym_LBRACE] = ACTIONS(6283),
    [anon_sym_exception] = ACTIONS(5585),
    [anon_sym_module] = ACTIONS(5585),
    [anon_sym_open] = ACTIONS(5585),
    [anon_sym_include] = ACTIONS(5585),
    [anon_sym_class] = ACTIONS(5585),
    [anon_sym_val] = ACTIONS(5585),
    [anon_sym_object] = ACTIONS(6285),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6287),
    [anon_sym_new] = ACTIONS(6289),
    [anon_sym_LBRACE_LT] = ACTIONS(6291),
    [anon_sym_begin] = ACTIONS(6293),
    [sym_ocamlyacc_value] = ACTIONS(6295),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5585),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5583),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6297),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6299),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5583),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5583),
    [aux_sym_number_token1] = ACTIONS(6301),
    [anon_sym_SQUOTE] = ACTIONS(6303),
    [anon_sym_DQUOTE] = ACTIONS(6305),
    [sym_prefix_operator] = ACTIONS(6307),
    [sym__uppercase_identifier] = ACTIONS(6309),
    [aux_sym_tag_token1] = ACTIONS(6311),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2512] = {
    [sym__simple_expression] = STATE(6881),
    [sym_typed_expression] = STATE(7128),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_labeled_argument] = STATE(7751),
    [sym_prefix_expression] = STATE(7128),
    [sym_hash_expression] = STATE(7128),
    [sym_field_get_expression] = STATE(7128),
    [sym_array_get_expression] = STATE(7128),
    [sym_string_get_expression] = STATE(7128),
    [sym_bigarray_get_expression] = STATE(7128),
    [sym_coercion_expression] = STATE(7128),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(2512),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [aux_sym_class_application_repeat1] = STATE(2512),
    [sym__lowercase_identifier] = ACTIONS(6313),
    [anon_sym_TILDE] = ACTIONS(6316),
    [anon_sym_QMARK] = ACTIONS(6316),
    [anon_sym_LPAREN] = ACTIONS(6319),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(6322),
    [anon_sym_true] = ACTIONS(6325),
    [anon_sym_false] = ACTIONS(6325),
    [anon_sym_LBRACE] = ACTIONS(6328),
    [anon_sym_SEMI] = ACTIONS(3720),
    [anon_sym_object] = ACTIONS(6331),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6334),
    [anon_sym_then] = ACTIONS(3722),
    [anon_sym_new] = ACTIONS(6337),
    [anon_sym_LBRACE_LT] = ACTIONS(6340),
    [anon_sym_begin] = ACTIONS(6343),
    [sym_ocamlyacc_value] = ACTIONS(6346),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6349),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6352),
    [aux_sym_number_token1] = ACTIONS(6355),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(6358),
    [anon_sym_DQUOTE] = ACTIONS(6361),
    [sym_prefix_operator] = ACTIONS(6364),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(6367),
    [aux_sym_tag_token1] = ACTIONS(6370),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2513] = {
    [sym__simple_expression] = STATE(7089),
    [sym_typed_expression] = STATE(6724),
    [sym_list_expression] = STATE(6724),
    [sym_array_expression] = STATE(6724),
    [sym_record_expression] = STATE(6724),
    [sym_labeled_argument] = STATE(7804),
    [sym_prefix_expression] = STATE(6724),
    [sym_hash_expression] = STATE(6724),
    [sym_field_get_expression] = STATE(6724),
    [sym_array_get_expression] = STATE(6724),
    [sym_string_get_expression] = STATE(6724),
    [sym_bigarray_get_expression] = STATE(6724),
    [sym_coercion_expression] = STATE(6724),
    [sym_local_open_expression] = STATE(6724),
    [sym_package_expression] = STATE(6724),
    [sym_new_expression] = STATE(6724),
    [sym_object_copy_expression] = STATE(6724),
    [sym_method_invocation] = STATE(6724),
    [sym_object_expression] = STATE(6724),
    [sym_parenthesized_expression] = STATE(6724),
    [sym_attribute] = STATE(2513),
    [sym_extension] = STATE(6724),
    [sym_quoted_extension] = STATE(6724),
    [sym__constant] = STATE(6724),
    [sym_number] = STATE(7169),
    [sym_character] = STATE(7169),
    [sym_string] = STATE(7169),
    [sym_quoted_string] = STATE(7169),
    [sym_boolean] = STATE(7169),
    [sym_unit] = STATE(7169),
    [sym__value_name] = STATE(6722),
    [sym_parenthesized_operator] = STATE(7077),
    [sym_value_path] = STATE(6724),
    [sym_module_path] = STATE(18484),
    [sym_constructor_path] = STATE(6724),
    [sym__constructor_name] = STATE(7168),
    [sym_tag] = STATE(6724),
    [aux_sym_class_application_repeat1] = STATE(2510),
    [sym__lowercase_identifier] = ACTIONS(6233),
    [anon_sym_SEMI_SEMI] = ACTIONS(5583),
    [anon_sym_and] = ACTIONS(5585),
    [anon_sym_TILDE] = ACTIONS(6235),
    [anon_sym_QMARK] = ACTIONS(6235),
    [anon_sym_LPAREN] = ACTIONS(6237),
    [anon_sym_external] = ACTIONS(5585),
    [anon_sym_type] = ACTIONS(5585),
    [anon_sym_LBRACK] = ACTIONS(6239),
    [anon_sym_true] = ACTIONS(6241),
    [anon_sym_false] = ACTIONS(6241),
    [anon_sym_LBRACE] = ACTIONS(6243),
    [anon_sym_exception] = ACTIONS(5585),
    [anon_sym_module] = ACTIONS(5585),
    [anon_sym_open] = ACTIONS(5585),
    [anon_sym_include] = ACTIONS(5585),
    [anon_sym_class] = ACTIONS(5585),
    [anon_sym_val] = ACTIONS(5585),
    [anon_sym_end] = ACTIONS(5585),
    [anon_sym_object] = ACTIONS(6245),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6247),
    [anon_sym_new] = ACTIONS(6249),
    [anon_sym_LBRACE_LT] = ACTIONS(6251),
    [anon_sym_begin] = ACTIONS(6253),
    [sym_ocamlyacc_value] = ACTIONS(6255),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5585),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5583),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6257),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6259),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5583),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5583),
    [aux_sym_number_token1] = ACTIONS(6261),
    [anon_sym_SQUOTE] = ACTIONS(6263),
    [anon_sym_DQUOTE] = ACTIONS(6265),
    [sym_prefix_operator] = ACTIONS(6267),
    [sym__uppercase_identifier] = ACTIONS(6269),
    [aux_sym_tag_token1] = ACTIONS(6271),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2514] = {
    [sym__simple_expression] = STATE(7089),
    [sym_typed_expression] = STATE(6724),
    [sym_list_expression] = STATE(6724),
    [sym_array_expression] = STATE(6724),
    [sym_record_expression] = STATE(6724),
    [sym_labeled_argument] = STATE(7804),
    [sym_prefix_expression] = STATE(6724),
    [sym_hash_expression] = STATE(6724),
    [sym_field_get_expression] = STATE(6724),
    [sym_array_get_expression] = STATE(6724),
    [sym_string_get_expression] = STATE(6724),
    [sym_bigarray_get_expression] = STATE(6724),
    [sym_coercion_expression] = STATE(6724),
    [sym_local_open_expression] = STATE(6724),
    [sym_package_expression] = STATE(6724),
    [sym_new_expression] = STATE(6724),
    [sym_object_copy_expression] = STATE(6724),
    [sym_method_invocation] = STATE(6724),
    [sym_object_expression] = STATE(6724),
    [sym_parenthesized_expression] = STATE(6724),
    [sym_attribute] = STATE(2514),
    [sym_extension] = STATE(6724),
    [sym_quoted_extension] = STATE(6724),
    [sym__constant] = STATE(6724),
    [sym_number] = STATE(7169),
    [sym_character] = STATE(7169),
    [sym_string] = STATE(7169),
    [sym_quoted_string] = STATE(7169),
    [sym_boolean] = STATE(7169),
    [sym_unit] = STATE(7169),
    [sym__value_name] = STATE(6722),
    [sym_parenthesized_operator] = STATE(7077),
    [sym_value_path] = STATE(6724),
    [sym_module_path] = STATE(18484),
    [sym_constructor_path] = STATE(6724),
    [sym__constructor_name] = STATE(7168),
    [sym_tag] = STATE(6724),
    [aux_sym_class_application_repeat1] = STATE(2514),
    [sym__lowercase_identifier] = ACTIONS(6373),
    [anon_sym_SEMI_SEMI] = ACTIONS(3720),
    [anon_sym_and] = ACTIONS(3722),
    [anon_sym_TILDE] = ACTIONS(6376),
    [anon_sym_QMARK] = ACTIONS(6376),
    [anon_sym_LPAREN] = ACTIONS(6379),
    [anon_sym_external] = ACTIONS(3722),
    [anon_sym_type] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(6382),
    [anon_sym_true] = ACTIONS(6385),
    [anon_sym_false] = ACTIONS(6385),
    [anon_sym_LBRACE] = ACTIONS(6388),
    [anon_sym_exception] = ACTIONS(3722),
    [anon_sym_module] = ACTIONS(3722),
    [anon_sym_open] = ACTIONS(3722),
    [anon_sym_include] = ACTIONS(3722),
    [anon_sym_class] = ACTIONS(3722),
    [anon_sym_val] = ACTIONS(3722),
    [anon_sym_end] = ACTIONS(3722),
    [anon_sym_object] = ACTIONS(6391),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6394),
    [anon_sym_new] = ACTIONS(6397),
    [anon_sym_LBRACE_LT] = ACTIONS(6400),
    [anon_sym_begin] = ACTIONS(6403),
    [sym_ocamlyacc_value] = ACTIONS(6406),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3722),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3720),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6409),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6412),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3720),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3720),
    [aux_sym_number_token1] = ACTIONS(6415),
    [anon_sym_SQUOTE] = ACTIONS(6418),
    [anon_sym_DQUOTE] = ACTIONS(6421),
    [sym_prefix_operator] = ACTIONS(6424),
    [sym__uppercase_identifier] = ACTIONS(6427),
    [aux_sym_tag_token1] = ACTIONS(6430),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2515] = {
    [sym__simple_expression] = STATE(7103),
    [sym_typed_expression] = STATE(7067),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_labeled_argument] = STATE(7762),
    [sym_prefix_expression] = STATE(7067),
    [sym_hash_expression] = STATE(7067),
    [sym_field_get_expression] = STATE(7067),
    [sym_array_get_expression] = STATE(7067),
    [sym_string_get_expression] = STATE(7067),
    [sym_bigarray_get_expression] = STATE(7067),
    [sym_coercion_expression] = STATE(7067),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2515),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [aux_sym_class_application_repeat1] = STATE(2517),
    [sym__lowercase_identifier] = ACTIONS(5561),
    [anon_sym_TILDE] = ACTIONS(5563),
    [anon_sym_QMARK] = ACTIONS(5563),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(2697),
    [anon_sym_true] = ACTIONS(2699),
    [anon_sym_false] = ACTIONS(2699),
    [anon_sym_LBRACE] = ACTIONS(2701),
    [anon_sym_SEMI] = ACTIONS(3943),
    [anon_sym_with] = ACTIONS(3945),
    [anon_sym_object] = ACTIONS(2703),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2707),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_LBRACE_LT] = ACTIONS(2719),
    [anon_sym_begin] = ACTIONS(2721),
    [sym_ocamlyacc_value] = ACTIONS(2723),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2725),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2727),
    [aux_sym_number_token1] = ACTIONS(2729),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2733),
    [sym_prefix_operator] = ACTIONS(2735),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(2739),
    [aux_sym_tag_token1] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2516] = {
    [sym__simple_expression] = STATE(7151),
    [sym_typed_expression] = STATE(7193),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_labeled_argument] = STATE(7826),
    [sym_prefix_expression] = STATE(7193),
    [sym_hash_expression] = STATE(7193),
    [sym_field_get_expression] = STATE(7193),
    [sym_array_get_expression] = STATE(7193),
    [sym_string_get_expression] = STATE(7193),
    [sym_bigarray_get_expression] = STATE(7193),
    [sym_coercion_expression] = STATE(7193),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(2516),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [aux_sym_class_application_repeat1] = STATE(2516),
    [sym__lowercase_identifier] = ACTIONS(6433),
    [anon_sym_TILDE] = ACTIONS(6436),
    [anon_sym_QMARK] = ACTIONS(6436),
    [anon_sym_LPAREN] = ACTIONS(6439),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(6442),
    [anon_sym_true] = ACTIONS(6445),
    [anon_sym_false] = ACTIONS(6445),
    [anon_sym_LBRACE] = ACTIONS(6448),
    [anon_sym_SEMI] = ACTIONS(3720),
    [anon_sym_object] = ACTIONS(6451),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6454),
    [anon_sym_do] = ACTIONS(3722),
    [anon_sym_new] = ACTIONS(6457),
    [anon_sym_LBRACE_LT] = ACTIONS(6460),
    [anon_sym_begin] = ACTIONS(6463),
    [sym_ocamlyacc_value] = ACTIONS(6466),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6469),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6472),
    [aux_sym_number_token1] = ACTIONS(6475),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(6478),
    [anon_sym_DQUOTE] = ACTIONS(6481),
    [sym_prefix_operator] = ACTIONS(6484),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(6487),
    [aux_sym_tag_token1] = ACTIONS(6490),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2517] = {
    [sym__simple_expression] = STATE(7103),
    [sym_typed_expression] = STATE(7067),
    [sym_list_expression] = STATE(7067),
    [sym_array_expression] = STATE(7067),
    [sym_record_expression] = STATE(7067),
    [sym_labeled_argument] = STATE(7762),
    [sym_prefix_expression] = STATE(7067),
    [sym_hash_expression] = STATE(7067),
    [sym_field_get_expression] = STATE(7067),
    [sym_array_get_expression] = STATE(7067),
    [sym_string_get_expression] = STATE(7067),
    [sym_bigarray_get_expression] = STATE(7067),
    [sym_coercion_expression] = STATE(7067),
    [sym_local_open_expression] = STATE(7067),
    [sym_package_expression] = STATE(7067),
    [sym_new_expression] = STATE(7067),
    [sym_object_copy_expression] = STATE(7067),
    [sym_method_invocation] = STATE(7067),
    [sym_object_expression] = STATE(7067),
    [sym_parenthesized_expression] = STATE(7067),
    [sym_attribute] = STATE(2517),
    [sym_extension] = STATE(7067),
    [sym_quoted_extension] = STATE(7067),
    [sym__constant] = STATE(7067),
    [sym_number] = STATE(6871),
    [sym_character] = STATE(6871),
    [sym_string] = STATE(6871),
    [sym_quoted_string] = STATE(6871),
    [sym_boolean] = STATE(6871),
    [sym_unit] = STATE(6871),
    [sym__value_name] = STATE(7081),
    [sym_parenthesized_operator] = STATE(7147),
    [sym_value_path] = STATE(7067),
    [sym_module_path] = STATE(19042),
    [sym_constructor_path] = STATE(7067),
    [sym__constructor_name] = STATE(6885),
    [sym_tag] = STATE(7067),
    [aux_sym_class_application_repeat1] = STATE(2517),
    [sym__lowercase_identifier] = ACTIONS(6493),
    [anon_sym_TILDE] = ACTIONS(6496),
    [anon_sym_QMARK] = ACTIONS(6496),
    [anon_sym_LPAREN] = ACTIONS(6499),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(6502),
    [anon_sym_true] = ACTIONS(6505),
    [anon_sym_false] = ACTIONS(6505),
    [anon_sym_LBRACE] = ACTIONS(6508),
    [anon_sym_SEMI] = ACTIONS(3720),
    [anon_sym_with] = ACTIONS(3722),
    [anon_sym_object] = ACTIONS(6511),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6514),
    [anon_sym_new] = ACTIONS(6517),
    [anon_sym_LBRACE_LT] = ACTIONS(6520),
    [anon_sym_begin] = ACTIONS(6523),
    [sym_ocamlyacc_value] = ACTIONS(6526),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6529),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6532),
    [aux_sym_number_token1] = ACTIONS(6535),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(6538),
    [anon_sym_DQUOTE] = ACTIONS(6541),
    [sym_prefix_operator] = ACTIONS(6544),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(6547),
    [aux_sym_tag_token1] = ACTIONS(6550),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2518] = {
    [sym__simple_expression] = STATE(7151),
    [sym_typed_expression] = STATE(7193),
    [sym_list_expression] = STATE(7193),
    [sym_array_expression] = STATE(7193),
    [sym_record_expression] = STATE(7193),
    [sym_labeled_argument] = STATE(7826),
    [sym_prefix_expression] = STATE(7193),
    [sym_hash_expression] = STATE(7193),
    [sym_field_get_expression] = STATE(7193),
    [sym_array_get_expression] = STATE(7193),
    [sym_string_get_expression] = STATE(7193),
    [sym_bigarray_get_expression] = STATE(7193),
    [sym_coercion_expression] = STATE(7193),
    [sym_local_open_expression] = STATE(7193),
    [sym_package_expression] = STATE(7193),
    [sym_new_expression] = STATE(7193),
    [sym_object_copy_expression] = STATE(7193),
    [sym_method_invocation] = STATE(7193),
    [sym_object_expression] = STATE(7193),
    [sym_parenthesized_expression] = STATE(7193),
    [sym_attribute] = STATE(2518),
    [sym_extension] = STATE(7193),
    [sym_quoted_extension] = STATE(7193),
    [sym__constant] = STATE(7193),
    [sym_number] = STATE(6940),
    [sym_character] = STATE(6940),
    [sym_string] = STATE(6940),
    [sym_quoted_string] = STATE(6940),
    [sym_boolean] = STATE(6940),
    [sym_unit] = STATE(6940),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7065),
    [sym_value_path] = STATE(7193),
    [sym_module_path] = STATE(19332),
    [sym_constructor_path] = STATE(7193),
    [sym__constructor_name] = STATE(6870),
    [sym_tag] = STATE(7193),
    [aux_sym_class_application_repeat1] = STATE(2516),
    [sym__lowercase_identifier] = ACTIONS(5571),
    [anon_sym_TILDE] = ACTIONS(5573),
    [anon_sym_QMARK] = ACTIONS(5573),
    [anon_sym_LPAREN] = ACTIONS(2747),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_true] = ACTIONS(2751),
    [anon_sym_false] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_SEMI] = ACTIONS(3943),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2759),
    [anon_sym_do] = ACTIONS(3945),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_LBRACE_LT] = ACTIONS(2771),
    [anon_sym_begin] = ACTIONS(2773),
    [sym_ocamlyacc_value] = ACTIONS(2775),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2777),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2779),
    [aux_sym_number_token1] = ACTIONS(2781),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2785),
    [sym_prefix_operator] = ACTIONS(2787),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(2791),
    [aux_sym_tag_token1] = ACTIONS(2793),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2519] = {
    [sym__simple_expression] = STATE(7115),
    [sym_typed_expression] = STATE(6896),
    [sym_list_expression] = STATE(6896),
    [sym_array_expression] = STATE(6896),
    [sym_record_expression] = STATE(6896),
    [sym_labeled_argument] = STATE(7641),
    [sym_prefix_expression] = STATE(6896),
    [sym_hash_expression] = STATE(6896),
    [sym_field_get_expression] = STATE(6896),
    [sym_array_get_expression] = STATE(6896),
    [sym_string_get_expression] = STATE(6896),
    [sym_bigarray_get_expression] = STATE(6896),
    [sym_coercion_expression] = STATE(6896),
    [sym_local_open_expression] = STATE(6896),
    [sym_package_expression] = STATE(6896),
    [sym_new_expression] = STATE(6896),
    [sym_object_copy_expression] = STATE(6896),
    [sym_method_invocation] = STATE(6896),
    [sym_object_expression] = STATE(6896),
    [sym_parenthesized_expression] = STATE(6896),
    [sym_attribute] = STATE(2519),
    [sym_extension] = STATE(6896),
    [sym_quoted_extension] = STATE(6896),
    [sym__constant] = STATE(6896),
    [sym_number] = STATE(6891),
    [sym_character] = STATE(6891),
    [sym_string] = STATE(6891),
    [sym_quoted_string] = STATE(6891),
    [sym_boolean] = STATE(6891),
    [sym_unit] = STATE(6891),
    [sym__value_name] = STATE(6884),
    [sym_parenthesized_operator] = STATE(6841),
    [sym_value_path] = STATE(6896),
    [sym_module_path] = STATE(18104),
    [sym_constructor_path] = STATE(6896),
    [sym__constructor_name] = STATE(6890),
    [sym_tag] = STATE(6896),
    [aux_sym_class_application_repeat1] = STATE(2522),
    [ts_builtin_sym_end] = ACTIONS(5583),
    [sym__lowercase_identifier] = ACTIONS(6553),
    [anon_sym_SEMI_SEMI] = ACTIONS(5583),
    [anon_sym_and] = ACTIONS(5585),
    [anon_sym_TILDE] = ACTIONS(6555),
    [anon_sym_QMARK] = ACTIONS(6555),
    [anon_sym_LPAREN] = ACTIONS(6557),
    [anon_sym_external] = ACTIONS(5585),
    [anon_sym_type] = ACTIONS(5585),
    [anon_sym_LBRACK] = ACTIONS(6559),
    [anon_sym_true] = ACTIONS(6561),
    [anon_sym_false] = ACTIONS(6561),
    [anon_sym_LBRACE] = ACTIONS(6563),
    [anon_sym_exception] = ACTIONS(5585),
    [anon_sym_module] = ACTIONS(5585),
    [anon_sym_open] = ACTIONS(5585),
    [anon_sym_include] = ACTIONS(5585),
    [anon_sym_class] = ACTIONS(5585),
    [anon_sym_val] = ACTIONS(5585),
    [anon_sym_object] = ACTIONS(6565),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6567),
    [anon_sym_new] = ACTIONS(6569),
    [anon_sym_LBRACE_LT] = ACTIONS(6571),
    [anon_sym_begin] = ACTIONS(6573),
    [sym_ocamlyacc_value] = ACTIONS(6575),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5585),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5583),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6577),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6579),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5583),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5583),
    [aux_sym_number_token1] = ACTIONS(6581),
    [anon_sym_SQUOTE] = ACTIONS(6583),
    [anon_sym_DQUOTE] = ACTIONS(6585),
    [sym_prefix_operator] = ACTIONS(6587),
    [sym__uppercase_identifier] = ACTIONS(6589),
    [aux_sym_tag_token1] = ACTIONS(6591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2520] = {
    [sym__simple_expression] = STATE(6862),
    [sym_typed_expression] = STATE(6715),
    [sym_list_expression] = STATE(6715),
    [sym_array_expression] = STATE(6715),
    [sym_record_expression] = STATE(6715),
    [sym_labeled_argument] = STATE(7641),
    [sym_prefix_expression] = STATE(6715),
    [sym_hash_expression] = STATE(6715),
    [sym_field_get_expression] = STATE(6715),
    [sym_array_get_expression] = STATE(6715),
    [sym_string_get_expression] = STATE(6715),
    [sym_bigarray_get_expression] = STATE(6715),
    [sym_coercion_expression] = STATE(6715),
    [sym_local_open_expression] = STATE(6715),
    [sym_package_expression] = STATE(6715),
    [sym_new_expression] = STATE(6715),
    [sym_object_copy_expression] = STATE(6715),
    [sym_method_invocation] = STATE(6715),
    [sym_object_expression] = STATE(6715),
    [sym_parenthesized_expression] = STATE(6715),
    [sym_attribute] = STATE(2520),
    [sym_extension] = STATE(6715),
    [sym_quoted_extension] = STATE(6715),
    [sym__constant] = STATE(6715),
    [sym_number] = STATE(7075),
    [sym_character] = STATE(7075),
    [sym_string] = STATE(7075),
    [sym_quoted_string] = STATE(7075),
    [sym_boolean] = STATE(7075),
    [sym_unit] = STATE(7075),
    [sym__value_name] = STATE(6814),
    [sym_parenthesized_operator] = STATE(7163),
    [sym_value_path] = STATE(6715),
    [sym_module_path] = STATE(18564),
    [sym_constructor_path] = STATE(6715),
    [sym__constructor_name] = STATE(7074),
    [sym_tag] = STATE(6715),
    [aux_sym_class_application_repeat1] = STATE(2523),
    [sym__lowercase_identifier] = ACTIONS(6273),
    [anon_sym_SEMI_SEMI] = ACTIONS(5687),
    [anon_sym_and] = ACTIONS(5689),
    [anon_sym_TILDE] = ACTIONS(6275),
    [anon_sym_QMARK] = ACTIONS(6275),
    [anon_sym_LPAREN] = ACTIONS(6277),
    [anon_sym_external] = ACTIONS(5689),
    [anon_sym_type] = ACTIONS(5689),
    [anon_sym_LBRACK] = ACTIONS(6279),
    [anon_sym_RBRACK] = ACTIONS(5687),
    [anon_sym_true] = ACTIONS(6281),
    [anon_sym_false] = ACTIONS(6281),
    [anon_sym_LBRACE] = ACTIONS(6283),
    [anon_sym_exception] = ACTIONS(5689),
    [anon_sym_module] = ACTIONS(5689),
    [anon_sym_open] = ACTIONS(5689),
    [anon_sym_include] = ACTIONS(5689),
    [anon_sym_class] = ACTIONS(5689),
    [anon_sym_val] = ACTIONS(5689),
    [anon_sym_object] = ACTIONS(6285),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6287),
    [anon_sym_new] = ACTIONS(6289),
    [anon_sym_LBRACE_LT] = ACTIONS(6291),
    [anon_sym_begin] = ACTIONS(6293),
    [sym_ocamlyacc_value] = ACTIONS(6295),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5689),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5687),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6297),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6299),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5687),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5687),
    [aux_sym_number_token1] = ACTIONS(6301),
    [anon_sym_SQUOTE] = ACTIONS(6303),
    [anon_sym_DQUOTE] = ACTIONS(6305),
    [sym_prefix_operator] = ACTIONS(6307),
    [sym__uppercase_identifier] = ACTIONS(6309),
    [aux_sym_tag_token1] = ACTIONS(6311),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2521] = {
    [sym__simple_expression] = STATE(6881),
    [sym_typed_expression] = STATE(7128),
    [sym_list_expression] = STATE(7128),
    [sym_array_expression] = STATE(7128),
    [sym_record_expression] = STATE(7128),
    [sym_labeled_argument] = STATE(7751),
    [sym_prefix_expression] = STATE(7128),
    [sym_hash_expression] = STATE(7128),
    [sym_field_get_expression] = STATE(7128),
    [sym_array_get_expression] = STATE(7128),
    [sym_string_get_expression] = STATE(7128),
    [sym_bigarray_get_expression] = STATE(7128),
    [sym_coercion_expression] = STATE(7128),
    [sym_local_open_expression] = STATE(7128),
    [sym_package_expression] = STATE(7128),
    [sym_new_expression] = STATE(7128),
    [sym_object_copy_expression] = STATE(7128),
    [sym_method_invocation] = STATE(7128),
    [sym_object_expression] = STATE(7128),
    [sym_parenthesized_expression] = STATE(7128),
    [sym_attribute] = STATE(2521),
    [sym_extension] = STATE(7128),
    [sym_quoted_extension] = STATE(7128),
    [sym__constant] = STATE(7128),
    [sym_number] = STATE(7136),
    [sym_character] = STATE(7136),
    [sym_string] = STATE(7136),
    [sym_quoted_string] = STATE(7136),
    [sym_boolean] = STATE(7136),
    [sym_unit] = STATE(7136),
    [sym__value_name] = STATE(7131),
    [sym_parenthesized_operator] = STATE(7200),
    [sym_value_path] = STATE(7128),
    [sym_module_path] = STATE(19879),
    [sym_constructor_path] = STATE(7128),
    [sym__constructor_name] = STATE(6939),
    [sym_tag] = STATE(7128),
    [aux_sym_class_application_repeat1] = STATE(2512),
    [sym__lowercase_identifier] = ACTIONS(5519),
    [anon_sym_TILDE] = ACTIONS(5521),
    [anon_sym_QMARK] = ACTIONS(5521),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_SEMI] = ACTIONS(3943),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_then] = ACTIONS(3945),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2522] = {
    [sym__simple_expression] = STATE(7115),
    [sym_typed_expression] = STATE(6896),
    [sym_list_expression] = STATE(6896),
    [sym_array_expression] = STATE(6896),
    [sym_record_expression] = STATE(6896),
    [sym_labeled_argument] = STATE(7641),
    [sym_prefix_expression] = STATE(6896),
    [sym_hash_expression] = STATE(6896),
    [sym_field_get_expression] = STATE(6896),
    [sym_array_get_expression] = STATE(6896),
    [sym_string_get_expression] = STATE(6896),
    [sym_bigarray_get_expression] = STATE(6896),
    [sym_coercion_expression] = STATE(6896),
    [sym_local_open_expression] = STATE(6896),
    [sym_package_expression] = STATE(6896),
    [sym_new_expression] = STATE(6896),
    [sym_object_copy_expression] = STATE(6896),
    [sym_method_invocation] = STATE(6896),
    [sym_object_expression] = STATE(6896),
    [sym_parenthesized_expression] = STATE(6896),
    [sym_attribute] = STATE(2522),
    [sym_extension] = STATE(6896),
    [sym_quoted_extension] = STATE(6896),
    [sym__constant] = STATE(6896),
    [sym_number] = STATE(6891),
    [sym_character] = STATE(6891),
    [sym_string] = STATE(6891),
    [sym_quoted_string] = STATE(6891),
    [sym_boolean] = STATE(6891),
    [sym_unit] = STATE(6891),
    [sym__value_name] = STATE(6884),
    [sym_parenthesized_operator] = STATE(6841),
    [sym_value_path] = STATE(6896),
    [sym_module_path] = STATE(18104),
    [sym_constructor_path] = STATE(6896),
    [sym__constructor_name] = STATE(6890),
    [sym_tag] = STATE(6896),
    [aux_sym_class_application_repeat1] = STATE(2527),
    [ts_builtin_sym_end] = ACTIONS(5687),
    [sym__lowercase_identifier] = ACTIONS(6553),
    [anon_sym_SEMI_SEMI] = ACTIONS(5687),
    [anon_sym_and] = ACTIONS(5689),
    [anon_sym_TILDE] = ACTIONS(6555),
    [anon_sym_QMARK] = ACTIONS(6555),
    [anon_sym_LPAREN] = ACTIONS(6557),
    [anon_sym_external] = ACTIONS(5689),
    [anon_sym_type] = ACTIONS(5689),
    [anon_sym_LBRACK] = ACTIONS(6559),
    [anon_sym_true] = ACTIONS(6561),
    [anon_sym_false] = ACTIONS(6561),
    [anon_sym_LBRACE] = ACTIONS(6563),
    [anon_sym_exception] = ACTIONS(5689),
    [anon_sym_module] = ACTIONS(5689),
    [anon_sym_open] = ACTIONS(5689),
    [anon_sym_include] = ACTIONS(5689),
    [anon_sym_class] = ACTIONS(5689),
    [anon_sym_val] = ACTIONS(5689),
    [anon_sym_object] = ACTIONS(6565),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6567),
    [anon_sym_new] = ACTIONS(6569),
    [anon_sym_LBRACE_LT] = ACTIONS(6571),
    [anon_sym_begin] = ACTIONS(6573),
    [sym_ocamlyacc_value] = ACTIONS(6575),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5689),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5687),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6577),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6579),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5687),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5687),
    [aux_sym_number_token1] = ACTIONS(6581),
    [anon_sym_SQUOTE] = ACTIONS(6583),
    [anon_sym_DQUOTE] = ACTIONS(6585),
    [sym_prefix_operator] = ACTIONS(6587),
    [sym__uppercase_identifier] = ACTIONS(6589),
    [aux_sym_tag_token1] = ACTIONS(6591),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2523] = {
    [sym__simple_expression] = STATE(6862),
    [sym_typed_expression] = STATE(6715),
    [sym_list_expression] = STATE(6715),
    [sym_array_expression] = STATE(6715),
    [sym_record_expression] = STATE(6715),
    [sym_labeled_argument] = STATE(7641),
    [sym_prefix_expression] = STATE(6715),
    [sym_hash_expression] = STATE(6715),
    [sym_field_get_expression] = STATE(6715),
    [sym_array_get_expression] = STATE(6715),
    [sym_string_get_expression] = STATE(6715),
    [sym_bigarray_get_expression] = STATE(6715),
    [sym_coercion_expression] = STATE(6715),
    [sym_local_open_expression] = STATE(6715),
    [sym_package_expression] = STATE(6715),
    [sym_new_expression] = STATE(6715),
    [sym_object_copy_expression] = STATE(6715),
    [sym_method_invocation] = STATE(6715),
    [sym_object_expression] = STATE(6715),
    [sym_parenthesized_expression] = STATE(6715),
    [sym_attribute] = STATE(2523),
    [sym_extension] = STATE(6715),
    [sym_quoted_extension] = STATE(6715),
    [sym__constant] = STATE(6715),
    [sym_number] = STATE(7075),
    [sym_character] = STATE(7075),
    [sym_string] = STATE(7075),
    [sym_quoted_string] = STATE(7075),
    [sym_boolean] = STATE(7075),
    [sym_unit] = STATE(7075),
    [sym__value_name] = STATE(6814),
    [sym_parenthesized_operator] = STATE(7163),
    [sym_value_path] = STATE(6715),
    [sym_module_path] = STATE(18564),
    [sym_constructor_path] = STATE(6715),
    [sym__constructor_name] = STATE(7074),
    [sym_tag] = STATE(6715),
    [aux_sym_class_application_repeat1] = STATE(2523),
    [sym__lowercase_identifier] = ACTIONS(6593),
    [anon_sym_SEMI_SEMI] = ACTIONS(3720),
    [anon_sym_and] = ACTIONS(3722),
    [anon_sym_TILDE] = ACTIONS(6596),
    [anon_sym_QMARK] = ACTIONS(6596),
    [anon_sym_LPAREN] = ACTIONS(6599),
    [anon_sym_external] = ACTIONS(3722),
    [anon_sym_type] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(6602),
    [anon_sym_RBRACK] = ACTIONS(3720),
    [anon_sym_true] = ACTIONS(6605),
    [anon_sym_false] = ACTIONS(6605),
    [anon_sym_LBRACE] = ACTIONS(6608),
    [anon_sym_exception] = ACTIONS(3722),
    [anon_sym_module] = ACTIONS(3722),
    [anon_sym_open] = ACTIONS(3722),
    [anon_sym_include] = ACTIONS(3722),
    [anon_sym_class] = ACTIONS(3722),
    [anon_sym_val] = ACTIONS(3722),
    [anon_sym_object] = ACTIONS(6611),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6614),
    [anon_sym_new] = ACTIONS(6617),
    [anon_sym_LBRACE_LT] = ACTIONS(6620),
    [anon_sym_begin] = ACTIONS(6623),
    [sym_ocamlyacc_value] = ACTIONS(6626),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3722),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3720),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6629),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6632),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3720),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3720),
    [aux_sym_number_token1] = ACTIONS(6635),
    [anon_sym_SQUOTE] = ACTIONS(6638),
    [anon_sym_DQUOTE] = ACTIONS(6641),
    [sym_prefix_operator] = ACTIONS(6644),
    [sym__uppercase_identifier] = ACTIONS(6647),
    [aux_sym_tag_token1] = ACTIONS(6650),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2524] = {
    [sym__simple_expression] = STATE(7222),
    [sym_typed_expression] = STATE(7138),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_labeled_argument] = STATE(7791),
    [sym_prefix_expression] = STATE(7138),
    [sym_hash_expression] = STATE(7138),
    [sym_field_get_expression] = STATE(7138),
    [sym_array_get_expression] = STATE(7138),
    [sym_string_get_expression] = STATE(7138),
    [sym_bigarray_get_expression] = STATE(7138),
    [sym_coercion_expression] = STATE(7138),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(2524),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [aux_sym_class_application_repeat1] = STATE(2526),
    [sym__lowercase_identifier] = ACTIONS(5529),
    [anon_sym_TILDE] = ACTIONS(5531),
    [anon_sym_QMARK] = ACTIONS(5531),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_true] = ACTIONS(2595),
    [anon_sym_false] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_SEMI] = ACTIONS(3943),
    [anon_sym_end] = ACTIONS(3945),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2603),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_LBRACE_LT] = ACTIONS(2615),
    [anon_sym_begin] = ACTIONS(2617),
    [sym_ocamlyacc_value] = ACTIONS(2619),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2623),
    [aux_sym_number_token1] = ACTIONS(2625),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(2627),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [sym_prefix_operator] = ACTIONS(2631),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(2635),
    [aux_sym_tag_token1] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2525] = {
    [sym__simple_expression] = STATE(6859),
    [sym_typed_expression] = STATE(7113),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_labeled_argument] = STATE(7731),
    [sym_prefix_expression] = STATE(7113),
    [sym_hash_expression] = STATE(7113),
    [sym_field_get_expression] = STATE(7113),
    [sym_array_get_expression] = STATE(7113),
    [sym_string_get_expression] = STATE(7113),
    [sym_bigarray_get_expression] = STATE(7113),
    [sym_coercion_expression] = STATE(7113),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(2525),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [aux_sym_class_application_repeat1] = STATE(2525),
    [sym__lowercase_identifier] = ACTIONS(6653),
    [anon_sym_TILDE] = ACTIONS(6656),
    [anon_sym_QMARK] = ACTIONS(6656),
    [anon_sym_LPAREN] = ACTIONS(6659),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(6662),
    [anon_sym_true] = ACTIONS(6665),
    [anon_sym_false] = ACTIONS(6665),
    [anon_sym_LBRACE] = ACTIONS(6668),
    [anon_sym_SEMI] = ACTIONS(3720),
    [anon_sym_object] = ACTIONS(6671),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6674),
    [anon_sym_done] = ACTIONS(3722),
    [anon_sym_new] = ACTIONS(6677),
    [anon_sym_LBRACE_LT] = ACTIONS(6680),
    [anon_sym_begin] = ACTIONS(6683),
    [sym_ocamlyacc_value] = ACTIONS(6686),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6689),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6692),
    [aux_sym_number_token1] = ACTIONS(6695),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(6698),
    [anon_sym_DQUOTE] = ACTIONS(6701),
    [sym_prefix_operator] = ACTIONS(6704),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(6707),
    [aux_sym_tag_token1] = ACTIONS(6710),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2526] = {
    [sym__simple_expression] = STATE(7222),
    [sym_typed_expression] = STATE(7138),
    [sym_list_expression] = STATE(7138),
    [sym_array_expression] = STATE(7138),
    [sym_record_expression] = STATE(7138),
    [sym_labeled_argument] = STATE(7791),
    [sym_prefix_expression] = STATE(7138),
    [sym_hash_expression] = STATE(7138),
    [sym_field_get_expression] = STATE(7138),
    [sym_array_get_expression] = STATE(7138),
    [sym_string_get_expression] = STATE(7138),
    [sym_bigarray_get_expression] = STATE(7138),
    [sym_coercion_expression] = STATE(7138),
    [sym_local_open_expression] = STATE(7138),
    [sym_package_expression] = STATE(7138),
    [sym_new_expression] = STATE(7138),
    [sym_object_copy_expression] = STATE(7138),
    [sym_method_invocation] = STATE(7138),
    [sym_object_expression] = STATE(7138),
    [sym_parenthesized_expression] = STATE(7138),
    [sym_attribute] = STATE(2526),
    [sym_extension] = STATE(7138),
    [sym_quoted_extension] = STATE(7138),
    [sym__constant] = STATE(7138),
    [sym_number] = STATE(6961),
    [sym_character] = STATE(6961),
    [sym_string] = STATE(6961),
    [sym_quoted_string] = STATE(6961),
    [sym_boolean] = STATE(6961),
    [sym_unit] = STATE(6961),
    [sym__value_name] = STATE(7135),
    [sym_parenthesized_operator] = STATE(6945),
    [sym_value_path] = STATE(7138),
    [sym_module_path] = STATE(18738),
    [sym_constructor_path] = STATE(7138),
    [sym__constructor_name] = STATE(6963),
    [sym_tag] = STATE(7138),
    [aux_sym_class_application_repeat1] = STATE(2526),
    [sym__lowercase_identifier] = ACTIONS(6713),
    [anon_sym_TILDE] = ACTIONS(6716),
    [anon_sym_QMARK] = ACTIONS(6716),
    [anon_sym_LPAREN] = ACTIONS(6719),
    [anon_sym_COMMA] = ACTIONS(3720),
    [anon_sym_PIPE] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(6722),
    [anon_sym_true] = ACTIONS(6725),
    [anon_sym_false] = ACTIONS(6725),
    [anon_sym_LBRACE] = ACTIONS(6728),
    [anon_sym_SEMI] = ACTIONS(3720),
    [anon_sym_end] = ACTIONS(3722),
    [anon_sym_object] = ACTIONS(6731),
    [anon_sym_COLON_COLON] = ACTIONS(3720),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6734),
    [anon_sym_new] = ACTIONS(6737),
    [anon_sym_LBRACE_LT] = ACTIONS(6740),
    [anon_sym_begin] = ACTIONS(6743),
    [sym_ocamlyacc_value] = ACTIONS(6746),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6749),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6752),
    [aux_sym_number_token1] = ACTIONS(6755),
    [aux_sym_signed_number_token1] = ACTIONS(3722),
    [anon_sym_SQUOTE] = ACTIONS(6758),
    [anon_sym_DQUOTE] = ACTIONS(6761),
    [sym_prefix_operator] = ACTIONS(6764),
    [aux_sym_sign_operator_token1] = ACTIONS(3722),
    [sym_pow_operator] = ACTIONS(3722),
    [sym_mult_operator] = ACTIONS(3722),
    [aux_sym_add_operator_token1] = ACTIONS(3722),
    [sym_concat_operator] = ACTIONS(3720),
    [sym_rel_operator] = ACTIONS(3722),
    [sym_and_operator] = ACTIONS(3722),
    [sym_or_operator] = ACTIONS(3722),
    [sym_assign_operator] = ACTIONS(3720),
    [sym__uppercase_identifier] = ACTIONS(6767),
    [aux_sym_tag_token1] = ACTIONS(6770),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2527] = {
    [sym__simple_expression] = STATE(7115),
    [sym_typed_expression] = STATE(6896),
    [sym_list_expression] = STATE(6896),
    [sym_array_expression] = STATE(6896),
    [sym_record_expression] = STATE(6896),
    [sym_labeled_argument] = STATE(7641),
    [sym_prefix_expression] = STATE(6896),
    [sym_hash_expression] = STATE(6896),
    [sym_field_get_expression] = STATE(6896),
    [sym_array_get_expression] = STATE(6896),
    [sym_string_get_expression] = STATE(6896),
    [sym_bigarray_get_expression] = STATE(6896),
    [sym_coercion_expression] = STATE(6896),
    [sym_local_open_expression] = STATE(6896),
    [sym_package_expression] = STATE(6896),
    [sym_new_expression] = STATE(6896),
    [sym_object_copy_expression] = STATE(6896),
    [sym_method_invocation] = STATE(6896),
    [sym_object_expression] = STATE(6896),
    [sym_parenthesized_expression] = STATE(6896),
    [sym_attribute] = STATE(2527),
    [sym_extension] = STATE(6896),
    [sym_quoted_extension] = STATE(6896),
    [sym__constant] = STATE(6896),
    [sym_number] = STATE(6891),
    [sym_character] = STATE(6891),
    [sym_string] = STATE(6891),
    [sym_quoted_string] = STATE(6891),
    [sym_boolean] = STATE(6891),
    [sym_unit] = STATE(6891),
    [sym__value_name] = STATE(6884),
    [sym_parenthesized_operator] = STATE(6841),
    [sym_value_path] = STATE(6896),
    [sym_module_path] = STATE(18104),
    [sym_constructor_path] = STATE(6896),
    [sym__constructor_name] = STATE(6890),
    [sym_tag] = STATE(6896),
    [aux_sym_class_application_repeat1] = STATE(2527),
    [ts_builtin_sym_end] = ACTIONS(3720),
    [sym__lowercase_identifier] = ACTIONS(6773),
    [anon_sym_SEMI_SEMI] = ACTIONS(3720),
    [anon_sym_and] = ACTIONS(3722),
    [anon_sym_TILDE] = ACTIONS(6776),
    [anon_sym_QMARK] = ACTIONS(6776),
    [anon_sym_LPAREN] = ACTIONS(6779),
    [anon_sym_external] = ACTIONS(3722),
    [anon_sym_type] = ACTIONS(3722),
    [anon_sym_LBRACK] = ACTIONS(6782),
    [anon_sym_true] = ACTIONS(6785),
    [anon_sym_false] = ACTIONS(6785),
    [anon_sym_LBRACE] = ACTIONS(6788),
    [anon_sym_exception] = ACTIONS(3722),
    [anon_sym_module] = ACTIONS(3722),
    [anon_sym_open] = ACTIONS(3722),
    [anon_sym_include] = ACTIONS(3722),
    [anon_sym_class] = ACTIONS(3722),
    [anon_sym_val] = ACTIONS(3722),
    [anon_sym_object] = ACTIONS(6791),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6794),
    [anon_sym_new] = ACTIONS(6797),
    [anon_sym_LBRACE_LT] = ACTIONS(6800),
    [anon_sym_begin] = ACTIONS(6803),
    [sym_ocamlyacc_value] = ACTIONS(6806),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3722),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3720),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6809),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6812),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3720),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3720),
    [aux_sym_number_token1] = ACTIONS(6815),
    [anon_sym_SQUOTE] = ACTIONS(6818),
    [anon_sym_DQUOTE] = ACTIONS(6821),
    [sym_prefix_operator] = ACTIONS(6824),
    [sym__uppercase_identifier] = ACTIONS(6827),
    [aux_sym_tag_token1] = ACTIONS(6830),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2528] = {
    [sym__simple_expression] = STATE(6859),
    [sym_typed_expression] = STATE(7113),
    [sym_list_expression] = STATE(7113),
    [sym_array_expression] = STATE(7113),
    [sym_record_expression] = STATE(7113),
    [sym_labeled_argument] = STATE(7731),
    [sym_prefix_expression] = STATE(7113),
    [sym_hash_expression] = STATE(7113),
    [sym_field_get_expression] = STATE(7113),
    [sym_array_get_expression] = STATE(7113),
    [sym_string_get_expression] = STATE(7113),
    [sym_bigarray_get_expression] = STATE(7113),
    [sym_coercion_expression] = STATE(7113),
    [sym_local_open_expression] = STATE(7113),
    [sym_package_expression] = STATE(7113),
    [sym_new_expression] = STATE(7113),
    [sym_object_copy_expression] = STATE(7113),
    [sym_method_invocation] = STATE(7113),
    [sym_object_expression] = STATE(7113),
    [sym_parenthesized_expression] = STATE(7113),
    [sym_attribute] = STATE(2528),
    [sym_extension] = STATE(7113),
    [sym_quoted_extension] = STATE(7113),
    [sym__constant] = STATE(7113),
    [sym_number] = STATE(6743),
    [sym_character] = STATE(6743),
    [sym_string] = STATE(6743),
    [sym_quoted_string] = STATE(6743),
    [sym_boolean] = STATE(6743),
    [sym_unit] = STATE(6743),
    [sym__value_name] = STATE(6846),
    [sym_parenthesized_operator] = STATE(7160),
    [sym_value_path] = STATE(7113),
    [sym_module_path] = STATE(17678),
    [sym_constructor_path] = STATE(7113),
    [sym__constructor_name] = STATE(6740),
    [sym_tag] = STATE(7113),
    [aux_sym_class_application_repeat1] = STATE(2525),
    [sym__lowercase_identifier] = ACTIONS(5551),
    [anon_sym_TILDE] = ACTIONS(5553),
    [anon_sym_QMARK] = ACTIONS(5553),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_PIPE] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_true] = ACTIONS(2647),
    [anon_sym_false] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_SEMI] = ACTIONS(3943),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_COLON_COLON] = ACTIONS(3943),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2655),
    [anon_sym_done] = ACTIONS(3945),
    [anon_sym_new] = ACTIONS(2665),
    [anon_sym_LBRACE_LT] = ACTIONS(2667),
    [anon_sym_begin] = ACTIONS(2669),
    [sym_ocamlyacc_value] = ACTIONS(2671),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2673),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2675),
    [aux_sym_number_token1] = ACTIONS(2677),
    [aux_sym_signed_number_token1] = ACTIONS(3945),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2681),
    [sym_prefix_operator] = ACTIONS(2683),
    [aux_sym_sign_operator_token1] = ACTIONS(3945),
    [sym_pow_operator] = ACTIONS(3945),
    [sym_mult_operator] = ACTIONS(3945),
    [aux_sym_add_operator_token1] = ACTIONS(3945),
    [sym_concat_operator] = ACTIONS(3943),
    [sym_rel_operator] = ACTIONS(3945),
    [sym_and_operator] = ACTIONS(3945),
    [sym_or_operator] = ACTIONS(3945),
    [sym_assign_operator] = ACTIONS(3943),
    [sym__uppercase_identifier] = ACTIONS(2687),
    [aux_sym_tag_token1] = ACTIONS(2689),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2529] = {
    [sym__binding_pattern] = STATE(13687),
    [sym_alias_binding_pattern] = STATE(13355),
    [sym_typed_binding_pattern] = STATE(13355),
    [sym_or_binding_pattern] = STATE(13355),
    [sym_constructor_binding_pattern] = STATE(13355),
    [sym_tag_binding_pattern] = STATE(13355),
    [sym_polymorphic_variant_pattern] = STATE(13355),
    [sym_tuple_binding_pattern] = STATE(13355),
    [sym_record_binding_pattern] = STATE(13357),
    [sym_list_binding_pattern] = STATE(13358),
    [sym_cons_binding_pattern] = STATE(13355),
    [sym_array_binding_pattern] = STATE(13361),
    [sym_range_pattern] = STATE(13355),
    [sym_lazy_binding_pattern] = STATE(13355),
    [sym_local_open_binding_pattern] = STATE(13355),
    [sym_package_pattern] = STATE(13355),
    [sym_parenthesized_binding_pattern] = STATE(13355),
    [sym_attribute] = STATE(2529),
    [sym_extension] = STATE(13355),
    [sym_quoted_extension] = STATE(13355),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(13219),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__infix_operator] = STATE(18810),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(13355),
    [sym_parenthesized_operator] = STATE(10358),
    [sym_module_path] = STATE(20421),
    [sym_constructor_path] = STATE(3559),
    [sym__constructor_name] = STATE(8440),
    [sym_tag] = STATE(3561),
    [sym__lowercase_identifier] = ACTIONS(6833),
    [anon_sym_LPAREN] = ACTIONS(6835),
    [anon_sym_RPAREN] = ACTIONS(6837),
    [anon_sym_LBRACK] = ACTIONS(6839),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_DOT] = ACTIONS(6841),
    [anon_sym_LBRACE] = ACTIONS(6843),
    [anon_sym_module] = ACTIONS(6845),
    [anon_sym_POUND] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(6847),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6849),
    [anon_sym_lazy] = ACTIONS(6851),
    [anon_sym_begin] = ACTIONS(4973),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(4983),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym_prefix_operator] = ACTIONS(6853),
    [aux_sym_sign_operator_token1] = ACTIONS(1469),
    [sym_hash_operator] = ACTIONS(6853),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(6853),
    [sym_let_and_operator] = ACTIONS(6853),
    [sym_match_operator] = ACTIONS(6853),
    [sym__uppercase_identifier] = ACTIONS(5515),
    [aux_sym_tag_token1] = ACTIONS(5517),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2530] = {
    [sym__binding_pattern] = STATE(13525),
    [sym_alias_binding_pattern] = STATE(13355),
    [sym_typed_binding_pattern] = STATE(13355),
    [sym_or_binding_pattern] = STATE(13355),
    [sym_constructor_binding_pattern] = STATE(13355),
    [sym_tag_binding_pattern] = STATE(13355),
    [sym_polymorphic_variant_pattern] = STATE(13355),
    [sym_tuple_binding_pattern] = STATE(13355),
    [sym_record_binding_pattern] = STATE(13357),
    [sym_list_binding_pattern] = STATE(13358),
    [sym_cons_binding_pattern] = STATE(13355),
    [sym_array_binding_pattern] = STATE(13361),
    [sym_range_pattern] = STATE(13355),
    [sym_lazy_binding_pattern] = STATE(13355),
    [sym_local_open_binding_pattern] = STATE(13355),
    [sym_package_pattern] = STATE(13355),
    [sym_parenthesized_binding_pattern] = STATE(13355),
    [sym_attribute] = STATE(2530),
    [sym_extension] = STATE(13355),
    [sym_quoted_extension] = STATE(13355),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(13219),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__infix_operator] = STATE(18115),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(13355),
    [sym_parenthesized_operator] = STATE(10358),
    [sym_module_path] = STATE(20421),
    [sym_constructor_path] = STATE(3559),
    [sym__constructor_name] = STATE(8440),
    [sym_tag] = STATE(3561),
    [sym__lowercase_identifier] = ACTIONS(6833),
    [anon_sym_LPAREN] = ACTIONS(6835),
    [anon_sym_RPAREN] = ACTIONS(6855),
    [anon_sym_LBRACK] = ACTIONS(6839),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_DOT] = ACTIONS(6857),
    [anon_sym_LBRACE] = ACTIONS(6843),
    [anon_sym_module] = ACTIONS(6859),
    [anon_sym_POUND] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(6861),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6849),
    [anon_sym_lazy] = ACTIONS(6851),
    [anon_sym_begin] = ACTIONS(4973),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(4983),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym_prefix_operator] = ACTIONS(6863),
    [aux_sym_sign_operator_token1] = ACTIONS(1469),
    [sym_hash_operator] = ACTIONS(6863),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(6863),
    [sym_let_and_operator] = ACTIONS(6863),
    [sym_match_operator] = ACTIONS(6863),
    [sym__uppercase_identifier] = ACTIONS(5515),
    [aux_sym_tag_token1] = ACTIONS(5517),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2531] = {
    [sym__binding_pattern] = STATE(13816),
    [sym_alias_binding_pattern] = STATE(13355),
    [sym_typed_binding_pattern] = STATE(13355),
    [sym_or_binding_pattern] = STATE(13355),
    [sym_constructor_binding_pattern] = STATE(13355),
    [sym_tag_binding_pattern] = STATE(13355),
    [sym_polymorphic_variant_pattern] = STATE(13355),
    [sym_tuple_binding_pattern] = STATE(13355),
    [sym_record_binding_pattern] = STATE(13357),
    [sym_list_binding_pattern] = STATE(13358),
    [sym_cons_binding_pattern] = STATE(13355),
    [sym_array_binding_pattern] = STATE(13361),
    [sym_range_pattern] = STATE(13355),
    [sym_lazy_binding_pattern] = STATE(13355),
    [sym_local_open_binding_pattern] = STATE(13355),
    [sym_package_pattern] = STATE(13355),
    [sym_parenthesized_binding_pattern] = STATE(13355),
    [sym_attribute] = STATE(2531),
    [sym_extension] = STATE(13355),
    [sym_quoted_extension] = STATE(13355),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(13219),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__infix_operator] = STATE(19722),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(13355),
    [sym_parenthesized_operator] = STATE(10358),
    [sym_module_path] = STATE(20421),
    [sym_constructor_path] = STATE(3559),
    [sym__constructor_name] = STATE(8440),
    [sym_tag] = STATE(3561),
    [sym__lowercase_identifier] = ACTIONS(6833),
    [anon_sym_LPAREN] = ACTIONS(6835),
    [anon_sym_RPAREN] = ACTIONS(6865),
    [anon_sym_LBRACK] = ACTIONS(6839),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_DOT] = ACTIONS(6867),
    [anon_sym_LBRACE] = ACTIONS(6843),
    [anon_sym_module] = ACTIONS(6869),
    [anon_sym_POUND] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(6871),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6849),
    [anon_sym_lazy] = ACTIONS(6851),
    [anon_sym_begin] = ACTIONS(4973),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(4983),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym_prefix_operator] = ACTIONS(6873),
    [aux_sym_sign_operator_token1] = ACTIONS(1469),
    [sym_hash_operator] = ACTIONS(6873),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(6873),
    [sym_let_and_operator] = ACTIONS(6873),
    [sym_match_operator] = ACTIONS(6873),
    [sym__uppercase_identifier] = ACTIONS(5515),
    [aux_sym_tag_token1] = ACTIONS(5517),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2532] = {
    [sym__binding_pattern] = STATE(13776),
    [sym_alias_binding_pattern] = STATE(13355),
    [sym_typed_binding_pattern] = STATE(13355),
    [sym_or_binding_pattern] = STATE(13355),
    [sym_constructor_binding_pattern] = STATE(13355),
    [sym_tag_binding_pattern] = STATE(13355),
    [sym_polymorphic_variant_pattern] = STATE(13355),
    [sym_tuple_binding_pattern] = STATE(13355),
    [sym_record_binding_pattern] = STATE(13357),
    [sym_list_binding_pattern] = STATE(13358),
    [sym_cons_binding_pattern] = STATE(13355),
    [sym_array_binding_pattern] = STATE(13361),
    [sym_range_pattern] = STATE(13355),
    [sym_lazy_binding_pattern] = STATE(13355),
    [sym_local_open_binding_pattern] = STATE(13355),
    [sym_package_pattern] = STATE(13355),
    [sym_parenthesized_binding_pattern] = STATE(13355),
    [sym_attribute] = STATE(2532),
    [sym_extension] = STATE(13355),
    [sym_quoted_extension] = STATE(13355),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(13219),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__infix_operator] = STATE(18285),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(13355),
    [sym_parenthesized_operator] = STATE(10358),
    [sym_module_path] = STATE(20421),
    [sym_constructor_path] = STATE(3559),
    [sym__constructor_name] = STATE(8440),
    [sym_tag] = STATE(3561),
    [sym__lowercase_identifier] = ACTIONS(6833),
    [anon_sym_LPAREN] = ACTIONS(6835),
    [anon_sym_RPAREN] = ACTIONS(6875),
    [anon_sym_LBRACK] = ACTIONS(6839),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_DOT] = ACTIONS(6877),
    [anon_sym_LBRACE] = ACTIONS(6843),
    [anon_sym_module] = ACTIONS(6879),
    [anon_sym_POUND] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(6881),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6849),
    [anon_sym_lazy] = ACTIONS(6851),
    [anon_sym_begin] = ACTIONS(4973),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(4983),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym_prefix_operator] = ACTIONS(6883),
    [aux_sym_sign_operator_token1] = ACTIONS(1469),
    [sym_hash_operator] = ACTIONS(6883),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(6883),
    [sym_let_and_operator] = ACTIONS(6883),
    [sym_match_operator] = ACTIONS(6883),
    [sym__uppercase_identifier] = ACTIONS(5515),
    [aux_sym_tag_token1] = ACTIONS(5517),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2533] = {
    [sym__binding_pattern] = STATE(13818),
    [sym_alias_binding_pattern] = STATE(13355),
    [sym_typed_binding_pattern] = STATE(13355),
    [sym_or_binding_pattern] = STATE(13355),
    [sym_constructor_binding_pattern] = STATE(13355),
    [sym_tag_binding_pattern] = STATE(13355),
    [sym_polymorphic_variant_pattern] = STATE(13355),
    [sym_tuple_binding_pattern] = STATE(13355),
    [sym_record_binding_pattern] = STATE(13357),
    [sym_list_binding_pattern] = STATE(13358),
    [sym_cons_binding_pattern] = STATE(13355),
    [sym_array_binding_pattern] = STATE(13361),
    [sym_range_pattern] = STATE(13355),
    [sym_lazy_binding_pattern] = STATE(13355),
    [sym_local_open_binding_pattern] = STATE(13355),
    [sym_package_pattern] = STATE(13355),
    [sym_parenthesized_binding_pattern] = STATE(13355),
    [sym_attribute] = STATE(2533),
    [sym_extension] = STATE(13355),
    [sym_quoted_extension] = STATE(13355),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(13219),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__infix_operator] = STATE(18720),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(13355),
    [sym_parenthesized_operator] = STATE(10358),
    [sym_module_path] = STATE(20421),
    [sym_constructor_path] = STATE(3559),
    [sym__constructor_name] = STATE(8440),
    [sym_tag] = STATE(3561),
    [sym__lowercase_identifier] = ACTIONS(6833),
    [anon_sym_LPAREN] = ACTIONS(6835),
    [anon_sym_RPAREN] = ACTIONS(5123),
    [anon_sym_LBRACK] = ACTIONS(6839),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_DOT] = ACTIONS(5125),
    [anon_sym_LBRACE] = ACTIONS(6843),
    [anon_sym_module] = ACTIONS(5127),
    [anon_sym_POUND] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(1873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6849),
    [anon_sym_lazy] = ACTIONS(6851),
    [anon_sym_begin] = ACTIONS(4973),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(4983),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym_prefix_operator] = ACTIONS(5131),
    [aux_sym_sign_operator_token1] = ACTIONS(1469),
    [sym_hash_operator] = ACTIONS(5131),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(5131),
    [sym_let_and_operator] = ACTIONS(5131),
    [sym_match_operator] = ACTIONS(5131),
    [sym__uppercase_identifier] = ACTIONS(5515),
    [aux_sym_tag_token1] = ACTIONS(5517),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2534] = {
    [sym__binding_pattern] = STATE(13731),
    [sym_alias_binding_pattern] = STATE(13355),
    [sym_typed_binding_pattern] = STATE(13355),
    [sym_or_binding_pattern] = STATE(13355),
    [sym_constructor_binding_pattern] = STATE(13355),
    [sym_tag_binding_pattern] = STATE(13355),
    [sym_polymorphic_variant_pattern] = STATE(13355),
    [sym_tuple_binding_pattern] = STATE(13355),
    [sym_record_binding_pattern] = STATE(13357),
    [sym_list_binding_pattern] = STATE(13358),
    [sym_cons_binding_pattern] = STATE(13355),
    [sym_array_binding_pattern] = STATE(13361),
    [sym_range_pattern] = STATE(13355),
    [sym_lazy_binding_pattern] = STATE(13355),
    [sym_local_open_binding_pattern] = STATE(13355),
    [sym_package_pattern] = STATE(13355),
    [sym_parenthesized_binding_pattern] = STATE(13355),
    [sym_attribute] = STATE(2534),
    [sym_extension] = STATE(13355),
    [sym_quoted_extension] = STATE(13355),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(13219),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__infix_operator] = STATE(18636),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(13355),
    [sym_parenthesized_operator] = STATE(10358),
    [sym_module_path] = STATE(20421),
    [sym_constructor_path] = STATE(3559),
    [sym__constructor_name] = STATE(8440),
    [sym_tag] = STATE(3561),
    [sym__lowercase_identifier] = ACTIONS(6833),
    [anon_sym_LPAREN] = ACTIONS(6835),
    [anon_sym_RPAREN] = ACTIONS(6885),
    [anon_sym_LBRACK] = ACTIONS(6839),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_DOT] = ACTIONS(6887),
    [anon_sym_LBRACE] = ACTIONS(6843),
    [anon_sym_module] = ACTIONS(6889),
    [anon_sym_POUND] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(6891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6849),
    [anon_sym_lazy] = ACTIONS(6851),
    [anon_sym_begin] = ACTIONS(4973),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(4983),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym_prefix_operator] = ACTIONS(6893),
    [aux_sym_sign_operator_token1] = ACTIONS(1469),
    [sym_hash_operator] = ACTIONS(6893),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(6893),
    [sym_let_and_operator] = ACTIONS(6893),
    [sym_match_operator] = ACTIONS(6893),
    [sym__uppercase_identifier] = ACTIONS(5515),
    [aux_sym_tag_token1] = ACTIONS(5517),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2535] = {
    [sym__binding_pattern] = STATE(13533),
    [sym_alias_binding_pattern] = STATE(13355),
    [sym_typed_binding_pattern] = STATE(13355),
    [sym_or_binding_pattern] = STATE(13355),
    [sym_constructor_binding_pattern] = STATE(13355),
    [sym_tag_binding_pattern] = STATE(13355),
    [sym_polymorphic_variant_pattern] = STATE(13355),
    [sym_tuple_binding_pattern] = STATE(13355),
    [sym_record_binding_pattern] = STATE(13357),
    [sym_list_binding_pattern] = STATE(13358),
    [sym_cons_binding_pattern] = STATE(13355),
    [sym_array_binding_pattern] = STATE(13361),
    [sym_range_pattern] = STATE(13355),
    [sym_lazy_binding_pattern] = STATE(13355),
    [sym_local_open_binding_pattern] = STATE(13355),
    [sym_package_pattern] = STATE(13355),
    [sym_parenthesized_binding_pattern] = STATE(13355),
    [sym_attribute] = STATE(2535),
    [sym_extension] = STATE(13355),
    [sym_quoted_extension] = STATE(13355),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(13219),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__infix_operator] = STATE(20476),
    [sym_add_operator] = STATE(20475),
    [sym__value_name] = STATE(13355),
    [sym_parenthesized_operator] = STATE(10358),
    [sym_module_path] = STATE(20421),
    [sym_constructor_path] = STATE(3559),
    [sym__constructor_name] = STATE(8440),
    [sym_tag] = STATE(3561),
    [sym__lowercase_identifier] = ACTIONS(6833),
    [anon_sym_LPAREN] = ACTIONS(6835),
    [anon_sym_RPAREN] = ACTIONS(2105),
    [anon_sym_LBRACK] = ACTIONS(6839),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_DOT] = ACTIONS(1941),
    [anon_sym_LBRACE] = ACTIONS(6843),
    [anon_sym_module] = ACTIONS(5143),
    [anon_sym_POUND] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(5139),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6849),
    [anon_sym_lazy] = ACTIONS(6851),
    [anon_sym_begin] = ACTIONS(4973),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(4983),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym_prefix_operator] = ACTIONS(1949),
    [aux_sym_sign_operator_token1] = ACTIONS(1469),
    [sym_hash_operator] = ACTIONS(1949),
    [sym_pow_operator] = ACTIONS(1467),
    [sym_mult_operator] = ACTIONS(1467),
    [aux_sym_add_operator_token1] = ACTIONS(1469),
    [sym_concat_operator] = ACTIONS(1471),
    [sym_rel_operator] = ACTIONS(1467),
    [sym_and_operator] = ACTIONS(1467),
    [sym_or_operator] = ACTIONS(1467),
    [sym_assign_operator] = ACTIONS(1471),
    [sym_let_operator] = ACTIONS(1949),
    [sym_let_and_operator] = ACTIONS(1949),
    [sym_match_operator] = ACTIONS(1949),
    [sym__uppercase_identifier] = ACTIONS(5515),
    [aux_sym_tag_token1] = ACTIONS(5517),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2536] = {
    [sym_parameter] = STATE(7522),
    [sym__class_typed] = STATE(11147),
    [sym__parenthesized_abstract_type] = STATE(7522),
    [sym__simple_pattern] = STATE(7538),
    [sym_typed_pattern] = STATE(7593),
    [sym_polymorphic_variant_pattern] = STATE(7593),
    [sym_record_pattern] = STATE(7593),
    [sym_list_pattern] = STATE(7593),
    [sym_array_pattern] = STATE(7593),
    [sym_local_open_pattern] = STATE(7593),
    [sym_package_pattern] = STATE(7593),
    [sym_parenthesized_pattern] = STATE(7593),
    [sym_attribute] = STATE(2536),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7593),
    [sym_quoted_extension] = STATE(7593),
    [sym__constant] = STATE(7549),
    [sym__signed_constant] = STATE(7593),
    [sym_number] = STATE(7628),
    [sym_signed_number] = STATE(7549),
    [sym_character] = STATE(7628),
    [sym_string] = STATE(7628),
    [sym_quoted_string] = STATE(7628),
    [sym_boolean] = STATE(7628),
    [sym_unit] = STATE(7628),
    [sym__simple_value_pattern] = STATE(7593),
    [sym_parenthesized_operator] = STATE(7593),
    [sym_module_path] = STATE(19032),
    [sym_constructor_path] = STATE(7593),
    [sym__constructor_name] = STATE(7627),
    [sym_tag] = STATE(7593),
    [aux_sym_expression_item_repeat1] = STATE(10544),
    [aux_sym_let_binding_repeat1] = STATE(2592),
    [sym__lowercase_identifier] = ACTIONS(6895),
    [anon_sym_SEMI_SEMI] = ACTIONS(6897),
    [anon_sym_let] = ACTIONS(6899),
    [anon_sym_and] = ACTIONS(6899),
    [anon_sym_EQ] = ACTIONS(6901),
    [anon_sym_TILDE] = ACTIONS(6903),
    [anon_sym_QMARK] = ACTIONS(6903),
    [anon_sym_LPAREN] = ACTIONS(6905),
    [anon_sym_external] = ACTIONS(6899),
    [anon_sym_type] = ACTIONS(6899),
    [anon_sym_LBRACK] = ACTIONS(6907),
    [anon_sym_true] = ACTIONS(6909),
    [anon_sym_false] = ACTIONS(6909),
    [anon_sym_COLON2] = ACTIONS(6911),
    [anon_sym_LBRACE] = ACTIONS(6913),
    [anon_sym_exception] = ACTIONS(6899),
    [anon_sym_module] = ACTIONS(6899),
    [anon_sym_open] = ACTIONS(6899),
    [anon_sym_include] = ACTIONS(6899),
    [anon_sym_class] = ACTIONS(6899),
    [anon_sym_end] = ACTIONS(6899),
    [anon_sym_POUND] = ACTIONS(6915),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6917),
    [anon_sym_begin] = ACTIONS(6919),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6897),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6923),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6925),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6897),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6897),
    [aux_sym_number_token1] = ACTIONS(6927),
    [aux_sym_signed_number_token1] = ACTIONS(6929),
    [anon_sym_SQUOTE] = ACTIONS(6931),
    [anon_sym_DQUOTE] = ACTIONS(6933),
    [sym_let_operator] = ACTIONS(6897),
    [sym__uppercase_identifier] = ACTIONS(6935),
    [aux_sym_directive_token1] = ACTIONS(6899),
    [aux_sym_tag_token1] = ACTIONS(6937),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2537] = {
    [sym__simple_expression] = STATE(8074),
    [sym_typed_expression] = STATE(8043),
    [sym_list_expression] = STATE(8043),
    [sym_array_expression] = STATE(8043),
    [sym_record_expression] = STATE(8043),
    [sym_labeled_argument] = STATE(8414),
    [sym_prefix_expression] = STATE(8043),
    [sym_hash_expression] = STATE(8043),
    [sym_field_get_expression] = STATE(8043),
    [sym_array_get_expression] = STATE(8043),
    [sym_string_get_expression] = STATE(8043),
    [sym_bigarray_get_expression] = STATE(8043),
    [sym_coercion_expression] = STATE(8043),
    [sym_local_open_expression] = STATE(8043),
    [sym_package_expression] = STATE(8043),
    [sym_new_expression] = STATE(8043),
    [sym_object_copy_expression] = STATE(8043),
    [sym_method_invocation] = STATE(8043),
    [sym_object_expression] = STATE(8043),
    [sym_parenthesized_expression] = STATE(8043),
    [sym_attribute] = STATE(2537),
    [sym_extension] = STATE(8043),
    [sym_quoted_extension] = STATE(8043),
    [sym__constant] = STATE(8043),
    [sym_number] = STATE(8015),
    [sym_character] = STATE(8015),
    [sym_string] = STATE(8015),
    [sym_quoted_string] = STATE(8015),
    [sym_boolean] = STATE(8015),
    [sym_unit] = STATE(8015),
    [sym__value_name] = STATE(8060),
    [sym_parenthesized_operator] = STATE(7908),
    [sym_value_path] = STATE(8043),
    [sym_module_path] = STATE(17704),
    [sym_constructor_path] = STATE(8043),
    [sym__constructor_name] = STATE(8013),
    [sym_tag] = STATE(8043),
    [aux_sym_class_application_repeat1] = STATE(2547),
    [sym__lowercase_identifier] = ACTIONS(6939),
    [anon_sym_TILDE] = ACTIONS(6941),
    [anon_sym_QMARK] = ACTIONS(6941),
    [anon_sym_LPAREN] = ACTIONS(6943),
    [anon_sym_LBRACK] = ACTIONS(6945),
    [anon_sym_true] = ACTIONS(6947),
    [anon_sym_false] = ACTIONS(6947),
    [anon_sym_LBRACE] = ACTIONS(6949),
    [anon_sym_constraint] = ACTIONS(5585),
    [anon_sym_val] = ACTIONS(5585),
    [anon_sym_end] = ACTIONS(5585),
    [anon_sym_object] = ACTIONS(6951),
    [anon_sym_inherit] = ACTIONS(5585),
    [anon_sym_method] = ACTIONS(5585),
    [anon_sym_as] = ACTIONS(5585),
    [anon_sym_initializer] = ACTIONS(5585),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6953),
    [anon_sym_new] = ACTIONS(6955),
    [anon_sym_LBRACE_LT] = ACTIONS(6957),
    [anon_sym_begin] = ACTIONS(6959),
    [sym_ocamlyacc_value] = ACTIONS(6961),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5585),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5583),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6963),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6965),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5583),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5583),
    [aux_sym_number_token1] = ACTIONS(6967),
    [anon_sym_SQUOTE] = ACTIONS(6969),
    [anon_sym_DQUOTE] = ACTIONS(6971),
    [sym_prefix_operator] = ACTIONS(6973),
    [sym__uppercase_identifier] = ACTIONS(6975),
    [aux_sym_tag_token1] = ACTIONS(6977),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2538] = {
    [sym_parameter] = STATE(7583),
    [sym__class_typed] = STATE(11069),
    [sym__parenthesized_abstract_type] = STATE(7583),
    [sym__simple_pattern] = STATE(7579),
    [sym_typed_pattern] = STATE(7652),
    [sym_polymorphic_variant_pattern] = STATE(7652),
    [sym_record_pattern] = STATE(7652),
    [sym_list_pattern] = STATE(7652),
    [sym_array_pattern] = STATE(7652),
    [sym_local_open_pattern] = STATE(7652),
    [sym_package_pattern] = STATE(7652),
    [sym_parenthesized_pattern] = STATE(7652),
    [sym_attribute] = STATE(2538),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7652),
    [sym_quoted_extension] = STATE(7652),
    [sym__constant] = STATE(7650),
    [sym__signed_constant] = STATE(7652),
    [sym_number] = STATE(7629),
    [sym_signed_number] = STATE(7650),
    [sym_character] = STATE(7629),
    [sym_string] = STATE(7629),
    [sym_quoted_string] = STATE(7629),
    [sym_boolean] = STATE(7629),
    [sym_unit] = STATE(7629),
    [sym__simple_value_pattern] = STATE(7652),
    [sym_parenthesized_operator] = STATE(7652),
    [sym_module_path] = STATE(19315),
    [sym_constructor_path] = STATE(7652),
    [sym__constructor_name] = STATE(7651),
    [sym_tag] = STATE(7652),
    [aux_sym_expression_item_repeat1] = STATE(10639),
    [aux_sym_let_binding_repeat1] = STATE(2557),
    [sym__lowercase_identifier] = ACTIONS(6979),
    [anon_sym_SEMI_SEMI] = ACTIONS(6981),
    [anon_sym_let] = ACTIONS(6983),
    [anon_sym_and] = ACTIONS(6983),
    [anon_sym_EQ] = ACTIONS(6985),
    [anon_sym_TILDE] = ACTIONS(6987),
    [anon_sym_QMARK] = ACTIONS(6987),
    [anon_sym_LPAREN] = ACTIONS(6989),
    [anon_sym_external] = ACTIONS(6983),
    [anon_sym_type] = ACTIONS(6983),
    [anon_sym_LBRACK] = ACTIONS(6991),
    [anon_sym_RBRACK] = ACTIONS(6981),
    [anon_sym_true] = ACTIONS(6993),
    [anon_sym_false] = ACTIONS(6993),
    [anon_sym_COLON2] = ACTIONS(6995),
    [anon_sym_LBRACE] = ACTIONS(6997),
    [anon_sym_exception] = ACTIONS(6983),
    [anon_sym_module] = ACTIONS(6983),
    [anon_sym_open] = ACTIONS(6983),
    [anon_sym_include] = ACTIONS(6983),
    [anon_sym_class] = ACTIONS(6983),
    [anon_sym_POUND] = ACTIONS(6999),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7001),
    [anon_sym_begin] = ACTIONS(7003),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6981),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7005),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7007),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6981),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6981),
    [aux_sym_number_token1] = ACTIONS(7009),
    [aux_sym_signed_number_token1] = ACTIONS(7011),
    [anon_sym_SQUOTE] = ACTIONS(7013),
    [anon_sym_DQUOTE] = ACTIONS(7015),
    [sym_let_operator] = ACTIONS(6981),
    [sym__uppercase_identifier] = ACTIONS(7017),
    [aux_sym_directive_token1] = ACTIONS(6983),
    [aux_sym_tag_token1] = ACTIONS(7019),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2539] = {
    [sym_parameter] = STATE(7583),
    [sym__class_typed] = STATE(11002),
    [sym__parenthesized_abstract_type] = STATE(7583),
    [sym__simple_pattern] = STATE(7579),
    [sym_typed_pattern] = STATE(7652),
    [sym_polymorphic_variant_pattern] = STATE(7652),
    [sym_record_pattern] = STATE(7652),
    [sym_list_pattern] = STATE(7652),
    [sym_array_pattern] = STATE(7652),
    [sym_local_open_pattern] = STATE(7652),
    [sym_package_pattern] = STATE(7652),
    [sym_parenthesized_pattern] = STATE(7652),
    [sym_attribute] = STATE(2539),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7652),
    [sym_quoted_extension] = STATE(7652),
    [sym__constant] = STATE(7650),
    [sym__signed_constant] = STATE(7652),
    [sym_number] = STATE(7629),
    [sym_signed_number] = STATE(7650),
    [sym_character] = STATE(7629),
    [sym_string] = STATE(7629),
    [sym_quoted_string] = STATE(7629),
    [sym_boolean] = STATE(7629),
    [sym_unit] = STATE(7629),
    [sym__simple_value_pattern] = STATE(7652),
    [sym_parenthesized_operator] = STATE(7652),
    [sym_module_path] = STATE(19315),
    [sym_constructor_path] = STATE(7652),
    [sym__constructor_name] = STATE(7651),
    [sym_tag] = STATE(7652),
    [aux_sym_expression_item_repeat1] = STATE(10538),
    [aux_sym_let_binding_repeat1] = STATE(2546),
    [sym__lowercase_identifier] = ACTIONS(6979),
    [anon_sym_SEMI_SEMI] = ACTIONS(7021),
    [anon_sym_let] = ACTIONS(7023),
    [anon_sym_and] = ACTIONS(7023),
    [anon_sym_EQ] = ACTIONS(7025),
    [anon_sym_TILDE] = ACTIONS(6987),
    [anon_sym_QMARK] = ACTIONS(6987),
    [anon_sym_LPAREN] = ACTIONS(6989),
    [anon_sym_external] = ACTIONS(7023),
    [anon_sym_type] = ACTIONS(7023),
    [anon_sym_LBRACK] = ACTIONS(6991),
    [anon_sym_RBRACK] = ACTIONS(7021),
    [anon_sym_true] = ACTIONS(6993),
    [anon_sym_false] = ACTIONS(6993),
    [anon_sym_COLON2] = ACTIONS(6995),
    [anon_sym_LBRACE] = ACTIONS(6997),
    [anon_sym_exception] = ACTIONS(7023),
    [anon_sym_module] = ACTIONS(7023),
    [anon_sym_open] = ACTIONS(7023),
    [anon_sym_include] = ACTIONS(7023),
    [anon_sym_class] = ACTIONS(7023),
    [anon_sym_POUND] = ACTIONS(6999),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7001),
    [anon_sym_begin] = ACTIONS(7003),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7021),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7005),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7007),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7021),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7021),
    [aux_sym_number_token1] = ACTIONS(7009),
    [aux_sym_signed_number_token1] = ACTIONS(7011),
    [anon_sym_SQUOTE] = ACTIONS(7013),
    [anon_sym_DQUOTE] = ACTIONS(7015),
    [sym_let_operator] = ACTIONS(7021),
    [sym__uppercase_identifier] = ACTIONS(7017),
    [aux_sym_directive_token1] = ACTIONS(7023),
    [aux_sym_tag_token1] = ACTIONS(7019),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2540] = {
    [sym__simple_expression] = STATE(8074),
    [sym_typed_expression] = STATE(8043),
    [sym_list_expression] = STATE(8043),
    [sym_array_expression] = STATE(8043),
    [sym_record_expression] = STATE(8043),
    [sym_labeled_argument] = STATE(8414),
    [sym_prefix_expression] = STATE(8043),
    [sym_hash_expression] = STATE(8043),
    [sym_field_get_expression] = STATE(8043),
    [sym_array_get_expression] = STATE(8043),
    [sym_string_get_expression] = STATE(8043),
    [sym_bigarray_get_expression] = STATE(8043),
    [sym_coercion_expression] = STATE(8043),
    [sym_local_open_expression] = STATE(8043),
    [sym_package_expression] = STATE(8043),
    [sym_new_expression] = STATE(8043),
    [sym_object_copy_expression] = STATE(8043),
    [sym_method_invocation] = STATE(8043),
    [sym_object_expression] = STATE(8043),
    [sym_parenthesized_expression] = STATE(8043),
    [sym_attribute] = STATE(2540),
    [sym_extension] = STATE(8043),
    [sym_quoted_extension] = STATE(8043),
    [sym__constant] = STATE(8043),
    [sym_number] = STATE(8015),
    [sym_character] = STATE(8015),
    [sym_string] = STATE(8015),
    [sym_quoted_string] = STATE(8015),
    [sym_boolean] = STATE(8015),
    [sym_unit] = STATE(8015),
    [sym__value_name] = STATE(8060),
    [sym_parenthesized_operator] = STATE(7908),
    [sym_value_path] = STATE(8043),
    [sym_module_path] = STATE(17704),
    [sym_constructor_path] = STATE(8043),
    [sym__constructor_name] = STATE(8013),
    [sym_tag] = STATE(8043),
    [aux_sym_class_application_repeat1] = STATE(2540),
    [sym__lowercase_identifier] = ACTIONS(7027),
    [anon_sym_TILDE] = ACTIONS(7030),
    [anon_sym_QMARK] = ACTIONS(7030),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_LBRACK] = ACTIONS(7036),
    [anon_sym_true] = ACTIONS(7039),
    [anon_sym_false] = ACTIONS(7039),
    [anon_sym_LBRACE] = ACTIONS(7042),
    [anon_sym_constraint] = ACTIONS(3722),
    [anon_sym_val] = ACTIONS(3722),
    [anon_sym_end] = ACTIONS(3722),
    [anon_sym_object] = ACTIONS(7045),
    [anon_sym_inherit] = ACTIONS(3722),
    [anon_sym_method] = ACTIONS(3722),
    [anon_sym_as] = ACTIONS(3722),
    [anon_sym_initializer] = ACTIONS(3722),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7048),
    [anon_sym_new] = ACTIONS(7051),
    [anon_sym_LBRACE_LT] = ACTIONS(7054),
    [anon_sym_begin] = ACTIONS(7057),
    [sym_ocamlyacc_value] = ACTIONS(7060),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3722),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3720),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7063),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7066),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3720),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3720),
    [aux_sym_number_token1] = ACTIONS(7069),
    [anon_sym_SQUOTE] = ACTIONS(7072),
    [anon_sym_DQUOTE] = ACTIONS(7075),
    [sym_prefix_operator] = ACTIONS(7078),
    [sym__uppercase_identifier] = ACTIONS(7081),
    [aux_sym_tag_token1] = ACTIONS(7084),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2541] = {
    [sym_parameter] = STATE(7522),
    [sym__class_typed] = STATE(11139),
    [sym__parenthesized_abstract_type] = STATE(7522),
    [sym__simple_pattern] = STATE(7538),
    [sym_typed_pattern] = STATE(7593),
    [sym_polymorphic_variant_pattern] = STATE(7593),
    [sym_record_pattern] = STATE(7593),
    [sym_list_pattern] = STATE(7593),
    [sym_array_pattern] = STATE(7593),
    [sym_local_open_pattern] = STATE(7593),
    [sym_package_pattern] = STATE(7593),
    [sym_parenthesized_pattern] = STATE(7593),
    [sym_attribute] = STATE(2541),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7593),
    [sym_quoted_extension] = STATE(7593),
    [sym__constant] = STATE(7549),
    [sym__signed_constant] = STATE(7593),
    [sym_number] = STATE(7628),
    [sym_signed_number] = STATE(7549),
    [sym_character] = STATE(7628),
    [sym_string] = STATE(7628),
    [sym_quoted_string] = STATE(7628),
    [sym_boolean] = STATE(7628),
    [sym_unit] = STATE(7628),
    [sym__simple_value_pattern] = STATE(7593),
    [sym_parenthesized_operator] = STATE(7593),
    [sym_module_path] = STATE(19032),
    [sym_constructor_path] = STATE(7593),
    [sym__constructor_name] = STATE(7627),
    [sym_tag] = STATE(7593),
    [aux_sym_expression_item_repeat1] = STATE(10536),
    [aux_sym_let_binding_repeat1] = STATE(2544),
    [sym__lowercase_identifier] = ACTIONS(6895),
    [anon_sym_SEMI_SEMI] = ACTIONS(7087),
    [anon_sym_let] = ACTIONS(7089),
    [anon_sym_and] = ACTIONS(7089),
    [anon_sym_EQ] = ACTIONS(7091),
    [anon_sym_TILDE] = ACTIONS(6903),
    [anon_sym_QMARK] = ACTIONS(6903),
    [anon_sym_LPAREN] = ACTIONS(6905),
    [anon_sym_external] = ACTIONS(7089),
    [anon_sym_type] = ACTIONS(7089),
    [anon_sym_LBRACK] = ACTIONS(6907),
    [anon_sym_true] = ACTIONS(6909),
    [anon_sym_false] = ACTIONS(6909),
    [anon_sym_COLON2] = ACTIONS(6911),
    [anon_sym_LBRACE] = ACTIONS(6913),
    [anon_sym_exception] = ACTIONS(7089),
    [anon_sym_module] = ACTIONS(7089),
    [anon_sym_open] = ACTIONS(7089),
    [anon_sym_include] = ACTIONS(7089),
    [anon_sym_class] = ACTIONS(7089),
    [anon_sym_end] = ACTIONS(7089),
    [anon_sym_POUND] = ACTIONS(6915),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6917),
    [anon_sym_begin] = ACTIONS(6919),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7087),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6923),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6925),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7087),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7087),
    [aux_sym_number_token1] = ACTIONS(6927),
    [aux_sym_signed_number_token1] = ACTIONS(6929),
    [anon_sym_SQUOTE] = ACTIONS(6931),
    [anon_sym_DQUOTE] = ACTIONS(6933),
    [sym_let_operator] = ACTIONS(7087),
    [sym__uppercase_identifier] = ACTIONS(6935),
    [aux_sym_directive_token1] = ACTIONS(7089),
    [aux_sym_tag_token1] = ACTIONS(6937),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2542] = {
    [sym_parameter] = STATE(7583),
    [sym__class_typed] = STATE(11112),
    [sym__parenthesized_abstract_type] = STATE(7583),
    [sym__simple_pattern] = STATE(7579),
    [sym_typed_pattern] = STATE(7652),
    [sym_polymorphic_variant_pattern] = STATE(7652),
    [sym_record_pattern] = STATE(7652),
    [sym_list_pattern] = STATE(7652),
    [sym_array_pattern] = STATE(7652),
    [sym_local_open_pattern] = STATE(7652),
    [sym_package_pattern] = STATE(7652),
    [sym_parenthesized_pattern] = STATE(7652),
    [sym_attribute] = STATE(2542),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7652),
    [sym_quoted_extension] = STATE(7652),
    [sym__constant] = STATE(7650),
    [sym__signed_constant] = STATE(7652),
    [sym_number] = STATE(7629),
    [sym_signed_number] = STATE(7650),
    [sym_character] = STATE(7629),
    [sym_string] = STATE(7629),
    [sym_quoted_string] = STATE(7629),
    [sym_boolean] = STATE(7629),
    [sym_unit] = STATE(7629),
    [sym__simple_value_pattern] = STATE(7652),
    [sym_parenthesized_operator] = STATE(7652),
    [sym_module_path] = STATE(19315),
    [sym_constructor_path] = STATE(7652),
    [sym__constructor_name] = STATE(7651),
    [sym_tag] = STATE(7652),
    [aux_sym_expression_item_repeat1] = STATE(10433),
    [aux_sym_let_binding_repeat1] = STATE(2554),
    [sym__lowercase_identifier] = ACTIONS(6979),
    [anon_sym_SEMI_SEMI] = ACTIONS(7093),
    [anon_sym_let] = ACTIONS(7095),
    [anon_sym_and] = ACTIONS(7095),
    [anon_sym_EQ] = ACTIONS(7097),
    [anon_sym_TILDE] = ACTIONS(6987),
    [anon_sym_QMARK] = ACTIONS(6987),
    [anon_sym_LPAREN] = ACTIONS(6989),
    [anon_sym_external] = ACTIONS(7095),
    [anon_sym_type] = ACTIONS(7095),
    [anon_sym_LBRACK] = ACTIONS(6991),
    [anon_sym_RBRACK] = ACTIONS(7093),
    [anon_sym_true] = ACTIONS(6993),
    [anon_sym_false] = ACTIONS(6993),
    [anon_sym_COLON2] = ACTIONS(6995),
    [anon_sym_LBRACE] = ACTIONS(6997),
    [anon_sym_exception] = ACTIONS(7095),
    [anon_sym_module] = ACTIONS(7095),
    [anon_sym_open] = ACTIONS(7095),
    [anon_sym_include] = ACTIONS(7095),
    [anon_sym_class] = ACTIONS(7095),
    [anon_sym_POUND] = ACTIONS(6999),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7001),
    [anon_sym_begin] = ACTIONS(7003),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7093),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7005),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7007),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7093),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7093),
    [aux_sym_number_token1] = ACTIONS(7009),
    [aux_sym_signed_number_token1] = ACTIONS(7011),
    [anon_sym_SQUOTE] = ACTIONS(7013),
    [anon_sym_DQUOTE] = ACTIONS(7015),
    [sym_let_operator] = ACTIONS(7093),
    [sym__uppercase_identifier] = ACTIONS(7017),
    [aux_sym_directive_token1] = ACTIONS(7095),
    [aux_sym_tag_token1] = ACTIONS(7019),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2543] = {
    [sym_parameter] = STATE(7583),
    [sym__class_typed] = STATE(11109),
    [sym__parenthesized_abstract_type] = STATE(7583),
    [sym__simple_pattern] = STATE(7579),
    [sym_typed_pattern] = STATE(7652),
    [sym_polymorphic_variant_pattern] = STATE(7652),
    [sym_record_pattern] = STATE(7652),
    [sym_list_pattern] = STATE(7652),
    [sym_array_pattern] = STATE(7652),
    [sym_local_open_pattern] = STATE(7652),
    [sym_package_pattern] = STATE(7652),
    [sym_parenthesized_pattern] = STATE(7652),
    [sym_attribute] = STATE(2543),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7652),
    [sym_quoted_extension] = STATE(7652),
    [sym__constant] = STATE(7650),
    [sym__signed_constant] = STATE(7652),
    [sym_number] = STATE(7629),
    [sym_signed_number] = STATE(7650),
    [sym_character] = STATE(7629),
    [sym_string] = STATE(7629),
    [sym_quoted_string] = STATE(7629),
    [sym_boolean] = STATE(7629),
    [sym_unit] = STATE(7629),
    [sym__simple_value_pattern] = STATE(7652),
    [sym_parenthesized_operator] = STATE(7652),
    [sym_module_path] = STATE(19315),
    [sym_constructor_path] = STATE(7652),
    [sym__constructor_name] = STATE(7651),
    [sym_tag] = STATE(7652),
    [aux_sym_expression_item_repeat1] = STATE(10434),
    [aux_sym_let_binding_repeat1] = STATE(2591),
    [sym__lowercase_identifier] = ACTIONS(6979),
    [anon_sym_SEMI_SEMI] = ACTIONS(7099),
    [anon_sym_let] = ACTIONS(7101),
    [anon_sym_and] = ACTIONS(7101),
    [anon_sym_EQ] = ACTIONS(7103),
    [anon_sym_TILDE] = ACTIONS(6987),
    [anon_sym_QMARK] = ACTIONS(6987),
    [anon_sym_LPAREN] = ACTIONS(6989),
    [anon_sym_external] = ACTIONS(7101),
    [anon_sym_type] = ACTIONS(7101),
    [anon_sym_LBRACK] = ACTIONS(6991),
    [anon_sym_RBRACK] = ACTIONS(7099),
    [anon_sym_true] = ACTIONS(6993),
    [anon_sym_false] = ACTIONS(6993),
    [anon_sym_COLON2] = ACTIONS(6995),
    [anon_sym_LBRACE] = ACTIONS(6997),
    [anon_sym_exception] = ACTIONS(7101),
    [anon_sym_module] = ACTIONS(7101),
    [anon_sym_open] = ACTIONS(7101),
    [anon_sym_include] = ACTIONS(7101),
    [anon_sym_class] = ACTIONS(7101),
    [anon_sym_POUND] = ACTIONS(6999),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7001),
    [anon_sym_begin] = ACTIONS(7003),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7099),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7005),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7007),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7099),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7099),
    [aux_sym_number_token1] = ACTIONS(7009),
    [aux_sym_signed_number_token1] = ACTIONS(7011),
    [anon_sym_SQUOTE] = ACTIONS(7013),
    [anon_sym_DQUOTE] = ACTIONS(7015),
    [sym_let_operator] = ACTIONS(7099),
    [sym__uppercase_identifier] = ACTIONS(7017),
    [aux_sym_directive_token1] = ACTIONS(7101),
    [aux_sym_tag_token1] = ACTIONS(7019),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2544] = {
    [sym_parameter] = STATE(7522),
    [sym__class_typed] = STATE(11138),
    [sym__parenthesized_abstract_type] = STATE(7522),
    [sym__simple_pattern] = STATE(7538),
    [sym_typed_pattern] = STATE(7593),
    [sym_polymorphic_variant_pattern] = STATE(7593),
    [sym_record_pattern] = STATE(7593),
    [sym_list_pattern] = STATE(7593),
    [sym_array_pattern] = STATE(7593),
    [sym_local_open_pattern] = STATE(7593),
    [sym_package_pattern] = STATE(7593),
    [sym_parenthesized_pattern] = STATE(7593),
    [sym_attribute] = STATE(2544),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7593),
    [sym_quoted_extension] = STATE(7593),
    [sym__constant] = STATE(7549),
    [sym__signed_constant] = STATE(7593),
    [sym_number] = STATE(7628),
    [sym_signed_number] = STATE(7549),
    [sym_character] = STATE(7628),
    [sym_string] = STATE(7628),
    [sym_quoted_string] = STATE(7628),
    [sym_boolean] = STATE(7628),
    [sym_unit] = STATE(7628),
    [sym__simple_value_pattern] = STATE(7593),
    [sym_parenthesized_operator] = STATE(7593),
    [sym_module_path] = STATE(19032),
    [sym_constructor_path] = STATE(7593),
    [sym__constructor_name] = STATE(7627),
    [sym_tag] = STATE(7593),
    [aux_sym_expression_item_repeat1] = STATE(10434),
    [aux_sym_let_binding_repeat1] = STATE(2592),
    [sym__lowercase_identifier] = ACTIONS(6895),
    [anon_sym_SEMI_SEMI] = ACTIONS(7099),
    [anon_sym_let] = ACTIONS(7101),
    [anon_sym_and] = ACTIONS(7101),
    [anon_sym_EQ] = ACTIONS(7105),
    [anon_sym_TILDE] = ACTIONS(6903),
    [anon_sym_QMARK] = ACTIONS(6903),
    [anon_sym_LPAREN] = ACTIONS(6905),
    [anon_sym_external] = ACTIONS(7101),
    [anon_sym_type] = ACTIONS(7101),
    [anon_sym_LBRACK] = ACTIONS(6907),
    [anon_sym_true] = ACTIONS(6909),
    [anon_sym_false] = ACTIONS(6909),
    [anon_sym_COLON2] = ACTIONS(6911),
    [anon_sym_LBRACE] = ACTIONS(6913),
    [anon_sym_exception] = ACTIONS(7101),
    [anon_sym_module] = ACTIONS(7101),
    [anon_sym_open] = ACTIONS(7101),
    [anon_sym_include] = ACTIONS(7101),
    [anon_sym_class] = ACTIONS(7101),
    [anon_sym_end] = ACTIONS(7101),
    [anon_sym_POUND] = ACTIONS(6915),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6917),
    [anon_sym_begin] = ACTIONS(6919),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7099),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6923),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6925),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7099),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7099),
    [aux_sym_number_token1] = ACTIONS(6927),
    [aux_sym_signed_number_token1] = ACTIONS(6929),
    [anon_sym_SQUOTE] = ACTIONS(6931),
    [anon_sym_DQUOTE] = ACTIONS(6933),
    [sym_let_operator] = ACTIONS(7099),
    [sym__uppercase_identifier] = ACTIONS(6935),
    [aux_sym_directive_token1] = ACTIONS(7101),
    [aux_sym_tag_token1] = ACTIONS(6937),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2545] = {
    [sym_parameter] = STATE(7522),
    [sym__class_typed] = STATE(11151),
    [sym__parenthesized_abstract_type] = STATE(7522),
    [sym__simple_pattern] = STATE(7538),
    [sym_typed_pattern] = STATE(7593),
    [sym_polymorphic_variant_pattern] = STATE(7593),
    [sym_record_pattern] = STATE(7593),
    [sym_list_pattern] = STATE(7593),
    [sym_array_pattern] = STATE(7593),
    [sym_local_open_pattern] = STATE(7593),
    [sym_package_pattern] = STATE(7593),
    [sym_parenthesized_pattern] = STATE(7593),
    [sym_attribute] = STATE(2545),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7593),
    [sym_quoted_extension] = STATE(7593),
    [sym__constant] = STATE(7549),
    [sym__signed_constant] = STATE(7593),
    [sym_number] = STATE(7628),
    [sym_signed_number] = STATE(7549),
    [sym_character] = STATE(7628),
    [sym_string] = STATE(7628),
    [sym_quoted_string] = STATE(7628),
    [sym_boolean] = STATE(7628),
    [sym_unit] = STATE(7628),
    [sym__simple_value_pattern] = STATE(7593),
    [sym_parenthesized_operator] = STATE(7593),
    [sym_module_path] = STATE(19032),
    [sym_constructor_path] = STATE(7593),
    [sym__constructor_name] = STATE(7627),
    [sym_tag] = STATE(7593),
    [aux_sym_expression_item_repeat1] = STATE(10538),
    [aux_sym_let_binding_repeat1] = STATE(2551),
    [sym__lowercase_identifier] = ACTIONS(6895),
    [anon_sym_SEMI_SEMI] = ACTIONS(7021),
    [anon_sym_let] = ACTIONS(7023),
    [anon_sym_and] = ACTIONS(7023),
    [anon_sym_EQ] = ACTIONS(7107),
    [anon_sym_TILDE] = ACTIONS(6903),
    [anon_sym_QMARK] = ACTIONS(6903),
    [anon_sym_LPAREN] = ACTIONS(6905),
    [anon_sym_external] = ACTIONS(7023),
    [anon_sym_type] = ACTIONS(7023),
    [anon_sym_LBRACK] = ACTIONS(6907),
    [anon_sym_true] = ACTIONS(6909),
    [anon_sym_false] = ACTIONS(6909),
    [anon_sym_COLON2] = ACTIONS(6911),
    [anon_sym_LBRACE] = ACTIONS(6913),
    [anon_sym_exception] = ACTIONS(7023),
    [anon_sym_module] = ACTIONS(7023),
    [anon_sym_open] = ACTIONS(7023),
    [anon_sym_include] = ACTIONS(7023),
    [anon_sym_class] = ACTIONS(7023),
    [anon_sym_end] = ACTIONS(7023),
    [anon_sym_POUND] = ACTIONS(6915),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6917),
    [anon_sym_begin] = ACTIONS(6919),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7021),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6923),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6925),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7021),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7021),
    [aux_sym_number_token1] = ACTIONS(6927),
    [aux_sym_signed_number_token1] = ACTIONS(6929),
    [anon_sym_SQUOTE] = ACTIONS(6931),
    [anon_sym_DQUOTE] = ACTIONS(6933),
    [sym_let_operator] = ACTIONS(7021),
    [sym__uppercase_identifier] = ACTIONS(6935),
    [aux_sym_directive_token1] = ACTIONS(7023),
    [aux_sym_tag_token1] = ACTIONS(6937),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2546] = {
    [sym_parameter] = STATE(7583),
    [sym__class_typed] = STATE(11055),
    [sym__parenthesized_abstract_type] = STATE(7583),
    [sym__simple_pattern] = STATE(7579),
    [sym_typed_pattern] = STATE(7652),
    [sym_polymorphic_variant_pattern] = STATE(7652),
    [sym_record_pattern] = STATE(7652),
    [sym_list_pattern] = STATE(7652),
    [sym_array_pattern] = STATE(7652),
    [sym_local_open_pattern] = STATE(7652),
    [sym_package_pattern] = STATE(7652),
    [sym_parenthesized_pattern] = STATE(7652),
    [sym_attribute] = STATE(2546),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7652),
    [sym_quoted_extension] = STATE(7652),
    [sym__constant] = STATE(7650),
    [sym__signed_constant] = STATE(7652),
    [sym_number] = STATE(7629),
    [sym_signed_number] = STATE(7650),
    [sym_character] = STATE(7629),
    [sym_string] = STATE(7629),
    [sym_quoted_string] = STATE(7629),
    [sym_boolean] = STATE(7629),
    [sym_unit] = STATE(7629),
    [sym__simple_value_pattern] = STATE(7652),
    [sym_parenthesized_operator] = STATE(7652),
    [sym_module_path] = STATE(19315),
    [sym_constructor_path] = STATE(7652),
    [sym__constructor_name] = STATE(7651),
    [sym_tag] = STATE(7652),
    [aux_sym_expression_item_repeat1] = STATE(10495),
    [aux_sym_let_binding_repeat1] = STATE(2591),
    [sym__lowercase_identifier] = ACTIONS(6979),
    [anon_sym_SEMI_SEMI] = ACTIONS(7109),
    [anon_sym_let] = ACTIONS(7111),
    [anon_sym_and] = ACTIONS(7111),
    [anon_sym_EQ] = ACTIONS(7113),
    [anon_sym_TILDE] = ACTIONS(6987),
    [anon_sym_QMARK] = ACTIONS(6987),
    [anon_sym_LPAREN] = ACTIONS(6989),
    [anon_sym_external] = ACTIONS(7111),
    [anon_sym_type] = ACTIONS(7111),
    [anon_sym_LBRACK] = ACTIONS(6991),
    [anon_sym_RBRACK] = ACTIONS(7109),
    [anon_sym_true] = ACTIONS(6993),
    [anon_sym_false] = ACTIONS(6993),
    [anon_sym_COLON2] = ACTIONS(6995),
    [anon_sym_LBRACE] = ACTIONS(6997),
    [anon_sym_exception] = ACTIONS(7111),
    [anon_sym_module] = ACTIONS(7111),
    [anon_sym_open] = ACTIONS(7111),
    [anon_sym_include] = ACTIONS(7111),
    [anon_sym_class] = ACTIONS(7111),
    [anon_sym_POUND] = ACTIONS(6999),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7001),
    [anon_sym_begin] = ACTIONS(7003),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7109),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7005),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7007),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7109),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7109),
    [aux_sym_number_token1] = ACTIONS(7009),
    [aux_sym_signed_number_token1] = ACTIONS(7011),
    [anon_sym_SQUOTE] = ACTIONS(7013),
    [anon_sym_DQUOTE] = ACTIONS(7015),
    [sym_let_operator] = ACTIONS(7109),
    [sym__uppercase_identifier] = ACTIONS(7017),
    [aux_sym_directive_token1] = ACTIONS(7111),
    [aux_sym_tag_token1] = ACTIONS(7019),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2547] = {
    [sym__simple_expression] = STATE(8074),
    [sym_typed_expression] = STATE(8043),
    [sym_list_expression] = STATE(8043),
    [sym_array_expression] = STATE(8043),
    [sym_record_expression] = STATE(8043),
    [sym_labeled_argument] = STATE(8414),
    [sym_prefix_expression] = STATE(8043),
    [sym_hash_expression] = STATE(8043),
    [sym_field_get_expression] = STATE(8043),
    [sym_array_get_expression] = STATE(8043),
    [sym_string_get_expression] = STATE(8043),
    [sym_bigarray_get_expression] = STATE(8043),
    [sym_coercion_expression] = STATE(8043),
    [sym_local_open_expression] = STATE(8043),
    [sym_package_expression] = STATE(8043),
    [sym_new_expression] = STATE(8043),
    [sym_object_copy_expression] = STATE(8043),
    [sym_method_invocation] = STATE(8043),
    [sym_object_expression] = STATE(8043),
    [sym_parenthesized_expression] = STATE(8043),
    [sym_attribute] = STATE(2547),
    [sym_extension] = STATE(8043),
    [sym_quoted_extension] = STATE(8043),
    [sym__constant] = STATE(8043),
    [sym_number] = STATE(8015),
    [sym_character] = STATE(8015),
    [sym_string] = STATE(8015),
    [sym_quoted_string] = STATE(8015),
    [sym_boolean] = STATE(8015),
    [sym_unit] = STATE(8015),
    [sym__value_name] = STATE(8060),
    [sym_parenthesized_operator] = STATE(7908),
    [sym_value_path] = STATE(8043),
    [sym_module_path] = STATE(17704),
    [sym_constructor_path] = STATE(8043),
    [sym__constructor_name] = STATE(8013),
    [sym_tag] = STATE(8043),
    [aux_sym_class_application_repeat1] = STATE(2540),
    [sym__lowercase_identifier] = ACTIONS(6939),
    [anon_sym_TILDE] = ACTIONS(6941),
    [anon_sym_QMARK] = ACTIONS(6941),
    [anon_sym_LPAREN] = ACTIONS(6943),
    [anon_sym_LBRACK] = ACTIONS(6945),
    [anon_sym_true] = ACTIONS(6947),
    [anon_sym_false] = ACTIONS(6947),
    [anon_sym_LBRACE] = ACTIONS(6949),
    [anon_sym_constraint] = ACTIONS(5689),
    [anon_sym_val] = ACTIONS(5689),
    [anon_sym_end] = ACTIONS(5689),
    [anon_sym_object] = ACTIONS(6951),
    [anon_sym_inherit] = ACTIONS(5689),
    [anon_sym_method] = ACTIONS(5689),
    [anon_sym_as] = ACTIONS(5689),
    [anon_sym_initializer] = ACTIONS(5689),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6953),
    [anon_sym_new] = ACTIONS(6955),
    [anon_sym_LBRACE_LT] = ACTIONS(6957),
    [anon_sym_begin] = ACTIONS(6959),
    [sym_ocamlyacc_value] = ACTIONS(6961),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5689),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5687),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6963),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6965),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5687),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5687),
    [aux_sym_number_token1] = ACTIONS(6967),
    [anon_sym_SQUOTE] = ACTIONS(6969),
    [anon_sym_DQUOTE] = ACTIONS(6971),
    [sym_prefix_operator] = ACTIONS(6973),
    [sym__uppercase_identifier] = ACTIONS(6975),
    [aux_sym_tag_token1] = ACTIONS(6977),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2548] = {
    [sym_parameter] = STATE(7522),
    [sym__class_typed] = STATE(11160),
    [sym__parenthesized_abstract_type] = STATE(7522),
    [sym__simple_pattern] = STATE(7538),
    [sym_typed_pattern] = STATE(7593),
    [sym_polymorphic_variant_pattern] = STATE(7593),
    [sym_record_pattern] = STATE(7593),
    [sym_list_pattern] = STATE(7593),
    [sym_array_pattern] = STATE(7593),
    [sym_local_open_pattern] = STATE(7593),
    [sym_package_pattern] = STATE(7593),
    [sym_parenthesized_pattern] = STATE(7593),
    [sym_attribute] = STATE(2548),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7593),
    [sym_quoted_extension] = STATE(7593),
    [sym__constant] = STATE(7549),
    [sym__signed_constant] = STATE(7593),
    [sym_number] = STATE(7628),
    [sym_signed_number] = STATE(7549),
    [sym_character] = STATE(7628),
    [sym_string] = STATE(7628),
    [sym_quoted_string] = STATE(7628),
    [sym_boolean] = STATE(7628),
    [sym_unit] = STATE(7628),
    [sym__simple_value_pattern] = STATE(7593),
    [sym_parenthesized_operator] = STATE(7593),
    [sym_module_path] = STATE(19032),
    [sym_constructor_path] = STATE(7593),
    [sym__constructor_name] = STATE(7627),
    [sym_tag] = STATE(7593),
    [aux_sym_expression_item_repeat1] = STATE(10705),
    [aux_sym_let_binding_repeat1] = STATE(2592),
    [sym__lowercase_identifier] = ACTIONS(6895),
    [anon_sym_SEMI_SEMI] = ACTIONS(7115),
    [anon_sym_let] = ACTIONS(7117),
    [anon_sym_and] = ACTIONS(7117),
    [anon_sym_EQ] = ACTIONS(7119),
    [anon_sym_TILDE] = ACTIONS(6903),
    [anon_sym_QMARK] = ACTIONS(6903),
    [anon_sym_LPAREN] = ACTIONS(6905),
    [anon_sym_external] = ACTIONS(7117),
    [anon_sym_type] = ACTIONS(7117),
    [anon_sym_LBRACK] = ACTIONS(6907),
    [anon_sym_true] = ACTIONS(6909),
    [anon_sym_false] = ACTIONS(6909),
    [anon_sym_COLON2] = ACTIONS(6911),
    [anon_sym_LBRACE] = ACTIONS(6913),
    [anon_sym_exception] = ACTIONS(7117),
    [anon_sym_module] = ACTIONS(7117),
    [anon_sym_open] = ACTIONS(7117),
    [anon_sym_include] = ACTIONS(7117),
    [anon_sym_class] = ACTIONS(7117),
    [anon_sym_end] = ACTIONS(7117),
    [anon_sym_POUND] = ACTIONS(6915),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6917),
    [anon_sym_begin] = ACTIONS(6919),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7115),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6923),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6925),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7115),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7115),
    [aux_sym_number_token1] = ACTIONS(6927),
    [aux_sym_signed_number_token1] = ACTIONS(6929),
    [anon_sym_SQUOTE] = ACTIONS(6931),
    [anon_sym_DQUOTE] = ACTIONS(6933),
    [sym_let_operator] = ACTIONS(7115),
    [sym__uppercase_identifier] = ACTIONS(6935),
    [aux_sym_directive_token1] = ACTIONS(7117),
    [aux_sym_tag_token1] = ACTIONS(6937),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2549] = {
    [sym_parameter] = STATE(7522),
    [sym__class_typed] = STATE(11008),
    [sym__parenthesized_abstract_type] = STATE(7522),
    [sym__simple_pattern] = STATE(7538),
    [sym_typed_pattern] = STATE(7593),
    [sym_polymorphic_variant_pattern] = STATE(7593),
    [sym_record_pattern] = STATE(7593),
    [sym_list_pattern] = STATE(7593),
    [sym_array_pattern] = STATE(7593),
    [sym_local_open_pattern] = STATE(7593),
    [sym_package_pattern] = STATE(7593),
    [sym_parenthesized_pattern] = STATE(7593),
    [sym_attribute] = STATE(2549),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7593),
    [sym_quoted_extension] = STATE(7593),
    [sym__constant] = STATE(7549),
    [sym__signed_constant] = STATE(7593),
    [sym_number] = STATE(7628),
    [sym_signed_number] = STATE(7549),
    [sym_character] = STATE(7628),
    [sym_string] = STATE(7628),
    [sym_quoted_string] = STATE(7628),
    [sym_boolean] = STATE(7628),
    [sym_unit] = STATE(7628),
    [sym__simple_value_pattern] = STATE(7593),
    [sym_parenthesized_operator] = STATE(7593),
    [sym_module_path] = STATE(19032),
    [sym_constructor_path] = STATE(7593),
    [sym__constructor_name] = STATE(7627),
    [sym_tag] = STATE(7593),
    [aux_sym_expression_item_repeat1] = STATE(10542),
    [aux_sym_let_binding_repeat1] = STATE(2548),
    [sym__lowercase_identifier] = ACTIONS(6895),
    [anon_sym_SEMI_SEMI] = ACTIONS(7121),
    [anon_sym_let] = ACTIONS(7123),
    [anon_sym_and] = ACTIONS(7123),
    [anon_sym_EQ] = ACTIONS(7125),
    [anon_sym_TILDE] = ACTIONS(6903),
    [anon_sym_QMARK] = ACTIONS(6903),
    [anon_sym_LPAREN] = ACTIONS(6905),
    [anon_sym_external] = ACTIONS(7123),
    [anon_sym_type] = ACTIONS(7123),
    [anon_sym_LBRACK] = ACTIONS(6907),
    [anon_sym_true] = ACTIONS(6909),
    [anon_sym_false] = ACTIONS(6909),
    [anon_sym_COLON2] = ACTIONS(6911),
    [anon_sym_LBRACE] = ACTIONS(6913),
    [anon_sym_exception] = ACTIONS(7123),
    [anon_sym_module] = ACTIONS(7123),
    [anon_sym_open] = ACTIONS(7123),
    [anon_sym_include] = ACTIONS(7123),
    [anon_sym_class] = ACTIONS(7123),
    [anon_sym_end] = ACTIONS(7123),
    [anon_sym_POUND] = ACTIONS(6915),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6917),
    [anon_sym_begin] = ACTIONS(6919),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7121),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6923),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6925),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7121),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7121),
    [aux_sym_number_token1] = ACTIONS(6927),
    [aux_sym_signed_number_token1] = ACTIONS(6929),
    [anon_sym_SQUOTE] = ACTIONS(6931),
    [anon_sym_DQUOTE] = ACTIONS(6933),
    [sym_let_operator] = ACTIONS(7121),
    [sym__uppercase_identifier] = ACTIONS(6935),
    [aux_sym_directive_token1] = ACTIONS(7123),
    [aux_sym_tag_token1] = ACTIONS(6937),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2550] = {
    [sym_parameter] = STATE(7583),
    [sym__class_typed] = STATE(11115),
    [sym__parenthesized_abstract_type] = STATE(7583),
    [sym__simple_pattern] = STATE(7579),
    [sym_typed_pattern] = STATE(7652),
    [sym_polymorphic_variant_pattern] = STATE(7652),
    [sym_record_pattern] = STATE(7652),
    [sym_list_pattern] = STATE(7652),
    [sym_array_pattern] = STATE(7652),
    [sym_local_open_pattern] = STATE(7652),
    [sym_package_pattern] = STATE(7652),
    [sym_parenthesized_pattern] = STATE(7652),
    [sym_attribute] = STATE(2550),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7652),
    [sym_quoted_extension] = STATE(7652),
    [sym__constant] = STATE(7650),
    [sym__signed_constant] = STATE(7652),
    [sym_number] = STATE(7629),
    [sym_signed_number] = STATE(7650),
    [sym_character] = STATE(7629),
    [sym_string] = STATE(7629),
    [sym_quoted_string] = STATE(7629),
    [sym_boolean] = STATE(7629),
    [sym_unit] = STATE(7629),
    [sym__simple_value_pattern] = STATE(7652),
    [sym_parenthesized_operator] = STATE(7652),
    [sym_module_path] = STATE(19315),
    [sym_constructor_path] = STATE(7652),
    [sym__constructor_name] = STATE(7651),
    [sym_tag] = STATE(7652),
    [aux_sym_expression_item_repeat1] = STATE(10542),
    [aux_sym_let_binding_repeat1] = STATE(2552),
    [sym__lowercase_identifier] = ACTIONS(6979),
    [anon_sym_SEMI_SEMI] = ACTIONS(7121),
    [anon_sym_let] = ACTIONS(7123),
    [anon_sym_and] = ACTIONS(7123),
    [anon_sym_EQ] = ACTIONS(7127),
    [anon_sym_TILDE] = ACTIONS(6987),
    [anon_sym_QMARK] = ACTIONS(6987),
    [anon_sym_LPAREN] = ACTIONS(6989),
    [anon_sym_external] = ACTIONS(7123),
    [anon_sym_type] = ACTIONS(7123),
    [anon_sym_LBRACK] = ACTIONS(6991),
    [anon_sym_RBRACK] = ACTIONS(7121),
    [anon_sym_true] = ACTIONS(6993),
    [anon_sym_false] = ACTIONS(6993),
    [anon_sym_COLON2] = ACTIONS(6995),
    [anon_sym_LBRACE] = ACTIONS(6997),
    [anon_sym_exception] = ACTIONS(7123),
    [anon_sym_module] = ACTIONS(7123),
    [anon_sym_open] = ACTIONS(7123),
    [anon_sym_include] = ACTIONS(7123),
    [anon_sym_class] = ACTIONS(7123),
    [anon_sym_POUND] = ACTIONS(6999),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7001),
    [anon_sym_begin] = ACTIONS(7003),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7121),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7005),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7007),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7121),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7121),
    [aux_sym_number_token1] = ACTIONS(7009),
    [aux_sym_signed_number_token1] = ACTIONS(7011),
    [anon_sym_SQUOTE] = ACTIONS(7013),
    [anon_sym_DQUOTE] = ACTIONS(7015),
    [sym_let_operator] = ACTIONS(7121),
    [sym__uppercase_identifier] = ACTIONS(7017),
    [aux_sym_directive_token1] = ACTIONS(7123),
    [aux_sym_tag_token1] = ACTIONS(7019),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2551] = {
    [sym_parameter] = STATE(7522),
    [sym__class_typed] = STATE(11189),
    [sym__parenthesized_abstract_type] = STATE(7522),
    [sym__simple_pattern] = STATE(7538),
    [sym_typed_pattern] = STATE(7593),
    [sym_polymorphic_variant_pattern] = STATE(7593),
    [sym_record_pattern] = STATE(7593),
    [sym_list_pattern] = STATE(7593),
    [sym_array_pattern] = STATE(7593),
    [sym_local_open_pattern] = STATE(7593),
    [sym_package_pattern] = STATE(7593),
    [sym_parenthesized_pattern] = STATE(7593),
    [sym_attribute] = STATE(2551),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7593),
    [sym_quoted_extension] = STATE(7593),
    [sym__constant] = STATE(7549),
    [sym__signed_constant] = STATE(7593),
    [sym_number] = STATE(7628),
    [sym_signed_number] = STATE(7549),
    [sym_character] = STATE(7628),
    [sym_string] = STATE(7628),
    [sym_quoted_string] = STATE(7628),
    [sym_boolean] = STATE(7628),
    [sym_unit] = STATE(7628),
    [sym__simple_value_pattern] = STATE(7593),
    [sym_parenthesized_operator] = STATE(7593),
    [sym_module_path] = STATE(19032),
    [sym_constructor_path] = STATE(7593),
    [sym__constructor_name] = STATE(7627),
    [sym_tag] = STATE(7593),
    [aux_sym_expression_item_repeat1] = STATE(10495),
    [aux_sym_let_binding_repeat1] = STATE(2592),
    [sym__lowercase_identifier] = ACTIONS(6895),
    [anon_sym_SEMI_SEMI] = ACTIONS(7109),
    [anon_sym_let] = ACTIONS(7111),
    [anon_sym_and] = ACTIONS(7111),
    [anon_sym_EQ] = ACTIONS(7129),
    [anon_sym_TILDE] = ACTIONS(6903),
    [anon_sym_QMARK] = ACTIONS(6903),
    [anon_sym_LPAREN] = ACTIONS(6905),
    [anon_sym_external] = ACTIONS(7111),
    [anon_sym_type] = ACTIONS(7111),
    [anon_sym_LBRACK] = ACTIONS(6907),
    [anon_sym_true] = ACTIONS(6909),
    [anon_sym_false] = ACTIONS(6909),
    [anon_sym_COLON2] = ACTIONS(6911),
    [anon_sym_LBRACE] = ACTIONS(6913),
    [anon_sym_exception] = ACTIONS(7111),
    [anon_sym_module] = ACTIONS(7111),
    [anon_sym_open] = ACTIONS(7111),
    [anon_sym_include] = ACTIONS(7111),
    [anon_sym_class] = ACTIONS(7111),
    [anon_sym_end] = ACTIONS(7111),
    [anon_sym_POUND] = ACTIONS(6915),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6917),
    [anon_sym_begin] = ACTIONS(6919),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7109),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6923),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6925),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7109),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7109),
    [aux_sym_number_token1] = ACTIONS(6927),
    [aux_sym_signed_number_token1] = ACTIONS(6929),
    [anon_sym_SQUOTE] = ACTIONS(6931),
    [anon_sym_DQUOTE] = ACTIONS(6933),
    [sym_let_operator] = ACTIONS(7109),
    [sym__uppercase_identifier] = ACTIONS(6935),
    [aux_sym_directive_token1] = ACTIONS(7111),
    [aux_sym_tag_token1] = ACTIONS(6937),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2552] = {
    [sym_parameter] = STATE(7583),
    [sym__class_typed] = STATE(11000),
    [sym__parenthesized_abstract_type] = STATE(7583),
    [sym__simple_pattern] = STATE(7579),
    [sym_typed_pattern] = STATE(7652),
    [sym_polymorphic_variant_pattern] = STATE(7652),
    [sym_record_pattern] = STATE(7652),
    [sym_list_pattern] = STATE(7652),
    [sym_array_pattern] = STATE(7652),
    [sym_local_open_pattern] = STATE(7652),
    [sym_package_pattern] = STATE(7652),
    [sym_parenthesized_pattern] = STATE(7652),
    [sym_attribute] = STATE(2552),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7652),
    [sym_quoted_extension] = STATE(7652),
    [sym__constant] = STATE(7650),
    [sym__signed_constant] = STATE(7652),
    [sym_number] = STATE(7629),
    [sym_signed_number] = STATE(7650),
    [sym_character] = STATE(7629),
    [sym_string] = STATE(7629),
    [sym_quoted_string] = STATE(7629),
    [sym_boolean] = STATE(7629),
    [sym_unit] = STATE(7629),
    [sym__simple_value_pattern] = STATE(7652),
    [sym_parenthesized_operator] = STATE(7652),
    [sym_module_path] = STATE(19315),
    [sym_constructor_path] = STATE(7652),
    [sym__constructor_name] = STATE(7651),
    [sym_tag] = STATE(7652),
    [aux_sym_expression_item_repeat1] = STATE(10705),
    [aux_sym_let_binding_repeat1] = STATE(2591),
    [sym__lowercase_identifier] = ACTIONS(6979),
    [anon_sym_SEMI_SEMI] = ACTIONS(7115),
    [anon_sym_let] = ACTIONS(7117),
    [anon_sym_and] = ACTIONS(7117),
    [anon_sym_EQ] = ACTIONS(7131),
    [anon_sym_TILDE] = ACTIONS(6987),
    [anon_sym_QMARK] = ACTIONS(6987),
    [anon_sym_LPAREN] = ACTIONS(6989),
    [anon_sym_external] = ACTIONS(7117),
    [anon_sym_type] = ACTIONS(7117),
    [anon_sym_LBRACK] = ACTIONS(6991),
    [anon_sym_RBRACK] = ACTIONS(7115),
    [anon_sym_true] = ACTIONS(6993),
    [anon_sym_false] = ACTIONS(6993),
    [anon_sym_COLON2] = ACTIONS(6995),
    [anon_sym_LBRACE] = ACTIONS(6997),
    [anon_sym_exception] = ACTIONS(7117),
    [anon_sym_module] = ACTIONS(7117),
    [anon_sym_open] = ACTIONS(7117),
    [anon_sym_include] = ACTIONS(7117),
    [anon_sym_class] = ACTIONS(7117),
    [anon_sym_POUND] = ACTIONS(6999),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7001),
    [anon_sym_begin] = ACTIONS(7003),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7115),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7005),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7007),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7115),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7115),
    [aux_sym_number_token1] = ACTIONS(7009),
    [aux_sym_signed_number_token1] = ACTIONS(7011),
    [anon_sym_SQUOTE] = ACTIONS(7013),
    [anon_sym_DQUOTE] = ACTIONS(7015),
    [sym_let_operator] = ACTIONS(7115),
    [sym__uppercase_identifier] = ACTIONS(7017),
    [aux_sym_directive_token1] = ACTIONS(7117),
    [aux_sym_tag_token1] = ACTIONS(7019),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2553] = {
    [sym_parameter] = STATE(7522),
    [sym__class_typed] = STATE(11001),
    [sym__parenthesized_abstract_type] = STATE(7522),
    [sym__simple_pattern] = STATE(7538),
    [sym_typed_pattern] = STATE(7593),
    [sym_polymorphic_variant_pattern] = STATE(7593),
    [sym_record_pattern] = STATE(7593),
    [sym_list_pattern] = STATE(7593),
    [sym_array_pattern] = STATE(7593),
    [sym_local_open_pattern] = STATE(7593),
    [sym_package_pattern] = STATE(7593),
    [sym_parenthesized_pattern] = STATE(7593),
    [sym_attribute] = STATE(2553),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7593),
    [sym_quoted_extension] = STATE(7593),
    [sym__constant] = STATE(7549),
    [sym__signed_constant] = STATE(7593),
    [sym_number] = STATE(7628),
    [sym_signed_number] = STATE(7549),
    [sym_character] = STATE(7628),
    [sym_string] = STATE(7628),
    [sym_quoted_string] = STATE(7628),
    [sym_boolean] = STATE(7628),
    [sym_unit] = STATE(7628),
    [sym__simple_value_pattern] = STATE(7593),
    [sym_parenthesized_operator] = STATE(7593),
    [sym_module_path] = STATE(19032),
    [sym_constructor_path] = STATE(7593),
    [sym__constructor_name] = STATE(7627),
    [sym_tag] = STATE(7593),
    [aux_sym_expression_item_repeat1] = STATE(10405),
    [aux_sym_let_binding_repeat1] = STATE(2592),
    [sym__lowercase_identifier] = ACTIONS(6895),
    [anon_sym_SEMI_SEMI] = ACTIONS(7133),
    [anon_sym_let] = ACTIONS(7135),
    [anon_sym_and] = ACTIONS(7135),
    [anon_sym_EQ] = ACTIONS(7137),
    [anon_sym_TILDE] = ACTIONS(6903),
    [anon_sym_QMARK] = ACTIONS(6903),
    [anon_sym_LPAREN] = ACTIONS(6905),
    [anon_sym_external] = ACTIONS(7135),
    [anon_sym_type] = ACTIONS(7135),
    [anon_sym_LBRACK] = ACTIONS(6907),
    [anon_sym_true] = ACTIONS(6909),
    [anon_sym_false] = ACTIONS(6909),
    [anon_sym_COLON2] = ACTIONS(6911),
    [anon_sym_LBRACE] = ACTIONS(6913),
    [anon_sym_exception] = ACTIONS(7135),
    [anon_sym_module] = ACTIONS(7135),
    [anon_sym_open] = ACTIONS(7135),
    [anon_sym_include] = ACTIONS(7135),
    [anon_sym_class] = ACTIONS(7135),
    [anon_sym_end] = ACTIONS(7135),
    [anon_sym_POUND] = ACTIONS(6915),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6917),
    [anon_sym_begin] = ACTIONS(6919),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7133),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6923),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6925),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7133),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7133),
    [aux_sym_number_token1] = ACTIONS(6927),
    [aux_sym_signed_number_token1] = ACTIONS(6929),
    [anon_sym_SQUOTE] = ACTIONS(6931),
    [anon_sym_DQUOTE] = ACTIONS(6933),
    [sym_let_operator] = ACTIONS(7133),
    [sym__uppercase_identifier] = ACTIONS(6935),
    [aux_sym_directive_token1] = ACTIONS(7135),
    [aux_sym_tag_token1] = ACTIONS(6937),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2554] = {
    [sym_parameter] = STATE(7583),
    [sym__class_typed] = STATE(11116),
    [sym__parenthesized_abstract_type] = STATE(7583),
    [sym__simple_pattern] = STATE(7579),
    [sym_typed_pattern] = STATE(7652),
    [sym_polymorphic_variant_pattern] = STATE(7652),
    [sym_record_pattern] = STATE(7652),
    [sym_list_pattern] = STATE(7652),
    [sym_array_pattern] = STATE(7652),
    [sym_local_open_pattern] = STATE(7652),
    [sym_package_pattern] = STATE(7652),
    [sym_parenthesized_pattern] = STATE(7652),
    [sym_attribute] = STATE(2554),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7652),
    [sym_quoted_extension] = STATE(7652),
    [sym__constant] = STATE(7650),
    [sym__signed_constant] = STATE(7652),
    [sym_number] = STATE(7629),
    [sym_signed_number] = STATE(7650),
    [sym_character] = STATE(7629),
    [sym_string] = STATE(7629),
    [sym_quoted_string] = STATE(7629),
    [sym_boolean] = STATE(7629),
    [sym_unit] = STATE(7629),
    [sym__simple_value_pattern] = STATE(7652),
    [sym_parenthesized_operator] = STATE(7652),
    [sym_module_path] = STATE(19315),
    [sym_constructor_path] = STATE(7652),
    [sym__constructor_name] = STATE(7651),
    [sym_tag] = STATE(7652),
    [aux_sym_expression_item_repeat1] = STATE(10405),
    [aux_sym_let_binding_repeat1] = STATE(2591),
    [sym__lowercase_identifier] = ACTIONS(6979),
    [anon_sym_SEMI_SEMI] = ACTIONS(7133),
    [anon_sym_let] = ACTIONS(7135),
    [anon_sym_and] = ACTIONS(7135),
    [anon_sym_EQ] = ACTIONS(7139),
    [anon_sym_TILDE] = ACTIONS(6987),
    [anon_sym_QMARK] = ACTIONS(6987),
    [anon_sym_LPAREN] = ACTIONS(6989),
    [anon_sym_external] = ACTIONS(7135),
    [anon_sym_type] = ACTIONS(7135),
    [anon_sym_LBRACK] = ACTIONS(6991),
    [anon_sym_RBRACK] = ACTIONS(7133),
    [anon_sym_true] = ACTIONS(6993),
    [anon_sym_false] = ACTIONS(6993),
    [anon_sym_COLON2] = ACTIONS(6995),
    [anon_sym_LBRACE] = ACTIONS(6997),
    [anon_sym_exception] = ACTIONS(7135),
    [anon_sym_module] = ACTIONS(7135),
    [anon_sym_open] = ACTIONS(7135),
    [anon_sym_include] = ACTIONS(7135),
    [anon_sym_class] = ACTIONS(7135),
    [anon_sym_POUND] = ACTIONS(6999),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7001),
    [anon_sym_begin] = ACTIONS(7003),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7133),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7005),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7007),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7133),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7133),
    [aux_sym_number_token1] = ACTIONS(7009),
    [aux_sym_signed_number_token1] = ACTIONS(7011),
    [anon_sym_SQUOTE] = ACTIONS(7013),
    [anon_sym_DQUOTE] = ACTIONS(7015),
    [sym_let_operator] = ACTIONS(7133),
    [sym__uppercase_identifier] = ACTIONS(7017),
    [aux_sym_directive_token1] = ACTIONS(7135),
    [aux_sym_tag_token1] = ACTIONS(7019),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2555] = {
    [sym_parameter] = STATE(7522),
    [sym__class_typed] = STATE(11176),
    [sym__parenthesized_abstract_type] = STATE(7522),
    [sym__simple_pattern] = STATE(7538),
    [sym_typed_pattern] = STATE(7593),
    [sym_polymorphic_variant_pattern] = STATE(7593),
    [sym_record_pattern] = STATE(7593),
    [sym_list_pattern] = STATE(7593),
    [sym_array_pattern] = STATE(7593),
    [sym_local_open_pattern] = STATE(7593),
    [sym_package_pattern] = STATE(7593),
    [sym_parenthesized_pattern] = STATE(7593),
    [sym_attribute] = STATE(2555),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7593),
    [sym_quoted_extension] = STATE(7593),
    [sym__constant] = STATE(7549),
    [sym__signed_constant] = STATE(7593),
    [sym_number] = STATE(7628),
    [sym_signed_number] = STATE(7549),
    [sym_character] = STATE(7628),
    [sym_string] = STATE(7628),
    [sym_quoted_string] = STATE(7628),
    [sym_boolean] = STATE(7628),
    [sym_unit] = STATE(7628),
    [sym__simple_value_pattern] = STATE(7593),
    [sym_parenthesized_operator] = STATE(7593),
    [sym_module_path] = STATE(19032),
    [sym_constructor_path] = STATE(7593),
    [sym__constructor_name] = STATE(7627),
    [sym_tag] = STATE(7593),
    [aux_sym_expression_item_repeat1] = STATE(10639),
    [aux_sym_let_binding_repeat1] = STATE(2536),
    [sym__lowercase_identifier] = ACTIONS(6895),
    [anon_sym_SEMI_SEMI] = ACTIONS(6981),
    [anon_sym_let] = ACTIONS(6983),
    [anon_sym_and] = ACTIONS(6983),
    [anon_sym_EQ] = ACTIONS(7141),
    [anon_sym_TILDE] = ACTIONS(6903),
    [anon_sym_QMARK] = ACTIONS(6903),
    [anon_sym_LPAREN] = ACTIONS(6905),
    [anon_sym_external] = ACTIONS(6983),
    [anon_sym_type] = ACTIONS(6983),
    [anon_sym_LBRACK] = ACTIONS(6907),
    [anon_sym_true] = ACTIONS(6909),
    [anon_sym_false] = ACTIONS(6909),
    [anon_sym_COLON2] = ACTIONS(6911),
    [anon_sym_LBRACE] = ACTIONS(6913),
    [anon_sym_exception] = ACTIONS(6983),
    [anon_sym_module] = ACTIONS(6983),
    [anon_sym_open] = ACTIONS(6983),
    [anon_sym_include] = ACTIONS(6983),
    [anon_sym_class] = ACTIONS(6983),
    [anon_sym_end] = ACTIONS(6983),
    [anon_sym_POUND] = ACTIONS(6915),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6917),
    [anon_sym_begin] = ACTIONS(6919),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6981),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6923),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6925),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6981),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6981),
    [aux_sym_number_token1] = ACTIONS(6927),
    [aux_sym_signed_number_token1] = ACTIONS(6929),
    [anon_sym_SQUOTE] = ACTIONS(6931),
    [anon_sym_DQUOTE] = ACTIONS(6933),
    [sym_let_operator] = ACTIONS(6981),
    [sym__uppercase_identifier] = ACTIONS(6935),
    [aux_sym_directive_token1] = ACTIONS(6983),
    [aux_sym_tag_token1] = ACTIONS(6937),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2556] = {
    [sym_parameter] = STATE(7583),
    [sym__class_typed] = STATE(11108),
    [sym__parenthesized_abstract_type] = STATE(7583),
    [sym__simple_pattern] = STATE(7579),
    [sym_typed_pattern] = STATE(7652),
    [sym_polymorphic_variant_pattern] = STATE(7652),
    [sym_record_pattern] = STATE(7652),
    [sym_list_pattern] = STATE(7652),
    [sym_array_pattern] = STATE(7652),
    [sym_local_open_pattern] = STATE(7652),
    [sym_package_pattern] = STATE(7652),
    [sym_parenthesized_pattern] = STATE(7652),
    [sym_attribute] = STATE(2556),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7652),
    [sym_quoted_extension] = STATE(7652),
    [sym__constant] = STATE(7650),
    [sym__signed_constant] = STATE(7652),
    [sym_number] = STATE(7629),
    [sym_signed_number] = STATE(7650),
    [sym_character] = STATE(7629),
    [sym_string] = STATE(7629),
    [sym_quoted_string] = STATE(7629),
    [sym_boolean] = STATE(7629),
    [sym_unit] = STATE(7629),
    [sym__simple_value_pattern] = STATE(7652),
    [sym_parenthesized_operator] = STATE(7652),
    [sym_module_path] = STATE(19315),
    [sym_constructor_path] = STATE(7652),
    [sym__constructor_name] = STATE(7651),
    [sym_tag] = STATE(7652),
    [aux_sym_expression_item_repeat1] = STATE(10536),
    [aux_sym_let_binding_repeat1] = STATE(2543),
    [sym__lowercase_identifier] = ACTIONS(6979),
    [anon_sym_SEMI_SEMI] = ACTIONS(7087),
    [anon_sym_let] = ACTIONS(7089),
    [anon_sym_and] = ACTIONS(7089),
    [anon_sym_EQ] = ACTIONS(7143),
    [anon_sym_TILDE] = ACTIONS(6987),
    [anon_sym_QMARK] = ACTIONS(6987),
    [anon_sym_LPAREN] = ACTIONS(6989),
    [anon_sym_external] = ACTIONS(7089),
    [anon_sym_type] = ACTIONS(7089),
    [anon_sym_LBRACK] = ACTIONS(6991),
    [anon_sym_RBRACK] = ACTIONS(7087),
    [anon_sym_true] = ACTIONS(6993),
    [anon_sym_false] = ACTIONS(6993),
    [anon_sym_COLON2] = ACTIONS(6995),
    [anon_sym_LBRACE] = ACTIONS(6997),
    [anon_sym_exception] = ACTIONS(7089),
    [anon_sym_module] = ACTIONS(7089),
    [anon_sym_open] = ACTIONS(7089),
    [anon_sym_include] = ACTIONS(7089),
    [anon_sym_class] = ACTIONS(7089),
    [anon_sym_POUND] = ACTIONS(6999),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7001),
    [anon_sym_begin] = ACTIONS(7003),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7087),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7005),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7007),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7087),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7087),
    [aux_sym_number_token1] = ACTIONS(7009),
    [aux_sym_signed_number_token1] = ACTIONS(7011),
    [anon_sym_SQUOTE] = ACTIONS(7013),
    [anon_sym_DQUOTE] = ACTIONS(7015),
    [sym_let_operator] = ACTIONS(7087),
    [sym__uppercase_identifier] = ACTIONS(7017),
    [aux_sym_directive_token1] = ACTIONS(7089),
    [aux_sym_tag_token1] = ACTIONS(7019),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2557] = {
    [sym_parameter] = STATE(7583),
    [sym__class_typed] = STATE(11162),
    [sym__parenthesized_abstract_type] = STATE(7583),
    [sym__simple_pattern] = STATE(7579),
    [sym_typed_pattern] = STATE(7652),
    [sym_polymorphic_variant_pattern] = STATE(7652),
    [sym_record_pattern] = STATE(7652),
    [sym_list_pattern] = STATE(7652),
    [sym_array_pattern] = STATE(7652),
    [sym_local_open_pattern] = STATE(7652),
    [sym_package_pattern] = STATE(7652),
    [sym_parenthesized_pattern] = STATE(7652),
    [sym_attribute] = STATE(2557),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7652),
    [sym_quoted_extension] = STATE(7652),
    [sym__constant] = STATE(7650),
    [sym__signed_constant] = STATE(7652),
    [sym_number] = STATE(7629),
    [sym_signed_number] = STATE(7650),
    [sym_character] = STATE(7629),
    [sym_string] = STATE(7629),
    [sym_quoted_string] = STATE(7629),
    [sym_boolean] = STATE(7629),
    [sym_unit] = STATE(7629),
    [sym__simple_value_pattern] = STATE(7652),
    [sym_parenthesized_operator] = STATE(7652),
    [sym_module_path] = STATE(19315),
    [sym_constructor_path] = STATE(7652),
    [sym__constructor_name] = STATE(7651),
    [sym_tag] = STATE(7652),
    [aux_sym_expression_item_repeat1] = STATE(10544),
    [aux_sym_let_binding_repeat1] = STATE(2591),
    [sym__lowercase_identifier] = ACTIONS(6979),
    [anon_sym_SEMI_SEMI] = ACTIONS(6897),
    [anon_sym_let] = ACTIONS(6899),
    [anon_sym_and] = ACTIONS(6899),
    [anon_sym_EQ] = ACTIONS(7145),
    [anon_sym_TILDE] = ACTIONS(6987),
    [anon_sym_QMARK] = ACTIONS(6987),
    [anon_sym_LPAREN] = ACTIONS(6989),
    [anon_sym_external] = ACTIONS(6899),
    [anon_sym_type] = ACTIONS(6899),
    [anon_sym_LBRACK] = ACTIONS(6991),
    [anon_sym_RBRACK] = ACTIONS(6897),
    [anon_sym_true] = ACTIONS(6993),
    [anon_sym_false] = ACTIONS(6993),
    [anon_sym_COLON2] = ACTIONS(6995),
    [anon_sym_LBRACE] = ACTIONS(6997),
    [anon_sym_exception] = ACTIONS(6899),
    [anon_sym_module] = ACTIONS(6899),
    [anon_sym_open] = ACTIONS(6899),
    [anon_sym_include] = ACTIONS(6899),
    [anon_sym_class] = ACTIONS(6899),
    [anon_sym_POUND] = ACTIONS(6999),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7001),
    [anon_sym_begin] = ACTIONS(7003),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6897),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7005),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7007),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6897),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6897),
    [aux_sym_number_token1] = ACTIONS(7009),
    [aux_sym_signed_number_token1] = ACTIONS(7011),
    [anon_sym_SQUOTE] = ACTIONS(7013),
    [anon_sym_DQUOTE] = ACTIONS(7015),
    [sym_let_operator] = ACTIONS(6897),
    [sym__uppercase_identifier] = ACTIONS(7017),
    [aux_sym_directive_token1] = ACTIONS(6899),
    [aux_sym_tag_token1] = ACTIONS(7019),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2558] = {
    [sym_parameter] = STATE(7522),
    [sym__class_typed] = STATE(11074),
    [sym__parenthesized_abstract_type] = STATE(7522),
    [sym__simple_pattern] = STATE(7538),
    [sym_typed_pattern] = STATE(7593),
    [sym_polymorphic_variant_pattern] = STATE(7593),
    [sym_record_pattern] = STATE(7593),
    [sym_list_pattern] = STATE(7593),
    [sym_array_pattern] = STATE(7593),
    [sym_local_open_pattern] = STATE(7593),
    [sym_package_pattern] = STATE(7593),
    [sym_parenthesized_pattern] = STATE(7593),
    [sym_attribute] = STATE(2558),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7593),
    [sym_quoted_extension] = STATE(7593),
    [sym__constant] = STATE(7549),
    [sym__signed_constant] = STATE(7593),
    [sym_number] = STATE(7628),
    [sym_signed_number] = STATE(7549),
    [sym_character] = STATE(7628),
    [sym_string] = STATE(7628),
    [sym_quoted_string] = STATE(7628),
    [sym_boolean] = STATE(7628),
    [sym_unit] = STATE(7628),
    [sym__simple_value_pattern] = STATE(7593),
    [sym_parenthesized_operator] = STATE(7593),
    [sym_module_path] = STATE(19032),
    [sym_constructor_path] = STATE(7593),
    [sym__constructor_name] = STATE(7627),
    [sym_tag] = STATE(7593),
    [aux_sym_expression_item_repeat1] = STATE(10433),
    [aux_sym_let_binding_repeat1] = STATE(2553),
    [sym__lowercase_identifier] = ACTIONS(6895),
    [anon_sym_SEMI_SEMI] = ACTIONS(7093),
    [anon_sym_let] = ACTIONS(7095),
    [anon_sym_and] = ACTIONS(7095),
    [anon_sym_EQ] = ACTIONS(7147),
    [anon_sym_TILDE] = ACTIONS(6903),
    [anon_sym_QMARK] = ACTIONS(6903),
    [anon_sym_LPAREN] = ACTIONS(6905),
    [anon_sym_external] = ACTIONS(7095),
    [anon_sym_type] = ACTIONS(7095),
    [anon_sym_LBRACK] = ACTIONS(6907),
    [anon_sym_true] = ACTIONS(6909),
    [anon_sym_false] = ACTIONS(6909),
    [anon_sym_COLON2] = ACTIONS(6911),
    [anon_sym_LBRACE] = ACTIONS(6913),
    [anon_sym_exception] = ACTIONS(7095),
    [anon_sym_module] = ACTIONS(7095),
    [anon_sym_open] = ACTIONS(7095),
    [anon_sym_include] = ACTIONS(7095),
    [anon_sym_class] = ACTIONS(7095),
    [anon_sym_end] = ACTIONS(7095),
    [anon_sym_POUND] = ACTIONS(6915),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6917),
    [anon_sym_begin] = ACTIONS(6919),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7093),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6923),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6925),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7093),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7093),
    [aux_sym_number_token1] = ACTIONS(6927),
    [aux_sym_signed_number_token1] = ACTIONS(6929),
    [anon_sym_SQUOTE] = ACTIONS(6931),
    [anon_sym_DQUOTE] = ACTIONS(6933),
    [sym_let_operator] = ACTIONS(7093),
    [sym__uppercase_identifier] = ACTIONS(6935),
    [aux_sym_directive_token1] = ACTIONS(7095),
    [aux_sym_tag_token1] = ACTIONS(6937),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2559] = {
    [sym__parenthesized_abstract_type] = STATE(3415),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13135),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2559),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_EQ] = ACTIONS(7149),
    [anon_sym_LPAREN] = ACTIONS(7151),
    [anon_sym_RPAREN] = ACTIONS(7149),
    [anon_sym_COMMA] = ACTIONS(7149),
    [anon_sym_PIPE] = ACTIONS(7149),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_RBRACK] = ACTIONS(7149),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_COLON2] = ACTIONS(7153),
    [anon_sym_DASH_GT] = ACTIONS(7149),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_as] = ACTIONS(7153),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_COLON_COLON] = ACTIONS(7149),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_when] = ACTIONS(7153),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7157),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2560] = {
    [sym_parameter] = STATE(7801),
    [sym__class_typed] = STATE(11746),
    [sym__parenthesized_abstract_type] = STATE(7801),
    [sym__simple_pattern] = STATE(7799),
    [sym_typed_pattern] = STATE(7796),
    [sym_polymorphic_variant_pattern] = STATE(7796),
    [sym_record_pattern] = STATE(7796),
    [sym_list_pattern] = STATE(7796),
    [sym_array_pattern] = STATE(7796),
    [sym_local_open_pattern] = STATE(7796),
    [sym_package_pattern] = STATE(7796),
    [sym_parenthesized_pattern] = STATE(7796),
    [sym_attribute] = STATE(2560),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7796),
    [sym_quoted_extension] = STATE(7796),
    [sym__constant] = STATE(7794),
    [sym__signed_constant] = STATE(7796),
    [sym_number] = STATE(7775),
    [sym_signed_number] = STATE(7794),
    [sym_character] = STATE(7775),
    [sym_string] = STATE(7775),
    [sym_quoted_string] = STATE(7775),
    [sym_boolean] = STATE(7775),
    [sym_unit] = STATE(7775),
    [sym__simple_value_pattern] = STATE(7796),
    [sym_parenthesized_operator] = STATE(7796),
    [sym_module_path] = STATE(20457),
    [sym_constructor_path] = STATE(7796),
    [sym__constructor_name] = STATE(7774),
    [sym_tag] = STATE(7796),
    [aux_sym_expression_item_repeat1] = STATE(10433),
    [aux_sym_let_binding_repeat1] = STATE(2572),
    [sym__lowercase_identifier] = ACTIONS(7159),
    [anon_sym_SEMI_SEMI] = ACTIONS(7093),
    [anon_sym_and] = ACTIONS(7095),
    [anon_sym_EQ] = ACTIONS(7161),
    [anon_sym_TILDE] = ACTIONS(7163),
    [anon_sym_QMARK] = ACTIONS(7163),
    [anon_sym_LPAREN] = ACTIONS(7165),
    [anon_sym_external] = ACTIONS(7095),
    [anon_sym_type] = ACTIONS(7095),
    [anon_sym_LBRACK] = ACTIONS(7167),
    [anon_sym_RBRACK] = ACTIONS(7093),
    [anon_sym_true] = ACTIONS(7169),
    [anon_sym_false] = ACTIONS(7169),
    [anon_sym_COLON2] = ACTIONS(7171),
    [anon_sym_LBRACE] = ACTIONS(7173),
    [anon_sym_exception] = ACTIONS(7095),
    [anon_sym_module] = ACTIONS(7095),
    [anon_sym_open] = ACTIONS(7095),
    [anon_sym_include] = ACTIONS(7095),
    [anon_sym_class] = ACTIONS(7095),
    [anon_sym_val] = ACTIONS(7095),
    [anon_sym_POUND] = ACTIONS(7175),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7177),
    [anon_sym_begin] = ACTIONS(7179),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7093),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7181),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7183),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7093),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7093),
    [aux_sym_number_token1] = ACTIONS(7185),
    [aux_sym_signed_number_token1] = ACTIONS(7187),
    [anon_sym_SQUOTE] = ACTIONS(7189),
    [anon_sym_DQUOTE] = ACTIONS(7191),
    [sym__uppercase_identifier] = ACTIONS(7193),
    [aux_sym_tag_token1] = ACTIONS(7195),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2561] = {
    [sym_parameter] = STATE(7801),
    [sym__class_typed] = STATE(11743),
    [sym__parenthesized_abstract_type] = STATE(7801),
    [sym__simple_pattern] = STATE(7799),
    [sym_typed_pattern] = STATE(7796),
    [sym_polymorphic_variant_pattern] = STATE(7796),
    [sym_record_pattern] = STATE(7796),
    [sym_list_pattern] = STATE(7796),
    [sym_array_pattern] = STATE(7796),
    [sym_local_open_pattern] = STATE(7796),
    [sym_package_pattern] = STATE(7796),
    [sym_parenthesized_pattern] = STATE(7796),
    [sym_attribute] = STATE(2561),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7796),
    [sym_quoted_extension] = STATE(7796),
    [sym__constant] = STATE(7794),
    [sym__signed_constant] = STATE(7796),
    [sym_number] = STATE(7775),
    [sym_signed_number] = STATE(7794),
    [sym_character] = STATE(7775),
    [sym_string] = STATE(7775),
    [sym_quoted_string] = STATE(7775),
    [sym_boolean] = STATE(7775),
    [sym_unit] = STATE(7775),
    [sym__simple_value_pattern] = STATE(7796),
    [sym_parenthesized_operator] = STATE(7796),
    [sym_module_path] = STATE(20457),
    [sym_constructor_path] = STATE(7796),
    [sym__constructor_name] = STATE(7774),
    [sym_tag] = STATE(7796),
    [aux_sym_expression_item_repeat1] = STATE(10544),
    [aux_sym_let_binding_repeat1] = STATE(2594),
    [sym__lowercase_identifier] = ACTIONS(7159),
    [anon_sym_SEMI_SEMI] = ACTIONS(6897),
    [anon_sym_and] = ACTIONS(6899),
    [anon_sym_EQ] = ACTIONS(7197),
    [anon_sym_TILDE] = ACTIONS(7163),
    [anon_sym_QMARK] = ACTIONS(7163),
    [anon_sym_LPAREN] = ACTIONS(7165),
    [anon_sym_external] = ACTIONS(6899),
    [anon_sym_type] = ACTIONS(6899),
    [anon_sym_LBRACK] = ACTIONS(7167),
    [anon_sym_RBRACK] = ACTIONS(6897),
    [anon_sym_true] = ACTIONS(7169),
    [anon_sym_false] = ACTIONS(7169),
    [anon_sym_COLON2] = ACTIONS(7171),
    [anon_sym_LBRACE] = ACTIONS(7173),
    [anon_sym_exception] = ACTIONS(6899),
    [anon_sym_module] = ACTIONS(6899),
    [anon_sym_open] = ACTIONS(6899),
    [anon_sym_include] = ACTIONS(6899),
    [anon_sym_class] = ACTIONS(6899),
    [anon_sym_val] = ACTIONS(6899),
    [anon_sym_POUND] = ACTIONS(7175),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7177),
    [anon_sym_begin] = ACTIONS(7179),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6897),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7181),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7183),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6897),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6897),
    [aux_sym_number_token1] = ACTIONS(7185),
    [aux_sym_signed_number_token1] = ACTIONS(7187),
    [anon_sym_SQUOTE] = ACTIONS(7189),
    [anon_sym_DQUOTE] = ACTIONS(7191),
    [sym__uppercase_identifier] = ACTIONS(7193),
    [aux_sym_tag_token1] = ACTIONS(7195),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2562] = {
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(12978),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2562),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_EQ] = ACTIONS(7149),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_RPAREN] = ACTIONS(7149),
    [anon_sym_COMMA] = ACTIONS(7149),
    [anon_sym_PIPE] = ACTIONS(7149),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_RBRACK] = ACTIONS(7149),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_COLON2] = ACTIONS(7153),
    [anon_sym_DASH_GT] = ACTIONS(7149),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_as] = ACTIONS(7153),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_COLON_COLON] = ACTIONS(7149),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_when] = ACTIONS(7153),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7157),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2563] = {
    [sym_parameter] = STATE(7869),
    [sym__class_typed] = STATE(11768),
    [sym__parenthesized_abstract_type] = STATE(7869),
    [sym__simple_pattern] = STATE(7868),
    [sym_typed_pattern] = STATE(8089),
    [sym_polymorphic_variant_pattern] = STATE(8089),
    [sym_record_pattern] = STATE(8089),
    [sym_list_pattern] = STATE(8089),
    [sym_array_pattern] = STATE(8089),
    [sym_local_open_pattern] = STATE(8089),
    [sym_package_pattern] = STATE(8089),
    [sym_parenthesized_pattern] = STATE(8089),
    [sym_attribute] = STATE(2563),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(8089),
    [sym_quoted_extension] = STATE(8089),
    [sym__constant] = STATE(8037),
    [sym__signed_constant] = STATE(8089),
    [sym_number] = STATE(8039),
    [sym_signed_number] = STATE(8037),
    [sym_character] = STATE(8039),
    [sym_string] = STATE(8039),
    [sym_quoted_string] = STATE(8039),
    [sym_boolean] = STATE(8039),
    [sym_unit] = STATE(8039),
    [sym__simple_value_pattern] = STATE(8089),
    [sym_parenthesized_operator] = STATE(8089),
    [sym_module_path] = STATE(18728),
    [sym_constructor_path] = STATE(8089),
    [sym__constructor_name] = STATE(8040),
    [sym_tag] = STATE(8089),
    [aux_sym_expression_item_repeat1] = STATE(10434),
    [aux_sym_let_binding_repeat1] = STATE(2595),
    [sym__lowercase_identifier] = ACTIONS(7199),
    [anon_sym_SEMI_SEMI] = ACTIONS(7099),
    [anon_sym_and] = ACTIONS(7101),
    [anon_sym_EQ] = ACTIONS(7201),
    [anon_sym_TILDE] = ACTIONS(7203),
    [anon_sym_QMARK] = ACTIONS(7203),
    [anon_sym_LPAREN] = ACTIONS(7205),
    [anon_sym_external] = ACTIONS(7101),
    [anon_sym_type] = ACTIONS(7101),
    [anon_sym_LBRACK] = ACTIONS(7207),
    [anon_sym_true] = ACTIONS(7209),
    [anon_sym_false] = ACTIONS(7209),
    [anon_sym_COLON2] = ACTIONS(7211),
    [anon_sym_LBRACE] = ACTIONS(7213),
    [anon_sym_exception] = ACTIONS(7101),
    [anon_sym_module] = ACTIONS(7101),
    [anon_sym_open] = ACTIONS(7101),
    [anon_sym_include] = ACTIONS(7101),
    [anon_sym_class] = ACTIONS(7101),
    [anon_sym_val] = ACTIONS(7101),
    [anon_sym_end] = ACTIONS(7101),
    [anon_sym_POUND] = ACTIONS(7215),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7217),
    [anon_sym_begin] = ACTIONS(7219),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7099),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7221),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7223),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7099),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7099),
    [aux_sym_number_token1] = ACTIONS(7225),
    [aux_sym_signed_number_token1] = ACTIONS(7227),
    [anon_sym_SQUOTE] = ACTIONS(7229),
    [anon_sym_DQUOTE] = ACTIONS(7231),
    [sym__uppercase_identifier] = ACTIONS(7233),
    [aux_sym_tag_token1] = ACTIONS(7235),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2564] = {
    [sym_parameter] = STATE(7801),
    [sym__class_typed] = STATE(11796),
    [sym__parenthesized_abstract_type] = STATE(7801),
    [sym__simple_pattern] = STATE(7799),
    [sym_typed_pattern] = STATE(7796),
    [sym_polymorphic_variant_pattern] = STATE(7796),
    [sym_record_pattern] = STATE(7796),
    [sym_list_pattern] = STATE(7796),
    [sym_array_pattern] = STATE(7796),
    [sym_local_open_pattern] = STATE(7796),
    [sym_package_pattern] = STATE(7796),
    [sym_parenthesized_pattern] = STATE(7796),
    [sym_attribute] = STATE(2564),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7796),
    [sym_quoted_extension] = STATE(7796),
    [sym__constant] = STATE(7794),
    [sym__signed_constant] = STATE(7796),
    [sym_number] = STATE(7775),
    [sym_signed_number] = STATE(7794),
    [sym_character] = STATE(7775),
    [sym_string] = STATE(7775),
    [sym_quoted_string] = STATE(7775),
    [sym_boolean] = STATE(7775),
    [sym_unit] = STATE(7775),
    [sym__simple_value_pattern] = STATE(7796),
    [sym_parenthesized_operator] = STATE(7796),
    [sym_module_path] = STATE(20457),
    [sym_constructor_path] = STATE(7796),
    [sym__constructor_name] = STATE(7774),
    [sym_tag] = STATE(7796),
    [aux_sym_expression_item_repeat1] = STATE(10542),
    [aux_sym_let_binding_repeat1] = STATE(2567),
    [ts_builtin_sym_end] = ACTIONS(7121),
    [sym__lowercase_identifier] = ACTIONS(7159),
    [anon_sym_SEMI_SEMI] = ACTIONS(7121),
    [anon_sym_and] = ACTIONS(7123),
    [anon_sym_EQ] = ACTIONS(7237),
    [anon_sym_TILDE] = ACTIONS(7163),
    [anon_sym_QMARK] = ACTIONS(7163),
    [anon_sym_LPAREN] = ACTIONS(7165),
    [anon_sym_external] = ACTIONS(7123),
    [anon_sym_type] = ACTIONS(7123),
    [anon_sym_LBRACK] = ACTIONS(7167),
    [anon_sym_true] = ACTIONS(7169),
    [anon_sym_false] = ACTIONS(7169),
    [anon_sym_COLON2] = ACTIONS(7171),
    [anon_sym_LBRACE] = ACTIONS(7173),
    [anon_sym_exception] = ACTIONS(7123),
    [anon_sym_module] = ACTIONS(7123),
    [anon_sym_open] = ACTIONS(7123),
    [anon_sym_include] = ACTIONS(7123),
    [anon_sym_class] = ACTIONS(7123),
    [anon_sym_val] = ACTIONS(7123),
    [anon_sym_POUND] = ACTIONS(7175),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7177),
    [anon_sym_begin] = ACTIONS(7179),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7121),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7181),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7183),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7121),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7121),
    [aux_sym_number_token1] = ACTIONS(7185),
    [aux_sym_signed_number_token1] = ACTIONS(7187),
    [anon_sym_SQUOTE] = ACTIONS(7189),
    [anon_sym_DQUOTE] = ACTIONS(7191),
    [sym__uppercase_identifier] = ACTIONS(7193),
    [aux_sym_tag_token1] = ACTIONS(7195),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2565] = {
    [sym_parameter] = STATE(7869),
    [sym__class_typed] = STATE(11780),
    [sym__parenthesized_abstract_type] = STATE(7869),
    [sym__simple_pattern] = STATE(7868),
    [sym_typed_pattern] = STATE(8089),
    [sym_polymorphic_variant_pattern] = STATE(8089),
    [sym_record_pattern] = STATE(8089),
    [sym_list_pattern] = STATE(8089),
    [sym_array_pattern] = STATE(8089),
    [sym_local_open_pattern] = STATE(8089),
    [sym_package_pattern] = STATE(8089),
    [sym_parenthesized_pattern] = STATE(8089),
    [sym_attribute] = STATE(2565),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(8089),
    [sym_quoted_extension] = STATE(8089),
    [sym__constant] = STATE(8037),
    [sym__signed_constant] = STATE(8089),
    [sym_number] = STATE(8039),
    [sym_signed_number] = STATE(8037),
    [sym_character] = STATE(8039),
    [sym_string] = STATE(8039),
    [sym_quoted_string] = STATE(8039),
    [sym_boolean] = STATE(8039),
    [sym_unit] = STATE(8039),
    [sym__simple_value_pattern] = STATE(8089),
    [sym_parenthesized_operator] = STATE(8089),
    [sym_module_path] = STATE(18728),
    [sym_constructor_path] = STATE(8089),
    [sym__constructor_name] = STATE(8040),
    [sym_tag] = STATE(8089),
    [aux_sym_expression_item_repeat1] = STATE(10705),
    [aux_sym_let_binding_repeat1] = STATE(2595),
    [sym__lowercase_identifier] = ACTIONS(7199),
    [anon_sym_SEMI_SEMI] = ACTIONS(7115),
    [anon_sym_and] = ACTIONS(7117),
    [anon_sym_EQ] = ACTIONS(7239),
    [anon_sym_TILDE] = ACTIONS(7203),
    [anon_sym_QMARK] = ACTIONS(7203),
    [anon_sym_LPAREN] = ACTIONS(7205),
    [anon_sym_external] = ACTIONS(7117),
    [anon_sym_type] = ACTIONS(7117),
    [anon_sym_LBRACK] = ACTIONS(7207),
    [anon_sym_true] = ACTIONS(7209),
    [anon_sym_false] = ACTIONS(7209),
    [anon_sym_COLON2] = ACTIONS(7211),
    [anon_sym_LBRACE] = ACTIONS(7213),
    [anon_sym_exception] = ACTIONS(7117),
    [anon_sym_module] = ACTIONS(7117),
    [anon_sym_open] = ACTIONS(7117),
    [anon_sym_include] = ACTIONS(7117),
    [anon_sym_class] = ACTIONS(7117),
    [anon_sym_val] = ACTIONS(7117),
    [anon_sym_end] = ACTIONS(7117),
    [anon_sym_POUND] = ACTIONS(7215),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7217),
    [anon_sym_begin] = ACTIONS(7219),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7115),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7221),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7223),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7115),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7115),
    [aux_sym_number_token1] = ACTIONS(7225),
    [aux_sym_signed_number_token1] = ACTIONS(7227),
    [anon_sym_SQUOTE] = ACTIONS(7229),
    [anon_sym_DQUOTE] = ACTIONS(7231),
    [sym__uppercase_identifier] = ACTIONS(7233),
    [aux_sym_tag_token1] = ACTIONS(7235),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2566] = {
    [sym_parameter] = STATE(7801),
    [sym__class_typed] = STATE(11738),
    [sym__parenthesized_abstract_type] = STATE(7801),
    [sym__simple_pattern] = STATE(7799),
    [sym_typed_pattern] = STATE(7796),
    [sym_polymorphic_variant_pattern] = STATE(7796),
    [sym_record_pattern] = STATE(7796),
    [sym_list_pattern] = STATE(7796),
    [sym_array_pattern] = STATE(7796),
    [sym_local_open_pattern] = STATE(7796),
    [sym_package_pattern] = STATE(7796),
    [sym_parenthesized_pattern] = STATE(7796),
    [sym_attribute] = STATE(2566),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7796),
    [sym_quoted_extension] = STATE(7796),
    [sym__constant] = STATE(7794),
    [sym__signed_constant] = STATE(7796),
    [sym_number] = STATE(7775),
    [sym_signed_number] = STATE(7794),
    [sym_character] = STATE(7775),
    [sym_string] = STATE(7775),
    [sym_quoted_string] = STATE(7775),
    [sym_boolean] = STATE(7775),
    [sym_unit] = STATE(7775),
    [sym__simple_value_pattern] = STATE(7796),
    [sym_parenthesized_operator] = STATE(7796),
    [sym_module_path] = STATE(20457),
    [sym_constructor_path] = STATE(7796),
    [sym__constructor_name] = STATE(7774),
    [sym_tag] = STATE(7796),
    [aux_sym_expression_item_repeat1] = STATE(10538),
    [aux_sym_let_binding_repeat1] = STATE(2582),
    [sym__lowercase_identifier] = ACTIONS(7159),
    [anon_sym_SEMI_SEMI] = ACTIONS(7021),
    [anon_sym_and] = ACTIONS(7023),
    [anon_sym_EQ] = ACTIONS(7241),
    [anon_sym_TILDE] = ACTIONS(7163),
    [anon_sym_QMARK] = ACTIONS(7163),
    [anon_sym_LPAREN] = ACTIONS(7165),
    [anon_sym_external] = ACTIONS(7023),
    [anon_sym_type] = ACTIONS(7023),
    [anon_sym_LBRACK] = ACTIONS(7167),
    [anon_sym_RBRACK] = ACTIONS(7021),
    [anon_sym_true] = ACTIONS(7169),
    [anon_sym_false] = ACTIONS(7169),
    [anon_sym_COLON2] = ACTIONS(7171),
    [anon_sym_LBRACE] = ACTIONS(7173),
    [anon_sym_exception] = ACTIONS(7023),
    [anon_sym_module] = ACTIONS(7023),
    [anon_sym_open] = ACTIONS(7023),
    [anon_sym_include] = ACTIONS(7023),
    [anon_sym_class] = ACTIONS(7023),
    [anon_sym_val] = ACTIONS(7023),
    [anon_sym_POUND] = ACTIONS(7175),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7177),
    [anon_sym_begin] = ACTIONS(7179),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7021),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7181),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7183),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7021),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7021),
    [aux_sym_number_token1] = ACTIONS(7185),
    [aux_sym_signed_number_token1] = ACTIONS(7187),
    [anon_sym_SQUOTE] = ACTIONS(7189),
    [anon_sym_DQUOTE] = ACTIONS(7191),
    [sym__uppercase_identifier] = ACTIONS(7193),
    [aux_sym_tag_token1] = ACTIONS(7195),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2567] = {
    [sym_parameter] = STATE(7801),
    [sym__class_typed] = STATE(11877),
    [sym__parenthesized_abstract_type] = STATE(7801),
    [sym__simple_pattern] = STATE(7799),
    [sym_typed_pattern] = STATE(7796),
    [sym_polymorphic_variant_pattern] = STATE(7796),
    [sym_record_pattern] = STATE(7796),
    [sym_list_pattern] = STATE(7796),
    [sym_array_pattern] = STATE(7796),
    [sym_local_open_pattern] = STATE(7796),
    [sym_package_pattern] = STATE(7796),
    [sym_parenthesized_pattern] = STATE(7796),
    [sym_attribute] = STATE(2567),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7796),
    [sym_quoted_extension] = STATE(7796),
    [sym__constant] = STATE(7794),
    [sym__signed_constant] = STATE(7796),
    [sym_number] = STATE(7775),
    [sym_signed_number] = STATE(7794),
    [sym_character] = STATE(7775),
    [sym_string] = STATE(7775),
    [sym_quoted_string] = STATE(7775),
    [sym_boolean] = STATE(7775),
    [sym_unit] = STATE(7775),
    [sym__simple_value_pattern] = STATE(7796),
    [sym_parenthesized_operator] = STATE(7796),
    [sym_module_path] = STATE(20457),
    [sym_constructor_path] = STATE(7796),
    [sym__constructor_name] = STATE(7774),
    [sym_tag] = STATE(7796),
    [aux_sym_expression_item_repeat1] = STATE(10705),
    [aux_sym_let_binding_repeat1] = STATE(2594),
    [ts_builtin_sym_end] = ACTIONS(7115),
    [sym__lowercase_identifier] = ACTIONS(7159),
    [anon_sym_SEMI_SEMI] = ACTIONS(7115),
    [anon_sym_and] = ACTIONS(7117),
    [anon_sym_EQ] = ACTIONS(7243),
    [anon_sym_TILDE] = ACTIONS(7163),
    [anon_sym_QMARK] = ACTIONS(7163),
    [anon_sym_LPAREN] = ACTIONS(7165),
    [anon_sym_external] = ACTIONS(7117),
    [anon_sym_type] = ACTIONS(7117),
    [anon_sym_LBRACK] = ACTIONS(7167),
    [anon_sym_true] = ACTIONS(7169),
    [anon_sym_false] = ACTIONS(7169),
    [anon_sym_COLON2] = ACTIONS(7171),
    [anon_sym_LBRACE] = ACTIONS(7173),
    [anon_sym_exception] = ACTIONS(7117),
    [anon_sym_module] = ACTIONS(7117),
    [anon_sym_open] = ACTIONS(7117),
    [anon_sym_include] = ACTIONS(7117),
    [anon_sym_class] = ACTIONS(7117),
    [anon_sym_val] = ACTIONS(7117),
    [anon_sym_POUND] = ACTIONS(7175),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7177),
    [anon_sym_begin] = ACTIONS(7179),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7115),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7181),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7183),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7115),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7115),
    [aux_sym_number_token1] = ACTIONS(7185),
    [aux_sym_signed_number_token1] = ACTIONS(7187),
    [anon_sym_SQUOTE] = ACTIONS(7189),
    [anon_sym_DQUOTE] = ACTIONS(7191),
    [sym__uppercase_identifier] = ACTIONS(7193),
    [aux_sym_tag_token1] = ACTIONS(7195),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2568] = {
    [sym_parameter] = STATE(7869),
    [sym__class_typed] = STATE(11774),
    [sym__parenthesized_abstract_type] = STATE(7869),
    [sym__simple_pattern] = STATE(7868),
    [sym_typed_pattern] = STATE(8089),
    [sym_polymorphic_variant_pattern] = STATE(8089),
    [sym_record_pattern] = STATE(8089),
    [sym_list_pattern] = STATE(8089),
    [sym_array_pattern] = STATE(8089),
    [sym_local_open_pattern] = STATE(8089),
    [sym_package_pattern] = STATE(8089),
    [sym_parenthesized_pattern] = STATE(8089),
    [sym_attribute] = STATE(2568),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(8089),
    [sym_quoted_extension] = STATE(8089),
    [sym__constant] = STATE(8037),
    [sym__signed_constant] = STATE(8089),
    [sym_number] = STATE(8039),
    [sym_signed_number] = STATE(8037),
    [sym_character] = STATE(8039),
    [sym_string] = STATE(8039),
    [sym_quoted_string] = STATE(8039),
    [sym_boolean] = STATE(8039),
    [sym_unit] = STATE(8039),
    [sym__simple_value_pattern] = STATE(8089),
    [sym_parenthesized_operator] = STATE(8089),
    [sym_module_path] = STATE(18728),
    [sym_constructor_path] = STATE(8089),
    [sym__constructor_name] = STATE(8040),
    [sym_tag] = STATE(8089),
    [aux_sym_expression_item_repeat1] = STATE(10495),
    [aux_sym_let_binding_repeat1] = STATE(2595),
    [sym__lowercase_identifier] = ACTIONS(7199),
    [anon_sym_SEMI_SEMI] = ACTIONS(7109),
    [anon_sym_and] = ACTIONS(7111),
    [anon_sym_EQ] = ACTIONS(7245),
    [anon_sym_TILDE] = ACTIONS(7203),
    [anon_sym_QMARK] = ACTIONS(7203),
    [anon_sym_LPAREN] = ACTIONS(7205),
    [anon_sym_external] = ACTIONS(7111),
    [anon_sym_type] = ACTIONS(7111),
    [anon_sym_LBRACK] = ACTIONS(7207),
    [anon_sym_true] = ACTIONS(7209),
    [anon_sym_false] = ACTIONS(7209),
    [anon_sym_COLON2] = ACTIONS(7211),
    [anon_sym_LBRACE] = ACTIONS(7213),
    [anon_sym_exception] = ACTIONS(7111),
    [anon_sym_module] = ACTIONS(7111),
    [anon_sym_open] = ACTIONS(7111),
    [anon_sym_include] = ACTIONS(7111),
    [anon_sym_class] = ACTIONS(7111),
    [anon_sym_val] = ACTIONS(7111),
    [anon_sym_end] = ACTIONS(7111),
    [anon_sym_POUND] = ACTIONS(7215),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7217),
    [anon_sym_begin] = ACTIONS(7219),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7109),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7221),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7223),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7109),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7109),
    [aux_sym_number_token1] = ACTIONS(7225),
    [aux_sym_signed_number_token1] = ACTIONS(7227),
    [anon_sym_SQUOTE] = ACTIONS(7229),
    [anon_sym_DQUOTE] = ACTIONS(7231),
    [sym__uppercase_identifier] = ACTIONS(7233),
    [aux_sym_tag_token1] = ACTIONS(7235),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2569] = {
    [sym_parameter] = STATE(7869),
    [sym__class_typed] = STATE(11781),
    [sym__parenthesized_abstract_type] = STATE(7869),
    [sym__simple_pattern] = STATE(7868),
    [sym_typed_pattern] = STATE(8089),
    [sym_polymorphic_variant_pattern] = STATE(8089),
    [sym_record_pattern] = STATE(8089),
    [sym_list_pattern] = STATE(8089),
    [sym_array_pattern] = STATE(8089),
    [sym_local_open_pattern] = STATE(8089),
    [sym_package_pattern] = STATE(8089),
    [sym_parenthesized_pattern] = STATE(8089),
    [sym_attribute] = STATE(2569),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(8089),
    [sym_quoted_extension] = STATE(8089),
    [sym__constant] = STATE(8037),
    [sym__signed_constant] = STATE(8089),
    [sym_number] = STATE(8039),
    [sym_signed_number] = STATE(8037),
    [sym_character] = STATE(8039),
    [sym_string] = STATE(8039),
    [sym_quoted_string] = STATE(8039),
    [sym_boolean] = STATE(8039),
    [sym_unit] = STATE(8039),
    [sym__simple_value_pattern] = STATE(8089),
    [sym_parenthesized_operator] = STATE(8089),
    [sym_module_path] = STATE(18728),
    [sym_constructor_path] = STATE(8089),
    [sym__constructor_name] = STATE(8040),
    [sym_tag] = STATE(8089),
    [aux_sym_expression_item_repeat1] = STATE(10538),
    [aux_sym_let_binding_repeat1] = STATE(2568),
    [sym__lowercase_identifier] = ACTIONS(7199),
    [anon_sym_SEMI_SEMI] = ACTIONS(7021),
    [anon_sym_and] = ACTIONS(7023),
    [anon_sym_EQ] = ACTIONS(7247),
    [anon_sym_TILDE] = ACTIONS(7203),
    [anon_sym_QMARK] = ACTIONS(7203),
    [anon_sym_LPAREN] = ACTIONS(7205),
    [anon_sym_external] = ACTIONS(7023),
    [anon_sym_type] = ACTIONS(7023),
    [anon_sym_LBRACK] = ACTIONS(7207),
    [anon_sym_true] = ACTIONS(7209),
    [anon_sym_false] = ACTIONS(7209),
    [anon_sym_COLON2] = ACTIONS(7211),
    [anon_sym_LBRACE] = ACTIONS(7213),
    [anon_sym_exception] = ACTIONS(7023),
    [anon_sym_module] = ACTIONS(7023),
    [anon_sym_open] = ACTIONS(7023),
    [anon_sym_include] = ACTIONS(7023),
    [anon_sym_class] = ACTIONS(7023),
    [anon_sym_val] = ACTIONS(7023),
    [anon_sym_end] = ACTIONS(7023),
    [anon_sym_POUND] = ACTIONS(7215),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7217),
    [anon_sym_begin] = ACTIONS(7219),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7021),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7221),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7223),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7021),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7021),
    [aux_sym_number_token1] = ACTIONS(7225),
    [aux_sym_signed_number_token1] = ACTIONS(7227),
    [anon_sym_SQUOTE] = ACTIONS(7229),
    [anon_sym_DQUOTE] = ACTIONS(7231),
    [sym__uppercase_identifier] = ACTIONS(7233),
    [aux_sym_tag_token1] = ACTIONS(7235),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2570] = {
    [sym_parameter] = STATE(7801),
    [sym__class_typed] = STATE(11859),
    [sym__parenthesized_abstract_type] = STATE(7801),
    [sym__simple_pattern] = STATE(7799),
    [sym_typed_pattern] = STATE(7796),
    [sym_polymorphic_variant_pattern] = STATE(7796),
    [sym_record_pattern] = STATE(7796),
    [sym_list_pattern] = STATE(7796),
    [sym_array_pattern] = STATE(7796),
    [sym_local_open_pattern] = STATE(7796),
    [sym_package_pattern] = STATE(7796),
    [sym_parenthesized_pattern] = STATE(7796),
    [sym_attribute] = STATE(2570),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7796),
    [sym_quoted_extension] = STATE(7796),
    [sym__constant] = STATE(7794),
    [sym__signed_constant] = STATE(7796),
    [sym_number] = STATE(7775),
    [sym_signed_number] = STATE(7794),
    [sym_character] = STATE(7775),
    [sym_string] = STATE(7775),
    [sym_quoted_string] = STATE(7775),
    [sym_boolean] = STATE(7775),
    [sym_unit] = STATE(7775),
    [sym__simple_value_pattern] = STATE(7796),
    [sym_parenthesized_operator] = STATE(7796),
    [sym_module_path] = STATE(20457),
    [sym_constructor_path] = STATE(7796),
    [sym__constructor_name] = STATE(7774),
    [sym_tag] = STATE(7796),
    [aux_sym_expression_item_repeat1] = STATE(10536),
    [aux_sym_let_binding_repeat1] = STATE(2590),
    [ts_builtin_sym_end] = ACTIONS(7087),
    [sym__lowercase_identifier] = ACTIONS(7159),
    [anon_sym_SEMI_SEMI] = ACTIONS(7087),
    [anon_sym_and] = ACTIONS(7089),
    [anon_sym_EQ] = ACTIONS(7249),
    [anon_sym_TILDE] = ACTIONS(7163),
    [anon_sym_QMARK] = ACTIONS(7163),
    [anon_sym_LPAREN] = ACTIONS(7165),
    [anon_sym_external] = ACTIONS(7089),
    [anon_sym_type] = ACTIONS(7089),
    [anon_sym_LBRACK] = ACTIONS(7167),
    [anon_sym_true] = ACTIONS(7169),
    [anon_sym_false] = ACTIONS(7169),
    [anon_sym_COLON2] = ACTIONS(7171),
    [anon_sym_LBRACE] = ACTIONS(7173),
    [anon_sym_exception] = ACTIONS(7089),
    [anon_sym_module] = ACTIONS(7089),
    [anon_sym_open] = ACTIONS(7089),
    [anon_sym_include] = ACTIONS(7089),
    [anon_sym_class] = ACTIONS(7089),
    [anon_sym_val] = ACTIONS(7089),
    [anon_sym_POUND] = ACTIONS(7175),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7177),
    [anon_sym_begin] = ACTIONS(7179),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7087),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7181),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7183),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7087),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7087),
    [aux_sym_number_token1] = ACTIONS(7185),
    [aux_sym_signed_number_token1] = ACTIONS(7187),
    [anon_sym_SQUOTE] = ACTIONS(7189),
    [anon_sym_DQUOTE] = ACTIONS(7191),
    [sym__uppercase_identifier] = ACTIONS(7193),
    [aux_sym_tag_token1] = ACTIONS(7195),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2571] = {
    [sym_parameter] = STATE(7869),
    [sym__class_typed] = STATE(11767),
    [sym__parenthesized_abstract_type] = STATE(7869),
    [sym__simple_pattern] = STATE(7868),
    [sym_typed_pattern] = STATE(8089),
    [sym_polymorphic_variant_pattern] = STATE(8089),
    [sym_record_pattern] = STATE(8089),
    [sym_list_pattern] = STATE(8089),
    [sym_array_pattern] = STATE(8089),
    [sym_local_open_pattern] = STATE(8089),
    [sym_package_pattern] = STATE(8089),
    [sym_parenthesized_pattern] = STATE(8089),
    [sym_attribute] = STATE(2571),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(8089),
    [sym_quoted_extension] = STATE(8089),
    [sym__constant] = STATE(8037),
    [sym__signed_constant] = STATE(8089),
    [sym_number] = STATE(8039),
    [sym_signed_number] = STATE(8037),
    [sym_character] = STATE(8039),
    [sym_string] = STATE(8039),
    [sym_quoted_string] = STATE(8039),
    [sym_boolean] = STATE(8039),
    [sym_unit] = STATE(8039),
    [sym__simple_value_pattern] = STATE(8089),
    [sym_parenthesized_operator] = STATE(8089),
    [sym_module_path] = STATE(18728),
    [sym_constructor_path] = STATE(8089),
    [sym__constructor_name] = STATE(8040),
    [sym_tag] = STATE(8089),
    [aux_sym_expression_item_repeat1] = STATE(10433),
    [aux_sym_let_binding_repeat1] = STATE(2581),
    [sym__lowercase_identifier] = ACTIONS(7199),
    [anon_sym_SEMI_SEMI] = ACTIONS(7093),
    [anon_sym_and] = ACTIONS(7095),
    [anon_sym_EQ] = ACTIONS(7251),
    [anon_sym_TILDE] = ACTIONS(7203),
    [anon_sym_QMARK] = ACTIONS(7203),
    [anon_sym_LPAREN] = ACTIONS(7205),
    [anon_sym_external] = ACTIONS(7095),
    [anon_sym_type] = ACTIONS(7095),
    [anon_sym_LBRACK] = ACTIONS(7207),
    [anon_sym_true] = ACTIONS(7209),
    [anon_sym_false] = ACTIONS(7209),
    [anon_sym_COLON2] = ACTIONS(7211),
    [anon_sym_LBRACE] = ACTIONS(7213),
    [anon_sym_exception] = ACTIONS(7095),
    [anon_sym_module] = ACTIONS(7095),
    [anon_sym_open] = ACTIONS(7095),
    [anon_sym_include] = ACTIONS(7095),
    [anon_sym_class] = ACTIONS(7095),
    [anon_sym_val] = ACTIONS(7095),
    [anon_sym_end] = ACTIONS(7095),
    [anon_sym_POUND] = ACTIONS(7215),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7217),
    [anon_sym_begin] = ACTIONS(7219),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7093),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7221),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7223),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7093),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7093),
    [aux_sym_number_token1] = ACTIONS(7225),
    [aux_sym_signed_number_token1] = ACTIONS(7227),
    [anon_sym_SQUOTE] = ACTIONS(7229),
    [anon_sym_DQUOTE] = ACTIONS(7231),
    [sym__uppercase_identifier] = ACTIONS(7233),
    [aux_sym_tag_token1] = ACTIONS(7235),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2572] = {
    [sym_parameter] = STATE(7801),
    [sym__class_typed] = STATE(11750),
    [sym__parenthesized_abstract_type] = STATE(7801),
    [sym__simple_pattern] = STATE(7799),
    [sym_typed_pattern] = STATE(7796),
    [sym_polymorphic_variant_pattern] = STATE(7796),
    [sym_record_pattern] = STATE(7796),
    [sym_list_pattern] = STATE(7796),
    [sym_array_pattern] = STATE(7796),
    [sym_local_open_pattern] = STATE(7796),
    [sym_package_pattern] = STATE(7796),
    [sym_parenthesized_pattern] = STATE(7796),
    [sym_attribute] = STATE(2572),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7796),
    [sym_quoted_extension] = STATE(7796),
    [sym__constant] = STATE(7794),
    [sym__signed_constant] = STATE(7796),
    [sym_number] = STATE(7775),
    [sym_signed_number] = STATE(7794),
    [sym_character] = STATE(7775),
    [sym_string] = STATE(7775),
    [sym_quoted_string] = STATE(7775),
    [sym_boolean] = STATE(7775),
    [sym_unit] = STATE(7775),
    [sym__simple_value_pattern] = STATE(7796),
    [sym_parenthesized_operator] = STATE(7796),
    [sym_module_path] = STATE(20457),
    [sym_constructor_path] = STATE(7796),
    [sym__constructor_name] = STATE(7774),
    [sym_tag] = STATE(7796),
    [aux_sym_expression_item_repeat1] = STATE(10405),
    [aux_sym_let_binding_repeat1] = STATE(2594),
    [sym__lowercase_identifier] = ACTIONS(7159),
    [anon_sym_SEMI_SEMI] = ACTIONS(7133),
    [anon_sym_and] = ACTIONS(7135),
    [anon_sym_EQ] = ACTIONS(7253),
    [anon_sym_TILDE] = ACTIONS(7163),
    [anon_sym_QMARK] = ACTIONS(7163),
    [anon_sym_LPAREN] = ACTIONS(7165),
    [anon_sym_external] = ACTIONS(7135),
    [anon_sym_type] = ACTIONS(7135),
    [anon_sym_LBRACK] = ACTIONS(7167),
    [anon_sym_RBRACK] = ACTIONS(7133),
    [anon_sym_true] = ACTIONS(7169),
    [anon_sym_false] = ACTIONS(7169),
    [anon_sym_COLON2] = ACTIONS(7171),
    [anon_sym_LBRACE] = ACTIONS(7173),
    [anon_sym_exception] = ACTIONS(7135),
    [anon_sym_module] = ACTIONS(7135),
    [anon_sym_open] = ACTIONS(7135),
    [anon_sym_include] = ACTIONS(7135),
    [anon_sym_class] = ACTIONS(7135),
    [anon_sym_val] = ACTIONS(7135),
    [anon_sym_POUND] = ACTIONS(7175),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7177),
    [anon_sym_begin] = ACTIONS(7179),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7133),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7181),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7183),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7133),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7133),
    [aux_sym_number_token1] = ACTIONS(7185),
    [aux_sym_signed_number_token1] = ACTIONS(7187),
    [anon_sym_SQUOTE] = ACTIONS(7189),
    [anon_sym_DQUOTE] = ACTIONS(7191),
    [sym__uppercase_identifier] = ACTIONS(7193),
    [aux_sym_tag_token1] = ACTIONS(7195),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2573] = {
    [sym_parameter] = STATE(7801),
    [sym__class_typed] = STATE(11745),
    [sym__parenthesized_abstract_type] = STATE(7801),
    [sym__simple_pattern] = STATE(7799),
    [sym_typed_pattern] = STATE(7796),
    [sym_polymorphic_variant_pattern] = STATE(7796),
    [sym_record_pattern] = STATE(7796),
    [sym_list_pattern] = STATE(7796),
    [sym_array_pattern] = STATE(7796),
    [sym_local_open_pattern] = STATE(7796),
    [sym_package_pattern] = STATE(7796),
    [sym_parenthesized_pattern] = STATE(7796),
    [sym_attribute] = STATE(2573),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7796),
    [sym_quoted_extension] = STATE(7796),
    [sym__constant] = STATE(7794),
    [sym__signed_constant] = STATE(7796),
    [sym_number] = STATE(7775),
    [sym_signed_number] = STATE(7794),
    [sym_character] = STATE(7775),
    [sym_string] = STATE(7775),
    [sym_quoted_string] = STATE(7775),
    [sym_boolean] = STATE(7775),
    [sym_unit] = STATE(7775),
    [sym__simple_value_pattern] = STATE(7796),
    [sym_parenthesized_operator] = STATE(7796),
    [sym_module_path] = STATE(20457),
    [sym_constructor_path] = STATE(7796),
    [sym__constructor_name] = STATE(7774),
    [sym_tag] = STATE(7796),
    [aux_sym_expression_item_repeat1] = STATE(10434),
    [aux_sym_let_binding_repeat1] = STATE(2594),
    [sym__lowercase_identifier] = ACTIONS(7159),
    [anon_sym_SEMI_SEMI] = ACTIONS(7099),
    [anon_sym_and] = ACTIONS(7101),
    [anon_sym_EQ] = ACTIONS(7255),
    [anon_sym_TILDE] = ACTIONS(7163),
    [anon_sym_QMARK] = ACTIONS(7163),
    [anon_sym_LPAREN] = ACTIONS(7165),
    [anon_sym_external] = ACTIONS(7101),
    [anon_sym_type] = ACTIONS(7101),
    [anon_sym_LBRACK] = ACTIONS(7167),
    [anon_sym_RBRACK] = ACTIONS(7099),
    [anon_sym_true] = ACTIONS(7169),
    [anon_sym_false] = ACTIONS(7169),
    [anon_sym_COLON2] = ACTIONS(7171),
    [anon_sym_LBRACE] = ACTIONS(7173),
    [anon_sym_exception] = ACTIONS(7101),
    [anon_sym_module] = ACTIONS(7101),
    [anon_sym_open] = ACTIONS(7101),
    [anon_sym_include] = ACTIONS(7101),
    [anon_sym_class] = ACTIONS(7101),
    [anon_sym_val] = ACTIONS(7101),
    [anon_sym_POUND] = ACTIONS(7175),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7177),
    [anon_sym_begin] = ACTIONS(7179),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7099),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7181),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7183),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7099),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7099),
    [aux_sym_number_token1] = ACTIONS(7185),
    [aux_sym_signed_number_token1] = ACTIONS(7187),
    [anon_sym_SQUOTE] = ACTIONS(7189),
    [anon_sym_DQUOTE] = ACTIONS(7191),
    [sym__uppercase_identifier] = ACTIONS(7193),
    [aux_sym_tag_token1] = ACTIONS(7195),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2574] = {
    [sym_parameter] = STATE(7869),
    [sym__class_typed] = STATE(11784),
    [sym__parenthesized_abstract_type] = STATE(7869),
    [sym__simple_pattern] = STATE(7868),
    [sym_typed_pattern] = STATE(8089),
    [sym_polymorphic_variant_pattern] = STATE(8089),
    [sym_record_pattern] = STATE(8089),
    [sym_list_pattern] = STATE(8089),
    [sym_array_pattern] = STATE(8089),
    [sym_local_open_pattern] = STATE(8089),
    [sym_package_pattern] = STATE(8089),
    [sym_parenthesized_pattern] = STATE(8089),
    [sym_attribute] = STATE(2574),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(8089),
    [sym_quoted_extension] = STATE(8089),
    [sym__constant] = STATE(8037),
    [sym__signed_constant] = STATE(8089),
    [sym_number] = STATE(8039),
    [sym_signed_number] = STATE(8037),
    [sym_character] = STATE(8039),
    [sym_string] = STATE(8039),
    [sym_quoted_string] = STATE(8039),
    [sym_boolean] = STATE(8039),
    [sym_unit] = STATE(8039),
    [sym__simple_value_pattern] = STATE(8089),
    [sym_parenthesized_operator] = STATE(8089),
    [sym_module_path] = STATE(18728),
    [sym_constructor_path] = STATE(8089),
    [sym__constructor_name] = STATE(8040),
    [sym_tag] = STATE(8089),
    [aux_sym_expression_item_repeat1] = STATE(10542),
    [aux_sym_let_binding_repeat1] = STATE(2565),
    [sym__lowercase_identifier] = ACTIONS(7199),
    [anon_sym_SEMI_SEMI] = ACTIONS(7121),
    [anon_sym_and] = ACTIONS(7123),
    [anon_sym_EQ] = ACTIONS(7257),
    [anon_sym_TILDE] = ACTIONS(7203),
    [anon_sym_QMARK] = ACTIONS(7203),
    [anon_sym_LPAREN] = ACTIONS(7205),
    [anon_sym_external] = ACTIONS(7123),
    [anon_sym_type] = ACTIONS(7123),
    [anon_sym_LBRACK] = ACTIONS(7207),
    [anon_sym_true] = ACTIONS(7209),
    [anon_sym_false] = ACTIONS(7209),
    [anon_sym_COLON2] = ACTIONS(7211),
    [anon_sym_LBRACE] = ACTIONS(7213),
    [anon_sym_exception] = ACTIONS(7123),
    [anon_sym_module] = ACTIONS(7123),
    [anon_sym_open] = ACTIONS(7123),
    [anon_sym_include] = ACTIONS(7123),
    [anon_sym_class] = ACTIONS(7123),
    [anon_sym_val] = ACTIONS(7123),
    [anon_sym_end] = ACTIONS(7123),
    [anon_sym_POUND] = ACTIONS(7215),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7217),
    [anon_sym_begin] = ACTIONS(7219),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7121),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7221),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7223),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7121),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7121),
    [aux_sym_number_token1] = ACTIONS(7225),
    [aux_sym_signed_number_token1] = ACTIONS(7227),
    [anon_sym_SQUOTE] = ACTIONS(7229),
    [anon_sym_DQUOTE] = ACTIONS(7231),
    [sym__uppercase_identifier] = ACTIONS(7233),
    [aux_sym_tag_token1] = ACTIONS(7235),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2575] = {
    [sym_parameter] = STATE(7801),
    [sym__class_typed] = STATE(11868),
    [sym__parenthesized_abstract_type] = STATE(7801),
    [sym__simple_pattern] = STATE(7799),
    [sym_typed_pattern] = STATE(7796),
    [sym_polymorphic_variant_pattern] = STATE(7796),
    [sym_record_pattern] = STATE(7796),
    [sym_list_pattern] = STATE(7796),
    [sym_array_pattern] = STATE(7796),
    [sym_local_open_pattern] = STATE(7796),
    [sym_package_pattern] = STATE(7796),
    [sym_parenthesized_pattern] = STATE(7796),
    [sym_attribute] = STATE(2575),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7796),
    [sym_quoted_extension] = STATE(7796),
    [sym__constant] = STATE(7794),
    [sym__signed_constant] = STATE(7796),
    [sym_number] = STATE(7775),
    [sym_signed_number] = STATE(7794),
    [sym_character] = STATE(7775),
    [sym_string] = STATE(7775),
    [sym_quoted_string] = STATE(7775),
    [sym_boolean] = STATE(7775),
    [sym_unit] = STATE(7775),
    [sym__simple_value_pattern] = STATE(7796),
    [sym_parenthesized_operator] = STATE(7796),
    [sym_module_path] = STATE(20457),
    [sym_constructor_path] = STATE(7796),
    [sym__constructor_name] = STATE(7774),
    [sym_tag] = STATE(7796),
    [aux_sym_expression_item_repeat1] = STATE(10405),
    [aux_sym_let_binding_repeat1] = STATE(2594),
    [ts_builtin_sym_end] = ACTIONS(7133),
    [sym__lowercase_identifier] = ACTIONS(7159),
    [anon_sym_SEMI_SEMI] = ACTIONS(7133),
    [anon_sym_and] = ACTIONS(7135),
    [anon_sym_EQ] = ACTIONS(7259),
    [anon_sym_TILDE] = ACTIONS(7163),
    [anon_sym_QMARK] = ACTIONS(7163),
    [anon_sym_LPAREN] = ACTIONS(7165),
    [anon_sym_external] = ACTIONS(7135),
    [anon_sym_type] = ACTIONS(7135),
    [anon_sym_LBRACK] = ACTIONS(7167),
    [anon_sym_true] = ACTIONS(7169),
    [anon_sym_false] = ACTIONS(7169),
    [anon_sym_COLON2] = ACTIONS(7171),
    [anon_sym_LBRACE] = ACTIONS(7173),
    [anon_sym_exception] = ACTIONS(7135),
    [anon_sym_module] = ACTIONS(7135),
    [anon_sym_open] = ACTIONS(7135),
    [anon_sym_include] = ACTIONS(7135),
    [anon_sym_class] = ACTIONS(7135),
    [anon_sym_val] = ACTIONS(7135),
    [anon_sym_POUND] = ACTIONS(7175),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7177),
    [anon_sym_begin] = ACTIONS(7179),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7133),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7181),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7183),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7133),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7133),
    [aux_sym_number_token1] = ACTIONS(7185),
    [aux_sym_signed_number_token1] = ACTIONS(7187),
    [anon_sym_SQUOTE] = ACTIONS(7189),
    [anon_sym_DQUOTE] = ACTIONS(7191),
    [sym__uppercase_identifier] = ACTIONS(7193),
    [aux_sym_tag_token1] = ACTIONS(7195),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2576] = {
    [sym_parameter] = STATE(7801),
    [sym__class_typed] = STATE(11744),
    [sym__parenthesized_abstract_type] = STATE(7801),
    [sym__simple_pattern] = STATE(7799),
    [sym_typed_pattern] = STATE(7796),
    [sym_polymorphic_variant_pattern] = STATE(7796),
    [sym_record_pattern] = STATE(7796),
    [sym_list_pattern] = STATE(7796),
    [sym_array_pattern] = STATE(7796),
    [sym_local_open_pattern] = STATE(7796),
    [sym_package_pattern] = STATE(7796),
    [sym_parenthesized_pattern] = STATE(7796),
    [sym_attribute] = STATE(2576),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7796),
    [sym_quoted_extension] = STATE(7796),
    [sym__constant] = STATE(7794),
    [sym__signed_constant] = STATE(7796),
    [sym_number] = STATE(7775),
    [sym_signed_number] = STATE(7794),
    [sym_character] = STATE(7775),
    [sym_string] = STATE(7775),
    [sym_quoted_string] = STATE(7775),
    [sym_boolean] = STATE(7775),
    [sym_unit] = STATE(7775),
    [sym__simple_value_pattern] = STATE(7796),
    [sym_parenthesized_operator] = STATE(7796),
    [sym_module_path] = STATE(20457),
    [sym_constructor_path] = STATE(7796),
    [sym__constructor_name] = STATE(7774),
    [sym_tag] = STATE(7796),
    [aux_sym_expression_item_repeat1] = STATE(10536),
    [aux_sym_let_binding_repeat1] = STATE(2573),
    [sym__lowercase_identifier] = ACTIONS(7159),
    [anon_sym_SEMI_SEMI] = ACTIONS(7087),
    [anon_sym_and] = ACTIONS(7089),
    [anon_sym_EQ] = ACTIONS(7261),
    [anon_sym_TILDE] = ACTIONS(7163),
    [anon_sym_QMARK] = ACTIONS(7163),
    [anon_sym_LPAREN] = ACTIONS(7165),
    [anon_sym_external] = ACTIONS(7089),
    [anon_sym_type] = ACTIONS(7089),
    [anon_sym_LBRACK] = ACTIONS(7167),
    [anon_sym_RBRACK] = ACTIONS(7087),
    [anon_sym_true] = ACTIONS(7169),
    [anon_sym_false] = ACTIONS(7169),
    [anon_sym_COLON2] = ACTIONS(7171),
    [anon_sym_LBRACE] = ACTIONS(7173),
    [anon_sym_exception] = ACTIONS(7089),
    [anon_sym_module] = ACTIONS(7089),
    [anon_sym_open] = ACTIONS(7089),
    [anon_sym_include] = ACTIONS(7089),
    [anon_sym_class] = ACTIONS(7089),
    [anon_sym_val] = ACTIONS(7089),
    [anon_sym_POUND] = ACTIONS(7175),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7177),
    [anon_sym_begin] = ACTIONS(7179),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7087),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7181),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7183),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7087),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7087),
    [aux_sym_number_token1] = ACTIONS(7185),
    [aux_sym_signed_number_token1] = ACTIONS(7187),
    [anon_sym_SQUOTE] = ACTIONS(7189),
    [anon_sym_DQUOTE] = ACTIONS(7191),
    [sym__uppercase_identifier] = ACTIONS(7193),
    [aux_sym_tag_token1] = ACTIONS(7195),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2577] = {
    [sym_parameter] = STATE(7801),
    [sym__class_typed] = STATE(11853),
    [sym__parenthesized_abstract_type] = STATE(7801),
    [sym__simple_pattern] = STATE(7799),
    [sym_typed_pattern] = STATE(7796),
    [sym_polymorphic_variant_pattern] = STATE(7796),
    [sym_record_pattern] = STATE(7796),
    [sym_list_pattern] = STATE(7796),
    [sym_array_pattern] = STATE(7796),
    [sym_local_open_pattern] = STATE(7796),
    [sym_package_pattern] = STATE(7796),
    [sym_parenthesized_pattern] = STATE(7796),
    [sym_attribute] = STATE(2577),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7796),
    [sym_quoted_extension] = STATE(7796),
    [sym__constant] = STATE(7794),
    [sym__signed_constant] = STATE(7796),
    [sym_number] = STATE(7775),
    [sym_signed_number] = STATE(7794),
    [sym_character] = STATE(7775),
    [sym_string] = STATE(7775),
    [sym_quoted_string] = STATE(7775),
    [sym_boolean] = STATE(7775),
    [sym_unit] = STATE(7775),
    [sym__simple_value_pattern] = STATE(7796),
    [sym_parenthesized_operator] = STATE(7796),
    [sym_module_path] = STATE(20457),
    [sym_constructor_path] = STATE(7796),
    [sym__constructor_name] = STATE(7774),
    [sym_tag] = STATE(7796),
    [aux_sym_expression_item_repeat1] = STATE(10538),
    [aux_sym_let_binding_repeat1] = STATE(2578),
    [ts_builtin_sym_end] = ACTIONS(7021),
    [sym__lowercase_identifier] = ACTIONS(7159),
    [anon_sym_SEMI_SEMI] = ACTIONS(7021),
    [anon_sym_and] = ACTIONS(7023),
    [anon_sym_EQ] = ACTIONS(7263),
    [anon_sym_TILDE] = ACTIONS(7163),
    [anon_sym_QMARK] = ACTIONS(7163),
    [anon_sym_LPAREN] = ACTIONS(7165),
    [anon_sym_external] = ACTIONS(7023),
    [anon_sym_type] = ACTIONS(7023),
    [anon_sym_LBRACK] = ACTIONS(7167),
    [anon_sym_true] = ACTIONS(7169),
    [anon_sym_false] = ACTIONS(7169),
    [anon_sym_COLON2] = ACTIONS(7171),
    [anon_sym_LBRACE] = ACTIONS(7173),
    [anon_sym_exception] = ACTIONS(7023),
    [anon_sym_module] = ACTIONS(7023),
    [anon_sym_open] = ACTIONS(7023),
    [anon_sym_include] = ACTIONS(7023),
    [anon_sym_class] = ACTIONS(7023),
    [anon_sym_val] = ACTIONS(7023),
    [anon_sym_POUND] = ACTIONS(7175),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7177),
    [anon_sym_begin] = ACTIONS(7179),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7021),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7181),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7183),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7021),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7021),
    [aux_sym_number_token1] = ACTIONS(7185),
    [aux_sym_signed_number_token1] = ACTIONS(7187),
    [anon_sym_SQUOTE] = ACTIONS(7189),
    [anon_sym_DQUOTE] = ACTIONS(7191),
    [sym__uppercase_identifier] = ACTIONS(7193),
    [aux_sym_tag_token1] = ACTIONS(7195),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2578] = {
    [sym_parameter] = STATE(7801),
    [sym__class_typed] = STATE(11749),
    [sym__parenthesized_abstract_type] = STATE(7801),
    [sym__simple_pattern] = STATE(7799),
    [sym_typed_pattern] = STATE(7796),
    [sym_polymorphic_variant_pattern] = STATE(7796),
    [sym_record_pattern] = STATE(7796),
    [sym_list_pattern] = STATE(7796),
    [sym_array_pattern] = STATE(7796),
    [sym_local_open_pattern] = STATE(7796),
    [sym_package_pattern] = STATE(7796),
    [sym_parenthesized_pattern] = STATE(7796),
    [sym_attribute] = STATE(2578),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7796),
    [sym_quoted_extension] = STATE(7796),
    [sym__constant] = STATE(7794),
    [sym__signed_constant] = STATE(7796),
    [sym_number] = STATE(7775),
    [sym_signed_number] = STATE(7794),
    [sym_character] = STATE(7775),
    [sym_string] = STATE(7775),
    [sym_quoted_string] = STATE(7775),
    [sym_boolean] = STATE(7775),
    [sym_unit] = STATE(7775),
    [sym__simple_value_pattern] = STATE(7796),
    [sym_parenthesized_operator] = STATE(7796),
    [sym_module_path] = STATE(20457),
    [sym_constructor_path] = STATE(7796),
    [sym__constructor_name] = STATE(7774),
    [sym_tag] = STATE(7796),
    [aux_sym_expression_item_repeat1] = STATE(10495),
    [aux_sym_let_binding_repeat1] = STATE(2594),
    [ts_builtin_sym_end] = ACTIONS(7109),
    [sym__lowercase_identifier] = ACTIONS(7159),
    [anon_sym_SEMI_SEMI] = ACTIONS(7109),
    [anon_sym_and] = ACTIONS(7111),
    [anon_sym_EQ] = ACTIONS(7265),
    [anon_sym_TILDE] = ACTIONS(7163),
    [anon_sym_QMARK] = ACTIONS(7163),
    [anon_sym_LPAREN] = ACTIONS(7165),
    [anon_sym_external] = ACTIONS(7111),
    [anon_sym_type] = ACTIONS(7111),
    [anon_sym_LBRACK] = ACTIONS(7167),
    [anon_sym_true] = ACTIONS(7169),
    [anon_sym_false] = ACTIONS(7169),
    [anon_sym_COLON2] = ACTIONS(7171),
    [anon_sym_LBRACE] = ACTIONS(7173),
    [anon_sym_exception] = ACTIONS(7111),
    [anon_sym_module] = ACTIONS(7111),
    [anon_sym_open] = ACTIONS(7111),
    [anon_sym_include] = ACTIONS(7111),
    [anon_sym_class] = ACTIONS(7111),
    [anon_sym_val] = ACTIONS(7111),
    [anon_sym_POUND] = ACTIONS(7175),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7177),
    [anon_sym_begin] = ACTIONS(7179),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7109),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7181),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7183),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7109),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7109),
    [aux_sym_number_token1] = ACTIONS(7185),
    [aux_sym_signed_number_token1] = ACTIONS(7187),
    [anon_sym_SQUOTE] = ACTIONS(7189),
    [anon_sym_DQUOTE] = ACTIONS(7191),
    [sym__uppercase_identifier] = ACTIONS(7193),
    [aux_sym_tag_token1] = ACTIONS(7195),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2579] = {
    [sym_parameter] = STATE(7801),
    [sym__class_typed] = STATE(11735),
    [sym__parenthesized_abstract_type] = STATE(7801),
    [sym__simple_pattern] = STATE(7799),
    [sym_typed_pattern] = STATE(7796),
    [sym_polymorphic_variant_pattern] = STATE(7796),
    [sym_record_pattern] = STATE(7796),
    [sym_list_pattern] = STATE(7796),
    [sym_array_pattern] = STATE(7796),
    [sym_local_open_pattern] = STATE(7796),
    [sym_package_pattern] = STATE(7796),
    [sym_parenthesized_pattern] = STATE(7796),
    [sym_attribute] = STATE(2579),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7796),
    [sym_quoted_extension] = STATE(7796),
    [sym__constant] = STATE(7794),
    [sym__signed_constant] = STATE(7796),
    [sym_number] = STATE(7775),
    [sym_signed_number] = STATE(7794),
    [sym_character] = STATE(7775),
    [sym_string] = STATE(7775),
    [sym_quoted_string] = STATE(7775),
    [sym_boolean] = STATE(7775),
    [sym_unit] = STATE(7775),
    [sym__simple_value_pattern] = STATE(7796),
    [sym_parenthesized_operator] = STATE(7796),
    [sym_module_path] = STATE(20457),
    [sym_constructor_path] = STATE(7796),
    [sym__constructor_name] = STATE(7774),
    [sym_tag] = STATE(7796),
    [aux_sym_expression_item_repeat1] = STATE(10639),
    [aux_sym_let_binding_repeat1] = STATE(2561),
    [sym__lowercase_identifier] = ACTIONS(7159),
    [anon_sym_SEMI_SEMI] = ACTIONS(6981),
    [anon_sym_and] = ACTIONS(6983),
    [anon_sym_EQ] = ACTIONS(7267),
    [anon_sym_TILDE] = ACTIONS(7163),
    [anon_sym_QMARK] = ACTIONS(7163),
    [anon_sym_LPAREN] = ACTIONS(7165),
    [anon_sym_external] = ACTIONS(6983),
    [anon_sym_type] = ACTIONS(6983),
    [anon_sym_LBRACK] = ACTIONS(7167),
    [anon_sym_RBRACK] = ACTIONS(6981),
    [anon_sym_true] = ACTIONS(7169),
    [anon_sym_false] = ACTIONS(7169),
    [anon_sym_COLON2] = ACTIONS(7171),
    [anon_sym_LBRACE] = ACTIONS(7173),
    [anon_sym_exception] = ACTIONS(6983),
    [anon_sym_module] = ACTIONS(6983),
    [anon_sym_open] = ACTIONS(6983),
    [anon_sym_include] = ACTIONS(6983),
    [anon_sym_class] = ACTIONS(6983),
    [anon_sym_val] = ACTIONS(6983),
    [anon_sym_POUND] = ACTIONS(7175),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7177),
    [anon_sym_begin] = ACTIONS(7179),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6981),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7181),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7183),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6981),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6981),
    [aux_sym_number_token1] = ACTIONS(7185),
    [aux_sym_signed_number_token1] = ACTIONS(7187),
    [anon_sym_SQUOTE] = ACTIONS(7189),
    [anon_sym_DQUOTE] = ACTIONS(7191),
    [sym__uppercase_identifier] = ACTIONS(7193),
    [aux_sym_tag_token1] = ACTIONS(7195),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2580] = {
    [sym_parameter] = STATE(7801),
    [sym__class_typed] = STATE(11818),
    [sym__parenthesized_abstract_type] = STATE(7801),
    [sym__simple_pattern] = STATE(7799),
    [sym_typed_pattern] = STATE(7796),
    [sym_polymorphic_variant_pattern] = STATE(7796),
    [sym_record_pattern] = STATE(7796),
    [sym_list_pattern] = STATE(7796),
    [sym_array_pattern] = STATE(7796),
    [sym_local_open_pattern] = STATE(7796),
    [sym_package_pattern] = STATE(7796),
    [sym_parenthesized_pattern] = STATE(7796),
    [sym_attribute] = STATE(2580),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7796),
    [sym_quoted_extension] = STATE(7796),
    [sym__constant] = STATE(7794),
    [sym__signed_constant] = STATE(7796),
    [sym_number] = STATE(7775),
    [sym_signed_number] = STATE(7794),
    [sym_character] = STATE(7775),
    [sym_string] = STATE(7775),
    [sym_quoted_string] = STATE(7775),
    [sym_boolean] = STATE(7775),
    [sym_unit] = STATE(7775),
    [sym__simple_value_pattern] = STATE(7796),
    [sym_parenthesized_operator] = STATE(7796),
    [sym_module_path] = STATE(20457),
    [sym_constructor_path] = STATE(7796),
    [sym__constructor_name] = STATE(7774),
    [sym_tag] = STATE(7796),
    [aux_sym_expression_item_repeat1] = STATE(10639),
    [aux_sym_let_binding_repeat1] = STATE(2588),
    [ts_builtin_sym_end] = ACTIONS(6981),
    [sym__lowercase_identifier] = ACTIONS(7159),
    [anon_sym_SEMI_SEMI] = ACTIONS(6981),
    [anon_sym_and] = ACTIONS(6983),
    [anon_sym_EQ] = ACTIONS(7269),
    [anon_sym_TILDE] = ACTIONS(7163),
    [anon_sym_QMARK] = ACTIONS(7163),
    [anon_sym_LPAREN] = ACTIONS(7165),
    [anon_sym_external] = ACTIONS(6983),
    [anon_sym_type] = ACTIONS(6983),
    [anon_sym_LBRACK] = ACTIONS(7167),
    [anon_sym_true] = ACTIONS(7169),
    [anon_sym_false] = ACTIONS(7169),
    [anon_sym_COLON2] = ACTIONS(7171),
    [anon_sym_LBRACE] = ACTIONS(7173),
    [anon_sym_exception] = ACTIONS(6983),
    [anon_sym_module] = ACTIONS(6983),
    [anon_sym_open] = ACTIONS(6983),
    [anon_sym_include] = ACTIONS(6983),
    [anon_sym_class] = ACTIONS(6983),
    [anon_sym_val] = ACTIONS(6983),
    [anon_sym_POUND] = ACTIONS(7175),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7177),
    [anon_sym_begin] = ACTIONS(7179),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6981),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7181),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7183),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6981),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6981),
    [aux_sym_number_token1] = ACTIONS(7185),
    [aux_sym_signed_number_token1] = ACTIONS(7187),
    [anon_sym_SQUOTE] = ACTIONS(7189),
    [anon_sym_DQUOTE] = ACTIONS(7191),
    [sym__uppercase_identifier] = ACTIONS(7193),
    [aux_sym_tag_token1] = ACTIONS(7195),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2581] = {
    [sym_parameter] = STATE(7869),
    [sym__class_typed] = STATE(11766),
    [sym__parenthesized_abstract_type] = STATE(7869),
    [sym__simple_pattern] = STATE(7868),
    [sym_typed_pattern] = STATE(8089),
    [sym_polymorphic_variant_pattern] = STATE(8089),
    [sym_record_pattern] = STATE(8089),
    [sym_list_pattern] = STATE(8089),
    [sym_array_pattern] = STATE(8089),
    [sym_local_open_pattern] = STATE(8089),
    [sym_package_pattern] = STATE(8089),
    [sym_parenthesized_pattern] = STATE(8089),
    [sym_attribute] = STATE(2581),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(8089),
    [sym_quoted_extension] = STATE(8089),
    [sym__constant] = STATE(8037),
    [sym__signed_constant] = STATE(8089),
    [sym_number] = STATE(8039),
    [sym_signed_number] = STATE(8037),
    [sym_character] = STATE(8039),
    [sym_string] = STATE(8039),
    [sym_quoted_string] = STATE(8039),
    [sym_boolean] = STATE(8039),
    [sym_unit] = STATE(8039),
    [sym__simple_value_pattern] = STATE(8089),
    [sym_parenthesized_operator] = STATE(8089),
    [sym_module_path] = STATE(18728),
    [sym_constructor_path] = STATE(8089),
    [sym__constructor_name] = STATE(8040),
    [sym_tag] = STATE(8089),
    [aux_sym_expression_item_repeat1] = STATE(10405),
    [aux_sym_let_binding_repeat1] = STATE(2595),
    [sym__lowercase_identifier] = ACTIONS(7199),
    [anon_sym_SEMI_SEMI] = ACTIONS(7133),
    [anon_sym_and] = ACTIONS(7135),
    [anon_sym_EQ] = ACTIONS(7271),
    [anon_sym_TILDE] = ACTIONS(7203),
    [anon_sym_QMARK] = ACTIONS(7203),
    [anon_sym_LPAREN] = ACTIONS(7205),
    [anon_sym_external] = ACTIONS(7135),
    [anon_sym_type] = ACTIONS(7135),
    [anon_sym_LBRACK] = ACTIONS(7207),
    [anon_sym_true] = ACTIONS(7209),
    [anon_sym_false] = ACTIONS(7209),
    [anon_sym_COLON2] = ACTIONS(7211),
    [anon_sym_LBRACE] = ACTIONS(7213),
    [anon_sym_exception] = ACTIONS(7135),
    [anon_sym_module] = ACTIONS(7135),
    [anon_sym_open] = ACTIONS(7135),
    [anon_sym_include] = ACTIONS(7135),
    [anon_sym_class] = ACTIONS(7135),
    [anon_sym_val] = ACTIONS(7135),
    [anon_sym_end] = ACTIONS(7135),
    [anon_sym_POUND] = ACTIONS(7215),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7217),
    [anon_sym_begin] = ACTIONS(7219),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7133),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7221),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7223),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7133),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7133),
    [aux_sym_number_token1] = ACTIONS(7225),
    [aux_sym_signed_number_token1] = ACTIONS(7227),
    [anon_sym_SQUOTE] = ACTIONS(7229),
    [anon_sym_DQUOTE] = ACTIONS(7231),
    [sym__uppercase_identifier] = ACTIONS(7233),
    [aux_sym_tag_token1] = ACTIONS(7235),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2582] = {
    [sym_parameter] = STATE(7801),
    [sym__class_typed] = STATE(11736),
    [sym__parenthesized_abstract_type] = STATE(7801),
    [sym__simple_pattern] = STATE(7799),
    [sym_typed_pattern] = STATE(7796),
    [sym_polymorphic_variant_pattern] = STATE(7796),
    [sym_record_pattern] = STATE(7796),
    [sym_list_pattern] = STATE(7796),
    [sym_array_pattern] = STATE(7796),
    [sym_local_open_pattern] = STATE(7796),
    [sym_package_pattern] = STATE(7796),
    [sym_parenthesized_pattern] = STATE(7796),
    [sym_attribute] = STATE(2582),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7796),
    [sym_quoted_extension] = STATE(7796),
    [sym__constant] = STATE(7794),
    [sym__signed_constant] = STATE(7796),
    [sym_number] = STATE(7775),
    [sym_signed_number] = STATE(7794),
    [sym_character] = STATE(7775),
    [sym_string] = STATE(7775),
    [sym_quoted_string] = STATE(7775),
    [sym_boolean] = STATE(7775),
    [sym_unit] = STATE(7775),
    [sym__simple_value_pattern] = STATE(7796),
    [sym_parenthesized_operator] = STATE(7796),
    [sym_module_path] = STATE(20457),
    [sym_constructor_path] = STATE(7796),
    [sym__constructor_name] = STATE(7774),
    [sym_tag] = STATE(7796),
    [aux_sym_expression_item_repeat1] = STATE(10495),
    [aux_sym_let_binding_repeat1] = STATE(2594),
    [sym__lowercase_identifier] = ACTIONS(7159),
    [anon_sym_SEMI_SEMI] = ACTIONS(7109),
    [anon_sym_and] = ACTIONS(7111),
    [anon_sym_EQ] = ACTIONS(7273),
    [anon_sym_TILDE] = ACTIONS(7163),
    [anon_sym_QMARK] = ACTIONS(7163),
    [anon_sym_LPAREN] = ACTIONS(7165),
    [anon_sym_external] = ACTIONS(7111),
    [anon_sym_type] = ACTIONS(7111),
    [anon_sym_LBRACK] = ACTIONS(7167),
    [anon_sym_RBRACK] = ACTIONS(7109),
    [anon_sym_true] = ACTIONS(7169),
    [anon_sym_false] = ACTIONS(7169),
    [anon_sym_COLON2] = ACTIONS(7171),
    [anon_sym_LBRACE] = ACTIONS(7173),
    [anon_sym_exception] = ACTIONS(7111),
    [anon_sym_module] = ACTIONS(7111),
    [anon_sym_open] = ACTIONS(7111),
    [anon_sym_include] = ACTIONS(7111),
    [anon_sym_class] = ACTIONS(7111),
    [anon_sym_val] = ACTIONS(7111),
    [anon_sym_POUND] = ACTIONS(7175),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7177),
    [anon_sym_begin] = ACTIONS(7179),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7109),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7181),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7183),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7109),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7109),
    [aux_sym_number_token1] = ACTIONS(7185),
    [aux_sym_signed_number_token1] = ACTIONS(7187),
    [anon_sym_SQUOTE] = ACTIONS(7189),
    [anon_sym_DQUOTE] = ACTIONS(7191),
    [sym__uppercase_identifier] = ACTIONS(7193),
    [aux_sym_tag_token1] = ACTIONS(7195),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2583] = {
    [sym_parameter] = STATE(7869),
    [sym__class_typed] = STATE(11772),
    [sym__parenthesized_abstract_type] = STATE(7869),
    [sym__simple_pattern] = STATE(7868),
    [sym_typed_pattern] = STATE(8089),
    [sym_polymorphic_variant_pattern] = STATE(8089),
    [sym_record_pattern] = STATE(8089),
    [sym_list_pattern] = STATE(8089),
    [sym_array_pattern] = STATE(8089),
    [sym_local_open_pattern] = STATE(8089),
    [sym_package_pattern] = STATE(8089),
    [sym_parenthesized_pattern] = STATE(8089),
    [sym_attribute] = STATE(2583),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(8089),
    [sym_quoted_extension] = STATE(8089),
    [sym__constant] = STATE(8037),
    [sym__signed_constant] = STATE(8089),
    [sym_number] = STATE(8039),
    [sym_signed_number] = STATE(8037),
    [sym_character] = STATE(8039),
    [sym_string] = STATE(8039),
    [sym_quoted_string] = STATE(8039),
    [sym_boolean] = STATE(8039),
    [sym_unit] = STATE(8039),
    [sym__simple_value_pattern] = STATE(8089),
    [sym_parenthesized_operator] = STATE(8089),
    [sym_module_path] = STATE(18728),
    [sym_constructor_path] = STATE(8089),
    [sym__constructor_name] = STATE(8040),
    [sym_tag] = STATE(8089),
    [aux_sym_expression_item_repeat1] = STATE(10639),
    [aux_sym_let_binding_repeat1] = STATE(2586),
    [sym__lowercase_identifier] = ACTIONS(7199),
    [anon_sym_SEMI_SEMI] = ACTIONS(6981),
    [anon_sym_and] = ACTIONS(6983),
    [anon_sym_EQ] = ACTIONS(7275),
    [anon_sym_TILDE] = ACTIONS(7203),
    [anon_sym_QMARK] = ACTIONS(7203),
    [anon_sym_LPAREN] = ACTIONS(7205),
    [anon_sym_external] = ACTIONS(6983),
    [anon_sym_type] = ACTIONS(6983),
    [anon_sym_LBRACK] = ACTIONS(7207),
    [anon_sym_true] = ACTIONS(7209),
    [anon_sym_false] = ACTIONS(7209),
    [anon_sym_COLON2] = ACTIONS(7211),
    [anon_sym_LBRACE] = ACTIONS(7213),
    [anon_sym_exception] = ACTIONS(6983),
    [anon_sym_module] = ACTIONS(6983),
    [anon_sym_open] = ACTIONS(6983),
    [anon_sym_include] = ACTIONS(6983),
    [anon_sym_class] = ACTIONS(6983),
    [anon_sym_val] = ACTIONS(6983),
    [anon_sym_end] = ACTIONS(6983),
    [anon_sym_POUND] = ACTIONS(7215),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7217),
    [anon_sym_begin] = ACTIONS(7219),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6981),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7221),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7223),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6981),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6981),
    [aux_sym_number_token1] = ACTIONS(7225),
    [aux_sym_signed_number_token1] = ACTIONS(7227),
    [anon_sym_SQUOTE] = ACTIONS(7229),
    [anon_sym_DQUOTE] = ACTIONS(7231),
    [sym__uppercase_identifier] = ACTIONS(7233),
    [aux_sym_tag_token1] = ACTIONS(7235),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2584] = {
    [sym_parameter] = STATE(7801),
    [sym__class_typed] = STATE(11747),
    [sym__parenthesized_abstract_type] = STATE(7801),
    [sym__simple_pattern] = STATE(7799),
    [sym_typed_pattern] = STATE(7796),
    [sym_polymorphic_variant_pattern] = STATE(7796),
    [sym_record_pattern] = STATE(7796),
    [sym_list_pattern] = STATE(7796),
    [sym_array_pattern] = STATE(7796),
    [sym_local_open_pattern] = STATE(7796),
    [sym_package_pattern] = STATE(7796),
    [sym_parenthesized_pattern] = STATE(7796),
    [sym_attribute] = STATE(2584),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7796),
    [sym_quoted_extension] = STATE(7796),
    [sym__constant] = STATE(7794),
    [sym__signed_constant] = STATE(7796),
    [sym_number] = STATE(7775),
    [sym_signed_number] = STATE(7794),
    [sym_character] = STATE(7775),
    [sym_string] = STATE(7775),
    [sym_quoted_string] = STATE(7775),
    [sym_boolean] = STATE(7775),
    [sym_unit] = STATE(7775),
    [sym__simple_value_pattern] = STATE(7796),
    [sym_parenthesized_operator] = STATE(7796),
    [sym_module_path] = STATE(20457),
    [sym_constructor_path] = STATE(7796),
    [sym__constructor_name] = STATE(7774),
    [sym_tag] = STATE(7796),
    [aux_sym_expression_item_repeat1] = STATE(10542),
    [aux_sym_let_binding_repeat1] = STATE(2585),
    [sym__lowercase_identifier] = ACTIONS(7159),
    [anon_sym_SEMI_SEMI] = ACTIONS(7121),
    [anon_sym_and] = ACTIONS(7123),
    [anon_sym_EQ] = ACTIONS(7277),
    [anon_sym_TILDE] = ACTIONS(7163),
    [anon_sym_QMARK] = ACTIONS(7163),
    [anon_sym_LPAREN] = ACTIONS(7165),
    [anon_sym_external] = ACTIONS(7123),
    [anon_sym_type] = ACTIONS(7123),
    [anon_sym_LBRACK] = ACTIONS(7167),
    [anon_sym_RBRACK] = ACTIONS(7121),
    [anon_sym_true] = ACTIONS(7169),
    [anon_sym_false] = ACTIONS(7169),
    [anon_sym_COLON2] = ACTIONS(7171),
    [anon_sym_LBRACE] = ACTIONS(7173),
    [anon_sym_exception] = ACTIONS(7123),
    [anon_sym_module] = ACTIONS(7123),
    [anon_sym_open] = ACTIONS(7123),
    [anon_sym_include] = ACTIONS(7123),
    [anon_sym_class] = ACTIONS(7123),
    [anon_sym_val] = ACTIONS(7123),
    [anon_sym_POUND] = ACTIONS(7175),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7177),
    [anon_sym_begin] = ACTIONS(7179),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7121),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7181),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7183),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7121),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7121),
    [aux_sym_number_token1] = ACTIONS(7185),
    [aux_sym_signed_number_token1] = ACTIONS(7187),
    [anon_sym_SQUOTE] = ACTIONS(7189),
    [anon_sym_DQUOTE] = ACTIONS(7191),
    [sym__uppercase_identifier] = ACTIONS(7193),
    [aux_sym_tag_token1] = ACTIONS(7195),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2585] = {
    [sym_parameter] = STATE(7801),
    [sym__class_typed] = STATE(11737),
    [sym__parenthesized_abstract_type] = STATE(7801),
    [sym__simple_pattern] = STATE(7799),
    [sym_typed_pattern] = STATE(7796),
    [sym_polymorphic_variant_pattern] = STATE(7796),
    [sym_record_pattern] = STATE(7796),
    [sym_list_pattern] = STATE(7796),
    [sym_array_pattern] = STATE(7796),
    [sym_local_open_pattern] = STATE(7796),
    [sym_package_pattern] = STATE(7796),
    [sym_parenthesized_pattern] = STATE(7796),
    [sym_attribute] = STATE(2585),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7796),
    [sym_quoted_extension] = STATE(7796),
    [sym__constant] = STATE(7794),
    [sym__signed_constant] = STATE(7796),
    [sym_number] = STATE(7775),
    [sym_signed_number] = STATE(7794),
    [sym_character] = STATE(7775),
    [sym_string] = STATE(7775),
    [sym_quoted_string] = STATE(7775),
    [sym_boolean] = STATE(7775),
    [sym_unit] = STATE(7775),
    [sym__simple_value_pattern] = STATE(7796),
    [sym_parenthesized_operator] = STATE(7796),
    [sym_module_path] = STATE(20457),
    [sym_constructor_path] = STATE(7796),
    [sym__constructor_name] = STATE(7774),
    [sym_tag] = STATE(7796),
    [aux_sym_expression_item_repeat1] = STATE(10705),
    [aux_sym_let_binding_repeat1] = STATE(2594),
    [sym__lowercase_identifier] = ACTIONS(7159),
    [anon_sym_SEMI_SEMI] = ACTIONS(7115),
    [anon_sym_and] = ACTIONS(7117),
    [anon_sym_EQ] = ACTIONS(7279),
    [anon_sym_TILDE] = ACTIONS(7163),
    [anon_sym_QMARK] = ACTIONS(7163),
    [anon_sym_LPAREN] = ACTIONS(7165),
    [anon_sym_external] = ACTIONS(7117),
    [anon_sym_type] = ACTIONS(7117),
    [anon_sym_LBRACK] = ACTIONS(7167),
    [anon_sym_RBRACK] = ACTIONS(7115),
    [anon_sym_true] = ACTIONS(7169),
    [anon_sym_false] = ACTIONS(7169),
    [anon_sym_COLON2] = ACTIONS(7171),
    [anon_sym_LBRACE] = ACTIONS(7173),
    [anon_sym_exception] = ACTIONS(7117),
    [anon_sym_module] = ACTIONS(7117),
    [anon_sym_open] = ACTIONS(7117),
    [anon_sym_include] = ACTIONS(7117),
    [anon_sym_class] = ACTIONS(7117),
    [anon_sym_val] = ACTIONS(7117),
    [anon_sym_POUND] = ACTIONS(7175),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7177),
    [anon_sym_begin] = ACTIONS(7179),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7115),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7181),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7183),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7115),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7115),
    [aux_sym_number_token1] = ACTIONS(7185),
    [aux_sym_signed_number_token1] = ACTIONS(7187),
    [anon_sym_SQUOTE] = ACTIONS(7189),
    [anon_sym_DQUOTE] = ACTIONS(7191),
    [sym__uppercase_identifier] = ACTIONS(7193),
    [aux_sym_tag_token1] = ACTIONS(7195),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2586] = {
    [sym_parameter] = STATE(7869),
    [sym__class_typed] = STATE(11770),
    [sym__parenthesized_abstract_type] = STATE(7869),
    [sym__simple_pattern] = STATE(7868),
    [sym_typed_pattern] = STATE(8089),
    [sym_polymorphic_variant_pattern] = STATE(8089),
    [sym_record_pattern] = STATE(8089),
    [sym_list_pattern] = STATE(8089),
    [sym_array_pattern] = STATE(8089),
    [sym_local_open_pattern] = STATE(8089),
    [sym_package_pattern] = STATE(8089),
    [sym_parenthesized_pattern] = STATE(8089),
    [sym_attribute] = STATE(2586),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(8089),
    [sym_quoted_extension] = STATE(8089),
    [sym__constant] = STATE(8037),
    [sym__signed_constant] = STATE(8089),
    [sym_number] = STATE(8039),
    [sym_signed_number] = STATE(8037),
    [sym_character] = STATE(8039),
    [sym_string] = STATE(8039),
    [sym_quoted_string] = STATE(8039),
    [sym_boolean] = STATE(8039),
    [sym_unit] = STATE(8039),
    [sym__simple_value_pattern] = STATE(8089),
    [sym_parenthesized_operator] = STATE(8089),
    [sym_module_path] = STATE(18728),
    [sym_constructor_path] = STATE(8089),
    [sym__constructor_name] = STATE(8040),
    [sym_tag] = STATE(8089),
    [aux_sym_expression_item_repeat1] = STATE(10544),
    [aux_sym_let_binding_repeat1] = STATE(2595),
    [sym__lowercase_identifier] = ACTIONS(7199),
    [anon_sym_SEMI_SEMI] = ACTIONS(6897),
    [anon_sym_and] = ACTIONS(6899),
    [anon_sym_EQ] = ACTIONS(7281),
    [anon_sym_TILDE] = ACTIONS(7203),
    [anon_sym_QMARK] = ACTIONS(7203),
    [anon_sym_LPAREN] = ACTIONS(7205),
    [anon_sym_external] = ACTIONS(6899),
    [anon_sym_type] = ACTIONS(6899),
    [anon_sym_LBRACK] = ACTIONS(7207),
    [anon_sym_true] = ACTIONS(7209),
    [anon_sym_false] = ACTIONS(7209),
    [anon_sym_COLON2] = ACTIONS(7211),
    [anon_sym_LBRACE] = ACTIONS(7213),
    [anon_sym_exception] = ACTIONS(6899),
    [anon_sym_module] = ACTIONS(6899),
    [anon_sym_open] = ACTIONS(6899),
    [anon_sym_include] = ACTIONS(6899),
    [anon_sym_class] = ACTIONS(6899),
    [anon_sym_val] = ACTIONS(6899),
    [anon_sym_end] = ACTIONS(6899),
    [anon_sym_POUND] = ACTIONS(7215),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7217),
    [anon_sym_begin] = ACTIONS(7219),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6897),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7221),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7223),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6897),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6897),
    [aux_sym_number_token1] = ACTIONS(7225),
    [aux_sym_signed_number_token1] = ACTIONS(7227),
    [anon_sym_SQUOTE] = ACTIONS(7229),
    [anon_sym_DQUOTE] = ACTIONS(7231),
    [sym__uppercase_identifier] = ACTIONS(7233),
    [aux_sym_tag_token1] = ACTIONS(7235),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2587] = {
    [sym_parameter] = STATE(7869),
    [sym__class_typed] = STATE(11769),
    [sym__parenthesized_abstract_type] = STATE(7869),
    [sym__simple_pattern] = STATE(7868),
    [sym_typed_pattern] = STATE(8089),
    [sym_polymorphic_variant_pattern] = STATE(8089),
    [sym_record_pattern] = STATE(8089),
    [sym_list_pattern] = STATE(8089),
    [sym_array_pattern] = STATE(8089),
    [sym_local_open_pattern] = STATE(8089),
    [sym_package_pattern] = STATE(8089),
    [sym_parenthesized_pattern] = STATE(8089),
    [sym_attribute] = STATE(2587),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(8089),
    [sym_quoted_extension] = STATE(8089),
    [sym__constant] = STATE(8037),
    [sym__signed_constant] = STATE(8089),
    [sym_number] = STATE(8039),
    [sym_signed_number] = STATE(8037),
    [sym_character] = STATE(8039),
    [sym_string] = STATE(8039),
    [sym_quoted_string] = STATE(8039),
    [sym_boolean] = STATE(8039),
    [sym_unit] = STATE(8039),
    [sym__simple_value_pattern] = STATE(8089),
    [sym_parenthesized_operator] = STATE(8089),
    [sym_module_path] = STATE(18728),
    [sym_constructor_path] = STATE(8089),
    [sym__constructor_name] = STATE(8040),
    [sym_tag] = STATE(8089),
    [aux_sym_expression_item_repeat1] = STATE(10536),
    [aux_sym_let_binding_repeat1] = STATE(2563),
    [sym__lowercase_identifier] = ACTIONS(7199),
    [anon_sym_SEMI_SEMI] = ACTIONS(7087),
    [anon_sym_and] = ACTIONS(7089),
    [anon_sym_EQ] = ACTIONS(7283),
    [anon_sym_TILDE] = ACTIONS(7203),
    [anon_sym_QMARK] = ACTIONS(7203),
    [anon_sym_LPAREN] = ACTIONS(7205),
    [anon_sym_external] = ACTIONS(7089),
    [anon_sym_type] = ACTIONS(7089),
    [anon_sym_LBRACK] = ACTIONS(7207),
    [anon_sym_true] = ACTIONS(7209),
    [anon_sym_false] = ACTIONS(7209),
    [anon_sym_COLON2] = ACTIONS(7211),
    [anon_sym_LBRACE] = ACTIONS(7213),
    [anon_sym_exception] = ACTIONS(7089),
    [anon_sym_module] = ACTIONS(7089),
    [anon_sym_open] = ACTIONS(7089),
    [anon_sym_include] = ACTIONS(7089),
    [anon_sym_class] = ACTIONS(7089),
    [anon_sym_val] = ACTIONS(7089),
    [anon_sym_end] = ACTIONS(7089),
    [anon_sym_POUND] = ACTIONS(7215),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7217),
    [anon_sym_begin] = ACTIONS(7219),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7087),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7221),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7223),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7087),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7087),
    [aux_sym_number_token1] = ACTIONS(7225),
    [aux_sym_signed_number_token1] = ACTIONS(7227),
    [anon_sym_SQUOTE] = ACTIONS(7229),
    [anon_sym_DQUOTE] = ACTIONS(7231),
    [sym__uppercase_identifier] = ACTIONS(7233),
    [aux_sym_tag_token1] = ACTIONS(7235),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2588] = {
    [sym_parameter] = STATE(7801),
    [sym__class_typed] = STATE(11858),
    [sym__parenthesized_abstract_type] = STATE(7801),
    [sym__simple_pattern] = STATE(7799),
    [sym_typed_pattern] = STATE(7796),
    [sym_polymorphic_variant_pattern] = STATE(7796),
    [sym_record_pattern] = STATE(7796),
    [sym_list_pattern] = STATE(7796),
    [sym_array_pattern] = STATE(7796),
    [sym_local_open_pattern] = STATE(7796),
    [sym_package_pattern] = STATE(7796),
    [sym_parenthesized_pattern] = STATE(7796),
    [sym_attribute] = STATE(2588),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7796),
    [sym_quoted_extension] = STATE(7796),
    [sym__constant] = STATE(7794),
    [sym__signed_constant] = STATE(7796),
    [sym_number] = STATE(7775),
    [sym_signed_number] = STATE(7794),
    [sym_character] = STATE(7775),
    [sym_string] = STATE(7775),
    [sym_quoted_string] = STATE(7775),
    [sym_boolean] = STATE(7775),
    [sym_unit] = STATE(7775),
    [sym__simple_value_pattern] = STATE(7796),
    [sym_parenthesized_operator] = STATE(7796),
    [sym_module_path] = STATE(20457),
    [sym_constructor_path] = STATE(7796),
    [sym__constructor_name] = STATE(7774),
    [sym_tag] = STATE(7796),
    [aux_sym_expression_item_repeat1] = STATE(10544),
    [aux_sym_let_binding_repeat1] = STATE(2594),
    [ts_builtin_sym_end] = ACTIONS(6897),
    [sym__lowercase_identifier] = ACTIONS(7159),
    [anon_sym_SEMI_SEMI] = ACTIONS(6897),
    [anon_sym_and] = ACTIONS(6899),
    [anon_sym_EQ] = ACTIONS(7285),
    [anon_sym_TILDE] = ACTIONS(7163),
    [anon_sym_QMARK] = ACTIONS(7163),
    [anon_sym_LPAREN] = ACTIONS(7165),
    [anon_sym_external] = ACTIONS(6899),
    [anon_sym_type] = ACTIONS(6899),
    [anon_sym_LBRACK] = ACTIONS(7167),
    [anon_sym_true] = ACTIONS(7169),
    [anon_sym_false] = ACTIONS(7169),
    [anon_sym_COLON2] = ACTIONS(7171),
    [anon_sym_LBRACE] = ACTIONS(7173),
    [anon_sym_exception] = ACTIONS(6899),
    [anon_sym_module] = ACTIONS(6899),
    [anon_sym_open] = ACTIONS(6899),
    [anon_sym_include] = ACTIONS(6899),
    [anon_sym_class] = ACTIONS(6899),
    [anon_sym_val] = ACTIONS(6899),
    [anon_sym_POUND] = ACTIONS(7175),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7177),
    [anon_sym_begin] = ACTIONS(7179),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6897),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7181),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7183),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6897),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6897),
    [aux_sym_number_token1] = ACTIONS(7185),
    [aux_sym_signed_number_token1] = ACTIONS(7187),
    [anon_sym_SQUOTE] = ACTIONS(7189),
    [anon_sym_DQUOTE] = ACTIONS(7191),
    [sym__uppercase_identifier] = ACTIONS(7193),
    [aux_sym_tag_token1] = ACTIONS(7195),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2589] = {
    [sym_parameter] = STATE(7801),
    [sym__class_typed] = STATE(11862),
    [sym__parenthesized_abstract_type] = STATE(7801),
    [sym__simple_pattern] = STATE(7799),
    [sym_typed_pattern] = STATE(7796),
    [sym_polymorphic_variant_pattern] = STATE(7796),
    [sym_record_pattern] = STATE(7796),
    [sym_list_pattern] = STATE(7796),
    [sym_array_pattern] = STATE(7796),
    [sym_local_open_pattern] = STATE(7796),
    [sym_package_pattern] = STATE(7796),
    [sym_parenthesized_pattern] = STATE(7796),
    [sym_attribute] = STATE(2589),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7796),
    [sym_quoted_extension] = STATE(7796),
    [sym__constant] = STATE(7794),
    [sym__signed_constant] = STATE(7796),
    [sym_number] = STATE(7775),
    [sym_signed_number] = STATE(7794),
    [sym_character] = STATE(7775),
    [sym_string] = STATE(7775),
    [sym_quoted_string] = STATE(7775),
    [sym_boolean] = STATE(7775),
    [sym_unit] = STATE(7775),
    [sym__simple_value_pattern] = STATE(7796),
    [sym_parenthesized_operator] = STATE(7796),
    [sym_module_path] = STATE(20457),
    [sym_constructor_path] = STATE(7796),
    [sym__constructor_name] = STATE(7774),
    [sym_tag] = STATE(7796),
    [aux_sym_expression_item_repeat1] = STATE(10433),
    [aux_sym_let_binding_repeat1] = STATE(2575),
    [ts_builtin_sym_end] = ACTIONS(7093),
    [sym__lowercase_identifier] = ACTIONS(7159),
    [anon_sym_SEMI_SEMI] = ACTIONS(7093),
    [anon_sym_and] = ACTIONS(7095),
    [anon_sym_EQ] = ACTIONS(7287),
    [anon_sym_TILDE] = ACTIONS(7163),
    [anon_sym_QMARK] = ACTIONS(7163),
    [anon_sym_LPAREN] = ACTIONS(7165),
    [anon_sym_external] = ACTIONS(7095),
    [anon_sym_type] = ACTIONS(7095),
    [anon_sym_LBRACK] = ACTIONS(7167),
    [anon_sym_true] = ACTIONS(7169),
    [anon_sym_false] = ACTIONS(7169),
    [anon_sym_COLON2] = ACTIONS(7171),
    [anon_sym_LBRACE] = ACTIONS(7173),
    [anon_sym_exception] = ACTIONS(7095),
    [anon_sym_module] = ACTIONS(7095),
    [anon_sym_open] = ACTIONS(7095),
    [anon_sym_include] = ACTIONS(7095),
    [anon_sym_class] = ACTIONS(7095),
    [anon_sym_val] = ACTIONS(7095),
    [anon_sym_POUND] = ACTIONS(7175),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7177),
    [anon_sym_begin] = ACTIONS(7179),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7093),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7181),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7183),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7093),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7093),
    [aux_sym_number_token1] = ACTIONS(7185),
    [aux_sym_signed_number_token1] = ACTIONS(7187),
    [anon_sym_SQUOTE] = ACTIONS(7189),
    [anon_sym_DQUOTE] = ACTIONS(7191),
    [sym__uppercase_identifier] = ACTIONS(7193),
    [aux_sym_tag_token1] = ACTIONS(7195),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2590] = {
    [sym_parameter] = STATE(7801),
    [sym__class_typed] = STATE(11860),
    [sym__parenthesized_abstract_type] = STATE(7801),
    [sym__simple_pattern] = STATE(7799),
    [sym_typed_pattern] = STATE(7796),
    [sym_polymorphic_variant_pattern] = STATE(7796),
    [sym_record_pattern] = STATE(7796),
    [sym_list_pattern] = STATE(7796),
    [sym_array_pattern] = STATE(7796),
    [sym_local_open_pattern] = STATE(7796),
    [sym_package_pattern] = STATE(7796),
    [sym_parenthesized_pattern] = STATE(7796),
    [sym_attribute] = STATE(2590),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(7796),
    [sym_quoted_extension] = STATE(7796),
    [sym__constant] = STATE(7794),
    [sym__signed_constant] = STATE(7796),
    [sym_number] = STATE(7775),
    [sym_signed_number] = STATE(7794),
    [sym_character] = STATE(7775),
    [sym_string] = STATE(7775),
    [sym_quoted_string] = STATE(7775),
    [sym_boolean] = STATE(7775),
    [sym_unit] = STATE(7775),
    [sym__simple_value_pattern] = STATE(7796),
    [sym_parenthesized_operator] = STATE(7796),
    [sym_module_path] = STATE(20457),
    [sym_constructor_path] = STATE(7796),
    [sym__constructor_name] = STATE(7774),
    [sym_tag] = STATE(7796),
    [aux_sym_expression_item_repeat1] = STATE(10434),
    [aux_sym_let_binding_repeat1] = STATE(2594),
    [ts_builtin_sym_end] = ACTIONS(7099),
    [sym__lowercase_identifier] = ACTIONS(7159),
    [anon_sym_SEMI_SEMI] = ACTIONS(7099),
    [anon_sym_and] = ACTIONS(7101),
    [anon_sym_EQ] = ACTIONS(7289),
    [anon_sym_TILDE] = ACTIONS(7163),
    [anon_sym_QMARK] = ACTIONS(7163),
    [anon_sym_LPAREN] = ACTIONS(7165),
    [anon_sym_external] = ACTIONS(7101),
    [anon_sym_type] = ACTIONS(7101),
    [anon_sym_LBRACK] = ACTIONS(7167),
    [anon_sym_true] = ACTIONS(7169),
    [anon_sym_false] = ACTIONS(7169),
    [anon_sym_COLON2] = ACTIONS(7171),
    [anon_sym_LBRACE] = ACTIONS(7173),
    [anon_sym_exception] = ACTIONS(7101),
    [anon_sym_module] = ACTIONS(7101),
    [anon_sym_open] = ACTIONS(7101),
    [anon_sym_include] = ACTIONS(7101),
    [anon_sym_class] = ACTIONS(7101),
    [anon_sym_val] = ACTIONS(7101),
    [anon_sym_POUND] = ACTIONS(7175),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7177),
    [anon_sym_begin] = ACTIONS(7179),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7099),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7181),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7183),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7099),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7099),
    [aux_sym_number_token1] = ACTIONS(7185),
    [aux_sym_signed_number_token1] = ACTIONS(7187),
    [anon_sym_SQUOTE] = ACTIONS(7189),
    [anon_sym_DQUOTE] = ACTIONS(7191),
    [sym__uppercase_identifier] = ACTIONS(7193),
    [aux_sym_tag_token1] = ACTIONS(7195),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2591] = {
    [sym_parameter] = STATE(7583),
    [sym__parenthesized_abstract_type] = STATE(7583),
    [sym__simple_pattern] = STATE(7579),
    [sym_typed_pattern] = STATE(7652),
    [sym_polymorphic_variant_pattern] = STATE(7652),
    [sym_record_pattern] = STATE(7652),
    [sym_list_pattern] = STATE(7652),
    [sym_array_pattern] = STATE(7652),
    [sym_local_open_pattern] = STATE(7652),
    [sym_package_pattern] = STATE(7652),
    [sym_parenthesized_pattern] = STATE(7652),
    [sym_attribute] = STATE(2591),
    [sym_extension] = STATE(7652),
    [sym_quoted_extension] = STATE(7652),
    [sym__constant] = STATE(7650),
    [sym__signed_constant] = STATE(7652),
    [sym_number] = STATE(7629),
    [sym_signed_number] = STATE(7650),
    [sym_character] = STATE(7629),
    [sym_string] = STATE(7629),
    [sym_quoted_string] = STATE(7629),
    [sym_boolean] = STATE(7629),
    [sym_unit] = STATE(7629),
    [sym__simple_value_pattern] = STATE(7652),
    [sym_parenthesized_operator] = STATE(7652),
    [sym_module_path] = STATE(19315),
    [sym_constructor_path] = STATE(7652),
    [sym__constructor_name] = STATE(7651),
    [sym_tag] = STATE(7652),
    [aux_sym_let_binding_repeat1] = STATE(2591),
    [sym__lowercase_identifier] = ACTIONS(7291),
    [anon_sym_SEMI_SEMI] = ACTIONS(7294),
    [anon_sym_let] = ACTIONS(7296),
    [anon_sym_and] = ACTIONS(7296),
    [anon_sym_EQ] = ACTIONS(7294),
    [anon_sym_TILDE] = ACTIONS(7298),
    [anon_sym_QMARK] = ACTIONS(7298),
    [anon_sym_LPAREN] = ACTIONS(7301),
    [anon_sym_external] = ACTIONS(7296),
    [anon_sym_type] = ACTIONS(7296),
    [anon_sym_LBRACK] = ACTIONS(7304),
    [anon_sym_RBRACK] = ACTIONS(7294),
    [anon_sym_true] = ACTIONS(7307),
    [anon_sym_false] = ACTIONS(7307),
    [anon_sym_COLON2] = ACTIONS(7294),
    [anon_sym_LBRACE] = ACTIONS(7310),
    [anon_sym_exception] = ACTIONS(7296),
    [anon_sym_module] = ACTIONS(7296),
    [anon_sym_open] = ACTIONS(7296),
    [anon_sym_include] = ACTIONS(7296),
    [anon_sym_class] = ACTIONS(7296),
    [anon_sym_POUND] = ACTIONS(7313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7316),
    [anon_sym_begin] = ACTIONS(7319),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(7296),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7294),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7322),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7325),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7294),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7328),
    [aux_sym_signed_number_token1] = ACTIONS(7331),
    [anon_sym_SQUOTE] = ACTIONS(7334),
    [anon_sym_DQUOTE] = ACTIONS(7337),
    [sym_let_operator] = ACTIONS(7294),
    [sym__uppercase_identifier] = ACTIONS(7340),
    [aux_sym_directive_token1] = ACTIONS(7296),
    [aux_sym_tag_token1] = ACTIONS(7343),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2592] = {
    [sym_parameter] = STATE(7522),
    [sym__parenthesized_abstract_type] = STATE(7522),
    [sym__simple_pattern] = STATE(7538),
    [sym_typed_pattern] = STATE(7593),
    [sym_polymorphic_variant_pattern] = STATE(7593),
    [sym_record_pattern] = STATE(7593),
    [sym_list_pattern] = STATE(7593),
    [sym_array_pattern] = STATE(7593),
    [sym_local_open_pattern] = STATE(7593),
    [sym_package_pattern] = STATE(7593),
    [sym_parenthesized_pattern] = STATE(7593),
    [sym_attribute] = STATE(2592),
    [sym_extension] = STATE(7593),
    [sym_quoted_extension] = STATE(7593),
    [sym__constant] = STATE(7549),
    [sym__signed_constant] = STATE(7593),
    [sym_number] = STATE(7628),
    [sym_signed_number] = STATE(7549),
    [sym_character] = STATE(7628),
    [sym_string] = STATE(7628),
    [sym_quoted_string] = STATE(7628),
    [sym_boolean] = STATE(7628),
    [sym_unit] = STATE(7628),
    [sym__simple_value_pattern] = STATE(7593),
    [sym_parenthesized_operator] = STATE(7593),
    [sym_module_path] = STATE(19032),
    [sym_constructor_path] = STATE(7593),
    [sym__constructor_name] = STATE(7627),
    [sym_tag] = STATE(7593),
    [aux_sym_let_binding_repeat1] = STATE(2592),
    [sym__lowercase_identifier] = ACTIONS(7346),
    [anon_sym_SEMI_SEMI] = ACTIONS(7294),
    [anon_sym_let] = ACTIONS(7296),
    [anon_sym_and] = ACTIONS(7296),
    [anon_sym_EQ] = ACTIONS(7294),
    [anon_sym_TILDE] = ACTIONS(7349),
    [anon_sym_QMARK] = ACTIONS(7349),
    [anon_sym_LPAREN] = ACTIONS(7352),
    [anon_sym_external] = ACTIONS(7296),
    [anon_sym_type] = ACTIONS(7296),
    [anon_sym_LBRACK] = ACTIONS(7355),
    [anon_sym_true] = ACTIONS(7358),
    [anon_sym_false] = ACTIONS(7358),
    [anon_sym_COLON2] = ACTIONS(7294),
    [anon_sym_LBRACE] = ACTIONS(7361),
    [anon_sym_exception] = ACTIONS(7296),
    [anon_sym_module] = ACTIONS(7296),
    [anon_sym_open] = ACTIONS(7296),
    [anon_sym_include] = ACTIONS(7296),
    [anon_sym_class] = ACTIONS(7296),
    [anon_sym_end] = ACTIONS(7296),
    [anon_sym_POUND] = ACTIONS(7364),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7367),
    [anon_sym_begin] = ACTIONS(7370),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(7296),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7294),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7373),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7376),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7294),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7379),
    [aux_sym_signed_number_token1] = ACTIONS(7382),
    [anon_sym_SQUOTE] = ACTIONS(7385),
    [anon_sym_DQUOTE] = ACTIONS(7388),
    [sym_let_operator] = ACTIONS(7294),
    [sym__uppercase_identifier] = ACTIONS(7391),
    [aux_sym_directive_token1] = ACTIONS(7296),
    [aux_sym_tag_token1] = ACTIONS(7394),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2593] = {
    [sym__parenthesized_abstract_type] = STATE(3496),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13135),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2593),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2593),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2597),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(7151),
    [anon_sym_COMMA] = ACTIONS(7149),
    [anon_sym_PIPE] = ACTIONS(7149),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_RBRACK] = ACTIONS(7149),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_SEMI] = ACTIONS(7149),
    [anon_sym_RBRACE] = ACTIONS(7149),
    [anon_sym_exception] = ACTIONS(7397),
    [anon_sym_as] = ACTIONS(7153),
    [anon_sym_POUND] = ACTIONS(7399),
    [anon_sym_COLON_COLON] = ACTIONS(7149),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(7401),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(7403),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7405),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7407),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2594] = {
    [sym_parameter] = STATE(7801),
    [sym__parenthesized_abstract_type] = STATE(7801),
    [sym__simple_pattern] = STATE(7799),
    [sym_typed_pattern] = STATE(7796),
    [sym_polymorphic_variant_pattern] = STATE(7796),
    [sym_record_pattern] = STATE(7796),
    [sym_list_pattern] = STATE(7796),
    [sym_array_pattern] = STATE(7796),
    [sym_local_open_pattern] = STATE(7796),
    [sym_package_pattern] = STATE(7796),
    [sym_parenthesized_pattern] = STATE(7796),
    [sym_attribute] = STATE(2594),
    [sym_extension] = STATE(7796),
    [sym_quoted_extension] = STATE(7796),
    [sym__constant] = STATE(7794),
    [sym__signed_constant] = STATE(7796),
    [sym_number] = STATE(7775),
    [sym_signed_number] = STATE(7794),
    [sym_character] = STATE(7775),
    [sym_string] = STATE(7775),
    [sym_quoted_string] = STATE(7775),
    [sym_boolean] = STATE(7775),
    [sym_unit] = STATE(7775),
    [sym__simple_value_pattern] = STATE(7796),
    [sym_parenthesized_operator] = STATE(7796),
    [sym_module_path] = STATE(20457),
    [sym_constructor_path] = STATE(7796),
    [sym__constructor_name] = STATE(7774),
    [sym_tag] = STATE(7796),
    [aux_sym_let_binding_repeat1] = STATE(2594),
    [ts_builtin_sym_end] = ACTIONS(7294),
    [sym__lowercase_identifier] = ACTIONS(7411),
    [anon_sym_SEMI_SEMI] = ACTIONS(7294),
    [anon_sym_and] = ACTIONS(7296),
    [anon_sym_EQ] = ACTIONS(7294),
    [anon_sym_TILDE] = ACTIONS(7414),
    [anon_sym_QMARK] = ACTIONS(7414),
    [anon_sym_LPAREN] = ACTIONS(7417),
    [anon_sym_external] = ACTIONS(7296),
    [anon_sym_type] = ACTIONS(7296),
    [anon_sym_LBRACK] = ACTIONS(7420),
    [anon_sym_RBRACK] = ACTIONS(7294),
    [anon_sym_true] = ACTIONS(7423),
    [anon_sym_false] = ACTIONS(7423),
    [anon_sym_COLON2] = ACTIONS(7294),
    [anon_sym_LBRACE] = ACTIONS(7426),
    [anon_sym_exception] = ACTIONS(7296),
    [anon_sym_module] = ACTIONS(7296),
    [anon_sym_open] = ACTIONS(7296),
    [anon_sym_include] = ACTIONS(7296),
    [anon_sym_class] = ACTIONS(7296),
    [anon_sym_val] = ACTIONS(7296),
    [anon_sym_POUND] = ACTIONS(7429),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7432),
    [anon_sym_begin] = ACTIONS(7435),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(7296),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7294),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7438),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7441),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7294),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7444),
    [aux_sym_signed_number_token1] = ACTIONS(7447),
    [anon_sym_SQUOTE] = ACTIONS(7450),
    [anon_sym_DQUOTE] = ACTIONS(7453),
    [sym__uppercase_identifier] = ACTIONS(7456),
    [aux_sym_tag_token1] = ACTIONS(7459),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2595] = {
    [sym_parameter] = STATE(7869),
    [sym__parenthesized_abstract_type] = STATE(7869),
    [sym__simple_pattern] = STATE(7868),
    [sym_typed_pattern] = STATE(8089),
    [sym_polymorphic_variant_pattern] = STATE(8089),
    [sym_record_pattern] = STATE(8089),
    [sym_list_pattern] = STATE(8089),
    [sym_array_pattern] = STATE(8089),
    [sym_local_open_pattern] = STATE(8089),
    [sym_package_pattern] = STATE(8089),
    [sym_parenthesized_pattern] = STATE(8089),
    [sym_attribute] = STATE(2595),
    [sym_extension] = STATE(8089),
    [sym_quoted_extension] = STATE(8089),
    [sym__constant] = STATE(8037),
    [sym__signed_constant] = STATE(8089),
    [sym_number] = STATE(8039),
    [sym_signed_number] = STATE(8037),
    [sym_character] = STATE(8039),
    [sym_string] = STATE(8039),
    [sym_quoted_string] = STATE(8039),
    [sym_boolean] = STATE(8039),
    [sym_unit] = STATE(8039),
    [sym__simple_value_pattern] = STATE(8089),
    [sym_parenthesized_operator] = STATE(8089),
    [sym_module_path] = STATE(18728),
    [sym_constructor_path] = STATE(8089),
    [sym__constructor_name] = STATE(8040),
    [sym_tag] = STATE(8089),
    [aux_sym_let_binding_repeat1] = STATE(2595),
    [sym__lowercase_identifier] = ACTIONS(7462),
    [anon_sym_SEMI_SEMI] = ACTIONS(7294),
    [anon_sym_and] = ACTIONS(7296),
    [anon_sym_EQ] = ACTIONS(7294),
    [anon_sym_TILDE] = ACTIONS(7465),
    [anon_sym_QMARK] = ACTIONS(7465),
    [anon_sym_LPAREN] = ACTIONS(7468),
    [anon_sym_external] = ACTIONS(7296),
    [anon_sym_type] = ACTIONS(7296),
    [anon_sym_LBRACK] = ACTIONS(7471),
    [anon_sym_true] = ACTIONS(7474),
    [anon_sym_false] = ACTIONS(7474),
    [anon_sym_COLON2] = ACTIONS(7294),
    [anon_sym_LBRACE] = ACTIONS(7477),
    [anon_sym_exception] = ACTIONS(7296),
    [anon_sym_module] = ACTIONS(7296),
    [anon_sym_open] = ACTIONS(7296),
    [anon_sym_include] = ACTIONS(7296),
    [anon_sym_class] = ACTIONS(7296),
    [anon_sym_val] = ACTIONS(7296),
    [anon_sym_end] = ACTIONS(7296),
    [anon_sym_POUND] = ACTIONS(7480),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7483),
    [anon_sym_begin] = ACTIONS(7486),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(7296),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7294),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7492),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7294),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7495),
    [aux_sym_signed_number_token1] = ACTIONS(7498),
    [anon_sym_SQUOTE] = ACTIONS(7501),
    [anon_sym_DQUOTE] = ACTIONS(7504),
    [sym__uppercase_identifier] = ACTIONS(7507),
    [aux_sym_tag_token1] = ACTIONS(7510),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2596] = {
    [sym__binding_pattern] = STATE(8878),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2596),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_and] = ACTIONS(5079),
    [anon_sym_COLON_GT] = ACTIONS(5077),
    [anon_sym_EQ] = ACTIONS(5077),
    [anon_sym_TILDE] = ACTIONS(5077),
    [anon_sym_QMARK] = ACTIONS(5077),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_COMMA] = ACTIONS(5077),
    [anon_sym_PIPE] = ACTIONS(5077),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_COLON2] = ACTIONS(5079),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_in] = ACTIONS(5079),
    [anon_sym_as] = ACTIONS(5079),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_COLON_COLON] = ACTIONS(5077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5077),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym_let_and_operator] = ACTIONS(5077),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2597] = {
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(12978),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2597),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2593),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2597),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_COMMA] = ACTIONS(7149),
    [anon_sym_PIPE] = ACTIONS(7149),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_RBRACK] = ACTIONS(7149),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_SEMI] = ACTIONS(7149),
    [anon_sym_RBRACE] = ACTIONS(7149),
    [anon_sym_exception] = ACTIONS(7397),
    [anon_sym_as] = ACTIONS(7153),
    [anon_sym_POUND] = ACTIONS(7399),
    [anon_sym_COLON_COLON] = ACTIONS(7149),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(7401),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(7403),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7405),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7407),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2598] = {
    [sym__parenthesized_abstract_type] = STATE(3627),
    [sym__simple_pattern] = STATE(14103),
    [sym__effect_pattern] = STATE(14108),
    [sym__pattern] = STATE(14110),
    [sym_alias_pattern] = STATE(14108),
    [sym_typed_pattern] = STATE(13926),
    [sym_or_pattern] = STATE(14108),
    [sym_constructor_pattern] = STATE(14103),
    [sym_tag_pattern] = STATE(14103),
    [sym_polymorphic_variant_pattern] = STATE(13926),
    [sym_tuple_pattern] = STATE(14108),
    [sym_record_pattern] = STATE(13926),
    [sym_list_pattern] = STATE(13926),
    [sym_cons_pattern] = STATE(14108),
    [sym_array_pattern] = STATE(13926),
    [sym_range_pattern] = STATE(14108),
    [sym_lazy_pattern] = STATE(14103),
    [sym_local_open_pattern] = STATE(13926),
    [sym_package_pattern] = STATE(13926),
    [sym_parenthesized_pattern] = STATE(13926),
    [sym_exception_pattern] = STATE(14108),
    [sym_effect_pattern] = STATE(14108),
    [sym_attribute] = STATE(2598),
    [sym_extension] = STATE(13926),
    [sym_quoted_extension] = STATE(13926),
    [sym__constant] = STATE(13604),
    [sym__signed_constant] = STATE(13607),
    [sym_number] = STATE(13737),
    [sym_signed_number] = STATE(13604),
    [sym_character] = STATE(13737),
    [sym_string] = STATE(13737),
    [sym_quoted_string] = STATE(13737),
    [sym_boolean] = STATE(13737),
    [sym_unit] = STATE(13737),
    [sym__simple_value_pattern] = STATE(13926),
    [sym_parenthesized_operator] = STATE(13926),
    [sym_module_path] = STATE(19855),
    [sym_constructor_path] = STATE(2598),
    [sym__constructor_name] = STATE(9510),
    [sym_tag] = STATE(2600),
    [sym__lowercase_identifier] = ACTIONS(7547),
    [anon_sym_LPAREN] = ACTIONS(7549),
    [anon_sym_COMMA] = ACTIONS(7149),
    [anon_sym_PIPE] = ACTIONS(7153),
    [anon_sym_LBRACK] = ACTIONS(7551),
    [anon_sym_true] = ACTIONS(7553),
    [anon_sym_false] = ACTIONS(7553),
    [anon_sym_LBRACE] = ACTIONS(7555),
    [anon_sym_SEMI] = ACTIONS(7149),
    [anon_sym_exception] = ACTIONS(7557),
    [anon_sym_as] = ACTIONS(7153),
    [anon_sym_POUND] = ACTIONS(7559),
    [anon_sym_COLON_COLON] = ACTIONS(7149),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7561),
    [anon_sym_PIPE_RBRACK] = ACTIONS(7149),
    [anon_sym_lazy] = ACTIONS(7563),
    [anon_sym_begin] = ACTIONS(7565),
    [anon_sym_effect] = ACTIONS(7567),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7569),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7571),
    [aux_sym_number_token1] = ACTIONS(7573),
    [aux_sym_signed_number_token1] = ACTIONS(7575),
    [anon_sym_SQUOTE] = ACTIONS(7577),
    [anon_sym_DQUOTE] = ACTIONS(7579),
    [sym__uppercase_identifier] = ACTIONS(7581),
    [aux_sym_tag_token1] = ACTIONS(7583),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2599] = {
    [sym__binding_pattern] = STATE(8881),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2599),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_and] = ACTIONS(5079),
    [anon_sym_COLON_GT] = ACTIONS(5077),
    [anon_sym_EQ] = ACTIONS(5077),
    [anon_sym_TILDE] = ACTIONS(5077),
    [anon_sym_QMARK] = ACTIONS(5077),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_COMMA] = ACTIONS(5077),
    [anon_sym_PIPE] = ACTIONS(5077),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_COLON2] = ACTIONS(5079),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_in] = ACTIONS(5079),
    [anon_sym_as] = ACTIONS(5079),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_COLON_COLON] = ACTIONS(5077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5077),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym_let_and_operator] = ACTIONS(5077),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2600] = {
    [sym__simple_pattern] = STATE(14103),
    [sym__effect_pattern] = STATE(14108),
    [sym__pattern] = STATE(14093),
    [sym_alias_pattern] = STATE(14108),
    [sym_typed_pattern] = STATE(13926),
    [sym_or_pattern] = STATE(14108),
    [sym_constructor_pattern] = STATE(14103),
    [sym_tag_pattern] = STATE(14103),
    [sym_polymorphic_variant_pattern] = STATE(13926),
    [sym_tuple_pattern] = STATE(14108),
    [sym_record_pattern] = STATE(13926),
    [sym_list_pattern] = STATE(13926),
    [sym_cons_pattern] = STATE(14108),
    [sym_array_pattern] = STATE(13926),
    [sym_range_pattern] = STATE(14108),
    [sym_lazy_pattern] = STATE(14103),
    [sym_local_open_pattern] = STATE(13926),
    [sym_package_pattern] = STATE(13926),
    [sym_parenthesized_pattern] = STATE(13926),
    [sym_exception_pattern] = STATE(14108),
    [sym_effect_pattern] = STATE(14108),
    [sym_attribute] = STATE(2600),
    [sym_extension] = STATE(13926),
    [sym_quoted_extension] = STATE(13926),
    [sym__constant] = STATE(13604),
    [sym__signed_constant] = STATE(13607),
    [sym_number] = STATE(13737),
    [sym_signed_number] = STATE(13604),
    [sym_character] = STATE(13737),
    [sym_string] = STATE(13737),
    [sym_quoted_string] = STATE(13737),
    [sym_boolean] = STATE(13737),
    [sym_unit] = STATE(13737),
    [sym__simple_value_pattern] = STATE(13926),
    [sym_parenthesized_operator] = STATE(13926),
    [sym_module_path] = STATE(19855),
    [sym_constructor_path] = STATE(2598),
    [sym__constructor_name] = STATE(9510),
    [sym_tag] = STATE(2600),
    [sym__lowercase_identifier] = ACTIONS(7547),
    [anon_sym_LPAREN] = ACTIONS(7585),
    [anon_sym_COMMA] = ACTIONS(7149),
    [anon_sym_PIPE] = ACTIONS(7153),
    [anon_sym_LBRACK] = ACTIONS(7551),
    [anon_sym_true] = ACTIONS(7553),
    [anon_sym_false] = ACTIONS(7553),
    [anon_sym_LBRACE] = ACTIONS(7555),
    [anon_sym_SEMI] = ACTIONS(7149),
    [anon_sym_exception] = ACTIONS(7557),
    [anon_sym_as] = ACTIONS(7153),
    [anon_sym_POUND] = ACTIONS(7559),
    [anon_sym_COLON_COLON] = ACTIONS(7149),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7561),
    [anon_sym_PIPE_RBRACK] = ACTIONS(7149),
    [anon_sym_lazy] = ACTIONS(7563),
    [anon_sym_begin] = ACTIONS(7565),
    [anon_sym_effect] = ACTIONS(7567),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7569),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7571),
    [aux_sym_number_token1] = ACTIONS(7573),
    [aux_sym_signed_number_token1] = ACTIONS(7575),
    [anon_sym_SQUOTE] = ACTIONS(7577),
    [anon_sym_DQUOTE] = ACTIONS(7579),
    [sym__uppercase_identifier] = ACTIONS(7581),
    [aux_sym_tag_token1] = ACTIONS(7583),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2601] = {
    [sym_parameter] = STATE(8645),
    [sym__polymorphic_typed] = STATE(12884),
    [sym__parenthesized_abstract_type] = STATE(8645),
    [sym__simple_pattern] = STATE(8641),
    [sym_typed_pattern] = STATE(8762),
    [sym_polymorphic_variant_pattern] = STATE(8762),
    [sym_record_pattern] = STATE(8762),
    [sym_list_pattern] = STATE(8762),
    [sym_array_pattern] = STATE(8762),
    [sym_local_open_pattern] = STATE(8762),
    [sym_package_pattern] = STATE(8762),
    [sym_parenthesized_pattern] = STATE(8762),
    [sym_attribute] = STATE(2601),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(8762),
    [sym_quoted_extension] = STATE(8762),
    [sym__constant] = STATE(8707),
    [sym__signed_constant] = STATE(8762),
    [sym_number] = STATE(8756),
    [sym_signed_number] = STATE(8707),
    [sym_character] = STATE(8756),
    [sym_string] = STATE(8756),
    [sym_quoted_string] = STATE(8756),
    [sym_boolean] = STATE(8756),
    [sym_unit] = STATE(8756),
    [sym__simple_value_pattern] = STATE(8762),
    [sym_parenthesized_operator] = STATE(8762),
    [sym_module_path] = STATE(18492),
    [sym_constructor_path] = STATE(8762),
    [sym__constructor_name] = STATE(8748),
    [sym_tag] = STATE(8762),
    [aux_sym_expression_item_repeat1] = STATE(12991),
    [aux_sym_let_binding_repeat1] = STATE(2955),
    [sym__lowercase_identifier] = ACTIONS(7587),
    [anon_sym_EQ] = ACTIONS(7589),
    [anon_sym_TILDE] = ACTIONS(7591),
    [anon_sym_QMARK] = ACTIONS(7591),
    [anon_sym_LPAREN] = ACTIONS(7593),
    [anon_sym_LBRACK] = ACTIONS(7595),
    [anon_sym_true] = ACTIONS(7597),
    [anon_sym_false] = ACTIONS(7597),
    [anon_sym_COLON2] = ACTIONS(7599),
    [anon_sym_LBRACE] = ACTIONS(7601),
    [anon_sym_constraint] = ACTIONS(7603),
    [anon_sym_val] = ACTIONS(7603),
    [anon_sym_end] = ACTIONS(7603),
    [anon_sym_inherit] = ACTIONS(7603),
    [anon_sym_method] = ACTIONS(7603),
    [anon_sym_initializer] = ACTIONS(7603),
    [anon_sym_POUND] = ACTIONS(7605),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7607),
    [anon_sym_begin] = ACTIONS(7609),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7611),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7613),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7615),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7611),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7611),
    [aux_sym_number_token1] = ACTIONS(7617),
    [aux_sym_signed_number_token1] = ACTIONS(7619),
    [anon_sym_SQUOTE] = ACTIONS(7621),
    [anon_sym_DQUOTE] = ACTIONS(7623),
    [sym__uppercase_identifier] = ACTIONS(7625),
    [aux_sym_tag_token1] = ACTIONS(7627),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2602] = {
    [sym__match_cases] = STATE(8110),
    [sym_match_case] = STATE(9395),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13787),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2602),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2834),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7629),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2603] = {
    [sym__match_cases] = STATE(8110),
    [sym_match_case] = STATE(10366),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13570),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2603),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2872),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7633),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2604] = {
    [sym__match_cases] = STATE(8131),
    [sym_match_case] = STATE(8374),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13600),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2604),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2700),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7635),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2605] = {
    [sym__match_cases] = STATE(8131),
    [sym_match_case] = STATE(8178),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13716),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2605),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2873),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7637),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2606] = {
    [sym__match_cases] = STATE(7863),
    [sym_match_case] = STATE(12430),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13779),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2606),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2776),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7639),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2607] = {
    [sym__match_cases] = STATE(10488),
    [sym_match_case] = STATE(11117),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13514),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2607),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2707),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7641),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2608] = {
    [sym__match_cases] = STATE(7863),
    [sym_match_case] = STATE(12340),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13803),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2608),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2806),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7643),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2609] = {
    [sym__match_cases] = STATE(7863),
    [sym_match_case] = STATE(9564),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13567),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2609),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2802),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7645),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2610] = {
    [sym__match_cases] = STATE(7863),
    [sym_match_case] = STATE(12431),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13650),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2610),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2765),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7647),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2611] = {
    [sym__match_cases] = STATE(7863),
    [sym_match_case] = STATE(12037),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13665),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2611),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2886),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7649),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2612] = {
    [sym__match_cases] = STATE(8131),
    [sym_match_case] = STATE(8226),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13545),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2612),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2708),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7651),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2613] = {
    [sym__match_cases] = STATE(7863),
    [sym_match_case] = STATE(11987),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13814),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2613),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2800),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7653),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2614] = {
    [sym__match_cases] = STATE(8110),
    [sym_match_case] = STATE(11924),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13743),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2614),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2740),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7655),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2615] = {
    [sym__match_cases] = STATE(10488),
    [sym_match_case] = STATE(12319),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13698),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2615),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2887),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7657),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2616] = {
    [sym__match_cases] = STATE(8131),
    [sym_match_case] = STATE(8352),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13563),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2616),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2796),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7659),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2617] = {
    [sym__match_cases] = STATE(8131),
    [sym_match_case] = STATE(8473),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13530),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2617),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2866),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7661),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2618] = {
    [sym__match_cases] = STATE(8110),
    [sym_match_case] = STATE(12340),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13803),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2618),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2761),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7643),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2619] = {
    [sym__match_cases] = STATE(8110),
    [sym_match_case] = STATE(10338),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13597),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2619),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2730),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7663),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2620] = {
    [sym__match_cases] = STATE(8110),
    [sym_match_case] = STATE(12431),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13650),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2620),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2810),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7647),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2621] = {
    [sym__match_cases] = STATE(8110),
    [sym_match_case] = STATE(9564),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13567),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2621),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2883),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7645),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2622] = {
    [sym__match_cases] = STATE(7863),
    [sym_match_case] = STATE(12151),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13546),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2622),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2742),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7665),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2623] = {
    [sym__match_cases] = STATE(10488),
    [sym_match_case] = STATE(11762),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13595),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2623),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2775),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7667),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2624] = {
    [sym__match_cases] = STATE(8110),
    [sym_match_case] = STATE(12430),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13779),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2624),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2825),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7639),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2625] = {
    [sym__match_cases] = STATE(8110),
    [sym_match_case] = STATE(12151),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13546),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2625),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2773),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7665),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2626] = {
    [sym__match_cases] = STATE(7863),
    [sym_match_case] = STATE(9395),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13787),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2626),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2733),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7629),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2627] = {
    [sym_parameter] = STATE(8645),
    [sym__polymorphic_typed] = STATE(12869),
    [sym__parenthesized_abstract_type] = STATE(8645),
    [sym__simple_pattern] = STATE(8641),
    [sym_typed_pattern] = STATE(8762),
    [sym_polymorphic_variant_pattern] = STATE(8762),
    [sym_record_pattern] = STATE(8762),
    [sym_list_pattern] = STATE(8762),
    [sym_array_pattern] = STATE(8762),
    [sym_local_open_pattern] = STATE(8762),
    [sym_package_pattern] = STATE(8762),
    [sym_parenthesized_pattern] = STATE(8762),
    [sym_attribute] = STATE(2627),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(8762),
    [sym_quoted_extension] = STATE(8762),
    [sym__constant] = STATE(8707),
    [sym__signed_constant] = STATE(8762),
    [sym_number] = STATE(8756),
    [sym_signed_number] = STATE(8707),
    [sym_character] = STATE(8756),
    [sym_string] = STATE(8756),
    [sym_quoted_string] = STATE(8756),
    [sym_boolean] = STATE(8756),
    [sym_unit] = STATE(8756),
    [sym__simple_value_pattern] = STATE(8762),
    [sym_parenthesized_operator] = STATE(8762),
    [sym_module_path] = STATE(18492),
    [sym_constructor_path] = STATE(8762),
    [sym__constructor_name] = STATE(8748),
    [sym_tag] = STATE(8762),
    [aux_sym_expression_item_repeat1] = STATE(13021),
    [aux_sym_let_binding_repeat1] = STATE(2637),
    [sym__lowercase_identifier] = ACTIONS(7587),
    [anon_sym_EQ] = ACTIONS(7669),
    [anon_sym_TILDE] = ACTIONS(7591),
    [anon_sym_QMARK] = ACTIONS(7591),
    [anon_sym_LPAREN] = ACTIONS(7593),
    [anon_sym_LBRACK] = ACTIONS(7595),
    [anon_sym_true] = ACTIONS(7597),
    [anon_sym_false] = ACTIONS(7597),
    [anon_sym_COLON2] = ACTIONS(7599),
    [anon_sym_LBRACE] = ACTIONS(7601),
    [anon_sym_constraint] = ACTIONS(7671),
    [anon_sym_val] = ACTIONS(7671),
    [anon_sym_end] = ACTIONS(7671),
    [anon_sym_inherit] = ACTIONS(7671),
    [anon_sym_method] = ACTIONS(7671),
    [anon_sym_initializer] = ACTIONS(7671),
    [anon_sym_POUND] = ACTIONS(7605),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7607),
    [anon_sym_begin] = ACTIONS(7609),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7673),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7613),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7615),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7673),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7673),
    [aux_sym_number_token1] = ACTIONS(7617),
    [aux_sym_signed_number_token1] = ACTIONS(7619),
    [anon_sym_SQUOTE] = ACTIONS(7621),
    [anon_sym_DQUOTE] = ACTIONS(7623),
    [sym__uppercase_identifier] = ACTIONS(7625),
    [aux_sym_tag_token1] = ACTIONS(7627),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2628] = {
    [sym__match_cases] = STATE(8131),
    [sym_match_case] = STATE(8461),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13747),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2628),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2915),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7675),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2629] = {
    [sym__match_cases] = STATE(7863),
    [sym_match_case] = STATE(10366),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13570),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2629),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2735),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7633),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2630] = {
    [sym__match_cases] = STATE(8131),
    [sym_match_case] = STATE(8310),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13788),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2630),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2922),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7677),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2631] = {
    [sym__match_cases] = STATE(8131),
    [sym_match_case] = STATE(8341),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13801),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2631),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2836),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7679),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2632] = {
    [sym__match_cases] = STATE(7863),
    [sym_match_case] = STATE(12234),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13634),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2632),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2718),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7681),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2633] = {
    [sym_parameter] = STATE(8645),
    [sym__polymorphic_typed] = STATE(12852),
    [sym__parenthesized_abstract_type] = STATE(8645),
    [sym__simple_pattern] = STATE(8641),
    [sym_typed_pattern] = STATE(8762),
    [sym_polymorphic_variant_pattern] = STATE(8762),
    [sym_record_pattern] = STATE(8762),
    [sym_list_pattern] = STATE(8762),
    [sym_array_pattern] = STATE(8762),
    [sym_local_open_pattern] = STATE(8762),
    [sym_package_pattern] = STATE(8762),
    [sym_parenthesized_pattern] = STATE(8762),
    [sym_attribute] = STATE(2633),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(8762),
    [sym_quoted_extension] = STATE(8762),
    [sym__constant] = STATE(8707),
    [sym__signed_constant] = STATE(8762),
    [sym_number] = STATE(8756),
    [sym_signed_number] = STATE(8707),
    [sym_character] = STATE(8756),
    [sym_string] = STATE(8756),
    [sym_quoted_string] = STATE(8756),
    [sym_boolean] = STATE(8756),
    [sym_unit] = STATE(8756),
    [sym__simple_value_pattern] = STATE(8762),
    [sym_parenthesized_operator] = STATE(8762),
    [sym_module_path] = STATE(18492),
    [sym_constructor_path] = STATE(8762),
    [sym__constructor_name] = STATE(8748),
    [sym_tag] = STATE(8762),
    [aux_sym_expression_item_repeat1] = STATE(13044),
    [aux_sym_let_binding_repeat1] = STATE(2955),
    [sym__lowercase_identifier] = ACTIONS(7587),
    [anon_sym_EQ] = ACTIONS(7683),
    [anon_sym_TILDE] = ACTIONS(7591),
    [anon_sym_QMARK] = ACTIONS(7591),
    [anon_sym_LPAREN] = ACTIONS(7593),
    [anon_sym_LBRACK] = ACTIONS(7595),
    [anon_sym_true] = ACTIONS(7597),
    [anon_sym_false] = ACTIONS(7597),
    [anon_sym_COLON2] = ACTIONS(7599),
    [anon_sym_LBRACE] = ACTIONS(7601),
    [anon_sym_constraint] = ACTIONS(7685),
    [anon_sym_val] = ACTIONS(7685),
    [anon_sym_end] = ACTIONS(7685),
    [anon_sym_inherit] = ACTIONS(7685),
    [anon_sym_method] = ACTIONS(7685),
    [anon_sym_initializer] = ACTIONS(7685),
    [anon_sym_POUND] = ACTIONS(7605),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7607),
    [anon_sym_begin] = ACTIONS(7609),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7687),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7613),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7615),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7687),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7687),
    [aux_sym_number_token1] = ACTIONS(7617),
    [aux_sym_signed_number_token1] = ACTIONS(7619),
    [anon_sym_SQUOTE] = ACTIONS(7621),
    [anon_sym_DQUOTE] = ACTIONS(7623),
    [sym__uppercase_identifier] = ACTIONS(7625),
    [aux_sym_tag_token1] = ACTIONS(7627),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2634] = {
    [sym__match_cases] = STATE(8131),
    [sym_match_case] = STATE(8674),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13641),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2634),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2859),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7689),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2635] = {
    [sym__match_cases] = STATE(8110),
    [sym_match_case] = STATE(12086),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13606),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2635),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2758),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7691),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2636] = {
    [sym__match_cases] = STATE(7863),
    [sym_match_case] = STATE(12086),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13606),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2636),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2729),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7691),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2637] = {
    [sym_parameter] = STATE(8645),
    [sym__polymorphic_typed] = STATE(12907),
    [sym__parenthesized_abstract_type] = STATE(8645),
    [sym__simple_pattern] = STATE(8641),
    [sym_typed_pattern] = STATE(8762),
    [sym_polymorphic_variant_pattern] = STATE(8762),
    [sym_record_pattern] = STATE(8762),
    [sym_list_pattern] = STATE(8762),
    [sym_array_pattern] = STATE(8762),
    [sym_local_open_pattern] = STATE(8762),
    [sym_package_pattern] = STATE(8762),
    [sym_parenthesized_pattern] = STATE(8762),
    [sym_attribute] = STATE(2637),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(8762),
    [sym_quoted_extension] = STATE(8762),
    [sym__constant] = STATE(8707),
    [sym__signed_constant] = STATE(8762),
    [sym_number] = STATE(8756),
    [sym_signed_number] = STATE(8707),
    [sym_character] = STATE(8756),
    [sym_string] = STATE(8756),
    [sym_quoted_string] = STATE(8756),
    [sym_boolean] = STATE(8756),
    [sym_unit] = STATE(8756),
    [sym__simple_value_pattern] = STATE(8762),
    [sym_parenthesized_operator] = STATE(8762),
    [sym_module_path] = STATE(18492),
    [sym_constructor_path] = STATE(8762),
    [sym__constructor_name] = STATE(8748),
    [sym_tag] = STATE(8762),
    [aux_sym_expression_item_repeat1] = STATE(13000),
    [aux_sym_let_binding_repeat1] = STATE(2955),
    [sym__lowercase_identifier] = ACTIONS(7587),
    [anon_sym_EQ] = ACTIONS(7693),
    [anon_sym_TILDE] = ACTIONS(7591),
    [anon_sym_QMARK] = ACTIONS(7591),
    [anon_sym_LPAREN] = ACTIONS(7593),
    [anon_sym_LBRACK] = ACTIONS(7595),
    [anon_sym_true] = ACTIONS(7597),
    [anon_sym_false] = ACTIONS(7597),
    [anon_sym_COLON2] = ACTIONS(7599),
    [anon_sym_LBRACE] = ACTIONS(7601),
    [anon_sym_constraint] = ACTIONS(7695),
    [anon_sym_val] = ACTIONS(7695),
    [anon_sym_end] = ACTIONS(7695),
    [anon_sym_inherit] = ACTIONS(7695),
    [anon_sym_method] = ACTIONS(7695),
    [anon_sym_initializer] = ACTIONS(7695),
    [anon_sym_POUND] = ACTIONS(7605),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7607),
    [anon_sym_begin] = ACTIONS(7609),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7697),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7613),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7615),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7697),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7697),
    [aux_sym_number_token1] = ACTIONS(7617),
    [aux_sym_signed_number_token1] = ACTIONS(7619),
    [anon_sym_SQUOTE] = ACTIONS(7621),
    [anon_sym_DQUOTE] = ACTIONS(7623),
    [sym__uppercase_identifier] = ACTIONS(7625),
    [aux_sym_tag_token1] = ACTIONS(7627),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2638] = {
    [sym__match_cases] = STATE(8110),
    [sym_match_case] = STATE(11987),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13814),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2638),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2743),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7653),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2639] = {
    [sym__match_cases] = STATE(8131),
    [sym_match_case] = STATE(8682),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13561),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2639),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2815),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7699),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2640] = {
    [sym__match_cases] = STATE(7863),
    [sym_match_case] = STATE(10338),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13597),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2640),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2906),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7663),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2641] = {
    [sym__match_cases] = STATE(8131),
    [sym_match_case] = STATE(8418),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13682),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2641),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2878),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7701),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2642] = {
    [sym_parameter] = STATE(8645),
    [sym__polymorphic_typed] = STATE(12851),
    [sym__parenthesized_abstract_type] = STATE(8645),
    [sym__simple_pattern] = STATE(8641),
    [sym_typed_pattern] = STATE(8762),
    [sym_polymorphic_variant_pattern] = STATE(8762),
    [sym_record_pattern] = STATE(8762),
    [sym_list_pattern] = STATE(8762),
    [sym_array_pattern] = STATE(8762),
    [sym_local_open_pattern] = STATE(8762),
    [sym_package_pattern] = STATE(8762),
    [sym_parenthesized_pattern] = STATE(8762),
    [sym_attribute] = STATE(2642),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(8762),
    [sym_quoted_extension] = STATE(8762),
    [sym__constant] = STATE(8707),
    [sym__signed_constant] = STATE(8762),
    [sym_number] = STATE(8756),
    [sym_signed_number] = STATE(8707),
    [sym_character] = STATE(8756),
    [sym_string] = STATE(8756),
    [sym_quoted_string] = STATE(8756),
    [sym_boolean] = STATE(8756),
    [sym_unit] = STATE(8756),
    [sym__simple_value_pattern] = STATE(8762),
    [sym_parenthesized_operator] = STATE(8762),
    [sym_module_path] = STATE(18492),
    [sym_constructor_path] = STATE(8762),
    [sym__constructor_name] = STATE(8748),
    [sym_tag] = STATE(8762),
    [aux_sym_expression_item_repeat1] = STATE(13025),
    [aux_sym_let_binding_repeat1] = STATE(2601),
    [sym__lowercase_identifier] = ACTIONS(7587),
    [anon_sym_EQ] = ACTIONS(7703),
    [anon_sym_TILDE] = ACTIONS(7591),
    [anon_sym_QMARK] = ACTIONS(7591),
    [anon_sym_LPAREN] = ACTIONS(7593),
    [anon_sym_LBRACK] = ACTIONS(7595),
    [anon_sym_true] = ACTIONS(7597),
    [anon_sym_false] = ACTIONS(7597),
    [anon_sym_COLON2] = ACTIONS(7599),
    [anon_sym_LBRACE] = ACTIONS(7601),
    [anon_sym_constraint] = ACTIONS(7705),
    [anon_sym_val] = ACTIONS(7705),
    [anon_sym_end] = ACTIONS(7705),
    [anon_sym_inherit] = ACTIONS(7705),
    [anon_sym_method] = ACTIONS(7705),
    [anon_sym_initializer] = ACTIONS(7705),
    [anon_sym_POUND] = ACTIONS(7605),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7607),
    [anon_sym_begin] = ACTIONS(7609),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7707),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7613),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7615),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7707),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7707),
    [aux_sym_number_token1] = ACTIONS(7617),
    [aux_sym_signed_number_token1] = ACTIONS(7619),
    [anon_sym_SQUOTE] = ACTIONS(7621),
    [anon_sym_DQUOTE] = ACTIONS(7623),
    [sym__uppercase_identifier] = ACTIONS(7625),
    [aux_sym_tag_token1] = ACTIONS(7627),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2643] = {
    [sym__match_cases] = STATE(8131),
    [sym_match_case] = STATE(8393),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13791),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2643),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2901),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7709),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2644] = {
    [sym_parameter] = STATE(8645),
    [sym__polymorphic_typed] = STATE(12901),
    [sym__parenthesized_abstract_type] = STATE(8645),
    [sym__simple_pattern] = STATE(8641),
    [sym_typed_pattern] = STATE(8762),
    [sym_polymorphic_variant_pattern] = STATE(8762),
    [sym_record_pattern] = STATE(8762),
    [sym_list_pattern] = STATE(8762),
    [sym_array_pattern] = STATE(8762),
    [sym_local_open_pattern] = STATE(8762),
    [sym_package_pattern] = STATE(8762),
    [sym_parenthesized_pattern] = STATE(8762),
    [sym_attribute] = STATE(2644),
    [sym_item_attribute] = STATE(9924),
    [sym_extension] = STATE(8762),
    [sym_quoted_extension] = STATE(8762),
    [sym__constant] = STATE(8707),
    [sym__signed_constant] = STATE(8762),
    [sym_number] = STATE(8756),
    [sym_signed_number] = STATE(8707),
    [sym_character] = STATE(8756),
    [sym_string] = STATE(8756),
    [sym_quoted_string] = STATE(8756),
    [sym_boolean] = STATE(8756),
    [sym_unit] = STATE(8756),
    [sym__simple_value_pattern] = STATE(8762),
    [sym_parenthesized_operator] = STATE(8762),
    [sym_module_path] = STATE(18492),
    [sym_constructor_path] = STATE(8762),
    [sym__constructor_name] = STATE(8748),
    [sym_tag] = STATE(8762),
    [aux_sym_expression_item_repeat1] = STATE(13017),
    [aux_sym_let_binding_repeat1] = STATE(2633),
    [sym__lowercase_identifier] = ACTIONS(7587),
    [anon_sym_EQ] = ACTIONS(7711),
    [anon_sym_TILDE] = ACTIONS(7591),
    [anon_sym_QMARK] = ACTIONS(7591),
    [anon_sym_LPAREN] = ACTIONS(7593),
    [anon_sym_LBRACK] = ACTIONS(7595),
    [anon_sym_true] = ACTIONS(7597),
    [anon_sym_false] = ACTIONS(7597),
    [anon_sym_COLON2] = ACTIONS(7599),
    [anon_sym_LBRACE] = ACTIONS(7601),
    [anon_sym_constraint] = ACTIONS(7713),
    [anon_sym_val] = ACTIONS(7713),
    [anon_sym_end] = ACTIONS(7713),
    [anon_sym_inherit] = ACTIONS(7713),
    [anon_sym_method] = ACTIONS(7713),
    [anon_sym_initializer] = ACTIONS(7713),
    [anon_sym_POUND] = ACTIONS(7605),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7607),
    [anon_sym_begin] = ACTIONS(7609),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6921),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7715),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7613),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7615),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7715),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7715),
    [aux_sym_number_token1] = ACTIONS(7617),
    [aux_sym_signed_number_token1] = ACTIONS(7619),
    [anon_sym_SQUOTE] = ACTIONS(7621),
    [anon_sym_DQUOTE] = ACTIONS(7623),
    [sym__uppercase_identifier] = ACTIONS(7625),
    [aux_sym_tag_token1] = ACTIONS(7627),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2645] = {
    [sym__match_cases] = STATE(8110),
    [sym_match_case] = STATE(12234),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13634),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2645),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2704),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7681),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2646] = {
    [sym__match_cases] = STATE(10488),
    [sym_match_case] = STATE(11595),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13526),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2646),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2923),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7717),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2647] = {
    [sym__match_cases] = STATE(10488),
    [sym_match_case] = STATE(11992),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13532),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2647),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2907),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7719),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2648] = {
    [sym__match_cases] = STATE(10488),
    [sym_match_case] = STATE(12100),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13656),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2648),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2821),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7721),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2649] = {
    [sym__match_cases] = STATE(7863),
    [sym_match_case] = STATE(12279),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13802),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2649),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2785),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7723),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2650] = {
    [sym__match_cases] = STATE(7863),
    [sym_match_case] = STATE(11924),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13743),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2650),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__attribute] = STATE(2862),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7655),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [anon_sym_PERCENT] = ACTIONS(7631),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2651] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(18978),
    [sym_module_definition] = STATE(18983),
    [sym_open_module] = STATE(18989),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2651),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2652] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(19850),
    [sym_module_definition] = STATE(19849),
    [sym_open_module] = STATE(19848),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2652),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2653] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(19099),
    [sym_module_definition] = STATE(19228),
    [sym_open_module] = STATE(19231),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2653),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2654] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(19373),
    [sym_module_definition] = STATE(19374),
    [sym_open_module] = STATE(19377),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2654),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2655] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(17971),
    [sym_module_definition] = STATE(17970),
    [sym_open_module] = STATE(17967),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2655),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2656] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(17718),
    [sym_module_definition] = STATE(17717),
    [sym_open_module] = STATE(17716),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2656),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2657] = {
    [sym_let_binding] = STATE(11570),
    [sym_exception_definition] = STATE(20451),
    [sym_module_definition] = STATE(20450),
    [sym_open_module] = STATE(20449),
    [sym__binding_pattern] = STATE(2480),
    [sym_alias_binding_pattern] = STATE(5519),
    [sym_typed_binding_pattern] = STATE(5519),
    [sym_or_binding_pattern] = STATE(5519),
    [sym_constructor_binding_pattern] = STATE(5519),
    [sym_tag_binding_pattern] = STATE(5519),
    [sym_polymorphic_variant_pattern] = STATE(5519),
    [sym_tuple_binding_pattern] = STATE(5519),
    [sym_record_binding_pattern] = STATE(5506),
    [sym_list_binding_pattern] = STATE(5515),
    [sym_cons_binding_pattern] = STATE(5519),
    [sym_array_binding_pattern] = STATE(5514),
    [sym_range_pattern] = STATE(5519),
    [sym_lazy_binding_pattern] = STATE(5519),
    [sym_local_open_binding_pattern] = STATE(5519),
    [sym_package_pattern] = STATE(5519),
    [sym_parenthesized_binding_pattern] = STATE(5519),
    [sym_attribute] = STATE(2657),
    [sym_extension] = STATE(5519),
    [sym_quoted_extension] = STATE(5519),
    [sym__attribute] = STATE(4527),
    [sym__constant] = STATE(5408),
    [sym__signed_constant] = STATE(5363),
    [sym_number] = STATE(5367),
    [sym_signed_number] = STATE(5408),
    [sym_character] = STATE(5367),
    [sym_string] = STATE(5367),
    [sym_quoted_string] = STATE(5367),
    [sym_boolean] = STATE(5367),
    [sym_unit] = STATE(5367),
    [sym__value_name] = STATE(5519),
    [sym_parenthesized_operator] = STATE(5498),
    [sym_module_path] = STATE(20448),
    [sym_constructor_path] = STATE(2453),
    [sym__constructor_name] = STATE(5364),
    [sym_tag] = STATE(2451),
    [sym__lowercase_identifier] = ACTIONS(5157),
    [anon_sym_rec] = ACTIONS(7735),
    [anon_sym_LPAREN] = ACTIONS(5159),
    [anon_sym_LBRACK] = ACTIONS(5161),
    [anon_sym_true] = ACTIONS(5163),
    [anon_sym_false] = ACTIONS(5163),
    [anon_sym_LBRACE] = ACTIONS(5165),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(5167),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5169),
    [anon_sym_lazy] = ACTIONS(5171),
    [anon_sym_begin] = ACTIONS(5173),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7737),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7739),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(5179),
    [aux_sym_signed_number_token1] = ACTIONS(5181),
    [anon_sym_SQUOTE] = ACTIONS(5183),
    [anon_sym_DQUOTE] = ACTIONS(5185),
    [sym__uppercase_identifier] = ACTIONS(5187),
    [aux_sym_tag_token1] = ACTIONS(5189),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2658] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(17783),
    [sym_module_definition] = STATE(17782),
    [sym_open_module] = STATE(17702),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2658),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2659] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(18366),
    [sym_module_definition] = STATE(18365),
    [sym_open_module] = STATE(18363),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2659),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2660] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(17614),
    [sym_module_definition] = STATE(17613),
    [sym_open_module] = STATE(17612),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2660),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2661] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(20492),
    [sym_module_definition] = STATE(20491),
    [sym_open_module] = STATE(20490),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2661),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2662] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(18416),
    [sym_module_definition] = STATE(18423),
    [sym_open_module] = STATE(18425),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2662),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2663] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(20117),
    [sym_module_definition] = STATE(20116),
    [sym_open_module] = STATE(20115),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2663),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2664] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(18804),
    [sym_module_definition] = STATE(18803),
    [sym_open_module] = STATE(18801),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2664),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2665] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(18281),
    [sym_module_definition] = STATE(18280),
    [sym_open_module] = STATE(18279),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2665),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2666] = {
    [sym_let_binding] = STATE(11408),
    [sym_exception_definition] = STATE(20117),
    [sym_module_definition] = STATE(20116),
    [sym_open_module] = STATE(20115),
    [sym__binding_pattern] = STATE(2483),
    [sym_alias_binding_pattern] = STATE(5483),
    [sym_typed_binding_pattern] = STATE(5483),
    [sym_or_binding_pattern] = STATE(5483),
    [sym_constructor_binding_pattern] = STATE(5483),
    [sym_tag_binding_pattern] = STATE(5483),
    [sym_polymorphic_variant_pattern] = STATE(5483),
    [sym_tuple_binding_pattern] = STATE(5483),
    [sym_record_binding_pattern] = STATE(5475),
    [sym_list_binding_pattern] = STATE(5538),
    [sym_cons_binding_pattern] = STATE(5483),
    [sym_array_binding_pattern] = STATE(5553),
    [sym_range_pattern] = STATE(5483),
    [sym_lazy_binding_pattern] = STATE(5483),
    [sym_local_open_binding_pattern] = STATE(5483),
    [sym_package_pattern] = STATE(5483),
    [sym_parenthesized_binding_pattern] = STATE(5483),
    [sym_attribute] = STATE(2666),
    [sym_extension] = STATE(5483),
    [sym_quoted_extension] = STATE(5483),
    [sym__attribute] = STATE(4505),
    [sym__constant] = STATE(5356),
    [sym__signed_constant] = STATE(5315),
    [sym_number] = STATE(5423),
    [sym_signed_number] = STATE(5356),
    [sym_character] = STATE(5423),
    [sym_string] = STATE(5423),
    [sym_quoted_string] = STATE(5423),
    [sym_boolean] = STATE(5423),
    [sym_unit] = STATE(5423),
    [sym__value_name] = STATE(5483),
    [sym_parenthesized_operator] = STATE(5534),
    [sym_module_path] = STATE(20406),
    [sym_constructor_path] = STATE(2444),
    [sym__constructor_name] = STATE(5376),
    [sym_tag] = STATE(2445),
    [sym__lowercase_identifier] = ACTIONS(5075),
    [anon_sym_rec] = ACTIONS(7741),
    [anon_sym_LPAREN] = ACTIONS(5081),
    [anon_sym_LBRACK] = ACTIONS(5083),
    [anon_sym_true] = ACTIONS(5085),
    [anon_sym_false] = ACTIONS(5085),
    [anon_sym_LBRACE] = ACTIONS(5087),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(5089),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5091),
    [anon_sym_lazy] = ACTIONS(5093),
    [anon_sym_begin] = ACTIONS(5095),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7743),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7745),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(5101),
    [aux_sym_signed_number_token1] = ACTIONS(5103),
    [anon_sym_SQUOTE] = ACTIONS(5105),
    [anon_sym_DQUOTE] = ACTIONS(5107),
    [sym__uppercase_identifier] = ACTIONS(5109),
    [aux_sym_tag_token1] = ACTIONS(5111),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2667] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(17908),
    [sym_module_definition] = STATE(17907),
    [sym_open_module] = STATE(17906),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2667),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2668] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(19981),
    [sym_module_definition] = STATE(19980),
    [sym_open_module] = STATE(19979),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2668),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2669] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(17724),
    [sym_module_definition] = STATE(17726),
    [sym_open_module] = STATE(17728),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2669),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2670] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(18716),
    [sym_module_definition] = STATE(18715),
    [sym_open_module] = STATE(18678),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2670),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2671] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(19141),
    [sym_module_definition] = STATE(19143),
    [sym_open_module] = STATE(19144),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2671),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2672] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(18112),
    [sym_module_definition] = STATE(18111),
    [sym_open_module] = STATE(18109),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2672),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2673] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(17877),
    [sym_module_definition] = STATE(17881),
    [sym_open_module] = STATE(17888),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2673),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2674] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(19322),
    [sym_module_definition] = STATE(19321),
    [sym_open_module] = STATE(19320),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2674),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2675] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(19591),
    [sym_module_definition] = STATE(19590),
    [sym_open_module] = STATE(19587),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2675),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2676] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(18906),
    [sym_module_definition] = STATE(18904),
    [sym_open_module] = STATE(18903),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2676),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2677] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(17657),
    [sym_module_definition] = STATE(17656),
    [sym_open_module] = STATE(17655),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2677),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2678] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(18540),
    [sym_module_definition] = STATE(18539),
    [sym_open_module] = STATE(18536),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2678),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2679] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(19483),
    [sym_module_definition] = STATE(19481),
    [sym_open_module] = STATE(19442),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2679),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2680] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(20503),
    [sym_module_definition] = STATE(20501),
    [sym_open_module] = STATE(20499),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2680),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2681] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(18700),
    [sym_module_definition] = STATE(18701),
    [sym_open_module] = STATE(18704),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2681),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2682] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(17844),
    [sym_module_definition] = STATE(17843),
    [sym_open_module] = STATE(17842),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2682),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2683] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(20451),
    [sym_module_definition] = STATE(20450),
    [sym_open_module] = STATE(20449),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2683),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2684] = {
    [sym_parameter] = STATE(10266),
    [sym__polymorphic_typed] = STATE(16670),
    [sym__parenthesized_abstract_type] = STATE(10266),
    [sym__simple_pattern] = STATE(10267),
    [sym_typed_pattern] = STATE(10147),
    [sym_polymorphic_variant_pattern] = STATE(10147),
    [sym_record_pattern] = STATE(10147),
    [sym_list_pattern] = STATE(10147),
    [sym_array_pattern] = STATE(10147),
    [sym_local_open_pattern] = STATE(10147),
    [sym_package_pattern] = STATE(10147),
    [sym_parenthesized_pattern] = STATE(10147),
    [sym_attribute] = STATE(2684),
    [sym_item_attribute] = STATE(14644),
    [sym_extension] = STATE(10147),
    [sym_quoted_extension] = STATE(10147),
    [sym__constant] = STATE(10250),
    [sym__signed_constant] = STATE(10147),
    [sym_number] = STATE(10120),
    [sym_signed_number] = STATE(10250),
    [sym_character] = STATE(10120),
    [sym_string] = STATE(10120),
    [sym_quoted_string] = STATE(10120),
    [sym_boolean] = STATE(10120),
    [sym_unit] = STATE(10120),
    [sym__simple_value_pattern] = STATE(10147),
    [sym_parenthesized_operator] = STATE(10147),
    [sym_module_path] = STATE(20425),
    [sym_constructor_path] = STATE(10147),
    [sym__constructor_name] = STATE(8440),
    [sym_tag] = STATE(10147),
    [aux_sym_expression_item_repeat1] = STATE(14162),
    [aux_sym_let_binding_repeat1] = STATE(4646),
    [sym__lowercase_identifier] = ACTIONS(5465),
    [anon_sym_and] = ACTIONS(5469),
    [anon_sym_COLON_GT] = ACTIONS(7747),
    [anon_sym_EQ] = ACTIONS(7749),
    [anon_sym_TILDE] = ACTIONS(5475),
    [anon_sym_QMARK] = ACTIONS(5475),
    [anon_sym_LPAREN] = ACTIONS(5477),
    [anon_sym_COMMA] = ACTIONS(7751),
    [anon_sym_PIPE] = ACTIONS(7753),
    [anon_sym_LBRACK] = ACTIONS(5483),
    [anon_sym_true] = ACTIONS(5485),
    [anon_sym_false] = ACTIONS(5485),
    [anon_sym_COLON2] = ACTIONS(5487),
    [anon_sym_LBRACE] = ACTIONS(5489),
    [anon_sym_in] = ACTIONS(5469),
    [anon_sym_as] = ACTIONS(7755),
    [anon_sym_POUND] = ACTIONS(5493),
    [anon_sym_COLON_COLON] = ACTIONS(7757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5497),
    [anon_sym_begin] = ACTIONS(5499),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(7759),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7761),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7763),
    [aux_sym_number_token1] = ACTIONS(5507),
    [aux_sym_signed_number_token1] = ACTIONS(5509),
    [anon_sym_SQUOTE] = ACTIONS(5511),
    [anon_sym_DQUOTE] = ACTIONS(5513),
    [sym_let_and_operator] = ACTIONS(5467),
    [sym__uppercase_identifier] = ACTIONS(5515),
    [aux_sym_tag_token1] = ACTIONS(5517),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2685] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(19028),
    [sym_module_definition] = STATE(19027),
    [sym_open_module] = STATE(19026),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2685),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2686] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(18016),
    [sym_module_definition] = STATE(18021),
    [sym_open_module] = STATE(18029),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2686),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2687] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(18287),
    [sym_module_definition] = STATE(18291),
    [sym_open_module] = STATE(18292),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2687),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2688] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(19071),
    [sym_module_definition] = STATE(19072),
    [sym_open_module] = STATE(19079),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2688),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2689] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(19251),
    [sym_module_definition] = STATE(19250),
    [sym_open_module] = STATE(19249),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2689),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2690] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(18815),
    [sym_module_definition] = STATE(18816),
    [sym_open_module] = STATE(18819),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2690),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2691] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(18454),
    [sym_module_definition] = STATE(18453),
    [sym_open_module] = STATE(18451),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2691),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2692] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(18543),
    [sym_module_definition] = STATE(18544),
    [sym_open_module] = STATE(18545),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2692),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2693] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(19179),
    [sym_module_definition] = STATE(19178),
    [sym_open_module] = STATE(19176),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2693),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2694] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(19398),
    [sym_module_definition] = STATE(19397),
    [sym_open_module] = STATE(19396),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2694),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2695] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(18138),
    [sym_module_definition] = STATE(18141),
    [sym_open_module] = STATE(18146),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2695),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2696] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(18192),
    [sym_module_definition] = STATE(18191),
    [sym_open_module] = STATE(18190),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2696),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2697] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(19717),
    [sym_module_definition] = STATE(19713),
    [sym_open_module] = STATE(19711),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2697),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2698] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(18038),
    [sym_module_definition] = STATE(18036),
    [sym_open_module] = STATE(18035),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2698),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2699] = {
    [sym_let_binding] = STATE(14512),
    [sym_exception_definition] = STATE(18629),
    [sym_module_definition] = STATE(18627),
    [sym_open_module] = STATE(18625),
    [sym__binding_pattern] = STATE(2684),
    [sym_alias_binding_pattern] = STATE(8897),
    [sym_typed_binding_pattern] = STATE(8897),
    [sym_or_binding_pattern] = STATE(8897),
    [sym_constructor_binding_pattern] = STATE(8897),
    [sym_tag_binding_pattern] = STATE(8897),
    [sym_polymorphic_variant_pattern] = STATE(8897),
    [sym_tuple_binding_pattern] = STATE(8897),
    [sym_record_binding_pattern] = STATE(8895),
    [sym_list_binding_pattern] = STATE(8894),
    [sym_cons_binding_pattern] = STATE(8897),
    [sym_array_binding_pattern] = STATE(8892),
    [sym_range_pattern] = STATE(8897),
    [sym_lazy_binding_pattern] = STATE(8897),
    [sym_local_open_binding_pattern] = STATE(8897),
    [sym_package_pattern] = STATE(8897),
    [sym_parenthesized_binding_pattern] = STATE(8897),
    [sym_attribute] = STATE(2699),
    [sym_extension] = STATE(8897),
    [sym_quoted_extension] = STATE(8897),
    [sym__attribute] = STATE(4543),
    [sym__constant] = STATE(8637),
    [sym__signed_constant] = STATE(8778),
    [sym_number] = STATE(8567),
    [sym_signed_number] = STATE(8637),
    [sym_character] = STATE(8567),
    [sym_string] = STATE(8567),
    [sym_quoted_string] = STATE(8567),
    [sym_boolean] = STATE(8567),
    [sym_unit] = STATE(8567),
    [sym__value_name] = STATE(8897),
    [sym_parenthesized_operator] = STATE(8914),
    [sym_module_path] = STATE(19304),
    [sym_constructor_path] = STATE(2599),
    [sym__constructor_name] = STATE(8611),
    [sym_tag] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(7513),
    [anon_sym_rec] = ACTIONS(7725),
    [anon_sym_LPAREN] = ACTIONS(7515),
    [anon_sym_LBRACK] = ACTIONS(7517),
    [anon_sym_true] = ACTIONS(7519),
    [anon_sym_false] = ACTIONS(7519),
    [anon_sym_LBRACE] = ACTIONS(7521),
    [anon_sym_exception] = ACTIONS(7727),
    [anon_sym_module] = ACTIONS(7729),
    [anon_sym_open] = ACTIONS(7731),
    [anon_sym_POUND] = ACTIONS(7523),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7525),
    [anon_sym_lazy] = ACTIONS(7527),
    [anon_sym_begin] = ACTIONS(7529),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7533),
    [anon_sym_PERCENT] = ACTIONS(7733),
    [aux_sym_number_token1] = ACTIONS(7535),
    [aux_sym_signed_number_token1] = ACTIONS(7537),
    [anon_sym_SQUOTE] = ACTIONS(7539),
    [anon_sym_DQUOTE] = ACTIONS(7541),
    [sym__uppercase_identifier] = ACTIONS(7543),
    [aux_sym_tag_token1] = ACTIONS(7545),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2700] = {
    [sym__match_cases] = STATE(8200),
    [sym_match_case] = STATE(8374),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13600),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2700),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7635),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2701] = {
    [sym__match_cases] = STATE(8282),
    [sym_match_case] = STATE(12431),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13650),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2701),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7647),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2702] = {
    [sym__match_cases] = STATE(7995),
    [sym_match_case] = STATE(10366),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13570),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2702),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7633),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2703] = {
    [sym__match_cases] = STATE(8184),
    [sym_match_case] = STATE(8226),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13545),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2703),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7651),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2704] = {
    [sym__match_cases] = STATE(8228),
    [sym_match_case] = STATE(12234),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13634),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2704),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7681),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2705] = {
    [sym__match_cases] = STATE(8212),
    [sym_match_case] = STATE(8226),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13545),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2705),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7651),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2706] = {
    [sym__match_cases] = STATE(8216),
    [sym_match_case] = STATE(8226),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13545),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2706),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7651),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2707] = {
    [sym__match_cases] = STATE(10547),
    [sym_match_case] = STATE(11117),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13514),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2707),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7641),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2708] = {
    [sym__match_cases] = STATE(8200),
    [sym_match_case] = STATE(8226),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13545),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2708),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7651),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2709] = {
    [sym__match_cases] = STATE(8266),
    [sym_match_case] = STATE(11987),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13814),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2709),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7653),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2710] = {
    [sym__match_cases] = STATE(7988),
    [sym_match_case] = STATE(10366),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13570),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2710),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7633),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2711] = {
    [sym__match_cases] = STATE(10615),
    [sym_match_case] = STATE(11117),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13514),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2711),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7641),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2712] = {
    [sym__match_cases] = STATE(8266),
    [sym_match_case] = STATE(12234),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13634),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2712),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7681),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2713] = {
    [sym__match_cases] = STATE(10604),
    [sym_match_case] = STATE(11117),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13514),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2713),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7641),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2714] = {
    [sym__match_cases] = STATE(8269),
    [sym_match_case] = STATE(12234),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13634),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2714),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7681),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2715] = {
    [sym__match_cases] = STATE(7995),
    [sym_match_case] = STATE(12086),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13606),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2715),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7691),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2716] = {
    [sym__match_cases] = STATE(8282),
    [sym_match_case] = STATE(12234),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13634),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2716),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7681),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2717] = {
    [sym__match_cases] = STATE(7988),
    [sym_match_case] = STATE(12086),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13606),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2717),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7691),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2718] = {
    [sym__match_cases] = STATE(7928),
    [sym_match_case] = STATE(12234),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13634),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2718),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7681),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2719] = {
    [sym__match_cases] = STATE(7965),
    [sym_match_case] = STATE(12086),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13606),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2719),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7691),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2720] = {
    [sym__match_cases] = STATE(10459),
    [sym_match_case] = STATE(11117),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13514),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2720),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7641),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2721] = {
    [sym__match_cases] = STATE(10456),
    [sym_match_case] = STATE(11117),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13514),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2721),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7641),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2722] = {
    [sym__match_cases] = STATE(7965),
    [sym_match_case] = STATE(10366),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13570),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2722),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7633),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2723] = {
    [sym__match_cases] = STATE(7958),
    [sym_match_case] = STATE(12086),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13606),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2723),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7691),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2724] = {
    [sym__match_cases] = STATE(7958),
    [sym_match_case] = STATE(10366),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13570),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2724),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7633),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2725] = {
    [sym__match_cases] = STATE(7958),
    [sym_match_case] = STATE(9395),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13787),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2725),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7629),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2726] = {
    [sym__match_cases] = STATE(7958),
    [sym_match_case] = STATE(12234),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13634),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2726),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7681),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2727] = {
    [sym__match_cases] = STATE(7965),
    [sym_match_case] = STATE(12234),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13634),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2727),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7681),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2728] = {
    [sym__match_cases] = STATE(8283),
    [sym_match_case] = STATE(12234),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13634),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2728),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7681),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2729] = {
    [sym__match_cases] = STATE(7928),
    [sym_match_case] = STATE(12086),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13606),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2729),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7691),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2730] = {
    [sym__match_cases] = STATE(8228),
    [sym_match_case] = STATE(10338),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13597),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2730),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7663),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2731] = {
    [sym__match_cases] = STATE(8266),
    [sym_match_case] = STATE(10338),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13597),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2731),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7663),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2732] = {
    [sym__match_cases] = STATE(8269),
    [sym_match_case] = STATE(10338),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13597),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2732),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7663),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2733] = {
    [sym__match_cases] = STATE(7928),
    [sym_match_case] = STATE(9395),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13787),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2733),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7629),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2734] = {
    [sym__match_cases] = STATE(8282),
    [sym_match_case] = STATE(10338),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13597),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2734),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7663),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2735] = {
    [sym__match_cases] = STATE(7928),
    [sym_match_case] = STATE(10366),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13570),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2735),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7633),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2736] = {
    [sym__match_cases] = STATE(8283),
    [sym_match_case] = STATE(10338),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13597),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2736),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7663),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2737] = {
    [sym__match_cases] = STATE(8146),
    [sym_match_case] = STATE(8461),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13747),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2737),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7675),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2738] = {
    [sym__match_cases] = STATE(7988),
    [sym_match_case] = STATE(12234),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13634),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2738),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7681),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2739] = {
    [sym__match_cases] = STATE(7995),
    [sym_match_case] = STATE(12234),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13634),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2739),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7681),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2740] = {
    [sym__match_cases] = STATE(8228),
    [sym_match_case] = STATE(11924),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13743),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2740),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7655),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2741] = {
    [sym__match_cases] = STATE(10456),
    [sym_match_case] = STATE(11762),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13595),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2741),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7667),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2742] = {
    [sym__match_cases] = STATE(7928),
    [sym_match_case] = STATE(12151),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13546),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2742),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7665),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2743] = {
    [sym__match_cases] = STATE(8228),
    [sym_match_case] = STATE(11987),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13814),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2743),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7653),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2744] = {
    [sym__match_cases] = STATE(8266),
    [sym_match_case] = STATE(11924),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13743),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2744),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7655),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2745] = {
    [sym__match_cases] = STATE(8269),
    [sym_match_case] = STATE(11924),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13743),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2745),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7655),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2746] = {
    [sym__match_cases] = STATE(10459),
    [sym_match_case] = STATE(11762),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13595),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2746),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7667),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2747] = {
    [sym__match_cases] = STATE(7958),
    [sym_match_case] = STATE(12151),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13546),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2747),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7665),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2748] = {
    [sym__match_cases] = STATE(8282),
    [sym_match_case] = STATE(11924),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13743),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2748),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7655),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2749] = {
    [sym__match_cases] = STATE(8283),
    [sym_match_case] = STATE(11924),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13743),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2749),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7655),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2750] = {
    [sym__match_cases] = STATE(7965),
    [sym_match_case] = STATE(12151),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13546),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2750),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7665),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2751] = {
    [sym__match_cases] = STATE(7958),
    [sym_match_case] = STATE(11987),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13814),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2751),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7653),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2752] = {
    [sym__match_cases] = STATE(8269),
    [sym_match_case] = STATE(11987),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13814),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2752),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7653),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2753] = {
    [sym__match_cases] = STATE(8282),
    [sym_match_case] = STATE(11987),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13814),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2753),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7653),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2754] = {
    [sym__match_cases] = STATE(8283),
    [sym_match_case] = STATE(11987),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13814),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2754),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7653),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2755] = {
    [sym__match_cases] = STATE(8283),
    [sym_match_case] = STATE(12340),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13803),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2755),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7643),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2756] = {
    [sym__match_cases] = STATE(8269),
    [sym_match_case] = STATE(12340),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13803),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2756),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7643),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2757] = {
    [sym__match_cases] = STATE(8266),
    [sym_match_case] = STATE(12340),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13803),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2757),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7643),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2758] = {
    [sym__match_cases] = STATE(8228),
    [sym_match_case] = STATE(12086),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13606),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2758),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7691),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2759] = {
    [sym__match_cases] = STATE(8266),
    [sym_match_case] = STATE(12086),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13606),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2759),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7691),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2760] = {
    [sym__match_cases] = STATE(8269),
    [sym_match_case] = STATE(12086),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13606),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2760),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7691),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2761] = {
    [sym__match_cases] = STATE(8228),
    [sym_match_case] = STATE(12340),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13803),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2761),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7643),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2762] = {
    [sym__match_cases] = STATE(7988),
    [sym_match_case] = STATE(12151),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13546),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2762),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7665),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2763] = {
    [sym__match_cases] = STATE(7995),
    [sym_match_case] = STATE(12151),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13546),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2763),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7665),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2764] = {
    [sym__match_cases] = STATE(10604),
    [sym_match_case] = STATE(11762),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13595),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2764),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7667),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2765] = {
    [sym__match_cases] = STATE(7928),
    [sym_match_case] = STATE(12431),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13650),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2765),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7647),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2766] = {
    [sym__match_cases] = STATE(7958),
    [sym_match_case] = STATE(12431),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13650),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2766),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7647),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2767] = {
    [sym__match_cases] = STATE(8282),
    [sym_match_case] = STATE(12086),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13606),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2767),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7691),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2768] = {
    [sym__match_cases] = STATE(7995),
    [sym_match_case] = STATE(12340),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13803),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2768),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7643),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2769] = {
    [sym__match_cases] = STATE(7988),
    [sym_match_case] = STATE(12340),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13803),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2769),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7643),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2770] = {
    [sym__match_cases] = STATE(10615),
    [sym_match_case] = STATE(11762),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13595),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2770),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7667),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2771] = {
    [sym__match_cases] = STATE(7965),
    [sym_match_case] = STATE(12431),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13650),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2771),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7647),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2772] = {
    [sym__match_cases] = STATE(8283),
    [sym_match_case] = STATE(12086),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13606),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2772),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7691),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2773] = {
    [sym__match_cases] = STATE(8228),
    [sym_match_case] = STATE(12151),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13546),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2773),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7665),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2774] = {
    [sym__match_cases] = STATE(8146),
    [sym_match_case] = STATE(8682),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13561),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2774),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7699),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2775] = {
    [sym__match_cases] = STATE(10547),
    [sym_match_case] = STATE(11762),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13595),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2775),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7667),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2776] = {
    [sym__match_cases] = STATE(7928),
    [sym_match_case] = STATE(12430),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13779),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2776),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7639),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2777] = {
    [sym__match_cases] = STATE(8184),
    [sym_match_case] = STATE(8682),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13561),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2777),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7699),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2778] = {
    [sym__match_cases] = STATE(7988),
    [sym_match_case] = STATE(12431),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13650),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2778),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7647),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2779] = {
    [sym__match_cases] = STATE(8184),
    [sym_match_case] = STATE(8461),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13747),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2779),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7675),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2780] = {
    [sym__match_cases] = STATE(7995),
    [sym_match_case] = STATE(12431),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13650),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2780),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7647),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2781] = {
    [sym__match_cases] = STATE(8216),
    [sym_match_case] = STATE(8352),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13563),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2781),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7659),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2782] = {
    [sym__match_cases] = STATE(8266),
    [sym_match_case] = STATE(12151),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13546),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2782),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7665),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2783] = {
    [sym__match_cases] = STATE(8269),
    [sym_match_case] = STATE(12151),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13546),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2783),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7665),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2784] = {
    [sym__match_cases] = STATE(8282),
    [sym_match_case] = STATE(12151),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13546),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2784),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7665),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2785] = {
    [sym__match_cases] = STATE(7928),
    [sym_match_case] = STATE(12279),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13802),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2785),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7723),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2786] = {
    [sym__match_cases] = STATE(8282),
    [sym_match_case] = STATE(12340),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13803),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2786),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7643),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2787] = {
    [sym__match_cases] = STATE(7965),
    [sym_match_case] = STATE(12340),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13803),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2787),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7643),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2788] = {
    [sym__match_cases] = STATE(8283),
    [sym_match_case] = STATE(12151),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13546),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2788),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7665),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2789] = {
    [sym__match_cases] = STATE(7958),
    [sym_match_case] = STATE(12340),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13803),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2789),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7643),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2790] = {
    [sym__match_cases] = STATE(7995),
    [sym_match_case] = STATE(11987),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13814),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2790),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7653),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2791] = {
    [sym__match_cases] = STATE(7988),
    [sym_match_case] = STATE(11987),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13814),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2791),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7653),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2792] = {
    [sym__match_cases] = STATE(10456),
    [sym_match_case] = STATE(12100),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13656),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2792),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7721),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2793] = {
    [sym__match_cases] = STATE(10459),
    [sym_match_case] = STATE(12100),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13656),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2793),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7721),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2794] = {
    [sym__match_cases] = STATE(8216),
    [sym_match_case] = STATE(8310),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13788),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2794),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7677),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2795] = {
    [sym__match_cases] = STATE(10615),
    [sym_match_case] = STATE(12100),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13656),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2795),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7721),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2796] = {
    [sym__match_cases] = STATE(8200),
    [sym_match_case] = STATE(8352),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13563),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2796),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7659),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2797] = {
    [sym__match_cases] = STATE(7965),
    [sym_match_case] = STATE(11987),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13814),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2797),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7653),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2798] = {
    [sym__match_cases] = STATE(7958),
    [sym_match_case] = STATE(12279),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13802),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2798),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7723),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2799] = {
    [sym__match_cases] = STATE(8266),
    [sym_match_case] = STATE(9395),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13787),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2799),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7629),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2800] = {
    [sym__match_cases] = STATE(7928),
    [sym_match_case] = STATE(11987),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13814),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2800),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7653),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2801] = {
    [sym__match_cases] = STATE(8146),
    [sym_match_case] = STATE(8352),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13563),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2801),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7659),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2802] = {
    [sym__match_cases] = STATE(7928),
    [sym_match_case] = STATE(9564),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13567),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2802),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7645),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2803] = {
    [sym__match_cases] = STATE(8184),
    [sym_match_case] = STATE(8352),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13563),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2803),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7659),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2804] = {
    [sym__match_cases] = STATE(8212),
    [sym_match_case] = STATE(8352),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13563),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2804),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7659),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2805] = {
    [sym__match_cases] = STATE(8216),
    [sym_match_case] = STATE(8682),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13561),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2805),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7699),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2806] = {
    [sym__match_cases] = STATE(7928),
    [sym_match_case] = STATE(12340),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13803),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2806),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7643),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2807] = {
    [sym__match_cases] = STATE(7958),
    [sym_match_case] = STATE(9564),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13567),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2807),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7645),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2808] = {
    [sym__match_cases] = STATE(7965),
    [sym_match_case] = STATE(9564),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13567),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2808),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7645),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2809] = {
    [sym__match_cases] = STATE(8216),
    [sym_match_case] = STATE(8393),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13791),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2809),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7709),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2810] = {
    [sym__match_cases] = STATE(8228),
    [sym_match_case] = STATE(12431),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13650),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2810),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7647),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2811] = {
    [sym__match_cases] = STATE(7988),
    [sym_match_case] = STATE(9564),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13567),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2811),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7645),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2812] = {
    [sym__match_cases] = STATE(7995),
    [sym_match_case] = STATE(9564),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13567),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2812),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7645),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2813] = {
    [sym__match_cases] = STATE(8283),
    [sym_match_case] = STATE(12430),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13779),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2813),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7639),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2814] = {
    [sym__match_cases] = STATE(8282),
    [sym_match_case] = STATE(12430),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13779),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2814),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7639),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2815] = {
    [sym__match_cases] = STATE(8200),
    [sym_match_case] = STATE(8682),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13561),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2815),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7699),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2816] = {
    [sym__match_cases] = STATE(8269),
    [sym_match_case] = STATE(12430),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13779),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2816),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7639),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2817] = {
    [sym__match_cases] = STATE(7965),
    [sym_match_case] = STATE(12279),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13802),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2817),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7723),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2818] = {
    [sym__simple_expression] = STATE(9228),
    [sym_typed_expression] = STATE(9278),
    [sym_list_expression] = STATE(9278),
    [sym_array_expression] = STATE(9278),
    [sym_record_expression] = STATE(9278),
    [sym_labeled_argument] = STATE(10062),
    [sym_prefix_expression] = STATE(9278),
    [sym_hash_expression] = STATE(9278),
    [sym_field_get_expression] = STATE(9278),
    [sym_array_get_expression] = STATE(9278),
    [sym_string_get_expression] = STATE(9278),
    [sym_bigarray_get_expression] = STATE(9278),
    [sym_coercion_expression] = STATE(9278),
    [sym_local_open_expression] = STATE(9278),
    [sym_package_expression] = STATE(9278),
    [sym_new_expression] = STATE(9278),
    [sym_object_copy_expression] = STATE(9278),
    [sym_method_invocation] = STATE(9278),
    [sym_object_expression] = STATE(9278),
    [sym_parenthesized_expression] = STATE(9278),
    [sym_attribute] = STATE(2818),
    [sym_extension] = STATE(9278),
    [sym_quoted_extension] = STATE(9278),
    [sym__constant] = STATE(9278),
    [sym_number] = STATE(9062),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9032),
    [sym_parenthesized_operator] = STATE(9072),
    [sym_value_path] = STATE(9278),
    [sym_module_path] = STATE(17894),
    [sym_constructor_path] = STATE(9278),
    [sym__constructor_name] = STATE(8125),
    [sym_tag] = STATE(9278),
    [aux_sym_class_application_repeat1] = STATE(2882),
    [sym__lowercase_identifier] = ACTIONS(7765),
    [anon_sym_TILDE] = ACTIONS(7767),
    [anon_sym_QMARK] = ACTIONS(7767),
    [anon_sym_LPAREN] = ACTIONS(7769),
    [anon_sym_RPAREN] = ACTIONS(5687),
    [anon_sym_LBRACK] = ACTIONS(7771),
    [anon_sym_true] = ACTIONS(7773),
    [anon_sym_false] = ACTIONS(7773),
    [anon_sym_COLON2] = ACTIONS(5687),
    [anon_sym_LBRACE] = ACTIONS(7775),
    [anon_sym_object] = ACTIONS(7777),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7779),
    [anon_sym_new] = ACTIONS(7781),
    [anon_sym_LBRACE_LT] = ACTIONS(7783),
    [anon_sym_begin] = ACTIONS(7785),
    [sym_ocamlyacc_value] = ACTIONS(7787),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7789),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7791),
    [aux_sym_number_token1] = ACTIONS(7793),
    [anon_sym_SQUOTE] = ACTIONS(7795),
    [anon_sym_DQUOTE] = ACTIONS(7797),
    [sym_prefix_operator] = ACTIONS(7799),
    [sym__uppercase_identifier] = ACTIONS(7801),
    [aux_sym_tag_token1] = ACTIONS(7803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2819] = {
    [sym__match_cases] = STATE(8212),
    [sym_match_case] = STATE(8682),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13561),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2819),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7699),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2820] = {
    [sym__match_cases] = STATE(10604),
    [sym_match_case] = STATE(12100),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13656),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2820),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7721),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2821] = {
    [sym__match_cases] = STATE(10547),
    [sym_match_case] = STATE(12100),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13656),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2821),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7721),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2822] = {
    [sym__match_cases] = STATE(7958),
    [sym_match_case] = STATE(12430),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13779),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2822),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7639),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2823] = {
    [sym__match_cases] = STATE(8266),
    [sym_match_case] = STATE(12430),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13779),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2823),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7639),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2824] = {
    [sym__match_cases] = STATE(8266),
    [sym_match_case] = STATE(12431),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13650),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2824),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7647),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2825] = {
    [sym__match_cases] = STATE(8228),
    [sym_match_case] = STATE(12430),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13779),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2825),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7639),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2826] = {
    [sym__match_cases] = STATE(8146),
    [sym_match_case] = STATE(8374),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13600),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2826),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7635),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2827] = {
    [sym__match_cases] = STATE(8184),
    [sym_match_case] = STATE(8374),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13600),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2827),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7635),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2828] = {
    [sym__match_cases] = STATE(8269),
    [sym_match_case] = STATE(12431),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13650),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2828),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7647),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2829] = {
    [sym__match_cases] = STATE(8212),
    [sym_match_case] = STATE(8374),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13600),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2829),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7635),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2830] = {
    [sym__match_cases] = STATE(8216),
    [sym_match_case] = STATE(8178),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13716),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2830),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7637),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2831] = {
    [sym__match_cases] = STATE(7988),
    [sym_match_case] = STATE(12279),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13802),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2831),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7723),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2832] = {
    [sym__match_cases] = STATE(8216),
    [sym_match_case] = STATE(8374),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13600),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2832),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7635),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2833] = {
    [sym__match_cases] = STATE(8146),
    [sym_match_case] = STATE(8226),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13545),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2833),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7651),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2834] = {
    [sym__match_cases] = STATE(8228),
    [sym_match_case] = STATE(9395),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13787),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2834),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7629),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2835] = {
    [sym__match_cases] = STATE(8283),
    [sym_match_case] = STATE(12431),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13650),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2835),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7647),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2836] = {
    [sym__match_cases] = STATE(8200),
    [sym_match_case] = STATE(8341),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13801),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2836),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7679),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2837] = {
    [sym__match_cases] = STATE(7995),
    [sym_match_case] = STATE(12279),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13802),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2837),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7723),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2838] = {
    [sym__match_cases] = STATE(8269),
    [sym_match_case] = STATE(9395),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13787),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2838),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7629),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2839] = {
    [sym__match_cases] = STATE(8282),
    [sym_match_case] = STATE(9395),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13787),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2839),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7629),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2840] = {
    [sym__match_cases] = STATE(8212),
    [sym_match_case] = STATE(8178),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13716),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2840),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7637),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2841] = {
    [sym__match_cases] = STATE(8283),
    [sym_match_case] = STATE(9395),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13787),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2841),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7629),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2842] = {
    [sym__match_cases] = STATE(8216),
    [sym_match_case] = STATE(8473),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13530),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2842),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7661),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2843] = {
    [sym__match_cases] = STATE(7995),
    [sym_match_case] = STATE(11924),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13743),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2843),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7655),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2844] = {
    [sym__match_cases] = STATE(8146),
    [sym_match_case] = STATE(8341),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13801),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2844),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7679),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2845] = {
    [sym__match_cases] = STATE(8216),
    [sym_match_case] = STATE(8674),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13641),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2845),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7689),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2846] = {
    [sym__match_cases] = STATE(7988),
    [sym_match_case] = STATE(11924),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13743),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2846),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7655),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2847] = {
    [sym__match_cases] = STATE(8184),
    [sym_match_case] = STATE(8341),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13801),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2847),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7679),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2848] = {
    [sym__match_cases] = STATE(8212),
    [sym_match_case] = STATE(8674),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13641),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2848),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7689),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2849] = {
    [sym__match_cases] = STATE(8212),
    [sym_match_case] = STATE(8393),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13791),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2849),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7709),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2850] = {
    [sym__match_cases] = STATE(7965),
    [sym_match_case] = STATE(12430),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13779),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2850),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7639),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2851] = {
    [sym__match_cases] = STATE(8212),
    [sym_match_case] = STATE(8341),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13801),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2851),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7679),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2852] = {
    [sym__match_cases] = STATE(8216),
    [sym_match_case] = STATE(8341),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13801),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2852),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7679),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2853] = {
    [sym__match_cases] = STATE(8184),
    [sym_match_case] = STATE(8393),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13791),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2853),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7709),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2854] = {
    [sym__simple_expression] = STATE(9228),
    [sym_typed_expression] = STATE(9278),
    [sym_list_expression] = STATE(9278),
    [sym_array_expression] = STATE(9278),
    [sym_record_expression] = STATE(9278),
    [sym_labeled_argument] = STATE(10062),
    [sym_prefix_expression] = STATE(9278),
    [sym_hash_expression] = STATE(9278),
    [sym_field_get_expression] = STATE(9278),
    [sym_array_get_expression] = STATE(9278),
    [sym_string_get_expression] = STATE(9278),
    [sym_bigarray_get_expression] = STATE(9278),
    [sym_coercion_expression] = STATE(9278),
    [sym_local_open_expression] = STATE(9278),
    [sym_package_expression] = STATE(9278),
    [sym_new_expression] = STATE(9278),
    [sym_object_copy_expression] = STATE(9278),
    [sym_method_invocation] = STATE(9278),
    [sym_object_expression] = STATE(9278),
    [sym_parenthesized_expression] = STATE(9278),
    [sym_attribute] = STATE(2854),
    [sym_extension] = STATE(9278),
    [sym_quoted_extension] = STATE(9278),
    [sym__constant] = STATE(9278),
    [sym_number] = STATE(9062),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9032),
    [sym_parenthesized_operator] = STATE(9072),
    [sym_value_path] = STATE(9278),
    [sym_module_path] = STATE(17894),
    [sym_constructor_path] = STATE(9278),
    [sym__constructor_name] = STATE(8125),
    [sym_tag] = STATE(9278),
    [aux_sym_class_application_repeat1] = STATE(2818),
    [sym__lowercase_identifier] = ACTIONS(7765),
    [anon_sym_TILDE] = ACTIONS(7767),
    [anon_sym_QMARK] = ACTIONS(7767),
    [anon_sym_LPAREN] = ACTIONS(7769),
    [anon_sym_RPAREN] = ACTIONS(5583),
    [anon_sym_LBRACK] = ACTIONS(7771),
    [anon_sym_true] = ACTIONS(7773),
    [anon_sym_false] = ACTIONS(7773),
    [anon_sym_COLON2] = ACTIONS(5583),
    [anon_sym_LBRACE] = ACTIONS(7775),
    [anon_sym_object] = ACTIONS(7777),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7779),
    [anon_sym_new] = ACTIONS(7781),
    [anon_sym_LBRACE_LT] = ACTIONS(7783),
    [anon_sym_begin] = ACTIONS(7785),
    [sym_ocamlyacc_value] = ACTIONS(7787),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7789),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7791),
    [aux_sym_number_token1] = ACTIONS(7793),
    [anon_sym_SQUOTE] = ACTIONS(7795),
    [anon_sym_DQUOTE] = ACTIONS(7797),
    [sym_prefix_operator] = ACTIONS(7799),
    [sym__uppercase_identifier] = ACTIONS(7801),
    [aux_sym_tag_token1] = ACTIONS(7803),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2855] = {
    [sym__match_cases] = STATE(7965),
    [sym_match_case] = STATE(11924),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13743),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2855),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7655),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2856] = {
    [sym__match_cases] = STATE(8184),
    [sym_match_case] = STATE(8674),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13641),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2856),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7689),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2857] = {
    [sym__match_cases] = STATE(8146),
    [sym_match_case] = STATE(8674),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13641),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2857),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7689),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2858] = {
    [sym__match_cases] = STATE(7958),
    [sym_match_case] = STATE(11924),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13743),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2858),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7655),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2859] = {
    [sym__match_cases] = STATE(8200),
    [sym_match_case] = STATE(8674),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13641),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2859),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7689),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2860] = {
    [sym__match_cases] = STATE(8184),
    [sym_match_case] = STATE(8178),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13716),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2860),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7637),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2861] = {
    [sym__match_cases] = STATE(8146),
    [sym_match_case] = STATE(8178),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13716),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2861),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7637),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2862] = {
    [sym__match_cases] = STATE(7928),
    [sym_match_case] = STATE(11924),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13743),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2862),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7655),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2863] = {
    [sym__match_cases] = STATE(8146),
    [sym_match_case] = STATE(8393),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13791),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2863),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7709),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2864] = {
    [sym__match_cases] = STATE(8212),
    [sym_match_case] = STATE(8310),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13788),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2864),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7677),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2865] = {
    [sym__match_cases] = STATE(7988),
    [sym_match_case] = STATE(12430),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13779),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2865),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7639),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2866] = {
    [sym__match_cases] = STATE(8200),
    [sym_match_case] = STATE(8473),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13530),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2866),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7661),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2867] = {
    [sym__match_cases] = STATE(7995),
    [sym_match_case] = STATE(12430),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13779),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2867),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7639),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2868] = {
    [sym__match_cases] = STATE(7965),
    [sym_match_case] = STATE(9395),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13787),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2868),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7629),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2869] = {
    [sym__match_cases] = STATE(8146),
    [sym_match_case] = STATE(8473),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13530),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2869),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7661),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2870] = {
    [sym__match_cases] = STATE(8184),
    [sym_match_case] = STATE(8473),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13530),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2870),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7661),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2871] = {
    [sym__match_cases] = STATE(8212),
    [sym_match_case] = STATE(8473),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13530),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2871),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7661),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2872] = {
    [sym__match_cases] = STATE(8228),
    [sym_match_case] = STATE(10366),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13570),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2872),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7633),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2873] = {
    [sym__match_cases] = STATE(8200),
    [sym_match_case] = STATE(8178),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13716),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2873),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7637),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2874] = {
    [sym__match_cases] = STATE(7995),
    [sym_match_case] = STATE(12037),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13665),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2874),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7649),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2875] = {
    [sym__match_cases] = STATE(7988),
    [sym_match_case] = STATE(12037),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13665),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2875),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7649),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2876] = {
    [sym__match_cases] = STATE(8283),
    [sym_match_case] = STATE(9564),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13567),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2876),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7645),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2877] = {
    [sym__match_cases] = STATE(7965),
    [sym_match_case] = STATE(12037),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13665),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2877),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7649),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2878] = {
    [sym__match_cases] = STATE(8200),
    [sym_match_case] = STATE(8418),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13682),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2878),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7701),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2879] = {
    [sym__match_cases] = STATE(8282),
    [sym_match_case] = STATE(9564),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13567),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2879),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7645),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2880] = {
    [sym__match_cases] = STATE(8269),
    [sym_match_case] = STATE(9564),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13567),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2880),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7645),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2881] = {
    [sym__match_cases] = STATE(8266),
    [sym_match_case] = STATE(9564),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13567),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2881),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7645),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2882] = {
    [sym__simple_expression] = STATE(9228),
    [sym_typed_expression] = STATE(9278),
    [sym_list_expression] = STATE(9278),
    [sym_array_expression] = STATE(9278),
    [sym_record_expression] = STATE(9278),
    [sym_labeled_argument] = STATE(10062),
    [sym_prefix_expression] = STATE(9278),
    [sym_hash_expression] = STATE(9278),
    [sym_field_get_expression] = STATE(9278),
    [sym_array_get_expression] = STATE(9278),
    [sym_string_get_expression] = STATE(9278),
    [sym_bigarray_get_expression] = STATE(9278),
    [sym_coercion_expression] = STATE(9278),
    [sym_local_open_expression] = STATE(9278),
    [sym_package_expression] = STATE(9278),
    [sym_new_expression] = STATE(9278),
    [sym_object_copy_expression] = STATE(9278),
    [sym_method_invocation] = STATE(9278),
    [sym_object_expression] = STATE(9278),
    [sym_parenthesized_expression] = STATE(9278),
    [sym_attribute] = STATE(2882),
    [sym_extension] = STATE(9278),
    [sym_quoted_extension] = STATE(9278),
    [sym__constant] = STATE(9278),
    [sym_number] = STATE(9062),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9032),
    [sym_parenthesized_operator] = STATE(9072),
    [sym_value_path] = STATE(9278),
    [sym_module_path] = STATE(17894),
    [sym_constructor_path] = STATE(9278),
    [sym__constructor_name] = STATE(8125),
    [sym_tag] = STATE(9278),
    [aux_sym_class_application_repeat1] = STATE(2882),
    [sym__lowercase_identifier] = ACTIONS(7805),
    [anon_sym_TILDE] = ACTIONS(7808),
    [anon_sym_QMARK] = ACTIONS(7808),
    [anon_sym_LPAREN] = ACTIONS(7811),
    [anon_sym_RPAREN] = ACTIONS(3720),
    [anon_sym_LBRACK] = ACTIONS(7814),
    [anon_sym_true] = ACTIONS(7817),
    [anon_sym_false] = ACTIONS(7817),
    [anon_sym_COLON2] = ACTIONS(3720),
    [anon_sym_LBRACE] = ACTIONS(7820),
    [anon_sym_object] = ACTIONS(7823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7826),
    [anon_sym_new] = ACTIONS(7829),
    [anon_sym_LBRACE_LT] = ACTIONS(7832),
    [anon_sym_begin] = ACTIONS(7835),
    [sym_ocamlyacc_value] = ACTIONS(7838),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7841),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7844),
    [aux_sym_number_token1] = ACTIONS(7847),
    [anon_sym_SQUOTE] = ACTIONS(7850),
    [anon_sym_DQUOTE] = ACTIONS(7853),
    [sym_prefix_operator] = ACTIONS(7856),
    [sym__uppercase_identifier] = ACTIONS(7859),
    [aux_sym_tag_token1] = ACTIONS(7862),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2883] = {
    [sym__match_cases] = STATE(8228),
    [sym_match_case] = STATE(9564),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13567),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2883),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7645),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2884] = {
    [sym__match_cases] = STATE(8146),
    [sym_match_case] = STATE(8418),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13682),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2884),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7701),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2885] = {
    [sym__match_cases] = STATE(7958),
    [sym_match_case] = STATE(12037),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13665),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2885),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7649),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2886] = {
    [sym__match_cases] = STATE(7928),
    [sym_match_case] = STATE(12037),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13665),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2886),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7649),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2887] = {
    [sym__match_cases] = STATE(10547),
    [sym_match_case] = STATE(12319),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13698),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2887),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7657),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2888] = {
    [sym__match_cases] = STATE(8184),
    [sym_match_case] = STATE(8418),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13682),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2888),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7701),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2889] = {
    [sym__match_cases] = STATE(10615),
    [sym_match_case] = STATE(12319),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13698),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2889),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7657),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2890] = {
    [sym__match_cases] = STATE(10604),
    [sym_match_case] = STATE(12319),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13698),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2890),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7657),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2891] = {
    [sym__match_cases] = STATE(8282),
    [sym_match_case] = STATE(10366),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13570),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2891),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7633),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2892] = {
    [sym__match_cases] = STATE(8212),
    [sym_match_case] = STATE(8418),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13682),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2892),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7701),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2893] = {
    [sym__match_cases] = STATE(8216),
    [sym_match_case] = STATE(8418),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13682),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2893),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7701),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2894] = {
    [sym__match_cases] = STATE(10459),
    [sym_match_case] = STATE(12319),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13698),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2894),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7657),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2895] = {
    [sym__match_cases] = STATE(10456),
    [sym_match_case] = STATE(12319),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13698),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2895),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7657),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2896] = {
    [sym__match_cases] = STATE(8269),
    [sym_match_case] = STATE(10366),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13570),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2896),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7633),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2897] = {
    [sym__signature] = STATE(20445),
    [sym_external] = STATE(12649),
    [sym_type_definition] = STATE(12649),
    [sym_exception_definition] = STATE(12649),
    [sym_module_definition] = STATE(12649),
    [sym_module_type_definition] = STATE(12649),
    [sym_open_module] = STATE(12649),
    [sym_class_definition] = STATE(12649),
    [sym_class_type_definition] = STATE(12649),
    [sym__signature_item] = STATE(12650),
    [sym_value_specification] = STATE(12649),
    [sym_include_module_type] = STATE(12649),
    [sym__simple_type] = STATE(11754),
    [sym__tuple_type] = STATE(13155),
    [sym__type] = STATE(15779),
    [sym_function_type] = STATE(8194),
    [sym_typed_label] = STATE(20444),
    [sym_tuple_type] = STATE(8103),
    [sym_constructed_type] = STATE(12249),
    [sym_aliased_type] = STATE(8194),
    [sym_local_open_type] = STATE(12249),
    [sym_polymorphic_variant_type] = STATE(12249),
    [sym_package_type] = STATE(12249),
    [sym_object_type] = STATE(12249),
    [sym_hash_type] = STATE(12249),
    [sym_parenthesized_type] = STATE(12249),
    [sym_attribute] = STATE(2897),
    [sym_floating_attribute] = STATE(12649),
    [sym_extension] = STATE(12249),
    [sym_quoted_extension] = STATE(12249),
    [sym_item_extension] = STATE(12649),
    [sym_quoted_item_extension] = STATE(12649),
    [sym_extended_module_path] = STATE(16552),
    [sym_type_constructor_path] = STATE(12249),
    [sym_type_variable] = STATE(12249),
    [aux_sym__structure_repeat1] = STATE(8978),
    [aux_sym__signature_repeat1] = STATE(8951),
    [sym__lowercase_identifier] = ACTIONS(7865),
    [anon_sym_SEMI_SEMI] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(7867),
    [anon_sym_LPAREN] = ACTIONS(7869),
    [anon_sym_external] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(7873),
    [anon_sym_RBRACK] = ACTIONS(7875),
    [anon_sym_exception] = ACTIONS(7877),
    [anon_sym_module] = ACTIONS(7879),
    [anon_sym_open] = ACTIONS(61),
    [anon_sym_include] = ACTIONS(7881),
    [anon_sym_class] = ACTIONS(7883),
    [anon_sym_val] = ACTIONS(7885),
    [anon_sym_LBRACK_GT] = ACTIONS(7887),
    [anon_sym_LBRACK_LT] = ACTIONS(7889),
    [anon_sym_LT] = ACTIONS(7891),
    [anon_sym_POUND] = ACTIONS(7893),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7895),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7897),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [sym__uppercase_identifier] = ACTIONS(7899),
    [aux_sym_type_variable_token1] = ACTIONS(7901),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2898] = {
    [sym__match_cases] = STATE(8266),
    [sym_match_case] = STATE(10366),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13570),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2898),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7633),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2899] = {
    [sym__match_cases] = STATE(10615),
    [sym_match_case] = STATE(11595),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13526),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2899),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7717),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2900] = {
    [sym__match_cases] = STATE(8283),
    [sym_match_case] = STATE(10366),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13570),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2900),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7633),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2901] = {
    [sym__match_cases] = STATE(8200),
    [sym_match_case] = STATE(8393),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13791),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2901),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7709),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2902] = {
    [sym__match_cases] = STATE(7995),
    [sym_match_case] = STATE(10338),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13597),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2902),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7663),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2903] = {
    [sym__match_cases] = STATE(7988),
    [sym_match_case] = STATE(10338),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13597),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2903),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7663),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2904] = {
    [sym__match_cases] = STATE(7965),
    [sym_match_case] = STATE(10338),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13597),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2904),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7663),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2905] = {
    [sym__match_cases] = STATE(7958),
    [sym_match_case] = STATE(10338),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13597),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2905),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7663),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2906] = {
    [sym__match_cases] = STATE(7928),
    [sym_match_case] = STATE(10338),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13597),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2906),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7663),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2907] = {
    [sym__match_cases] = STATE(10547),
    [sym_match_case] = STATE(11992),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13532),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2907),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7719),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2908] = {
    [sym__match_cases] = STATE(7988),
    [sym_match_case] = STATE(9395),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13787),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2908),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7629),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2909] = {
    [sym__match_cases] = STATE(10615),
    [sym_match_case] = STATE(11992),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13532),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2909),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7719),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2910] = {
    [sym__match_cases] = STATE(10604),
    [sym_match_case] = STATE(11992),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13532),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2910),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7719),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2911] = {
    [sym__match_cases] = STATE(10459),
    [sym_match_case] = STATE(11992),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13532),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2911),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7719),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2912] = {
    [sym__match_cases] = STATE(10456),
    [sym_match_case] = STATE(11992),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13532),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2912),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7719),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2913] = {
    [sym__match_cases] = STATE(10456),
    [sym_match_case] = STATE(11595),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13526),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2913),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7717),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2914] = {
    [sym__match_cases] = STATE(10459),
    [sym_match_case] = STATE(11595),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13526),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2914),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7717),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2915] = {
    [sym__match_cases] = STATE(8200),
    [sym_match_case] = STATE(8461),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13747),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2915),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7675),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2916] = {
    [sym__match_cases] = STATE(8212),
    [sym_match_case] = STATE(8461),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13747),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2916),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7675),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2917] = {
    [sym__match_cases] = STATE(8216),
    [sym_match_case] = STATE(8461),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13747),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2917),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7675),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2918] = {
    [sym__match_cases] = STATE(7995),
    [sym_match_case] = STATE(9395),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13787),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2918),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7629),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2919] = {
    [sym__match_cases] = STATE(8184),
    [sym_match_case] = STATE(8310),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13788),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2919),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7677),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2920] = {
    [sym__match_cases] = STATE(10604),
    [sym_match_case] = STATE(11595),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13526),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2920),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7717),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2921] = {
    [sym__match_cases] = STATE(8146),
    [sym_match_case] = STATE(8310),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13788),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2921),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7677),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2922] = {
    [sym__match_cases] = STATE(8200),
    [sym_match_case] = STATE(8310),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13788),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2922),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7677),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2923] = {
    [sym__match_cases] = STATE(10547),
    [sym_match_case] = STATE(11595),
    [sym__simple_pattern] = STATE(13110),
    [sym__effect_pattern] = STATE(13033),
    [sym__pattern] = STATE(13526),
    [sym_alias_pattern] = STATE(13033),
    [sym_typed_pattern] = STATE(12929),
    [sym_or_pattern] = STATE(13033),
    [sym_constructor_pattern] = STATE(13110),
    [sym_tag_pattern] = STATE(13110),
    [sym_polymorphic_variant_pattern] = STATE(12929),
    [sym_tuple_pattern] = STATE(13033),
    [sym_record_pattern] = STATE(12929),
    [sym_list_pattern] = STATE(12929),
    [sym_cons_pattern] = STATE(13033),
    [sym_array_pattern] = STATE(12929),
    [sym_range_pattern] = STATE(13033),
    [sym_lazy_pattern] = STATE(13110),
    [sym_local_open_pattern] = STATE(12929),
    [sym_package_pattern] = STATE(12929),
    [sym_parenthesized_pattern] = STATE(12929),
    [sym_exception_pattern] = STATE(13033),
    [sym_effect_pattern] = STATE(13033),
    [sym_attribute] = STATE(2923),
    [sym_extension] = STATE(12929),
    [sym_quoted_extension] = STATE(12929),
    [sym__constant] = STATE(12920),
    [sym__signed_constant] = STATE(12882),
    [sym_number] = STATE(12006),
    [sym_signed_number] = STATE(12920),
    [sym_character] = STATE(12006),
    [sym_string] = STATE(12006),
    [sym_quoted_string] = STATE(12006),
    [sym_boolean] = STATE(12006),
    [sym_unit] = STATE(12006),
    [sym__simple_value_pattern] = STATE(12929),
    [sym_parenthesized_operator] = STATE(12929),
    [sym_module_path] = STATE(20471),
    [sym_constructor_path] = STATE(2559),
    [sym__constructor_name] = STATE(8442),
    [sym_tag] = STATE(2562),
    [sym__lowercase_identifier] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(7717),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_true] = ACTIONS(4955),
    [anon_sym_false] = ACTIONS(4955),
    [anon_sym_LBRACE] = ACTIONS(4959),
    [anon_sym_exception] = ACTIONS(4961),
    [anon_sym_POUND] = ACTIONS(7155),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4969),
    [anon_sym_lazy] = ACTIONS(4971),
    [anon_sym_begin] = ACTIONS(4973),
    [anon_sym_effect] = ACTIONS(4975),
    [aux_sym_attribute_token1] = ACTIONS(1095),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4977),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4979),
    [aux_sym_number_token1] = ACTIONS(4981),
    [aux_sym_signed_number_token1] = ACTIONS(7409),
    [anon_sym_SQUOTE] = ACTIONS(4985),
    [anon_sym_DQUOTE] = ACTIONS(4987),
    [sym__uppercase_identifier] = ACTIONS(4991),
    [aux_sym_tag_token1] = ACTIONS(4993),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2924), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 38,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [75] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2925), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [150] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 38,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [225] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2927), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [300] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(5391), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7919), 1,
      anon_sym_RPAREN,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(2928), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(14394), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [435] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 38,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [510] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2930), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [585] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2931), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [660] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2932), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [735] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 38,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [810] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2934), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [885] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2935), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [960] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [1035] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2937), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 38,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [1110] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 38,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [1185] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2939), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 38,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [1260] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [1335] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2941), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 38,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [1410] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2942), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 38,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [1485] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7631), 1,
      anon_sym_PERCENT,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(2943), 1,
      sym_attribute,
    STATE(3531), 1,
      sym__attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(12993), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [1620] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(5403), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7941), 1,
      anon_sym_RPAREN,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(2944), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(14389), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [1755] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7631), 1,
      anon_sym_PERCENT,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(2945), 1,
      sym_attribute,
    STATE(3533), 1,
      sym__attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13710), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [1890] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    ACTIONS(7631), 1,
      anon_sym_PERCENT,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(2946), 1,
      sym_attribute,
    STATE(3616), 1,
      sym__attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(14147), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [2025] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    ACTIONS(7631), 1,
      anon_sym_PERCENT,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(2947), 1,
      sym_attribute,
    STATE(3617), 1,
      sym__attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(14141), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [2160] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7149), 1,
      anon_sym_COMMA,
    ACTIONS(7151), 1,
      anon_sym_LPAREN,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(2948), 1,
      sym_attribute,
    STATE(3510), 1,
      sym__parenthesized_abstract_type,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(14742), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [2295] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(5145), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7919), 1,
      anon_sym_RPAREN,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(2949), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(14394), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [2430] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(5119), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7943), 1,
      anon_sym_RPAREN,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(2950), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(14230), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [2565] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7631), 1,
      anon_sym_PERCENT,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(2951), 1,
      sym_attribute,
    STATE(3441), 1,
      sym__attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13193), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [2700] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7631), 1,
      anon_sym_PERCENT,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(2952), 1,
      sym_attribute,
    STATE(3430), 1,
      sym__attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(12993), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [2835] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(5129), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7941), 1,
      anon_sym_RPAREN,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(2953), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(14389), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [2970] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(5279), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7919), 1,
      anon_sym_RPAREN,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(2954), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(14394), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [3105] = 29,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7945), 1,
      sym__lowercase_identifier,
    ACTIONS(7951), 1,
      anon_sym_LPAREN,
    ACTIONS(7954), 1,
      anon_sym_LBRACK,
    ACTIONS(7960), 1,
      anon_sym_LBRACE,
    ACTIONS(7963), 1,
      anon_sym_POUND,
    ACTIONS(7966), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7969), 1,
      anon_sym_begin,
    ACTIONS(7972), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7975), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7978), 1,
      aux_sym_number_token1,
    ACTIONS(7981), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7984), 1,
      anon_sym_SQUOTE,
    ACTIONS(7987), 1,
      anon_sym_DQUOTE,
    ACTIONS(7990), 1,
      sym__uppercase_identifier,
    ACTIONS(7993), 1,
      aux_sym_tag_token1,
    STATE(8641), 1,
      sym__simple_pattern,
    STATE(8748), 1,
      sym__constructor_name,
    STATE(18492), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7948), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(7957), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(2955), 2,
      sym_attribute,
      aux_sym_let_binding_repeat1,
    STATE(8645), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(8707), 2,
      sym__constant,
      sym_signed_number,
    ACTIONS(7294), 5,
      anon_sym_EQ,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    STATE(8756), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    ACTIONS(7296), 7,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
    STATE(8762), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [3228] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(2956), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [3305] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8006), 1,
      anon_sym_LT_DASH,
    STATE(2957), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [3382] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(5071), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8008), 1,
      anon_sym_RPAREN,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(2958), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(14192), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [3517] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(5197), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8010), 1,
      anon_sym_RPAREN,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(2959), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(14354), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [3652] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7631), 1,
      anon_sym_PERCENT,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(2960), 1,
      sym_attribute,
    STATE(3511), 1,
      sym__attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(14743), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [3787] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(5153), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8012), 1,
      anon_sym_RPAREN,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(2961), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(14355), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [3922] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(2962), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [3999] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8014), 1,
      anon_sym_LT_DASH,
    STATE(2963), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [4076] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4967), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8016), 1,
      anon_sym_RPAREN,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(2964), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(14382), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [4211] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(5139), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8018), 1,
      anon_sym_RPAREN,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(2965), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(14187), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [4346] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(2966), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14514), 1,
      sym__simple_expression,
    STATE(15569), 1,
      sym_field_expression,
    STATE(17900), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [4476] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(2967), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14705), 1,
      sym__simple_expression,
    STATE(16475), 1,
      sym_field_expression,
    STATE(17609), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [4606] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2968), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [4680] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(2969), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14554), 1,
      sym__simple_expression,
    STATE(16057), 1,
      sym_field_expression,
    STATE(19470), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [4810] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(2970), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14988), 1,
      sym__simple_expression,
    STATE(15411), 1,
      sym_field_expression,
    STATE(19904), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [4940] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(2971), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(10611), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13532), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [5072] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2972), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [5146] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2973), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [5220] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2974), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [5294] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2975), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [5368] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(2976), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(15008), 1,
      sym__simple_expression,
    STATE(15317), 1,
      sym_field_expression,
    STATE(19861), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [5498] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(2977), 1,
      sym_attribute,
    STATE(8221), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13779), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [5630] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(2978), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(10611), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13526), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [5762] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [5836] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2980), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [5910] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2981), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [5984] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [6058] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2983), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [6132] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2984), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [6206] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2985), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [6280] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [6354] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2987), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [6428] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [6502] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2989), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [6576] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2990), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [6650] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2991), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [6724] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2992), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [6798] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2993), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [6872] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(2994), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14491), 1,
      sym__simple_expression,
    STATE(16285), 1,
      sym_field_expression,
    STATE(19429), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [7002] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(2995), 1,
      sym_attribute,
    STATE(8221), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13597), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [7134] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2996), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [7208] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2997), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [7282] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3057), 1,
      anon_sym_DOT,
    ACTIONS(3059), 1,
      anon_sym_POUND,
    ACTIONS(3061), 1,
      sym_hash_operator,
    STATE(2998), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [7362] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2999), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [7436] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3000), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(9394), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13787), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [7568] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3001), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [7642] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3002), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [7716] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3003), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [7790] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3004), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [7864] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3005), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [7938] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3006), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [8012] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3007), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [8086] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3008), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [8160] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3009), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [8234] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3010), 1,
      sym_attribute,
    STATE(8163), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13545), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [8366] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3011), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [8440] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3012), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [8514] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    ACTIONS(8152), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3013), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(14116), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [8646] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3014), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [8720] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [8794] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3016), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [8868] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [8942] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [9016] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [9090] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3020), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [9164] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3021), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [9238] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3022), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14586), 1,
      sym__simple_expression,
    STATE(15899), 1,
      sym_field_expression,
    STATE(19510), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [9368] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3057), 1,
      anon_sym_DOT,
    STATE(3023), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [9444] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [9518] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3025), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [9592] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    ACTIONS(8186), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3026), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(13736), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [9724] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8188), 1,
      anon_sym_RBRACK,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3027), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13748), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [9856] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3028), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [9930] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3029), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [10004] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3030), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [10078] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3031), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [10152] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [10226] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3033), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [10300] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3034), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [10374] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3035), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [10448] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    ACTIONS(8206), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3036), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(14116), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [10580] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [10654] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [10728] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8216), 1,
      anon_sym_RBRACK,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3039), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13871), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [10860] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [10934] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3041), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(10611), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13514), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [11066] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [11140] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(3043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [11216] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3044), 1,
      sym_attribute,
    STATE(8369), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13600), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [11348] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3045), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14971), 1,
      sym__simple_expression,
    STATE(15505), 1,
      sym_field_expression,
    STATE(19949), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [11478] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3057), 1,
      anon_sym_DOT,
    ACTIONS(3059), 1,
      anon_sym_POUND,
    ACTIONS(3061), 1,
      sym_hash_operator,
    STATE(3046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [11558] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3047), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [11632] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3048), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [11706] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3049), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [11780] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3050), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [11854] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3051), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [11928] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3052), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [12002] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8250), 1,
      anon_sym_RBRACK,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3053), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13871), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [12134] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3054), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [12208] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3055), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14426), 1,
      sym__simple_expression,
    STATE(16481), 1,
      sym_field_expression,
    STATE(19354), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [12338] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3056), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [12412] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3057), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14605), 1,
      sym__simple_expression,
    STATE(16343), 1,
      sym_field_expression,
    STATE(19246), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [12542] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8252), 1,
      anon_sym_LT_DASH,
    STATE(3058), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [12618] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    ACTIONS(8254), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3059), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(14116), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [12750] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3060), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [12824] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3061), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [12898] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3062), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [12972] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3063), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [13046] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3064), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [13120] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3065), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(15047), 1,
      sym__simple_expression,
    STATE(15221), 1,
      sym_field_expression,
    STATE(19783), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [13250] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3066), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [13324] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3067), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [13398] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3068), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [13472] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3069), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12433), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13779), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [13604] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3070), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [13678] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3071), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [13752] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3072), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14445), 1,
      sym__simple_expression,
    STATE(15583), 1,
      sym_field_expression,
    STATE(17964), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [13882] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3073), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [13956] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3074), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12152), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13546), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [14088] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3075), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [14162] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3076), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14945), 1,
      sym__simple_expression,
    STATE(15701), 1,
      sym_field_expression,
    STATE(19556), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [14292] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [14366] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3078), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [14440] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3079), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14567), 1,
      sym__simple_expression,
    STATE(16349), 1,
      sym_field_expression,
    STATE(17839), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [14570] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3080), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14950), 1,
      sym__simple_expression,
    STATE(15598), 1,
      sym_field_expression,
    STATE(19990), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [14700] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [14774] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3082), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14797), 1,
      sym__simple_expression,
    STATE(15757), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    STATE(20442), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [14904] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8256), 1,
      anon_sym_RBRACK,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3083), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13871), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [15036] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8258), 1,
      anon_sym_LT_DASH,
    STATE(3084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [15112] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3085), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [15186] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3086), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14634), 1,
      sym__simple_expression,
    STATE(16031), 1,
      sym_field_expression,
    STATE(19152), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [15316] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(3087), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [15392] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3088), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [15466] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3089), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [15540] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3090), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12517), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13665), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [15672] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3091), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [15746] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3092), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [15820] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3093), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(10611), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13595), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [15952] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3094), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [16026] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3095), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [16100] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3096), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [16174] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3097), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(10611), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13698), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [16306] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3098), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14926), 1,
      sym__simple_expression,
    STATE(15690), 1,
      sym_field_expression,
    STATE(20016), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [16436] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3099), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12026), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13665), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [16568] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8260), 1,
      anon_sym_LT_DASH,
    STATE(3100), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [16644] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(3101), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [16720] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3102), 1,
      sym_attribute,
    STATE(8163), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13563), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [16852] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [16926] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3104), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [17000] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3105), 1,
      sym_attribute,
    STATE(8163), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13788), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [17132] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3106), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [17206] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3107), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [17280] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [17354] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3109), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [17428] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [17502] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3111), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [17576] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [17650] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [17724] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3114), 1,
      sym_attribute,
    STATE(8367), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13563), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [17856] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [17930] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18004] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3081), 1,
      anon_sym_DOT,
    ACTIONS(3083), 1,
      anon_sym_POUND,
    ACTIONS(3085), 1,
      sym_hash_operator,
    STATE(3117), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18084] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3118), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18158] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3119), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18232] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3120), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18306] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18380] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(3122), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18456] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18530] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18604] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18678] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18752] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3127), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18826] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3128), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18900] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3129), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18974] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3130), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14417), 1,
      sym__simple_expression,
    STATE(15965), 1,
      sym_field_expression,
    STATE(18360), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [19104] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3131), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [19178] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(3132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [19254] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3133), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [19328] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3134), 1,
      sym_attribute,
    STATE(8163), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13600), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [19460] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3135), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [19534] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [19608] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [19682] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [19756] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    ACTIONS(8330), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3139), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(14116), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [19888] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [19962] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8332), 1,
      anon_sym_RBRACK,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3141), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13871), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [20094] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [20168] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [20242] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [20316] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3145), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12087), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13606), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [20448] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3146), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [20522] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [20596] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [20670] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3149), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [20744] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3150), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14751), 1,
      sym__simple_expression,
    STATE(15784), 1,
      sym_field_expression,
    STATE(19172), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [20874] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3151), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [20948] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3152), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [21022] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3153), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [21096] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3154), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [21170] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3155), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14636), 1,
      sym__simple_expression,
    STATE(15126), 1,
      sym_field_expression,
    STATE(17712), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [21300] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3156), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [21374] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3157), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [21448] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3081), 1,
      anon_sym_DOT,
    STATE(3158), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [21524] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [21598] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [21672] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3161), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [21746] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [21820] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [21894] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [21968] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [22042] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3166), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [22116] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3081), 1,
      anon_sym_DOT,
    ACTIONS(3083), 1,
      anon_sym_POUND,
    ACTIONS(3085), 1,
      sym_hash_operator,
    STATE(3167), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [22196] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [22270] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3169), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [22344] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [22418] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [22492] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [22566] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [22640] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [22714] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3175), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [22788] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [22862] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3177), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [22936] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [23010] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3179), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(10611), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13656), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [23142] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    ACTIONS(8342), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3180), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(14116), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [23274] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8344), 1,
      anon_sym_RBRACK,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3181), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13871), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [23406] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(3182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [23482] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3183), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [23556] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8346), 1,
      anon_sym_RBRACK,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3184), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13784), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [23688] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [23762] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [23836] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3187), 1,
      sym_attribute,
    STATE(8238), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13545), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [23968] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [24042] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [24116] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [24190] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    ACTIONS(8348), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3191), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(13778), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [24322] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3192), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [24396] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3193), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [24470] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3194), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [24544] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(3195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [24620] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [24694] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [24768] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [24842] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3199), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(11988), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13532), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [24974] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3200), 1,
      sym_attribute,
    STATE(8221), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13743), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [25106] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [25180] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3202), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14420), 1,
      sym__simple_expression,
    STATE(16204), 1,
      sym_field_expression,
    STATE(19580), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [25310] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3203), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14785), 1,
      sym__simple_expression,
    STATE(15489), 1,
      sym_field_expression,
    STATE(18999), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [25440] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3204), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(15073), 1,
      sym__simple_expression,
    STATE(15125), 1,
      sym_field_expression,
    STATE(19733), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [25570] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3205), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [25644] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3206), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [25718] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [25792] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3208), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [25866] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3209), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12517), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13802), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [25998] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [26072] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [26146] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3212), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [26220] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3213), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [26294] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3214), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(8714), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13641), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [26426] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3215), 1,
      sym_attribute,
    STATE(8163), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13530), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [26558] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3216), 1,
      sym_attribute,
    STATE(8297), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13801), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [26690] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8366), 1,
      anon_sym_RBRACK,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3217), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13681), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [26822] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    ACTIONS(8368), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3218), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(13683), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [26954] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3219), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14938), 1,
      sym__simple_expression,
    STATE(15219), 1,
      sym_field_expression,
    STATE(18839), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [27084] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3220), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14709), 1,
      sym__simple_expression,
    STATE(15399), 1,
      sym_field_expression,
    STATE(20111), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [27214] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7149), 1,
      anon_sym_COMMA,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3221), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(14685), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [27346] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8370), 1,
      anon_sym_RBRACK,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3222), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13746), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [27478] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3223), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12337), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13803), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [27610] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3224), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(10442), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13570), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [27742] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    ACTIONS(8372), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3225), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(13785), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [27874] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3226), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(15006), 1,
      sym__simple_expression,
    STATE(15458), 1,
      sym_field_expression,
    STATE(19617), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [28004] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3227), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(11587), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13526), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [28136] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3228), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14677), 1,
      sym__simple_expression,
    STATE(15256), 1,
      sym_field_expression,
    STATE(19706), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [28266] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3229), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(8482), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13530), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [28398] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3230), 1,
      sym_attribute,
    STATE(8163), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13641), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [28530] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3231), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14607), 1,
      sym__simple_expression,
    STATE(16017), 1,
      sym_field_expression,
    STATE(17652), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [28660] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8374), 1,
      anon_sym_RBRACK,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3232), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13871), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [28792] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    ACTIONS(8376), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3233), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(14116), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [28924] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3234), 1,
      sym_attribute,
    STATE(8221), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13814), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [29056] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3235), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14979), 1,
      sym__simple_expression,
    STATE(15150), 1,
      sym_field_expression,
    STATE(18707), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [29186] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3236), 1,
      sym_attribute,
    STATE(8163), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13801), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [29318] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3237), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12229), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13634), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [29450] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3238), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(15071), 1,
      sym__simple_expression,
    STATE(15338), 1,
      sym_field_expression,
    STATE(18549), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [29580] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8378), 1,
      anon_sym_RBRACK,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3239), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13871), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [29712] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3240), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12101), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13656), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [29844] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    ACTIONS(8380), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3241), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(14116), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [29976] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8382), 1,
      anon_sym_LT_DASH,
    STATE(3242), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [30052] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(3243), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [30128] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3244), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(15017), 1,
      sym__simple_expression,
    STATE(15993), 1,
      sym_field_expression,
    STATE(19392), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [30258] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3245), 1,
      sym_attribute,
    STATE(8163), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13747), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [30390] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5079), 1,
      anon_sym_as,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    STATE(3247), 1,
      sym_tag,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13312), 1,
      sym__binding_pattern,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3246), 2,
      sym_attribute,
      sym_constructor_path,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    ACTIONS(5077), 6,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [30522] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5079), 1,
      anon_sym_as,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13310), 1,
      sym__binding_pattern,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3247), 2,
      sym_attribute,
      sym_tag,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    ACTIONS(5077), 6,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [30654] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3248), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14777), 1,
      sym__simple_expression,
    STATE(16346), 1,
      sym_field_expression,
    STATE(18533), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [30784] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3249), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(15061), 1,
      sym__simple_expression,
    STATE(15548), 1,
      sym_field_expression,
    STATE(18429), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [30914] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3250), 1,
      sym_attribute,
    STATE(8221), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13606), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [31046] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3251), 1,
      sym_attribute,
    STATE(8363), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13788), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [31178] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3252), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(8861), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13561), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [31310] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3253), 1,
      sym_attribute,
    STATE(8221), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13567), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [31442] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3254), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14990), 1,
      sym__simple_expression,
    STATE(15739), 1,
      sym_field_expression,
    STATE(18303), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [31572] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3255), 1,
      sym_attribute,
    STATE(8221), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13546), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [31704] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3256), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14903), 1,
      sym__simple_expression,
    STATE(15909), 1,
      sym_field_expression,
    STATE(18157), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [31834] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3257), 1,
      sym_attribute,
    STATE(8221), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13803), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [31966] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    ACTIONS(8388), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3258), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(14116), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [32098] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3259), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12612), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13698), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [32230] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3260), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12441), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13650), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [32362] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    ACTIONS(8390), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3261), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(14116), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [32494] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8392), 1,
      anon_sym_RBRACK,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3262), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13871), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [32626] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3263), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(11761), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13595), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [32758] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3264), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14758), 1,
      sym__simple_expression,
    STATE(15145), 1,
      sym_field_expression,
    STATE(19316), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [32888] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3265), 1,
      sym_attribute,
    STATE(8221), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13650), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [33020] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    ACTIONS(8394), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3266), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(13621), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [33152] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3267), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(8488), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13747), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [33284] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8396), 1,
      anon_sym_RBRACK,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3268), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13624), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [33416] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3269), 1,
      sym_attribute,
    STATE(8163), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13682), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [33548] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3270), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(11991), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13814), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [33680] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8398), 1,
      anon_sym_RBRACK,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3271), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13871), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [33812] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3272), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14880), 1,
      sym__simple_expression,
    STATE(16051), 1,
      sym_field_expression,
    STATE(18032), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [33942] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3273), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(9596), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13567), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [34074] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3274), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(11118), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13514), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [34206] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3275), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(15037), 1,
      sym__simple_expression,
    STATE(15212), 1,
      sym_field_expression,
    STATE(19667), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [34336] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3276), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14787), 1,
      sym__simple_expression,
    STATE(15340), 1,
      sym_field_expression,
    STATE(19245), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [34466] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    ACTIONS(8400), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3277), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(14116), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [34598] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8402), 1,
      anon_sym_RBRACK,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3278), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13535), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [34730] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    ACTIONS(8404), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3279), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13534), 1,
      sym__pattern,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [34862] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8406), 1,
      anon_sym_RBRACK,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3280), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13871), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [34994] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3281), 1,
      sym_attribute,
    STATE(8380), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13682), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [35126] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3282), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12274), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13802), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [35258] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8408), 1,
      anon_sym_RBRACK,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3283), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13871), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [35390] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    ACTIONS(8410), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3284), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(13822), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [35522] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    ACTIONS(8412), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3285), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(14116), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [35654] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8414), 1,
      anon_sym_RBRACK,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3286), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13871), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [35786] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3287), 1,
      sym_attribute,
    STATE(8221), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13634), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [35918] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    ACTIONS(8416), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3288), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(14116), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [36050] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3289), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(10331), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13597), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [36182] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3290), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14677), 1,
      sym__simple_expression,
    STATE(15256), 1,
      sym_field_expression,
    STATE(19170), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [36312] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3291), 1,
      sym_attribute,
    STATE(8221), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13570), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [36444] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8418), 1,
      anon_sym_RBRACK,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3292), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13871), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [36576] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    ACTIONS(8420), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3293), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(14116), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [36708] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3294), 1,
      sym_attribute,
    STATE(8163), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13791), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [36840] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3295), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14854), 1,
      sym__simple_expression,
    STATE(16168), 1,
      sym_field_expression,
    STATE(17899), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [36970] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8422), 1,
      anon_sym_RBRACK,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3296), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13824), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [37102] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    ACTIONS(8424), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3297), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(14116), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [37234] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8426), 1,
      anon_sym_RBRACK,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3298), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13871), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [37366] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    ACTIONS(8428), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3299), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13528), 1,
      sym__pattern,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [37498] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3300), 1,
      sym_attribute,
    STATE(8391), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13791), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [37630] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8430), 1,
      anon_sym_RBRACK,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3301), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13871), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [37762] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    ACTIONS(8432), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3302), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(14116), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [37894] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3303), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(11925), 1,
      sym_match_case,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13743), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [38026] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3304), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14826), 1,
      sym__simple_expression,
    STATE(16325), 1,
      sym_field_expression,
    STATE(17731), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [38156] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3305), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(15066), 1,
      sym__simple_expression,
    STATE(16199), 1,
      sym_field_expression,
    STATE(19015), 1,
      sym__quoted_string,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [38286] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3306), 1,
      sym_attribute,
    STATE(8163), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13561), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [38418] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3307), 1,
      sym_attribute,
    STATE(8221), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13787), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [38550] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3308), 1,
      sym_attribute,
    STATE(8186), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13716), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [38682] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3309), 1,
      sym_attribute,
    STATE(8163), 1,
      sym_match_case,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13716), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [38814] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8434), 1,
      anon_sym_RBRACK,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3310), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13871), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [38946] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8436), 1,
      anon_sym_RBRACK,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3311), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13644), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [39078] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    ACTIONS(8438), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3312), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(14116), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [39210] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3313), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13742), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [39339] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3314), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13640), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [39468] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3315), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [39541] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3316), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [39614] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3317), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [39687] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3318), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [39760] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3319), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13767), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [39889] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(3320), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [39964] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3321), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13769), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [40093] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3322), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13827), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [40222] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3323), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13823), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [40351] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3151), 1,
      anon_sym_DOT,
    ACTIONS(3153), 1,
      anon_sym_POUND,
    ACTIONS(3155), 1,
      sym_hash_operator,
    STATE(3324), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [40430] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8440), 1,
      anon_sym_LT_DASH,
    STATE(3325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [40505] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3326), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13636), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [40634] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3327), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13775), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [40763] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3328), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13750), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [40892] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [40965] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3330), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13667), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [41094] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3331), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [41167] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [41240] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3333), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13756), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [41369] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3241), 1,
      anon_sym_DOT,
    ACTIONS(3243), 1,
      anon_sym_POUND,
    ACTIONS(3245), 1,
      sym_hash_operator,
    STATE(3334), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [41448] = 39,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    ACTIONS(7725), 1,
      anon_sym_rec,
    ACTIONS(7731), 1,
      anon_sym_open,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(3335), 1,
      sym_attribute,
    STATE(4543), 1,
      sym__attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(18926), 1,
      sym_open_module,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [41589] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3336), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13706), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [41718] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3337), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [41791] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3338), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13688), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [41920] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3339), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [41993] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3340), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [42066] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3241), 1,
      anon_sym_DOT,
    ACTIONS(3243), 1,
      anon_sym_POUND,
    ACTIONS(3245), 1,
      sym_hash_operator,
    STATE(3341), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [42145] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3342), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13663), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [42274] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3343), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13647), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [42403] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3344), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [42476] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3345), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [42549] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [42622] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3347), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [42695] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3348), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [42768] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [42841] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3350), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [42914] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [42987] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3352), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [43060] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3353), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [43133] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3354), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [43206] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3355), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [43279] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [43352] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [43425] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [43498] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3359), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13699), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [43627] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3360), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [43700] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [43773] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3362), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13588), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [43902] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3363), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [43975] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44048] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3365), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44121] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3366), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44194] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3367), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44267] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44340] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44413] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3370), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44486] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44559] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3372), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44632] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44705] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44778] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3375), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44851] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44924] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44997] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3378), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [45070] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3379), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [45143] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [45216] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [45289] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [45362] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [45435] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [45508] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3385), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [45581] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3386), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [45654] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3387), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13642), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [45783] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8442), 1,
      anon_sym_LT_DASH,
    STATE(3388), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [45858] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [45931] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [46004] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3391), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13768), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [46133] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(3392), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [46208] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3393), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [46281] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3394), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13773), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [46410] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [46483] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3241), 1,
      anon_sym_DOT,
    STATE(3396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [46558] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3397), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [46631] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [46704] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(3399), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [46779] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3400), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [46852] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [46925] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3402), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13819), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [47054] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3403), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [47127] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [47200] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3405), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [47273] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [47346] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3407), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [47419] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [47492] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3409), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13817), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [47621] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [47694] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3411), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [47767] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [47840] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [47913] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3414), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13804), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [48042] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3415), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13125), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [48171] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [48244] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3417), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13218), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [48373] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [48446] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3419), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [48519] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3420), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13758), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [48648] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(3421), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [48723] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3422), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13504), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [48852] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3423), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13230), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [48981] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3424), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [49054] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3425), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13753), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [49183] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3426), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13225), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [49312] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3151), 1,
      anon_sym_DOT,
    ACTIONS(3153), 1,
      anon_sym_POUND,
    ACTIONS(3155), 1,
      sym_hash_operator,
    STATE(3427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [49391] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [49464] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [49537] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3430), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13105), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [49666] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(3431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [49741] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [49814] = 39,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    ACTIONS(7725), 1,
      anon_sym_rec,
    ACTIONS(7731), 1,
      anon_sym_open,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(3433), 1,
      sym_attribute,
    STATE(4543), 1,
      sym__attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19189), 1,
      sym_open_module,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [49955] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [50028] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [50101] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [50174] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3437), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [50247] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3438), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13782), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [50376] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [50449] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3440), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [50522] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3441), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13217), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [50651] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3442), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13708), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [50780] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3443), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [50853] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3444), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [50926] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3445), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13704), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [51055] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3446), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [51128] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [51201] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3448), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [51274] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3449), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [51347] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3450), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [51420] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3451), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [51493] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3452), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [51566] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3453), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13673), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [51695] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3454), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [51768] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(3455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [51843] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3456), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [51916] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3457), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [51989] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [52062] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [52135] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3460), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [52208] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3461), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [52281] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3462), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13722), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [52410] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [52483] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [52556] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3465), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [52629] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3466), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13548), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [52758] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [52831] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [52904] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [52977] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(3470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [53052] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [53125] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [53198] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3473), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [53271] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [53344] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3475), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [53417] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3476), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [53490] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3477), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13544), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [53619] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [53692] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [53765] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3480), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [53838] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3481), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [53911] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3482), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13666), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [54040] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [54113] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3484), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [54186] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [54259] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3486), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [54332] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [54405] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(3488), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [54480] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [54553] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3490), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [54626] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3491), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [54699] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3492), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [54772] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [54845] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3494), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [54918] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3495), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [54991] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3496), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13125), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [55120] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3497), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [55193] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3498), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [55266] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3499), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13660), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [55395] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3500), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13555), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [55524] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [55597] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [55670] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3503), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [55743] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [55816] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3505), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(14007), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [55945] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [56018] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3507), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [56091] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3508), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13653), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [56220] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3509), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [56293] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3510), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(14529), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [56422] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3511), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(14533), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [56551] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3512), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [56624] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3513), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [56697] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3514), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [56770] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3515), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [56843] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3516), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [56916] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3517), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [56989] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [57062] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3519), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [57135] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3520), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [57208] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3521), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13639), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [57337] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3522), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [57410] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [57483] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3524), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13637), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [57612] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3525), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13628), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [57741] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3526), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [57814] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3527), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [57887] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3528), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [57960] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3529), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13638), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [58089] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3530), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13615), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [58218] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3531), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13105), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [58347] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3532), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [58420] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3533), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13677), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [58549] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3534), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13658), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [58678] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3535), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [58751] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3536), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [58824] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3537), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13591), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [58953] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [59026] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3539), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [59099] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3540), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [59172] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(3541), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [59247] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3542), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [59320] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3543), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [59393] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3544), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [59466] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3545), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13649), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [59595] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3546), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13702), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [59724] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3547), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [59797] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [59870] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3549), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [59943] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3550), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13635), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [60072] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3551), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [60145] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3552), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13589), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [60274] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3553), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13576), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [60403] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [60476] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3555), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [60549] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3556), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [60622] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [60695] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3558), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [60768] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6833), 1,
      sym__lowercase_identifier,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6851), 1,
      anon_sym_lazy,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(3561), 1,
      sym_tag,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10358), 1,
      sym_parenthesized_operator,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13312), 1,
      sym__binding_pattern,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(5079), 2,
      anon_sym_COLON2,
      anon_sym_as,
    STATE(3559), 2,
      sym_attribute,
      sym_constructor_path,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    ACTIONS(5077), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_COLON_COLON,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [60899] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3560), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [60972] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6833), 1,
      sym__lowercase_identifier,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6851), 1,
      anon_sym_lazy,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(3559), 1,
      sym_constructor_path,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10358), 1,
      sym_parenthesized_operator,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13310), 1,
      sym__binding_pattern,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(5079), 2,
      anon_sym_COLON2,
      anon_sym_as,
    STATE(3561), 2,
      sym_attribute,
      sym_tag,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    ACTIONS(5077), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_COLON_COLON,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [61103] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3562), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13556), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [61232] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3563), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [61305] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3564), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [61378] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3565), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [61451] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3566), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13760), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [61580] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3567), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [61653] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3568), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13671), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [61782] = 39,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    ACTIONS(7725), 1,
      anon_sym_rec,
    ACTIONS(7731), 1,
      anon_sym_open,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(3569), 1,
      sym_attribute,
    STATE(4543), 1,
      sym__attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    STATE(19650), 1,
      sym_open_module,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [61923] = 39,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    ACTIONS(7725), 1,
      anon_sym_rec,
    ACTIONS(7731), 1,
      anon_sym_open,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(3570), 1,
      sym_attribute,
    STATE(4543), 1,
      sym__attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(18619), 1,
      sym_open_module,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [62064] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [62137] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3572), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13538), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [62266] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3573), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [62339] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3574), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13552), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [62468] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3575), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [62541] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3576), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [62614] = 39,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    ACTIONS(7725), 1,
      anon_sym_rec,
    ACTIONS(7731), 1,
      anon_sym_open,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(3577), 1,
      sym_attribute,
    STATE(4543), 1,
      sym__attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    STATE(20302), 1,
      sym_open_module,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [62755] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3578), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [62828] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [62901] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3580), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13503), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [63030] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3581), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13521), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [63159] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3582), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [63232] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3583), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [63305] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3584), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [63378] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3585), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13618), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [63507] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3586), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13648), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [63636] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3587), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13643), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [63765] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3588), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [63838] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3589), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [63911] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3590), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [63984] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3591), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13550), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [64113] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3592), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13632), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [64242] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3593), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [64315] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3594), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [64388] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3595), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [64461] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3596), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13810), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [64590] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3597), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [64663] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3598), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [64736] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3599), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [64809] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3600), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [64882] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3601), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [64955] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3602), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [65028] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3603), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [65101] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3263), 1,
      anon_sym_DOT,
    ACTIONS(3265), 1,
      anon_sym_POUND,
    ACTIONS(3267), 1,
      sym_hash_operator,
    STATE(3604), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [65180] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3161), 1,
      anon_sym_DOT,
    ACTIONS(3163), 1,
      anon_sym_POUND,
    ACTIONS(3165), 1,
      sym_hash_operator,
    STATE(3605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [65259] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3606), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [65332] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [65405] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3608), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [65478] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3609), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [65551] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3610), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [65624] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3611), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [65697] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3612), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [65770] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3613), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13669), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [65899] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3614), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [65972] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3615), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [66045] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3616), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(14002), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [66174] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3617), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(14001), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [66303] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3618), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [66376] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3619), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [66449] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3620), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(13998), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [66578] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3621), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(13995), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [66707] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3622), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(13955), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [66836] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3623), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13573), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [66965] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13836), 1,
      sym__binding_pattern,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5079), 2,
      anon_sym_PIPE,
      anon_sym_as,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3624), 2,
      sym_attribute,
      sym_tag,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    ACTIONS(5077), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [67096] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    STATE(3624), 1,
      sym_tag,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13901), 1,
      sym__binding_pattern,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5079), 2,
      anon_sym_PIPE,
      anon_sym_as,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3625), 2,
      sym_attribute,
      sym_constructor_path,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    ACTIONS(5077), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [67227] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3626), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [67300] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3627), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(13870), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [67429] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [67502] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3629), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [67575] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3630), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [67648] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3631), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13712), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [67777] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [67850] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3633), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [67923] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3634), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [67996] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3635), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [68069] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [68142] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3637), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [68215] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3151), 1,
      anon_sym_DOT,
    STATE(3638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [68290] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3263), 1,
      anon_sym_DOT,
    STATE(3639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [68365] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3640), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [68438] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3641), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13790), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [68567] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3642), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [68640] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [68713] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3644), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13741), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [68842] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3645), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [68915] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3646), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13685), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [69044] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3647), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [69117] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3648), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [69190] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [69263] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3650), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [69336] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3651), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [69409] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3652), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [69482] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [69555] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3654), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13560), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [69684] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [69757] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3656), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [69830] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3657), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [69903] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [69976] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3659), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [70049] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3660), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [70122] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3661), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [70195] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [70268] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3663), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [70341] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3664), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [70414] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3665), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13651), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [70543] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3666), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13686), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [70672] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [70745] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [70818] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [70891] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3670), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13697), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [71020] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3671), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13655), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [71149] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3672), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [71222] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3161), 1,
      anon_sym_DOT,
    STATE(3673), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [71297] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [71370] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3263), 1,
      anon_sym_DOT,
    ACTIONS(3265), 1,
      anon_sym_POUND,
    ACTIONS(3267), 1,
      sym_hash_operator,
    STATE(3675), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [71449] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3676), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [71522] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [71595] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3678), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13498), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [71724] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3679), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [71797] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [71870] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3681), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13770), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [71999] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3682), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [72072] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [72145] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3684), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13871), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [72274] = 39,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    ACTIONS(7725), 1,
      anon_sym_rec,
    ACTIONS(7731), 1,
      anon_sym_open,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(3685), 1,
      sym_attribute,
    STATE(4543), 1,
      sym__attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    STATE(20468), 1,
      sym_open_module,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [72415] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3686), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13719), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [72544] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3687), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13569), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [72673] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3688), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [72746] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3689), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [72819] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3690), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [72892] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3691), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [72965] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3692), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [73038] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3693), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13592), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [73167] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3694), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [73240] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(3695), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [73315] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3696), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [73388] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3697), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [73461] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3698), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [73534] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7557), 1,
      anon_sym_exception,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7563), 1,
      anon_sym_lazy,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7567), 1,
      anon_sym_effect,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7581), 1,
      sym__uppercase_identifier,
    ACTIONS(7583), 1,
      aux_sym_tag_token1,
    ACTIONS(7585), 1,
      anon_sym_LPAREN,
    STATE(2598), 1,
      sym_constructor_path,
    STATE(2600), 1,
      sym_tag,
    STATE(3699), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__constructor_name,
    STATE(13607), 1,
      sym__signed_constant,
    STATE(14116), 1,
      sym__pattern,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(14103), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14108), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13926), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [73663] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3700), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [73736] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3701), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13622), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [73865] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3702), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13559), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [73994] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3703), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13723), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [74123] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3704), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [74196] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [74269] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3706), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [74342] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3707), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13515), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [74471] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3708), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [74544] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3709), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [74617] = 39,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    ACTIONS(7725), 1,
      anon_sym_rec,
    ACTIONS(7731), 1,
      anon_sym_open,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(3710), 1,
      sym_attribute,
    STATE(4543), 1,
      sym__attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    STATE(20247), 1,
      sym_open_module,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [74758] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3711), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13713), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [74887] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3712), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13520), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [75016] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3713), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13689), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [75145] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3714), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [75218] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3715), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [75291] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3716), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [75364] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3717), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13766), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [75493] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3718), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [75566] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3719), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13652), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [75695] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3720), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13789), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [75824] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3721), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [75897] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3722), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [75970] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3723), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [76043] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3724), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [76116] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3725), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [76189] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [76262] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3727), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [76335] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3728), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [76408] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3729), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [76481] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3730), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [76554] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [76627] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3732), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [76700] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3733), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [76773] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3734), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13587), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [76902] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3735), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13507), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [77031] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3736), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [77104] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [77177] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3738), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13608), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [77306] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3739), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13631), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [77435] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3740), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [77508] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3741), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [77581] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3742), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [77654] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3743), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [77727] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7397), 1,
      anon_sym_exception,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7401), 1,
      anon_sym_lazy,
    ACTIONS(7403), 1,
      anon_sym_effect,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2593), 1,
      sym_constructor_path,
    STATE(2597), 1,
      sym_tag,
    STATE(3744), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13833), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [77856] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3161), 1,
      anon_sym_DOT,
    ACTIONS(3163), 1,
      anon_sym_POUND,
    ACTIONS(3165), 1,
      sym_hash_operator,
    STATE(3745), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [77935] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3746), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [78008] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3747), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13603), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [78137] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4961), 1,
      anon_sym_exception,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4971), 1,
      anon_sym_lazy,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4975), 1,
      anon_sym_effect,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(2559), 1,
      sym_constructor_path,
    STATE(2562), 1,
      sym_tag,
    STATE(3748), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(12882), 1,
      sym__signed_constant,
    STATE(13547), 1,
      sym__pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13033), 8,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_or_pattern,
      sym_tuple_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(12929), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [78266] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3749), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [78338] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3750), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [78410] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3751), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 36,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [78482] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3752), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [78554] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3753), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 36,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [78626] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3754), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [78698] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3755), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [78770] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3756), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14554), 1,
      sym__simple_expression,
    STATE(16057), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [78894] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [78966] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [79038] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3759), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [79110] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3760), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [79182] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3761), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(15061), 1,
      sym__simple_expression,
    STATE(15548), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [79306] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3762), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [79378] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3763), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [79450] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3764), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [79522] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3765), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [79594] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3766), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14636), 1,
      sym__simple_expression,
    STATE(15126), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [79718] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3767), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [79790] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(3768), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [79864] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [79936] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3770), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14785), 1,
      sym__simple_expression,
    STATE(15489), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [80060] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3771), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14751), 1,
      sym__simple_expression,
    STATE(15784), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [80184] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3772), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [80256] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [80328] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3774), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [80400] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3775), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [80472] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [80544] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3777), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [80616] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3778), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [80688] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(3779), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [80762] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3780), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [80834] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3781), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [80906] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [80978] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3783), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [81050] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3784), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [81122] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3785), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [81194] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [81266] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3787), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [81338] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3788), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [81410] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3789), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [81482] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3790), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14491), 1,
      sym__simple_expression,
    STATE(16285), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [81606] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3791), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [81678] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3792), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14938), 1,
      sym__simple_expression,
    STATE(15219), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [81802] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3793), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14677), 1,
      sym__simple_expression,
    STATE(15256), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [81926] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3794), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14950), 1,
      sym__simple_expression,
    STATE(15598), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [82050] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8456), 1,
      sym__lowercase_identifier,
    ACTIONS(8458), 1,
      anon_sym_LPAREN,
    ACTIONS(8460), 1,
      anon_sym_LBRACK,
    ACTIONS(8464), 1,
      anon_sym_LBRACE,
    ACTIONS(8466), 1,
      anon_sym_object,
    ACTIONS(8468), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8470), 1,
      anon_sym_new,
    ACTIONS(8472), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8474), 1,
      anon_sym_begin,
    ACTIONS(8476), 1,
      sym_ocamlyacc_value,
    ACTIONS(8478), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8480), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8482), 1,
      anon_sym_PERCENT,
    ACTIONS(8484), 1,
      aux_sym_number_token1,
    ACTIONS(8486), 1,
      anon_sym_SQUOTE,
    ACTIONS(8488), 1,
      anon_sym_DQUOTE,
    ACTIONS(8490), 1,
      sym_prefix_operator,
    ACTIONS(8492), 1,
      sym__uppercase_identifier,
    ACTIONS(8494), 1,
      aux_sym_tag_token1,
    STATE(3795), 1,
      sym_attribute,
    STATE(4392), 1,
      sym__attribute,
    STATE(7320), 1,
      sym__value_name,
    STATE(7412), 1,
      sym_parenthesized_operator,
    STATE(7454), 1,
      sym__constructor_name,
    STATE(9180), 1,
      sym__simple_expression,
    STATE(18504), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8462), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7383), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7348), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [82174] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3796), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [82246] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3275), 1,
      anon_sym_DOT,
    ACTIONS(3277), 1,
      anon_sym_POUND,
    ACTIONS(3279), 1,
      sym_hash_operator,
    STATE(3797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [82324] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3798), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 36,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [82396] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3799), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [82468] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8482), 1,
      anon_sym_PERCENT,
    ACTIONS(8496), 1,
      sym__lowercase_identifier,
    ACTIONS(8498), 1,
      anon_sym_LPAREN,
    ACTIONS(8502), 1,
      anon_sym_LBRACE,
    ACTIONS(8504), 1,
      anon_sym_begin,
    ACTIONS(8506), 1,
      aux_sym_number_token1,
    ACTIONS(8508), 1,
      anon_sym_SQUOTE,
    ACTIONS(8510), 1,
      anon_sym_DQUOTE,
    ACTIONS(8512), 1,
      sym_prefix_operator,
    STATE(3800), 1,
      sym_attribute,
    STATE(4307), 1,
      sym__attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(7558), 1,
      sym__simple_expression,
    STATE(20132), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8500), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7550), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [82592] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3801), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [82664] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8456), 1,
      sym__lowercase_identifier,
    ACTIONS(8458), 1,
      anon_sym_LPAREN,
    ACTIONS(8460), 1,
      anon_sym_LBRACK,
    ACTIONS(8464), 1,
      anon_sym_LBRACE,
    ACTIONS(8466), 1,
      anon_sym_object,
    ACTIONS(8468), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8470), 1,
      anon_sym_new,
    ACTIONS(8472), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8474), 1,
      anon_sym_begin,
    ACTIONS(8476), 1,
      sym_ocamlyacc_value,
    ACTIONS(8478), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8480), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8482), 1,
      anon_sym_PERCENT,
    ACTIONS(8484), 1,
      aux_sym_number_token1,
    ACTIONS(8486), 1,
      anon_sym_SQUOTE,
    ACTIONS(8488), 1,
      anon_sym_DQUOTE,
    ACTIONS(8490), 1,
      sym_prefix_operator,
    ACTIONS(8492), 1,
      sym__uppercase_identifier,
    ACTIONS(8494), 1,
      aux_sym_tag_token1,
    STATE(3802), 1,
      sym_attribute,
    STATE(4385), 1,
      sym__attribute,
    STATE(7320), 1,
      sym__value_name,
    STATE(7412), 1,
      sym_parenthesized_operator,
    STATE(7454), 1,
      sym__constructor_name,
    STATE(9172), 1,
      sym__simple_expression,
    STATE(18504), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8462), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7383), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7348), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [82788] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3803), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14605), 1,
      sym__simple_expression,
    STATE(16343), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [82912] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3804), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [82984] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3805), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 36,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [83056] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3806), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [83128] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3807), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14777), 1,
      sym__simple_expression,
    STATE(16346), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [83252] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3808), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [83324] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3809), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(15006), 1,
      sym__simple_expression,
    STATE(15458), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [83448] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [83520] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8478), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8480), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8482), 1,
      anon_sym_PERCENT,
    ACTIONS(8514), 1,
      sym__lowercase_identifier,
    ACTIONS(8516), 1,
      anon_sym_LPAREN,
    ACTIONS(8518), 1,
      anon_sym_LBRACK,
    ACTIONS(8522), 1,
      anon_sym_LBRACE,
    ACTIONS(8524), 1,
      anon_sym_object,
    ACTIONS(8526), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8528), 1,
      anon_sym_new,
    ACTIONS(8530), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8532), 1,
      anon_sym_begin,
    ACTIONS(8534), 1,
      sym_ocamlyacc_value,
    ACTIONS(8536), 1,
      aux_sym_number_token1,
    ACTIONS(8538), 1,
      anon_sym_SQUOTE,
    ACTIONS(8540), 1,
      anon_sym_DQUOTE,
    ACTIONS(8542), 1,
      sym_prefix_operator,
    ACTIONS(8544), 1,
      sym__uppercase_identifier,
    ACTIONS(8546), 1,
      aux_sym_tag_token1,
    STATE(3811), 1,
      sym_attribute,
    STATE(4310), 1,
      sym__attribute,
    STATE(7480), 1,
      sym__constructor_name,
    STATE(7576), 1,
      sym__simple_expression,
    STATE(7580), 1,
      sym_parenthesized_operator,
    STATE(7659), 1,
      sym__value_name,
    STATE(18524), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8520), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7525), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7725), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [83644] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3812), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [83716] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8478), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8480), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8482), 1,
      anon_sym_PERCENT,
    ACTIONS(8514), 1,
      sym__lowercase_identifier,
    ACTIONS(8516), 1,
      anon_sym_LPAREN,
    ACTIONS(8518), 1,
      anon_sym_LBRACK,
    ACTIONS(8522), 1,
      anon_sym_LBRACE,
    ACTIONS(8524), 1,
      anon_sym_object,
    ACTIONS(8526), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8528), 1,
      anon_sym_new,
    ACTIONS(8530), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8532), 1,
      anon_sym_begin,
    ACTIONS(8534), 1,
      sym_ocamlyacc_value,
    ACTIONS(8536), 1,
      aux_sym_number_token1,
    ACTIONS(8538), 1,
      anon_sym_SQUOTE,
    ACTIONS(8540), 1,
      anon_sym_DQUOTE,
    ACTIONS(8542), 1,
      sym_prefix_operator,
    ACTIONS(8544), 1,
      sym__uppercase_identifier,
    ACTIONS(8546), 1,
      aux_sym_tag_token1,
    STATE(3813), 1,
      sym_attribute,
    STATE(4308), 1,
      sym__attribute,
    STATE(7480), 1,
      sym__constructor_name,
    STATE(7577), 1,
      sym__simple_expression,
    STATE(7580), 1,
      sym_parenthesized_operator,
    STATE(7659), 1,
      sym__value_name,
    STATE(18524), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8520), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7525), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7725), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [83840] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3814), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14567), 1,
      sym__simple_expression,
    STATE(16349), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [83964] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3815), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [84036] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3816), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(15017), 1,
      sym__simple_expression,
    STATE(15993), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [84160] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3817), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [84232] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3818), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14990), 1,
      sym__simple_expression,
    STATE(15739), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [84356] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [84428] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3820), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [84500] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [84572] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3822), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [84644] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [84716] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3824), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [84788] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3825), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [84860] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [84932] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8552), 1,
      anon_sym_COLON,
    STATE(3827), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8548), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [85006] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3828), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [85078] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3829), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 36,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [85150] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3830), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [85222] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3831), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14705), 1,
      sym__simple_expression,
    STATE(16475), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [85346] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3832), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [85418] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3833), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 36,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [85490] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3834), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 36,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [85562] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3835), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14979), 1,
      sym__simple_expression,
    STATE(15150), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [85686] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3836), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14971), 1,
      sym__simple_expression,
    STATE(15505), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [85810] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8482), 1,
      anon_sym_PERCENT,
    ACTIONS(8496), 1,
      sym__lowercase_identifier,
    ACTIONS(8498), 1,
      anon_sym_LPAREN,
    ACTIONS(8502), 1,
      anon_sym_LBRACE,
    ACTIONS(8504), 1,
      anon_sym_begin,
    ACTIONS(8506), 1,
      aux_sym_number_token1,
    ACTIONS(8508), 1,
      anon_sym_SQUOTE,
    ACTIONS(8510), 1,
      anon_sym_DQUOTE,
    ACTIONS(8512), 1,
      sym_prefix_operator,
    STATE(3837), 1,
      sym_attribute,
    STATE(4321), 1,
      sym__attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(7557), 1,
      sym__simple_expression,
    STATE(20132), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8500), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7550), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [85934] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3838), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [86006] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3839), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [86078] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3840), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [86150] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [86222] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3842), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [86294] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3275), 1,
      anon_sym_DOT,
    STATE(3843), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [86368] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3844), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14420), 1,
      sym__simple_expression,
    STATE(16204), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [86492] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8554), 1,
      anon_sym_COLON,
    STATE(3845), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8548), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [86566] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3846), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [86638] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3847), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [86710] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3848), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(15037), 1,
      sym__simple_expression,
    STATE(15212), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [86834] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3849), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [86906] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8482), 1,
      anon_sym_PERCENT,
    ACTIONS(8556), 1,
      sym__lowercase_identifier,
    ACTIONS(8558), 1,
      anon_sym_LPAREN,
    ACTIONS(8560), 1,
      anon_sym_LBRACK,
    ACTIONS(8564), 1,
      anon_sym_LBRACE,
    ACTIONS(8566), 1,
      anon_sym_object,
    ACTIONS(8568), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8570), 1,
      anon_sym_new,
    ACTIONS(8572), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8574), 1,
      anon_sym_begin,
    ACTIONS(8576), 1,
      sym_ocamlyacc_value,
    ACTIONS(8578), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8580), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8582), 1,
      aux_sym_number_token1,
    ACTIONS(8584), 1,
      anon_sym_SQUOTE,
    ACTIONS(8586), 1,
      anon_sym_DQUOTE,
    ACTIONS(8588), 1,
      sym_prefix_operator,
    ACTIONS(8590), 1,
      sym__uppercase_identifier,
    ACTIONS(8592), 1,
      aux_sym_tag_token1,
    STATE(3850), 1,
      sym_attribute,
    STATE(4202), 1,
      sym__attribute,
    STATE(9576), 1,
      sym__value_name,
    STATE(9739), 1,
      sym__constructor_name,
    STATE(9784), 1,
      sym_parenthesized_operator,
    STATE(9796), 1,
      sym__simple_expression,
    STATE(18244), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8562), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9811), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9740), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [87030] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8482), 1,
      anon_sym_PERCENT,
    ACTIONS(8556), 1,
      sym__lowercase_identifier,
    ACTIONS(8558), 1,
      anon_sym_LPAREN,
    ACTIONS(8560), 1,
      anon_sym_LBRACK,
    ACTIONS(8564), 1,
      anon_sym_LBRACE,
    ACTIONS(8566), 1,
      anon_sym_object,
    ACTIONS(8568), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8570), 1,
      anon_sym_new,
    ACTIONS(8572), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8574), 1,
      anon_sym_begin,
    ACTIONS(8576), 1,
      sym_ocamlyacc_value,
    ACTIONS(8578), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8580), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8582), 1,
      aux_sym_number_token1,
    ACTIONS(8584), 1,
      anon_sym_SQUOTE,
    ACTIONS(8586), 1,
      anon_sym_DQUOTE,
    ACTIONS(8588), 1,
      sym_prefix_operator,
    ACTIONS(8590), 1,
      sym__uppercase_identifier,
    ACTIONS(8592), 1,
      aux_sym_tag_token1,
    STATE(3851), 1,
      sym_attribute,
    STATE(4200), 1,
      sym__attribute,
    STATE(9576), 1,
      sym__value_name,
    STATE(9739), 1,
      sym__constructor_name,
    STATE(9784), 1,
      sym_parenthesized_operator,
    STATE(9797), 1,
      sym__simple_expression,
    STATE(18244), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8562), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9811), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9740), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [87154] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3852), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14926), 1,
      sym__simple_expression,
    STATE(15690), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [87278] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3853), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(15066), 1,
      sym__simple_expression,
    STATE(16199), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [87402] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(3854), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [87476] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3285), 1,
      anon_sym_DOT,
    STATE(3855), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [87550] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3856), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [87622] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [87694] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [87766] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3285), 1,
      anon_sym_DOT,
    ACTIONS(3287), 1,
      anon_sym_POUND,
    ACTIONS(3289), 1,
      sym_hash_operator,
    STATE(3859), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 33,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [87844] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3860), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14426), 1,
      sym__simple_expression,
    STATE(16481), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [87968] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3861), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [88040] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3862), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [88112] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3863), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [88184] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3864), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [88256] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3865), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [88328] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3866), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [88400] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3867), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [88472] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3868), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [88544] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3869), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14634), 1,
      sym__simple_expression,
    STATE(16031), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [88668] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [88740] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3871), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [88812] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3872), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [88884] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3873), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [88956] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [89028] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3875), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [89100] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3876), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [89172] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3285), 1,
      anon_sym_DOT,
    ACTIONS(3287), 1,
      anon_sym_POUND,
    ACTIONS(3289), 1,
      sym_hash_operator,
    STATE(3877), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 33,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [89250] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3878), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [89322] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [89394] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3880), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [89466] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3881), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [89538] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3882), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [89610] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3883), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [89682] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3884), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [89754] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3885), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [89826] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [89898] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(3887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [89972] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3888), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [90044] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3889), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [90116] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3890), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [90188] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3891), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [90260] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3892), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [90332] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3893), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [90404] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [90476] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3895), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14787), 1,
      sym__simple_expression,
    STATE(15340), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [90600] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3896), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14826), 1,
      sym__simple_expression,
    STATE(16325), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [90724] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3897), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [90796] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3898), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [90868] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [90940] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3900), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14988), 1,
      sym__simple_expression,
    STATE(15411), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [91064] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3901), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [91136] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3902), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(15073), 1,
      sym__simple_expression,
    STATE(15125), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [91260] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [91332] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3904), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [91404] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [91476] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3906), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [91548] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3907), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [91620] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(3908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [91694] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8594), 1,
      anon_sym_LT_DASH,
    STATE(3909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [91768] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [91840] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8456), 1,
      sym__lowercase_identifier,
    ACTIONS(8458), 1,
      anon_sym_LPAREN,
    ACTIONS(8460), 1,
      anon_sym_LBRACK,
    ACTIONS(8464), 1,
      anon_sym_LBRACE,
    ACTIONS(8466), 1,
      anon_sym_object,
    ACTIONS(8468), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8470), 1,
      anon_sym_new,
    ACTIONS(8472), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8474), 1,
      anon_sym_begin,
    ACTIONS(8476), 1,
      sym_ocamlyacc_value,
    ACTIONS(8482), 1,
      anon_sym_PERCENT,
    ACTIONS(8484), 1,
      aux_sym_number_token1,
    ACTIONS(8486), 1,
      anon_sym_SQUOTE,
    ACTIONS(8488), 1,
      anon_sym_DQUOTE,
    ACTIONS(8492), 1,
      sym__uppercase_identifier,
    ACTIONS(8494), 1,
      aux_sym_tag_token1,
    ACTIONS(8596), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8598), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8600), 1,
      sym_prefix_operator,
    STATE(3911), 1,
      sym_attribute,
    STATE(4338), 1,
      sym__attribute,
    STATE(7320), 1,
      sym__value_name,
    STATE(7412), 1,
      sym_parenthesized_operator,
    STATE(7454), 1,
      sym__constructor_name,
    STATE(8902), 1,
      sym__simple_expression,
    STATE(18504), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8462), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7383), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7348), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [91964] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [92036] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3913), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [92108] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3914), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14445), 1,
      sym__simple_expression,
    STATE(15583), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [92232] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3915), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14514), 1,
      sym__simple_expression,
    STATE(15569), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [92356] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3916), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [92428] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3917), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14945), 1,
      sym__simple_expression,
    STATE(15701), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [92552] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3918), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14880), 1,
      sym__simple_expression,
    STATE(16051), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [92676] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3919), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14854), 1,
      sym__simple_expression,
    STATE(16168), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [92800] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [92872] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [92944] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3922), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [93016] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3923), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14586), 1,
      sym__simple_expression,
    STATE(15899), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [93140] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3924), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [93212] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3925), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14417), 1,
      sym__simple_expression,
    STATE(15965), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [93336] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [93408] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3927), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [93480] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8602), 1,
      anon_sym_LT_DASH,
    STATE(3928), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [93554] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(3929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [93628] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3930), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [93700] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3931), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [93772] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3932), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14903), 1,
      sym__simple_expression,
    STATE(15909), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [93896] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3933), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14797), 1,
      sym__simple_expression,
    STATE(15757), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [94020] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3934), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14607), 1,
      sym__simple_expression,
    STATE(16017), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [94144] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3935), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [94216] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [94288] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3937), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [94360] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [94432] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3939), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(15047), 1,
      sym__simple_expression,
    STATE(15221), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [94556] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [94628] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8456), 1,
      sym__lowercase_identifier,
    ACTIONS(8458), 1,
      anon_sym_LPAREN,
    ACTIONS(8460), 1,
      anon_sym_LBRACK,
    ACTIONS(8464), 1,
      anon_sym_LBRACE,
    ACTIONS(8466), 1,
      anon_sym_object,
    ACTIONS(8468), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8470), 1,
      anon_sym_new,
    ACTIONS(8472), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8474), 1,
      anon_sym_begin,
    ACTIONS(8476), 1,
      sym_ocamlyacc_value,
    ACTIONS(8482), 1,
      anon_sym_PERCENT,
    ACTIONS(8484), 1,
      aux_sym_number_token1,
    ACTIONS(8486), 1,
      anon_sym_SQUOTE,
    ACTIONS(8488), 1,
      anon_sym_DQUOTE,
    ACTIONS(8492), 1,
      sym__uppercase_identifier,
    ACTIONS(8494), 1,
      aux_sym_tag_token1,
    ACTIONS(8596), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8598), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8600), 1,
      sym_prefix_operator,
    STATE(3941), 1,
      sym_attribute,
    STATE(4293), 1,
      sym__attribute,
    STATE(7320), 1,
      sym__value_name,
    STATE(7412), 1,
      sym_parenthesized_operator,
    STATE(7454), 1,
      sym__constructor_name,
    STATE(8903), 1,
      sym__simple_expression,
    STATE(18504), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8462), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7383), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7348), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [94752] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3942), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14758), 1,
      sym__simple_expression,
    STATE(15145), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [94876] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [94948] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3275), 1,
      anon_sym_DOT,
    ACTIONS(3277), 1,
      anon_sym_POUND,
    ACTIONS(3279), 1,
      sym_hash_operator,
    STATE(3944), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [95026] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3945), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [95098] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3946), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [95170] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3947), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [95242] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3948), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [95314] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3949), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [95386] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3950), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [95458] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3951), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [95530] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3952), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [95602] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3953), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [95674] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3954), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(15008), 1,
      sym__simple_expression,
    STATE(15317), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [95798] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3955), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [95870] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3956), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(14709), 1,
      sym__simple_expression,
    STATE(15399), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [95994] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3957), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [96066] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [96138] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3959), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [96210] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3960), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 36,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [96282] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3961), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [96354] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3962), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [96426] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3963), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [96498] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3964), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [96570] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3965), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [96642] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8020), 1,
      sym__lowercase_identifier,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3966), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(14194), 1,
      sym_field_path,
    STATE(15071), 1,
      sym__simple_expression,
    STATE(15338), 1,
      sym_field_expression,
    STATE(20441), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [96766] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3967), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 36,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [96838] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3968), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [96910] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [96982] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3970), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [97053] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3971), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [97124] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3972), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [97195] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3973), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [97266] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3229), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(3974), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [97387] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8604), 1,
      anon_sym_COLON,
    STATE(3975), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8548), 33,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [97460] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3191), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(3976), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [97581] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3977), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [97652] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8606), 1,
      anon_sym_LT_DASH,
    STATE(3978), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [97725] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [97796] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3980), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [97867] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3981), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [97938] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [98009] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3193), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(3983), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [98130] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3984), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [98201] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3221), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(3985), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [98322] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [98393] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3987), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [98464] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [98535] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3989), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [98606] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3990), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [98677] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3185), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(3991), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [98798] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3992), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [98869] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3993), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [98940] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3994), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [99011] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3995), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [99082] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3996), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [99153] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3997), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [99224] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3998), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [99295] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3999), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [99366] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4000), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [99437] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4001), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [99508] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4002), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [99579] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4003), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [99650] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3187), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4004), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [99771] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4005), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [99842] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4006), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [99913] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3449), 1,
      anon_sym_DOT,
    ACTIONS(3451), 1,
      anon_sym_POUND,
    ACTIONS(3453), 1,
      sym_hash_operator,
    STATE(4007), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [99990] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4008), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [100061] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4009), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [100132] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4010), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [100203] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3183), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4011), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [100324] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3179), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4012), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [100445] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4013), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [100516] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4014), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [100587] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3331), 1,
      anon_sym_DOT,
    ACTIONS(3333), 1,
      anon_sym_POUND,
    ACTIONS(3335), 1,
      sym_hash_operator,
    STATE(4015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [100664] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(4016), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [100737] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3189), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4017), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [100858] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [100929] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [101000] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4020), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [101071] = 37,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5245), 1,
      sym__lowercase_identifier,
    ACTIONS(5247), 1,
      anon_sym_LPAREN,
    ACTIONS(5249), 1,
      anon_sym_LBRACK,
    ACTIONS(5253), 1,
      anon_sym_LBRACE,
    ACTIONS(5255), 1,
      anon_sym_POUND,
    ACTIONS(5257), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5259), 1,
      anon_sym_lazy,
    ACTIONS(5261), 1,
      anon_sym_begin,
    ACTIONS(5267), 1,
      aux_sym_number_token1,
    ACTIONS(5269), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5271), 1,
      anon_sym_SQUOTE,
    ACTIONS(5273), 1,
      anon_sym_DQUOTE,
    ACTIONS(5275), 1,
      sym__uppercase_identifier,
    ACTIONS(5277), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(8608), 1,
      anon_sym_rec,
    ACTIONS(8610), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8612), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2458), 1,
      sym_tag,
    STATE(2459), 1,
      sym_constructor_path,
    STATE(2493), 1,
      sym__binding_pattern,
    STATE(4021), 1,
      sym_attribute,
    STATE(4524), 1,
      sym__attribute,
    STATE(5482), 1,
      sym__signed_constant,
    STATE(5554), 1,
      sym__constructor_name,
    STATE(5674), 1,
      sym_parenthesized_operator,
    STATE(5721), 1,
      sym_array_binding_pattern,
    STATE(5723), 1,
      sym_list_binding_pattern,
    STATE(5729), 1,
      sym_record_binding_pattern,
    STATE(11849), 1,
      sym_let_binding,
    STATE(19030), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5251), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5522), 2,
      sym__constant,
      sym_signed_number,
    STATE(5551), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5731), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [101206] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4022), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [101277] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3231), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4023), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [101398] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [101469] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4025), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [101540] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4026), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [101611] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4027), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [101682] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3201), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4028), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [101803] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4029), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [101874] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3233), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4030), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [101995] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4031), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [102066] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(4032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [102139] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4033), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [102210] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3195), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4034), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [102331] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4035), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [102402] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4036), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [102473] = 37,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5201), 1,
      sym__lowercase_identifier,
    ACTIONS(5203), 1,
      anon_sym_LPAREN,
    ACTIONS(5205), 1,
      anon_sym_LBRACK,
    ACTIONS(5209), 1,
      anon_sym_LBRACE,
    ACTIONS(5211), 1,
      anon_sym_POUND,
    ACTIONS(5213), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5215), 1,
      anon_sym_lazy,
    ACTIONS(5217), 1,
      anon_sym_begin,
    ACTIONS(5223), 1,
      aux_sym_number_token1,
    ACTIONS(5225), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5227), 1,
      anon_sym_SQUOTE,
    ACTIONS(5229), 1,
      anon_sym_DQUOTE,
    ACTIONS(5231), 1,
      sym__uppercase_identifier,
    ACTIONS(5233), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(8614), 1,
      anon_sym_rec,
    ACTIONS(8616), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8618), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2455), 1,
      sym_tag,
    STATE(2456), 1,
      sym_constructor_path,
    STATE(2492), 1,
      sym__binding_pattern,
    STATE(4037), 1,
      sym_attribute,
    STATE(4492), 1,
      sym__attribute,
    STATE(5443), 1,
      sym__signed_constant,
    STATE(5444), 1,
      sym__constructor_name,
    STATE(5626), 1,
      sym_array_binding_pattern,
    STATE(5663), 1,
      sym_list_binding_pattern,
    STATE(5664), 1,
      sym_record_binding_pattern,
    STATE(5725), 1,
      sym_parenthesized_operator,
    STATE(11783), 1,
      sym_let_binding,
    STATE(18726), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5207), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5523), 2,
      sym__constant,
      sym_signed_number,
    STATE(5445), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5668), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [102608] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [102679] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3257), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4039), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [102800] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [102871] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4041), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [102942] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8226), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [103013] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [103084] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [103155] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4045), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [103226] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8620), 1,
      anon_sym_LT_DASH,
    STATE(4046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [103299] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4047), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [103370] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4048), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [103441] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3177), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4049), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [103562] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3197), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4050), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [103683] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4051), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [103754] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4052), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8226), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [103825] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3331), 1,
      anon_sym_DOT,
    ACTIONS(3333), 1,
      anon_sym_POUND,
    ACTIONS(3335), 1,
      sym_hash_operator,
    STATE(4053), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [103902] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4054), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [103973] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4055), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [104044] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4056), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [104115] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3199), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4057), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [104236] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4058), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [104307] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4059), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [104378] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3211), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4060), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [104499] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4061), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [104570] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4062), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [104641] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4063), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [104712] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4064), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [104783] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3209), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4065), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [104904] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4066), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8622), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [104975] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4067), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [105046] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3225), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4068), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [105167] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3223), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4069), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [105288] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4070), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [105359] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4071), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [105430] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8626), 1,
      anon_sym_COLON,
    STATE(4072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8548), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [105503] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3203), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4073), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [105624] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3207), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4074), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [105745] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4075), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [105816] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(4076), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [105889] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3331), 1,
      anon_sym_DOT,
    STATE(4077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [105962] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4078), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [106033] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8628), 1,
      anon_sym_COLON,
    STATE(4079), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8548), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [106106] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4080), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [106177] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [106248] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3249), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4082), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [106369] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3135), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4083), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [106490] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [106561] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4085), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [106632] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3251), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4086), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [106753] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4087), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [106824] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4088), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [106895] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3143), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4089), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [107016] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3255), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4090), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [107137] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4091), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [107208] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4092), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [107279] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4093), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [107350] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3449), 1,
      anon_sym_DOT,
    ACTIONS(3451), 1,
      anon_sym_POUND,
    ACTIONS(3453), 1,
      sym_hash_operator,
    STATE(4094), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [107427] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3215), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4095), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [107548] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4096), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [107619] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4097), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [107690] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4098), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [107761] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4099), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [107832] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4100), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [107903] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3175), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4101), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [108024] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4102), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [108095] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [108166] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4104), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [108237] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3217), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4105), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [108358] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3139), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4106), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [108479] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4107), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [108550] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [108621] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3269), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4109), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [108742] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [108813] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4111), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [108884] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [108955] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [109026] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4114), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [109097] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [109168] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [109239] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4117), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [109310] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4118), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [109381] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4119), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [109452] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3449), 1,
      anon_sym_DOT,
    STATE(4120), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [109525] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [109596] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4122), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [109667] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [109738] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3205), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4124), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [109859] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [109930] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3141), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4126), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [110051] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4127), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [110122] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4128), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [110193] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4129), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [110264] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4130), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [110335] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3169), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4131), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [110456] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [110527] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4133), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [110598] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [110669] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3253), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4135), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [110790] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [110861] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [110932] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [111003] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4139), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [111074] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [111145] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4141), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [111216] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [111287] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [111358] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [111429] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [111500] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3213), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4146), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [111621] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8622), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [111692] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8630), 1,
      anon_sym_COLON,
    STATE(4148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8548), 33,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [111765] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3171), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4149), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [111886] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4150), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [111957] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4151), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [112028] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4152), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [112099] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4153), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [112170] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4154), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [112241] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [112312] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4156), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [112383] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3167), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4157), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [112504] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4158), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [112575] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [112646] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [112717] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4161), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [112788] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [112859] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [112930] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [113001] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [113072] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4166), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [113143] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4167), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [113214] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [113285] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4169), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [113356] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3173), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4170), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [113477] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [113548] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [113619] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [113690] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(4174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [113763] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4175), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [113834] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3219), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4176), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [113955] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4177), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [114026] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [114097] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [114168] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [114239] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3235), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4181), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [114360] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(3137), 1,
      anon_sym_RPAREN,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4182), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [114481] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(4183), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [114554] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4184), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [114625] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(4185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [114698] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [114769] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4187), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [114840] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [114911] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [114982] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2695), 1,
      anon_sym_LPAREN,
    ACTIONS(2697), 1,
      anon_sym_LBRACK,
    ACTIONS(2701), 1,
      anon_sym_LBRACE,
    ACTIONS(2703), 1,
      anon_sym_object,
    ACTIONS(2707), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2717), 1,
      anon_sym_new,
    ACTIONS(2719), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2721), 1,
      anon_sym_begin,
    ACTIONS(2723), 1,
      sym_ocamlyacc_value,
    ACTIONS(2725), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2727), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2729), 1,
      aux_sym_number_token1,
    ACTIONS(2731), 1,
      anon_sym_SQUOTE,
    ACTIONS(2733), 1,
      anon_sym_DQUOTE,
    ACTIONS(2735), 1,
      sym_prefix_operator,
    ACTIONS(2739), 1,
      sym__uppercase_identifier,
    ACTIONS(2741), 1,
      aux_sym_tag_token1,
    ACTIONS(5561), 1,
      sym__lowercase_identifier,
    STATE(4190), 1,
      sym_attribute,
    STATE(6876), 1,
      sym__simple_expression,
    STATE(6885), 1,
      sym__constructor_name,
    STATE(7081), 1,
      sym__value_name,
    STATE(7147), 1,
      sym_parenthesized_operator,
    STATE(19042), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2699), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6871), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7067), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [115100] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2695), 1,
      anon_sym_LPAREN,
    ACTIONS(2697), 1,
      anon_sym_LBRACK,
    ACTIONS(2701), 1,
      anon_sym_LBRACE,
    ACTIONS(2703), 1,
      anon_sym_object,
    ACTIONS(2707), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2717), 1,
      anon_sym_new,
    ACTIONS(2719), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2721), 1,
      anon_sym_begin,
    ACTIONS(2723), 1,
      sym_ocamlyacc_value,
    ACTIONS(2725), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2727), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2729), 1,
      aux_sym_number_token1,
    ACTIONS(2731), 1,
      anon_sym_SQUOTE,
    ACTIONS(2733), 1,
      anon_sym_DQUOTE,
    ACTIONS(2735), 1,
      sym_prefix_operator,
    ACTIONS(2739), 1,
      sym__uppercase_identifier,
    ACTIONS(2741), 1,
      aux_sym_tag_token1,
    ACTIONS(5561), 1,
      sym__lowercase_identifier,
    STATE(4191), 1,
      sym_attribute,
    STATE(6885), 1,
      sym__constructor_name,
    STATE(7081), 1,
      sym__value_name,
    STATE(7147), 1,
      sym_parenthesized_operator,
    STATE(7245), 1,
      sym__simple_expression,
    STATE(19042), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2699), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6871), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7067), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [115218] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4192), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [115288] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6553), 1,
      sym__lowercase_identifier,
    ACTIONS(6557), 1,
      anon_sym_LPAREN,
    ACTIONS(6559), 1,
      anon_sym_LBRACK,
    ACTIONS(6563), 1,
      anon_sym_LBRACE,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(6567), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6569), 1,
      anon_sym_new,
    ACTIONS(6571), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(6573), 1,
      anon_sym_begin,
    ACTIONS(6575), 1,
      sym_ocamlyacc_value,
    ACTIONS(6581), 1,
      aux_sym_number_token1,
    ACTIONS(6583), 1,
      anon_sym_SQUOTE,
    ACTIONS(6585), 1,
      anon_sym_DQUOTE,
    ACTIONS(6587), 1,
      sym_prefix_operator,
    ACTIONS(6589), 1,
      sym__uppercase_identifier,
    ACTIONS(6591), 1,
      aux_sym_tag_token1,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4193), 1,
      sym_attribute,
    STATE(6841), 1,
      sym_parenthesized_operator,
    STATE(6843), 1,
      sym__simple_expression,
    STATE(6884), 1,
      sym__value_name,
    STATE(6890), 1,
      sym__constructor_name,
    STATE(18104), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6561), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6891), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6896), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [115406] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4194), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [115476] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [115546] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [115616] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [115686] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8636), 1,
      anon_sym_COLON,
    STATE(4198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8548), 32,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [115758] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [115828] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8556), 1,
      sym__lowercase_identifier,
    ACTIONS(8558), 1,
      anon_sym_LPAREN,
    ACTIONS(8560), 1,
      anon_sym_LBRACK,
    ACTIONS(8564), 1,
      anon_sym_LBRACE,
    ACTIONS(8566), 1,
      anon_sym_object,
    ACTIONS(8568), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8570), 1,
      anon_sym_new,
    ACTIONS(8572), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8574), 1,
      anon_sym_begin,
    ACTIONS(8576), 1,
      sym_ocamlyacc_value,
    ACTIONS(8578), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8580), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8582), 1,
      aux_sym_number_token1,
    ACTIONS(8584), 1,
      anon_sym_SQUOTE,
    ACTIONS(8586), 1,
      anon_sym_DQUOTE,
    ACTIONS(8588), 1,
      sym_prefix_operator,
    ACTIONS(8590), 1,
      sym__uppercase_identifier,
    ACTIONS(8592), 1,
      aux_sym_tag_token1,
    STATE(4200), 1,
      sym_attribute,
    STATE(9576), 1,
      sym__value_name,
    STATE(9739), 1,
      sym__constructor_name,
    STATE(9784), 1,
      sym_parenthesized_operator,
    STATE(9860), 1,
      sym__simple_expression,
    STATE(18244), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8562), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9811), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9740), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [115946] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5581), 1,
      sym__lowercase_identifier,
    ACTIONS(5589), 1,
      anon_sym_LPAREN,
    ACTIONS(5591), 1,
      anon_sym_LBRACK,
    ACTIONS(5595), 1,
      anon_sym_LBRACE,
    ACTIONS(5597), 1,
      anon_sym_object,
    ACTIONS(5599), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5601), 1,
      anon_sym_new,
    ACTIONS(5603), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(5605), 1,
      anon_sym_begin,
    ACTIONS(5607), 1,
      sym_ocamlyacc_value,
    ACTIONS(5613), 1,
      aux_sym_number_token1,
    ACTIONS(5615), 1,
      anon_sym_SQUOTE,
    ACTIONS(5617), 1,
      anon_sym_DQUOTE,
    ACTIONS(5619), 1,
      sym_prefix_operator,
    ACTIONS(5621), 1,
      sym__uppercase_identifier,
    ACTIONS(5623), 1,
      aux_sym_tag_token1,
    ACTIONS(8638), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8640), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4201), 1,
      sym_attribute,
    STATE(5852), 1,
      sym__simple_expression,
    STATE(5955), 1,
      sym__value_name,
    STATE(6068), 1,
      sym_parenthesized_operator,
    STATE(6088), 1,
      sym__constructor_name,
    STATE(18110), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5593), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6094), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5961), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [116064] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8556), 1,
      sym__lowercase_identifier,
    ACTIONS(8558), 1,
      anon_sym_LPAREN,
    ACTIONS(8560), 1,
      anon_sym_LBRACK,
    ACTIONS(8564), 1,
      anon_sym_LBRACE,
    ACTIONS(8566), 1,
      anon_sym_object,
    ACTIONS(8568), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8570), 1,
      anon_sym_new,
    ACTIONS(8572), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8574), 1,
      anon_sym_begin,
    ACTIONS(8576), 1,
      sym_ocamlyacc_value,
    ACTIONS(8578), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8580), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8582), 1,
      aux_sym_number_token1,
    ACTIONS(8584), 1,
      anon_sym_SQUOTE,
    ACTIONS(8586), 1,
      anon_sym_DQUOTE,
    ACTIONS(8588), 1,
      sym_prefix_operator,
    ACTIONS(8590), 1,
      sym__uppercase_identifier,
    ACTIONS(8592), 1,
      aux_sym_tag_token1,
    STATE(4202), 1,
      sym_attribute,
    STATE(9576), 1,
      sym__value_name,
    STATE(9739), 1,
      sym__constructor_name,
    STATE(9784), 1,
      sym_parenthesized_operator,
    STATE(9857), 1,
      sym__simple_expression,
    STATE(18244), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8562), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9811), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9740), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [116182] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8456), 1,
      sym__lowercase_identifier,
    ACTIONS(8458), 1,
      anon_sym_LPAREN,
    ACTIONS(8460), 1,
      anon_sym_LBRACK,
    ACTIONS(8464), 1,
      anon_sym_LBRACE,
    ACTIONS(8466), 1,
      anon_sym_object,
    ACTIONS(8468), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8470), 1,
      anon_sym_new,
    ACTIONS(8472), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8474), 1,
      anon_sym_begin,
    ACTIONS(8476), 1,
      sym_ocamlyacc_value,
    ACTIONS(8484), 1,
      aux_sym_number_token1,
    ACTIONS(8486), 1,
      anon_sym_SQUOTE,
    ACTIONS(8488), 1,
      anon_sym_DQUOTE,
    ACTIONS(8492), 1,
      sym__uppercase_identifier,
    ACTIONS(8494), 1,
      aux_sym_tag_token1,
    ACTIONS(8596), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8598), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8600), 1,
      sym_prefix_operator,
    STATE(4203), 1,
      sym_attribute,
    STATE(7320), 1,
      sym__value_name,
    STATE(7338), 1,
      sym__simple_expression,
    STATE(7412), 1,
      sym_parenthesized_operator,
    STATE(7454), 1,
      sym__constructor_name,
    STATE(18504), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8462), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7383), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7348), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [116300] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6553), 1,
      sym__lowercase_identifier,
    ACTIONS(6557), 1,
      anon_sym_LPAREN,
    ACTIONS(6559), 1,
      anon_sym_LBRACK,
    ACTIONS(6563), 1,
      anon_sym_LBRACE,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(6567), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6569), 1,
      anon_sym_new,
    ACTIONS(6571), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(6573), 1,
      anon_sym_begin,
    ACTIONS(6575), 1,
      sym_ocamlyacc_value,
    ACTIONS(6581), 1,
      aux_sym_number_token1,
    ACTIONS(6583), 1,
      anon_sym_SQUOTE,
    ACTIONS(6585), 1,
      anon_sym_DQUOTE,
    ACTIONS(6587), 1,
      sym_prefix_operator,
    ACTIONS(6589), 1,
      sym__uppercase_identifier,
    ACTIONS(6591), 1,
      aux_sym_tag_token1,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4204), 1,
      sym_attribute,
    STATE(6764), 1,
      sym__simple_expression,
    STATE(6841), 1,
      sym_parenthesized_operator,
    STATE(6884), 1,
      sym__value_name,
    STATE(6890), 1,
      sym__constructor_name,
    STATE(18104), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6561), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6891), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6896), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [116418] = 29,
    ACTIONS(861), 1,
      anon_sym_LPAREN,
    ACTIONS(863), 1,
      anon_sym_LBRACK,
    ACTIONS(867), 1,
      anon_sym_LBRACE,
    ACTIONS(869), 1,
      anon_sym_object,
    ACTIONS(873), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(883), 1,
      anon_sym_new,
    ACTIONS(885), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(887), 1,
      anon_sym_begin,
    ACTIONS(889), 1,
      sym_ocamlyacc_value,
    ACTIONS(895), 1,
      aux_sym_number_token1,
    ACTIONS(897), 1,
      anon_sym_SQUOTE,
    ACTIONS(899), 1,
      anon_sym_DQUOTE,
    ACTIONS(901), 1,
      sym_prefix_operator,
    ACTIONS(905), 1,
      sym__uppercase_identifier,
    ACTIONS(907), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3103), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3105), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3445), 1,
      sym__lowercase_identifier,
    STATE(4054), 1,
      sym__constructor_name,
    STATE(4062), 1,
      sym__simple_expression,
    STATE(4104), 1,
      sym__value_name,
    STATE(4160), 1,
      sym_parenthesized_operator,
    STATE(4205), 1,
      sym_attribute,
    STATE(17631), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(865), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4047), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4041), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [116536] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4206), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [116606] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2591), 1,
      anon_sym_LPAREN,
    ACTIONS(2593), 1,
      anon_sym_LBRACK,
    ACTIONS(2597), 1,
      anon_sym_LBRACE,
    ACTIONS(2599), 1,
      anon_sym_object,
    ACTIONS(2603), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2613), 1,
      anon_sym_new,
    ACTIONS(2615), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2617), 1,
      anon_sym_begin,
    ACTIONS(2619), 1,
      sym_ocamlyacc_value,
    ACTIONS(2621), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2623), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2625), 1,
      aux_sym_number_token1,
    ACTIONS(2627), 1,
      anon_sym_SQUOTE,
    ACTIONS(2629), 1,
      anon_sym_DQUOTE,
    ACTIONS(2631), 1,
      sym_prefix_operator,
    ACTIONS(2635), 1,
      sym__uppercase_identifier,
    ACTIONS(2637), 1,
      aux_sym_tag_token1,
    ACTIONS(5529), 1,
      sym__lowercase_identifier,
    STATE(4207), 1,
      sym_attribute,
    STATE(6945), 1,
      sym_parenthesized_operator,
    STATE(6963), 1,
      sym__constructor_name,
    STATE(7084), 1,
      sym__simple_expression,
    STATE(7135), 1,
      sym__value_name,
    STATE(18738), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2595), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6961), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7138), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [116724] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4208), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8622), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [116794] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4209), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [116864] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [116934] = 29,
    ACTIONS(413), 1,
      anon_sym_LPAREN,
    ACTIONS(417), 1,
      anon_sym_LBRACK,
    ACTIONS(421), 1,
      anon_sym_LBRACE,
    ACTIONS(431), 1,
      anon_sym_object,
    ACTIONS(435), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(445), 1,
      anon_sym_new,
    ACTIONS(447), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(449), 1,
      anon_sym_begin,
    ACTIONS(451), 1,
      sym_ocamlyacc_value,
    ACTIONS(457), 1,
      aux_sym_number_token1,
    ACTIONS(459), 1,
      anon_sym_SQUOTE,
    ACTIONS(461), 1,
      anon_sym_DQUOTE,
    ACTIONS(463), 1,
      sym_prefix_operator,
    ACTIONS(469), 1,
      sym__uppercase_identifier,
    ACTIONS(473), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3095), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3097), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3955), 1,
      sym__lowercase_identifier,
    STATE(4211), 1,
      sym_attribute,
    STATE(4258), 1,
      sym__simple_expression,
    STATE(4279), 1,
      sym_parenthesized_operator,
    STATE(4287), 1,
      sym__value_name,
    STATE(4480), 1,
      sym__constructor_name,
    STATE(20400), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(419), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4219), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4413), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [117052] = 29,
    ACTIONS(637), 1,
      anon_sym_LPAREN,
    ACTIONS(639), 1,
      anon_sym_LBRACK,
    ACTIONS(643), 1,
      anon_sym_LBRACE,
    ACTIONS(645), 1,
      anon_sym_object,
    ACTIONS(649), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(659), 1,
      anon_sym_new,
    ACTIONS(661), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(663), 1,
      anon_sym_begin,
    ACTIONS(665), 1,
      sym_ocamlyacc_value,
    ACTIONS(671), 1,
      aux_sym_number_token1,
    ACTIONS(673), 1,
      anon_sym_SQUOTE,
    ACTIONS(675), 1,
      anon_sym_DQUOTE,
    ACTIONS(677), 1,
      sym_prefix_operator,
    ACTIONS(681), 1,
      sym__uppercase_identifier,
    ACTIONS(683), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3131), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3133), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3147), 1,
      sym__lowercase_identifier,
    STATE(3324), 1,
      sym__simple_expression,
    STATE(3405), 1,
      sym_parenthesized_operator,
    STATE(3457), 1,
      sym__value_name,
    STATE(3460), 1,
      sym__constructor_name,
    STATE(4212), 1,
      sym_attribute,
    STATE(17786), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(641), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3635), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3727), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [117170] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2417), 1,
      anon_sym_LPAREN,
    ACTIONS(2419), 1,
      anon_sym_LBRACK,
    ACTIONS(2423), 1,
      anon_sym_LBRACE,
    ACTIONS(2425), 1,
      anon_sym_object,
    ACTIONS(2429), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2439), 1,
      anon_sym_new,
    ACTIONS(2441), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2443), 1,
      anon_sym_begin,
    ACTIONS(2445), 1,
      sym_ocamlyacc_value,
    ACTIONS(2447), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2449), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2451), 1,
      aux_sym_number_token1,
    ACTIONS(2453), 1,
      anon_sym_SQUOTE,
    ACTIONS(2455), 1,
      anon_sym_DQUOTE,
    ACTIONS(2457), 1,
      sym_prefix_operator,
    ACTIONS(2461), 1,
      sym__uppercase_identifier,
    ACTIONS(2463), 1,
      aux_sym_tag_token1,
    ACTIONS(5393), 1,
      sym__lowercase_identifier,
    STATE(4213), 1,
      sym_attribute,
    STATE(6205), 1,
      sym__simple_expression,
    STATE(6262), 1,
      sym__value_name,
    STATE(6367), 1,
      sym__constructor_name,
    STATE(6621), 1,
      sym_parenthesized_operator,
    STATE(18284), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2421), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6373), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6162), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [117288] = 29,
    ACTIONS(757), 1,
      anon_sym_LPAREN,
    ACTIONS(759), 1,
      anon_sym_LBRACK,
    ACTIONS(763), 1,
      anon_sym_LBRACE,
    ACTIONS(765), 1,
      anon_sym_object,
    ACTIONS(769), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(779), 1,
      anon_sym_new,
    ACTIONS(781), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(783), 1,
      anon_sym_begin,
    ACTIONS(785), 1,
      sym_ocamlyacc_value,
    ACTIONS(791), 1,
      aux_sym_number_token1,
    ACTIONS(793), 1,
      anon_sym_SQUOTE,
    ACTIONS(795), 1,
      anon_sym_DQUOTE,
    ACTIONS(797), 1,
      sym_prefix_operator,
    ACTIONS(801), 1,
      sym__uppercase_identifier,
    ACTIONS(803), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3087), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3089), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3271), 1,
      sym__lowercase_identifier,
    STATE(3777), 1,
      sym__constructor_name,
    STATE(3791), 1,
      sym_parenthesized_operator,
    STATE(3843), 1,
      sym__simple_expression,
    STATE(3924), 1,
      sym__value_name,
    STATE(4214), 1,
      sym_attribute,
    STATE(18444), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(761), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3778), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3838), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [117406] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4215), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [117476] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4216), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [117546] = 29,
    ACTIONS(757), 1,
      anon_sym_LPAREN,
    ACTIONS(759), 1,
      anon_sym_LBRACK,
    ACTIONS(763), 1,
      anon_sym_LBRACE,
    ACTIONS(765), 1,
      anon_sym_object,
    ACTIONS(769), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(779), 1,
      anon_sym_new,
    ACTIONS(781), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(783), 1,
      anon_sym_begin,
    ACTIONS(785), 1,
      sym_ocamlyacc_value,
    ACTIONS(791), 1,
      aux_sym_number_token1,
    ACTIONS(793), 1,
      anon_sym_SQUOTE,
    ACTIONS(795), 1,
      anon_sym_DQUOTE,
    ACTIONS(797), 1,
      sym_prefix_operator,
    ACTIONS(801), 1,
      sym__uppercase_identifier,
    ACTIONS(803), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3087), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3089), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3271), 1,
      sym__lowercase_identifier,
    STATE(3777), 1,
      sym__constructor_name,
    STATE(3791), 1,
      sym_parenthesized_operator,
    STATE(3806), 1,
      sym__simple_expression,
    STATE(3924), 1,
      sym__value_name,
    STATE(4217), 1,
      sym_attribute,
    STATE(18444), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(761), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3778), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3838), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [117664] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [117734] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4219), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [117804] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4220), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8226), 33,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [117874] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4221), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [117944] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4222), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [118014] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4223), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [118084] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [118154] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4225), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [118224] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(4149), 1,
      anon_sym_DOT,
    STATE(4226), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [118296] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4227), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [118366] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [118436] = 29,
    ACTIONS(303), 1,
      anon_sym_LPAREN,
    ACTIONS(305), 1,
      anon_sym_LBRACK,
    ACTIONS(309), 1,
      anon_sym_LBRACE,
    ACTIONS(311), 1,
      anon_sym_object,
    ACTIONS(315), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(325), 1,
      anon_sym_new,
    ACTIONS(327), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(329), 1,
      anon_sym_begin,
    ACTIONS(331), 1,
      sym_ocamlyacc_value,
    ACTIONS(339), 1,
      aux_sym_number_token1,
    ACTIONS(341), 1,
      anon_sym_SQUOTE,
    ACTIONS(343), 1,
      anon_sym_DQUOTE,
    ACTIONS(345), 1,
      sym_prefix_operator,
    ACTIONS(351), 1,
      sym__uppercase_identifier,
    ACTIONS(353), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3049), 1,
      sym__lowercase_identifier,
    ACTIONS(3119), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3121), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2972), 1,
      sym__value_name,
    STATE(3023), 1,
      sym__simple_expression,
    STATE(3089), 1,
      sym_parenthesized_operator,
    STATE(3189), 1,
      sym__constructor_name,
    STATE(4229), 1,
      sym_attribute,
    STATE(18756), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(307), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3188), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3052), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [118554] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [118624] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4231), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [118694] = 29,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(361), 1,
      anon_sym_LBRACK,
    ACTIONS(365), 1,
      anon_sym_LBRACE,
    ACTIONS(367), 1,
      anon_sym_object,
    ACTIONS(371), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(381), 1,
      anon_sym_new,
    ACTIONS(383), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(385), 1,
      anon_sym_begin,
    ACTIONS(387), 1,
      sym_ocamlyacc_value,
    ACTIONS(393), 1,
      aux_sym_number_token1,
    ACTIONS(395), 1,
      anon_sym_SQUOTE,
    ACTIONS(397), 1,
      anon_sym_DQUOTE,
    ACTIONS(399), 1,
      sym_prefix_operator,
    ACTIONS(403), 1,
      sym__uppercase_identifier,
    ACTIONS(405), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3077), 1,
      sym__lowercase_identifier,
    ACTIONS(3107), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3109), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2983), 1,
      sym_parenthesized_operator,
    STATE(3103), 1,
      sym__value_name,
    STATE(3124), 1,
      sym__constructor_name,
    STATE(3158), 1,
      sym__simple_expression,
    STATE(4232), 1,
      sym_attribute,
    STATE(18642), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(363), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3123), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3176), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [118812] = 29,
    ACTIONS(531), 1,
      anon_sym_LPAREN,
    ACTIONS(533), 1,
      anon_sym_LBRACK,
    ACTIONS(537), 1,
      anon_sym_LBRACE,
    ACTIONS(539), 1,
      anon_sym_object,
    ACTIONS(543), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(553), 1,
      anon_sym_new,
    ACTIONS(555), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(557), 1,
      anon_sym_begin,
    ACTIONS(559), 1,
      sym_ocamlyacc_value,
    ACTIONS(565), 1,
      aux_sym_number_token1,
    ACTIONS(567), 1,
      anon_sym_SQUOTE,
    ACTIONS(569), 1,
      anon_sym_DQUOTE,
    ACTIONS(571), 1,
      sym_prefix_operator,
    ACTIONS(575), 1,
      sym__uppercase_identifier,
    ACTIONS(577), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3259), 1,
      sym__lowercase_identifier,
    STATE(3337), 1,
      sym_parenthesized_operator,
    STATE(3434), 1,
      sym__constructor_name,
    STATE(3583), 1,
      sym__value_name,
    STATE(3604), 1,
      sym__simple_expression,
    STATE(4233), 1,
      sym_attribute,
    STATE(18905), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(535), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3432), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3704), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [118930] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8496), 1,
      sym__lowercase_identifier,
    ACTIONS(8498), 1,
      anon_sym_LPAREN,
    ACTIONS(8502), 1,
      anon_sym_LBRACE,
    ACTIONS(8504), 1,
      anon_sym_begin,
    ACTIONS(8506), 1,
      aux_sym_number_token1,
    ACTIONS(8508), 1,
      anon_sym_SQUOTE,
    ACTIONS(8510), 1,
      anon_sym_DQUOTE,
    ACTIONS(8512), 1,
      sym_prefix_operator,
    STATE(4234), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7440), 1,
      sym__simple_expression,
    STATE(7460), 1,
      sym__value_name,
    STATE(20132), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8500), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7550), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [119048] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2469), 1,
      anon_sym_LPAREN,
    ACTIONS(2471), 1,
      anon_sym_LBRACK,
    ACTIONS(2475), 1,
      anon_sym_LBRACE,
    ACTIONS(2477), 1,
      anon_sym_object,
    ACTIONS(2481), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2491), 1,
      anon_sym_new,
    ACTIONS(2493), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2495), 1,
      anon_sym_begin,
    ACTIONS(2497), 1,
      sym_ocamlyacc_value,
    ACTIONS(2499), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2501), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2503), 1,
      aux_sym_number_token1,
    ACTIONS(2505), 1,
      anon_sym_SQUOTE,
    ACTIONS(2507), 1,
      anon_sym_DQUOTE,
    ACTIONS(2509), 1,
      sym_prefix_operator,
    ACTIONS(2513), 1,
      sym__uppercase_identifier,
    ACTIONS(2515), 1,
      aux_sym_tag_token1,
    ACTIONS(5381), 1,
      sym__lowercase_identifier,
    STATE(4235), 1,
      sym_attribute,
    STATE(6224), 1,
      sym__value_name,
    STATE(6391), 1,
      sym__simple_expression,
    STATE(6398), 1,
      sym_parenthesized_operator,
    STATE(6510), 1,
      sym__constructor_name,
    STATE(18680), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2473), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6519), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6258), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [119166] = 29,
    ACTIONS(41), 1,
      anon_sym_LPAREN,
    ACTIONS(47), 1,
      anon_sym_LBRACK,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    ACTIONS(67), 1,
      anon_sym_object,
    ACTIONS(71), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(89), 1,
      anon_sym_new,
    ACTIONS(91), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(93), 1,
      anon_sym_begin,
    ACTIONS(95), 1,
      sym_ocamlyacc_value,
    ACTIONS(101), 1,
      aux_sym_number_token1,
    ACTIONS(105), 1,
      anon_sym_SQUOTE,
    ACTIONS(107), 1,
      anon_sym_DQUOTE,
    ACTIONS(109), 1,
      sym_prefix_operator,
    ACTIONS(117), 1,
      sym__uppercase_identifier,
    ACTIONS(121), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3067), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3069), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4145), 1,
      sym__lowercase_identifier,
    STATE(4236), 1,
      sym_attribute,
    STATE(4257), 1,
      sym__constructor_name,
    STATE(4302), 1,
      sym_parenthesized_operator,
    STATE(4427), 1,
      sym__simple_expression,
    STATE(4454), 1,
      sym__value_name,
    STATE(20480), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(51), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4466), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4315), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [119284] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5581), 1,
      sym__lowercase_identifier,
    ACTIONS(5589), 1,
      anon_sym_LPAREN,
    ACTIONS(5591), 1,
      anon_sym_LBRACK,
    ACTIONS(5595), 1,
      anon_sym_LBRACE,
    ACTIONS(5597), 1,
      anon_sym_object,
    ACTIONS(5599), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5601), 1,
      anon_sym_new,
    ACTIONS(5603), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(5605), 1,
      anon_sym_begin,
    ACTIONS(5607), 1,
      sym_ocamlyacc_value,
    ACTIONS(5613), 1,
      aux_sym_number_token1,
    ACTIONS(5615), 1,
      anon_sym_SQUOTE,
    ACTIONS(5617), 1,
      anon_sym_DQUOTE,
    ACTIONS(5619), 1,
      sym_prefix_operator,
    ACTIONS(5621), 1,
      sym__uppercase_identifier,
    ACTIONS(5623), 1,
      aux_sym_tag_token1,
    ACTIONS(8638), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8640), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4237), 1,
      sym_attribute,
    STATE(5879), 1,
      sym__simple_expression,
    STATE(5955), 1,
      sym__value_name,
    STATE(6068), 1,
      sym_parenthesized_operator,
    STATE(6088), 1,
      sym__constructor_name,
    STATE(18110), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5593), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6094), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5961), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [119402] = 29,
    ACTIONS(303), 1,
      anon_sym_LPAREN,
    ACTIONS(305), 1,
      anon_sym_LBRACK,
    ACTIONS(309), 1,
      anon_sym_LBRACE,
    ACTIONS(311), 1,
      anon_sym_object,
    ACTIONS(315), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(325), 1,
      anon_sym_new,
    ACTIONS(327), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(329), 1,
      anon_sym_begin,
    ACTIONS(331), 1,
      sym_ocamlyacc_value,
    ACTIONS(339), 1,
      aux_sym_number_token1,
    ACTIONS(341), 1,
      anon_sym_SQUOTE,
    ACTIONS(343), 1,
      anon_sym_DQUOTE,
    ACTIONS(345), 1,
      sym_prefix_operator,
    ACTIONS(351), 1,
      sym__uppercase_identifier,
    ACTIONS(353), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3049), 1,
      sym__lowercase_identifier,
    ACTIONS(3119), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3121), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2972), 1,
      sym__value_name,
    STATE(3047), 1,
      sym__simple_expression,
    STATE(3089), 1,
      sym_parenthesized_operator,
    STATE(3189), 1,
      sym__constructor_name,
    STATE(4238), 1,
      sym_attribute,
    STATE(18756), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(307), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3188), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3052), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [119520] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4239), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [119590] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1545), 1,
      anon_sym_LPAREN,
    ACTIONS(1547), 1,
      anon_sym_LBRACK,
    ACTIONS(1551), 1,
      anon_sym_LBRACE,
    ACTIONS(1553), 1,
      anon_sym_object,
    ACTIONS(1557), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1567), 1,
      anon_sym_new,
    ACTIONS(1569), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1571), 1,
      anon_sym_begin,
    ACTIONS(1573), 1,
      sym_ocamlyacc_value,
    ACTIONS(1575), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1577), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1579), 1,
      aux_sym_number_token1,
    ACTIONS(1581), 1,
      anon_sym_SQUOTE,
    ACTIONS(1583), 1,
      anon_sym_DQUOTE,
    ACTIONS(1585), 1,
      sym_prefix_operator,
    ACTIONS(1589), 1,
      sym__uppercase_identifier,
    ACTIONS(1591), 1,
      aux_sym_tag_token1,
    ACTIONS(5361), 1,
      sym__lowercase_identifier,
    STATE(4240), 1,
      sym_attribute,
    STATE(6487), 1,
      sym__value_name,
    STATE(6566), 1,
      sym__simple_expression,
    STATE(6631), 1,
      sym__constructor_name,
    STATE(6655), 1,
      sym_parenthesized_operator,
    STATE(17732), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1549), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6629), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6303), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [119708] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4241), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [119778] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1175), 1,
      anon_sym_LPAREN,
    ACTIONS(1177), 1,
      anon_sym_LBRACK,
    ACTIONS(1181), 1,
      anon_sym_LBRACE,
    ACTIONS(1183), 1,
      anon_sym_object,
    ACTIONS(1187), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1197), 1,
      anon_sym_new,
    ACTIONS(1199), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1201), 1,
      anon_sym_begin,
    ACTIONS(1203), 1,
      sym_ocamlyacc_value,
    ACTIONS(1205), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1207), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1209), 1,
      aux_sym_number_token1,
    ACTIONS(1211), 1,
      anon_sym_SQUOTE,
    ACTIONS(1213), 1,
      anon_sym_DQUOTE,
    ACTIONS(1215), 1,
      sym_prefix_operator,
    ACTIONS(1219), 1,
      sym__uppercase_identifier,
    ACTIONS(1221), 1,
      aux_sym_tag_token1,
    ACTIONS(4685), 1,
      sym__lowercase_identifier,
    STATE(4242), 1,
      sym_attribute,
    STATE(5357), 1,
      sym__constructor_name,
    STATE(5382), 1,
      sym__value_name,
    STATE(5383), 1,
      sym__simple_expression,
    STATE(5392), 1,
      sym_parenthesized_operator,
    STATE(18056), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1179), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5334), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5411), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [119896] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8496), 1,
      sym__lowercase_identifier,
    ACTIONS(8498), 1,
      anon_sym_LPAREN,
    ACTIONS(8502), 1,
      anon_sym_LBRACE,
    ACTIONS(8504), 1,
      anon_sym_begin,
    ACTIONS(8506), 1,
      aux_sym_number_token1,
    ACTIONS(8508), 1,
      anon_sym_SQUOTE,
    ACTIONS(8510), 1,
      anon_sym_DQUOTE,
    ACTIONS(8512), 1,
      sym_prefix_operator,
    STATE(4243), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(7588), 1,
      sym__simple_expression,
    STATE(20132), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8500), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7550), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [120014] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2417), 1,
      anon_sym_LPAREN,
    ACTIONS(2419), 1,
      anon_sym_LBRACK,
    ACTIONS(2423), 1,
      anon_sym_LBRACE,
    ACTIONS(2425), 1,
      anon_sym_object,
    ACTIONS(2429), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2439), 1,
      anon_sym_new,
    ACTIONS(2441), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2443), 1,
      anon_sym_begin,
    ACTIONS(2445), 1,
      sym_ocamlyacc_value,
    ACTIONS(2447), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2449), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2451), 1,
      aux_sym_number_token1,
    ACTIONS(2453), 1,
      anon_sym_SQUOTE,
    ACTIONS(2455), 1,
      anon_sym_DQUOTE,
    ACTIONS(2457), 1,
      sym_prefix_operator,
    ACTIONS(2461), 1,
      sym__uppercase_identifier,
    ACTIONS(2463), 1,
      aux_sym_tag_token1,
    ACTIONS(5393), 1,
      sym__lowercase_identifier,
    STATE(4244), 1,
      sym_attribute,
    STATE(6262), 1,
      sym__value_name,
    STATE(6367), 1,
      sym__constructor_name,
    STATE(6508), 1,
      sym__simple_expression,
    STATE(6621), 1,
      sym_parenthesized_operator,
    STATE(18284), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2421), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6373), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6162), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [120132] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4245), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [120202] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4246), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [120272] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4247), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8622), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [120342] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [120412] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3959), 1,
      anon_sym_DOT,
    STATE(4249), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [120484] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4250), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [120554] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4251), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [120624] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4252), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8226), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [120694] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8456), 1,
      sym__lowercase_identifier,
    ACTIONS(8458), 1,
      anon_sym_LPAREN,
    ACTIONS(8460), 1,
      anon_sym_LBRACK,
    ACTIONS(8464), 1,
      anon_sym_LBRACE,
    ACTIONS(8466), 1,
      anon_sym_object,
    ACTIONS(8468), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8470), 1,
      anon_sym_new,
    ACTIONS(8472), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8474), 1,
      anon_sym_begin,
    ACTIONS(8476), 1,
      sym_ocamlyacc_value,
    ACTIONS(8484), 1,
      aux_sym_number_token1,
    ACTIONS(8486), 1,
      anon_sym_SQUOTE,
    ACTIONS(8488), 1,
      anon_sym_DQUOTE,
    ACTIONS(8492), 1,
      sym__uppercase_identifier,
    ACTIONS(8494), 1,
      aux_sym_tag_token1,
    ACTIONS(8596), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8598), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8600), 1,
      sym_prefix_operator,
    STATE(4253), 1,
      sym_attribute,
    STATE(7316), 1,
      sym__simple_expression,
    STATE(7320), 1,
      sym__value_name,
    STATE(7412), 1,
      sym_parenthesized_operator,
    STATE(7454), 1,
      sym__constructor_name,
    STATE(18504), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8462), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7383), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7348), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [120812] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4254), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [120882] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4255), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [120952] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8478), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8480), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8514), 1,
      sym__lowercase_identifier,
    ACTIONS(8516), 1,
      anon_sym_LPAREN,
    ACTIONS(8518), 1,
      anon_sym_LBRACK,
    ACTIONS(8522), 1,
      anon_sym_LBRACE,
    ACTIONS(8524), 1,
      anon_sym_object,
    ACTIONS(8526), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8528), 1,
      anon_sym_new,
    ACTIONS(8530), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8532), 1,
      anon_sym_begin,
    ACTIONS(8534), 1,
      sym_ocamlyacc_value,
    ACTIONS(8536), 1,
      aux_sym_number_token1,
    ACTIONS(8538), 1,
      anon_sym_SQUOTE,
    ACTIONS(8540), 1,
      anon_sym_DQUOTE,
    ACTIONS(8542), 1,
      sym_prefix_operator,
    ACTIONS(8544), 1,
      sym__uppercase_identifier,
    ACTIONS(8546), 1,
      aux_sym_tag_token1,
    STATE(4256), 1,
      sym_attribute,
    STATE(7480), 1,
      sym__constructor_name,
    STATE(7580), 1,
      sym_parenthesized_operator,
    STATE(7659), 1,
      sym__value_name,
    STATE(7718), 1,
      sym__simple_expression,
    STATE(18524), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8520), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7525), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7725), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [121070] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [121140] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4258), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [121210] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4259), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [121280] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4260), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [121350] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [121420] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1175), 1,
      anon_sym_LPAREN,
    ACTIONS(1177), 1,
      anon_sym_LBRACK,
    ACTIONS(1181), 1,
      anon_sym_LBRACE,
    ACTIONS(1183), 1,
      anon_sym_object,
    ACTIONS(1187), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1197), 1,
      anon_sym_new,
    ACTIONS(1199), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1201), 1,
      anon_sym_begin,
    ACTIONS(1203), 1,
      sym_ocamlyacc_value,
    ACTIONS(1205), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1207), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1209), 1,
      aux_sym_number_token1,
    ACTIONS(1211), 1,
      anon_sym_SQUOTE,
    ACTIONS(1213), 1,
      anon_sym_DQUOTE,
    ACTIONS(1215), 1,
      sym_prefix_operator,
    ACTIONS(1219), 1,
      sym__uppercase_identifier,
    ACTIONS(1221), 1,
      aux_sym_tag_token1,
    ACTIONS(4685), 1,
      sym__lowercase_identifier,
    STATE(4262), 1,
      sym_attribute,
    STATE(5349), 1,
      sym__simple_expression,
    STATE(5357), 1,
      sym__constructor_name,
    STATE(5382), 1,
      sym__value_name,
    STATE(5392), 1,
      sym_parenthesized_operator,
    STATE(18056), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1179), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5334), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5411), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [121538] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [121608] = 29,
    ACTIONS(693), 1,
      anon_sym_LPAREN,
    ACTIONS(695), 1,
      anon_sym_LBRACK,
    ACTIONS(699), 1,
      anon_sym_LBRACE,
    ACTIONS(701), 1,
      anon_sym_object,
    ACTIONS(705), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(715), 1,
      anon_sym_new,
    ACTIONS(717), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(719), 1,
      anon_sym_begin,
    ACTIONS(721), 1,
      sym_ocamlyacc_value,
    ACTIONS(727), 1,
      aux_sym_number_token1,
    ACTIONS(729), 1,
      anon_sym_SQUOTE,
    ACTIONS(731), 1,
      anon_sym_DQUOTE,
    ACTIONS(733), 1,
      sym_prefix_operator,
    ACTIONS(737), 1,
      sym__uppercase_identifier,
    ACTIONS(739), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3091), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3093), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3281), 1,
      sym__lowercase_identifier,
    STATE(3822), 1,
      sym_parenthesized_operator,
    STATE(3855), 1,
      sym__simple_expression,
    STATE(3881), 1,
      sym__constructor_name,
    STATE(3913), 1,
      sym__value_name,
    STATE(4264), 1,
      sym_attribute,
    STATE(18364), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(697), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3886), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3957), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [121726] = 29,
    ACTIONS(861), 1,
      anon_sym_LPAREN,
    ACTIONS(863), 1,
      anon_sym_LBRACK,
    ACTIONS(867), 1,
      anon_sym_LBRACE,
    ACTIONS(869), 1,
      anon_sym_object,
    ACTIONS(873), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(883), 1,
      anon_sym_new,
    ACTIONS(885), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(887), 1,
      anon_sym_begin,
    ACTIONS(889), 1,
      sym_ocamlyacc_value,
    ACTIONS(895), 1,
      aux_sym_number_token1,
    ACTIONS(897), 1,
      anon_sym_SQUOTE,
    ACTIONS(899), 1,
      anon_sym_DQUOTE,
    ACTIONS(901), 1,
      sym_prefix_operator,
    ACTIONS(905), 1,
      sym__uppercase_identifier,
    ACTIONS(907), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3103), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3105), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3445), 1,
      sym__lowercase_identifier,
    STATE(4007), 1,
      sym__simple_expression,
    STATE(4054), 1,
      sym__constructor_name,
    STATE(4104), 1,
      sym__value_name,
    STATE(4160), 1,
      sym_parenthesized_operator,
    STATE(4265), 1,
      sym_attribute,
    STATE(17631), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(865), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4047), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4041), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [121844] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1341), 1,
      anon_sym_LPAREN,
    ACTIONS(1343), 1,
      anon_sym_LBRACK,
    ACTIONS(1347), 1,
      anon_sym_LBRACE,
    ACTIONS(1349), 1,
      anon_sym_object,
    ACTIONS(1353), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1363), 1,
      anon_sym_new,
    ACTIONS(1365), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1367), 1,
      anon_sym_begin,
    ACTIONS(1369), 1,
      sym_ocamlyacc_value,
    ACTIONS(1371), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1373), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1375), 1,
      aux_sym_number_token1,
    ACTIONS(1377), 1,
      anon_sym_SQUOTE,
    ACTIONS(1379), 1,
      anon_sym_DQUOTE,
    ACTIONS(1381), 1,
      sym_prefix_operator,
    ACTIONS(1385), 1,
      sym__uppercase_identifier,
    ACTIONS(1387), 1,
      aux_sym_tag_token1,
    ACTIONS(5055), 1,
      sym__lowercase_identifier,
    STATE(4266), 1,
      sym_attribute,
    STATE(5784), 1,
      sym__simple_expression,
    STATE(5786), 1,
      sym_parenthesized_operator,
    STATE(5832), 1,
      sym__value_name,
    STATE(5844), 1,
      sym__constructor_name,
    STATE(17948), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1345), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5842), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5778), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [121962] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [122032] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1341), 1,
      anon_sym_LPAREN,
    ACTIONS(1343), 1,
      anon_sym_LBRACK,
    ACTIONS(1347), 1,
      anon_sym_LBRACE,
    ACTIONS(1349), 1,
      anon_sym_object,
    ACTIONS(1353), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1363), 1,
      anon_sym_new,
    ACTIONS(1365), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1367), 1,
      anon_sym_begin,
    ACTIONS(1369), 1,
      sym_ocamlyacc_value,
    ACTIONS(1371), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1373), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1375), 1,
      aux_sym_number_token1,
    ACTIONS(1377), 1,
      anon_sym_SQUOTE,
    ACTIONS(1379), 1,
      anon_sym_DQUOTE,
    ACTIONS(1381), 1,
      sym_prefix_operator,
    ACTIONS(1385), 1,
      sym__uppercase_identifier,
    ACTIONS(1387), 1,
      aux_sym_tag_token1,
    ACTIONS(5055), 1,
      sym__lowercase_identifier,
    STATE(4268), 1,
      sym_attribute,
    STATE(5786), 1,
      sym_parenthesized_operator,
    STATE(5798), 1,
      sym__simple_expression,
    STATE(5832), 1,
      sym__value_name,
    STATE(5844), 1,
      sym__constructor_name,
    STATE(17948), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1345), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5842), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5778), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [122150] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4269), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [122220] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [122290] = 29,
    ACTIONS(693), 1,
      anon_sym_LPAREN,
    ACTIONS(695), 1,
      anon_sym_LBRACK,
    ACTIONS(699), 1,
      anon_sym_LBRACE,
    ACTIONS(701), 1,
      anon_sym_object,
    ACTIONS(705), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(715), 1,
      anon_sym_new,
    ACTIONS(717), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(719), 1,
      anon_sym_begin,
    ACTIONS(721), 1,
      sym_ocamlyacc_value,
    ACTIONS(727), 1,
      aux_sym_number_token1,
    ACTIONS(729), 1,
      anon_sym_SQUOTE,
    ACTIONS(731), 1,
      anon_sym_DQUOTE,
    ACTIONS(733), 1,
      sym_prefix_operator,
    ACTIONS(737), 1,
      sym__uppercase_identifier,
    ACTIONS(739), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3091), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3093), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3281), 1,
      sym__lowercase_identifier,
    STATE(3822), 1,
      sym_parenthesized_operator,
    STATE(3878), 1,
      sym__simple_expression,
    STATE(3881), 1,
      sym__constructor_name,
    STATE(3913), 1,
      sym__value_name,
    STATE(4271), 1,
      sym_attribute,
    STATE(18364), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(697), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3886), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3957), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [122408] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1175), 1,
      anon_sym_LPAREN,
    ACTIONS(1177), 1,
      anon_sym_LBRACK,
    ACTIONS(1181), 1,
      anon_sym_LBRACE,
    ACTIONS(1183), 1,
      anon_sym_object,
    ACTIONS(1187), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1197), 1,
      anon_sym_new,
    ACTIONS(1199), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1201), 1,
      anon_sym_begin,
    ACTIONS(1203), 1,
      sym_ocamlyacc_value,
    ACTIONS(1205), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1207), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1209), 1,
      aux_sym_number_token1,
    ACTIONS(1211), 1,
      anon_sym_SQUOTE,
    ACTIONS(1213), 1,
      anon_sym_DQUOTE,
    ACTIONS(1215), 1,
      sym_prefix_operator,
    ACTIONS(1219), 1,
      sym__uppercase_identifier,
    ACTIONS(1221), 1,
      aux_sym_tag_token1,
    ACTIONS(4685), 1,
      sym__lowercase_identifier,
    STATE(4272), 1,
      sym_attribute,
    STATE(5357), 1,
      sym__constructor_name,
    STATE(5359), 1,
      sym__simple_expression,
    STATE(5382), 1,
      sym__value_name,
    STATE(5392), 1,
      sym_parenthesized_operator,
    STATE(18056), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1179), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5334), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5411), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [122526] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1281), 1,
      anon_sym_LPAREN,
    ACTIONS(1283), 1,
      anon_sym_LBRACK,
    ACTIONS(1287), 1,
      anon_sym_LBRACE,
    ACTIONS(1289), 1,
      anon_sym_object,
    ACTIONS(1293), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1311), 1,
      anon_sym_new,
    ACTIONS(1313), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1315), 1,
      anon_sym_begin,
    ACTIONS(1317), 1,
      sym_ocamlyacc_value,
    ACTIONS(1319), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1321), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1323), 1,
      aux_sym_number_token1,
    ACTIONS(1325), 1,
      anon_sym_SQUOTE,
    ACTIONS(1327), 1,
      anon_sym_DQUOTE,
    ACTIONS(1329), 1,
      sym_prefix_operator,
    ACTIONS(1333), 1,
      sym__uppercase_identifier,
    ACTIONS(1335), 1,
      aux_sym_tag_token1,
    ACTIONS(4815), 1,
      sym__lowercase_identifier,
    STATE(4273), 1,
      sym_attribute,
    STATE(5616), 1,
      sym__constructor_name,
    STATE(5669), 1,
      sym__value_name,
    STATE(5713), 1,
      sym_parenthesized_operator,
    STATE(5736), 1,
      sym__simple_expression,
    STATE(18794), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1285), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5617), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5700), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [122644] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [122714] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4275), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [122784] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [122854] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4277), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [122924] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [122994] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4279), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [123064] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4280), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8226), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [123134] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4281), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [123204] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [123274] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2813), 1,
      anon_sym_LPAREN,
    ACTIONS(2815), 1,
      anon_sym_LBRACK,
    ACTIONS(2819), 1,
      anon_sym_LBRACE,
    ACTIONS(2821), 1,
      anon_sym_object,
    ACTIONS(2825), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2835), 1,
      anon_sym_new,
    ACTIONS(2837), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2839), 1,
      anon_sym_begin,
    ACTIONS(2841), 1,
      sym_ocamlyacc_value,
    ACTIONS(2843), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2845), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2847), 1,
      aux_sym_number_token1,
    ACTIONS(2849), 1,
      anon_sym_SQUOTE,
    ACTIONS(2851), 1,
      anon_sym_DQUOTE,
    ACTIONS(2853), 1,
      sym_prefix_operator,
    ACTIONS(2857), 1,
      sym__uppercase_identifier,
    ACTIONS(2859), 1,
      aux_sym_tag_token1,
    ACTIONS(5519), 1,
      sym__lowercase_identifier,
    STATE(4283), 1,
      sym_attribute,
    STATE(6939), 1,
      sym__constructor_name,
    STATE(7131), 1,
      sym__value_name,
    STATE(7184), 1,
      sym__simple_expression,
    STATE(7200), 1,
      sym_parenthesized_operator,
    STATE(19879), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2817), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7136), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7128), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [123392] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4284), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [123462] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4285), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [123532] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [123602] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [123672] = 29,
    ACTIONS(809), 1,
      anon_sym_LPAREN,
    ACTIONS(811), 1,
      anon_sym_LBRACK,
    ACTIONS(815), 1,
      anon_sym_LBRACE,
    ACTIONS(817), 1,
      anon_sym_object,
    ACTIONS(821), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(831), 1,
      anon_sym_new,
    ACTIONS(833), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(835), 1,
      anon_sym_begin,
    ACTIONS(837), 1,
      sym_ocamlyacc_value,
    ACTIONS(843), 1,
      aux_sym_number_token1,
    ACTIONS(845), 1,
      anon_sym_SQUOTE,
    ACTIONS(847), 1,
      anon_sym_DQUOTE,
    ACTIONS(849), 1,
      sym_prefix_operator,
    ACTIONS(853), 1,
      sym__uppercase_identifier,
    ACTIONS(855), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3115), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3117), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3327), 1,
      sym__lowercase_identifier,
    STATE(3972), 1,
      sym_parenthesized_operator,
    STATE(3979), 1,
      sym__constructor_name,
    STATE(4077), 1,
      sym__simple_expression,
    STATE(4164), 1,
      sym__value_name,
    STATE(4288), 1,
      sym_attribute,
    STATE(17840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(813), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3977), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4161), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [123790] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2695), 1,
      anon_sym_LPAREN,
    ACTIONS(2697), 1,
      anon_sym_LBRACK,
    ACTIONS(2701), 1,
      anon_sym_LBRACE,
    ACTIONS(2703), 1,
      anon_sym_object,
    ACTIONS(2707), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2717), 1,
      anon_sym_new,
    ACTIONS(2719), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2721), 1,
      anon_sym_begin,
    ACTIONS(2723), 1,
      sym_ocamlyacc_value,
    ACTIONS(2725), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2727), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2729), 1,
      aux_sym_number_token1,
    ACTIONS(2731), 1,
      anon_sym_SQUOTE,
    ACTIONS(2733), 1,
      anon_sym_DQUOTE,
    ACTIONS(2735), 1,
      sym_prefix_operator,
    ACTIONS(2739), 1,
      sym__uppercase_identifier,
    ACTIONS(2741), 1,
      aux_sym_tag_token1,
    ACTIONS(5561), 1,
      sym__lowercase_identifier,
    STATE(4289), 1,
      sym_attribute,
    STATE(6885), 1,
      sym__constructor_name,
    STATE(7081), 1,
      sym__value_name,
    STATE(7147), 1,
      sym_parenthesized_operator,
    STATE(7185), 1,
      sym__simple_expression,
    STATE(19042), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2699), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6871), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7067), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [123908] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2357), 1,
      anon_sym_LPAREN,
    ACTIONS(2359), 1,
      anon_sym_LBRACK,
    ACTIONS(2363), 1,
      anon_sym_LBRACE,
    ACTIONS(2365), 1,
      anon_sym_object,
    ACTIONS(2369), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2379), 1,
      anon_sym_new,
    ACTIONS(2381), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2383), 1,
      anon_sym_begin,
    ACTIONS(2385), 1,
      sym_ocamlyacc_value,
    ACTIONS(2387), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2389), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2391), 1,
      aux_sym_number_token1,
    ACTIONS(2393), 1,
      anon_sym_SQUOTE,
    ACTIONS(2395), 1,
      anon_sym_DQUOTE,
    ACTIONS(2397), 1,
      sym_prefix_operator,
    ACTIONS(2401), 1,
      sym__uppercase_identifier,
    ACTIONS(2403), 1,
      aux_sym_tag_token1,
    ACTIONS(5351), 1,
      sym__lowercase_identifier,
    STATE(4290), 1,
      sym_attribute,
    STATE(6169), 1,
      sym__value_name,
    STATE(6315), 1,
      sym__simple_expression,
    STATE(6529), 1,
      sym_parenthesized_operator,
    STATE(6547), 1,
      sym__constructor_name,
    STATE(18204), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2361), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6548), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6357), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [124026] = 29,
    ACTIONS(809), 1,
      anon_sym_LPAREN,
    ACTIONS(811), 1,
      anon_sym_LBRACK,
    ACTIONS(815), 1,
      anon_sym_LBRACE,
    ACTIONS(817), 1,
      anon_sym_object,
    ACTIONS(821), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(831), 1,
      anon_sym_new,
    ACTIONS(833), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(835), 1,
      anon_sym_begin,
    ACTIONS(837), 1,
      sym_ocamlyacc_value,
    ACTIONS(843), 1,
      aux_sym_number_token1,
    ACTIONS(845), 1,
      anon_sym_SQUOTE,
    ACTIONS(847), 1,
      anon_sym_DQUOTE,
    ACTIONS(849), 1,
      sym_prefix_operator,
    ACTIONS(853), 1,
      sym__uppercase_identifier,
    ACTIONS(855), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3115), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3117), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3327), 1,
      sym__lowercase_identifier,
    STATE(3972), 1,
      sym_parenthesized_operator,
    STATE(3979), 1,
      sym__constructor_name,
    STATE(4015), 1,
      sym__simple_expression,
    STATE(4164), 1,
      sym__value_name,
    STATE(4291), 1,
      sym_attribute,
    STATE(17840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(813), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3977), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4161), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [124144] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4292), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5275), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [124262] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8456), 1,
      sym__lowercase_identifier,
    ACTIONS(8458), 1,
      anon_sym_LPAREN,
    ACTIONS(8460), 1,
      anon_sym_LBRACK,
    ACTIONS(8464), 1,
      anon_sym_LBRACE,
    ACTIONS(8466), 1,
      anon_sym_object,
    ACTIONS(8468), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8470), 1,
      anon_sym_new,
    ACTIONS(8472), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8474), 1,
      anon_sym_begin,
    ACTIONS(8476), 1,
      sym_ocamlyacc_value,
    ACTIONS(8484), 1,
      aux_sym_number_token1,
    ACTIONS(8486), 1,
      anon_sym_SQUOTE,
    ACTIONS(8488), 1,
      anon_sym_DQUOTE,
    ACTIONS(8492), 1,
      sym__uppercase_identifier,
    ACTIONS(8494), 1,
      aux_sym_tag_token1,
    ACTIONS(8596), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8598), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8600), 1,
      sym_prefix_operator,
    STATE(4293), 1,
      sym_attribute,
    STATE(7320), 1,
      sym__value_name,
    STATE(7412), 1,
      sym_parenthesized_operator,
    STATE(7454), 1,
      sym__constructor_name,
    STATE(8875), 1,
      sym__simple_expression,
    STATE(18504), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8462), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7383), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7348), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [124380] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [124450] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [124520] = 29,
    ACTIONS(809), 1,
      anon_sym_LPAREN,
    ACTIONS(811), 1,
      anon_sym_LBRACK,
    ACTIONS(815), 1,
      anon_sym_LBRACE,
    ACTIONS(817), 1,
      anon_sym_object,
    ACTIONS(821), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(831), 1,
      anon_sym_new,
    ACTIONS(833), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(835), 1,
      anon_sym_begin,
    ACTIONS(837), 1,
      sym_ocamlyacc_value,
    ACTIONS(843), 1,
      aux_sym_number_token1,
    ACTIONS(845), 1,
      anon_sym_SQUOTE,
    ACTIONS(847), 1,
      anon_sym_DQUOTE,
    ACTIONS(849), 1,
      sym_prefix_operator,
    ACTIONS(853), 1,
      sym__uppercase_identifier,
    ACTIONS(855), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3115), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3117), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3327), 1,
      sym__lowercase_identifier,
    STATE(3972), 1,
      sym_parenthesized_operator,
    STATE(3979), 1,
      sym__constructor_name,
    STATE(4115), 1,
      sym__simple_expression,
    STATE(4164), 1,
      sym__value_name,
    STATE(4296), 1,
      sym_attribute,
    STATE(17840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(813), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3977), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4161), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [124638] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [124708] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2357), 1,
      anon_sym_LPAREN,
    ACTIONS(2359), 1,
      anon_sym_LBRACK,
    ACTIONS(2363), 1,
      anon_sym_LBRACE,
    ACTIONS(2365), 1,
      anon_sym_object,
    ACTIONS(2369), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2379), 1,
      anon_sym_new,
    ACTIONS(2381), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2383), 1,
      anon_sym_begin,
    ACTIONS(2385), 1,
      sym_ocamlyacc_value,
    ACTIONS(2387), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2389), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2391), 1,
      aux_sym_number_token1,
    ACTIONS(2393), 1,
      anon_sym_SQUOTE,
    ACTIONS(2395), 1,
      anon_sym_DQUOTE,
    ACTIONS(2397), 1,
      sym_prefix_operator,
    ACTIONS(2401), 1,
      sym__uppercase_identifier,
    ACTIONS(2403), 1,
      aux_sym_tag_token1,
    ACTIONS(5351), 1,
      sym__lowercase_identifier,
    STATE(4298), 1,
      sym_attribute,
    STATE(6169), 1,
      sym__value_name,
    STATE(6253), 1,
      sym__simple_expression,
    STATE(6529), 1,
      sym_parenthesized_operator,
    STATE(6547), 1,
      sym__constructor_name,
    STATE(18204), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2361), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6548), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6357), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [124826] = 29,
    ACTIONS(479), 1,
      anon_sym_LPAREN,
    ACTIONS(481), 1,
      anon_sym_LBRACK,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(487), 1,
      anon_sym_object,
    ACTIONS(491), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(501), 1,
      anon_sym_new,
    ACTIONS(503), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(505), 1,
      anon_sym_begin,
    ACTIONS(507), 1,
      sym_ocamlyacc_value,
    ACTIONS(513), 1,
      aux_sym_number_token1,
    ACTIONS(515), 1,
      anon_sym_SQUOTE,
    ACTIONS(517), 1,
      anon_sym_DQUOTE,
    ACTIONS(519), 1,
      sym_prefix_operator,
    ACTIONS(523), 1,
      sym__uppercase_identifier,
    ACTIONS(525), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3123), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3125), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3157), 1,
      sym__lowercase_identifier,
    STATE(3349), 1,
      sym_parenthesized_operator,
    STATE(3406), 1,
      sym__constructor_name,
    STATE(3691), 1,
      sym__value_name,
    STATE(3745), 1,
      sym__simple_expression,
    STATE(4299), 1,
      sym_attribute,
    STATE(18868), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(483), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3400), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3532), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [124944] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8642), 1,
      anon_sym_COLON,
    STATE(4300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8548), 33,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [125016] = 29,
    ACTIONS(583), 1,
      anon_sym_LPAREN,
    ACTIONS(585), 1,
      anon_sym_LBRACK,
    ACTIONS(589), 1,
      anon_sym_LBRACE,
    ACTIONS(591), 1,
      anon_sym_object,
    ACTIONS(595), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(605), 1,
      anon_sym_new,
    ACTIONS(607), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(609), 1,
      anon_sym_begin,
    ACTIONS(611), 1,
      sym_ocamlyacc_value,
    ACTIONS(617), 1,
      aux_sym_number_token1,
    ACTIONS(619), 1,
      anon_sym_SQUOTE,
    ACTIONS(621), 1,
      anon_sym_DQUOTE,
    ACTIONS(623), 1,
      sym_prefix_operator,
    ACTIONS(627), 1,
      sym__uppercase_identifier,
    ACTIONS(629), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3099), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3101), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3237), 1,
      sym__lowercase_identifier,
    STATE(3340), 1,
      sym__value_name,
    STATE(3341), 1,
      sym__simple_expression,
    STATE(3473), 1,
      sym__constructor_name,
    STATE(3728), 1,
      sym_parenthesized_operator,
    STATE(4301), 1,
      sym_attribute,
    STATE(17910), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(587), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3472), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3461), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [125134] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [125204] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [125274] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4304), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [125344] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4305), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [125414] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2747), 1,
      anon_sym_LPAREN,
    ACTIONS(2749), 1,
      anon_sym_LBRACK,
    ACTIONS(2753), 1,
      anon_sym_LBRACE,
    ACTIONS(2755), 1,
      anon_sym_object,
    ACTIONS(2759), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2769), 1,
      anon_sym_new,
    ACTIONS(2771), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2773), 1,
      anon_sym_begin,
    ACTIONS(2775), 1,
      sym_ocamlyacc_value,
    ACTIONS(2777), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2779), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2781), 1,
      aux_sym_number_token1,
    ACTIONS(2783), 1,
      anon_sym_SQUOTE,
    ACTIONS(2785), 1,
      anon_sym_DQUOTE,
    ACTIONS(2787), 1,
      sym_prefix_operator,
    ACTIONS(2791), 1,
      sym__uppercase_identifier,
    ACTIONS(2793), 1,
      aux_sym_tag_token1,
    ACTIONS(5571), 1,
      sym__lowercase_identifier,
    STATE(4306), 1,
      sym_attribute,
    STATE(6870), 1,
      sym__constructor_name,
    STATE(7065), 1,
      sym_parenthesized_operator,
    STATE(7189), 1,
      sym__value_name,
    STATE(7266), 1,
      sym__simple_expression,
    STATE(19332), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2751), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6940), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7193), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [125532] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8496), 1,
      sym__lowercase_identifier,
    ACTIONS(8498), 1,
      anon_sym_LPAREN,
    ACTIONS(8502), 1,
      anon_sym_LBRACE,
    ACTIONS(8504), 1,
      anon_sym_begin,
    ACTIONS(8506), 1,
      aux_sym_number_token1,
    ACTIONS(8508), 1,
      anon_sym_SQUOTE,
    ACTIONS(8510), 1,
      anon_sym_DQUOTE,
    ACTIONS(8512), 1,
      sym_prefix_operator,
    STATE(4307), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(7596), 1,
      sym__simple_expression,
    STATE(20132), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8500), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7550), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [125650] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8478), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8480), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8514), 1,
      sym__lowercase_identifier,
    ACTIONS(8516), 1,
      anon_sym_LPAREN,
    ACTIONS(8518), 1,
      anon_sym_LBRACK,
    ACTIONS(8522), 1,
      anon_sym_LBRACE,
    ACTIONS(8524), 1,
      anon_sym_object,
    ACTIONS(8526), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8528), 1,
      anon_sym_new,
    ACTIONS(8530), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8532), 1,
      anon_sym_begin,
    ACTIONS(8534), 1,
      sym_ocamlyacc_value,
    ACTIONS(8536), 1,
      aux_sym_number_token1,
    ACTIONS(8538), 1,
      anon_sym_SQUOTE,
    ACTIONS(8540), 1,
      anon_sym_DQUOTE,
    ACTIONS(8542), 1,
      sym_prefix_operator,
    ACTIONS(8544), 1,
      sym__uppercase_identifier,
    ACTIONS(8546), 1,
      aux_sym_tag_token1,
    STATE(4308), 1,
      sym_attribute,
    STATE(7480), 1,
      sym__constructor_name,
    STATE(7552), 1,
      sym__simple_expression,
    STATE(7580), 1,
      sym_parenthesized_operator,
    STATE(7659), 1,
      sym__value_name,
    STATE(18524), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8520), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7525), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7725), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [125768] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4309), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [125838] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8478), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8480), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8514), 1,
      sym__lowercase_identifier,
    ACTIONS(8516), 1,
      anon_sym_LPAREN,
    ACTIONS(8518), 1,
      anon_sym_LBRACK,
    ACTIONS(8522), 1,
      anon_sym_LBRACE,
    ACTIONS(8524), 1,
      anon_sym_object,
    ACTIONS(8526), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8528), 1,
      anon_sym_new,
    ACTIONS(8530), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8532), 1,
      anon_sym_begin,
    ACTIONS(8534), 1,
      sym_ocamlyacc_value,
    ACTIONS(8536), 1,
      aux_sym_number_token1,
    ACTIONS(8538), 1,
      anon_sym_SQUOTE,
    ACTIONS(8540), 1,
      anon_sym_DQUOTE,
    ACTIONS(8542), 1,
      sym_prefix_operator,
    ACTIONS(8544), 1,
      sym__uppercase_identifier,
    ACTIONS(8546), 1,
      aux_sym_tag_token1,
    STATE(4310), 1,
      sym_attribute,
    STATE(7480), 1,
      sym__constructor_name,
    STATE(7551), 1,
      sym__simple_expression,
    STATE(7580), 1,
      sym_parenthesized_operator,
    STATE(7659), 1,
      sym__value_name,
    STATE(18524), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8520), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7525), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7725), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [125956] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8556), 1,
      sym__lowercase_identifier,
    ACTIONS(8558), 1,
      anon_sym_LPAREN,
    ACTIONS(8560), 1,
      anon_sym_LBRACK,
    ACTIONS(8564), 1,
      anon_sym_LBRACE,
    ACTIONS(8566), 1,
      anon_sym_object,
    ACTIONS(8568), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8570), 1,
      anon_sym_new,
    ACTIONS(8572), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8574), 1,
      anon_sym_begin,
    ACTIONS(8576), 1,
      sym_ocamlyacc_value,
    ACTIONS(8578), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8580), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8582), 1,
      aux_sym_number_token1,
    ACTIONS(8584), 1,
      anon_sym_SQUOTE,
    ACTIONS(8586), 1,
      anon_sym_DQUOTE,
    ACTIONS(8588), 1,
      sym_prefix_operator,
    ACTIONS(8590), 1,
      sym__uppercase_identifier,
    ACTIONS(8592), 1,
      aux_sym_tag_token1,
    STATE(4311), 1,
      sym_attribute,
    STATE(9576), 1,
      sym__value_name,
    STATE(9719), 1,
      sym__simple_expression,
    STATE(9739), 1,
      sym__constructor_name,
    STATE(9784), 1,
      sym_parenthesized_operator,
    STATE(18244), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8562), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9811), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9740), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [126074] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1119), 1,
      anon_sym_LPAREN,
    ACTIONS(1121), 1,
      anon_sym_LBRACK,
    ACTIONS(1125), 1,
      anon_sym_LBRACE,
    ACTIONS(1127), 1,
      anon_sym_object,
    ACTIONS(1131), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1145), 1,
      anon_sym_new,
    ACTIONS(1147), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1149), 1,
      anon_sym_begin,
    ACTIONS(1151), 1,
      sym_ocamlyacc_value,
    ACTIONS(1153), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1155), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1157), 1,
      aux_sym_number_token1,
    ACTIONS(1159), 1,
      anon_sym_SQUOTE,
    ACTIONS(1161), 1,
      anon_sym_DQUOTE,
    ACTIONS(1163), 1,
      sym_prefix_operator,
    ACTIONS(1167), 1,
      sym__uppercase_identifier,
    ACTIONS(1169), 1,
      aux_sym_tag_token1,
    ACTIONS(4595), 1,
      sym__lowercase_identifier,
    STATE(4312), 1,
      sym_attribute,
    STATE(5044), 1,
      sym_parenthesized_operator,
    STATE(5072), 1,
      sym__constructor_name,
    STATE(5076), 1,
      sym__simple_expression,
    STATE(5124), 1,
      sym__value_name,
    STATE(18002), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1123), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5096), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5003), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [126192] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [126262] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2521), 1,
      anon_sym_LPAREN,
    ACTIONS(2523), 1,
      anon_sym_LBRACK,
    ACTIONS(2527), 1,
      anon_sym_LBRACE,
    ACTIONS(2529), 1,
      anon_sym_object,
    ACTIONS(2533), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2543), 1,
      anon_sym_new,
    ACTIONS(2545), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2547), 1,
      anon_sym_begin,
    ACTIONS(2549), 1,
      sym_ocamlyacc_value,
    ACTIONS(2551), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2553), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2555), 1,
      aux_sym_number_token1,
    ACTIONS(2557), 1,
      anon_sym_SQUOTE,
    ACTIONS(2559), 1,
      anon_sym_DQUOTE,
    ACTIONS(2561), 1,
      sym_prefix_operator,
    ACTIONS(2565), 1,
      sym__uppercase_identifier,
    ACTIONS(2567), 1,
      aux_sym_tag_token1,
    ACTIONS(5341), 1,
      sym__lowercase_identifier,
    STATE(4314), 1,
      sym_attribute,
    STATE(6272), 1,
      sym__simple_expression,
    STATE(6354), 1,
      sym__value_name,
    STATE(6438), 1,
      sym__constructor_name,
    STATE(6647), 1,
      sym_parenthesized_operator,
    STATE(18324), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2525), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6449), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6255), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [126380] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4315), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [126450] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2521), 1,
      anon_sym_LPAREN,
    ACTIONS(2523), 1,
      anon_sym_LBRACK,
    ACTIONS(2527), 1,
      anon_sym_LBRACE,
    ACTIONS(2529), 1,
      anon_sym_object,
    ACTIONS(2533), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2543), 1,
      anon_sym_new,
    ACTIONS(2545), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2547), 1,
      anon_sym_begin,
    ACTIONS(2549), 1,
      sym_ocamlyacc_value,
    ACTIONS(2551), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2553), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2555), 1,
      aux_sym_number_token1,
    ACTIONS(2557), 1,
      anon_sym_SQUOTE,
    ACTIONS(2559), 1,
      anon_sym_DQUOTE,
    ACTIONS(2561), 1,
      sym_prefix_operator,
    ACTIONS(2565), 1,
      sym__uppercase_identifier,
    ACTIONS(2567), 1,
      aux_sym_tag_token1,
    ACTIONS(5341), 1,
      sym__lowercase_identifier,
    STATE(4316), 1,
      sym_attribute,
    STATE(6297), 1,
      sym__simple_expression,
    STATE(6354), 1,
      sym__value_name,
    STATE(6438), 1,
      sym__constructor_name,
    STATE(6647), 1,
      sym_parenthesized_operator,
    STATE(18324), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2525), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6449), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6255), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [126568] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4317), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [126638] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6273), 1,
      sym__lowercase_identifier,
    ACTIONS(6277), 1,
      anon_sym_LPAREN,
    ACTIONS(6279), 1,
      anon_sym_LBRACK,
    ACTIONS(6283), 1,
      anon_sym_LBRACE,
    ACTIONS(6285), 1,
      anon_sym_object,
    ACTIONS(6287), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6289), 1,
      anon_sym_new,
    ACTIONS(6291), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(6293), 1,
      anon_sym_begin,
    ACTIONS(6295), 1,
      sym_ocamlyacc_value,
    ACTIONS(6301), 1,
      aux_sym_number_token1,
    ACTIONS(6303), 1,
      anon_sym_SQUOTE,
    ACTIONS(6305), 1,
      anon_sym_DQUOTE,
    ACTIONS(6307), 1,
      sym_prefix_operator,
    ACTIONS(6309), 1,
      sym__uppercase_identifier,
    ACTIONS(6311), 1,
      aux_sym_tag_token1,
    ACTIONS(8644), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8646), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4318), 1,
      sym_attribute,
    STATE(6814), 1,
      sym__value_name,
    STATE(6849), 1,
      sym__simple_expression,
    STATE(7074), 1,
      sym__constructor_name,
    STATE(7163), 1,
      sym_parenthesized_operator,
    STATE(18564), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6281), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7075), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6715), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [126756] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4319), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [126826] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4320), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [126896] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8496), 1,
      sym__lowercase_identifier,
    ACTIONS(8498), 1,
      anon_sym_LPAREN,
    ACTIONS(8502), 1,
      anon_sym_LBRACE,
    ACTIONS(8504), 1,
      anon_sym_begin,
    ACTIONS(8506), 1,
      aux_sym_number_token1,
    ACTIONS(8508), 1,
      anon_sym_SQUOTE,
    ACTIONS(8510), 1,
      anon_sym_DQUOTE,
    ACTIONS(8512), 1,
      sym_prefix_operator,
    STATE(4321), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(7597), 1,
      sym__simple_expression,
    STATE(20132), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8500), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7550), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [127014] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5685), 1,
      sym__lowercase_identifier,
    ACTIONS(5693), 1,
      anon_sym_LPAREN,
    ACTIONS(5695), 1,
      anon_sym_LBRACK,
    ACTIONS(5699), 1,
      anon_sym_LBRACE,
    ACTIONS(5701), 1,
      anon_sym_object,
    ACTIONS(5703), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5705), 1,
      anon_sym_new,
    ACTIONS(5707), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(5709), 1,
      anon_sym_begin,
    ACTIONS(5711), 1,
      sym_ocamlyacc_value,
    ACTIONS(5717), 1,
      aux_sym_number_token1,
    ACTIONS(5719), 1,
      anon_sym_SQUOTE,
    ACTIONS(5721), 1,
      anon_sym_DQUOTE,
    ACTIONS(5723), 1,
      sym_prefix_operator,
    ACTIONS(5725), 1,
      sym__uppercase_identifier,
    ACTIONS(5727), 1,
      aux_sym_tag_token1,
    ACTIONS(8648), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8650), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4322), 1,
      sym_attribute,
    STATE(5950), 1,
      sym__value_name,
    STATE(6023), 1,
      sym__simple_expression,
    STATE(6049), 1,
      sym__constructor_name,
    STATE(6060), 1,
      sym_parenthesized_operator,
    STATE(18404), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5697), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6054), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6030), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [127132] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4323), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [127202] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4324), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [127272] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [127342] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [127412] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1341), 1,
      anon_sym_LPAREN,
    ACTIONS(1343), 1,
      anon_sym_LBRACK,
    ACTIONS(1347), 1,
      anon_sym_LBRACE,
    ACTIONS(1349), 1,
      anon_sym_object,
    ACTIONS(1353), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1363), 1,
      anon_sym_new,
    ACTIONS(1365), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1367), 1,
      anon_sym_begin,
    ACTIONS(1369), 1,
      sym_ocamlyacc_value,
    ACTIONS(1371), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1373), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1375), 1,
      aux_sym_number_token1,
    ACTIONS(1377), 1,
      anon_sym_SQUOTE,
    ACTIONS(1379), 1,
      anon_sym_DQUOTE,
    ACTIONS(1381), 1,
      sym_prefix_operator,
    ACTIONS(1385), 1,
      sym__uppercase_identifier,
    ACTIONS(1387), 1,
      aux_sym_tag_token1,
    ACTIONS(5055), 1,
      sym__lowercase_identifier,
    STATE(4327), 1,
      sym_attribute,
    STATE(5786), 1,
      sym_parenthesized_operator,
    STATE(5832), 1,
      sym__value_name,
    STATE(5836), 1,
      sym__simple_expression,
    STATE(5844), 1,
      sym__constructor_name,
    STATE(17948), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1345), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5842), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5778), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [127530] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6939), 1,
      sym__lowercase_identifier,
    ACTIONS(6943), 1,
      anon_sym_LPAREN,
    ACTIONS(6945), 1,
      anon_sym_LBRACK,
    ACTIONS(6949), 1,
      anon_sym_LBRACE,
    ACTIONS(6951), 1,
      anon_sym_object,
    ACTIONS(6953), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6955), 1,
      anon_sym_new,
    ACTIONS(6957), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(6959), 1,
      anon_sym_begin,
    ACTIONS(6961), 1,
      sym_ocamlyacc_value,
    ACTIONS(6967), 1,
      aux_sym_number_token1,
    ACTIONS(6969), 1,
      anon_sym_SQUOTE,
    ACTIONS(6971), 1,
      anon_sym_DQUOTE,
    ACTIONS(6973), 1,
      sym_prefix_operator,
    ACTIONS(6975), 1,
      sym__uppercase_identifier,
    ACTIONS(6977), 1,
      aux_sym_tag_token1,
    ACTIONS(8652), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8654), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4328), 1,
      sym_attribute,
    STATE(7908), 1,
      sym_parenthesized_operator,
    STATE(7984), 1,
      sym__simple_expression,
    STATE(8013), 1,
      sym__constructor_name,
    STATE(8060), 1,
      sym__value_name,
    STATE(17704), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6947), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8015), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8043), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [127648] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [127718] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5685), 1,
      sym__lowercase_identifier,
    ACTIONS(5693), 1,
      anon_sym_LPAREN,
    ACTIONS(5695), 1,
      anon_sym_LBRACK,
    ACTIONS(5699), 1,
      anon_sym_LBRACE,
    ACTIONS(5701), 1,
      anon_sym_object,
    ACTIONS(5703), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5705), 1,
      anon_sym_new,
    ACTIONS(5707), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(5709), 1,
      anon_sym_begin,
    ACTIONS(5711), 1,
      sym_ocamlyacc_value,
    ACTIONS(5717), 1,
      aux_sym_number_token1,
    ACTIONS(5719), 1,
      anon_sym_SQUOTE,
    ACTIONS(5721), 1,
      anon_sym_DQUOTE,
    ACTIONS(5723), 1,
      sym_prefix_operator,
    ACTIONS(5725), 1,
      sym__uppercase_identifier,
    ACTIONS(5727), 1,
      aux_sym_tag_token1,
    ACTIONS(8648), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8650), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4330), 1,
      sym_attribute,
    STATE(5950), 1,
      sym__value_name,
    STATE(5991), 1,
      sym__simple_expression,
    STATE(6049), 1,
      sym__constructor_name,
    STATE(6060), 1,
      sym_parenthesized_operator,
    STATE(18404), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5697), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6054), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6030), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [127836] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4331), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [127906] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6939), 1,
      sym__lowercase_identifier,
    ACTIONS(6943), 1,
      anon_sym_LPAREN,
    ACTIONS(6945), 1,
      anon_sym_LBRACK,
    ACTIONS(6949), 1,
      anon_sym_LBRACE,
    ACTIONS(6951), 1,
      anon_sym_object,
    ACTIONS(6953), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6955), 1,
      anon_sym_new,
    ACTIONS(6957), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(6959), 1,
      anon_sym_begin,
    ACTIONS(6961), 1,
      sym_ocamlyacc_value,
    ACTIONS(6967), 1,
      aux_sym_number_token1,
    ACTIONS(6969), 1,
      anon_sym_SQUOTE,
    ACTIONS(6971), 1,
      anon_sym_DQUOTE,
    ACTIONS(6973), 1,
      sym_prefix_operator,
    ACTIONS(6975), 1,
      sym__uppercase_identifier,
    ACTIONS(6977), 1,
      aux_sym_tag_token1,
    ACTIONS(8652), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8654), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4332), 1,
      sym_attribute,
    STATE(7908), 1,
      sym_parenthesized_operator,
    STATE(8013), 1,
      sym__constructor_name,
    STATE(8022), 1,
      sym__simple_expression,
    STATE(8060), 1,
      sym__value_name,
    STATE(17704), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6947), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8015), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8043), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [128024] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2417), 1,
      anon_sym_LPAREN,
    ACTIONS(2419), 1,
      anon_sym_LBRACK,
    ACTIONS(2423), 1,
      anon_sym_LBRACE,
    ACTIONS(2425), 1,
      anon_sym_object,
    ACTIONS(2429), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2439), 1,
      anon_sym_new,
    ACTIONS(2441), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2443), 1,
      anon_sym_begin,
    ACTIONS(2445), 1,
      sym_ocamlyacc_value,
    ACTIONS(2447), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2449), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2451), 1,
      aux_sym_number_token1,
    ACTIONS(2453), 1,
      anon_sym_SQUOTE,
    ACTIONS(2455), 1,
      anon_sym_DQUOTE,
    ACTIONS(2457), 1,
      sym_prefix_operator,
    ACTIONS(2461), 1,
      sym__uppercase_identifier,
    ACTIONS(2463), 1,
      aux_sym_tag_token1,
    ACTIONS(5393), 1,
      sym__lowercase_identifier,
    STATE(4333), 1,
      sym_attribute,
    STATE(6180), 1,
      sym__simple_expression,
    STATE(6262), 1,
      sym__value_name,
    STATE(6367), 1,
      sym__constructor_name,
    STATE(6621), 1,
      sym_parenthesized_operator,
    STATE(18284), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2421), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6373), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6162), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [128142] = 29,
    ACTIONS(999), 1,
      anon_sym_LPAREN,
    ACTIONS(1001), 1,
      anon_sym_LBRACK,
    ACTIONS(1005), 1,
      anon_sym_LBRACE,
    ACTIONS(1007), 1,
      anon_sym_object,
    ACTIONS(1011), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1021), 1,
      anon_sym_new,
    ACTIONS(1023), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1025), 1,
      anon_sym_begin,
    ACTIONS(1027), 1,
      sym_ocamlyacc_value,
    ACTIONS(1033), 1,
      aux_sym_number_token1,
    ACTIONS(1035), 1,
      anon_sym_SQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DQUOTE,
    ACTIONS(1039), 1,
      sym_prefix_operator,
    ACTIONS(1043), 1,
      sym__uppercase_identifier,
    ACTIONS(1045), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3073), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3075), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4585), 1,
      sym__lowercase_identifier,
    STATE(4334), 1,
      sym_attribute,
    STATE(4924), 1,
      sym__constructor_name,
    STATE(4935), 1,
      sym_parenthesized_operator,
    STATE(4945), 1,
      sym__simple_expression,
    STATE(4959), 1,
      sym__value_name,
    STATE(18304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1003), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4922), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4984), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [128260] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [128330] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(4336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [128402] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4337), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [128472] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8456), 1,
      sym__lowercase_identifier,
    ACTIONS(8458), 1,
      anon_sym_LPAREN,
    ACTIONS(8460), 1,
      anon_sym_LBRACK,
    ACTIONS(8464), 1,
      anon_sym_LBRACE,
    ACTIONS(8466), 1,
      anon_sym_object,
    ACTIONS(8468), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8470), 1,
      anon_sym_new,
    ACTIONS(8472), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8474), 1,
      anon_sym_begin,
    ACTIONS(8476), 1,
      sym_ocamlyacc_value,
    ACTIONS(8484), 1,
      aux_sym_number_token1,
    ACTIONS(8486), 1,
      anon_sym_SQUOTE,
    ACTIONS(8488), 1,
      anon_sym_DQUOTE,
    ACTIONS(8492), 1,
      sym__uppercase_identifier,
    ACTIONS(8494), 1,
      aux_sym_tag_token1,
    ACTIONS(8596), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8598), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8600), 1,
      sym_prefix_operator,
    STATE(4338), 1,
      sym_attribute,
    STATE(7320), 1,
      sym__value_name,
    STATE(7412), 1,
      sym_parenthesized_operator,
    STATE(7454), 1,
      sym__constructor_name,
    STATE(8876), 1,
      sym__simple_expression,
    STATE(18504), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8462), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7383), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7348), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [128590] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6553), 1,
      sym__lowercase_identifier,
    ACTIONS(6557), 1,
      anon_sym_LPAREN,
    ACTIONS(6559), 1,
      anon_sym_LBRACK,
    ACTIONS(6563), 1,
      anon_sym_LBRACE,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(6567), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6569), 1,
      anon_sym_new,
    ACTIONS(6571), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(6573), 1,
      anon_sym_begin,
    ACTIONS(6575), 1,
      sym_ocamlyacc_value,
    ACTIONS(6581), 1,
      aux_sym_number_token1,
    ACTIONS(6583), 1,
      anon_sym_SQUOTE,
    ACTIONS(6585), 1,
      anon_sym_DQUOTE,
    ACTIONS(6587), 1,
      sym_prefix_operator,
    ACTIONS(6589), 1,
      sym__uppercase_identifier,
    ACTIONS(6591), 1,
      aux_sym_tag_token1,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4339), 1,
      sym_attribute,
    STATE(6841), 1,
      sym_parenthesized_operator,
    STATE(6884), 1,
      sym__value_name,
    STATE(6890), 1,
      sym__constructor_name,
    STATE(7002), 1,
      sym__simple_expression,
    STATE(18104), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6561), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6891), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6896), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [128708] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3959), 1,
      anon_sym_DOT,
    ACTIONS(3961), 1,
      anon_sym_POUND,
    ACTIONS(3963), 1,
      sym_hash_operator,
    STATE(4340), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [128784] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4341), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [128854] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4342), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [128924] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4343), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [128994] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8556), 1,
      sym__lowercase_identifier,
    ACTIONS(8558), 1,
      anon_sym_LPAREN,
    ACTIONS(8560), 1,
      anon_sym_LBRACK,
    ACTIONS(8564), 1,
      anon_sym_LBRACE,
    ACTIONS(8566), 1,
      anon_sym_object,
    ACTIONS(8568), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8570), 1,
      anon_sym_new,
    ACTIONS(8572), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8574), 1,
      anon_sym_begin,
    ACTIONS(8576), 1,
      sym_ocamlyacc_value,
    ACTIONS(8578), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8580), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8582), 1,
      aux_sym_number_token1,
    ACTIONS(8584), 1,
      anon_sym_SQUOTE,
    ACTIONS(8586), 1,
      anon_sym_DQUOTE,
    ACTIONS(8588), 1,
      sym_prefix_operator,
    ACTIONS(8590), 1,
      sym__uppercase_identifier,
    ACTIONS(8592), 1,
      aux_sym_tag_token1,
    STATE(4344), 1,
      sym_attribute,
    STATE(9576), 1,
      sym__value_name,
    STATE(9661), 1,
      sym__simple_expression,
    STATE(9739), 1,
      sym__constructor_name,
    STATE(9784), 1,
      sym_parenthesized_operator,
    STATE(18244), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8562), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9811), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9740), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [129112] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4345), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [129182] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [129252] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4347), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [129322] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5685), 1,
      sym__lowercase_identifier,
    ACTIONS(5693), 1,
      anon_sym_LPAREN,
    ACTIONS(5695), 1,
      anon_sym_LBRACK,
    ACTIONS(5699), 1,
      anon_sym_LBRACE,
    ACTIONS(5701), 1,
      anon_sym_object,
    ACTIONS(5703), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5705), 1,
      anon_sym_new,
    ACTIONS(5707), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(5709), 1,
      anon_sym_begin,
    ACTIONS(5711), 1,
      sym_ocamlyacc_value,
    ACTIONS(5717), 1,
      aux_sym_number_token1,
    ACTIONS(5719), 1,
      anon_sym_SQUOTE,
    ACTIONS(5721), 1,
      anon_sym_DQUOTE,
    ACTIONS(5723), 1,
      sym_prefix_operator,
    ACTIONS(5725), 1,
      sym__uppercase_identifier,
    ACTIONS(5727), 1,
      aux_sym_tag_token1,
    ACTIONS(8648), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8650), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4348), 1,
      sym_attribute,
    STATE(5950), 1,
      sym__value_name,
    STATE(6049), 1,
      sym__constructor_name,
    STATE(6060), 1,
      sym_parenthesized_operator,
    STATE(6067), 1,
      sym__simple_expression,
    STATE(18404), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5697), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6054), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6030), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [129440] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [129510] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4350), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [129580] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [129650] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4352), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [129720] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4353), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [129790] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1119), 1,
      anon_sym_LPAREN,
    ACTIONS(1121), 1,
      anon_sym_LBRACK,
    ACTIONS(1125), 1,
      anon_sym_LBRACE,
    ACTIONS(1127), 1,
      anon_sym_object,
    ACTIONS(1131), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1145), 1,
      anon_sym_new,
    ACTIONS(1147), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1149), 1,
      anon_sym_begin,
    ACTIONS(1151), 1,
      sym_ocamlyacc_value,
    ACTIONS(1153), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1155), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1157), 1,
      aux_sym_number_token1,
    ACTIONS(1159), 1,
      anon_sym_SQUOTE,
    ACTIONS(1161), 1,
      anon_sym_DQUOTE,
    ACTIONS(1163), 1,
      sym_prefix_operator,
    ACTIONS(1167), 1,
      sym__uppercase_identifier,
    ACTIONS(1169), 1,
      aux_sym_tag_token1,
    ACTIONS(4595), 1,
      sym__lowercase_identifier,
    STATE(4354), 1,
      sym_attribute,
    STATE(5044), 1,
      sym_parenthesized_operator,
    STATE(5072), 1,
      sym__constructor_name,
    STATE(5119), 1,
      sym__simple_expression,
    STATE(5124), 1,
      sym__value_name,
    STATE(18002), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1123), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5096), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5003), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [129908] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7765), 1,
      sym__lowercase_identifier,
    ACTIONS(7769), 1,
      anon_sym_LPAREN,
    ACTIONS(7771), 1,
      anon_sym_LBRACK,
    ACTIONS(7775), 1,
      anon_sym_LBRACE,
    ACTIONS(7777), 1,
      anon_sym_object,
    ACTIONS(7779), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7781), 1,
      anon_sym_new,
    ACTIONS(7783), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(7785), 1,
      anon_sym_begin,
    ACTIONS(7787), 1,
      sym_ocamlyacc_value,
    ACTIONS(7789), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7791), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7793), 1,
      aux_sym_number_token1,
    ACTIONS(7795), 1,
      anon_sym_SQUOTE,
    ACTIONS(7797), 1,
      anon_sym_DQUOTE,
    ACTIONS(7799), 1,
      sym_prefix_operator,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    STATE(4355), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(9032), 1,
      sym__value_name,
    STATE(9072), 1,
      sym_parenthesized_operator,
    STATE(9086), 1,
      sym__simple_expression,
    STATE(17894), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7773), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9278), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [130026] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [130096] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(4357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [130168] = 29,
    ACTIONS(999), 1,
      anon_sym_LPAREN,
    ACTIONS(1001), 1,
      anon_sym_LBRACK,
    ACTIONS(1005), 1,
      anon_sym_LBRACE,
    ACTIONS(1007), 1,
      anon_sym_object,
    ACTIONS(1011), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1021), 1,
      anon_sym_new,
    ACTIONS(1023), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1025), 1,
      anon_sym_begin,
    ACTIONS(1027), 1,
      sym_ocamlyacc_value,
    ACTIONS(1033), 1,
      aux_sym_number_token1,
    ACTIONS(1035), 1,
      anon_sym_SQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DQUOTE,
    ACTIONS(1039), 1,
      sym_prefix_operator,
    ACTIONS(1043), 1,
      sym__uppercase_identifier,
    ACTIONS(1045), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3073), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3075), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4585), 1,
      sym__lowercase_identifier,
    STATE(4358), 1,
      sym_attribute,
    STATE(4924), 1,
      sym__constructor_name,
    STATE(4935), 1,
      sym_parenthesized_operator,
    STATE(4959), 1,
      sym__value_name,
    STATE(4989), 1,
      sym__simple_expression,
    STATE(18304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1003), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4922), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4984), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [130286] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1119), 1,
      anon_sym_LPAREN,
    ACTIONS(1121), 1,
      anon_sym_LBRACK,
    ACTIONS(1125), 1,
      anon_sym_LBRACE,
    ACTIONS(1127), 1,
      anon_sym_object,
    ACTIONS(1131), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1145), 1,
      anon_sym_new,
    ACTIONS(1147), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1149), 1,
      anon_sym_begin,
    ACTIONS(1151), 1,
      sym_ocamlyacc_value,
    ACTIONS(1153), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1155), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1157), 1,
      aux_sym_number_token1,
    ACTIONS(1159), 1,
      anon_sym_SQUOTE,
    ACTIONS(1161), 1,
      anon_sym_DQUOTE,
    ACTIONS(1163), 1,
      sym_prefix_operator,
    ACTIONS(1167), 1,
      sym__uppercase_identifier,
    ACTIONS(1169), 1,
      aux_sym_tag_token1,
    ACTIONS(4595), 1,
      sym__lowercase_identifier,
    STATE(4359), 1,
      sym_attribute,
    STATE(5042), 1,
      sym__simple_expression,
    STATE(5044), 1,
      sym_parenthesized_operator,
    STATE(5072), 1,
      sym__constructor_name,
    STATE(5124), 1,
      sym__value_name,
    STATE(18002), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1123), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5096), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5003), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [130404] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4360), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [130474] = 29,
    ACTIONS(583), 1,
      anon_sym_LPAREN,
    ACTIONS(585), 1,
      anon_sym_LBRACK,
    ACTIONS(589), 1,
      anon_sym_LBRACE,
    ACTIONS(591), 1,
      anon_sym_object,
    ACTIONS(595), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(605), 1,
      anon_sym_new,
    ACTIONS(607), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(609), 1,
      anon_sym_begin,
    ACTIONS(611), 1,
      sym_ocamlyacc_value,
    ACTIONS(617), 1,
      aux_sym_number_token1,
    ACTIONS(619), 1,
      anon_sym_SQUOTE,
    ACTIONS(621), 1,
      anon_sym_DQUOTE,
    ACTIONS(623), 1,
      sym_prefix_operator,
    ACTIONS(627), 1,
      sym__uppercase_identifier,
    ACTIONS(629), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3099), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3101), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3237), 1,
      sym__lowercase_identifier,
    STATE(3340), 1,
      sym__value_name,
    STATE(3439), 1,
      sym__simple_expression,
    STATE(3473), 1,
      sym__constructor_name,
    STATE(3728), 1,
      sym_parenthesized_operator,
    STATE(4361), 1,
      sym_attribute,
    STATE(17910), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(587), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3472), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3461), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [130592] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2643), 1,
      anon_sym_LPAREN,
    ACTIONS(2645), 1,
      anon_sym_LBRACK,
    ACTIONS(2649), 1,
      anon_sym_LBRACE,
    ACTIONS(2651), 1,
      anon_sym_object,
    ACTIONS(2655), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2665), 1,
      anon_sym_new,
    ACTIONS(2667), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2669), 1,
      anon_sym_begin,
    ACTIONS(2671), 1,
      sym_ocamlyacc_value,
    ACTIONS(2673), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2675), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2677), 1,
      aux_sym_number_token1,
    ACTIONS(2679), 1,
      anon_sym_SQUOTE,
    ACTIONS(2681), 1,
      anon_sym_DQUOTE,
    ACTIONS(2683), 1,
      sym_prefix_operator,
    ACTIONS(2687), 1,
      sym__uppercase_identifier,
    ACTIONS(2689), 1,
      aux_sym_tag_token1,
    ACTIONS(5551), 1,
      sym__lowercase_identifier,
    STATE(4362), 1,
      sym_attribute,
    STATE(6740), 1,
      sym__constructor_name,
    STATE(6846), 1,
      sym__value_name,
    STATE(7049), 1,
      sym__simple_expression,
    STATE(7160), 1,
      sym_parenthesized_operator,
    STATE(17678), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2647), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6743), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7113), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [130710] = 29,
    ACTIONS(583), 1,
      anon_sym_LPAREN,
    ACTIONS(585), 1,
      anon_sym_LBRACK,
    ACTIONS(589), 1,
      anon_sym_LBRACE,
    ACTIONS(591), 1,
      anon_sym_object,
    ACTIONS(595), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(605), 1,
      anon_sym_new,
    ACTIONS(607), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(609), 1,
      anon_sym_begin,
    ACTIONS(611), 1,
      sym_ocamlyacc_value,
    ACTIONS(617), 1,
      aux_sym_number_token1,
    ACTIONS(619), 1,
      anon_sym_SQUOTE,
    ACTIONS(621), 1,
      anon_sym_DQUOTE,
    ACTIONS(623), 1,
      sym_prefix_operator,
    ACTIONS(627), 1,
      sym__uppercase_identifier,
    ACTIONS(629), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3099), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3101), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3237), 1,
      sym__lowercase_identifier,
    STATE(3340), 1,
      sym__value_name,
    STATE(3396), 1,
      sym__simple_expression,
    STATE(3473), 1,
      sym__constructor_name,
    STATE(3728), 1,
      sym_parenthesized_operator,
    STATE(4363), 1,
      sym_attribute,
    STATE(17910), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(587), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3472), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3461), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [130828] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2747), 1,
      anon_sym_LPAREN,
    ACTIONS(2749), 1,
      anon_sym_LBRACK,
    ACTIONS(2753), 1,
      anon_sym_LBRACE,
    ACTIONS(2755), 1,
      anon_sym_object,
    ACTIONS(2759), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2769), 1,
      anon_sym_new,
    ACTIONS(2771), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2773), 1,
      anon_sym_begin,
    ACTIONS(2775), 1,
      sym_ocamlyacc_value,
    ACTIONS(2777), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2779), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2781), 1,
      aux_sym_number_token1,
    ACTIONS(2783), 1,
      anon_sym_SQUOTE,
    ACTIONS(2785), 1,
      anon_sym_DQUOTE,
    ACTIONS(2787), 1,
      sym_prefix_operator,
    ACTIONS(2791), 1,
      sym__uppercase_identifier,
    ACTIONS(2793), 1,
      aux_sym_tag_token1,
    ACTIONS(5571), 1,
      sym__lowercase_identifier,
    STATE(4364), 1,
      sym_attribute,
    STATE(6870), 1,
      sym__constructor_name,
    STATE(6985), 1,
      sym__simple_expression,
    STATE(7065), 1,
      sym_parenthesized_operator,
    STATE(7189), 1,
      sym__value_name,
    STATE(19332), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2751), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6940), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7193), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [130946] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4365), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [131016] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4366), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [131086] = 29,
    ACTIONS(861), 1,
      anon_sym_LPAREN,
    ACTIONS(863), 1,
      anon_sym_LBRACK,
    ACTIONS(867), 1,
      anon_sym_LBRACE,
    ACTIONS(869), 1,
      anon_sym_object,
    ACTIONS(873), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(883), 1,
      anon_sym_new,
    ACTIONS(885), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(887), 1,
      anon_sym_begin,
    ACTIONS(889), 1,
      sym_ocamlyacc_value,
    ACTIONS(895), 1,
      aux_sym_number_token1,
    ACTIONS(897), 1,
      anon_sym_SQUOTE,
    ACTIONS(899), 1,
      anon_sym_DQUOTE,
    ACTIONS(901), 1,
      sym_prefix_operator,
    ACTIONS(905), 1,
      sym__uppercase_identifier,
    ACTIONS(907), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3103), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3105), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3445), 1,
      sym__lowercase_identifier,
    STATE(4054), 1,
      sym__constructor_name,
    STATE(4104), 1,
      sym__value_name,
    STATE(4120), 1,
      sym__simple_expression,
    STATE(4160), 1,
      sym_parenthesized_operator,
    STATE(4367), 1,
      sym_attribute,
    STATE(17631), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(865), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4047), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4041), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [131204] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2303), 1,
      anon_sym_LPAREN,
    ACTIONS(2305), 1,
      anon_sym_LBRACK,
    ACTIONS(2309), 1,
      anon_sym_LBRACE,
    ACTIONS(2311), 1,
      anon_sym_object,
    ACTIONS(2315), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2325), 1,
      anon_sym_new,
    ACTIONS(2327), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2329), 1,
      anon_sym_begin,
    ACTIONS(2331), 1,
      sym_ocamlyacc_value,
    ACTIONS(2333), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2335), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2337), 1,
      aux_sym_number_token1,
    ACTIONS(2339), 1,
      anon_sym_SQUOTE,
    ACTIONS(2341), 1,
      anon_sym_DQUOTE,
    ACTIONS(2343), 1,
      sym_prefix_operator,
    ACTIONS(2347), 1,
      sym__uppercase_identifier,
    ACTIONS(2349), 1,
      aux_sym_tag_token1,
    ACTIONS(5371), 1,
      sym__lowercase_identifier,
    STATE(4368), 1,
      sym_attribute,
    STATE(6336), 1,
      sym__value_name,
    STATE(6437), 1,
      sym_parenthesized_operator,
    STATE(6511), 1,
      sym__simple_expression,
    STATE(6592), 1,
      sym__constructor_name,
    STATE(18163), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2307), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6584), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6539), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [131322] = 29,
    ACTIONS(917), 1,
      anon_sym_LPAREN,
    ACTIONS(919), 1,
      anon_sym_LBRACK,
    ACTIONS(923), 1,
      anon_sym_LBRACE,
    ACTIONS(925), 1,
      anon_sym_object,
    ACTIONS(929), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(947), 1,
      anon_sym_new,
    ACTIONS(949), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(951), 1,
      anon_sym_begin,
    ACTIONS(953), 1,
      sym_ocamlyacc_value,
    ACTIONS(959), 1,
      aux_sym_number_token1,
    ACTIONS(961), 1,
      anon_sym_SQUOTE,
    ACTIONS(963), 1,
      anon_sym_DQUOTE,
    ACTIONS(965), 1,
      sym_prefix_operator,
    ACTIONS(969), 1,
      sym__uppercase_identifier,
    ACTIONS(971), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3111), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3113), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4575), 1,
      sym__lowercase_identifier,
    STATE(4369), 1,
      sym_attribute,
    STATE(4786), 1,
      sym__constructor_name,
    STATE(4812), 1,
      sym_parenthesized_operator,
    STATE(4817), 1,
      sym__value_name,
    STATE(4854), 1,
      sym__simple_expression,
    STATE(18603), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(921), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4865), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [131440] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4370), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [131510] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [131580] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2591), 1,
      anon_sym_LPAREN,
    ACTIONS(2593), 1,
      anon_sym_LBRACK,
    ACTIONS(2597), 1,
      anon_sym_LBRACE,
    ACTIONS(2599), 1,
      anon_sym_object,
    ACTIONS(2603), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2613), 1,
      anon_sym_new,
    ACTIONS(2615), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2617), 1,
      anon_sym_begin,
    ACTIONS(2619), 1,
      sym_ocamlyacc_value,
    ACTIONS(2621), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2623), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2625), 1,
      aux_sym_number_token1,
    ACTIONS(2627), 1,
      anon_sym_SQUOTE,
    ACTIONS(2629), 1,
      anon_sym_DQUOTE,
    ACTIONS(2631), 1,
      sym_prefix_operator,
    ACTIONS(2635), 1,
      sym__uppercase_identifier,
    ACTIONS(2637), 1,
      aux_sym_tag_token1,
    ACTIONS(5529), 1,
      sym__lowercase_identifier,
    STATE(4372), 1,
      sym_attribute,
    STATE(6945), 1,
      sym_parenthesized_operator,
    STATE(6963), 1,
      sym__constructor_name,
    STATE(7135), 1,
      sym__value_name,
    STATE(7194), 1,
      sym__simple_expression,
    STATE(18738), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2595), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6961), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7138), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [131698] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [131768] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [131838] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2521), 1,
      anon_sym_LPAREN,
    ACTIONS(2523), 1,
      anon_sym_LBRACK,
    ACTIONS(2527), 1,
      anon_sym_LBRACE,
    ACTIONS(2529), 1,
      anon_sym_object,
    ACTIONS(2533), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2543), 1,
      anon_sym_new,
    ACTIONS(2545), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2547), 1,
      anon_sym_begin,
    ACTIONS(2549), 1,
      sym_ocamlyacc_value,
    ACTIONS(2551), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2553), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2555), 1,
      aux_sym_number_token1,
    ACTIONS(2557), 1,
      anon_sym_SQUOTE,
    ACTIONS(2559), 1,
      anon_sym_DQUOTE,
    ACTIONS(2561), 1,
      sym_prefix_operator,
    ACTIONS(2565), 1,
      sym__uppercase_identifier,
    ACTIONS(2567), 1,
      aux_sym_tag_token1,
    ACTIONS(5341), 1,
      sym__lowercase_identifier,
    STATE(4375), 1,
      sym_attribute,
    STATE(6354), 1,
      sym__value_name,
    STATE(6438), 1,
      sym__constructor_name,
    STATE(6600), 1,
      sym__simple_expression,
    STATE(6647), 1,
      sym_parenthesized_operator,
    STATE(18324), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2525), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6449), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6255), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [131956] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [132026] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [132096] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6273), 1,
      sym__lowercase_identifier,
    ACTIONS(6277), 1,
      anon_sym_LPAREN,
    ACTIONS(6279), 1,
      anon_sym_LBRACK,
    ACTIONS(6283), 1,
      anon_sym_LBRACE,
    ACTIONS(6285), 1,
      anon_sym_object,
    ACTIONS(6287), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6289), 1,
      anon_sym_new,
    ACTIONS(6291), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(6293), 1,
      anon_sym_begin,
    ACTIONS(6295), 1,
      sym_ocamlyacc_value,
    ACTIONS(6301), 1,
      aux_sym_number_token1,
    ACTIONS(6303), 1,
      anon_sym_SQUOTE,
    ACTIONS(6305), 1,
      anon_sym_DQUOTE,
    ACTIONS(6307), 1,
      sym_prefix_operator,
    ACTIONS(6309), 1,
      sym__uppercase_identifier,
    ACTIONS(6311), 1,
      aux_sym_tag_token1,
    ACTIONS(8644), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8646), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4378), 1,
      sym_attribute,
    STATE(6732), 1,
      sym__simple_expression,
    STATE(6814), 1,
      sym__value_name,
    STATE(7074), 1,
      sym__constructor_name,
    STATE(7163), 1,
      sym_parenthesized_operator,
    STATE(18564), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6281), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7075), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6715), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [132214] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2643), 1,
      anon_sym_LPAREN,
    ACTIONS(2645), 1,
      anon_sym_LBRACK,
    ACTIONS(2649), 1,
      anon_sym_LBRACE,
    ACTIONS(2651), 1,
      anon_sym_object,
    ACTIONS(2655), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2665), 1,
      anon_sym_new,
    ACTIONS(2667), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2669), 1,
      anon_sym_begin,
    ACTIONS(2671), 1,
      sym_ocamlyacc_value,
    ACTIONS(2673), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2675), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2677), 1,
      aux_sym_number_token1,
    ACTIONS(2679), 1,
      anon_sym_SQUOTE,
    ACTIONS(2681), 1,
      anon_sym_DQUOTE,
    ACTIONS(2683), 1,
      sym_prefix_operator,
    ACTIONS(2687), 1,
      sym__uppercase_identifier,
    ACTIONS(2689), 1,
      aux_sym_tag_token1,
    ACTIONS(5551), 1,
      sym__lowercase_identifier,
    STATE(4379), 1,
      sym_attribute,
    STATE(6740), 1,
      sym__constructor_name,
    STATE(6846), 1,
      sym__value_name,
    STATE(7024), 1,
      sym__simple_expression,
    STATE(7160), 1,
      sym_parenthesized_operator,
    STATE(17678), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2647), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6743), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7113), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [132332] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8622), 33,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [132402] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2643), 1,
      anon_sym_LPAREN,
    ACTIONS(2645), 1,
      anon_sym_LBRACK,
    ACTIONS(2649), 1,
      anon_sym_LBRACE,
    ACTIONS(2651), 1,
      anon_sym_object,
    ACTIONS(2655), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2665), 1,
      anon_sym_new,
    ACTIONS(2667), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2669), 1,
      anon_sym_begin,
    ACTIONS(2671), 1,
      sym_ocamlyacc_value,
    ACTIONS(2673), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2675), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2677), 1,
      aux_sym_number_token1,
    ACTIONS(2679), 1,
      anon_sym_SQUOTE,
    ACTIONS(2681), 1,
      anon_sym_DQUOTE,
    ACTIONS(2683), 1,
      sym_prefix_operator,
    ACTIONS(2687), 1,
      sym__uppercase_identifier,
    ACTIONS(2689), 1,
      aux_sym_tag_token1,
    ACTIONS(5551), 1,
      sym__lowercase_identifier,
    STATE(4381), 1,
      sym_attribute,
    STATE(6740), 1,
      sym__constructor_name,
    STATE(6846), 1,
      sym__value_name,
    STATE(7091), 1,
      sym__simple_expression,
    STATE(7160), 1,
      sym_parenthesized_operator,
    STATE(17678), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2647), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6743), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7113), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [132520] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(4382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [132592] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [132662] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6273), 1,
      sym__lowercase_identifier,
    ACTIONS(6277), 1,
      anon_sym_LPAREN,
    ACTIONS(6279), 1,
      anon_sym_LBRACK,
    ACTIONS(6283), 1,
      anon_sym_LBRACE,
    ACTIONS(6285), 1,
      anon_sym_object,
    ACTIONS(6287), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6289), 1,
      anon_sym_new,
    ACTIONS(6291), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(6293), 1,
      anon_sym_begin,
    ACTIONS(6295), 1,
      sym_ocamlyacc_value,
    ACTIONS(6301), 1,
      aux_sym_number_token1,
    ACTIONS(6303), 1,
      anon_sym_SQUOTE,
    ACTIONS(6305), 1,
      anon_sym_DQUOTE,
    ACTIONS(6307), 1,
      sym_prefix_operator,
    ACTIONS(6309), 1,
      sym__uppercase_identifier,
    ACTIONS(6311), 1,
      aux_sym_tag_token1,
    ACTIONS(8644), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8646), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4384), 1,
      sym_attribute,
    STATE(6757), 1,
      sym__simple_expression,
    STATE(6814), 1,
      sym__value_name,
    STATE(7074), 1,
      sym__constructor_name,
    STATE(7163), 1,
      sym_parenthesized_operator,
    STATE(18564), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6281), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7075), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6715), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [132780] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8456), 1,
      sym__lowercase_identifier,
    ACTIONS(8458), 1,
      anon_sym_LPAREN,
    ACTIONS(8460), 1,
      anon_sym_LBRACK,
    ACTIONS(8464), 1,
      anon_sym_LBRACE,
    ACTIONS(8466), 1,
      anon_sym_object,
    ACTIONS(8468), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8470), 1,
      anon_sym_new,
    ACTIONS(8472), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8474), 1,
      anon_sym_begin,
    ACTIONS(8476), 1,
      sym_ocamlyacc_value,
    ACTIONS(8478), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8480), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8484), 1,
      aux_sym_number_token1,
    ACTIONS(8486), 1,
      anon_sym_SQUOTE,
    ACTIONS(8488), 1,
      anon_sym_DQUOTE,
    ACTIONS(8490), 1,
      sym_prefix_operator,
    ACTIONS(8492), 1,
      sym__uppercase_identifier,
    ACTIONS(8494), 1,
      aux_sym_tag_token1,
    STATE(4385), 1,
      sym_attribute,
    STATE(7320), 1,
      sym__value_name,
    STATE(7412), 1,
      sym_parenthesized_operator,
    STATE(7454), 1,
      sym__constructor_name,
    STATE(9182), 1,
      sym__simple_expression,
    STATE(18504), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8462), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7383), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7348), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [132898] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1399), 1,
      anon_sym_LPAREN,
    ACTIONS(1401), 1,
      anon_sym_LBRACK,
    ACTIONS(1405), 1,
      anon_sym_LBRACE,
    ACTIONS(1407), 1,
      anon_sym_object,
    ACTIONS(1411), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1421), 1,
      anon_sym_new,
    ACTIONS(1423), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1425), 1,
      anon_sym_begin,
    ACTIONS(1427), 1,
      sym_ocamlyacc_value,
    ACTIONS(1429), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1431), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1433), 1,
      aux_sym_number_token1,
    ACTIONS(1435), 1,
      anon_sym_SQUOTE,
    ACTIONS(1437), 1,
      anon_sym_DQUOTE,
    ACTIONS(1439), 1,
      sym_prefix_operator,
    ACTIONS(1443), 1,
      sym__uppercase_identifier,
    ACTIONS(1445), 1,
      aux_sym_tag_token1,
    ACTIONS(5235), 1,
      sym__lowercase_identifier,
    STATE(4386), 1,
      sym_attribute,
    STATE(5857), 1,
      sym_parenthesized_operator,
    STATE(5938), 1,
      sym__simple_expression,
    STATE(6011), 1,
      sym__constructor_name,
    STATE(6089), 1,
      sym__value_name,
    STATE(18718), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1403), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6008), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6138), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [133016] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4387), 1,
      sym_attribute,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5277), 1,
      sym__simple_expression,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [133134] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2303), 1,
      anon_sym_LPAREN,
    ACTIONS(2305), 1,
      anon_sym_LBRACK,
    ACTIONS(2309), 1,
      anon_sym_LBRACE,
    ACTIONS(2311), 1,
      anon_sym_object,
    ACTIONS(2315), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2325), 1,
      anon_sym_new,
    ACTIONS(2327), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2329), 1,
      anon_sym_begin,
    ACTIONS(2331), 1,
      sym_ocamlyacc_value,
    ACTIONS(2333), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2335), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2337), 1,
      aux_sym_number_token1,
    ACTIONS(2339), 1,
      anon_sym_SQUOTE,
    ACTIONS(2341), 1,
      anon_sym_DQUOTE,
    ACTIONS(2343), 1,
      sym_prefix_operator,
    ACTIONS(2347), 1,
      sym__uppercase_identifier,
    ACTIONS(2349), 1,
      aux_sym_tag_token1,
    ACTIONS(5371), 1,
      sym__lowercase_identifier,
    STATE(4388), 1,
      sym_attribute,
    STATE(6336), 1,
      sym__value_name,
    STATE(6437), 1,
      sym_parenthesized_operator,
    STATE(6478), 1,
      sym__simple_expression,
    STATE(6592), 1,
      sym__constructor_name,
    STATE(18163), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2307), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6584), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6539), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [133252] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2469), 1,
      anon_sym_LPAREN,
    ACTIONS(2471), 1,
      anon_sym_LBRACK,
    ACTIONS(2475), 1,
      anon_sym_LBRACE,
    ACTIONS(2477), 1,
      anon_sym_object,
    ACTIONS(2481), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2491), 1,
      anon_sym_new,
    ACTIONS(2493), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2495), 1,
      anon_sym_begin,
    ACTIONS(2497), 1,
      sym_ocamlyacc_value,
    ACTIONS(2499), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2501), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2503), 1,
      aux_sym_number_token1,
    ACTIONS(2505), 1,
      anon_sym_SQUOTE,
    ACTIONS(2507), 1,
      anon_sym_DQUOTE,
    ACTIONS(2509), 1,
      sym_prefix_operator,
    ACTIONS(2513), 1,
      sym__uppercase_identifier,
    ACTIONS(2515), 1,
      aux_sym_tag_token1,
    ACTIONS(5381), 1,
      sym__lowercase_identifier,
    STATE(4389), 1,
      sym_attribute,
    STATE(6224), 1,
      sym__value_name,
    STATE(6398), 1,
      sym_parenthesized_operator,
    STATE(6510), 1,
      sym__constructor_name,
    STATE(6642), 1,
      sym__simple_expression,
    STATE(18680), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2473), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6519), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6258), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [133370] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6233), 1,
      sym__lowercase_identifier,
    ACTIONS(6237), 1,
      anon_sym_LPAREN,
    ACTIONS(6239), 1,
      anon_sym_LBRACK,
    ACTIONS(6243), 1,
      anon_sym_LBRACE,
    ACTIONS(6245), 1,
      anon_sym_object,
    ACTIONS(6247), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6249), 1,
      anon_sym_new,
    ACTIONS(6251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(6253), 1,
      anon_sym_begin,
    ACTIONS(6255), 1,
      sym_ocamlyacc_value,
    ACTIONS(6261), 1,
      aux_sym_number_token1,
    ACTIONS(6263), 1,
      anon_sym_SQUOTE,
    ACTIONS(6265), 1,
      anon_sym_DQUOTE,
    ACTIONS(6267), 1,
      sym_prefix_operator,
    ACTIONS(6269), 1,
      sym__uppercase_identifier,
    ACTIONS(6271), 1,
      aux_sym_tag_token1,
    ACTIONS(8656), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8658), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4390), 1,
      sym_attribute,
    STATE(6722), 1,
      sym__value_name,
    STATE(7041), 1,
      sym__simple_expression,
    STATE(7077), 1,
      sym_parenthesized_operator,
    STATE(7168), 1,
      sym__constructor_name,
    STATE(18484), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6241), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7169), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6724), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [133488] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [133558] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8456), 1,
      sym__lowercase_identifier,
    ACTIONS(8458), 1,
      anon_sym_LPAREN,
    ACTIONS(8460), 1,
      anon_sym_LBRACK,
    ACTIONS(8464), 1,
      anon_sym_LBRACE,
    ACTIONS(8466), 1,
      anon_sym_object,
    ACTIONS(8468), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8470), 1,
      anon_sym_new,
    ACTIONS(8472), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8474), 1,
      anon_sym_begin,
    ACTIONS(8476), 1,
      sym_ocamlyacc_value,
    ACTIONS(8478), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8480), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8484), 1,
      aux_sym_number_token1,
    ACTIONS(8486), 1,
      anon_sym_SQUOTE,
    ACTIONS(8488), 1,
      anon_sym_DQUOTE,
    ACTIONS(8490), 1,
      sym_prefix_operator,
    ACTIONS(8492), 1,
      sym__uppercase_identifier,
    ACTIONS(8494), 1,
      aux_sym_tag_token1,
    STATE(4392), 1,
      sym_attribute,
    STATE(7320), 1,
      sym__value_name,
    STATE(7412), 1,
      sym_parenthesized_operator,
    STATE(7454), 1,
      sym__constructor_name,
    STATE(9191), 1,
      sym__simple_expression,
    STATE(18504), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8462), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7383), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7348), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [133676] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8456), 1,
      sym__lowercase_identifier,
    ACTIONS(8458), 1,
      anon_sym_LPAREN,
    ACTIONS(8460), 1,
      anon_sym_LBRACK,
    ACTIONS(8464), 1,
      anon_sym_LBRACE,
    ACTIONS(8466), 1,
      anon_sym_object,
    ACTIONS(8468), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8470), 1,
      anon_sym_new,
    ACTIONS(8472), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8474), 1,
      anon_sym_begin,
    ACTIONS(8476), 1,
      sym_ocamlyacc_value,
    ACTIONS(8478), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8480), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8484), 1,
      aux_sym_number_token1,
    ACTIONS(8486), 1,
      anon_sym_SQUOTE,
    ACTIONS(8488), 1,
      anon_sym_DQUOTE,
    ACTIONS(8490), 1,
      sym_prefix_operator,
    ACTIONS(8492), 1,
      sym__uppercase_identifier,
    ACTIONS(8494), 1,
      aux_sym_tag_token1,
    STATE(4393), 1,
      sym_attribute,
    STATE(7320), 1,
      sym__value_name,
    STATE(7338), 1,
      sym__simple_expression,
    STATE(7412), 1,
      sym_parenthesized_operator,
    STATE(7454), 1,
      sym__constructor_name,
    STATE(18504), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8462), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7383), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7348), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [133794] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8456), 1,
      sym__lowercase_identifier,
    ACTIONS(8458), 1,
      anon_sym_LPAREN,
    ACTIONS(8460), 1,
      anon_sym_LBRACK,
    ACTIONS(8464), 1,
      anon_sym_LBRACE,
    ACTIONS(8466), 1,
      anon_sym_object,
    ACTIONS(8468), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8470), 1,
      anon_sym_new,
    ACTIONS(8472), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8474), 1,
      anon_sym_begin,
    ACTIONS(8476), 1,
      sym_ocamlyacc_value,
    ACTIONS(8478), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8480), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8484), 1,
      aux_sym_number_token1,
    ACTIONS(8486), 1,
      anon_sym_SQUOTE,
    ACTIONS(8488), 1,
      anon_sym_DQUOTE,
    ACTIONS(8490), 1,
      sym_prefix_operator,
    ACTIONS(8492), 1,
      sym__uppercase_identifier,
    ACTIONS(8494), 1,
      aux_sym_tag_token1,
    STATE(4394), 1,
      sym_attribute,
    STATE(7316), 1,
      sym__simple_expression,
    STATE(7320), 1,
      sym__value_name,
    STATE(7412), 1,
      sym_parenthesized_operator,
    STATE(7454), 1,
      sym__constructor_name,
    STATE(18504), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8462), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7383), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7348), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [133912] = 29,
    ACTIONS(413), 1,
      anon_sym_LPAREN,
    ACTIONS(417), 1,
      anon_sym_LBRACK,
    ACTIONS(421), 1,
      anon_sym_LBRACE,
    ACTIONS(431), 1,
      anon_sym_object,
    ACTIONS(435), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(445), 1,
      anon_sym_new,
    ACTIONS(447), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(449), 1,
      anon_sym_begin,
    ACTIONS(451), 1,
      sym_ocamlyacc_value,
    ACTIONS(457), 1,
      aux_sym_number_token1,
    ACTIONS(459), 1,
      anon_sym_SQUOTE,
    ACTIONS(461), 1,
      anon_sym_DQUOTE,
    ACTIONS(463), 1,
      sym_prefix_operator,
    ACTIONS(469), 1,
      sym__uppercase_identifier,
    ACTIONS(473), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3095), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3097), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3955), 1,
      sym__lowercase_identifier,
    STATE(4249), 1,
      sym__simple_expression,
    STATE(4279), 1,
      sym_parenthesized_operator,
    STATE(4287), 1,
      sym__value_name,
    STATE(4395), 1,
      sym_attribute,
    STATE(4480), 1,
      sym__constructor_name,
    STATE(20400), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(419), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4219), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4413), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [134030] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [134100] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6939), 1,
      sym__lowercase_identifier,
    ACTIONS(6943), 1,
      anon_sym_LPAREN,
    ACTIONS(6945), 1,
      anon_sym_LBRACK,
    ACTIONS(6949), 1,
      anon_sym_LBRACE,
    ACTIONS(6951), 1,
      anon_sym_object,
    ACTIONS(6953), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6955), 1,
      anon_sym_new,
    ACTIONS(6957), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(6959), 1,
      anon_sym_begin,
    ACTIONS(6961), 1,
      sym_ocamlyacc_value,
    ACTIONS(6967), 1,
      aux_sym_number_token1,
    ACTIONS(6969), 1,
      anon_sym_SQUOTE,
    ACTIONS(6971), 1,
      anon_sym_DQUOTE,
    ACTIONS(6973), 1,
      sym_prefix_operator,
    ACTIONS(6975), 1,
      sym__uppercase_identifier,
    ACTIONS(6977), 1,
      aux_sym_tag_token1,
    ACTIONS(8652), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8654), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4397), 1,
      sym_attribute,
    STATE(7908), 1,
      sym_parenthesized_operator,
    STATE(8013), 1,
      sym__constructor_name,
    STATE(8060), 1,
      sym__value_name,
    STATE(8084), 1,
      sym__simple_expression,
    STATE(17704), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6947), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8015), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8043), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [134218] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2591), 1,
      anon_sym_LPAREN,
    ACTIONS(2593), 1,
      anon_sym_LBRACK,
    ACTIONS(2597), 1,
      anon_sym_LBRACE,
    ACTIONS(2599), 1,
      anon_sym_object,
    ACTIONS(2603), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2613), 1,
      anon_sym_new,
    ACTIONS(2615), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2617), 1,
      anon_sym_begin,
    ACTIONS(2619), 1,
      sym_ocamlyacc_value,
    ACTIONS(2621), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2623), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2625), 1,
      aux_sym_number_token1,
    ACTIONS(2627), 1,
      anon_sym_SQUOTE,
    ACTIONS(2629), 1,
      anon_sym_DQUOTE,
    ACTIONS(2631), 1,
      sym_prefix_operator,
    ACTIONS(2635), 1,
      sym__uppercase_identifier,
    ACTIONS(2637), 1,
      aux_sym_tag_token1,
    ACTIONS(5529), 1,
      sym__lowercase_identifier,
    STATE(4398), 1,
      sym_attribute,
    STATE(6945), 1,
      sym_parenthesized_operator,
    STATE(6963), 1,
      sym__constructor_name,
    STATE(7119), 1,
      sym__simple_expression,
    STATE(7135), 1,
      sym__value_name,
    STATE(18738), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2595), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6961), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7138), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [134336] = 29,
    ACTIONS(531), 1,
      anon_sym_LPAREN,
    ACTIONS(533), 1,
      anon_sym_LBRACK,
    ACTIONS(537), 1,
      anon_sym_LBRACE,
    ACTIONS(539), 1,
      anon_sym_object,
    ACTIONS(543), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(553), 1,
      anon_sym_new,
    ACTIONS(555), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(557), 1,
      anon_sym_begin,
    ACTIONS(559), 1,
      sym_ocamlyacc_value,
    ACTIONS(565), 1,
      aux_sym_number_token1,
    ACTIONS(567), 1,
      anon_sym_SQUOTE,
    ACTIONS(569), 1,
      anon_sym_DQUOTE,
    ACTIONS(571), 1,
      sym_prefix_operator,
    ACTIONS(575), 1,
      sym__uppercase_identifier,
    ACTIONS(577), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3259), 1,
      sym__lowercase_identifier,
    STATE(3337), 1,
      sym_parenthesized_operator,
    STATE(3434), 1,
      sym__constructor_name,
    STATE(3583), 1,
      sym__value_name,
    STATE(3639), 1,
      sym__simple_expression,
    STATE(4399), 1,
      sym_attribute,
    STATE(18905), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(535), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3432), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3704), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [134454] = 29,
    ACTIONS(41), 1,
      anon_sym_LPAREN,
    ACTIONS(47), 1,
      anon_sym_LBRACK,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    ACTIONS(67), 1,
      anon_sym_object,
    ACTIONS(71), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(89), 1,
      anon_sym_new,
    ACTIONS(91), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(93), 1,
      anon_sym_begin,
    ACTIONS(95), 1,
      sym_ocamlyacc_value,
    ACTIONS(101), 1,
      aux_sym_number_token1,
    ACTIONS(105), 1,
      anon_sym_SQUOTE,
    ACTIONS(107), 1,
      anon_sym_DQUOTE,
    ACTIONS(109), 1,
      sym_prefix_operator,
    ACTIONS(117), 1,
      sym__uppercase_identifier,
    ACTIONS(121), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3067), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3069), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4145), 1,
      sym__lowercase_identifier,
    STATE(4226), 1,
      sym__simple_expression,
    STATE(4257), 1,
      sym__constructor_name,
    STATE(4302), 1,
      sym_parenthesized_operator,
    STATE(4400), 1,
      sym_attribute,
    STATE(4454), 1,
      sym__value_name,
    STATE(20480), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(51), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4466), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4315), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [134572] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [134642] = 29,
    ACTIONS(531), 1,
      anon_sym_LPAREN,
    ACTIONS(533), 1,
      anon_sym_LBRACK,
    ACTIONS(537), 1,
      anon_sym_LBRACE,
    ACTIONS(539), 1,
      anon_sym_object,
    ACTIONS(543), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(553), 1,
      anon_sym_new,
    ACTIONS(555), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(557), 1,
      anon_sym_begin,
    ACTIONS(559), 1,
      sym_ocamlyacc_value,
    ACTIONS(565), 1,
      aux_sym_number_token1,
    ACTIONS(567), 1,
      anon_sym_SQUOTE,
    ACTIONS(569), 1,
      anon_sym_DQUOTE,
    ACTIONS(571), 1,
      sym_prefix_operator,
    ACTIONS(575), 1,
      sym__uppercase_identifier,
    ACTIONS(577), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3259), 1,
      sym__lowercase_identifier,
    STATE(3337), 1,
      sym_parenthesized_operator,
    STATE(3434), 1,
      sym__constructor_name,
    STATE(3583), 1,
      sym__value_name,
    STATE(3676), 1,
      sym__simple_expression,
    STATE(4402), 1,
      sym_attribute,
    STATE(18905), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(535), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3432), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3704), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [134760] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(4149), 1,
      anon_sym_DOT,
    ACTIONS(4151), 1,
      anon_sym_POUND,
    ACTIONS(4153), 1,
      sym_hash_operator,
    STATE(4403), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 32,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [134836] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [134906] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1233), 1,
      anon_sym_LBRACE,
    ACTIONS(1235), 1,
      anon_sym_object,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1249), 1,
      anon_sym_new,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1253), 1,
      anon_sym_begin,
    ACTIONS(1255), 1,
      sym_ocamlyacc_value,
    ACTIONS(1257), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1259), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1261), 1,
      aux_sym_number_token1,
    ACTIONS(1263), 1,
      anon_sym_SQUOTE,
    ACTIONS(1265), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      sym_prefix_operator,
    ACTIONS(1271), 1,
      sym__uppercase_identifier,
    ACTIONS(1273), 1,
      aux_sym_tag_token1,
    ACTIONS(4605), 1,
      sym__lowercase_identifier,
    STATE(4405), 1,
      sym_attribute,
    STATE(5198), 1,
      sym__simple_expression,
    STATE(5227), 1,
      sym__constructor_name,
    STATE(5269), 1,
      sym__value_name,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(20456), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1231), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5231), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5299), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [135024] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8496), 1,
      sym__lowercase_identifier,
    STATE(4406), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7460), 1,
      sym__value_name,
    STATE(15064), 1,
      sym__simple_expression,
    STATE(20497), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [135142] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7765), 1,
      sym__lowercase_identifier,
    ACTIONS(7769), 1,
      anon_sym_LPAREN,
    ACTIONS(7771), 1,
      anon_sym_LBRACK,
    ACTIONS(7775), 1,
      anon_sym_LBRACE,
    ACTIONS(7777), 1,
      anon_sym_object,
    ACTIONS(7779), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7781), 1,
      anon_sym_new,
    ACTIONS(7783), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(7785), 1,
      anon_sym_begin,
    ACTIONS(7787), 1,
      sym_ocamlyacc_value,
    ACTIONS(7789), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7791), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7793), 1,
      aux_sym_number_token1,
    ACTIONS(7795), 1,
      anon_sym_SQUOTE,
    ACTIONS(7797), 1,
      anon_sym_DQUOTE,
    ACTIONS(7799), 1,
      sym_prefix_operator,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    STATE(4407), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(9032), 1,
      sym__value_name,
    STATE(9072), 1,
      sym_parenthesized_operator,
    STATE(9221), 1,
      sym__simple_expression,
    STATE(17894), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7773), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9278), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [135260] = 29,
    ACTIONS(1065), 1,
      anon_sym_LPAREN,
    ACTIONS(1067), 1,
      anon_sym_LBRACK,
    ACTIONS(1071), 1,
      anon_sym_LBRACE,
    ACTIONS(1073), 1,
      anon_sym_object,
    ACTIONS(1077), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1087), 1,
      anon_sym_new,
    ACTIONS(1089), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1091), 1,
      anon_sym_begin,
    ACTIONS(1093), 1,
      sym_ocamlyacc_value,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1097), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1099), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1101), 1,
      aux_sym_number_token1,
    ACTIONS(1103), 1,
      anon_sym_SQUOTE,
    ACTIONS(1105), 1,
      anon_sym_DQUOTE,
    ACTIONS(1107), 1,
      sym_prefix_operator,
    ACTIONS(1111), 1,
      sym__uppercase_identifier,
    ACTIONS(1113), 1,
      aux_sym_tag_token1,
    ACTIONS(4615), 1,
      sym__lowercase_identifier,
    STATE(4408), 1,
      sym_attribute,
    STATE(5203), 1,
      sym_parenthesized_operator,
    STATE(5210), 1,
      sym__value_name,
    STATE(5248), 1,
      sym__constructor_name,
    STATE(5282), 1,
      sym__simple_expression,
    STATE(18831), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1069), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5233), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5216), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [135378] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4409), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [135448] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [135518] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4411), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [135588] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2303), 1,
      anon_sym_LPAREN,
    ACTIONS(2305), 1,
      anon_sym_LBRACK,
    ACTIONS(2309), 1,
      anon_sym_LBRACE,
    ACTIONS(2311), 1,
      anon_sym_object,
    ACTIONS(2315), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2325), 1,
      anon_sym_new,
    ACTIONS(2327), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2329), 1,
      anon_sym_begin,
    ACTIONS(2331), 1,
      sym_ocamlyacc_value,
    ACTIONS(2333), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2335), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2337), 1,
      aux_sym_number_token1,
    ACTIONS(2339), 1,
      anon_sym_SQUOTE,
    ACTIONS(2341), 1,
      anon_sym_DQUOTE,
    ACTIONS(2343), 1,
      sym_prefix_operator,
    ACTIONS(2347), 1,
      sym__uppercase_identifier,
    ACTIONS(2349), 1,
      aux_sym_tag_token1,
    ACTIONS(5371), 1,
      sym__lowercase_identifier,
    STATE(4412), 1,
      sym_attribute,
    STATE(6324), 1,
      sym__simple_expression,
    STATE(6336), 1,
      sym__value_name,
    STATE(6437), 1,
      sym_parenthesized_operator,
    STATE(6592), 1,
      sym__constructor_name,
    STATE(18163), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2307), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6584), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6539), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [135706] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [135776] = 29,
    ACTIONS(1065), 1,
      anon_sym_LPAREN,
    ACTIONS(1067), 1,
      anon_sym_LBRACK,
    ACTIONS(1071), 1,
      anon_sym_LBRACE,
    ACTIONS(1073), 1,
      anon_sym_object,
    ACTIONS(1077), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1087), 1,
      anon_sym_new,
    ACTIONS(1089), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1091), 1,
      anon_sym_begin,
    ACTIONS(1093), 1,
      sym_ocamlyacc_value,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1097), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1099), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1101), 1,
      aux_sym_number_token1,
    ACTIONS(1103), 1,
      anon_sym_SQUOTE,
    ACTIONS(1105), 1,
      anon_sym_DQUOTE,
    ACTIONS(1107), 1,
      sym_prefix_operator,
    ACTIONS(1111), 1,
      sym__uppercase_identifier,
    ACTIONS(1113), 1,
      aux_sym_tag_token1,
    ACTIONS(4615), 1,
      sym__lowercase_identifier,
    STATE(4414), 1,
      sym_attribute,
    STATE(5181), 1,
      sym__simple_expression,
    STATE(5203), 1,
      sym_parenthesized_operator,
    STATE(5210), 1,
      sym__value_name,
    STATE(5248), 1,
      sym__constructor_name,
    STATE(18831), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1069), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5233), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5216), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [135894] = 29,
    ACTIONS(1065), 1,
      anon_sym_LPAREN,
    ACTIONS(1067), 1,
      anon_sym_LBRACK,
    ACTIONS(1071), 1,
      anon_sym_LBRACE,
    ACTIONS(1073), 1,
      anon_sym_object,
    ACTIONS(1077), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1087), 1,
      anon_sym_new,
    ACTIONS(1089), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1091), 1,
      anon_sym_begin,
    ACTIONS(1093), 1,
      sym_ocamlyacc_value,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1097), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1099), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1101), 1,
      aux_sym_number_token1,
    ACTIONS(1103), 1,
      anon_sym_SQUOTE,
    ACTIONS(1105), 1,
      anon_sym_DQUOTE,
    ACTIONS(1107), 1,
      sym_prefix_operator,
    ACTIONS(1111), 1,
      sym__uppercase_identifier,
    ACTIONS(1113), 1,
      aux_sym_tag_token1,
    ACTIONS(4615), 1,
      sym__lowercase_identifier,
    STATE(4415), 1,
      sym_attribute,
    STATE(5203), 1,
      sym_parenthesized_operator,
    STATE(5210), 1,
      sym__value_name,
    STATE(5248), 1,
      sym__constructor_name,
    STATE(5288), 1,
      sym__simple_expression,
    STATE(18831), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1069), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5233), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5216), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [136012] = 29,
    ACTIONS(303), 1,
      anon_sym_LPAREN,
    ACTIONS(305), 1,
      anon_sym_LBRACK,
    ACTIONS(309), 1,
      anon_sym_LBRACE,
    ACTIONS(311), 1,
      anon_sym_object,
    ACTIONS(315), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(325), 1,
      anon_sym_new,
    ACTIONS(327), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(329), 1,
      anon_sym_begin,
    ACTIONS(331), 1,
      sym_ocamlyacc_value,
    ACTIONS(339), 1,
      aux_sym_number_token1,
    ACTIONS(341), 1,
      anon_sym_SQUOTE,
    ACTIONS(343), 1,
      anon_sym_DQUOTE,
    ACTIONS(345), 1,
      sym_prefix_operator,
    ACTIONS(351), 1,
      sym__uppercase_identifier,
    ACTIONS(353), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3049), 1,
      sym__lowercase_identifier,
    ACTIONS(3119), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3121), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2972), 1,
      sym__value_name,
    STATE(2998), 1,
      sym__simple_expression,
    STATE(3089), 1,
      sym_parenthesized_operator,
    STATE(3189), 1,
      sym__constructor_name,
    STATE(4416), 1,
      sym_attribute,
    STATE(18756), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(307), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3188), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3052), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [136130] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4417), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [136200] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2469), 1,
      anon_sym_LPAREN,
    ACTIONS(2471), 1,
      anon_sym_LBRACK,
    ACTIONS(2475), 1,
      anon_sym_LBRACE,
    ACTIONS(2477), 1,
      anon_sym_object,
    ACTIONS(2481), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2491), 1,
      anon_sym_new,
    ACTIONS(2493), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2495), 1,
      anon_sym_begin,
    ACTIONS(2497), 1,
      sym_ocamlyacc_value,
    ACTIONS(2499), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2501), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2503), 1,
      aux_sym_number_token1,
    ACTIONS(2505), 1,
      anon_sym_SQUOTE,
    ACTIONS(2507), 1,
      anon_sym_DQUOTE,
    ACTIONS(2509), 1,
      sym_prefix_operator,
    ACTIONS(2513), 1,
      sym__uppercase_identifier,
    ACTIONS(2515), 1,
      aux_sym_tag_token1,
    ACTIONS(5381), 1,
      sym__lowercase_identifier,
    STATE(4418), 1,
      sym_attribute,
    STATE(6224), 1,
      sym__value_name,
    STATE(6398), 1,
      sym_parenthesized_operator,
    STATE(6465), 1,
      sym__simple_expression,
    STATE(6510), 1,
      sym__constructor_name,
    STATE(18680), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2473), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6519), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6258), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [136318] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4419), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [136388] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4420), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [136458] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2813), 1,
      anon_sym_LPAREN,
    ACTIONS(2815), 1,
      anon_sym_LBRACK,
    ACTIONS(2819), 1,
      anon_sym_LBRACE,
    ACTIONS(2821), 1,
      anon_sym_object,
    ACTIONS(2825), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2835), 1,
      anon_sym_new,
    ACTIONS(2837), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2839), 1,
      anon_sym_begin,
    ACTIONS(2841), 1,
      sym_ocamlyacc_value,
    ACTIONS(2843), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2845), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2847), 1,
      aux_sym_number_token1,
    ACTIONS(2849), 1,
      anon_sym_SQUOTE,
    ACTIONS(2851), 1,
      anon_sym_DQUOTE,
    ACTIONS(2853), 1,
      sym_prefix_operator,
    ACTIONS(2857), 1,
      sym__uppercase_identifier,
    ACTIONS(2859), 1,
      aux_sym_tag_token1,
    ACTIONS(5519), 1,
      sym__lowercase_identifier,
    STATE(4421), 1,
      sym_attribute,
    STATE(6939), 1,
      sym__constructor_name,
    STATE(7131), 1,
      sym__value_name,
    STATE(7150), 1,
      sym__simple_expression,
    STATE(7200), 1,
      sym_parenthesized_operator,
    STATE(19879), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2817), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7136), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7128), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [136576] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4422), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [136646] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4423), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8622), 33,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [136716] = 29,
    ACTIONS(41), 1,
      anon_sym_LPAREN,
    ACTIONS(47), 1,
      anon_sym_LBRACK,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    ACTIONS(67), 1,
      anon_sym_object,
    ACTIONS(71), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(89), 1,
      anon_sym_new,
    ACTIONS(91), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(93), 1,
      anon_sym_begin,
    ACTIONS(95), 1,
      sym_ocamlyacc_value,
    ACTIONS(101), 1,
      aux_sym_number_token1,
    ACTIONS(105), 1,
      anon_sym_SQUOTE,
    ACTIONS(107), 1,
      anon_sym_DQUOTE,
    ACTIONS(109), 1,
      sym_prefix_operator,
    ACTIONS(117), 1,
      sym__uppercase_identifier,
    ACTIONS(121), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3067), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3069), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4145), 1,
      sym__lowercase_identifier,
    STATE(4257), 1,
      sym__constructor_name,
    STATE(4302), 1,
      sym_parenthesized_operator,
    STATE(4374), 1,
      sym__simple_expression,
    STATE(4424), 1,
      sym_attribute,
    STATE(4454), 1,
      sym__value_name,
    STATE(20480), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(51), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4466), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4315), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [136834] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4425), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [136904] = 29,
    ACTIONS(999), 1,
      anon_sym_LPAREN,
    ACTIONS(1001), 1,
      anon_sym_LBRACK,
    ACTIONS(1005), 1,
      anon_sym_LBRACE,
    ACTIONS(1007), 1,
      anon_sym_object,
    ACTIONS(1011), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1021), 1,
      anon_sym_new,
    ACTIONS(1023), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1025), 1,
      anon_sym_begin,
    ACTIONS(1027), 1,
      sym_ocamlyacc_value,
    ACTIONS(1033), 1,
      aux_sym_number_token1,
    ACTIONS(1035), 1,
      anon_sym_SQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DQUOTE,
    ACTIONS(1039), 1,
      sym_prefix_operator,
    ACTIONS(1043), 1,
      sym__uppercase_identifier,
    ACTIONS(1045), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3073), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3075), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4585), 1,
      sym__lowercase_identifier,
    STATE(4426), 1,
      sym_attribute,
    STATE(4921), 1,
      sym__simple_expression,
    STATE(4924), 1,
      sym__constructor_name,
    STATE(4935), 1,
      sym_parenthesized_operator,
    STATE(4959), 1,
      sym__value_name,
    STATE(18304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1003), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4922), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4984), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [137022] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(4149), 1,
      anon_sym_DOT,
    ACTIONS(4151), 1,
      anon_sym_POUND,
    ACTIONS(4153), 1,
      sym_hash_operator,
    STATE(4427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 32,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [137098] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1545), 1,
      anon_sym_LPAREN,
    ACTIONS(1547), 1,
      anon_sym_LBRACK,
    ACTIONS(1551), 1,
      anon_sym_LBRACE,
    ACTIONS(1553), 1,
      anon_sym_object,
    ACTIONS(1557), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1567), 1,
      anon_sym_new,
    ACTIONS(1569), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1571), 1,
      anon_sym_begin,
    ACTIONS(1573), 1,
      sym_ocamlyacc_value,
    ACTIONS(1575), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1577), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1579), 1,
      aux_sym_number_token1,
    ACTIONS(1581), 1,
      anon_sym_SQUOTE,
    ACTIONS(1583), 1,
      anon_sym_DQUOTE,
    ACTIONS(1585), 1,
      sym_prefix_operator,
    ACTIONS(1589), 1,
      sym__uppercase_identifier,
    ACTIONS(1591), 1,
      aux_sym_tag_token1,
    ACTIONS(5361), 1,
      sym__lowercase_identifier,
    STATE(4428), 1,
      sym_attribute,
    STATE(6155), 1,
      sym__simple_expression,
    STATE(6487), 1,
      sym__value_name,
    STATE(6631), 1,
      sym__constructor_name,
    STATE(6655), 1,
      sym_parenthesized_operator,
    STATE(17732), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1549), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6629), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6303), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [137216] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3959), 1,
      anon_sym_DOT,
    ACTIONS(3961), 1,
      anon_sym_POUND,
    ACTIONS(3963), 1,
      sym_hash_operator,
    STATE(4429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [137292] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1545), 1,
      anon_sym_LPAREN,
    ACTIONS(1547), 1,
      anon_sym_LBRACK,
    ACTIONS(1551), 1,
      anon_sym_LBRACE,
    ACTIONS(1553), 1,
      anon_sym_object,
    ACTIONS(1557), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1567), 1,
      anon_sym_new,
    ACTIONS(1569), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1571), 1,
      anon_sym_begin,
    ACTIONS(1573), 1,
      sym_ocamlyacc_value,
    ACTIONS(1575), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1577), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1579), 1,
      aux_sym_number_token1,
    ACTIONS(1581), 1,
      anon_sym_SQUOTE,
    ACTIONS(1583), 1,
      anon_sym_DQUOTE,
    ACTIONS(1585), 1,
      sym_prefix_operator,
    ACTIONS(1589), 1,
      sym__uppercase_identifier,
    ACTIONS(1591), 1,
      aux_sym_tag_token1,
    ACTIONS(5361), 1,
      sym__lowercase_identifier,
    STATE(4430), 1,
      sym_attribute,
    STATE(6355), 1,
      sym__simple_expression,
    STATE(6487), 1,
      sym__value_name,
    STATE(6631), 1,
      sym__constructor_name,
    STATE(6655), 1,
      sym_parenthesized_operator,
    STATE(17732), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1549), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6629), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6303), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [137410] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6233), 1,
      sym__lowercase_identifier,
    ACTIONS(6237), 1,
      anon_sym_LPAREN,
    ACTIONS(6239), 1,
      anon_sym_LBRACK,
    ACTIONS(6243), 1,
      anon_sym_LBRACE,
    ACTIONS(6245), 1,
      anon_sym_object,
    ACTIONS(6247), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6249), 1,
      anon_sym_new,
    ACTIONS(6251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(6253), 1,
      anon_sym_begin,
    ACTIONS(6255), 1,
      sym_ocamlyacc_value,
    ACTIONS(6261), 1,
      aux_sym_number_token1,
    ACTIONS(6263), 1,
      anon_sym_SQUOTE,
    ACTIONS(6265), 1,
      anon_sym_DQUOTE,
    ACTIONS(6267), 1,
      sym_prefix_operator,
    ACTIONS(6269), 1,
      sym__uppercase_identifier,
    ACTIONS(6271), 1,
      aux_sym_tag_token1,
    ACTIONS(8656), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8658), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4431), 1,
      sym_attribute,
    STATE(6702), 1,
      sym__simple_expression,
    STATE(6722), 1,
      sym__value_name,
    STATE(7077), 1,
      sym_parenthesized_operator,
    STATE(7168), 1,
      sym__constructor_name,
    STATE(18484), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6241), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7169), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6724), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [137528] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [137598] = 29,
    ACTIONS(479), 1,
      anon_sym_LPAREN,
    ACTIONS(481), 1,
      anon_sym_LBRACK,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(487), 1,
      anon_sym_object,
    ACTIONS(491), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(501), 1,
      anon_sym_new,
    ACTIONS(503), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(505), 1,
      anon_sym_begin,
    ACTIONS(507), 1,
      sym_ocamlyacc_value,
    ACTIONS(513), 1,
      aux_sym_number_token1,
    ACTIONS(515), 1,
      anon_sym_SQUOTE,
    ACTIONS(517), 1,
      anon_sym_DQUOTE,
    ACTIONS(519), 1,
      sym_prefix_operator,
    ACTIONS(523), 1,
      sym__uppercase_identifier,
    ACTIONS(525), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3123), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3125), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3157), 1,
      sym__lowercase_identifier,
    STATE(3349), 1,
      sym_parenthesized_operator,
    STATE(3406), 1,
      sym__constructor_name,
    STATE(3673), 1,
      sym__simple_expression,
    STATE(3691), 1,
      sym__value_name,
    STATE(4433), 1,
      sym_attribute,
    STATE(18868), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(483), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3400), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3532), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [137716] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6233), 1,
      sym__lowercase_identifier,
    ACTIONS(6237), 1,
      anon_sym_LPAREN,
    ACTIONS(6239), 1,
      anon_sym_LBRACK,
    ACTIONS(6243), 1,
      anon_sym_LBRACE,
    ACTIONS(6245), 1,
      anon_sym_object,
    ACTIONS(6247), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6249), 1,
      anon_sym_new,
    ACTIONS(6251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(6253), 1,
      anon_sym_begin,
    ACTIONS(6255), 1,
      sym_ocamlyacc_value,
    ACTIONS(6261), 1,
      aux_sym_number_token1,
    ACTIONS(6263), 1,
      anon_sym_SQUOTE,
    ACTIONS(6265), 1,
      anon_sym_DQUOTE,
    ACTIONS(6267), 1,
      sym_prefix_operator,
    ACTIONS(6269), 1,
      sym__uppercase_identifier,
    ACTIONS(6271), 1,
      aux_sym_tag_token1,
    ACTIONS(8656), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8658), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4434), 1,
      sym_attribute,
    STATE(6717), 1,
      sym__simple_expression,
    STATE(6722), 1,
      sym__value_name,
    STATE(7077), 1,
      sym_parenthesized_operator,
    STATE(7168), 1,
      sym__constructor_name,
    STATE(18484), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6241), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7169), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6724), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [137834] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [137904] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2747), 1,
      anon_sym_LPAREN,
    ACTIONS(2749), 1,
      anon_sym_LBRACK,
    ACTIONS(2753), 1,
      anon_sym_LBRACE,
    ACTIONS(2755), 1,
      anon_sym_object,
    ACTIONS(2759), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2769), 1,
      anon_sym_new,
    ACTIONS(2771), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2773), 1,
      anon_sym_begin,
    ACTIONS(2775), 1,
      sym_ocamlyacc_value,
    ACTIONS(2777), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2779), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2781), 1,
      aux_sym_number_token1,
    ACTIONS(2783), 1,
      anon_sym_SQUOTE,
    ACTIONS(2785), 1,
      anon_sym_DQUOTE,
    ACTIONS(2787), 1,
      sym_prefix_operator,
    ACTIONS(2791), 1,
      sym__uppercase_identifier,
    ACTIONS(2793), 1,
      aux_sym_tag_token1,
    ACTIONS(5571), 1,
      sym__lowercase_identifier,
    STATE(4436), 1,
      sym_attribute,
    STATE(6870), 1,
      sym__constructor_name,
    STATE(7065), 1,
      sym_parenthesized_operator,
    STATE(7104), 1,
      sym__simple_expression,
    STATE(7189), 1,
      sym__value_name,
    STATE(19332), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2751), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6940), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7193), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [138022] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1399), 1,
      anon_sym_LPAREN,
    ACTIONS(1401), 1,
      anon_sym_LBRACK,
    ACTIONS(1405), 1,
      anon_sym_LBRACE,
    ACTIONS(1407), 1,
      anon_sym_object,
    ACTIONS(1411), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1421), 1,
      anon_sym_new,
    ACTIONS(1423), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1425), 1,
      anon_sym_begin,
    ACTIONS(1427), 1,
      sym_ocamlyacc_value,
    ACTIONS(1429), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1431), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1433), 1,
      aux_sym_number_token1,
    ACTIONS(1435), 1,
      anon_sym_SQUOTE,
    ACTIONS(1437), 1,
      anon_sym_DQUOTE,
    ACTIONS(1439), 1,
      sym_prefix_operator,
    ACTIONS(1443), 1,
      sym__uppercase_identifier,
    ACTIONS(1445), 1,
      aux_sym_tag_token1,
    ACTIONS(5235), 1,
      sym__lowercase_identifier,
    STATE(4437), 1,
      sym_attribute,
    STATE(5857), 1,
      sym_parenthesized_operator,
    STATE(5943), 1,
      sym__simple_expression,
    STATE(6011), 1,
      sym__constructor_name,
    STATE(6089), 1,
      sym__value_name,
    STATE(18718), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1403), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6008), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6138), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [138140] = 29,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(361), 1,
      anon_sym_LBRACK,
    ACTIONS(365), 1,
      anon_sym_LBRACE,
    ACTIONS(367), 1,
      anon_sym_object,
    ACTIONS(371), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(381), 1,
      anon_sym_new,
    ACTIONS(383), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(385), 1,
      anon_sym_begin,
    ACTIONS(387), 1,
      sym_ocamlyacc_value,
    ACTIONS(393), 1,
      aux_sym_number_token1,
    ACTIONS(395), 1,
      anon_sym_SQUOTE,
    ACTIONS(397), 1,
      anon_sym_DQUOTE,
    ACTIONS(399), 1,
      sym_prefix_operator,
    ACTIONS(403), 1,
      sym__uppercase_identifier,
    ACTIONS(405), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3077), 1,
      sym__lowercase_identifier,
    ACTIONS(3107), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3109), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2983), 1,
      sym_parenthesized_operator,
    STATE(3103), 1,
      sym__value_name,
    STATE(3117), 1,
      sym__simple_expression,
    STATE(3124), 1,
      sym__constructor_name,
    STATE(4438), 1,
      sym_attribute,
    STATE(18642), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(363), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3123), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3176), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [138258] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8226), 33,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [138328] = 29,
    ACTIONS(637), 1,
      anon_sym_LPAREN,
    ACTIONS(639), 1,
      anon_sym_LBRACK,
    ACTIONS(643), 1,
      anon_sym_LBRACE,
    ACTIONS(645), 1,
      anon_sym_object,
    ACTIONS(649), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(659), 1,
      anon_sym_new,
    ACTIONS(661), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(663), 1,
      anon_sym_begin,
    ACTIONS(665), 1,
      sym_ocamlyacc_value,
    ACTIONS(671), 1,
      aux_sym_number_token1,
    ACTIONS(673), 1,
      anon_sym_SQUOTE,
    ACTIONS(675), 1,
      anon_sym_DQUOTE,
    ACTIONS(677), 1,
      sym_prefix_operator,
    ACTIONS(681), 1,
      sym__uppercase_identifier,
    ACTIONS(683), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3131), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3133), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3147), 1,
      sym__lowercase_identifier,
    STATE(3405), 1,
      sym_parenthesized_operator,
    STATE(3457), 1,
      sym__value_name,
    STATE(3460), 1,
      sym__constructor_name,
    STATE(3638), 1,
      sym__simple_expression,
    STATE(4440), 1,
      sym_attribute,
    STATE(17786), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(641), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3635), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3727), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [138446] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4441), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [138516] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4442), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [138586] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4443), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [138656] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2357), 1,
      anon_sym_LPAREN,
    ACTIONS(2359), 1,
      anon_sym_LBRACK,
    ACTIONS(2363), 1,
      anon_sym_LBRACE,
    ACTIONS(2365), 1,
      anon_sym_object,
    ACTIONS(2369), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2379), 1,
      anon_sym_new,
    ACTIONS(2381), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2383), 1,
      anon_sym_begin,
    ACTIONS(2385), 1,
      sym_ocamlyacc_value,
    ACTIONS(2387), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2389), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2391), 1,
      aux_sym_number_token1,
    ACTIONS(2393), 1,
      anon_sym_SQUOTE,
    ACTIONS(2395), 1,
      anon_sym_DQUOTE,
    ACTIONS(2397), 1,
      sym_prefix_operator,
    ACTIONS(2401), 1,
      sym__uppercase_identifier,
    ACTIONS(2403), 1,
      aux_sym_tag_token1,
    ACTIONS(5351), 1,
      sym__lowercase_identifier,
    STATE(4444), 1,
      sym_attribute,
    STATE(6169), 1,
      sym__value_name,
    STATE(6416), 1,
      sym__simple_expression,
    STATE(6529), 1,
      sym_parenthesized_operator,
    STATE(6547), 1,
      sym__constructor_name,
    STATE(18204), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2361), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6548), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6357), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [138774] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1399), 1,
      anon_sym_LPAREN,
    ACTIONS(1401), 1,
      anon_sym_LBRACK,
    ACTIONS(1405), 1,
      anon_sym_LBRACE,
    ACTIONS(1407), 1,
      anon_sym_object,
    ACTIONS(1411), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1421), 1,
      anon_sym_new,
    ACTIONS(1423), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1425), 1,
      anon_sym_begin,
    ACTIONS(1427), 1,
      sym_ocamlyacc_value,
    ACTIONS(1429), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1431), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1433), 1,
      aux_sym_number_token1,
    ACTIONS(1435), 1,
      anon_sym_SQUOTE,
    ACTIONS(1437), 1,
      anon_sym_DQUOTE,
    ACTIONS(1439), 1,
      sym_prefix_operator,
    ACTIONS(1443), 1,
      sym__uppercase_identifier,
    ACTIONS(1445), 1,
      aux_sym_tag_token1,
    ACTIONS(5235), 1,
      sym__lowercase_identifier,
    STATE(4445), 1,
      sym_attribute,
    STATE(5857), 1,
      sym_parenthesized_operator,
    STATE(6011), 1,
      sym__constructor_name,
    STATE(6084), 1,
      sym__simple_expression,
    STATE(6089), 1,
      sym__value_name,
    STATE(18718), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1403), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6008), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6138), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [138892] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1281), 1,
      anon_sym_LPAREN,
    ACTIONS(1283), 1,
      anon_sym_LBRACK,
    ACTIONS(1287), 1,
      anon_sym_LBRACE,
    ACTIONS(1289), 1,
      anon_sym_object,
    ACTIONS(1293), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1311), 1,
      anon_sym_new,
    ACTIONS(1313), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1315), 1,
      anon_sym_begin,
    ACTIONS(1317), 1,
      sym_ocamlyacc_value,
    ACTIONS(1319), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1321), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1323), 1,
      aux_sym_number_token1,
    ACTIONS(1325), 1,
      anon_sym_SQUOTE,
    ACTIONS(1327), 1,
      anon_sym_DQUOTE,
    ACTIONS(1329), 1,
      sym_prefix_operator,
    ACTIONS(1333), 1,
      sym__uppercase_identifier,
    ACTIONS(1335), 1,
      aux_sym_tag_token1,
    ACTIONS(4815), 1,
      sym__lowercase_identifier,
    STATE(4446), 1,
      sym_attribute,
    STATE(5616), 1,
      sym__constructor_name,
    STATE(5669), 1,
      sym__value_name,
    STATE(5713), 1,
      sym_parenthesized_operator,
    STATE(5733), 1,
      sym__simple_expression,
    STATE(18794), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1285), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5617), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5700), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [139010] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [139080] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4448), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [139150] = 29,
    ACTIONS(757), 1,
      anon_sym_LPAREN,
    ACTIONS(759), 1,
      anon_sym_LBRACK,
    ACTIONS(763), 1,
      anon_sym_LBRACE,
    ACTIONS(765), 1,
      anon_sym_object,
    ACTIONS(769), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(779), 1,
      anon_sym_new,
    ACTIONS(781), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(783), 1,
      anon_sym_begin,
    ACTIONS(785), 1,
      sym_ocamlyacc_value,
    ACTIONS(791), 1,
      aux_sym_number_token1,
    ACTIONS(793), 1,
      anon_sym_SQUOTE,
    ACTIONS(795), 1,
      anon_sym_DQUOTE,
    ACTIONS(797), 1,
      sym_prefix_operator,
    ACTIONS(801), 1,
      sym__uppercase_identifier,
    ACTIONS(803), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3087), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3089), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3271), 1,
      sym__lowercase_identifier,
    STATE(3777), 1,
      sym__constructor_name,
    STATE(3791), 1,
      sym_parenthesized_operator,
    STATE(3924), 1,
      sym__value_name,
    STATE(3944), 1,
      sym__simple_expression,
    STATE(4449), 1,
      sym_attribute,
    STATE(18444), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(761), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3778), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3838), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [139268] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1281), 1,
      anon_sym_LPAREN,
    ACTIONS(1283), 1,
      anon_sym_LBRACK,
    ACTIONS(1287), 1,
      anon_sym_LBRACE,
    ACTIONS(1289), 1,
      anon_sym_object,
    ACTIONS(1293), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1311), 1,
      anon_sym_new,
    ACTIONS(1313), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1315), 1,
      anon_sym_begin,
    ACTIONS(1317), 1,
      sym_ocamlyacc_value,
    ACTIONS(1319), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1321), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1323), 1,
      aux_sym_number_token1,
    ACTIONS(1325), 1,
      anon_sym_SQUOTE,
    ACTIONS(1327), 1,
      anon_sym_DQUOTE,
    ACTIONS(1329), 1,
      sym_prefix_operator,
    ACTIONS(1333), 1,
      sym__uppercase_identifier,
    ACTIONS(1335), 1,
      aux_sym_tag_token1,
    ACTIONS(4815), 1,
      sym__lowercase_identifier,
    STATE(4450), 1,
      sym_attribute,
    STATE(5616), 1,
      sym__constructor_name,
    STATE(5669), 1,
      sym__value_name,
    STATE(5713), 1,
      sym_parenthesized_operator,
    STATE(5753), 1,
      sym__simple_expression,
    STATE(18794), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1285), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5617), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5700), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [139386] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4451), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [139456] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4452), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [139526] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4453), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [139596] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4454), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [139666] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [139736] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2813), 1,
      anon_sym_LPAREN,
    ACTIONS(2815), 1,
      anon_sym_LBRACK,
    ACTIONS(2819), 1,
      anon_sym_LBRACE,
    ACTIONS(2821), 1,
      anon_sym_object,
    ACTIONS(2825), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2835), 1,
      anon_sym_new,
    ACTIONS(2837), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2839), 1,
      anon_sym_begin,
    ACTIONS(2841), 1,
      sym_ocamlyacc_value,
    ACTIONS(2843), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2845), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2847), 1,
      aux_sym_number_token1,
    ACTIONS(2849), 1,
      anon_sym_SQUOTE,
    ACTIONS(2851), 1,
      anon_sym_DQUOTE,
    ACTIONS(2853), 1,
      sym_prefix_operator,
    ACTIONS(2857), 1,
      sym__uppercase_identifier,
    ACTIONS(2859), 1,
      aux_sym_tag_token1,
    ACTIONS(5519), 1,
      sym__lowercase_identifier,
    STATE(4456), 1,
      sym_attribute,
    STATE(6939), 1,
      sym__constructor_name,
    STATE(7063), 1,
      sym__simple_expression,
    STATE(7131), 1,
      sym__value_name,
    STATE(7200), 1,
      sym_parenthesized_operator,
    STATE(19879), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2817), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7136), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7128), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [139854] = 29,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(361), 1,
      anon_sym_LBRACK,
    ACTIONS(365), 1,
      anon_sym_LBRACE,
    ACTIONS(367), 1,
      anon_sym_object,
    ACTIONS(371), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(381), 1,
      anon_sym_new,
    ACTIONS(383), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(385), 1,
      anon_sym_begin,
    ACTIONS(387), 1,
      sym_ocamlyacc_value,
    ACTIONS(393), 1,
      aux_sym_number_token1,
    ACTIONS(395), 1,
      anon_sym_SQUOTE,
    ACTIONS(397), 1,
      anon_sym_DQUOTE,
    ACTIONS(399), 1,
      sym_prefix_operator,
    ACTIONS(403), 1,
      sym__uppercase_identifier,
    ACTIONS(405), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3077), 1,
      sym__lowercase_identifier,
    ACTIONS(3107), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3109), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2983), 1,
      sym_parenthesized_operator,
    STATE(3103), 1,
      sym__value_name,
    STATE(3124), 1,
      sym__constructor_name,
    STATE(3168), 1,
      sym__simple_expression,
    STATE(4457), 1,
      sym_attribute,
    STATE(18642), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(363), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3123), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3176), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [139972] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [140042] = 29,
    ACTIONS(479), 1,
      anon_sym_LPAREN,
    ACTIONS(481), 1,
      anon_sym_LBRACK,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(487), 1,
      anon_sym_object,
    ACTIONS(491), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(501), 1,
      anon_sym_new,
    ACTIONS(503), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(505), 1,
      anon_sym_begin,
    ACTIONS(507), 1,
      sym_ocamlyacc_value,
    ACTIONS(513), 1,
      aux_sym_number_token1,
    ACTIONS(515), 1,
      anon_sym_SQUOTE,
    ACTIONS(517), 1,
      anon_sym_DQUOTE,
    ACTIONS(519), 1,
      sym_prefix_operator,
    ACTIONS(523), 1,
      sym__uppercase_identifier,
    ACTIONS(525), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3123), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3125), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3157), 1,
      sym__lowercase_identifier,
    STATE(3349), 1,
      sym_parenthesized_operator,
    STATE(3406), 1,
      sym__constructor_name,
    STATE(3602), 1,
      sym__simple_expression,
    STATE(3691), 1,
      sym__value_name,
    STATE(4459), 1,
      sym_attribute,
    STATE(18868), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(483), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3400), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3532), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [140160] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7765), 1,
      sym__lowercase_identifier,
    ACTIONS(7769), 1,
      anon_sym_LPAREN,
    ACTIONS(7771), 1,
      anon_sym_LBRACK,
    ACTIONS(7775), 1,
      anon_sym_LBRACE,
    ACTIONS(7777), 1,
      anon_sym_object,
    ACTIONS(7779), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7781), 1,
      anon_sym_new,
    ACTIONS(7783), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(7785), 1,
      anon_sym_begin,
    ACTIONS(7787), 1,
      sym_ocamlyacc_value,
    ACTIONS(7789), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7791), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7793), 1,
      aux_sym_number_token1,
    ACTIONS(7795), 1,
      anon_sym_SQUOTE,
    ACTIONS(7797), 1,
      anon_sym_DQUOTE,
    ACTIONS(7799), 1,
      sym_prefix_operator,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    STATE(4460), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(9032), 1,
      sym__value_name,
    STATE(9072), 1,
      sym_parenthesized_operator,
    STATE(9243), 1,
      sym__simple_expression,
    STATE(17894), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7773), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9278), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [140278] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4461), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [140348] = 29,
    ACTIONS(637), 1,
      anon_sym_LPAREN,
    ACTIONS(639), 1,
      anon_sym_LBRACK,
    ACTIONS(643), 1,
      anon_sym_LBRACE,
    ACTIONS(645), 1,
      anon_sym_object,
    ACTIONS(649), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(659), 1,
      anon_sym_new,
    ACTIONS(661), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(663), 1,
      anon_sym_begin,
    ACTIONS(665), 1,
      sym_ocamlyacc_value,
    ACTIONS(671), 1,
      aux_sym_number_token1,
    ACTIONS(673), 1,
      anon_sym_SQUOTE,
    ACTIONS(675), 1,
      anon_sym_DQUOTE,
    ACTIONS(677), 1,
      sym_prefix_operator,
    ACTIONS(681), 1,
      sym__uppercase_identifier,
    ACTIONS(683), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3131), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3133), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3147), 1,
      sym__lowercase_identifier,
    STATE(3405), 1,
      sym_parenthesized_operator,
    STATE(3457), 1,
      sym__value_name,
    STATE(3460), 1,
      sym__constructor_name,
    STATE(3689), 1,
      sym__simple_expression,
    STATE(4462), 1,
      sym_attribute,
    STATE(17786), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(641), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3635), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3727), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [140466] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8478), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8480), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8514), 1,
      sym__lowercase_identifier,
    ACTIONS(8516), 1,
      anon_sym_LPAREN,
    ACTIONS(8518), 1,
      anon_sym_LBRACK,
    ACTIONS(8522), 1,
      anon_sym_LBRACE,
    ACTIONS(8524), 1,
      anon_sym_object,
    ACTIONS(8526), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8528), 1,
      anon_sym_new,
    ACTIONS(8530), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8532), 1,
      anon_sym_begin,
    ACTIONS(8534), 1,
      sym_ocamlyacc_value,
    ACTIONS(8536), 1,
      aux_sym_number_token1,
    ACTIONS(8538), 1,
      anon_sym_SQUOTE,
    ACTIONS(8540), 1,
      anon_sym_DQUOTE,
    ACTIONS(8542), 1,
      sym_prefix_operator,
    ACTIONS(8544), 1,
      sym__uppercase_identifier,
    ACTIONS(8546), 1,
      aux_sym_tag_token1,
    STATE(4463), 1,
      sym_attribute,
    STATE(7480), 1,
      sym__constructor_name,
    STATE(7580), 1,
      sym_parenthesized_operator,
    STATE(7659), 1,
      sym__value_name,
    STATE(7703), 1,
      sym__simple_expression,
    STATE(18524), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8520), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7525), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7725), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [140584] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [140654] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4465), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [140724] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4466), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [140794] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5581), 1,
      sym__lowercase_identifier,
    ACTIONS(5589), 1,
      anon_sym_LPAREN,
    ACTIONS(5591), 1,
      anon_sym_LBRACK,
    ACTIONS(5595), 1,
      anon_sym_LBRACE,
    ACTIONS(5597), 1,
      anon_sym_object,
    ACTIONS(5599), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5601), 1,
      anon_sym_new,
    ACTIONS(5603), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(5605), 1,
      anon_sym_begin,
    ACTIONS(5607), 1,
      sym_ocamlyacc_value,
    ACTIONS(5613), 1,
      aux_sym_number_token1,
    ACTIONS(5615), 1,
      anon_sym_SQUOTE,
    ACTIONS(5617), 1,
      anon_sym_DQUOTE,
    ACTIONS(5619), 1,
      sym_prefix_operator,
    ACTIONS(5621), 1,
      sym__uppercase_identifier,
    ACTIONS(5623), 1,
      aux_sym_tag_token1,
    ACTIONS(8638), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8640), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4467), 1,
      sym_attribute,
    STATE(5955), 1,
      sym__value_name,
    STATE(6068), 1,
      sym_parenthesized_operator,
    STATE(6088), 1,
      sym__constructor_name,
    STATE(6099), 1,
      sym__simple_expression,
    STATE(18110), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5593), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6094), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5961), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [140912] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [140982] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [141052] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [141122] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(4471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [141194] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [141264] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(8022), 1,
      anon_sym_LPAREN,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_LBRACE,
    ACTIONS(8028), 1,
      anon_sym_object,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8032), 1,
      anon_sym_new,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8036), 1,
      anon_sym_begin,
    ACTIONS(8038), 1,
      sym_ocamlyacc_value,
    ACTIONS(8040), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8042), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8496), 1,
      sym__lowercase_identifier,
    STATE(4473), 1,
      sym_attribute,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(7440), 1,
      sym__simple_expression,
    STATE(7460), 1,
      sym__value_name,
    STATE(20497), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7462), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [141382] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [141452] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4475), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [141522] = 29,
    ACTIONS(693), 1,
      anon_sym_LPAREN,
    ACTIONS(695), 1,
      anon_sym_LBRACK,
    ACTIONS(699), 1,
      anon_sym_LBRACE,
    ACTIONS(701), 1,
      anon_sym_object,
    ACTIONS(705), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(715), 1,
      anon_sym_new,
    ACTIONS(717), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(719), 1,
      anon_sym_begin,
    ACTIONS(721), 1,
      sym_ocamlyacc_value,
    ACTIONS(727), 1,
      aux_sym_number_token1,
    ACTIONS(729), 1,
      anon_sym_SQUOTE,
    ACTIONS(731), 1,
      anon_sym_DQUOTE,
    ACTIONS(733), 1,
      sym_prefix_operator,
    ACTIONS(737), 1,
      sym__uppercase_identifier,
    ACTIONS(739), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3091), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3093), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3281), 1,
      sym__lowercase_identifier,
    STATE(3822), 1,
      sym_parenthesized_operator,
    STATE(3877), 1,
      sym__simple_expression,
    STATE(3881), 1,
      sym__constructor_name,
    STATE(3913), 1,
      sym__value_name,
    STATE(4476), 1,
      sym_attribute,
    STATE(18364), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(697), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3886), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3957), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [141640] = 29,
    ACTIONS(917), 1,
      anon_sym_LPAREN,
    ACTIONS(919), 1,
      anon_sym_LBRACK,
    ACTIONS(923), 1,
      anon_sym_LBRACE,
    ACTIONS(925), 1,
      anon_sym_object,
    ACTIONS(929), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(947), 1,
      anon_sym_new,
    ACTIONS(949), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(951), 1,
      anon_sym_begin,
    ACTIONS(953), 1,
      sym_ocamlyacc_value,
    ACTIONS(959), 1,
      aux_sym_number_token1,
    ACTIONS(961), 1,
      anon_sym_SQUOTE,
    ACTIONS(963), 1,
      anon_sym_DQUOTE,
    ACTIONS(965), 1,
      sym_prefix_operator,
    ACTIONS(969), 1,
      sym__uppercase_identifier,
    ACTIONS(971), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3111), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3113), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4575), 1,
      sym__lowercase_identifier,
    STATE(4477), 1,
      sym_attribute,
    STATE(4786), 1,
      sym__constructor_name,
    STATE(4812), 1,
      sym_parenthesized_operator,
    STATE(4817), 1,
      sym__value_name,
    STATE(4887), 1,
      sym__simple_expression,
    STATE(18603), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(921), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4865), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [141758] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [141828] = 29,
    ACTIONS(917), 1,
      anon_sym_LPAREN,
    ACTIONS(919), 1,
      anon_sym_LBRACK,
    ACTIONS(923), 1,
      anon_sym_LBRACE,
    ACTIONS(925), 1,
      anon_sym_object,
    ACTIONS(929), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(947), 1,
      anon_sym_new,
    ACTIONS(949), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(951), 1,
      anon_sym_begin,
    ACTIONS(953), 1,
      sym_ocamlyacc_value,
    ACTIONS(959), 1,
      aux_sym_number_token1,
    ACTIONS(961), 1,
      anon_sym_SQUOTE,
    ACTIONS(963), 1,
      anon_sym_DQUOTE,
    ACTIONS(965), 1,
      sym_prefix_operator,
    ACTIONS(969), 1,
      sym__uppercase_identifier,
    ACTIONS(971), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3111), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3113), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4575), 1,
      sym__lowercase_identifier,
    STATE(4479), 1,
      sym_attribute,
    STATE(4786), 1,
      sym__constructor_name,
    STATE(4801), 1,
      sym__simple_expression,
    STATE(4812), 1,
      sym_parenthesized_operator,
    STATE(4817), 1,
      sym__value_name,
    STATE(18603), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(921), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4865), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [141946] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4480), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [142016] = 29,
    ACTIONS(413), 1,
      anon_sym_LPAREN,
    ACTIONS(417), 1,
      anon_sym_LBRACK,
    ACTIONS(421), 1,
      anon_sym_LBRACE,
    ACTIONS(431), 1,
      anon_sym_object,
    ACTIONS(435), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(445), 1,
      anon_sym_new,
    ACTIONS(447), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(449), 1,
      anon_sym_begin,
    ACTIONS(451), 1,
      sym_ocamlyacc_value,
    ACTIONS(457), 1,
      aux_sym_number_token1,
    ACTIONS(459), 1,
      anon_sym_SQUOTE,
    ACTIONS(461), 1,
      anon_sym_DQUOTE,
    ACTIONS(463), 1,
      sym_prefix_operator,
    ACTIONS(469), 1,
      sym__uppercase_identifier,
    ACTIONS(473), 1,
      aux_sym_tag_token1,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3095), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3097), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3955), 1,
      sym__lowercase_identifier,
    STATE(4279), 1,
      sym_parenthesized_operator,
    STATE(4287), 1,
      sym__value_name,
    STATE(4340), 1,
      sym__simple_expression,
    STATE(4480), 1,
      sym__constructor_name,
    STATE(4481), 1,
      sym_attribute,
    STATE(20400), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(419), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4219), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4413), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [142134] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4482), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [142204] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3215), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4483), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [142333] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3231), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4484), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [142462] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3235), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4485), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [142591] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3173), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4486), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [142720] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8622), 33,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [142789] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3221), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4488), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [142918] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3203), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4489), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [143047] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4490), 1,
      sym_attribute,
    STATE(4632), 1,
      sym__attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(13987), 1,
      sym__binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [143176] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3139), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4491), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [143305] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5201), 1,
      sym__lowercase_identifier,
    ACTIONS(5203), 1,
      anon_sym_LPAREN,
    ACTIONS(5205), 1,
      anon_sym_LBRACK,
    ACTIONS(5209), 1,
      anon_sym_LBRACE,
    ACTIONS(5211), 1,
      anon_sym_POUND,
    ACTIONS(5213), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5215), 1,
      anon_sym_lazy,
    ACTIONS(5217), 1,
      anon_sym_begin,
    ACTIONS(5223), 1,
      aux_sym_number_token1,
    ACTIONS(5225), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5227), 1,
      anon_sym_SQUOTE,
    ACTIONS(5229), 1,
      anon_sym_DQUOTE,
    ACTIONS(5231), 1,
      sym__uppercase_identifier,
    ACTIONS(5233), 1,
      aux_sym_tag_token1,
    ACTIONS(8616), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8618), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8660), 1,
      anon_sym_rec,
    STATE(2455), 1,
      sym_tag,
    STATE(2456), 1,
      sym_constructor_path,
    STATE(2492), 1,
      sym__binding_pattern,
    STATE(4492), 1,
      sym_attribute,
    STATE(5443), 1,
      sym__signed_constant,
    STATE(5444), 1,
      sym__constructor_name,
    STATE(5626), 1,
      sym_array_binding_pattern,
    STATE(5663), 1,
      sym_list_binding_pattern,
    STATE(5664), 1,
      sym_record_binding_pattern,
    STATE(5725), 1,
      sym_parenthesized_operator,
    STATE(11779), 1,
      sym_let_binding,
    STATE(18726), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5207), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5523), 2,
      sym__constant,
      sym_signed_number,
    STATE(5445), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5668), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [143434] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3207), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4493), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [143563] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3143), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4494), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [143692] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3177), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4495), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [143821] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3233), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4496), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [143950] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3141), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4497), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [144079] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3135), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4498), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [144208] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6833), 1,
      sym__lowercase_identifier,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6851), 1,
      anon_sym_lazy,
    ACTIONS(6891), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8662), 1,
      anon_sym_RPAREN,
    STATE(3559), 1,
      sym_constructor_path,
    STATE(3561), 1,
      sym_tag,
    STATE(4499), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10358), 1,
      sym_parenthesized_operator,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(14252), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [144337] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3179), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4500), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [144466] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3191), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4501), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [144595] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3175), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4502), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [144724] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5075), 1,
      sym__lowercase_identifier,
    ACTIONS(5081), 1,
      anon_sym_LPAREN,
    ACTIONS(5083), 1,
      anon_sym_LBRACK,
    ACTIONS(5087), 1,
      anon_sym_LBRACE,
    ACTIONS(5089), 1,
      anon_sym_POUND,
    ACTIONS(5091), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5093), 1,
      anon_sym_lazy,
    ACTIONS(5095), 1,
      anon_sym_begin,
    ACTIONS(5101), 1,
      aux_sym_number_token1,
    ACTIONS(5103), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5105), 1,
      anon_sym_SQUOTE,
    ACTIONS(5107), 1,
      anon_sym_DQUOTE,
    ACTIONS(5109), 1,
      sym__uppercase_identifier,
    ACTIONS(5111), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7743), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7745), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2444), 1,
      sym_constructor_path,
    STATE(2445), 1,
      sym_tag,
    STATE(4503), 1,
      sym_attribute,
    STATE(4644), 1,
      sym__attribute,
    STATE(5315), 1,
      sym__signed_constant,
    STATE(5376), 1,
      sym__constructor_name,
    STATE(5453), 1,
      sym__binding_pattern,
    STATE(5475), 1,
      sym_record_binding_pattern,
    STATE(5534), 1,
      sym_parenthesized_operator,
    STATE(5538), 1,
      sym_list_binding_pattern,
    STATE(5553), 1,
      sym_array_binding_pattern,
    STATE(20406), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5085), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5356), 2,
      sym__constant,
      sym_signed_number,
    STATE(5423), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5483), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [144853] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(4504), 1,
      sym_attribute,
    STATE(4641), 1,
      sym__attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8882), 1,
      sym__binding_pattern,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [144982] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5075), 1,
      sym__lowercase_identifier,
    ACTIONS(5081), 1,
      anon_sym_LPAREN,
    ACTIONS(5083), 1,
      anon_sym_LBRACK,
    ACTIONS(5087), 1,
      anon_sym_LBRACE,
    ACTIONS(5089), 1,
      anon_sym_POUND,
    ACTIONS(5091), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5093), 1,
      anon_sym_lazy,
    ACTIONS(5095), 1,
      anon_sym_begin,
    ACTIONS(5101), 1,
      aux_sym_number_token1,
    ACTIONS(5103), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5105), 1,
      anon_sym_SQUOTE,
    ACTIONS(5107), 1,
      anon_sym_DQUOTE,
    ACTIONS(5109), 1,
      sym__uppercase_identifier,
    ACTIONS(5111), 1,
      aux_sym_tag_token1,
    ACTIONS(7743), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7745), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8664), 1,
      anon_sym_rec,
    STATE(2444), 1,
      sym_constructor_path,
    STATE(2445), 1,
      sym_tag,
    STATE(2483), 1,
      sym__binding_pattern,
    STATE(4505), 1,
      sym_attribute,
    STATE(5315), 1,
      sym__signed_constant,
    STATE(5376), 1,
      sym__constructor_name,
    STATE(5475), 1,
      sym_record_binding_pattern,
    STATE(5534), 1,
      sym_parenthesized_operator,
    STATE(5538), 1,
      sym_list_binding_pattern,
    STATE(5553), 1,
      sym_array_binding_pattern,
    STATE(11391), 1,
      sym_let_binding,
    STATE(20406), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5085), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5356), 2,
      sym__constant,
      sym_signed_number,
    STATE(5423), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5483), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [145111] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8226), 33,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [145180] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8666), 1,
      anon_sym_COLON,
    STATE(4507), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8548), 32,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [145251] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3219), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4508), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [145380] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6833), 1,
      sym__lowercase_identifier,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6851), 1,
      anon_sym_lazy,
    ACTIONS(6871), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8668), 1,
      anon_sym_RPAREN,
    STATE(3559), 1,
      sym_constructor_path,
    STATE(3561), 1,
      sym_tag,
    STATE(4509), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10358), 1,
      sym_parenthesized_operator,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(14364), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [145509] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3269), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4510), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [145638] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3211), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4511), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [145767] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3169), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4512), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [145896] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3185), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4513), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [146025] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3187), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4514), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [146154] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3205), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4515), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [146283] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3249), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4516), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [146412] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6833), 1,
      sym__lowercase_identifier,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6847), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6851), 1,
      anon_sym_lazy,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8670), 1,
      anon_sym_RPAREN,
    STATE(3559), 1,
      sym_constructor_path,
    STATE(3561), 1,
      sym_tag,
    STATE(4517), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10358), 1,
      sym_parenthesized_operator,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(14384), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [146541] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3199), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4518), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [146670] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3195), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4519), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [146799] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3255), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4520), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [146928] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3167), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4521), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [147057] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5201), 1,
      sym__lowercase_identifier,
    ACTIONS(5203), 1,
      anon_sym_LPAREN,
    ACTIONS(5205), 1,
      anon_sym_LBRACK,
    ACTIONS(5209), 1,
      anon_sym_LBRACE,
    ACTIONS(5211), 1,
      anon_sym_POUND,
    ACTIONS(5213), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5215), 1,
      anon_sym_lazy,
    ACTIONS(5217), 1,
      anon_sym_begin,
    ACTIONS(5223), 1,
      aux_sym_number_token1,
    ACTIONS(5225), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5227), 1,
      anon_sym_SQUOTE,
    ACTIONS(5229), 1,
      anon_sym_DQUOTE,
    ACTIONS(5231), 1,
      sym__uppercase_identifier,
    ACTIONS(5233), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(8616), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8618), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2455), 1,
      sym_tag,
    STATE(2456), 1,
      sym_constructor_path,
    STATE(4522), 1,
      sym_attribute,
    STATE(4630), 1,
      sym__attribute,
    STATE(5443), 1,
      sym__signed_constant,
    STATE(5444), 1,
      sym__constructor_name,
    STATE(5626), 1,
      sym_array_binding_pattern,
    STATE(5654), 1,
      sym__binding_pattern,
    STATE(5663), 1,
      sym_list_binding_pattern,
    STATE(5664), 1,
      sym_record_binding_pattern,
    STATE(5725), 1,
      sym_parenthesized_operator,
    STATE(18726), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5207), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5523), 2,
      sym__constant,
      sym_signed_number,
    STATE(5445), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5668), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [147186] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3171), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4523), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [147315] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5245), 1,
      sym__lowercase_identifier,
    ACTIONS(5247), 1,
      anon_sym_LPAREN,
    ACTIONS(5249), 1,
      anon_sym_LBRACK,
    ACTIONS(5253), 1,
      anon_sym_LBRACE,
    ACTIONS(5255), 1,
      anon_sym_POUND,
    ACTIONS(5257), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5259), 1,
      anon_sym_lazy,
    ACTIONS(5261), 1,
      anon_sym_begin,
    ACTIONS(5267), 1,
      aux_sym_number_token1,
    ACTIONS(5269), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5271), 1,
      anon_sym_SQUOTE,
    ACTIONS(5273), 1,
      anon_sym_DQUOTE,
    ACTIONS(5275), 1,
      sym__uppercase_identifier,
    ACTIONS(5277), 1,
      aux_sym_tag_token1,
    ACTIONS(8610), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8612), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8672), 1,
      anon_sym_rec,
    STATE(2458), 1,
      sym_tag,
    STATE(2459), 1,
      sym_constructor_path,
    STATE(2493), 1,
      sym__binding_pattern,
    STATE(4524), 1,
      sym_attribute,
    STATE(5482), 1,
      sym__signed_constant,
    STATE(5554), 1,
      sym__constructor_name,
    STATE(5674), 1,
      sym_parenthesized_operator,
    STATE(5721), 1,
      sym_array_binding_pattern,
    STATE(5723), 1,
      sym_list_binding_pattern,
    STATE(5729), 1,
      sym_record_binding_pattern,
    STATE(11839), 1,
      sym_let_binding,
    STATE(19030), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5251), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5522), 2,
      sym__constant,
      sym_signed_number,
    STATE(5551), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5731), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [147444] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6833), 1,
      sym__lowercase_identifier,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6851), 1,
      anon_sym_lazy,
    ACTIONS(6881), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8674), 1,
      anon_sym_RPAREN,
    STATE(3559), 1,
      sym_constructor_path,
    STATE(3561), 1,
      sym_tag,
    STATE(4525), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10358), 1,
      sym_parenthesized_operator,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(14183), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [147573] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3137), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4526), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [147702] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5157), 1,
      sym__lowercase_identifier,
    ACTIONS(5159), 1,
      anon_sym_LPAREN,
    ACTIONS(5161), 1,
      anon_sym_LBRACK,
    ACTIONS(5165), 1,
      anon_sym_LBRACE,
    ACTIONS(5167), 1,
      anon_sym_POUND,
    ACTIONS(5169), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5171), 1,
      anon_sym_lazy,
    ACTIONS(5173), 1,
      anon_sym_begin,
    ACTIONS(5179), 1,
      aux_sym_number_token1,
    ACTIONS(5181), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5183), 1,
      anon_sym_SQUOTE,
    ACTIONS(5185), 1,
      anon_sym_DQUOTE,
    ACTIONS(5187), 1,
      sym__uppercase_identifier,
    ACTIONS(5189), 1,
      aux_sym_tag_token1,
    ACTIONS(7737), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7739), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8676), 1,
      anon_sym_rec,
    STATE(2451), 1,
      sym_tag,
    STATE(2453), 1,
      sym_constructor_path,
    STATE(2480), 1,
      sym__binding_pattern,
    STATE(4527), 1,
      sym_attribute,
    STATE(5363), 1,
      sym__signed_constant,
    STATE(5364), 1,
      sym__constructor_name,
    STATE(5498), 1,
      sym_parenthesized_operator,
    STATE(5506), 1,
      sym_record_binding_pattern,
    STATE(5514), 1,
      sym_array_binding_pattern,
    STATE(5515), 1,
      sym_list_binding_pattern,
    STATE(11253), 1,
      sym_let_binding,
    STATE(20448), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5163), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5408), 2,
      sym__constant,
      sym_signed_number,
    STATE(5367), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5519), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [147831] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3209), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4528), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [147960] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3229), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4529), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [148089] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5157), 1,
      sym__lowercase_identifier,
    ACTIONS(5159), 1,
      anon_sym_LPAREN,
    ACTIONS(5161), 1,
      anon_sym_LBRACK,
    ACTIONS(5165), 1,
      anon_sym_LBRACE,
    ACTIONS(5167), 1,
      anon_sym_POUND,
    ACTIONS(5169), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5171), 1,
      anon_sym_lazy,
    ACTIONS(5173), 1,
      anon_sym_begin,
    ACTIONS(5179), 1,
      aux_sym_number_token1,
    ACTIONS(5181), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5183), 1,
      anon_sym_SQUOTE,
    ACTIONS(5185), 1,
      anon_sym_DQUOTE,
    ACTIONS(5187), 1,
      sym__uppercase_identifier,
    ACTIONS(5189), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7737), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7739), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2451), 1,
      sym_tag,
    STATE(2453), 1,
      sym_constructor_path,
    STATE(4530), 1,
      sym_attribute,
    STATE(4647), 1,
      sym__attribute,
    STATE(5363), 1,
      sym__signed_constant,
    STATE(5364), 1,
      sym__constructor_name,
    STATE(5461), 1,
      sym__binding_pattern,
    STATE(5498), 1,
      sym_parenthesized_operator,
    STATE(5506), 1,
      sym_record_binding_pattern,
    STATE(5514), 1,
      sym_array_binding_pattern,
    STATE(5515), 1,
      sym_list_binding_pattern,
    STATE(20448), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5163), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5408), 2,
      sym__constant,
      sym_signed_number,
    STATE(5367), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5519), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [148218] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8678), 1,
      anon_sym_COLON,
    STATE(4531), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8548), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [148289] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3183), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4532), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [148418] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3217), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4533), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [148547] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3251), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4534), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [148676] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5139), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6833), 1,
      sym__lowercase_identifier,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6851), 1,
      anon_sym_lazy,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8680), 1,
      anon_sym_RPAREN,
    STATE(3559), 1,
      sym_constructor_path,
    STATE(3561), 1,
      sym_tag,
    STATE(4535), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10358), 1,
      sym_parenthesized_operator,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(14171), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [148805] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3201), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4536), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [148934] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5245), 1,
      sym__lowercase_identifier,
    ACTIONS(5247), 1,
      anon_sym_LPAREN,
    ACTIONS(5249), 1,
      anon_sym_LBRACK,
    ACTIONS(5253), 1,
      anon_sym_LBRACE,
    ACTIONS(5255), 1,
      anon_sym_POUND,
    ACTIONS(5257), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5259), 1,
      anon_sym_lazy,
    ACTIONS(5261), 1,
      anon_sym_begin,
    ACTIONS(5267), 1,
      aux_sym_number_token1,
    ACTIONS(5269), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5271), 1,
      anon_sym_SQUOTE,
    ACTIONS(5273), 1,
      anon_sym_DQUOTE,
    ACTIONS(5275), 1,
      sym__uppercase_identifier,
    ACTIONS(5277), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(8610), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8612), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2458), 1,
      sym_tag,
    STATE(2459), 1,
      sym_constructor_path,
    STATE(4537), 1,
      sym_attribute,
    STATE(4648), 1,
      sym__attribute,
    STATE(5482), 1,
      sym__signed_constant,
    STATE(5554), 1,
      sym__constructor_name,
    STATE(5674), 1,
      sym_parenthesized_operator,
    STATE(5717), 1,
      sym__binding_pattern,
    STATE(5721), 1,
      sym_array_binding_pattern,
    STATE(5723), 1,
      sym_list_binding_pattern,
    STATE(5729), 1,
      sym_record_binding_pattern,
    STATE(19030), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5251), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5522), 2,
      sym__constant,
      sym_signed_number,
    STATE(5551), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5731), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [149063] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3213), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4538), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [149192] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3189), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4539), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [149321] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6833), 1,
      sym__lowercase_identifier,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6851), 1,
      anon_sym_lazy,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    STATE(3559), 1,
      sym_constructor_path,
    STATE(3561), 1,
      sym_tag,
    STATE(4540), 1,
      sym_attribute,
    STATE(4657), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10358), 1,
      sym_parenthesized_operator,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13314), 1,
      sym__binding_pattern,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [149450] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3223), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4541), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [149579] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4542), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8622), 32,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [149648] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    ACTIONS(8682), 1,
      anon_sym_rec,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4543), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14930), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [149777] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6833), 1,
      sym__lowercase_identifier,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6851), 1,
      anon_sym_lazy,
    ACTIONS(6861), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8684), 1,
      anon_sym_RPAREN,
    STATE(3559), 1,
      sym_constructor_path,
    STATE(3561), 1,
      sym_tag,
    STATE(4544), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10358), 1,
      sym_parenthesized_operator,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(14381), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [149906] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3225), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4545), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [150035] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4546), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8226), 32,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [150104] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3257), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4547), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [150233] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1873), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6833), 1,
      sym__lowercase_identifier,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6851), 1,
      anon_sym_lazy,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8686), 1,
      anon_sym_RPAREN,
    STATE(3559), 1,
      sym_constructor_path,
    STATE(3561), 1,
      sym_tag,
    STATE(4548), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10358), 1,
      sym_parenthesized_operator,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(14393), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [150362] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3193), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4549), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [150491] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3253), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4550), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [150620] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4551), 1,
      sym_attribute,
    STATE(4635), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13314), 1,
      sym__binding_pattern,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [150749] = 35,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3197), 1,
      anon_sym_RPAREN,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4552), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [150878] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    ACTIONS(8688), 1,
      anon_sym_PIPE_RBRACK,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4553), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(14150), 1,
      sym__binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [151004] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8622), 32,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [151072] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    ACTIONS(8690), 1,
      anon_sym_PIPE_RBRACK,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4555), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(14150), 1,
      sym__binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [151198] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5075), 1,
      sym__lowercase_identifier,
    ACTIONS(5081), 1,
      anon_sym_LPAREN,
    ACTIONS(5083), 1,
      anon_sym_LBRACK,
    ACTIONS(5087), 1,
      anon_sym_LBRACE,
    ACTIONS(5089), 1,
      anon_sym_POUND,
    ACTIONS(5091), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5093), 1,
      anon_sym_lazy,
    ACTIONS(5095), 1,
      anon_sym_begin,
    ACTIONS(5101), 1,
      aux_sym_number_token1,
    ACTIONS(5103), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5105), 1,
      anon_sym_SQUOTE,
    ACTIONS(5107), 1,
      anon_sym_DQUOTE,
    ACTIONS(5109), 1,
      sym__uppercase_identifier,
    ACTIONS(5111), 1,
      aux_sym_tag_token1,
    ACTIONS(7743), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7745), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2444), 1,
      sym_constructor_path,
    STATE(2445), 1,
      sym_tag,
    STATE(2483), 1,
      sym__binding_pattern,
    STATE(4556), 1,
      sym_attribute,
    STATE(5315), 1,
      sym__signed_constant,
    STATE(5376), 1,
      sym__constructor_name,
    STATE(5475), 1,
      sym_record_binding_pattern,
    STATE(5534), 1,
      sym_parenthesized_operator,
    STATE(5538), 1,
      sym_list_binding_pattern,
    STATE(5553), 1,
      sym_array_binding_pattern,
    STATE(11408), 1,
      sym_let_binding,
    STATE(20406), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5085), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5356), 2,
      sym__constant,
      sym_signed_number,
    STATE(5423), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5483), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [151324] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5201), 1,
      sym__lowercase_identifier,
    ACTIONS(5203), 1,
      anon_sym_LPAREN,
    ACTIONS(5205), 1,
      anon_sym_LBRACK,
    ACTIONS(5209), 1,
      anon_sym_LBRACE,
    ACTIONS(5211), 1,
      anon_sym_POUND,
    ACTIONS(5213), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5215), 1,
      anon_sym_lazy,
    ACTIONS(5217), 1,
      anon_sym_begin,
    ACTIONS(5223), 1,
      aux_sym_number_token1,
    ACTIONS(5225), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5227), 1,
      anon_sym_SQUOTE,
    ACTIONS(5229), 1,
      anon_sym_DQUOTE,
    ACTIONS(5231), 1,
      sym__uppercase_identifier,
    ACTIONS(5233), 1,
      aux_sym_tag_token1,
    ACTIONS(8616), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8618), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2455), 1,
      sym_tag,
    STATE(2456), 1,
      sym_constructor_path,
    STATE(2492), 1,
      sym__binding_pattern,
    STATE(4557), 1,
      sym_attribute,
    STATE(5443), 1,
      sym__signed_constant,
    STATE(5444), 1,
      sym__constructor_name,
    STATE(5626), 1,
      sym_array_binding_pattern,
    STATE(5663), 1,
      sym_list_binding_pattern,
    STATE(5664), 1,
      sym_record_binding_pattern,
    STATE(5725), 1,
      sym_parenthesized_operator,
    STATE(11783), 1,
      sym_let_binding,
    STATE(18726), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5207), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5523), 2,
      sym__constant,
      sym_signed_number,
    STATE(5445), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5668), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [151450] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5075), 1,
      sym__lowercase_identifier,
    ACTIONS(5081), 1,
      anon_sym_LPAREN,
    ACTIONS(5083), 1,
      anon_sym_LBRACK,
    ACTIONS(5087), 1,
      anon_sym_LBRACE,
    ACTIONS(5089), 1,
      anon_sym_POUND,
    ACTIONS(5091), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5093), 1,
      anon_sym_lazy,
    ACTIONS(5095), 1,
      anon_sym_begin,
    ACTIONS(5101), 1,
      aux_sym_number_token1,
    ACTIONS(5103), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5105), 1,
      anon_sym_SQUOTE,
    ACTIONS(5107), 1,
      anon_sym_DQUOTE,
    ACTIONS(5109), 1,
      sym__uppercase_identifier,
    ACTIONS(5111), 1,
      aux_sym_tag_token1,
    ACTIONS(7743), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7745), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2444), 1,
      sym_constructor_path,
    STATE(2445), 1,
      sym_tag,
    STATE(2483), 1,
      sym__binding_pattern,
    STATE(4558), 1,
      sym_attribute,
    STATE(5315), 1,
      sym__signed_constant,
    STATE(5376), 1,
      sym__constructor_name,
    STATE(5475), 1,
      sym_record_binding_pattern,
    STATE(5534), 1,
      sym_parenthesized_operator,
    STATE(5538), 1,
      sym_list_binding_pattern,
    STATE(5553), 1,
      sym_array_binding_pattern,
    STATE(11621), 1,
      sym_let_binding,
    STATE(20406), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5085), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5356), 2,
      sym__constant,
      sym_signed_number,
    STATE(5423), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5483), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [151576] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4559), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14578), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [151702] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8692), 1,
      anon_sym_COLON,
    STATE(4560), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8548), 31,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [151772] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    ACTIONS(8694), 1,
      anon_sym_RBRACK,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4561), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(13918), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [151898] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    ACTIONS(8696), 1,
      anon_sym_PIPE_RBRACK,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4562), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(14150), 1,
      sym__binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [152024] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    ACTIONS(8698), 1,
      anon_sym_RBRACK,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4563), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(13918), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [152150] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    ACTIONS(8700), 1,
      anon_sym_PIPE_RBRACK,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4564), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(14150), 1,
      sym__binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [152276] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    ACTIONS(8702), 1,
      anon_sym_RBRACK,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4565), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(13918), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [152402] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4566), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(16001), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [152528] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5201), 1,
      sym__lowercase_identifier,
    ACTIONS(5203), 1,
      anon_sym_LPAREN,
    ACTIONS(5205), 1,
      anon_sym_LBRACK,
    ACTIONS(5209), 1,
      anon_sym_LBRACE,
    ACTIONS(5211), 1,
      anon_sym_POUND,
    ACTIONS(5213), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5215), 1,
      anon_sym_lazy,
    ACTIONS(5217), 1,
      anon_sym_begin,
    ACTIONS(5223), 1,
      aux_sym_number_token1,
    ACTIONS(5225), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5227), 1,
      anon_sym_SQUOTE,
    ACTIONS(5229), 1,
      anon_sym_DQUOTE,
    ACTIONS(5231), 1,
      sym__uppercase_identifier,
    ACTIONS(5233), 1,
      aux_sym_tag_token1,
    ACTIONS(8616), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8618), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2455), 1,
      sym_tag,
    STATE(2456), 1,
      sym_constructor_path,
    STATE(2492), 1,
      sym__binding_pattern,
    STATE(4567), 1,
      sym_attribute,
    STATE(5443), 1,
      sym__signed_constant,
    STATE(5444), 1,
      sym__constructor_name,
    STATE(5626), 1,
      sym_array_binding_pattern,
    STATE(5663), 1,
      sym_list_binding_pattern,
    STATE(5664), 1,
      sym_record_binding_pattern,
    STATE(5725), 1,
      sym_parenthesized_operator,
    STATE(11779), 1,
      sym_let_binding,
    STATE(18726), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5207), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5523), 2,
      sym__constant,
      sym_signed_number,
    STATE(5445), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5668), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [152654] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5201), 1,
      sym__lowercase_identifier,
    ACTIONS(5203), 1,
      anon_sym_LPAREN,
    ACTIONS(5205), 1,
      anon_sym_LBRACK,
    ACTIONS(5209), 1,
      anon_sym_LBRACE,
    ACTIONS(5211), 1,
      anon_sym_POUND,
    ACTIONS(5213), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5215), 1,
      anon_sym_lazy,
    ACTIONS(5217), 1,
      anon_sym_begin,
    ACTIONS(5223), 1,
      aux_sym_number_token1,
    ACTIONS(5225), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5227), 1,
      anon_sym_SQUOTE,
    ACTIONS(5229), 1,
      anon_sym_DQUOTE,
    ACTIONS(5231), 1,
      sym__uppercase_identifier,
    ACTIONS(5233), 1,
      aux_sym_tag_token1,
    ACTIONS(8616), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8618), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2455), 1,
      sym_tag,
    STATE(2456), 1,
      sym_constructor_path,
    STATE(2492), 1,
      sym__binding_pattern,
    STATE(4568), 1,
      sym_attribute,
    STATE(5443), 1,
      sym__signed_constant,
    STATE(5444), 1,
      sym__constructor_name,
    STATE(5626), 1,
      sym_array_binding_pattern,
    STATE(5663), 1,
      sym_list_binding_pattern,
    STATE(5664), 1,
      sym_record_binding_pattern,
    STATE(5725), 1,
      sym_parenthesized_operator,
    STATE(11892), 1,
      sym_let_binding,
    STATE(18726), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5207), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5523), 2,
      sym__constant,
      sym_signed_number,
    STATE(5445), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5668), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [152780] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    ACTIONS(8704), 1,
      anon_sym_RBRACK,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4569), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13728), 1,
      sym__binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [152906] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    ACTIONS(8706), 1,
      anon_sym_PIPE_RBRACK,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4570), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13721), 1,
      sym__binding_pattern,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [153032] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    ACTIONS(8708), 1,
      anon_sym_RBRACK,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4571), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(13918), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [153158] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    ACTIONS(8710), 1,
      anon_sym_RBRACK,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4572), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(13918), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [153284] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    ACTIONS(8712), 1,
      anon_sym_PIPE_RBRACK,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4573), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(14150), 1,
      sym__binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [153410] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    ACTIONS(8714), 1,
      anon_sym_PIPE_RBRACK,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4574), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(14150), 1,
      sym__binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [153536] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4575), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8226), 32,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [153604] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5075), 1,
      sym__lowercase_identifier,
    ACTIONS(5081), 1,
      anon_sym_LPAREN,
    ACTIONS(5083), 1,
      anon_sym_LBRACK,
    ACTIONS(5087), 1,
      anon_sym_LBRACE,
    ACTIONS(5089), 1,
      anon_sym_POUND,
    ACTIONS(5091), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5093), 1,
      anon_sym_lazy,
    ACTIONS(5095), 1,
      anon_sym_begin,
    ACTIONS(5101), 1,
      aux_sym_number_token1,
    ACTIONS(5103), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5105), 1,
      anon_sym_SQUOTE,
    ACTIONS(5107), 1,
      anon_sym_DQUOTE,
    ACTIONS(5109), 1,
      sym__uppercase_identifier,
    ACTIONS(5111), 1,
      aux_sym_tag_token1,
    ACTIONS(7743), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7745), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2444), 1,
      sym_constructor_path,
    STATE(2445), 1,
      sym_tag,
    STATE(2483), 1,
      sym__binding_pattern,
    STATE(4576), 1,
      sym_attribute,
    STATE(5315), 1,
      sym__signed_constant,
    STATE(5376), 1,
      sym__constructor_name,
    STATE(5475), 1,
      sym_record_binding_pattern,
    STATE(5534), 1,
      sym_parenthesized_operator,
    STATE(5538), 1,
      sym_list_binding_pattern,
    STATE(5553), 1,
      sym_array_binding_pattern,
    STATE(11391), 1,
      sym_let_binding,
    STATE(20406), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5085), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5356), 2,
      sym__constant,
      sym_signed_number,
    STATE(5423), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5483), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [153730] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    ACTIONS(8716), 1,
      anon_sym_RBRACK,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4577), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13693), 1,
      sym__binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [153856] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    ACTIONS(8718), 1,
      anon_sym_PIPE_RBRACK,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4578), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13696), 1,
      sym__binding_pattern,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [153982] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    ACTIONS(8720), 1,
      anon_sym_RBRACK,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4579), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13691), 1,
      sym__binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [154108] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5157), 1,
      sym__lowercase_identifier,
    ACTIONS(5159), 1,
      anon_sym_LPAREN,
    ACTIONS(5161), 1,
      anon_sym_LBRACK,
    ACTIONS(5165), 1,
      anon_sym_LBRACE,
    ACTIONS(5167), 1,
      anon_sym_POUND,
    ACTIONS(5169), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5171), 1,
      anon_sym_lazy,
    ACTIONS(5173), 1,
      anon_sym_begin,
    ACTIONS(5179), 1,
      aux_sym_number_token1,
    ACTIONS(5181), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5183), 1,
      anon_sym_SQUOTE,
    ACTIONS(5185), 1,
      anon_sym_DQUOTE,
    ACTIONS(5187), 1,
      sym__uppercase_identifier,
    ACTIONS(5189), 1,
      aux_sym_tag_token1,
    ACTIONS(7737), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7739), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2451), 1,
      sym_tag,
    STATE(2453), 1,
      sym_constructor_path,
    STATE(2480), 1,
      sym__binding_pattern,
    STATE(4580), 1,
      sym_attribute,
    STATE(5363), 1,
      sym__signed_constant,
    STATE(5364), 1,
      sym__constructor_name,
    STATE(5498), 1,
      sym_parenthesized_operator,
    STATE(5506), 1,
      sym_record_binding_pattern,
    STATE(5514), 1,
      sym_array_binding_pattern,
    STATE(5515), 1,
      sym_list_binding_pattern,
    STATE(11621), 1,
      sym_let_binding,
    STATE(20448), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5163), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5408), 2,
      sym__constant,
      sym_signed_number,
    STATE(5367), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5519), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [154234] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    ACTIONS(8722), 1,
      anon_sym_RBRACK,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4581), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(13918), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [154360] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    ACTIONS(8724), 1,
      anon_sym_PIPE_RBRACK,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4582), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(14150), 1,
      sym__binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [154486] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    ACTIONS(8726), 1,
      anon_sym_PIPE_RBRACK,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4583), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13527), 1,
      sym__binding_pattern,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [154612] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    ACTIONS(8728), 1,
      anon_sym_RBRACK,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4584), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(13918), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [154738] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    ACTIONS(8730), 1,
      anon_sym_RBRACK,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4585), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13529), 1,
      sym__binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [154864] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    ACTIONS(8732), 1,
      anon_sym_PIPE_RBRACK,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4586), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(14150), 1,
      sym__binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [154990] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4587), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14930), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [155116] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5075), 1,
      sym__lowercase_identifier,
    ACTIONS(5081), 1,
      anon_sym_LPAREN,
    ACTIONS(5083), 1,
      anon_sym_LBRACK,
    ACTIONS(5087), 1,
      anon_sym_LBRACE,
    ACTIONS(5089), 1,
      anon_sym_POUND,
    ACTIONS(5091), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5093), 1,
      anon_sym_lazy,
    ACTIONS(5095), 1,
      anon_sym_begin,
    ACTIONS(5101), 1,
      aux_sym_number_token1,
    ACTIONS(5103), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5105), 1,
      anon_sym_SQUOTE,
    ACTIONS(5107), 1,
      anon_sym_DQUOTE,
    ACTIONS(5109), 1,
      sym__uppercase_identifier,
    ACTIONS(5111), 1,
      aux_sym_tag_token1,
    ACTIONS(7743), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7745), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2444), 1,
      sym_constructor_path,
    STATE(2445), 1,
      sym_tag,
    STATE(2483), 1,
      sym__binding_pattern,
    STATE(4588), 1,
      sym_attribute,
    STATE(5315), 1,
      sym__signed_constant,
    STATE(5376), 1,
      sym__constructor_name,
    STATE(5475), 1,
      sym_record_binding_pattern,
    STATE(5534), 1,
      sym_parenthesized_operator,
    STATE(5538), 1,
      sym_list_binding_pattern,
    STATE(5553), 1,
      sym_array_binding_pattern,
    STATE(11276), 1,
      sym_let_binding,
    STATE(20406), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5085), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5356), 2,
      sym__constant,
      sym_signed_number,
    STATE(5423), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5483), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [155242] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5245), 1,
      sym__lowercase_identifier,
    ACTIONS(5247), 1,
      anon_sym_LPAREN,
    ACTIONS(5249), 1,
      anon_sym_LBRACK,
    ACTIONS(5253), 1,
      anon_sym_LBRACE,
    ACTIONS(5255), 1,
      anon_sym_POUND,
    ACTIONS(5257), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5259), 1,
      anon_sym_lazy,
    ACTIONS(5261), 1,
      anon_sym_begin,
    ACTIONS(5267), 1,
      aux_sym_number_token1,
    ACTIONS(5269), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5271), 1,
      anon_sym_SQUOTE,
    ACTIONS(5273), 1,
      anon_sym_DQUOTE,
    ACTIONS(5275), 1,
      sym__uppercase_identifier,
    ACTIONS(5277), 1,
      aux_sym_tag_token1,
    ACTIONS(8610), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8612), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2458), 1,
      sym_tag,
    STATE(2459), 1,
      sym_constructor_path,
    STATE(2493), 1,
      sym__binding_pattern,
    STATE(4589), 1,
      sym_attribute,
    STATE(5482), 1,
      sym__signed_constant,
    STATE(5554), 1,
      sym__constructor_name,
    STATE(5674), 1,
      sym_parenthesized_operator,
    STATE(5721), 1,
      sym_array_binding_pattern,
    STATE(5723), 1,
      sym_list_binding_pattern,
    STATE(5729), 1,
      sym_record_binding_pattern,
    STATE(11839), 1,
      sym_let_binding,
    STATE(19030), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5251), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5522), 2,
      sym__constant,
      sym_signed_number,
    STATE(5551), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5731), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [155368] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    ACTIONS(8734), 1,
      anon_sym_PIPE_RBRACK,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4590), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(14150), 1,
      sym__binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [155494] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    ACTIONS(8736), 1,
      anon_sym_RBRACK,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4591), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(13918), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [155620] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(2684), 1,
      sym__binding_pattern,
    STATE(4592), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(14512), 1,
      sym_let_binding,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [155746] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    ACTIONS(8738), 1,
      anon_sym_PIPE_RBRACK,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4593), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(14150), 1,
      sym__binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [155872] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    ACTIONS(8740), 1,
      anon_sym_RBRACK,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4594), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(13918), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [155998] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5157), 1,
      sym__lowercase_identifier,
    ACTIONS(5159), 1,
      anon_sym_LPAREN,
    ACTIONS(5161), 1,
      anon_sym_LBRACK,
    ACTIONS(5165), 1,
      anon_sym_LBRACE,
    ACTIONS(5167), 1,
      anon_sym_POUND,
    ACTIONS(5169), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5171), 1,
      anon_sym_lazy,
    ACTIONS(5173), 1,
      anon_sym_begin,
    ACTIONS(5179), 1,
      aux_sym_number_token1,
    ACTIONS(5181), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5183), 1,
      anon_sym_SQUOTE,
    ACTIONS(5185), 1,
      anon_sym_DQUOTE,
    ACTIONS(5187), 1,
      sym__uppercase_identifier,
    ACTIONS(5189), 1,
      aux_sym_tag_token1,
    ACTIONS(7737), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7739), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2451), 1,
      sym_tag,
    STATE(2453), 1,
      sym_constructor_path,
    STATE(2480), 1,
      sym__binding_pattern,
    STATE(4595), 1,
      sym_attribute,
    STATE(5363), 1,
      sym__signed_constant,
    STATE(5364), 1,
      sym__constructor_name,
    STATE(5498), 1,
      sym_parenthesized_operator,
    STATE(5506), 1,
      sym_record_binding_pattern,
    STATE(5514), 1,
      sym_array_binding_pattern,
    STATE(5515), 1,
      sym_list_binding_pattern,
    STATE(11253), 1,
      sym_let_binding,
    STATE(20448), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5163), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5408), 2,
      sym__constant,
      sym_signed_number,
    STATE(5367), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5519), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [156124] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5157), 1,
      sym__lowercase_identifier,
    ACTIONS(5159), 1,
      anon_sym_LPAREN,
    ACTIONS(5161), 1,
      anon_sym_LBRACK,
    ACTIONS(5165), 1,
      anon_sym_LBRACE,
    ACTIONS(5167), 1,
      anon_sym_POUND,
    ACTIONS(5169), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5171), 1,
      anon_sym_lazy,
    ACTIONS(5173), 1,
      anon_sym_begin,
    ACTIONS(5179), 1,
      aux_sym_number_token1,
    ACTIONS(5181), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5183), 1,
      anon_sym_SQUOTE,
    ACTIONS(5185), 1,
      anon_sym_DQUOTE,
    ACTIONS(5187), 1,
      sym__uppercase_identifier,
    ACTIONS(5189), 1,
      aux_sym_tag_token1,
    ACTIONS(7737), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7739), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2451), 1,
      sym_tag,
    STATE(2453), 1,
      sym_constructor_path,
    STATE(2480), 1,
      sym__binding_pattern,
    STATE(4596), 1,
      sym_attribute,
    STATE(5363), 1,
      sym__signed_constant,
    STATE(5364), 1,
      sym__constructor_name,
    STATE(5498), 1,
      sym_parenthesized_operator,
    STATE(5506), 1,
      sym_record_binding_pattern,
    STATE(5514), 1,
      sym_array_binding_pattern,
    STATE(5515), 1,
      sym_list_binding_pattern,
    STATE(11570), 1,
      sym_let_binding,
    STATE(20448), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5163), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5408), 2,
      sym__constant,
      sym_signed_number,
    STATE(5367), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5519), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [156250] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    ACTIONS(8742), 1,
      anon_sym_RBRACK,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4597), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(13828), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [156376] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    ACTIONS(8744), 1,
      anon_sym_PIPE_RBRACK,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4598), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13807), 1,
      sym__binding_pattern,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [156502] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    ACTIONS(8746), 1,
      anon_sym_RBRACK,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4599), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(13918), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [156628] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    ACTIONS(8748), 1,
      anon_sym_PIPE_RBRACK,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4600), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13800), 1,
      sym__binding_pattern,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [156754] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5245), 1,
      sym__lowercase_identifier,
    ACTIONS(5247), 1,
      anon_sym_LPAREN,
    ACTIONS(5249), 1,
      anon_sym_LBRACK,
    ACTIONS(5253), 1,
      anon_sym_LBRACE,
    ACTIONS(5255), 1,
      anon_sym_POUND,
    ACTIONS(5257), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5259), 1,
      anon_sym_lazy,
    ACTIONS(5261), 1,
      anon_sym_begin,
    ACTIONS(5267), 1,
      aux_sym_number_token1,
    ACTIONS(5269), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5271), 1,
      anon_sym_SQUOTE,
    ACTIONS(5273), 1,
      anon_sym_DQUOTE,
    ACTIONS(5275), 1,
      sym__uppercase_identifier,
    ACTIONS(5277), 1,
      aux_sym_tag_token1,
    ACTIONS(8610), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8612), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2458), 1,
      sym_tag,
    STATE(2459), 1,
      sym_constructor_path,
    STATE(2493), 1,
      sym__binding_pattern,
    STATE(4601), 1,
      sym_attribute,
    STATE(5482), 1,
      sym__signed_constant,
    STATE(5554), 1,
      sym__constructor_name,
    STATE(5674), 1,
      sym_parenthesized_operator,
    STATE(5721), 1,
      sym_array_binding_pattern,
    STATE(5723), 1,
      sym_list_binding_pattern,
    STATE(5729), 1,
      sym_record_binding_pattern,
    STATE(11763), 1,
      sym_let_binding,
    STATE(19030), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5251), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5522), 2,
      sym__constant,
      sym_signed_number,
    STATE(5551), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5731), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [156880] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4602), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8622), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [156948] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    ACTIONS(8750), 1,
      anon_sym_PIPE_RBRACK,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4603), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(14150), 1,
      sym__binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [157074] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    ACTIONS(8752), 1,
      anon_sym_PIPE_RBRACK,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4604), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(14150), 1,
      sym__binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [157200] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    ACTIONS(8754), 1,
      anon_sym_RBRACK,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4605), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13496), 1,
      sym__binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [157326] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    ACTIONS(8756), 1,
      anon_sym_PIPE_RBRACK,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4606), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(14150), 1,
      sym__binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [157452] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5245), 1,
      sym__lowercase_identifier,
    ACTIONS(5247), 1,
      anon_sym_LPAREN,
    ACTIONS(5249), 1,
      anon_sym_LBRACK,
    ACTIONS(5253), 1,
      anon_sym_LBRACE,
    ACTIONS(5255), 1,
      anon_sym_POUND,
    ACTIONS(5257), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5259), 1,
      anon_sym_lazy,
    ACTIONS(5261), 1,
      anon_sym_begin,
    ACTIONS(5267), 1,
      aux_sym_number_token1,
    ACTIONS(5269), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5271), 1,
      anon_sym_SQUOTE,
    ACTIONS(5273), 1,
      anon_sym_DQUOTE,
    ACTIONS(5275), 1,
      sym__uppercase_identifier,
    ACTIONS(5277), 1,
      aux_sym_tag_token1,
    ACTIONS(8610), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8612), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2458), 1,
      sym_tag,
    STATE(2459), 1,
      sym_constructor_path,
    STATE(2493), 1,
      sym__binding_pattern,
    STATE(4607), 1,
      sym_attribute,
    STATE(5482), 1,
      sym__signed_constant,
    STATE(5554), 1,
      sym__constructor_name,
    STATE(5674), 1,
      sym_parenthesized_operator,
    STATE(5721), 1,
      sym_array_binding_pattern,
    STATE(5723), 1,
      sym_list_binding_pattern,
    STATE(5729), 1,
      sym_record_binding_pattern,
    STATE(11621), 1,
      sym_let_binding,
    STATE(19030), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5251), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5522), 2,
      sym__constant,
      sym_signed_number,
    STATE(5551), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5731), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [157578] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    ACTIONS(8758), 1,
      anon_sym_PIPE_RBRACK,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4608), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(14150), 1,
      sym__binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [157704] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5201), 1,
      sym__lowercase_identifier,
    ACTIONS(5203), 1,
      anon_sym_LPAREN,
    ACTIONS(5205), 1,
      anon_sym_LBRACK,
    ACTIONS(5209), 1,
      anon_sym_LBRACE,
    ACTIONS(5211), 1,
      anon_sym_POUND,
    ACTIONS(5213), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5215), 1,
      anon_sym_lazy,
    ACTIONS(5217), 1,
      anon_sym_begin,
    ACTIONS(5223), 1,
      aux_sym_number_token1,
    ACTIONS(5225), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5227), 1,
      anon_sym_SQUOTE,
    ACTIONS(5229), 1,
      anon_sym_DQUOTE,
    ACTIONS(5231), 1,
      sym__uppercase_identifier,
    ACTIONS(5233), 1,
      aux_sym_tag_token1,
    ACTIONS(8616), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8618), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2455), 1,
      sym_tag,
    STATE(2456), 1,
      sym_constructor_path,
    STATE(2492), 1,
      sym__binding_pattern,
    STATE(4609), 1,
      sym_attribute,
    STATE(5443), 1,
      sym__signed_constant,
    STATE(5444), 1,
      sym__constructor_name,
    STATE(5626), 1,
      sym_array_binding_pattern,
    STATE(5663), 1,
      sym_list_binding_pattern,
    STATE(5664), 1,
      sym_record_binding_pattern,
    STATE(5725), 1,
      sym_parenthesized_operator,
    STATE(11621), 1,
      sym_let_binding,
    STATE(18726), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5207), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5523), 2,
      sym__constant,
      sym_signed_number,
    STATE(5445), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5668), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [157830] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5157), 1,
      sym__lowercase_identifier,
    ACTIONS(5159), 1,
      anon_sym_LPAREN,
    ACTIONS(5161), 1,
      anon_sym_LBRACK,
    ACTIONS(5165), 1,
      anon_sym_LBRACE,
    ACTIONS(5167), 1,
      anon_sym_POUND,
    ACTIONS(5169), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5171), 1,
      anon_sym_lazy,
    ACTIONS(5173), 1,
      anon_sym_begin,
    ACTIONS(5179), 1,
      aux_sym_number_token1,
    ACTIONS(5181), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5183), 1,
      anon_sym_SQUOTE,
    ACTIONS(5185), 1,
      anon_sym_DQUOTE,
    ACTIONS(5187), 1,
      sym__uppercase_identifier,
    ACTIONS(5189), 1,
      aux_sym_tag_token1,
    ACTIONS(7737), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7739), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2451), 1,
      sym_tag,
    STATE(2453), 1,
      sym_constructor_path,
    STATE(2480), 1,
      sym__binding_pattern,
    STATE(4610), 1,
      sym_attribute,
    STATE(5363), 1,
      sym__signed_constant,
    STATE(5364), 1,
      sym__constructor_name,
    STATE(5498), 1,
      sym_parenthesized_operator,
    STATE(5506), 1,
      sym_record_binding_pattern,
    STATE(5514), 1,
      sym_array_binding_pattern,
    STATE(5515), 1,
      sym_list_binding_pattern,
    STATE(11574), 1,
      sym_let_binding,
    STATE(20448), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5163), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5408), 2,
      sym__constant,
      sym_signed_number,
    STATE(5367), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5519), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [157956] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    ACTIONS(8760), 1,
      anon_sym_PIPE_RBRACK,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4611), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13505), 1,
      sym__binding_pattern,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [158082] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    ACTIONS(8762), 1,
      anon_sym_RBRACK,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4612), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(13918), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [158208] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4613), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8226), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [158276] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    ACTIONS(8764), 1,
      anon_sym_RBRACK,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4614), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13765), 1,
      sym__binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [158402] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    ACTIONS(8766), 1,
      anon_sym_RBRACK,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4615), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(13918), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [158528] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    ACTIONS(8768), 1,
      anon_sym_PIPE_RBRACK,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4616), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13759), 1,
      sym__binding_pattern,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [158654] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8770), 1,
      anon_sym_COLON,
    STATE(4617), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8548), 32,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [158724] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    ACTIONS(8772), 1,
      anon_sym_RBRACK,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4618), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(13918), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [158850] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5245), 1,
      sym__lowercase_identifier,
    ACTIONS(5247), 1,
      anon_sym_LPAREN,
    ACTIONS(5249), 1,
      anon_sym_LBRACK,
    ACTIONS(5253), 1,
      anon_sym_LBRACE,
    ACTIONS(5255), 1,
      anon_sym_POUND,
    ACTIONS(5257), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5259), 1,
      anon_sym_lazy,
    ACTIONS(5261), 1,
      anon_sym_begin,
    ACTIONS(5267), 1,
      aux_sym_number_token1,
    ACTIONS(5269), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5271), 1,
      anon_sym_SQUOTE,
    ACTIONS(5273), 1,
      anon_sym_DQUOTE,
    ACTIONS(5275), 1,
      sym__uppercase_identifier,
    ACTIONS(5277), 1,
      aux_sym_tag_token1,
    ACTIONS(8610), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8612), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2458), 1,
      sym_tag,
    STATE(2459), 1,
      sym_constructor_path,
    STATE(2493), 1,
      sym__binding_pattern,
    STATE(4619), 1,
      sym_attribute,
    STATE(5482), 1,
      sym__signed_constant,
    STATE(5554), 1,
      sym__constructor_name,
    STATE(5674), 1,
      sym_parenthesized_operator,
    STATE(5721), 1,
      sym_array_binding_pattern,
    STATE(5723), 1,
      sym_list_binding_pattern,
    STATE(5729), 1,
      sym_record_binding_pattern,
    STATE(11849), 1,
      sym_let_binding,
    STATE(19030), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5251), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5522), 2,
      sym__constant,
      sym_signed_number,
    STATE(5551), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5731), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [158976] = 34,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    ACTIONS(8774), 1,
      anon_sym_RBRACK,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4620), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(13918), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [159102] = 32,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5487), 1,
      anon_sym_COLON2,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8776), 1,
      anon_sym_COLON_GT,
    ACTIONS(8778), 1,
      anon_sym_EQ,
    STATE(4621), 1,
      sym_attribute,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(16600), 1,
      sym__polymorphic_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [159223] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4622), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(14030), 1,
      sym__binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [159346] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(4623), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(8929), 1,
      sym__binding_pattern,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [159469] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4624), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13585), 1,
      sym__binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [159592] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4625), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(14020), 1,
      sym__binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [159715] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4626), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(14010), 1,
      sym__binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [159838] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4627), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13574), 1,
      sym__binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [159961] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4628), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(13918), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [160084] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7296), 1,
      anon_sym_COLON2,
    ACTIONS(8780), 1,
      sym__lowercase_identifier,
    ACTIONS(8786), 1,
      anon_sym_LPAREN,
    ACTIONS(8789), 1,
      anon_sym_LBRACK,
    ACTIONS(8795), 1,
      anon_sym_LBRACE,
    ACTIONS(8798), 1,
      anon_sym_POUND,
    ACTIONS(8801), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8804), 1,
      anon_sym_begin,
    ACTIONS(8807), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8810), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8813), 1,
      aux_sym_number_token1,
    ACTIONS(8816), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8819), 1,
      anon_sym_SQUOTE,
    ACTIONS(8822), 1,
      anon_sym_DQUOTE,
    ACTIONS(8825), 1,
      sym__uppercase_identifier,
    ACTIONS(8828), 1,
      aux_sym_tag_token1,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8783), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(8792), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4629), 2,
      sym_attribute,
      aux_sym_let_binding_repeat1,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    ACTIONS(7294), 3,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [160199] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5201), 1,
      sym__lowercase_identifier,
    ACTIONS(5203), 1,
      anon_sym_LPAREN,
    ACTIONS(5205), 1,
      anon_sym_LBRACK,
    ACTIONS(5209), 1,
      anon_sym_LBRACE,
    ACTIONS(5211), 1,
      anon_sym_POUND,
    ACTIONS(5213), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5215), 1,
      anon_sym_lazy,
    ACTIONS(5217), 1,
      anon_sym_begin,
    ACTIONS(5223), 1,
      aux_sym_number_token1,
    ACTIONS(5225), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5227), 1,
      anon_sym_SQUOTE,
    ACTIONS(5229), 1,
      anon_sym_DQUOTE,
    ACTIONS(5231), 1,
      sym__uppercase_identifier,
    ACTIONS(5233), 1,
      aux_sym_tag_token1,
    ACTIONS(8616), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8618), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2455), 1,
      sym_tag,
    STATE(2456), 1,
      sym_constructor_path,
    STATE(4630), 1,
      sym_attribute,
    STATE(5443), 1,
      sym__signed_constant,
    STATE(5444), 1,
      sym__constructor_name,
    STATE(5626), 1,
      sym_array_binding_pattern,
    STATE(5640), 1,
      sym__binding_pattern,
    STATE(5663), 1,
      sym_list_binding_pattern,
    STATE(5664), 1,
      sym_record_binding_pattern,
    STATE(5725), 1,
      sym_parenthesized_operator,
    STATE(18726), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5207), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5523), 2,
      sym__constant,
      sym_signed_number,
    STATE(5445), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5668), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [160322] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5201), 1,
      sym__lowercase_identifier,
    ACTIONS(5203), 1,
      anon_sym_LPAREN,
    ACTIONS(5205), 1,
      anon_sym_LBRACK,
    ACTIONS(5209), 1,
      anon_sym_LBRACE,
    ACTIONS(5211), 1,
      anon_sym_POUND,
    ACTIONS(5213), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5215), 1,
      anon_sym_lazy,
    ACTIONS(5217), 1,
      anon_sym_begin,
    ACTIONS(5223), 1,
      aux_sym_number_token1,
    ACTIONS(5225), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5227), 1,
      anon_sym_SQUOTE,
    ACTIONS(5229), 1,
      anon_sym_DQUOTE,
    ACTIONS(5231), 1,
      sym__uppercase_identifier,
    ACTIONS(5233), 1,
      aux_sym_tag_token1,
    ACTIONS(8616), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8618), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2455), 1,
      sym_tag,
    STATE(2456), 1,
      sym_constructor_path,
    STATE(4631), 1,
      sym_attribute,
    STATE(5443), 1,
      sym__signed_constant,
    STATE(5444), 1,
      sym__constructor_name,
    STATE(5626), 1,
      sym_array_binding_pattern,
    STATE(5639), 1,
      sym__binding_pattern,
    STATE(5663), 1,
      sym_list_binding_pattern,
    STATE(5664), 1,
      sym_record_binding_pattern,
    STATE(5725), 1,
      sym_parenthesized_operator,
    STATE(18726), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5207), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5523), 2,
      sym__constant,
      sym_signed_number,
    STATE(5445), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5668), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [160445] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4632), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13843), 1,
      sym__binding_pattern,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [160568] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5201), 1,
      sym__lowercase_identifier,
    ACTIONS(5203), 1,
      anon_sym_LPAREN,
    ACTIONS(5205), 1,
      anon_sym_LBRACK,
    ACTIONS(5209), 1,
      anon_sym_LBRACE,
    ACTIONS(5211), 1,
      anon_sym_POUND,
    ACTIONS(5213), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5215), 1,
      anon_sym_lazy,
    ACTIONS(5217), 1,
      anon_sym_begin,
    ACTIONS(5223), 1,
      aux_sym_number_token1,
    ACTIONS(5225), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5227), 1,
      anon_sym_SQUOTE,
    ACTIONS(5229), 1,
      anon_sym_DQUOTE,
    ACTIONS(5231), 1,
      sym__uppercase_identifier,
    ACTIONS(5233), 1,
      aux_sym_tag_token1,
    ACTIONS(8616), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8618), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2455), 1,
      sym_tag,
    STATE(2456), 1,
      sym_constructor_path,
    STATE(4633), 1,
      sym_attribute,
    STATE(5443), 1,
      sym__signed_constant,
    STATE(5444), 1,
      sym__constructor_name,
    STATE(5626), 1,
      sym_array_binding_pattern,
    STATE(5638), 1,
      sym__binding_pattern,
    STATE(5663), 1,
      sym_list_binding_pattern,
    STATE(5664), 1,
      sym_record_binding_pattern,
    STATE(5725), 1,
      sym_parenthesized_operator,
    STATE(18726), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5207), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5523), 2,
      sym__constant,
      sym_signed_number,
    STATE(5445), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5668), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [160691] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5245), 1,
      sym__lowercase_identifier,
    ACTIONS(5247), 1,
      anon_sym_LPAREN,
    ACTIONS(5249), 1,
      anon_sym_LBRACK,
    ACTIONS(5253), 1,
      anon_sym_LBRACE,
    ACTIONS(5255), 1,
      anon_sym_POUND,
    ACTIONS(5257), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5259), 1,
      anon_sym_lazy,
    ACTIONS(5261), 1,
      anon_sym_begin,
    ACTIONS(5267), 1,
      aux_sym_number_token1,
    ACTIONS(5269), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5271), 1,
      anon_sym_SQUOTE,
    ACTIONS(5273), 1,
      anon_sym_DQUOTE,
    ACTIONS(5275), 1,
      sym__uppercase_identifier,
    ACTIONS(5277), 1,
      aux_sym_tag_token1,
    ACTIONS(8610), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8612), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2458), 1,
      sym_tag,
    STATE(2459), 1,
      sym_constructor_path,
    STATE(4634), 1,
      sym_attribute,
    STATE(5482), 1,
      sym__signed_constant,
    STATE(5554), 1,
      sym__constructor_name,
    STATE(5674), 1,
      sym_parenthesized_operator,
    STATE(5701), 1,
      sym__binding_pattern,
    STATE(5721), 1,
      sym_array_binding_pattern,
    STATE(5723), 1,
      sym_list_binding_pattern,
    STATE(5729), 1,
      sym_record_binding_pattern,
    STATE(19030), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5251), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5522), 2,
      sym__constant,
      sym_signed_number,
    STATE(5551), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5731), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [160814] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4635), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13265), 1,
      sym__binding_pattern,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [160937] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4636), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13571), 1,
      sym__binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [161060] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5201), 1,
      sym__lowercase_identifier,
    ACTIONS(5203), 1,
      anon_sym_LPAREN,
    ACTIONS(5205), 1,
      anon_sym_LBRACK,
    ACTIONS(5209), 1,
      anon_sym_LBRACE,
    ACTIONS(5211), 1,
      anon_sym_POUND,
    ACTIONS(5213), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5215), 1,
      anon_sym_lazy,
    ACTIONS(5217), 1,
      anon_sym_begin,
    ACTIONS(5223), 1,
      aux_sym_number_token1,
    ACTIONS(5225), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5227), 1,
      anon_sym_SQUOTE,
    ACTIONS(5229), 1,
      anon_sym_DQUOTE,
    ACTIONS(5231), 1,
      sym__uppercase_identifier,
    ACTIONS(5233), 1,
      aux_sym_tag_token1,
    ACTIONS(8616), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8618), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2455), 1,
      sym_tag,
    STATE(2456), 1,
      sym_constructor_path,
    STATE(4637), 1,
      sym_attribute,
    STATE(5443), 1,
      sym__signed_constant,
    STATE(5444), 1,
      sym__constructor_name,
    STATE(5626), 1,
      sym_array_binding_pattern,
    STATE(5636), 1,
      sym__binding_pattern,
    STATE(5663), 1,
      sym_list_binding_pattern,
    STATE(5664), 1,
      sym_record_binding_pattern,
    STATE(5725), 1,
      sym_parenthesized_operator,
    STATE(18726), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5207), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5523), 2,
      sym__constant,
      sym_signed_number,
    STATE(5445), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5668), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [161183] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8226), 32,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [161250] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5157), 1,
      sym__lowercase_identifier,
    ACTIONS(5159), 1,
      anon_sym_LPAREN,
    ACTIONS(5161), 1,
      anon_sym_LBRACK,
    ACTIONS(5165), 1,
      anon_sym_LBRACE,
    ACTIONS(5167), 1,
      anon_sym_POUND,
    ACTIONS(5169), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5171), 1,
      anon_sym_lazy,
    ACTIONS(5173), 1,
      anon_sym_begin,
    ACTIONS(5179), 1,
      aux_sym_number_token1,
    ACTIONS(5181), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5183), 1,
      anon_sym_SQUOTE,
    ACTIONS(5185), 1,
      anon_sym_DQUOTE,
    ACTIONS(5187), 1,
      sym__uppercase_identifier,
    ACTIONS(5189), 1,
      aux_sym_tag_token1,
    ACTIONS(7737), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7739), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2451), 1,
      sym_tag,
    STATE(2453), 1,
      sym_constructor_path,
    STATE(4639), 1,
      sym_attribute,
    STATE(5363), 1,
      sym__signed_constant,
    STATE(5364), 1,
      sym__constructor_name,
    STATE(5498), 1,
      sym_parenthesized_operator,
    STATE(5506), 1,
      sym_record_binding_pattern,
    STATE(5514), 1,
      sym_array_binding_pattern,
    STATE(5515), 1,
      sym_list_binding_pattern,
    STATE(5535), 1,
      sym__binding_pattern,
    STATE(20448), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5163), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5408), 2,
      sym__constant,
      sym_signed_number,
    STATE(5367), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5519), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [161373] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4640), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8622), 32,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [161440] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(4641), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8913), 1,
      sym__binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [161563] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4642), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(13986), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [161686] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5157), 1,
      sym__lowercase_identifier,
    ACTIONS(5159), 1,
      anon_sym_LPAREN,
    ACTIONS(5161), 1,
      anon_sym_LBRACK,
    ACTIONS(5165), 1,
      anon_sym_LBRACE,
    ACTIONS(5167), 1,
      anon_sym_POUND,
    ACTIONS(5169), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5171), 1,
      anon_sym_lazy,
    ACTIONS(5173), 1,
      anon_sym_begin,
    ACTIONS(5179), 1,
      aux_sym_number_token1,
    ACTIONS(5181), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5183), 1,
      anon_sym_SQUOTE,
    ACTIONS(5185), 1,
      anon_sym_DQUOTE,
    ACTIONS(5187), 1,
      sym__uppercase_identifier,
    ACTIONS(5189), 1,
      aux_sym_tag_token1,
    ACTIONS(7737), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7739), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2451), 1,
      sym_tag,
    STATE(2453), 1,
      sym_constructor_path,
    STATE(4643), 1,
      sym_attribute,
    STATE(5363), 1,
      sym__signed_constant,
    STATE(5364), 1,
      sym__constructor_name,
    STATE(5498), 1,
      sym_parenthesized_operator,
    STATE(5506), 1,
      sym_record_binding_pattern,
    STATE(5514), 1,
      sym_array_binding_pattern,
    STATE(5515), 1,
      sym_list_binding_pattern,
    STATE(5548), 1,
      sym__binding_pattern,
    STATE(20448), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5163), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5408), 2,
      sym__constant,
      sym_signed_number,
    STATE(5367), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5519), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [161809] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5075), 1,
      sym__lowercase_identifier,
    ACTIONS(5081), 1,
      anon_sym_LPAREN,
    ACTIONS(5083), 1,
      anon_sym_LBRACK,
    ACTIONS(5087), 1,
      anon_sym_LBRACE,
    ACTIONS(5089), 1,
      anon_sym_POUND,
    ACTIONS(5091), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5093), 1,
      anon_sym_lazy,
    ACTIONS(5095), 1,
      anon_sym_begin,
    ACTIONS(5101), 1,
      aux_sym_number_token1,
    ACTIONS(5103), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5105), 1,
      anon_sym_SQUOTE,
    ACTIONS(5107), 1,
      anon_sym_DQUOTE,
    ACTIONS(5109), 1,
      sym__uppercase_identifier,
    ACTIONS(5111), 1,
      aux_sym_tag_token1,
    ACTIONS(7743), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7745), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2444), 1,
      sym_constructor_path,
    STATE(2445), 1,
      sym_tag,
    STATE(4644), 1,
      sym_attribute,
    STATE(5315), 1,
      sym__signed_constant,
    STATE(5376), 1,
      sym__constructor_name,
    STATE(5475), 1,
      sym_record_binding_pattern,
    STATE(5534), 1,
      sym_parenthesized_operator,
    STATE(5537), 1,
      sym__binding_pattern,
    STATE(5538), 1,
      sym_list_binding_pattern,
    STATE(5553), 1,
      sym_array_binding_pattern,
    STATE(20406), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5085), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5356), 2,
      sym__constant,
      sym_signed_number,
    STATE(5423), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5483), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [161932] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5157), 1,
      sym__lowercase_identifier,
    ACTIONS(5159), 1,
      anon_sym_LPAREN,
    ACTIONS(5161), 1,
      anon_sym_LBRACK,
    ACTIONS(5165), 1,
      anon_sym_LBRACE,
    ACTIONS(5167), 1,
      anon_sym_POUND,
    ACTIONS(5169), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5171), 1,
      anon_sym_lazy,
    ACTIONS(5173), 1,
      anon_sym_begin,
    ACTIONS(5179), 1,
      aux_sym_number_token1,
    ACTIONS(5181), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5183), 1,
      anon_sym_SQUOTE,
    ACTIONS(5185), 1,
      anon_sym_DQUOTE,
    ACTIONS(5187), 1,
      sym__uppercase_identifier,
    ACTIONS(5189), 1,
      aux_sym_tag_token1,
    ACTIONS(7737), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7739), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2451), 1,
      sym_tag,
    STATE(2453), 1,
      sym_constructor_path,
    STATE(4645), 1,
      sym_attribute,
    STATE(5363), 1,
      sym__signed_constant,
    STATE(5364), 1,
      sym__constructor_name,
    STATE(5498), 1,
      sym_parenthesized_operator,
    STATE(5506), 1,
      sym_record_binding_pattern,
    STATE(5514), 1,
      sym_array_binding_pattern,
    STATE(5515), 1,
      sym_list_binding_pattern,
    STATE(5563), 1,
      sym__binding_pattern,
    STATE(20448), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5163), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5408), 2,
      sym__constant,
      sym_signed_number,
    STATE(5367), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5519), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [162055] = 32,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5487), 1,
      anon_sym_COLON2,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8831), 1,
      anon_sym_COLON_GT,
    ACTIONS(8833), 1,
      anon_sym_EQ,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4646), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(16678), 1,
      sym__polymorphic_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [162176] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5157), 1,
      sym__lowercase_identifier,
    ACTIONS(5159), 1,
      anon_sym_LPAREN,
    ACTIONS(5161), 1,
      anon_sym_LBRACK,
    ACTIONS(5165), 1,
      anon_sym_LBRACE,
    ACTIONS(5167), 1,
      anon_sym_POUND,
    ACTIONS(5169), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5171), 1,
      anon_sym_lazy,
    ACTIONS(5173), 1,
      anon_sym_begin,
    ACTIONS(5179), 1,
      aux_sym_number_token1,
    ACTIONS(5181), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5183), 1,
      anon_sym_SQUOTE,
    ACTIONS(5185), 1,
      anon_sym_DQUOTE,
    ACTIONS(5187), 1,
      sym__uppercase_identifier,
    ACTIONS(5189), 1,
      aux_sym_tag_token1,
    ACTIONS(7737), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7739), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2451), 1,
      sym_tag,
    STATE(2453), 1,
      sym_constructor_path,
    STATE(4647), 1,
      sym_attribute,
    STATE(5363), 1,
      sym__signed_constant,
    STATE(5364), 1,
      sym__constructor_name,
    STATE(5498), 1,
      sym_parenthesized_operator,
    STATE(5506), 1,
      sym_record_binding_pattern,
    STATE(5514), 1,
      sym_array_binding_pattern,
    STATE(5515), 1,
      sym_list_binding_pattern,
    STATE(5527), 1,
      sym__binding_pattern,
    STATE(20448), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5163), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5408), 2,
      sym__constant,
      sym_signed_number,
    STATE(5367), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5519), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [162299] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5245), 1,
      sym__lowercase_identifier,
    ACTIONS(5247), 1,
      anon_sym_LPAREN,
    ACTIONS(5249), 1,
      anon_sym_LBRACK,
    ACTIONS(5253), 1,
      anon_sym_LBRACE,
    ACTIONS(5255), 1,
      anon_sym_POUND,
    ACTIONS(5257), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5259), 1,
      anon_sym_lazy,
    ACTIONS(5261), 1,
      anon_sym_begin,
    ACTIONS(5267), 1,
      aux_sym_number_token1,
    ACTIONS(5269), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5271), 1,
      anon_sym_SQUOTE,
    ACTIONS(5273), 1,
      anon_sym_DQUOTE,
    ACTIONS(5275), 1,
      sym__uppercase_identifier,
    ACTIONS(5277), 1,
      aux_sym_tag_token1,
    ACTIONS(8610), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8612), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2458), 1,
      sym_tag,
    STATE(2459), 1,
      sym_constructor_path,
    STATE(4648), 1,
      sym_attribute,
    STATE(5482), 1,
      sym__signed_constant,
    STATE(5554), 1,
      sym__constructor_name,
    STATE(5674), 1,
      sym_parenthesized_operator,
    STATE(5703), 1,
      sym__binding_pattern,
    STATE(5721), 1,
      sym_array_binding_pattern,
    STATE(5723), 1,
      sym_list_binding_pattern,
    STATE(5729), 1,
      sym_record_binding_pattern,
    STATE(19030), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5251), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5522), 2,
      sym__constant,
      sym_signed_number,
    STATE(5551), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5731), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [162422] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8226), 31,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [162489] = 32,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5487), 1,
      anon_sym_COLON2,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8835), 1,
      anon_sym_COLON_GT,
    ACTIONS(8837), 1,
      anon_sym_EQ,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4650), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(16630), 1,
      sym__polymorphic_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [162610] = 32,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5487), 1,
      anon_sym_COLON2,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8839), 1,
      anon_sym_COLON_GT,
    ACTIONS(8841), 1,
      anon_sym_EQ,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4651), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(16541), 1,
      sym__polymorphic_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [162731] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5245), 1,
      sym__lowercase_identifier,
    ACTIONS(5247), 1,
      anon_sym_LPAREN,
    ACTIONS(5249), 1,
      anon_sym_LBRACK,
    ACTIONS(5253), 1,
      anon_sym_LBRACE,
    ACTIONS(5255), 1,
      anon_sym_POUND,
    ACTIONS(5257), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5259), 1,
      anon_sym_lazy,
    ACTIONS(5261), 1,
      anon_sym_begin,
    ACTIONS(5267), 1,
      aux_sym_number_token1,
    ACTIONS(5269), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5271), 1,
      anon_sym_SQUOTE,
    ACTIONS(5273), 1,
      anon_sym_DQUOTE,
    ACTIONS(5275), 1,
      sym__uppercase_identifier,
    ACTIONS(5277), 1,
      aux_sym_tag_token1,
    ACTIONS(8610), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8612), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2458), 1,
      sym_tag,
    STATE(2459), 1,
      sym_constructor_path,
    STATE(4652), 1,
      sym_attribute,
    STATE(5482), 1,
      sym__signed_constant,
    STATE(5554), 1,
      sym__constructor_name,
    STATE(5674), 1,
      sym_parenthesized_operator,
    STATE(5702), 1,
      sym__binding_pattern,
    STATE(5721), 1,
      sym_array_binding_pattern,
    STATE(5723), 1,
      sym_list_binding_pattern,
    STATE(5729), 1,
      sym_record_binding_pattern,
    STATE(19030), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5251), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5522), 2,
      sym__constant,
      sym_signed_number,
    STATE(5551), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5731), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [162854] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5075), 1,
      sym__lowercase_identifier,
    ACTIONS(5081), 1,
      anon_sym_LPAREN,
    ACTIONS(5083), 1,
      anon_sym_LBRACK,
    ACTIONS(5087), 1,
      anon_sym_LBRACE,
    ACTIONS(5089), 1,
      anon_sym_POUND,
    ACTIONS(5091), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5093), 1,
      anon_sym_lazy,
    ACTIONS(5095), 1,
      anon_sym_begin,
    ACTIONS(5101), 1,
      aux_sym_number_token1,
    ACTIONS(5103), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5105), 1,
      anon_sym_SQUOTE,
    ACTIONS(5107), 1,
      anon_sym_DQUOTE,
    ACTIONS(5109), 1,
      sym__uppercase_identifier,
    ACTIONS(5111), 1,
      aux_sym_tag_token1,
    ACTIONS(7743), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7745), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2444), 1,
      sym_constructor_path,
    STATE(2445), 1,
      sym_tag,
    STATE(4653), 1,
      sym_attribute,
    STATE(5315), 1,
      sym__signed_constant,
    STATE(5376), 1,
      sym__constructor_name,
    STATE(5475), 1,
      sym_record_binding_pattern,
    STATE(5534), 1,
      sym_parenthesized_operator,
    STATE(5538), 1,
      sym_list_binding_pattern,
    STATE(5553), 1,
      sym_array_binding_pattern,
    STATE(5560), 1,
      sym__binding_pattern,
    STATE(20406), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5085), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5356), 2,
      sym__constant,
      sym_signed_number,
    STATE(5423), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5483), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [162977] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5075), 1,
      sym__lowercase_identifier,
    ACTIONS(5081), 1,
      anon_sym_LPAREN,
    ACTIONS(5083), 1,
      anon_sym_LBRACK,
    ACTIONS(5087), 1,
      anon_sym_LBRACE,
    ACTIONS(5089), 1,
      anon_sym_POUND,
    ACTIONS(5091), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5093), 1,
      anon_sym_lazy,
    ACTIONS(5095), 1,
      anon_sym_begin,
    ACTIONS(5101), 1,
      aux_sym_number_token1,
    ACTIONS(5103), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5105), 1,
      anon_sym_SQUOTE,
    ACTIONS(5107), 1,
      anon_sym_DQUOTE,
    ACTIONS(5109), 1,
      sym__uppercase_identifier,
    ACTIONS(5111), 1,
      aux_sym_tag_token1,
    ACTIONS(7743), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7745), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2444), 1,
      sym_constructor_path,
    STATE(2445), 1,
      sym_tag,
    STATE(4654), 1,
      sym_attribute,
    STATE(5315), 1,
      sym__signed_constant,
    STATE(5376), 1,
      sym__constructor_name,
    STATE(5468), 1,
      sym__binding_pattern,
    STATE(5475), 1,
      sym_record_binding_pattern,
    STATE(5534), 1,
      sym_parenthesized_operator,
    STATE(5538), 1,
      sym_list_binding_pattern,
    STATE(5553), 1,
      sym_array_binding_pattern,
    STATE(20406), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5085), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5356), 2,
      sym__constant,
      sym_signed_number,
    STATE(5423), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5483), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [163100] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5075), 1,
      sym__lowercase_identifier,
    ACTIONS(5081), 1,
      anon_sym_LPAREN,
    ACTIONS(5083), 1,
      anon_sym_LBRACK,
    ACTIONS(5087), 1,
      anon_sym_LBRACE,
    ACTIONS(5089), 1,
      anon_sym_POUND,
    ACTIONS(5091), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5093), 1,
      anon_sym_lazy,
    ACTIONS(5095), 1,
      anon_sym_begin,
    ACTIONS(5101), 1,
      aux_sym_number_token1,
    ACTIONS(5103), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5105), 1,
      anon_sym_SQUOTE,
    ACTIONS(5107), 1,
      anon_sym_DQUOTE,
    ACTIONS(5109), 1,
      sym__uppercase_identifier,
    ACTIONS(5111), 1,
      aux_sym_tag_token1,
    ACTIONS(7743), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7745), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2444), 1,
      sym_constructor_path,
    STATE(2445), 1,
      sym_tag,
    STATE(4655), 1,
      sym_attribute,
    STATE(5315), 1,
      sym__signed_constant,
    STATE(5376), 1,
      sym__constructor_name,
    STATE(5475), 1,
      sym_record_binding_pattern,
    STATE(5534), 1,
      sym_parenthesized_operator,
    STATE(5538), 1,
      sym_list_binding_pattern,
    STATE(5553), 1,
      sym_array_binding_pattern,
    STATE(5561), 1,
      sym__binding_pattern,
    STATE(20406), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5085), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5356), 2,
      sym__constant,
      sym_signed_number,
    STATE(5423), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5483), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [163223] = 32,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5487), 1,
      anon_sym_COLON2,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8843), 1,
      anon_sym_COLON_GT,
    ACTIONS(8845), 1,
      anon_sym_EQ,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4656), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(16811), 1,
      sym__polymorphic_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [163344] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6833), 1,
      sym__lowercase_identifier,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6851), 1,
      anon_sym_lazy,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(3559), 1,
      sym_constructor_path,
    STATE(3561), 1,
      sym_tag,
    STATE(4657), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10358), 1,
      sym_parenthesized_operator,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13265), 1,
      sym__binding_pattern,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [163467] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8622), 31,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [163534] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(4659), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(8935), 1,
      sym__binding_pattern,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [163657] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6833), 1,
      sym__lowercase_identifier,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6851), 1,
      anon_sym_lazy,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(3559), 1,
      sym_constructor_path,
    STATE(3561), 1,
      sym_tag,
    STATE(4660), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10358), 1,
      sym_parenthesized_operator,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(14085), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [163780] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6833), 1,
      sym__lowercase_identifier,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6851), 1,
      anon_sym_lazy,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(3559), 1,
      sym_constructor_path,
    STATE(3561), 1,
      sym_tag,
    STATE(4661), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10358), 1,
      sym_parenthesized_operator,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(14092), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [163903] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6833), 1,
      sym__lowercase_identifier,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6851), 1,
      anon_sym_lazy,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    STATE(3559), 1,
      sym_constructor_path,
    STATE(3561), 1,
      sym_tag,
    STATE(4662), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10358), 1,
      sym_parenthesized_operator,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(14104), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [164026] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7513), 1,
      sym__lowercase_identifier,
    ACTIONS(7515), 1,
      anon_sym_LPAREN,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7521), 1,
      anon_sym_LBRACE,
    ACTIONS(7523), 1,
      anon_sym_POUND,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7527), 1,
      anon_sym_lazy,
    ACTIONS(7529), 1,
      anon_sym_begin,
    ACTIONS(7531), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7533), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(7543), 1,
      sym__uppercase_identifier,
    ACTIONS(7545), 1,
      aux_sym_tag_token1,
    STATE(2596), 1,
      sym_tag,
    STATE(2599), 1,
      sym_constructor_path,
    STATE(4663), 1,
      sym_attribute,
    STATE(8611), 1,
      sym__constructor_name,
    STATE(8778), 1,
      sym__signed_constant,
    STATE(8892), 1,
      sym_array_binding_pattern,
    STATE(8894), 1,
      sym_list_binding_pattern,
    STATE(8895), 1,
      sym_record_binding_pattern,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(8917), 1,
      sym__binding_pattern,
    STATE(19304), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7519), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8897), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [164149] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(7801), 1,
      sym__uppercase_identifier,
    ACTIONS(7803), 1,
      aux_sym_tag_token1,
    ACTIONS(8444), 1,
      sym__lowercase_identifier,
    ACTIONS(8446), 1,
      anon_sym_LPAREN,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8454), 1,
      anon_sym_lazy,
    STATE(3624), 1,
      sym_tag,
    STATE(3625), 1,
      sym_constructor_path,
    STATE(4664), 1,
      sym_attribute,
    STATE(8125), 1,
      sym__constructor_name,
    STATE(13780), 1,
      sym__signed_constant,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(13908), 1,
      sym_array_binding_pattern,
    STATE(13909), 1,
      sym_list_binding_pattern,
    STATE(13911), 1,
      sym_record_binding_pattern,
    STATE(14150), 1,
      sym__binding_pattern,
    STATE(19840), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13920), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [164272] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5245), 1,
      sym__lowercase_identifier,
    ACTIONS(5247), 1,
      anon_sym_LPAREN,
    ACTIONS(5249), 1,
      anon_sym_LBRACK,
    ACTIONS(5253), 1,
      anon_sym_LBRACE,
    ACTIONS(5255), 1,
      anon_sym_POUND,
    ACTIONS(5257), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5259), 1,
      anon_sym_lazy,
    ACTIONS(5261), 1,
      anon_sym_begin,
    ACTIONS(5267), 1,
      aux_sym_number_token1,
    ACTIONS(5269), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5271), 1,
      anon_sym_SQUOTE,
    ACTIONS(5273), 1,
      anon_sym_DQUOTE,
    ACTIONS(5275), 1,
      sym__uppercase_identifier,
    ACTIONS(5277), 1,
      aux_sym_tag_token1,
    ACTIONS(8610), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8612), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2458), 1,
      sym_tag,
    STATE(2459), 1,
      sym_constructor_path,
    STATE(4665), 1,
      sym_attribute,
    STATE(5482), 1,
      sym__signed_constant,
    STATE(5554), 1,
      sym__constructor_name,
    STATE(5674), 1,
      sym_parenthesized_operator,
    STATE(5697), 1,
      sym__binding_pattern,
    STATE(5721), 1,
      sym_array_binding_pattern,
    STATE(5723), 1,
      sym_list_binding_pattern,
    STATE(5729), 1,
      sym_record_binding_pattern,
    STATE(19030), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5251), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5522), 2,
      sym__constant,
      sym_signed_number,
    STATE(5551), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5731), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [164395] = 33,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(6835), 1,
      anon_sym_LPAREN,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6843), 1,
      anon_sym_LBRACE,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8384), 1,
      sym__lowercase_identifier,
    ACTIONS(8386), 1,
      anon_sym_lazy,
    STATE(3246), 1,
      sym_constructor_path,
    STATE(3247), 1,
      sym_tag,
    STATE(4666), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(13219), 1,
      sym__signed_constant,
    STATE(13357), 1,
      sym_record_binding_pattern,
    STATE(13358), 1,
      sym_list_binding_pattern,
    STATE(13361), 1,
      sym_array_binding_pattern,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(13941), 1,
      sym__binding_pattern,
    STATE(20421), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13355), 16,
      sym_alias_binding_pattern,
      sym_typed_binding_pattern,
      sym_or_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_tuple_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [164518] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8849), 1,
      anon_sym_DASH_GT,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4667), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19866), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [164636] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8853), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4668), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19300), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [164754] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8855), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4669), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19560), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [164872] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8857), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4670), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18581), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [164990] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8859), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4671), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18086), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [165108] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8861), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4672), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19100), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [165226] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8863), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4673), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19180), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [165344] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8865), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4674), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20381), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [165462] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8867), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4675), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19301), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [165580] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8869), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4676), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19171), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [165698] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8871), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4677), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(17598), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [165816] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8873), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4678), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19679), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [165934] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8875), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4679), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(17593), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [166052] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8877), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4680), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19325), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [166170] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4681), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 31,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [166236] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8879), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4682), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18160), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [166354] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 31,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [166420] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8881), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4684), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19814), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [166538] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8883), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4685), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19290), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [166656] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8885), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4686), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18072), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [166774] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8887), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4687), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19407), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [166892] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8889), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4688), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19409), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [167010] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4689), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 31,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [167076] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4690), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 31,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [167142] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8891), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4691), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(17748), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [167260] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4692), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 31,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [167326] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8893), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4693), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18757), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [167444] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8895), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4694), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19360), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [167562] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8897), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4695), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19229), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [167680] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8899), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4696), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19220), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [167798] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8901), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4697), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18015), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [167916] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4698), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 31,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [167982] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8903), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4699), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18495), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [168100] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8905), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4700), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18957), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [168218] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8907), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4701), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(17642), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [168336] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8909), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4702), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19543), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [168454] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(4703), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [168522] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8911), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4704), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19371), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [168640] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8913), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4705), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18420), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [168758] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8915), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4706), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18004), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [168876] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8917), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4707), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18869), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [168994] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4708), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 31,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [169060] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8923), 1,
      aux_sym_attribute_id_token1,
    STATE(4709), 1,
      sym_attribute,
    STATE(4727), 1,
      aux_sym_attribute_id_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8921), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8919), 29,
      anon_sym_let,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [169130] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8925), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4710), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19046), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [169248] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8927), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4711), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18223), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [169366] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8929), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4712), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19029), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [169484] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8931), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4713), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18510), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [169602] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8933), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4714), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18148), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [169720] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8935), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4715), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(17780), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [169838] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8937), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4716), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18768), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [169956] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8939), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4717), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18598), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [170074] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8941), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4718), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18914), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [170192] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8943), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4719), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19110), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [170310] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8945), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4720), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18407), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [170428] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8947), 1,
      anon_sym_LT_DASH,
    STATE(4721), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [170496] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8949), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4722), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(17803), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [170614] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8951), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4723), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18887), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [170732] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8953), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4724), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    STATE(20502), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [170850] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8955), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4725), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20055), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [170968] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8957), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4726), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18764), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [171086] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8963), 1,
      aux_sym_attribute_id_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(4727), 2,
      sym_attribute,
      aux_sym_attribute_id_repeat1,
    ACTIONS(8961), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8959), 29,
      anon_sym_let,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [171154] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8966), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4728), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18084), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [171272] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8968), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4729), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(17684), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [171390] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8970), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4730), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18079), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [171508] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8972), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4731), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18949), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [171626] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8974), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4732), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(17949), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [171744] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8976), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4733), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19942), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [171862] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8978), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4734), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18611), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [171980] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8980), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4735), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19659), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [172098] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8982), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4736), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18592), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [172216] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8984), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4737), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(17694), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [172334] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8986), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4738), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(17634), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [172452] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8988), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4739), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19441), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [172570] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8990), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4740), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19128), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [172688] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8992), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4741), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(17941), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [172806] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8994), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4742), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19458), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [172924] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8996), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4743), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    STATE(20485), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [173042] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8998), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4744), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18975), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [173160] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9000), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4745), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18237), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [173278] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9002), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4746), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    STATE(20486), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [173396] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9004), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4747), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18322), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [173514] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9006), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4748), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18334), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [173632] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9008), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4749), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18856), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [173750] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9010), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4750), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20077), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [173868] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9012), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4751), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18464), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [173986] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4752), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 31,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [174052] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9014), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4753), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20379), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [174170] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9016), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4754), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18471), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [174288] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9018), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4755), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(17887), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [174406] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9020), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4756), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18198), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [174524] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9022), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4757), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18681), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [174642] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9024), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4758), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18669), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [174760] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9026), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4759), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18344), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [174878] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9028), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4760), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(17761), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [174996] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9030), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4761), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18246), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [175114] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9032), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4762), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(17923), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [175232] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9034), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4763), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(17876), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [175350] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9036), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4764), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19098), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [175468] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9038), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4765), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(18332), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [175586] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9040), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4766), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(17822), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [175704] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9042), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4767), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(17815), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [175822] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9044), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4768), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(19789), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [175940] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 31,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [176006] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9046), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4770), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(17819), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [176124] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8847), 1,
      anon_sym_COLON2,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9048), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4771), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20253), 1,
      sym__simple_typed,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [176242] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8923), 1,
      aux_sym_attribute_id_token1,
    STATE(4709), 1,
      aux_sym_attribute_id_repeat1,
    STATE(4772), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9052), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9050), 29,
      anon_sym_let,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [176312] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [176377] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4774), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [176442] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4775), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [176507] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [176572] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4777), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [176637] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4715), 1,
      aux_sym_let_binding_repeat1,
    STATE(4778), 1,
      sym_attribute,
    STATE(5047), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [176752] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(4779), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [176819] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4717), 1,
      aux_sym_let_binding_repeat1,
    STATE(4780), 1,
      sym_attribute,
    STATE(5012), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [176934] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4781), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [176999] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [177064] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4783), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [177129] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4784), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [177194] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4704), 1,
      aux_sym_let_binding_repeat1,
    STATE(4785), 1,
      sym_attribute,
    STATE(5016), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [177309] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [177374] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4787), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [177439] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(4788), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [177506] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4789), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [177571] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [177636] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4713), 1,
      aux_sym_let_binding_repeat1,
    STATE(4791), 1,
      sym_attribute,
    STATE(5029), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [177751] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4792), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [177816] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4723), 1,
      aux_sym_let_binding_repeat1,
    STATE(4793), 1,
      sym_attribute,
    STATE(5037), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [177931] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4794), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [177996] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4766), 1,
      aux_sym_let_binding_repeat1,
    STATE(4795), 1,
      sym_attribute,
    STATE(5036), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [178111] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4674), 1,
      aux_sym_let_binding_repeat1,
    STATE(4796), 1,
      sym_attribute,
    STATE(5027), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [178226] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4765), 1,
      aux_sym_let_binding_repeat1,
    STATE(4797), 1,
      sym_attribute,
    STATE(5098), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [178341] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4760), 1,
      aux_sym_let_binding_repeat1,
    STATE(4798), 1,
      sym_attribute,
    STATE(5051), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [178456] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4732), 1,
      aux_sym_let_binding_repeat1,
    STATE(4799), 1,
      sym_attribute,
    STATE(5039), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [178571] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4687), 1,
      aux_sym_let_binding_repeat1,
    STATE(4800), 1,
      sym_attribute,
    STATE(4996), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [178686] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(4579), 1,
      anon_sym_DOT,
    STATE(4801), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [178753] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4802), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [178818] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [178883] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4750), 1,
      aux_sym_let_binding_repeat1,
    STATE(4804), 1,
      sym_attribute,
    STATE(5002), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [178998] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4746), 1,
      aux_sym_let_binding_repeat1,
    STATE(4805), 1,
      sym_attribute,
    STATE(5071), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [179113] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4806), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [179178] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4807), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [179243] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4808), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [179308] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4716), 1,
      aux_sym_let_binding_repeat1,
    STATE(4809), 1,
      sym_attribute,
    STATE(5060), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [179423] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [179488] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4811), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [179553] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4812), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [179618] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4813), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [179683] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4731), 1,
      aux_sym_let_binding_repeat1,
    STATE(4814), 1,
      sym_attribute,
    STATE(5069), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [179798] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4742), 1,
      aux_sym_let_binding_repeat1,
    STATE(4815), 1,
      sym_attribute,
    STATE(5056), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [179913] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4816), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [179978] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4817), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [180043] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4695), 1,
      aux_sym_let_binding_repeat1,
    STATE(4818), 1,
      sym_attribute,
    STATE(5028), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [180158] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4669), 1,
      aux_sym_let_binding_repeat1,
    STATE(4819), 1,
      sym_attribute,
    STATE(5094), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [180273] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4672), 1,
      aux_sym_let_binding_repeat1,
    STATE(4820), 1,
      sym_attribute,
    STATE(5054), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [180388] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [180453] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4822), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [180518] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [180583] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4824), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [180648] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4825), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [180713] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [180778] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4705), 1,
      aux_sym_let_binding_repeat1,
    STATE(4827), 1,
      sym_attribute,
    STATE(5143), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [180893] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4733), 1,
      aux_sym_let_binding_repeat1,
    STATE(4828), 1,
      sym_attribute,
    STATE(5025), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [181008] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(4829), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [181075] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4830), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [181140] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4668), 1,
      aux_sym_let_binding_repeat1,
    STATE(4831), 1,
      sym_attribute,
    STATE(5135), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [181255] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4677), 1,
      aux_sym_let_binding_repeat1,
    STATE(4832), 1,
      sym_attribute,
    STATE(5144), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [181370] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4676), 1,
      aux_sym_let_binding_repeat1,
    STATE(4833), 1,
      sym_attribute,
    STATE(5133), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [181485] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4834), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [181550] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4835), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [181615] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9054), 1,
      anon_sym_LT_DASH,
    STATE(4836), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [181682] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4837), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [181747] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4838), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [181812] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4712), 1,
      aux_sym_let_binding_repeat1,
    STATE(4839), 1,
      sym_attribute,
    STATE(5118), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [181927] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4744), 1,
      aux_sym_let_binding_repeat1,
    STATE(4840), 1,
      sym_attribute,
    STATE(5087), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [182042] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9056), 1,
      anon_sym_LT_DASH,
    STATE(4841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [182109] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4678), 1,
      aux_sym_let_binding_repeat1,
    STATE(4842), 1,
      sym_attribute,
    STATE(5140), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [182224] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4757), 1,
      aux_sym_let_binding_repeat1,
    STATE(4843), 1,
      sym_attribute,
    STATE(4998), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [182339] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4844), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [182404] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4751), 1,
      aux_sym_let_binding_repeat1,
    STATE(4845), 1,
      sym_attribute,
    STATE(5078), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [182519] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4748), 1,
      aux_sym_let_binding_repeat1,
    STATE(4846), 1,
      sym_attribute,
    STATE(5080), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [182634] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4847), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [182699] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4848), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [182764] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4849), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [182829] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4761), 1,
      aux_sym_let_binding_repeat1,
    STATE(4850), 1,
      sym_attribute,
    STATE(5049), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [182944] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4851), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [183009] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4852), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [183074] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4730), 1,
      aux_sym_let_binding_repeat1,
    STATE(4853), 1,
      sym_attribute,
    STATE(5073), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [183189] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(4579), 1,
      anon_sym_DOT,
    ACTIONS(4581), 1,
      anon_sym_POUND,
    ACTIONS(4583), 1,
      sym_hash_operator,
    STATE(4854), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [183260] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4755), 1,
      aux_sym_let_binding_repeat1,
    STATE(4855), 1,
      sym_attribute,
    STATE(5006), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [183375] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4856), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [183440] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [183505] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [183570] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4707), 1,
      aux_sym_let_binding_repeat1,
    STATE(4859), 1,
      sym_attribute,
    STATE(5055), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [183685] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4701), 1,
      aux_sym_let_binding_repeat1,
    STATE(4860), 1,
      sym_attribute,
    STATE(5092), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [183800] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4682), 1,
      aux_sym_let_binding_repeat1,
    STATE(4861), 1,
      sym_attribute,
    STATE(5031), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [183915] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4862), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [183980] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4863), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [184045] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4675), 1,
      aux_sym_let_binding_repeat1,
    STATE(4864), 1,
      sym_attribute,
    STATE(5138), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [184160] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4865), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [184225] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4684), 1,
      aux_sym_let_binding_repeat1,
    STATE(4866), 1,
      sym_attribute,
    STATE(5053), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [184340] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4867), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [184405] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4868), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [184470] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4869), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [184535] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [184600] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4871), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [184665] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4671), 1,
      aux_sym_let_binding_repeat1,
    STATE(4872), 1,
      sym_attribute,
    STATE(5062), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [184780] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4873), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [184845] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [184910] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4875), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [184975] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4876), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [185040] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(4579), 1,
      anon_sym_DOT,
    ACTIONS(4581), 1,
      anon_sym_POUND,
    ACTIONS(4583), 1,
      sym_hash_operator,
    STATE(4877), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [185111] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4724), 1,
      aux_sym_let_binding_repeat1,
    STATE(4878), 1,
      sym_attribute,
    STATE(5134), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [185226] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [185291] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4756), 1,
      aux_sym_let_binding_repeat1,
    STATE(4880), 1,
      sym_attribute,
    STATE(5066), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [185406] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4881), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [185471] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4882), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [185536] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4737), 1,
      aux_sym_let_binding_repeat1,
    STATE(4883), 1,
      sym_attribute,
    STATE(5058), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [185651] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4884), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [185716] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4885), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [185781] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4764), 1,
      aux_sym_let_binding_repeat1,
    STATE(4886), 1,
      sym_attribute,
    STATE(5004), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [185896] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [185961] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4888), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [186026] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4889), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [186091] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4890), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [186156] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4891), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [186221] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4892), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [186286] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4762), 1,
      aux_sym_let_binding_repeat1,
    STATE(4893), 1,
      sym_attribute,
    STATE(5112), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [186401] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [186466] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [186531] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4697), 1,
      aux_sym_let_binding_repeat1,
    STATE(4896), 1,
      sym_attribute,
    STATE(5032), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [186646] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4897), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [186711] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7733), 1,
      anon_sym_PERCENT,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4736), 1,
      aux_sym_let_binding_repeat1,
    STATE(4898), 1,
      sym_attribute,
    STATE(5041), 1,
      sym__attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [186826] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [186891] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4900), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [186956] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4901), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [187021] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4902), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [187086] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8961), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
      aux_sym_attribute_id_token1,
    ACTIONS(8959), 29,
      anon_sym_let,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [187151] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4904), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [187215] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [187279] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(4906), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7917), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [187343] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4907), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [187407] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [187471] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [187535] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [187599] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4911), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [187663] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(4589), 1,
      anon_sym_DOT,
    ACTIONS(4591), 1,
      anon_sym_POUND,
    ACTIONS(4593), 1,
      sym_hash_operator,
    STATE(4912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 28,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [187733] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4913), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [187797] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4914), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [187861] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(4915), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [187927] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4916), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [187991] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4917), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [188055] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4918), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [188119] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4919), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [188183] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [188247] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(4589), 1,
      anon_sym_DOT,
    ACTIONS(4591), 1,
      anon_sym_POUND,
    ACTIONS(4593), 1,
      sym_hash_operator,
    STATE(4921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 28,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [188317] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4922), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [188381] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [188445] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4924), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [188509] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4925), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [188573] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9058), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4926), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [188685] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4927), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [188749] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4928), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [188813] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [188877] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4930), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [188941] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4931), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [189005] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4932), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [189069] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [189133] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4934), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [189197] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4935), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [189261] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(4936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7907), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7909), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [189325] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4937), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [189389] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [189453] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4939), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [189517] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [189581] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9060), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4941), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [189693] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4942), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [189757] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [189821] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9062), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4944), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [189933] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(4589), 1,
      anon_sym_DOT,
    STATE(4945), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [189999] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4946), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [190063] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4947), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [190127] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9064), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4948), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [190239] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(4949), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7903), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7905), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [190303] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4950), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [190367] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4951), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [190431] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4952), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [190495] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4953), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [190559] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9066), 1,
      anon_sym_LT_DASH,
    STATE(4954), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 28,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [190625] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4955), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [190689] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4956), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [190753] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4957), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [190817] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(4958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7911), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7913), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [190881] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4959), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [190945] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4960), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [191009] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4961), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [191073] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4962), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [191137] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4963), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [191201] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(4964), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7996), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7998), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [191267] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4965), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [191331] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4966), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [191395] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(4967), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7923), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [191459] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4968), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [191523] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [191587] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4970), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [191651] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4971), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [191715] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4972), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [191779] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4973), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [191843] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4974), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [191907] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4975), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [191971] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9068), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4976), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [192083] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(4977), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7939), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [192147] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4978), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [192211] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(4979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [192277] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4980), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [192341] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9070), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4981), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [192453] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(4982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7925), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7927), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [192517] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4983), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [192581] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4984), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [192645] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4985), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [192709] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [192773] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(4987), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7935), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [192837] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [192901] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4989), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [192965] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4990), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [193029] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4991), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [193093] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8851), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9072), 1,
      anon_sym_DASH_GT,
    STATE(4629), 1,
      aux_sym_let_binding_repeat1,
    STATE(4992), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [193205] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(4993), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7929), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7931), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [193269] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9074), 1,
      anon_sym_LT_DASH,
    STATE(4994), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8002), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8004), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [193334] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(4995), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8296), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [193399] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4688), 1,
      aux_sym_let_binding_repeat1,
    STATE(4996), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [193508] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(4997), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8092), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8094), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [193571] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4758), 1,
      aux_sym_let_binding_repeat1,
    STATE(4998), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [193680] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(4999), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8088), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8090), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [193743] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5000), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8084), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8086), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [193806] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5001), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8336), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [193869] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4725), 1,
      aux_sym_let_binding_repeat1,
    STATE(5002), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [193978] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5003), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8002), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8004), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [194041] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4740), 1,
      aux_sym_let_binding_repeat1,
    STATE(5004), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [194150] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5005), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8076), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8078), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [194213] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4763), 1,
      aux_sym_let_binding_repeat1,
    STATE(5006), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [194322] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5007), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8144), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8146), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [194385] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4976), 1,
      aux_sym_let_binding_repeat1,
    STATE(5008), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [194494] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5009), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8248), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [194557] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4948), 1,
      aux_sym_let_binding_repeat1,
    STATE(5010), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [194666] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(5011), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7996), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7998), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [194731] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4670), 1,
      aux_sym_let_binding_repeat1,
    STATE(5012), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [194840] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5013), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8104), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8106), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [194903] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5014), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8244), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [194966] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7907), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7909), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [195029] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4694), 1,
      aux_sym_let_binding_repeat1,
    STATE(5016), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [195138] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8128), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8130), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [195201] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8132), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8134), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [195264] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7903), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7905), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [195327] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5020), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8136), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8138), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [195390] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5021), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8240), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [195453] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5022), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8340), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [195516] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5023), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8096), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8098), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [195579] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8140), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8142), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [195642] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4667), 1,
      aux_sym_let_binding_repeat1,
    STATE(5025), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [195751] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5026), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8236), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [195814] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4771), 1,
      aux_sym_let_binding_repeat1,
    STATE(5027), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [195923] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4696), 1,
      aux_sym_let_binding_repeat1,
    STATE(5028), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [196032] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4699), 1,
      aux_sym_let_binding_repeat1,
    STATE(5029), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [196141] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4599), 1,
      anon_sym_DOT,
    ACTIONS(4601), 1,
      anon_sym_POUND,
    ACTIONS(4603), 1,
      sym_hash_operator,
    STATE(5030), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8228), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [196210] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4714), 1,
      aux_sym_let_binding_repeat1,
    STATE(5031), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [196319] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4706), 1,
      aux_sym_let_binding_repeat1,
    STATE(5032), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [196428] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5033), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8148), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8150), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [196491] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5034), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8156), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [196554] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4981), 1,
      aux_sym_let_binding_repeat1,
    STATE(5035), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [196663] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4767), 1,
      aux_sym_let_binding_repeat1,
    STATE(5036), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [196772] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4718), 1,
      aux_sym_let_binding_repeat1,
    STATE(5037), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [196881] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8120), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8122), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [196944] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4741), 1,
      aux_sym_let_binding_repeat1,
    STATE(5039), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [197053] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7907), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7909), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [197116] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4734), 1,
      aux_sym_let_binding_repeat1,
    STATE(5041), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [197225] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8232), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [197288] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8264), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [197351] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8060), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8062), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [197414] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5045), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7996), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7998), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [197477] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8080), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8082), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [197540] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4722), 1,
      aux_sym_let_binding_repeat1,
    STATE(5047), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [197649] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5048), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7917), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [197712] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4745), 1,
      aux_sym_let_binding_repeat1,
    STATE(5049), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [197821] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9078), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5050), 2,
      sym_attribute,
      aux_sym__structure_repeat1,
    ACTIONS(9081), 17,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9076), 29,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [197886] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4691), 1,
      aux_sym_let_binding_repeat1,
    STATE(5051), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [197995] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9083), 1,
      anon_sym_lazy,
    STATE(2948), 1,
      sym_constructor_path,
    STATE(3221), 1,
      sym_tag,
    STATE(5052), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(20453), 1,
      sym__effect_pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(12929), 13,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [198106] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4768), 1,
      aux_sym_let_binding_repeat1,
    STATE(5053), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [198215] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4719), 1,
      aux_sym_let_binding_repeat1,
    STATE(5054), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [198324] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4749), 1,
      aux_sym_let_binding_repeat1,
    STATE(5055), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [198433] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4739), 1,
      aux_sym_let_binding_repeat1,
    STATE(5056), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [198542] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5057), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8112), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8114), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [198605] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4729), 1,
      aux_sym_let_binding_repeat1,
    STATE(5058), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [198714] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5059), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8160), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [198777] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4693), 1,
      aux_sym_let_binding_repeat1,
    STATE(5060), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [198886] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5061), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8070), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [198949] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4686), 1,
      aux_sym_let_binding_repeat1,
    STATE(5062), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [199058] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5063), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8268), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [199121] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5064), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8180), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [199184] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5065), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8310), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [199247] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4711), 1,
      aux_sym_let_binding_repeat1,
    STATE(5066), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [199356] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5067), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8108), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8110), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [199419] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5068), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8164), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [199482] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4726), 1,
      aux_sym_let_binding_repeat1,
    STATE(5069), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [199591] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5070), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8168), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [199654] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4743), 1,
      aux_sym_let_binding_repeat1,
    STATE(5071), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [199763] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8304), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8306), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [199826] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4728), 1,
      aux_sym_let_binding_repeat1,
    STATE(5073), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [199935] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8172), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [199998] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5075), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8314), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [200061] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4599), 1,
      anon_sym_DOT,
    ACTIONS(4601), 1,
      anon_sym_POUND,
    ACTIONS(4603), 1,
      sym_hash_operator,
    STATE(5076), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8100), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8102), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [200130] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8328), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [200193] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4754), 1,
      aux_sym_let_binding_repeat1,
    STATE(5078), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [200302] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5079), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7917), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [200365] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4747), 1,
      aux_sym_let_binding_repeat1,
    STATE(5080), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [200474] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8318), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [200537] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5082), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7903), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7905), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [200600] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5083), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7925), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7927), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [200663] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8192), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [200726] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9085), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5085), 2,
      sym_attribute,
      aux_sym__structure_repeat1,
    ACTIONS(9081), 18,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9076), 28,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [200791] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5086), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7929), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7931), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [200854] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4700), 1,
      aux_sym_let_binding_repeat1,
    STATE(5087), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [200963] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5088), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7911), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7913), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [201026] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5089), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7923), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [201089] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9083), 1,
      anon_sym_lazy,
    STATE(2948), 1,
      sym_constructor_path,
    STATE(3221), 1,
      sym_tag,
    STATE(5090), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(20392), 1,
      sym__effect_pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(12929), 13,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [201200] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5091), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7939), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [201263] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4738), 1,
      aux_sym_let_binding_repeat1,
    STATE(5092), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [201372] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(5093), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7996), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7998), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [201437] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4702), 1,
      aux_sym_let_binding_repeat1,
    STATE(5094), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [201546] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5095), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7935), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [201609] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5096), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8302), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [201672] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4947), 1,
      anon_sym_LPAREN,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(4991), 1,
      sym__uppercase_identifier,
    ACTIONS(4993), 1,
      aux_sym_tag_token1,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9083), 1,
      anon_sym_lazy,
    STATE(2948), 1,
      sym_constructor_path,
    STATE(3221), 1,
      sym_tag,
    STATE(5097), 1,
      sym_attribute,
    STATE(8442), 1,
      sym__constructor_name,
    STATE(20293), 1,
      sym__effect_pattern,
    STATE(20471), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(13110), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(12929), 13,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [201783] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4759), 1,
      aux_sym_let_binding_repeat1,
    STATE(5098), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [201892] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4944), 1,
      aux_sym_let_binding_repeat1,
    STATE(5099), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [202001] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5100), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7939), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202064] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(5101), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8296), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202129] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5102), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7923), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202192] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8224), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202255] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5104), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7911), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7913), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202318] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5105), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8124), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8126), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202381] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5106), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7935), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202444] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5107), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7929), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7931), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202507] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4941), 1,
      aux_sym_let_binding_repeat1,
    STATE(5108), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [202616] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5109), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7925), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7927), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202679] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8074), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202742] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5111), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8064), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8066), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202805] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4770), 1,
      aux_sym_let_binding_repeat1,
    STATE(5112), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [202914] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8220), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202977] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4926), 1,
      aux_sym_let_binding_repeat1,
    STATE(5114), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [203086] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8292), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203149] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8288), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203212] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5117), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8052), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8054), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203275] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4710), 1,
      aux_sym_let_binding_repeat1,
    STATE(5118), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [203384] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4599), 1,
      anon_sym_DOT,
    STATE(5119), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8176), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203449] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4992), 1,
      aux_sym_let_binding_repeat1,
    STATE(5120), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [203558] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8284), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203621] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5122), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8278), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8280), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203684] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8184), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203747] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8056), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8058), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203810] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8196), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203873] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8272), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203936] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5127), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8212), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8214), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203999] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5128), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8322), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [204062] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5129), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8116), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8118), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [204125] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5130), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8208), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8210), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [204188] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5131), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8204), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [204251] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8364), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [204314] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4673), 1,
      aux_sym_let_binding_repeat1,
    STATE(5133), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [204423] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4753), 1,
      aux_sym_let_binding_repeat1,
    STATE(5134), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [204532] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4680), 1,
      aux_sym_let_binding_repeat1,
    STATE(5135), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [204641] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8200), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [204704] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8360), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [204767] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4685), 1,
      aux_sym_let_binding_repeat1,
    STATE(5138), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [204876] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5139), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8356), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [204939] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4735), 1,
      aux_sym_let_binding_repeat1,
    STATE(5140), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [205048] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5141), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8350), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8352), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [205111] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9088), 1,
      anon_sym_COLON,
    STATE(5142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8548), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [205176] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4720), 1,
      aux_sym_let_binding_repeat1,
    STATE(5143), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [205285] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4679), 1,
      aux_sym_let_binding_repeat1,
    STATE(5144), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10267), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5475), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10266), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [205394] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8274), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8276), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [205457] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5146), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8128), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8130), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [205519] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8240), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [205581] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7903), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7905), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [205643] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5149), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8108), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8110), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [205705] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5150), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8148), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8150), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [205767] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(5151), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8296), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [205831] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5152), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8292), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [205893] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5153), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8196), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [205955] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5154), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8248), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206017] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(5155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8296), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206081] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5156), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8070), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206143] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5157), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8064), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8066), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206205] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5158), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8140), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8142), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206267] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8328), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206329] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9090), 1,
      anon_sym_LT_DASH,
    STATE(5160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8002), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8004), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206393] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5161), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8136), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8138), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206455] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8132), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8134), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206517] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7907), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7909), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206579] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8322), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206641] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8128), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8130), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206703] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5166), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8074), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206765] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5167), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8124), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8126), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206827] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8328), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206889] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5169), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8120), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8122), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206951] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8116), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8118), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207013] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8356), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207075] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8360), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207137] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8156), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207199] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8284), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207261] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5175), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8160), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207323] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8336), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207385] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5177), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8164), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207447] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8168), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207509] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8244), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207571] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8172), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207633] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4619), 1,
      anon_sym_DOT,
    STATE(5181), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8176), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207697] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8112), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8114), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207759] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5183), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8080), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8082), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207821] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9092), 1,
      anon_sym_COLON,
    STATE(5184), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8548), 28,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [207885] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8180), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207947] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8076), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8078), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208009] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(5187), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8296), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208073] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8084), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8086), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208135] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8092), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8094), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208197] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8088), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8090), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208259] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5191), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8084), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8086), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208321] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5192), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8076), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8078), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208383] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5193), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8310), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208445] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5194), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8088), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8090), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208507] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8184), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208569] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8092), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8094), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208631] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9094), 1,
      anon_sym_LT_DASH,
    STATE(5197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8002), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8004), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208695] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4609), 1,
      anon_sym_DOT,
    ACTIONS(4611), 1,
      anon_sym_POUND,
    ACTIONS(4613), 1,
      sym_hash_operator,
    STATE(5198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8100), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8102), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208763] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4609), 1,
      anon_sym_DOT,
    ACTIONS(4611), 1,
      anon_sym_POUND,
    ACTIONS(4613), 1,
      sym_hash_operator,
    STATE(5199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8228), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208831] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8264), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208893] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8108), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8110), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208955] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5202), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8070), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209017] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8060), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8062), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209079] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5204), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7996), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7998), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209141] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5205), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8112), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8114), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209203] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5206), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8144), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8146), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209265] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(5207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8296), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209329] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5208), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8350), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8352), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209391] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5209), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8340), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209453] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8056), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8058), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209515] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8116), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8118), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209577] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5212), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8268), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209639] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5213), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8272), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209701] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5214), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8120), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8122), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209763] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5215), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8124), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8126), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209825] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5216), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8002), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8004), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209887] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8356), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209949] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8274), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8276), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210011] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5219), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8132), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8134), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210073] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5220), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8200), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210135] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5221), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8204), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210197] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5222), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8278), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8280), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210259] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5223), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8136), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8138), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210321] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8140), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8142), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210383] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5225), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8288), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210445] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5226), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8184), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210507] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5227), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8304), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8306), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210569] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8052), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8054), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210631] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5229), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8192), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210693] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(5230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [210757] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5231), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8302), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210819] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5232), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8224), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210881] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5233), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8302), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210943] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5234), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8360), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211005] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5235), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8148), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8150), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211067] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8310), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211129] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5237), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8336), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211191] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5238), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8284), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211253] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5239), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8314), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211315] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5240), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8236), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211377] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5241), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8314), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211439] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5242), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9098), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9096), 29,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [211501] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5243), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8220), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211563] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4619), 1,
      anon_sym_DOT,
    ACTIONS(4621), 1,
      anon_sym_POUND,
    ACTIONS(4623), 1,
      sym_hash_operator,
    STATE(5244), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8228), 22,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211631] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5245), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8156), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211693] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5246), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8364), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211755] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5247), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8212), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8214), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211817] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8304), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8306), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211879] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(5249), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8296), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211943] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5250), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8064), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8066), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212005] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5251), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8074), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212067] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5252), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8208), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8210), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212129] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5253), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8080), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8082), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212191] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5254), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8096), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8098), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212253] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5255), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8160), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212315] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5256), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8104), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8106), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212377] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8164), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212439] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5258), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8168), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212501] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5259), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8144), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8146), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212563] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5260), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8340), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212625] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8180), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212687] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5262), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8322), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212749] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8212), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8214), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212811] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8052), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8054), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212873] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5265), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8192), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212935] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5266), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8220), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212997] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8292), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213059] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5268), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8196), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213121] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5269), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8056), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8058), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213183] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8172), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213245] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5271), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8096), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8098), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213307] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5272), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7996), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7998), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213369] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5273), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9098), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9096), 28,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [213431] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8278), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8280), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213493] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5275), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8232), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213555] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8622), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [213617] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4609), 1,
      anon_sym_DOT,
    STATE(5277), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8176), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213681] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8274), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8276), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213743] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5279), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8224), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213805] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5280), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7917), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213867] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5281), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8288), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213929] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4619), 1,
      anon_sym_DOT,
    ACTIONS(4621), 1,
      anon_sym_POUND,
    ACTIONS(4623), 1,
      sym_hash_operator,
    STATE(5282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8100), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8102), 22,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213997] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5283), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8272), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214059] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5284), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7911), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7913), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214121] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5285), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7923), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214183] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7939), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214245] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(5287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8296), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214309] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5288), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8232), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214371] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8236), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214433] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5290), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8264), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214495] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8318), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214557] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5292), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8060), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8062), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214619] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8240), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214681] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [214743] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8244), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214805] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5296), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8268), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214867] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8200), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214929] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5298), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8204), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214991] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5299), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8002), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8004), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [215053] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8350), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8352), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [215115] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(5301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [215179] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8104), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8106), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [215241] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8318), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [215303] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5304), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8248), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [215365] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5305), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7935), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [215427] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5306), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8364), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [215489] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(5307), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7996), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7998), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [215553] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5308), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7929), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7931), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [215615] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5309), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8208), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8210), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [215677] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5310), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7925), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7927), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [215739] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5311), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8136), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8138), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [215800] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5312), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8124), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8126), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [215861] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8318), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [215922] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5314), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8322), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [215983] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9100), 1,
      anon_sym_DOT_DOT,
    STATE(5315), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5077), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(5079), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [216046] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5316), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8622), 28,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [216107] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5317), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8268), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [216168] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5318), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8272), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [216229] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5319), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8156), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [216290] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5320), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8160), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [216351] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5321), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [216412] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5322), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8132), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8134), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [216473] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5323), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8274), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8276), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [216534] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5324), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8278), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8280), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [216595] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9102), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9104), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [216656] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8140), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8142), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [216717] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5327), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8336), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [216778] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8148), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8150), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [216839] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8340), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [216900] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5330), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8164), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [216961] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5331), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8168), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [217022] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8070), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [217083] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5333), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8292), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [217144] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5334), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8302), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [217205] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(5335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8296), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [217268] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8350), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8352), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [217329] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5337), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8172), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [217390] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5338), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8310), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [217451] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5339), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8356), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [217512] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5340), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8120), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8122), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [217573] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5341), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8360), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [217634] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9106), 1,
      anon_sym_LT_DASH,
    STATE(5342), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8002), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8004), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [217697] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5343), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8288), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [217758] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5344), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 28,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [217819] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5345), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8314), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [217880] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8328), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [217941] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5347), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8116), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8118), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218002] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5348), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8112), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8114), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218063] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4689), 1,
      anon_sym_DOT,
    STATE(5349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8176), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218126] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5350), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8184), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218187] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8108), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8110), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218248] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5352), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8128), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8130), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218309] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(5353), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8296), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218372] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5354), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8092), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8094), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218433] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5355), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8364), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218494] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9108), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9110), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218555] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8304), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8306), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218616] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(5358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8296), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218679] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4689), 1,
      anon_sym_DOT,
    ACTIONS(4691), 1,
      anon_sym_POUND,
    ACTIONS(4693), 1,
      sym_hash_operator,
    STATE(5359), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8100), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8102), 22,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218746] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5360), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8314), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218807] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8284), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218868] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5362), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8088), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8090), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218929] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9112), 1,
      anon_sym_DOT_DOT,
    STATE(5363), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5079), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(5077), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218992] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8304), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8306), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [219053] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5365), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8288), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [219114] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5366), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8200), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [219175] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5367), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8302), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [219236] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8084), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8086), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [219297] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8310), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [219358] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5370), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8204), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [219419] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4689), 1,
      anon_sym_DOT,
    ACTIONS(4691), 1,
      anon_sym_POUND,
    ACTIONS(4693), 1,
      sym_hash_operator,
    STATE(5371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8228), 22,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [219486] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5372), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8336), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [219547] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8284), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [219608] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8076), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8078), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [219669] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5375), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8208), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8210), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [219730] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [219791] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8212), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8214), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [219852] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5378), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8220), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [219913] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5379), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8224), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [219974] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8104), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8106), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [220035] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [220096] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8056), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8058), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [220157] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8232), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [220218] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8052), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8054), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [220279] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(5385), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8296), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [220342] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5386), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9116), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9114), 34,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [220403] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5387), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8236), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [220464] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5388), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8292), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [220525] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8240), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [220586] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9120), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9118), 34,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [220647] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8244), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [220708] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5392), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8060), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8062), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [220769] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5393), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8248), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [220830] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5394), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9102), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9104), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [220891] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9122), 1,
      anon_sym_COLON,
    STATE(5395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8548), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8550), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [220954] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7996), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7998), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [221015] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5397), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8064), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8066), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [221076] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8074), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [221137] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5399), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8080), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8082), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [221198] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5400), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8340), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [221259] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8322), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [221320] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8318), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [221381] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5403), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8318), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [221442] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8322), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [221503] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(5405), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [221566] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8340), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [221627] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5407), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8096), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8098), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [221688] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9108), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9110), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [221749] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5409), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8196), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [221810] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8264), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [221871] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5411), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8002), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8004), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [221932] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8192), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [221993] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8180), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [222054] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8328), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [222115] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5415), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8288), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [222176] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [222237] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5417), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8336), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [222298] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(5418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [222361] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5419), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9126), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9124), 34,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [222422] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5420), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8310), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [222483] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5421), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8292), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [222544] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5422), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8144), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8146), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [222605] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5423), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8302), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [222666] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5424), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9130), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9128), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [222726] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5425), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8284), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [222786] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5426), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8322), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [222846] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [222906] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9134), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9132), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [222966] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [223026] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5430), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9136), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9138), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [223086] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [223146] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [223206] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5433), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [223266] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9140), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9142), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [223326] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [223386] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [223446] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5437), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [223506] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5438), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8310), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [223566] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [223626] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5440), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9144), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9146), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [223686] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5441), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [223746] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5442), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [223806] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9148), 1,
      anon_sym_DOT_DOT,
    STATE(5443), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5077), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(5079), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [223868] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5444), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [223928] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5445), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8302), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [223988] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5446), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9132), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9134), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [224048] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(5447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [224110] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5448), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9150), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9152), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [224170] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5449), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8292), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [224230] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5450), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9154), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9156), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [224290] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5451), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8288), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [224350] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5452), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9158), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [224410] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5453), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9164), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9162), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [224470] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5454), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [224530] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9168), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9166), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [224590] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5456), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9172), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9170), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [224650] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5457), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9174), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9176), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [224710] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9180), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9178), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [224770] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9182), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [224830] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5460), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8336), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [224890] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5461), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9162), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9164), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [224950] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5462), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9170), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9172), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [225010] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8228), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [225070] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9188), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9186), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [225130] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5465), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9186), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9188), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [225190] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5466), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [225250] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9192), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9190), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [225310] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5543), 1,
      anon_sym_COMMA,
    ACTIONS(5549), 1,
      anon_sym_COLON_COLON,
    STATE(5468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9196), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9194), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [225374] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [225434] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8340), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [225494] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9152), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9150), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [225554] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [225614] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5473), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [225674] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9200), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9198), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [225734] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5475), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9204), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9202), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [225794] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5476), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9206), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9208), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [225854] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9210), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9212), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [225914] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [225974] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8622), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8624), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [226034] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5480), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8328), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [226094] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5481), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9176), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9174), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [226154] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9214), 1,
      anon_sym_DOT_DOT,
    STATE(5482), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5079), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(5077), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [226216] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5077), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(5079), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [226276] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5484), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9216), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9218), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [226336] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9222), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9220), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [226396] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5486), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9226), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [226456] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9166), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9168), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [226516] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5488), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9220), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9222), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [226576] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9226), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9224), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [226636] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5490), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8278), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8280), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [226696] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5491), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8340), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [226756] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5492), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8322), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [226816] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8274), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8276), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [226876] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5494), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [226936] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5495), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8318), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [226996] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5496), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9230), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9228), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [227056] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5497), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8318), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [227116] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5498), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8060), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8062), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [227176] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5499), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [227236] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5500), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9138), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9136), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [227296] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9102), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9104), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [227356] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8272), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [227416] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9232), 1,
      anon_sym_LT_DASH,
    STATE(5503), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [227478] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9184), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [227538] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5505), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9218), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9216), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [227598] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9202), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9204), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [227658] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9234), 1,
      anon_sym_COLON,
    STATE(5507), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8548), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8550), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [227720] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5508), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9198), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9200), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [227780] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5509), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9238), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9236), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [227840] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5510), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9102), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9104), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [227900] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5511), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9178), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9180), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [227960] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5512), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9190), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9192), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [228020] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5513), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9146), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9144), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [228080] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5514), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9240), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9242), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [228140] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5515), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9244), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9246), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [228200] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5516), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [228260] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5517), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9250), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9248), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [228320] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9254), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9252), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [228380] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5519), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5079), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(5077), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [228440] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5520), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9158), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9160), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [228500] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5521), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9256), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9258), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [228560] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5522), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9108), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9110), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [228620] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9108), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9110), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [228680] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5524), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9156), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9154), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [228740] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5525), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8314), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [228800] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5526), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7996), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(7998), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [228860] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5527), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9260), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9262), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [228920] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9264), 1,
      anon_sym_COLON,
    STATE(5528), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8548), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8550), 22,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [228982] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5529), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8268), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [229042] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5530), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9142), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9140), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [229102] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5531), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9128), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9130), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [229162] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5532), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8364), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [229222] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5533), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9258), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9256), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [229282] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [229342] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5495), 1,
      anon_sym_COLON_COLON,
    STATE(5535), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9266), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9268), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [229404] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5536), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8264), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [229464] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5537), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9262), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9260), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [229524] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9246), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9244), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [229584] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5539), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9252), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9254), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [229644] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5540), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8350), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8352), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [229704] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5541), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9272), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9270), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [229764] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5542), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9276), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9274), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [229824] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5543), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9228), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9230), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [229884] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5544), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8288), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [229944] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9212), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9210), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [230004] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5546), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8292), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [230064] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5547), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [230124] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5479), 1,
      anon_sym_COMMA,
    ACTIONS(5495), 1,
      anon_sym_COLON_COLON,
    STATE(5548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9196), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9194), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [230188] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5549), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9236), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9238), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [230248] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5550), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8360), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [230308] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5551), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8302), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [230368] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5552), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8356), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [230428] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5553), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9242), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9240), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [230488] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8304), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8306), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [230548] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5555), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9270), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9272), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [230608] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5556), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8310), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [230668] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9274), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9276), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [230728] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5558), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9208), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9206), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [230788] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5559), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9278), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9280), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [230848] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5549), 1,
      anon_sym_COLON_COLON,
    STATE(5560), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9268), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9266), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [230910] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5549), 1,
      anon_sym_COLON_COLON,
    STATE(5561), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9284), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9282), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [230972] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5562), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [231032] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5495), 1,
      anon_sym_COLON_COLON,
    STATE(5563), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9282), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9284), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [231094] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5564), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8336), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [231154] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5565), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9248), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9250), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [231214] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9280), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9278), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [231274] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5567), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8272), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [231333] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5568), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8278), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8280), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [231392] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5569), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [231451] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5570), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [231510] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [231569] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5572), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [231628] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5573), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8228), 22,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [231687] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5574), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9158), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9160), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [231746] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5575), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9166), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9168), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [231805] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5576), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8274), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8276), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [231864] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5577), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9256), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9258), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [231923] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5578), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [231982] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8350), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8352), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [232041] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5580), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9228), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9230), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [232100] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5581), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9140), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9142), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [232159] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5582), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8228), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [232218] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5583), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9144), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9146), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [232277] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5584), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [232336] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5585), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8356), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [232395] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5586), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8360), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [232454] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5587), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8364), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [232513] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5588), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8364), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [232572] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5589), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8360), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [232631] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5590), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8356), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [232690] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5591), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9174), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9176), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [232749] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5592), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [232808] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5593), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8268), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [232867] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5594), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9206), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9208), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [232926] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5595), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9158), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9160), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [232985] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5596), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [233044] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5597), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9206), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9208), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [233103] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9286), 1,
      anon_sym_LT_DASH,
    STATE(5598), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [233164] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5599), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9256), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9258), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [233223] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5600), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8622), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8624), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [233282] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5601), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8350), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8352), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [233341] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(5602), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [233402] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5603), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [233461] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5604), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9236), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9238), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [233520] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [233579] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5606), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9136), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9138), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [233638] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9190), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9192), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [233697] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(5608), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [233758] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5609), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [233817] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5610), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9184), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [233876] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5611), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [233935] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5612), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9178), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9180), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [233994] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5613), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [234053] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5614), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [234112] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5615), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [234171] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5616), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [234230] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5617), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [234289] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(5618), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [234350] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5619), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [234409] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5620), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9198), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9200), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [234468] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5621), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [234527] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5622), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9228), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9230), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [234586] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5623), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [234645] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5624), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9220), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9222), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [234704] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5625), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [234763] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5626), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9240), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9242), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [234822] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5627), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9226), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [234881] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9144), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9146), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [234940] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5629), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9154), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9156), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [234999] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5630), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9140), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9142), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [235058] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5631), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9174), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9176), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [235117] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9210), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9212), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [235176] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5633), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [235235] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5634), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9128), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9130), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [235294] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5635), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9216), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9218), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [235353] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5739), 1,
      anon_sym_COLON_COLON,
    STATE(5636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9268), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9266), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [235414] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5637), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9252), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9254), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [235473] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5733), 1,
      anon_sym_COMMA,
    ACTIONS(5739), 1,
      anon_sym_COLON_COLON,
    STATE(5638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9196), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9194), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [235536] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5739), 1,
      anon_sym_COLON_COLON,
    STATE(5639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9284), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9282), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [235597] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5640), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9260), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9262), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [235656] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5641), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9248), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9250), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [235715] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5642), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [235774] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [235833] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [235892] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5645), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [235951] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5646), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [236010] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5647), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9278), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9280), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [236069] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5648), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [236128] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [236187] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5650), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9274), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9276), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [236246] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5651), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9270), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9272), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [236305] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5652), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9132), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9134), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [236364] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9150), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9152), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [236423] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5654), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9162), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9164), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [236482] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [236541] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5656), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9170), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9172), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [236600] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5657), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7996), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(7998), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [236659] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9186), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9188), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [236718] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5659), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8264), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [236777] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9288), 1,
      anon_sym_COLON,
    STATE(5660), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8548), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8550), 22,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [236838] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5661), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [236897] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9290), 1,
      anon_sym_LT_DASH,
    STATE(5662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [236958] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5663), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9244), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9246), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [237017] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5664), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9202), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9204), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [237076] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5665), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [237135] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5666), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [237194] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [237253] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5077), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(5079), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [237312] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [237371] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5670), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9236), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9238), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [237430] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5671), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [237489] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5672), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9136), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9138), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [237548] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5673), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7996), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(7998), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [237607] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8060), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8062), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [237666] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5675), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8622), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8624), 22,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [237725] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5676), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9190), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9192), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [237784] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8264), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [237843] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9184), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [237902] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5679), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9178), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9180), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [237961] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9198), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9200), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [238020] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5681), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [238079] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5682), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [238138] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [238197] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5684), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [238256] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5685), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9186), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9188), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [238315] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5686), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9220), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9222), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [238374] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5687), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9166), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9168), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [238433] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5688), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8268), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [238492] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5689), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [238551] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5690), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [238610] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5691), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9226), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [238669] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5692), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9154), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9156), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [238728] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5693), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9210), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9212), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [238787] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5694), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [238846] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5695), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9128), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9130), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [238905] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5696), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9216), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9218), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [238964] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5751), 1,
      anon_sym_COLON_COLON,
    STATE(5697), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9266), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9268), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [239025] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5698), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8272), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [239084] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5699), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9252), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9254), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [239143] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5700), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [239202] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5745), 1,
      anon_sym_COMMA,
    ACTIONS(5751), 1,
      anon_sym_COLON_COLON,
    STATE(5701), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9194), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9196), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [239265] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5751), 1,
      anon_sym_COLON_COLON,
    STATE(5702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9282), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9284), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [239326] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5703), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9260), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9262), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [239385] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5704), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9248), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9250), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [239444] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [239503] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5706), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [239562] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5707), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8274), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8276), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [239621] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5708), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [239680] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5709), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9278), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9280), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [239739] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5710), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8278), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8280), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [239798] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5711), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9274), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9276), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [239857] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5712), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [239916] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5713), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [239975] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5714), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9270), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9272), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [240034] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5715), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9132), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9134), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [240093] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5716), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9150), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9152), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [240152] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5717), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9162), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9164), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [240211] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5718), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [240270] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5719), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9170), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9172), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [240329] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5720), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [240388] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5721), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9240), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9242), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [240447] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5722), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [240506] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5723), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9244), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9246), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [240565] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5724), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [240624] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5725), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8060), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8062), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [240683] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [240742] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5727), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [240801] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5728), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [240860] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5729), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9202), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9204), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [240919] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5730), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [240978] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5079), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(5077), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [241037] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5732), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241096] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5733), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241155] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(4819), 1,
      anon_sym_DOT,
    ACTIONS(4821), 1,
      anon_sym_POUND,
    ACTIONS(4823), 1,
      sym_hash_operator,
    STATE(5734), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241220] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5735), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241279] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(4819), 1,
      anon_sym_DOT,
    ACTIONS(4821), 1,
      anon_sym_POUND,
    ACTIONS(4823), 1,
      sym_hash_operator,
    STATE(5736), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241344] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241403] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5738), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241462] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5739), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241521] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5740), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241580] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5741), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241639] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5742), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241698] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5743), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241757] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5744), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241816] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5745), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241875] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5746), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241934] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5747), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241993] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5748), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [242052] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5749), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [242111] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5750), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [242170] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5751), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [242229] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5752), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [242288] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(4819), 1,
      anon_sym_DOT,
    STATE(5753), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [242349] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5754), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [242407] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5755), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [242465] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5756), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [242523] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [242581] = 25,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7159), 1,
      sym__lowercase_identifier,
    ACTIONS(7167), 1,
      anon_sym_LBRACK,
    ACTIONS(7173), 1,
      anon_sym_LBRACE,
    ACTIONS(7175), 1,
      anon_sym_POUND,
    ACTIONS(7177), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7179), 1,
      anon_sym_begin,
    ACTIONS(7185), 1,
      aux_sym_number_token1,
    ACTIONS(7187), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7189), 1,
      anon_sym_SQUOTE,
    ACTIONS(7191), 1,
      anon_sym_DQUOTE,
    ACTIONS(7193), 1,
      sym__uppercase_identifier,
    ACTIONS(7195), 1,
      aux_sym_tag_token1,
    ACTIONS(9292), 1,
      anon_sym_LPAREN,
    ACTIONS(9294), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9296), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(5758), 1,
      sym_attribute,
    STATE(7743), 1,
      sym__simple_pattern,
    STATE(7774), 1,
      sym__constructor_name,
    STATE(20457), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7169), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7794), 2,
      sym__constant,
      sym_signed_number,
    STATE(7775), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7796), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [242679] = 25,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(7155), 1,
      anon_sym_POUND,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9298), 1,
      anon_sym_LPAREN,
    ACTIONS(9300), 1,
      sym__uppercase_identifier,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    STATE(5759), 1,
      sym_attribute,
    STATE(8923), 1,
      sym__constructor_name,
    STATE(13113), 1,
      sym__simple_pattern,
    STATE(18293), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(12929), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [242777] = 25,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7587), 1,
      sym__lowercase_identifier,
    ACTIONS(7595), 1,
      anon_sym_LBRACK,
    ACTIONS(7601), 1,
      anon_sym_LBRACE,
    ACTIONS(7605), 1,
      anon_sym_POUND,
    ACTIONS(7607), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7609), 1,
      anon_sym_begin,
    ACTIONS(7617), 1,
      aux_sym_number_token1,
    ACTIONS(7619), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7621), 1,
      anon_sym_SQUOTE,
    ACTIONS(7623), 1,
      anon_sym_DQUOTE,
    ACTIONS(7625), 1,
      sym__uppercase_identifier,
    ACTIONS(7627), 1,
      aux_sym_tag_token1,
    ACTIONS(9304), 1,
      anon_sym_LPAREN,
    ACTIONS(9306), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9308), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(5760), 1,
      sym_attribute,
    STATE(8561), 1,
      sym__simple_pattern,
    STATE(8748), 1,
      sym__constructor_name,
    STATE(18492), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7597), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8707), 2,
      sym__constant,
      sym_signed_number,
    STATE(8756), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8762), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [242875] = 25,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7199), 1,
      sym__lowercase_identifier,
    ACTIONS(7207), 1,
      anon_sym_LBRACK,
    ACTIONS(7213), 1,
      anon_sym_LBRACE,
    ACTIONS(7215), 1,
      anon_sym_POUND,
    ACTIONS(7217), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7219), 1,
      anon_sym_begin,
    ACTIONS(7225), 1,
      aux_sym_number_token1,
    ACTIONS(7227), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7229), 1,
      anon_sym_SQUOTE,
    ACTIONS(7231), 1,
      anon_sym_DQUOTE,
    ACTIONS(7233), 1,
      sym__uppercase_identifier,
    ACTIONS(7235), 1,
      aux_sym_tag_token1,
    ACTIONS(9310), 1,
      anon_sym_LPAREN,
    ACTIONS(9312), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9314), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(5761), 1,
      sym_attribute,
    STATE(7922), 1,
      sym__simple_pattern,
    STATE(8040), 1,
      sym__constructor_name,
    STATE(18728), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7209), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8037), 2,
      sym__constant,
      sym_signed_number,
    STATE(8039), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8089), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [242973] = 25,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5465), 1,
      sym__lowercase_identifier,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5489), 1,
      anon_sym_LBRACE,
    ACTIONS(5493), 1,
      anon_sym_POUND,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5499), 1,
      anon_sym_begin,
    ACTIONS(5507), 1,
      aux_sym_number_token1,
    ACTIONS(5509), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5511), 1,
      anon_sym_SQUOTE,
    ACTIONS(5513), 1,
      anon_sym_DQUOTE,
    ACTIONS(5515), 1,
      sym__uppercase_identifier,
    ACTIONS(5517), 1,
      aux_sym_tag_token1,
    ACTIONS(7761), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7763), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9316), 1,
      anon_sym_LPAREN,
    STATE(5762), 1,
      sym_attribute,
    STATE(8440), 1,
      sym__constructor_name,
    STATE(10112), 1,
      sym__simple_pattern,
    STATE(20425), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5485), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10250), 2,
      sym__constant,
      sym_signed_number,
    STATE(10120), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10147), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [243071] = 25,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6895), 1,
      sym__lowercase_identifier,
    ACTIONS(6907), 1,
      anon_sym_LBRACK,
    ACTIONS(6913), 1,
      anon_sym_LBRACE,
    ACTIONS(6915), 1,
      anon_sym_POUND,
    ACTIONS(6917), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6919), 1,
      anon_sym_begin,
    ACTIONS(6927), 1,
      aux_sym_number_token1,
    ACTIONS(6929), 1,
      aux_sym_signed_number_token1,
    ACTIONS(6931), 1,
      anon_sym_SQUOTE,
    ACTIONS(6933), 1,
      anon_sym_DQUOTE,
    ACTIONS(6935), 1,
      sym__uppercase_identifier,
    ACTIONS(6937), 1,
      aux_sym_tag_token1,
    ACTIONS(9318), 1,
      anon_sym_LPAREN,
    ACTIONS(9320), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9322), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(5763), 1,
      sym_attribute,
    STATE(7600), 1,
      sym__simple_pattern,
    STATE(7627), 1,
      sym__constructor_name,
    STATE(19032), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6909), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7549), 2,
      sym__constant,
      sym_signed_number,
    STATE(7628), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7593), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [243169] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5764), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [243227] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5765), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [243285] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8228), 22,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [243343] = 25,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7547), 1,
      sym__lowercase_identifier,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7555), 1,
      anon_sym_LBRACE,
    ACTIONS(7559), 1,
      anon_sym_POUND,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7565), 1,
      anon_sym_begin,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(9324), 1,
      anon_sym_LPAREN,
    ACTIONS(9326), 1,
      sym__uppercase_identifier,
    ACTIONS(9328), 1,
      aux_sym_tag_token1,
    STATE(5767), 1,
      sym_attribute,
    STATE(13847), 1,
      sym__constructor_name,
    STATE(14137), 1,
      sym__simple_pattern,
    STATE(17893), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7553), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13926), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [243441] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5768), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [243499] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8622), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8624), 22,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [243557] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5770), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [243615] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5771), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [243673] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5772), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [243731] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [243789] = 25,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6979), 1,
      sym__lowercase_identifier,
    ACTIONS(6991), 1,
      anon_sym_LBRACK,
    ACTIONS(6997), 1,
      anon_sym_LBRACE,
    ACTIONS(6999), 1,
      anon_sym_POUND,
    ACTIONS(7001), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7003), 1,
      anon_sym_begin,
    ACTIONS(7009), 1,
      aux_sym_number_token1,
    ACTIONS(7011), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7013), 1,
      anon_sym_SQUOTE,
    ACTIONS(7015), 1,
      anon_sym_DQUOTE,
    ACTIONS(7017), 1,
      sym__uppercase_identifier,
    ACTIONS(7019), 1,
      aux_sym_tag_token1,
    ACTIONS(9330), 1,
      anon_sym_LPAREN,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(5774), 1,
      sym_attribute,
    STATE(7476), 1,
      sym__simple_pattern,
    STATE(7651), 1,
      sym__constructor_name,
    STATE(19315), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6993), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7650), 2,
      sym__constant,
      sym_signed_number,
    STATE(7629), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7652), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [243887] = 25,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4945), 1,
      sym__lowercase_identifier,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4959), 1,
      anon_sym_LBRACE,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4973), 1,
      anon_sym_begin,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(7399), 1,
      anon_sym_POUND,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9336), 1,
      anon_sym_LPAREN,
    ACTIONS(9338), 1,
      sym__uppercase_identifier,
    STATE(5775), 1,
      sym_attribute,
    STATE(13113), 1,
      sym__simple_pattern,
    STATE(13339), 1,
      sym__constructor_name,
    STATE(18089), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4955), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(12929), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [243985] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9340), 1,
      anon_sym_LT_DASH,
    STATE(5776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244045] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(5777), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244105] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5778), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244163] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5779), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244221] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5780), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244279] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5781), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244337] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244395] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5783), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244453] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5784), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244511] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5785), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244569] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244627] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5787), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244685] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9342), 1,
      anon_sym_LT_DASH,
    STATE(5788), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8002), 21,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8004), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [244745] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5789), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244803] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244861] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5791), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244919] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5792), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244977] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5793), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [245035] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5794), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [245093] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5795), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [245151] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5796), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [245209] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [245267] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5059), 1,
      anon_sym_DOT,
    STATE(5798), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [245327] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5799), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [245385] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5800), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [245443] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5801), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [245501] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5802), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [245559] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [245617] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5804), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [245675] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5805), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [245733] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5806), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [245791] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5807), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [245849] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5808), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [245907] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(5809), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [245967] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246025] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5811), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246083] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5812), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246141] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5813), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246199] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5814), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246257] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5815), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246315] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5816), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246373] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5817), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246431] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5818), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246489] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246547] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5820), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246605] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246663] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5822), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246721] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246779] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5824), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246837] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5825), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246895] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246953] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5827), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [247011] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5828), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [247069] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5829), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [247127] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5830), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [247185] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5831), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [247243] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5832), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [247301] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5833), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [247359] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5834), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [247417] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5835), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [247475] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5059), 1,
      anon_sym_DOT,
    ACTIONS(5061), 1,
      anon_sym_POUND,
    ACTIONS(5063), 1,
      sym_hash_operator,
    STATE(5836), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 21,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [247539] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5837), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [247597] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5838), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [247655] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5839), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [247713] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(5840), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [247773] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [247831] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5842), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [247889] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5843), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [247947] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5844), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [248005] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5845), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [248063] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5059), 1,
      anon_sym_DOT,
    ACTIONS(5061), 1,
      anon_sym_POUND,
    ACTIONS(5063), 1,
      sym_hash_operator,
    STATE(5846), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 21,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [248127] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5847), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [248185] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5848), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [248243] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5849), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [248300] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5850), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [248357] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5851), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [248414] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5852), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [248471] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [248528] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9344), 1,
      anon_sym_DOT,
    ACTIONS(9346), 1,
      anon_sym_POUND,
    ACTIONS(9348), 1,
      sym_hash_operator,
    STATE(5854), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [248591] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5855), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [248648] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5856), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [248705] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [248762] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [248819] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5859), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [248876] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5860), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [248933] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5861), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [248990] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5862), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [249047] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5863), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [249104] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5864), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [249161] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5865), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [249218] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5866), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [249275] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5867), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [249332] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5868), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [249389] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5869), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [249446] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [249503] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5871), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [249560] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5872), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [249617] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5873), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [249674] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [249731] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5875), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [249788] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5876), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [249845] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5877), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [249902] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5878), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [249959] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9344), 1,
      anon_sym_DOT,
    STATE(5879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [250018] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5880), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [250075] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5881), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [250132] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5882), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [250189] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5883), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [250246] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5884), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [250303] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5885), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [250360] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [250417] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [250474] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5888), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [250531] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5889), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [250588] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5890), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [250645] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5891), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [250702] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(5892), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [250761] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5893), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [250818] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [250875] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(5895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [250934] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5896), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [250991] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9350), 1,
      anon_sym_COLON,
    STATE(5897), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8548), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [251050] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5898), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [251107] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [251164] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5900), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [251221] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5901), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [251278] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5902), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [251335] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [251392] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5904), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [251449] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [251506] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5906), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [251563] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(5907), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [251622] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [251679] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [251736] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [251793] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5911), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [251850] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [251907] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5913), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [251964] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5914), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252021] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(5241), 1,
      anon_sym_POUND,
    ACTIONS(5243), 1,
      sym_hash_operator,
    STATE(5915), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [252084] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5916), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252141] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5917), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252198] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5918), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252255] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5919), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252312] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(5920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [252371] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252428] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5922), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252485] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252542] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5924), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252599] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5925), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [252656] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252713] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5927), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252770] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(5928), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252829] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252886] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5930), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252943] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9352), 1,
      anon_sym_DOT,
    ACTIONS(9354), 1,
      anon_sym_POUND,
    ACTIONS(9356), 1,
      sym_hash_operator,
    STATE(5931), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [253006] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5932), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [253063] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [253120] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5934), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [253177] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5935), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [253234] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [253291] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5937), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [253348] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    STATE(5938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [253407] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5939), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [253464] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [253521] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5941), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [253578] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5942), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [253635] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [253692] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5944), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [253749] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5945), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [253806] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5946), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [253863] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5947), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [253920] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5948), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [253977] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5949), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [254034] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5950), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [254091] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5951), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [254148] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5952), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [254205] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5953), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [254262] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5954), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [254319] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5955), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [254376] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5956), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [254433] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5957), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [254490] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [254547] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5959), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [254604] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5960), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [254661] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5961), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [254718] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5962), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [254775] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5963), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [254832] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5964), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [254889] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5965), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [254946] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5966), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [255003] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5967), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [255060] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5968), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [255117] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [255174] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5970), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [255231] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5971), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [255288] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5972), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [255345] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5973), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [255402] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5974), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [255459] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5975), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [255516] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5976), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [255573] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5977), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [255630] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5978), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [255687] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [255744] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5980), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [255801] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5981), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [255858] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [255915] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5983), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [255972] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5984), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [256029] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5985), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [256086] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [256143] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5987), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [256200] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [256257] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5989), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [256314] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5990), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [256371] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9352), 1,
      anon_sym_DOT,
    STATE(5991), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [256430] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5992), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [256487] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5993), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [256544] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5994), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [256601] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5995), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [256658] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5996), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [256715] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5997), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [256772] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5998), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [256829] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5999), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [256886] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6000), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [256943] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6001), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [257000] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6002), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [257057] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6003), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [257114] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(6004), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [257173] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6005), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [257230] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6006), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [257287] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6007), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [257344] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6008), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [257401] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9358), 1,
      anon_sym_LT_DASH,
    STATE(6009), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [257460] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6010), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [257517] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6011), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [257574] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(6012), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [257633] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6013), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [257690] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6014), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [257747] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [257804] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6016), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [257861] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [257918] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [257975] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [258032] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6020), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [258089] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6021), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [258146] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6022), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258203] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6023), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258260] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258317] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(6025), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [258376] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6026), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258433] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6027), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258490] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6028), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258547] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6029), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258604] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6030), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258661] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6031), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258718] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [258775] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(6033), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258834] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6034), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [258891] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6035), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [258948] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6036), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [259005] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [259062] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [259119] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6039), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [259176] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [259233] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6041), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [259290] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [259347] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [259404] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [259461] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(6045), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [259520] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [259577] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6047), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [259634] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6048), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [259691] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6049), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [259748] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9360), 1,
      anon_sym_LT_DASH,
    STATE(6050), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [259807] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6051), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [259864] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6052), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [259921] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6053), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [259978] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6054), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [260035] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6055), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [260092] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6056), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [260149] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6057), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [260206] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6058), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [260263] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(6059), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [260322] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6060), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [260379] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6061), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [260436] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6062), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [260493] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6063), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [260550] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6064), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [260607] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6065), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [260664] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6066), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [260721] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9352), 1,
      anon_sym_DOT,
    ACTIONS(9354), 1,
      anon_sym_POUND,
    ACTIONS(9356), 1,
      sym_hash_operator,
    STATE(6067), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [260784] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6068), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [260841] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6069), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [260898] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6070), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [260955] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6071), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [261012] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [261069] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6073), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [261126] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [261183] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6075), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [261240] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6076), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [261297] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [261354] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6078), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [261411] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6079), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [261468] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6080), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [261525] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [261582] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6082), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [261639] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6083), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [261696] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(5241), 1,
      anon_sym_POUND,
    ACTIONS(5243), 1,
      sym_hash_operator,
    STATE(6084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [261759] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6085), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [261816] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6086), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [261873] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6087), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [261930] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6088), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [261987] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6089), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [262044] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6090), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [262101] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6091), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [262158] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6092), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [262215] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6093), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [262272] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6094), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [262329] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(6095), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [262388] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6096), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [262445] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6097), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [262502] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6098), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [262559] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9344), 1,
      anon_sym_DOT,
    ACTIONS(9346), 1,
      anon_sym_POUND,
    ACTIONS(9348), 1,
      sym_hash_operator,
    STATE(6099), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [262622] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6100), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [262679] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6101), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [262736] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6102), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [262793] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [262850] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9362), 1,
      anon_sym_LT_DASH,
    STATE(6104), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [262909] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6105), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [262966] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6106), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263023] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6107), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263080] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263137] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6109), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263194] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263251] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6111), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263308] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263365] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263422] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6114), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263479] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [263536] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [263593] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9364), 1,
      anon_sym_LT_DASH,
    STATE(6117), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263652] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9366), 1,
      anon_sym_LT_DASH,
    STATE(6118), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263711] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6119), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263768] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6120), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263825] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263882] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6122), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [263939] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9368), 1,
      anon_sym_LT_DASH,
    STATE(6123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263998] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [264055] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [264112] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [264169] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6127), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [264226] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6128), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [264283] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6129), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [264340] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6130), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [264397] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6131), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [264454] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [264511] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6133), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [264568] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [264625] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6135), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [264682] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [264739] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [264796] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [264853] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6139), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [264910] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [264967] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6141), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265024] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265081] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [265138] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [265195] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [265252] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9370), 1,
      anon_sym_LT_DASH,
    STATE(6146), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265311] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [265368] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265425] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6149), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265482] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6150), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265539] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6151), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265595] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6152), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [265651] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6153), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265707] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6154), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265763] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265819] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6156), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265875] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6157), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265931] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6158), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265987] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266043] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266099] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6161), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266155] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266211] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266267] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266323] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266379] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6166), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266435] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6167), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266491] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266547] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6169), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266603] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266659] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266715] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266771] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266827] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266883] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6175), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266939] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9372), 1,
      anon_sym_LT_DASH,
    STATE(6176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266997] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6177), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267053] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267109] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267165] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267221] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6181), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267277] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267333] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(6183), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267391] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6184), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267447] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267503] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267559] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6187), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267615] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267671] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267727] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267783] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6191), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267839] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6192), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267895] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6193), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267951] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6194), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268007] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268063] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268119] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268175] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268231] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268287] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268343] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268399] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6202), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268455] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268511] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6204), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268567] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5397), 1,
      anon_sym_DOT,
    STATE(6205), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268625] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6206), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268681] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268737] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6208), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268793] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6209), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268849] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268905] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268961] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6212), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [269017] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6213), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [269073] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6214), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [269129] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6215), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [269185] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6216), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [269241] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [269297] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [269353] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6219), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [269409] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6220), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [269465] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6221), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [269521] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6222), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [269577] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6223), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [269633] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [269689] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6225), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [269745] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6226), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [269801] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6227), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [269857] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [269913] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6229), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [269969] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [270025] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6231), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [270081] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6232), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [270137] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6233), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [270193] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6234), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [270249] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6235), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [270305] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [270361] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6237), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [270417] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6238), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [270473] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6239), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [270529] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6240), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [270585] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6241), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [270641] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6242), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [270697] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6243), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [270753] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6244), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [270809] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6245), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [270865] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6246), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [270921] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6247), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [270977] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [271033] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6249), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [271089] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6250), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [271145] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6251), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [271201] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6252), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [271257] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5355), 1,
      anon_sym_DOT,
    STATE(6253), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [271315] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6254), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [271371] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6255), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [271427] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6256), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [271483] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9374), 1,
      anon_sym_LT_DASH,
    STATE(6257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [271541] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6258), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [271597] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6259), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [271653] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6260), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [271709] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [271765] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6262), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [271821] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [271877] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [271933] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6265), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [271989] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6266), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [272045] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [272101] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6268), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [272157] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6269), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [272213] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [272269] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6271), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [272325] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6272), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [272381] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6273), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [272437] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5375), 1,
      anon_sym_DOT,
    ACTIONS(5377), 1,
      anon_sym_POUND,
    ACTIONS(5379), 1,
      sym_hash_operator,
    STATE(6274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [272499] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(9376), 1,
      sym__lowercase_identifier,
    ACTIONS(9378), 1,
      anon_sym_LPAREN,
    ACTIONS(9380), 1,
      anon_sym_private,
    ACTIONS(9382), 1,
      anon_sym_DOT_DOT,
    ACTIONS(9384), 1,
      anon_sym_PIPE,
    ACTIONS(9386), 1,
      anon_sym_LBRACK,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      sym__uppercase_identifier,
    ACTIONS(9406), 1,
      aux_sym_type_variable_token1,
    STATE(6275), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(9183), 1,
      sym__simple_type,
    STATE(10587), 1,
      sym__tuple_type,
    STATE(10650), 1,
      sym__constructor_name,
    STATE(10900), 1,
      sym__type,
    STATE(11177), 1,
      sym_constructor_declaration,
    STATE(16745), 1,
      sym_extended_module_path,
    STATE(19846), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9388), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(10429), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(9437), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [272607] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [272663] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9404), 1,
      sym__uppercase_identifier,
    ACTIONS(9408), 1,
      sym__lowercase_identifier,
    ACTIONS(9410), 1,
      anon_sym_LPAREN,
    ACTIONS(9412), 1,
      anon_sym_private,
    ACTIONS(9414), 1,
      anon_sym_DOT_DOT,
    ACTIONS(9416), 1,
      anon_sym_PIPE,
    ACTIONS(9418), 1,
      anon_sym_LBRACK,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9424), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9426), 1,
      anon_sym_LT,
    ACTIONS(9428), 1,
      anon_sym_POUND,
    ACTIONS(9430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9434), 1,
      aux_sym_type_variable_token1,
    STATE(6277), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(9482), 1,
      sym__simple_type,
    STATE(10815), 1,
      sym__tuple_type,
    STATE(10928), 1,
      sym__constructor_name,
    STATE(11025), 1,
      sym__type,
    STATE(11569), 1,
      sym_constructor_declaration,
    STATE(16665), 1,
      sym_extended_module_path,
    STATE(20113), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9420), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(10794), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(9574), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [272771] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [272827] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6279), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [272883] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6280), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [272939] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6281), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [272995] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273051] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6283), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273107] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6284), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273163] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6285), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273219] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273275] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273331] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6288), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273387] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273443] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6290), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273499] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273555] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6292), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [273611] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273667] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [273723] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273779] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6296), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273835] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5345), 1,
      anon_sym_DOT,
    STATE(6297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273893] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(9376), 1,
      sym__lowercase_identifier,
    ACTIONS(9378), 1,
      anon_sym_LPAREN,
    ACTIONS(9384), 1,
      anon_sym_PIPE,
    ACTIONS(9386), 1,
      anon_sym_LBRACK,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      sym__uppercase_identifier,
    ACTIONS(9406), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9436), 1,
      anon_sym_private,
    ACTIONS(9438), 1,
      anon_sym_DOT_DOT,
    STATE(6298), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(9183), 1,
      sym__simple_type,
    STATE(10587), 1,
      sym__tuple_type,
    STATE(10650), 1,
      sym__constructor_name,
    STATE(10900), 1,
      sym__type,
    STATE(11177), 1,
      sym_constructor_declaration,
    STATE(16745), 1,
      sym_extended_module_path,
    STATE(19846), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9388), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(10520), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(9437), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [274001] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6299), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274057] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274113] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274169] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274225] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274281] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6304), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274337] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6305), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274393] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6306), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274449] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6307), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274505] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6308), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274561] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6309), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274617] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6310), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274673] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6311), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274729] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6312), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274785] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274841] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6314), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274897] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6315), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274953] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6316), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275009] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6317), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275065] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6318), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275121] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6319), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275177] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6320), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275233] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6321), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275289] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6322), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275345] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6323), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275401] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5375), 1,
      anon_sym_DOT,
    ACTIONS(5377), 1,
      anon_sym_POUND,
    ACTIONS(5379), 1,
      sym_hash_operator,
    STATE(6324), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275463] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275519] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275575] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6327), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275631] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275687] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9440), 1,
      anon_sym_LT_DASH,
    STATE(6329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275745] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6330), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275801] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6331), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275857] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275913] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6333), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275969] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6334), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [276025] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(6335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276083] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276139] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6337), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276195] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6338), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276251] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6339), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276307] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6340), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276363] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6341), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276419] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6342), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276475] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6343), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276531] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6344), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276587] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6345), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276643] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276699] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6347), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276755] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6348), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276811] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276867] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6350), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276923] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276979] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(6352), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277037] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6353), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [277093] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6354), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277149] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5365), 1,
      anon_sym_DOT,
    STATE(6355), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277207] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277263] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277319] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277375] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6359), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277431] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6360), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277487] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277543] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6362), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277599] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6363), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277655] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [277711] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6365), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277767] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5355), 1,
      anon_sym_DOT,
    ACTIONS(5357), 1,
      anon_sym_POUND,
    ACTIONS(5359), 1,
      sym_hash_operator,
    STATE(6366), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277829] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6367), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277885] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277941] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277997] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6370), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278053] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278109] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6372), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278165] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278221] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278277] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6375), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278333] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278389] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278445] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6378), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278501] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6379), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278557] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278613] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278669] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9442), 1,
      anon_sym_LT_DASH,
    STATE(6382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8002), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8004), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [278727] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(6383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278785] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278841] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9444), 1,
      anon_sym_LT_DASH,
    STATE(6385), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278899] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6386), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278955] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6387), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279011] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6388), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279067] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279123] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [279179] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5385), 1,
      anon_sym_DOT,
    ACTIONS(5387), 1,
      anon_sym_POUND,
    ACTIONS(5389), 1,
      sym_hash_operator,
    STATE(6391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279241] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6392), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279297] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6393), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279353] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6394), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279409] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279465] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279521] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9404), 1,
      sym__uppercase_identifier,
    ACTIONS(9408), 1,
      sym__lowercase_identifier,
    ACTIONS(9410), 1,
      anon_sym_LPAREN,
    ACTIONS(9416), 1,
      anon_sym_PIPE,
    ACTIONS(9418), 1,
      anon_sym_LBRACK,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9424), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9426), 1,
      anon_sym_LT,
    ACTIONS(9428), 1,
      anon_sym_POUND,
    ACTIONS(9430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9434), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9446), 1,
      anon_sym_private,
    ACTIONS(9448), 1,
      anon_sym_DOT_DOT,
    STATE(6397), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(9482), 1,
      sym__simple_type,
    STATE(10815), 1,
      sym__tuple_type,
    STATE(10928), 1,
      sym__constructor_name,
    STATE(11025), 1,
      sym__type,
    STATE(11569), 1,
      sym_constructor_declaration,
    STATE(16665), 1,
      sym_extended_module_path,
    STATE(20113), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9420), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(10941), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(9574), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [279629] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279685] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6399), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279741] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6400), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279797] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279853] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279909] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6403), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279965] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(6404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280023] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6405), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280079] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280135] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6407), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280191] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8622), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280247] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6409), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280303] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280359] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6411), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280415] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280471] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280527] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280583] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6415), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280639] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5355), 1,
      anon_sym_DOT,
    ACTIONS(5357), 1,
      anon_sym_POUND,
    ACTIONS(5359), 1,
      sym_hash_operator,
    STATE(6416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280701] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9450), 1,
      anon_sym_LT_DASH,
    STATE(6417), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280759] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280815] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6419), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280871] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6420), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280927] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6421), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280983] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6422), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281039] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6423), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281095] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6424), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281151] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6425), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281207] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6426), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281263] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281319] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281375] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281431] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6430), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281487] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281543] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281599] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6433), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281655] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281711] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281767] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281823] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6437), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281879] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6438), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281935] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281991] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6440), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282047] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6441), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282103] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6442), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282159] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9452), 1,
      anon_sym_LT_DASH,
    STATE(6443), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282217] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6444), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282273] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6445), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282329] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9404), 1,
      sym__uppercase_identifier,
    ACTIONS(9454), 1,
      sym__lowercase_identifier,
    ACTIONS(9456), 1,
      anon_sym_LPAREN,
    ACTIONS(9458), 1,
      anon_sym_private,
    ACTIONS(9460), 1,
      anon_sym_DOT_DOT,
    ACTIONS(9462), 1,
      anon_sym_PIPE,
    ACTIONS(9464), 1,
      anon_sym_LBRACK,
    ACTIONS(9468), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9470), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9472), 1,
      anon_sym_LT,
    ACTIONS(9474), 1,
      anon_sym_POUND,
    ACTIONS(9476), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9478), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9480), 1,
      aux_sym_type_variable_token1,
    STATE(6446), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(9025), 1,
      sym__simple_type,
    STATE(10401), 1,
      sym__tuple_type,
    STATE(10408), 1,
      sym__constructor_name,
    STATE(10996), 1,
      sym__type,
    STATE(11053), 1,
      sym_constructor_declaration,
    STATE(16859), 1,
      sym_extended_module_path,
    STATE(19708), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9466), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(10673), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(9377), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [282437] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282493] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6448), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282549] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6449), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282605] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6450), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282661] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6451), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282717] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6452), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282773] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6453), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282829] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6454), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282885] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282941] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6456), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282997] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6457), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283053] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5397), 1,
      anon_sym_DOT,
    ACTIONS(5399), 1,
      anon_sym_POUND,
    ACTIONS(5401), 1,
      sym_hash_operator,
    STATE(6458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283115] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283171] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6460), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283227] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6461), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283283] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6462), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283339] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283395] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283451] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5385), 1,
      anon_sym_DOT,
    STATE(6465), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283509] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6466), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283565] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283621] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283677] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283733] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283789] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283845] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283901] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6473), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283957] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284013] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6475), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284069] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9404), 1,
      sym__uppercase_identifier,
    ACTIONS(9454), 1,
      sym__lowercase_identifier,
    ACTIONS(9456), 1,
      anon_sym_LPAREN,
    ACTIONS(9462), 1,
      anon_sym_PIPE,
    ACTIONS(9464), 1,
      anon_sym_LBRACK,
    ACTIONS(9468), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9470), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9472), 1,
      anon_sym_LT,
    ACTIONS(9474), 1,
      anon_sym_POUND,
    ACTIONS(9476), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9478), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9480), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9482), 1,
      anon_sym_private,
    ACTIONS(9484), 1,
      anon_sym_DOT_DOT,
    STATE(6476), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(9025), 1,
      sym__simple_type,
    STATE(10401), 1,
      sym__tuple_type,
    STATE(10408), 1,
      sym__constructor_name,
    STATE(10996), 1,
      sym__type,
    STATE(11053), 1,
      sym_constructor_declaration,
    STATE(16859), 1,
      sym_extended_module_path,
    STATE(19708), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9466), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(10597), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(9377), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [284177] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284233] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5375), 1,
      anon_sym_DOT,
    STATE(6478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284291] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284347] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6480), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284403] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6481), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284459] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6482), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284515] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284571] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6484), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284627] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284683] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6486), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284739] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284795] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6488), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284851] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284907] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6490), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284963] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(6491), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285021] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6492), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285077] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285133] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(6494), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285191] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6495), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285247] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6496), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285303] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6497), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285359] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6498), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285415] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6499), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285471] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6500), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285527] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285583] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285639] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6503), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285695] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285751] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6505), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285807] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285863] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6507), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285919] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5397), 1,
      anon_sym_DOT,
    ACTIONS(5399), 1,
      anon_sym_POUND,
    ACTIONS(5401), 1,
      sym_hash_operator,
    STATE(6508), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285981] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6509), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286037] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6510), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286093] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6511), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286149] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6512), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286205] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(6513), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286263] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6514), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286319] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6515), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286375] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6516), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286431] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6517), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286487] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5365), 1,
      anon_sym_DOT,
    ACTIONS(5367), 1,
      anon_sym_POUND,
    ACTIONS(5369), 1,
      sym_hash_operator,
    STATE(6518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286549] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6519), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286605] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6520), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286661] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(6521), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286719] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6522), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286775] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286831] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6524), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286887] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6525), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286943] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6526), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286999] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6527), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287055] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6528), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287111] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6529), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287167] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6530), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287223] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6531), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287279] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6532), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287335] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6533), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287391] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287447] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6535), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287503] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6536), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287559] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6537), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287615] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287671] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6539), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287727] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6540), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287783] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6541), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287839] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6542), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287895] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6543), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287951] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6544), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288007] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288063] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(6546), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288121] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6547), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288177] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288233] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6549), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288289] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5345), 1,
      anon_sym_DOT,
    ACTIONS(5347), 1,
      anon_sym_POUND,
    ACTIONS(5349), 1,
      sym_hash_operator,
    STATE(6550), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288351] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6551), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288407] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6552), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288463] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6553), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288519] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288575] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6555), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288631] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6556), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288687] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288743] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6558), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288799] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(6559), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288857] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6560), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288913] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6561), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288969] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6562), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289025] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6563), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289081] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6564), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289137] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6565), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289193] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5365), 1,
      anon_sym_DOT,
    ACTIONS(5367), 1,
      anon_sym_POUND,
    ACTIONS(5369), 1,
      sym_hash_operator,
    STATE(6566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289255] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6567), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289311] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6568), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289367] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6569), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289423] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6570), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289479] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289535] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9404), 1,
      sym__uppercase_identifier,
    ACTIONS(9486), 1,
      sym__lowercase_identifier,
    ACTIONS(9488), 1,
      anon_sym_LPAREN,
    ACTIONS(9490), 1,
      anon_sym_private,
    ACTIONS(9492), 1,
      anon_sym_DOT_DOT,
    ACTIONS(9494), 1,
      anon_sym_PIPE,
    ACTIONS(9496), 1,
      anon_sym_LBRACK,
    ACTIONS(9500), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9502), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9504), 1,
      anon_sym_LT,
    ACTIONS(9506), 1,
      anon_sym_POUND,
    ACTIONS(9508), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9510), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9512), 1,
      aux_sym_type_variable_token1,
    STATE(6572), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(9760), 1,
      sym__simple_type,
    STATE(11003), 1,
      sym__constructor_name,
    STATE(11076), 1,
      sym__tuple_type,
    STATE(11453), 1,
      sym__type,
    STATE(11787), 1,
      sym_constructor_declaration,
    STATE(16914), 1,
      sym_extended_module_path,
    STATE(19582), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9498), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(11029), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(10076), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [289643] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6573), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289699] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6574), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289755] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6575), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289811] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6576), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289867] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6577), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289923] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6578), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289979] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290035] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6580), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290091] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6581), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290147] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9514), 1,
      anon_sym_LT_DASH,
    STATE(6582), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290205] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(6583), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290263] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6584), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290319] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6585), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290375] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6586), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290431] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6587), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290487] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9516), 1,
      anon_sym_LT_DASH,
    STATE(6588), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290545] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6589), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290601] = 31,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9404), 1,
      sym__uppercase_identifier,
    ACTIONS(9486), 1,
      sym__lowercase_identifier,
    ACTIONS(9488), 1,
      anon_sym_LPAREN,
    ACTIONS(9494), 1,
      anon_sym_PIPE,
    ACTIONS(9496), 1,
      anon_sym_LBRACK,
    ACTIONS(9500), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9502), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9504), 1,
      anon_sym_LT,
    ACTIONS(9506), 1,
      anon_sym_POUND,
    ACTIONS(9508), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9510), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9512), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9518), 1,
      anon_sym_private,
    ACTIONS(9520), 1,
      anon_sym_DOT_DOT,
    STATE(6590), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(9760), 1,
      sym__simple_type,
    STATE(11003), 1,
      sym__constructor_name,
    STATE(11076), 1,
      sym__tuple_type,
    STATE(11453), 1,
      sym__type,
    STATE(11787), 1,
      sym_constructor_declaration,
    STATE(16914), 1,
      sym_extended_module_path,
    STATE(19582), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9498), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(11070), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(10076), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [290709] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6591), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290765] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6592), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290821] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6593), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290877] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6594), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290933] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6595), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290989] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6596), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291045] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6597), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291101] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6598), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291157] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6599), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291213] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5345), 1,
      anon_sym_DOT,
    ACTIONS(5347), 1,
      anon_sym_POUND,
    ACTIONS(5349), 1,
      sym_hash_operator,
    STATE(6600), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291275] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6601), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291331] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9522), 1,
      anon_sym_LT_DASH,
    STATE(6602), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291389] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6603), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291445] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6604), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291501] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(6605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291559] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6606), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291615] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9524), 1,
      anon_sym_COLON,
    STATE(6607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8548), 21,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291673] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6608), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291729] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6609), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291785] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6610), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291841] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6611), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291897] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6612), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291953] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6613), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292009] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6614), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292065] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6615), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292121] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6616), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292177] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8000), 1,
      anon_sym_LT_DASH,
    STATE(6617), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292235] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6618), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292291] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6619), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292347] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6620), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292403] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6621), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292459] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6622), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292515] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6623), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292571] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6624), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292627] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6625), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292683] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(6626), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292741] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6627), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292797] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292853] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6629), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292909] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6630), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292965] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6631), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293021] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293077] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6633), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293133] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6634), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293189] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6635), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293245] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [293301] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6637), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293357] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293413] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293469] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6640), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293525] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6641), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293581] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6642), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293637] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [293693] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5385), 1,
      anon_sym_DOT,
    ACTIONS(5387), 1,
      anon_sym_POUND,
    ACTIONS(5389), 1,
      sym_hash_operator,
    STATE(6644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293755] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6645), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293811] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6646), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293867] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6647), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293923] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6648), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293979] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294035] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6650), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294091] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6651), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294147] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6652), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294203] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294259] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6654), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294315] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294371] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(6656), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294429] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6657), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294485] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294541] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6659), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294597] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6660), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294653] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6661), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294709] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [294765] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6663), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294821] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6664), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [294877] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6665), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294933] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(6666), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294991] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [295046] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [295101] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [295156] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6670), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [295211] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6671), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [295266] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9404), 1,
      sym__uppercase_identifier,
    ACTIONS(9408), 1,
      sym__lowercase_identifier,
    ACTIONS(9410), 1,
      anon_sym_LPAREN,
    ACTIONS(9416), 1,
      anon_sym_PIPE,
    ACTIONS(9418), 1,
      anon_sym_LBRACK,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9424), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9426), 1,
      anon_sym_LT,
    ACTIONS(9428), 1,
      anon_sym_POUND,
    ACTIONS(9430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9434), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9526), 1,
      anon_sym_DOT_DOT,
    STATE(6672), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(9482), 1,
      sym__simple_type,
    STATE(10815), 1,
      sym__tuple_type,
    STATE(10928), 1,
      sym__constructor_name,
    STATE(11082), 1,
      sym__type,
    STATE(11569), 1,
      sym_constructor_declaration,
    STATE(16665), 1,
      sym_extended_module_path,
    STATE(20113), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9420), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(10863), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(9574), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [295371] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6673), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [295426] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [295481] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6675), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [295536] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6676), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [295591] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [295646] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [295701] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6679), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [295756] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [295811] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6681), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [295866] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6682), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [295921] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [295976] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6684), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [296031] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6685), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [296086] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6686), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [296141] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6687), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [296196] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6688), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [296251] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6689), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [296306] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6690), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [296361] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6691), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [296416] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6692), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [296471] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6693), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [296526] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6694), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [296581] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6695), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [296636] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6696), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [296691] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6697), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [296746] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6698), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [296801] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6699), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [296856] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6700), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [296911] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6701), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [296966] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9528), 1,
      anon_sym_DOT,
    STATE(6702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [297023] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6703), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [297078] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6704), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [297133] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [297188] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6706), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [297243] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6707), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [297298] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6708), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [297353] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6709), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [297408] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6710), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [297463] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6711), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [297518] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6712), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [297573] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6713), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [297628] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6714), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [297683] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6715), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [297738] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6716), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [297793] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6717), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [297848] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6718), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [297903] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6719), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [297958] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6720), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [298013] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6721), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [298068] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6722), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [298123] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6723), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [298178] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6724), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [298233] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6725), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [298288] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [298343] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6727), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [298398] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6728), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [298453] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6729), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [298508] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6730), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [298563] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(6731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [298620] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6732), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [298675] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6733), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [298730] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6734), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [298785] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6735), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [298840] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6736), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [298895] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [298950] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6738), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [299005] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6739), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [299060] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6740), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [299115] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6741), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [299170] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6742), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [299225] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6743), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [299280] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6744), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [299335] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6745), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [299390] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6746), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [299445] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(6747), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [299502] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6748), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [299557] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6749), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [299612] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6750), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [299667] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6751), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [299722] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6752), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [299777] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6753), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [299832] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6754), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [299887] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6755), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [299942] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6756), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [299997] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9530), 1,
      anon_sym_DOT,
    STATE(6757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [300054] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [300109] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6759), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [300164] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6760), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [300219] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6761), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [300274] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6762), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [300329] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6763), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [300384] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9532), 1,
      anon_sym_DOT,
    STATE(6764), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [300441] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6765), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [300496] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [300551] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6767), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [300606] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6768), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [300661] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [300716] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6770), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [300771] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6771), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [300826] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6772), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [300881] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [300936] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6774), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [300991] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6775), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [301046] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [301101] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6777), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [301156] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6778), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [301211] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6779), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [301266] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6780), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [301321] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6781), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [301376] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [301431] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6783), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [301486] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6784), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [301541] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6785), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [301596] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [301651] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6787), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [301706] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6788), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [301761] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6789), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [301816] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [301871] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6791), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [301926] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6792), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [301981] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6793), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [302036] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6794), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [302091] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6795), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [302146] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6796), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [302201] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [302256] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6798), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [302311] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6799), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [302366] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6800), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [302421] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6801), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [302476] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6802), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [302531] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [302586] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6804), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [302641] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6805), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [302696] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6806), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [302751] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6807), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [302806] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6808), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [302861] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6809), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [302916] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [302971] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9534), 1,
      anon_sym_LT_DASH,
    STATE(6811), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303028] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6812), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303083] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6813), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303138] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6814), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [303193] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6815), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [303248] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6816), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [303303] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6817), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303358] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6818), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [303413] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303468] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6820), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303523] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303578] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6822), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [303633] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303688] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6824), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [303743] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6825), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [303798] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [303853] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6827), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303908] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6828), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303963] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6829), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304018] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6830), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304073] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6831), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304128] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6832), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304183] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6833), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304238] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6834), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304293] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6835), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [304348] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6836), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304403] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6837), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304458] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6838), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304513] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6839), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304568] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6840), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304623] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [304678] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6842), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [304733] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6843), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [304788] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6844), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304843] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6845), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [304898] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6846), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304953] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6847), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [305008] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6848), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [305063] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9530), 1,
      anon_sym_DOT,
    ACTIONS(9536), 1,
      anon_sym_POUND,
    ACTIONS(9538), 1,
      sym_hash_operator,
    STATE(6849), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [305124] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6850), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [305179] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6851), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [305234] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6852), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [305289] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [305344] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6854), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [305399] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6855), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [305454] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6856), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [305509] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [305564] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [305619] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5555), 1,
      anon_sym_DOT,
    ACTIONS(5557), 1,
      anon_sym_POUND,
    ACTIONS(5559), 1,
      sym_hash_operator,
    STATE(6859), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [305680] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6860), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [305735] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6861), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [305790] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9530), 1,
      anon_sym_DOT,
    ACTIONS(9536), 1,
      anon_sym_POUND,
    ACTIONS(9538), 1,
      sym_hash_operator,
    STATE(6862), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [305851] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6863), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [305906] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6864), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [305961] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6865), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [306016] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6866), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [306071] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6867), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [306126] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6868), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [306181] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(6869), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [306238] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [306293] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6871), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [306348] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6872), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [306403] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6873), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7996), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(7998), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [306458] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [306513] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(6875), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [306570] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5565), 1,
      anon_sym_DOT,
    ACTIONS(5567), 1,
      anon_sym_POUND,
    ACTIONS(5569), 1,
      sym_hash_operator,
    STATE(6876), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [306631] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6877), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [306686] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6878), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [306741] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [306796] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6880), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [306851] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5523), 1,
      anon_sym_DOT,
    ACTIONS(5525), 1,
      anon_sym_POUND,
    ACTIONS(5527), 1,
      sym_hash_operator,
    STATE(6881), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [306912] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6882), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [306967] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6883), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [307022] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6884), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [307077] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6885), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [307132] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(6886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [307189] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [307244] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6888), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [307299] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6889), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [307354] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6890), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [307409] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6891), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [307464] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(6892), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [307521] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6893), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [307576] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [307631] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [307686] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6896), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [307741] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6897), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [307796] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6898), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [307851] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [307906] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6900), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [307961] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6901), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8060), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8062), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [308016] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6902), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [308071] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [308126] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(9376), 1,
      sym__lowercase_identifier,
    ACTIONS(9378), 1,
      anon_sym_LPAREN,
    ACTIONS(9384), 1,
      anon_sym_PIPE,
    ACTIONS(9386), 1,
      anon_sym_LBRACK,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      sym__uppercase_identifier,
    ACTIONS(9406), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9540), 1,
      anon_sym_DOT_DOT,
    STATE(6904), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(9183), 1,
      sym__simple_type,
    STATE(10587), 1,
      sym__tuple_type,
    STATE(10650), 1,
      sym__constructor_name,
    STATE(10778), 1,
      sym__type,
    STATE(11177), 1,
      sym_constructor_declaration,
    STATE(16745), 1,
      sym_extended_module_path,
    STATE(19846), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9388), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(10516), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(9437), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [308231] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [308286] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6906), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [308341] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6907), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [308396] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [308451] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [308506] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [308561] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6911), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [308616] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [308671] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6913), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [308726] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6914), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [308781] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(6915), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [308838] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6916), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [308893] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(9376), 1,
      sym__lowercase_identifier,
    ACTIONS(9378), 1,
      anon_sym_LPAREN,
    ACTIONS(9384), 1,
      anon_sym_PIPE,
    ACTIONS(9386), 1,
      anon_sym_LBRACK,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      sym__uppercase_identifier,
    ACTIONS(9406), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9542), 1,
      anon_sym_DOT_DOT,
    STATE(6917), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(9183), 1,
      sym__simple_type,
    STATE(10587), 1,
      sym__tuple_type,
    STATE(10650), 1,
      sym__constructor_name,
    STATE(10778), 1,
      sym__type,
    STATE(11177), 1,
      sym_constructor_declaration,
    STATE(16745), 1,
      sym_extended_module_path,
    STATE(19846), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9388), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(10539), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(9437), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [308998] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6918), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309053] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6919), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309108] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309163] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309218] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(6922), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309275] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [309330] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6924), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309385] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6925), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309440] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309495] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6927), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [309550] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6928), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309605] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309660] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6930), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309715] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6931), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309770] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6932), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [309825] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309880] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6934), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309935] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6935), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309990] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310045] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6937), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310100] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9544), 1,
      anon_sym_COLON,
    STATE(6938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8548), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310157] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6939), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310212] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310267] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(6941), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310324] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6942), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310379] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310434] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6944), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310489] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6945), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310544] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6946), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310599] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6947), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310654] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6948), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310709] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6949), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310764] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6950), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310819] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6951), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310874] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6952), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310929] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6953), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [310984] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6954), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311039] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6955), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [311094] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6956), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311149] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6957), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [311204] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(6958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311261] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6959), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311316] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6960), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [311371] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6961), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311426] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6962), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311481] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6963), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311536] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6964), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311591] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6965), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [311646] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6966), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311701] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6967), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311756] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6968), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311811] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [311866] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6970), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311921] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6971), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [311976] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6972), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312031] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6973), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312086] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6974), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312141] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6975), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8622), 21,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312196] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6976), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [312251] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6977), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [312306] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6978), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312361] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312416] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6980), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312471] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6981), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312526] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312581] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6983), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312636] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6984), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [312691] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5575), 1,
      anon_sym_DOT,
    STATE(6985), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312748] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [312803] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6987), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [312858] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312913] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6989), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312968] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6990), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313023] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6991), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [313078] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6992), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313133] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6993), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313188] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6994), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [313243] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6995), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313298] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6996), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313353] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6997), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [313408] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6998), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313463] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6999), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313518] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7000), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313573] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7001), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313628] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9532), 1,
      anon_sym_DOT,
    ACTIONS(9546), 1,
      anon_sym_POUND,
    ACTIONS(9548), 1,
      sym_hash_operator,
    STATE(7002), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [313689] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7003), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [313744] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7004), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313799] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7005), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [313854] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7006), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313909] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7007), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313964] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7008), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314019] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7009), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314074] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7010), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314129] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7011), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314184] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7012), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314239] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7013), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314294] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7014), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314349] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314404] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7016), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 21,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314459] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [314514] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314569] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [314624] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9404), 1,
      sym__uppercase_identifier,
    ACTIONS(9486), 1,
      sym__lowercase_identifier,
    ACTIONS(9488), 1,
      anon_sym_LPAREN,
    ACTIONS(9494), 1,
      anon_sym_PIPE,
    ACTIONS(9496), 1,
      anon_sym_LBRACK,
    ACTIONS(9500), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9502), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9504), 1,
      anon_sym_LT,
    ACTIONS(9506), 1,
      anon_sym_POUND,
    ACTIONS(9508), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9510), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9512), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9550), 1,
      anon_sym_DOT_DOT,
    STATE(7020), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(9760), 1,
      sym__simple_type,
    STATE(11003), 1,
      sym__constructor_name,
    STATE(11076), 1,
      sym__tuple_type,
    STATE(11390), 1,
      sym__type,
    STATE(11787), 1,
      sym_constructor_declaration,
    STATE(16914), 1,
      sym_extended_module_path,
    STATE(19582), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9498), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(11060), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(10076), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [314729] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7021), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314784] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7022), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314839] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7023), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [314894] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5555), 1,
      anon_sym_DOT,
    STATE(7024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314951] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7025), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [315006] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7026), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [315061] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7027), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [315116] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7028), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [315171] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7029), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [315226] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7030), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [315281] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7031), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [315336] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [315391] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7033), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [315446] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7034), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [315501] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7035), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [315556] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(7036), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [315613] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [315668] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [315723] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7039), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [315778] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [315833] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9528), 1,
      anon_sym_DOT,
    ACTIONS(9552), 1,
      anon_sym_POUND,
    ACTIONS(9554), 1,
      sym_hash_operator,
    STATE(7041), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [315894] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [315949] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316004] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316059] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7045), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316114] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316169] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7047), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316224] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7048), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316279] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5555), 1,
      anon_sym_DOT,
    ACTIONS(5557), 1,
      anon_sym_POUND,
    ACTIONS(5559), 1,
      sym_hash_operator,
    STATE(7049), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316340] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7050), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316395] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7051), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316450] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7052), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316505] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7053), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316560] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7054), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [316615] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7055), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316670] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7056), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316725] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(7057), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [316782] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7058), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [316837] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7059), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [316892] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7060), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316947] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7061), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [317002] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7062), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317057] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5523), 1,
      anon_sym_DOT,
    ACTIONS(5525), 1,
      anon_sym_POUND,
    ACTIONS(5527), 1,
      sym_hash_operator,
    STATE(7063), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317118] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7064), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317173] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7065), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317228] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7066), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [317283] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7067), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317338] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(7068), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8296), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [317395] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7069), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317450] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7070), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [317505] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9556), 1,
      anon_sym_LT_DASH,
    STATE(7071), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317562] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(7072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317619] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7073), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [317674] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [317729] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7075), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [317784] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(7076), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [317841] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [317896] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7078), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317951] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7079), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318006] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7080), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [318061] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318116] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7082), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [318171] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7083), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318226] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5533), 1,
      anon_sym_DOT,
    STATE(7084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318283] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7085), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318338] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7086), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318393] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7087), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [318448] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7088), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318503] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9528), 1,
      anon_sym_DOT,
    ACTIONS(9552), 1,
      anon_sym_POUND,
    ACTIONS(9554), 1,
      sym_hash_operator,
    STATE(7089), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [318564] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7090), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318619] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7091), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318674] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7092), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318729] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7093), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318784] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7094), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318839] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7095), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318894] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7096), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318949] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7097), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [319004] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7098), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [319059] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7099), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [319114] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7100), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [319169] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7101), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [319224] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7102), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [319279] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5565), 1,
      anon_sym_DOT,
    ACTIONS(5567), 1,
      anon_sym_POUND,
    ACTIONS(5569), 1,
      sym_hash_operator,
    STATE(7103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [319340] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7104), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [319395] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7105), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [319450] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7106), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8304), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8306), 26,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [319505] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7107), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [319560] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [319615] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7109), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [319670] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9404), 1,
      sym__uppercase_identifier,
    ACTIONS(9486), 1,
      sym__lowercase_identifier,
    ACTIONS(9488), 1,
      anon_sym_LPAREN,
    ACTIONS(9494), 1,
      anon_sym_PIPE,
    ACTIONS(9496), 1,
      anon_sym_LBRACK,
    ACTIONS(9500), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9502), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9504), 1,
      anon_sym_LT,
    ACTIONS(9506), 1,
      anon_sym_POUND,
    ACTIONS(9508), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9510), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9512), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9558), 1,
      anon_sym_DOT_DOT,
    STATE(7110), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(9760), 1,
      sym__simple_type,
    STATE(11003), 1,
      sym__constructor_name,
    STATE(11076), 1,
      sym__tuple_type,
    STATE(11390), 1,
      sym__type,
    STATE(11787), 1,
      sym_constructor_declaration,
    STATE(16914), 1,
      sym_extended_module_path,
    STATE(19582), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9498), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(11104), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(10076), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [319775] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7111), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [319830] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [319885] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [319940] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7114), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [319995] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9532), 1,
      anon_sym_DOT,
    ACTIONS(9546), 1,
      anon_sym_POUND,
    ACTIONS(9548), 1,
      sym_hash_operator,
    STATE(7115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [320056] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [320111] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7117), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [320166] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7118), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [320221] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7119), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [320276] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7120), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [320331] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [320386] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7122), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [320441] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [320496] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [320551] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [320606] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [320661] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7127), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [320716] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7128), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [320771] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7129), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [320826] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9560), 1,
      anon_sym_LT_DASH,
    STATE(7130), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [320883] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7131), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [320938] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [320993] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7133), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [321048] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(7134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [321105] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7135), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [321160] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [321215] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [321270] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [321325] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7139), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [321380] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [321435] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7141), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [321490] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [321545] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [321600] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [321655] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [321710] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9404), 1,
      sym__uppercase_identifier,
    ACTIONS(9408), 1,
      sym__lowercase_identifier,
    ACTIONS(9410), 1,
      anon_sym_LPAREN,
    ACTIONS(9416), 1,
      anon_sym_PIPE,
    ACTIONS(9418), 1,
      anon_sym_LBRACK,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9424), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9426), 1,
      anon_sym_LT,
    ACTIONS(9428), 1,
      anon_sym_POUND,
    ACTIONS(9430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9434), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9562), 1,
      anon_sym_DOT_DOT,
    STATE(7146), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(9482), 1,
      sym__simple_type,
    STATE(10815), 1,
      sym__tuple_type,
    STATE(10928), 1,
      sym__constructor_name,
    STATE(11082), 1,
      sym__type,
    STATE(11569), 1,
      sym_constructor_declaration,
    STATE(16665), 1,
      sym_extended_module_path,
    STATE(20113), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9420), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(10742), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(9574), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [321815] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [321870] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [321925] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7149), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [321980] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7150), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322035] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5575), 1,
      anon_sym_DOT,
    ACTIONS(5577), 1,
      anon_sym_POUND,
    ACTIONS(5579), 1,
      sym_hash_operator,
    STATE(7151), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322096] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7152), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [322151] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7153), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322206] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7154), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322261] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322316] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7156), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322371] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7157), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322426] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7158), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [322481] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322536] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322591] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7161), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [322646] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322701] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [322756] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322811] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [322866] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7166), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322921] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7167), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [322976] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [323031] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7169), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [323086] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323141] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323196] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323251] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(7173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [323308] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323363] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7175), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323418] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323473] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7177), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323528] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323583] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [323638] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323693] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7181), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [323748] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323803] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7183), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323858] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5523), 1,
      anon_sym_DOT,
    STATE(7184), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323915] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323970] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324025] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7187), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324080] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8284), 26,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_tag_token1,
  [324135] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324190] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324245] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9564), 1,
      anon_sym_LT_DASH,
    STATE(7191), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324302] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7192), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324357] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7193), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324412] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5533), 1,
      anon_sym_DOT,
    ACTIONS(5535), 1,
      anon_sym_POUND,
    ACTIONS(5537), 1,
      sym_hash_operator,
    STATE(7194), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324473] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324528] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [324583] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324638] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324693] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [324748] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324803] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324858] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7202), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324913] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324968] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7204), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325023] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7205), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325078] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7206), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325133] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325188] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7208), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325243] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7209), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [325298] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [325353] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [325408] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7212), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325463] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7213), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [325518] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7214), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325573] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7215), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325628] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7216), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325683] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325738] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325793] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7219), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325848] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7220), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325903] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7221), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325958] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5533), 1,
      anon_sym_DOT,
    ACTIONS(5535), 1,
      anon_sym_POUND,
    ACTIONS(5537), 1,
      sym_hash_operator,
    STATE(7222), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326019] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7223), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326074] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326129] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7225), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326184] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7226), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326239] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7227), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326294] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326349] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7229), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326404] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326459] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7231), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326514] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7232), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326569] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9566), 1,
      anon_sym_COLON,
    STATE(7233), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8548), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [326626] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7234), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326681] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7235), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326736] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326791] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7237), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326846] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7238), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8328), 26,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [326901] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9404), 1,
      sym__uppercase_identifier,
    ACTIONS(9454), 1,
      sym__lowercase_identifier,
    ACTIONS(9456), 1,
      anon_sym_LPAREN,
    ACTIONS(9462), 1,
      anon_sym_PIPE,
    ACTIONS(9464), 1,
      anon_sym_LBRACK,
    ACTIONS(9468), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9470), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9472), 1,
      anon_sym_LT,
    ACTIONS(9474), 1,
      anon_sym_POUND,
    ACTIONS(9476), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9478), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9480), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9568), 1,
      anon_sym_DOT_DOT,
    STATE(7239), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(9025), 1,
      sym__simple_type,
    STATE(10401), 1,
      sym__tuple_type,
    STATE(10408), 1,
      sym__constructor_name,
    STATE(10906), 1,
      sym__type,
    STATE(11053), 1,
      sym_constructor_declaration,
    STATE(16859), 1,
      sym_extended_module_path,
    STATE(19708), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9466), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(10612), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(9377), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [327006] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7240), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [327061] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7241), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [327116] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(7242), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8296), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [327173] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9570), 1,
      anon_sym_COLON,
    STATE(7243), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8548), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [327230] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7244), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [327285] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5565), 1,
      anon_sym_DOT,
    STATE(7245), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [327342] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7246), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [327397] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7247), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [327452] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [327507] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7249), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [327562] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7250), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [327617] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7251), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [327672] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7252), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [327727] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7253), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [327782] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7254), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [327837] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7255), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [327892] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7256), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [327947] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [328002] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7258), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [328057] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7259), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [328112] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7260), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [328167] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [328222] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7262), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [328277] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [328332] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [328387] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7265), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [328442] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5575), 1,
      anon_sym_DOT,
    ACTIONS(5577), 1,
      anon_sym_POUND,
    ACTIONS(5579), 1,
      sym_hash_operator,
    STATE(7266), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [328503] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [328558] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7268), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [328613] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7269), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [328668] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [328723] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7271), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [328778] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7272), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [328833] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7273), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [328888] = 30,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9404), 1,
      sym__uppercase_identifier,
    ACTIONS(9454), 1,
      sym__lowercase_identifier,
    ACTIONS(9456), 1,
      anon_sym_LPAREN,
    ACTIONS(9462), 1,
      anon_sym_PIPE,
    ACTIONS(9464), 1,
      anon_sym_LBRACK,
    ACTIONS(9468), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9470), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9472), 1,
      anon_sym_LT,
    ACTIONS(9474), 1,
      anon_sym_POUND,
    ACTIONS(9476), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9478), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9480), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9572), 1,
      anon_sym_DOT_DOT,
    STATE(7274), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(9025), 1,
      sym__simple_type,
    STATE(10401), 1,
      sym__tuple_type,
    STATE(10408), 1,
      sym__constructor_name,
    STATE(10906), 1,
      sym__type,
    STATE(11053), 1,
      sym_constructor_declaration,
    STATE(16859), 1,
      sym_extended_module_path,
    STATE(19708), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9466), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(10559), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(9377), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [328993] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7275), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [329048] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [329103] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7277), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [329158] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [329213] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7279), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [329268] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7280), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [329323] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7281), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7935), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [329377] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8076), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8078), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [329431] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7283), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8084), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8086), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [329485] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7284), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8088), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8090), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [329539] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(7285), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8296), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [329595] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7929), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7931), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [329649] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8092), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8094), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [329703] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7288), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7939), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [329757] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7923), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [329811] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7290), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7911), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7913), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [329865] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7925), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7927), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [329919] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7292), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8070), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [329973] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8108), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8110), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [330027] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9576), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9574), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [330081] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8112), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8114), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [330135] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7296), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9580), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9578), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [330189] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8116), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8118), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [330243] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7298), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8120), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8122), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [330297] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7299), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8124), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8126), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [330351] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8128), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8130), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [330405] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8362), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [330459] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9584), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9582), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [330513] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8132), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8134), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [330567] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7304), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8136), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8138), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [330621] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7305), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8140), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8142), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [330675] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7306), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8148), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8150), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [330729] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7307), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9588), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9586), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [330783] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7308), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8156), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [330837] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7309), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8160), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [330891] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7310), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8164), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [330945] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7311), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8168), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [330999] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7312), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8358), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [331053] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8354), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [331107] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7314), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8172), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [331161] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(7315), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8296), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [331217] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9590), 1,
      anon_sym_DOT,
    STATE(7316), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8176), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [331273] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7317), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8184), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [331327] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7318), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7903), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7905), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [331381] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7319), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8226), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [331435] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7320), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8056), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8058), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [331489] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7321), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8200), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [331543] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7322), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8226), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [331597] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7323), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8204), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [331651] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7324), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8208), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8210), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [331705] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8212), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8214), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [331759] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8220), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [331813] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7327), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8052), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8054), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [331867] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8224), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [331921] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8104), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8106), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [331975] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7330), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8064), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8066), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [332029] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7331), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8350), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [332083] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8074), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [332137] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7333), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8080), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8082), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [332191] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7334), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8096), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8098), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [332245] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8104), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8106), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [332299] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9594), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9592), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [332353] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7337), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8144), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8146), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [332407] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7338), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8232), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [332461] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7339), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8236), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [332515] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7340), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8240), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [332569] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7341), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8244), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [332623] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7342), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8180), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [332677] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7343), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8248), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [332731] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7344), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8622), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [332785] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7345), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8192), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [332839] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8196), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [332893] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7347), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8622), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [332947] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7348), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8002), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8004), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [333001] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8064), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [333055] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7350), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8080), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [333109] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8074), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [333163] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7352), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8096), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [333217] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7353), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8196), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [333271] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7354), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8192), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [333325] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7355), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8144), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [333379] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8070), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [333433] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8314), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [333487] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9576), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9574), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [333541] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7359), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7925), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(7927), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [333595] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7360), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7929), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(7931), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [333649] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9596), 1,
      anon_sym_COLON,
    STATE(7361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8548), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [333705] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7362), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8340), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [333759] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7363), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8322), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [333813] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8178), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [333867] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7365), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8318), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [333921] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7366), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8350), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8352), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [333975] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7367), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(7935), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [334029] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8180), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [334083] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8190), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [334137] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7370), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8064), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [334191] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8076), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8078), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [334245] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7372), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8072), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [334299] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8194), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [334353] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8104), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [334407] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(7375), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [334463] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8084), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8086), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [334517] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8336), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [334571] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7378), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8088), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8090), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [334625] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7379), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8116), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8118), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [334679] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8310), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [334733] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9580), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9578), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [334787] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9584), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9582), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [334841] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8302), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [334895] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8092), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8094), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [334949] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7385), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8292), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [335003] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7386), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8288), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [335057] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7387), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(7939), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [335111] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7388), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(7923), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [335165] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8356), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [335219] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7911), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(7913), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [335273] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8108), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8110), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [335327] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(7392), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [335383] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7393), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8080), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [335437] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7394), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8112), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8114), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [335491] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8144), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8146), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [335545] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8360), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [335599] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7397), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8120), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8122), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [335653] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8124), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8126), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [335707] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7399), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8128), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8130), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [335761] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7400), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8364), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [335815] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9588), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9586), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [335869] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8132), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8134), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [335923] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7403), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8136), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8138), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [335977] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8140), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8142), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [336031] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7405), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8148), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8150), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [336085] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8096), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8098), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [336139] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7407), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8156), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [336193] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8160), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [336247] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7409), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8164), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [336301] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8168), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [336355] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7411), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7996), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7998), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [336409] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8060), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8062), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [336463] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8052), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8054), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [336517] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8172), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [336571] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7415), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8184), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [336625] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8622), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [336679] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7417), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7903), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(7905), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [336733] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8072), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [336787] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7419), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8200), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [336841] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7420), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8204), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [336895] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7421), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8208), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8210), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [336949] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7422), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8080), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8082), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [337003] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7423), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8212), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8214), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [337057] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7424), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8096), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [337111] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7425), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8220), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [337165] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7426), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8104), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [337219] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8224), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [337273] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [337327] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9602), 1,
      anon_sym_COLON,
    STATE(7429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9600), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9598), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [337383] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7430), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8248), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [337437] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9604), 1,
      anon_sym_COLON,
    STATE(7431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9600), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9598), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [337493] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9594), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9592), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [337547] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7433), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8264), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [337601] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8268), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [337655] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8272), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [337709] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8274), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8276), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [337763] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9606), 1,
      anon_sym_COLON,
    STATE(7437), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8548), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [337819] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7438), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8278), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8280), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [337873] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8362), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [337927] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7440), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8232), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [337981] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7441), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8284), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [338035] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7442), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8236), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [338089] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7443), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8240), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [338143] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7444), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8358), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [338197] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7445), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8354), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [338251] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9608), 1,
      anon_sym_COLON,
    STATE(7446), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8548), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [338307] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9610), 1,
      anon_sym_COLON,
    STATE(7447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8548), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [338363] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(7448), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8296), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [338419] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7449), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8194), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [338473] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7450), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8190), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [338527] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7451), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8244), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [338581] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7452), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8178), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [338635] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7453), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8064), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8066), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [338689] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7454), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8304), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8306), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [338743] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8350), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [338797] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(7456), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8296), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [338853] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7457), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8328), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [338907] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9612), 1,
      anon_sym_COLON,
    STATE(7458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8548), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [338963] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7917), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [339017] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7460), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8056), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8058), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [339071] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7461), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8314), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [339125] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7462), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8002), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8004), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [339179] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8144), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [339233] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9614), 1,
      anon_sym_COLON,
    STATE(7464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8548), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [339289] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7465), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7907), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7909), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [339343] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9616), 1,
      anon_sym_COLON,
    STATE(7466), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8548), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [339398] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8248), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [339451] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9618), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9620), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [339504] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8274), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8276), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [339557] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8328), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [339610] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(7471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8296), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [339665] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8314), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [339718] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7473), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9624), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9622), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [339771] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9628), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9626), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [339824] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7475), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8272), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [339877] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7476), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9630), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9632), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [339930] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9636), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9634), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [339983] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9638), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9640), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [340036] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9644), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9642), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [340089] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7480), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8304), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8306), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [340142] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(7481), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8296), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [340197] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7482), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9126), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9124), 26,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [340250] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9646), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9648), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [340303] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7484), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9230), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9228), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [340356] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8284), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [340409] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7486), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8278), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8280), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [340462] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8268), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [340515] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7488), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8274), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8276), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [340568] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8272), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [340621] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7490), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8268), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [340674] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7491), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8350), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8352), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [340727] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7492), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9650), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9652), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [340780] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8278), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8280), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [340833] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7494), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8356), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [340886] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7495), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8360), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [340939] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7496), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8340), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [340992] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7497), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8364), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [341045] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7498), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8264), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [341098] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7499), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8622), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [341151] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7500), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8336), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [341204] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9654), 1,
      anon_sym_COLON,
    STATE(7501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8548), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [341259] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [341312] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7503), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9656), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9658), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [341365] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9660), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9662), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [341418] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7505), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9176), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9174), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [341471] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9666), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9664), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [341524] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7507), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9670), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9668), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [341577] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7508), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9674), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9672), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [341630] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7509), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9678), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9676), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [341683] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7510), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9682), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9680), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [341736] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7511), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9686), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9684), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [341789] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7512), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9146), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9144), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [341842] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7513), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9690), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9688), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [341895] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7514), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9694), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9692), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [341948] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7515), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9698), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9696), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [342001] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7516), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8364), 33,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [342054] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7517), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8310), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [342107] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [342160] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7519), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9588), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9586), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [342213] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7520), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8322), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [342266] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7521), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8318), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [342319] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7522), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9702), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9700), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [342372] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9104), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9102), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [342425] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7524), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8310), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [342478] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7525), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8302), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [342531] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7526), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9208), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9206), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [342584] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9704), 1,
      anon_sym_COLON,
    STATE(7527), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8548), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [342639] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7528), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8292), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [342692] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7529), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8288), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [342745] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7530), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9708), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9706), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [342798] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7531), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9712), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9710), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [342851] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7532), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8622), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [342904] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7533), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [342957] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(7534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8296), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [343012] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7535), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9142), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9140), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [343065] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7536), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9716), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9714), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [343118] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7537), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9158), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9160), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [343171] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9720), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9718), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [343224] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7539), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8622), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [343277] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7540), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8622), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [343330] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7541), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [343383] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7542), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [343436] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7543), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [343489] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7544), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [343542] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [343595] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7546), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8288), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [343648] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7547), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9120), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9118), 26,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [343701] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8292), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [343754] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7549), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9110), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9108), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [343807] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7550), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8302), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [343860] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9726), 1,
      anon_sym_DOT,
    ACTIONS(9728), 1,
      anon_sym_POUND,
    ACTIONS(9730), 1,
      sym_hash_operator,
    STATE(7551), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9724), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9722), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [343919] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9726), 1,
      anon_sym_DOT,
    ACTIONS(9728), 1,
      anon_sym_POUND,
    ACTIONS(9730), 1,
      sym_hash_operator,
    STATE(7552), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9734), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9732), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [343978] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7553), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [344031] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9738), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9736), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [344084] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7555), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8622), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [344137] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7556), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8310), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [344190] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9744), 1,
      anon_sym_DOT,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(9748), 1,
      sym_hash_operator,
    STATE(7557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9742), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(9740), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [344249] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9744), 1,
      anon_sym_DOT,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(9748), 1,
      sym_hash_operator,
    STATE(7558), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9752), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(9750), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [344308] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7559), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9756), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9754), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [344361] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7560), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8336), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [344414] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7561), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9158), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [344467] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7562), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8350), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8352), 33,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [344520] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7563), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9758), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9760), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [344573] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7564), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8264), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [344626] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7565), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9760), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9758), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [344679] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8318), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [344732] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7567), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8322), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [344785] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7568), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8284), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [344838] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7569), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [344891] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7570), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8340), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [344944] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9762), 1,
      anon_sym_COLON,
    STATE(7571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9600), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9598), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [344999] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7572), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8278), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8280), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [345052] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7573), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8274), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8276), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [345105] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7574), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8272), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [345158] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7575), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8268), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [345211] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9726), 1,
      anon_sym_DOT,
    ACTIONS(9728), 1,
      anon_sym_POUND,
    ACTIONS(9730), 1,
      sym_hash_operator,
    STATE(7576), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9742), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9740), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [345270] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9726), 1,
      anon_sym_DOT,
    ACTIONS(9728), 1,
      anon_sym_POUND,
    ACTIONS(9730), 1,
      sym_hash_operator,
    STATE(7577), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9752), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9750), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [345329] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7578), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8264), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [345382] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9718), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9720), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [345435] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7580), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8060), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8062), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [345488] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7581), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7996), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7998), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [345541] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7582), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9258), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9256), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [345594] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7583), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9700), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9702), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [345647] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7584), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9594), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9592), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [345700] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7585), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9116), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9114), 26,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [345753] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9764), 1,
      anon_sym_COLON,
    STATE(7586), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8548), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [345808] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(7587), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8296), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [345863] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9744), 1,
      anon_sym_DOT,
    STATE(7588), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8176), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [345918] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7589), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9140), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9142), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [345971] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7590), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8622), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [346024] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7591), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9766), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9768), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [346077] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7592), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9144), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9146), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [346130] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7593), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7149), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7153), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [346183] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7594), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9174), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9176), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [346236] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7595), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [346289] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9744), 1,
      anon_sym_DOT,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(9748), 1,
      sym_hash_operator,
    STATE(7596), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9734), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(9732), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [346348] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9744), 1,
      anon_sym_DOT,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(9748), 1,
      sym_hash_operator,
    STATE(7597), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9724), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(9722), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [346407] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7598), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [346460] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7599), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9640), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9638), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [346513] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7600), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9632), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9630), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [346566] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7601), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7907), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(7909), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [346619] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7602), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9228), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9230), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [346672] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7603), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [346725] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7604), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8196), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [346778] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8192), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [346831] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7606), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8180), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [346884] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8144), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8146), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [346937] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7608), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9600), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9598), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [346990] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7609), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8364), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [347043] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7610), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8104), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8106), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [347096] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7611), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8096), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8098), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [347149] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9770), 1,
      anon_sym_COLON,
    STATE(7612), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8548), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [347204] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7613), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8356), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [347257] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7614), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8622), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [347310] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7615), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8080), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8082), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [347363] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7616), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8074), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [347416] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7617), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8064), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8066), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [347469] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7618), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [347522] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7619), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [347575] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7620), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9620), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9618), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [347628] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7621), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8350), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8352), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [347681] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7622), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [347734] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9772), 1,
      anon_sym_COLON,
    STATE(7623), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8548), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [347789] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7624), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8288), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [347842] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7625), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8360), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [347895] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7626), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8292), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [347948] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7627), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [348001] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [348054] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7629), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8302), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [348107] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7630), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9714), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9716), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [348160] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7631), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [348213] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8318), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [348266] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7633), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [348319] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7634), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8336), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [348372] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7635), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9102), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9104), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [348425] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [348478] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7637), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9206), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9208), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [348531] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8314), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [348584] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(7917), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [348637] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7640), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9648), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9646), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [348690] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7641), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [348743] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7642), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9652), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9650), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [348796] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9658), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9656), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [348849] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9706), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9708), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [348902] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7645), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9662), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9660), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [348955] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7646), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8322), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [349008] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7647), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8340), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [349061] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7648), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9598), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9600), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [349114] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8052), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8054), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [349167] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7650), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9108), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9110), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [349220] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7651), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8304), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8306), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [349273] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7652), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7149), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7153), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [349326] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9584), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9582), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [349379] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7654), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9580), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9578), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [349432] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [349485] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7656), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8328), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [349538] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7657), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9754), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9756), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [349591] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9736), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9738), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [349644] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7659), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8056), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8058), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [349697] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9774), 1,
      anon_sym_COLON,
    STATE(7660), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8548), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [349752] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7661), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [349805] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8070), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [349858] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7663), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9696), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9698), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [349911] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7664), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9692), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9694), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [349964] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7665), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9688), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9690), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [350017] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7666), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7925), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7927), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [350070] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9676), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9678), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [350123] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [350176] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7929), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7931), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [350229] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7670), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7935), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [350282] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7671), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [350335] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7672), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8076), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8078), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [350388] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7673), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [350441] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [350494] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7675), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8084), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8086), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [350547] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7676), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8088), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8090), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [350600] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8092), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8094), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [350653] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7939), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [350706] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7679), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9642), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9644), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [350759] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9634), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9636), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [350812] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7681), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7923), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [350865] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7682), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7911), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7913), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [350918] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8108), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8110), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [350971] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7684), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8112), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8114), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [351024] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9776), 1,
      anon_sym_COLON,
    STATE(7685), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8548), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [351079] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7686), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9710), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9712), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [351132] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7687), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9626), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9628), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [351185] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7688), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9622), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9624), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [351238] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7689), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8116), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8118), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [351291] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7690), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8120), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8122), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [351344] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7691), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8124), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8126), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [351397] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7692), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8128), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8130), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [351450] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7693), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7907), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7909), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [351503] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7694), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8132), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8134), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [351556] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7695), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8136), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8138), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [351609] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7696), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8140), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8142), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [351662] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7697), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8148), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8150), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [351715] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7698), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8156), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [351768] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7699), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8160), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [351821] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7700), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8164), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [351874] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7701), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8168), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [351927] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8172), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [351980] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9726), 1,
      anon_sym_DOT,
    STATE(7703), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8176), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [352035] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7704), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8184), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [352088] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9256), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9258), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [352141] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7706), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7903), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7905), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [352194] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7707), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8200), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [352247] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7708), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8204), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [352300] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7709), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8208), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8210), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [352353] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7710), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8212), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8214), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [352406] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7711), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8220), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [352459] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7712), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8224), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [352512] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7713), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8360), 33,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [352565] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7714), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7917), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [352618] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7715), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9576), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9574), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [352671] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7716), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9768), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9766), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [352724] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7717), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8356), 33,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [352777] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7718), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8232), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [352830] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7719), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8236), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [352883] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7720), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8240), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [352936] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7721), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9684), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9686), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [352989] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7722), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8244), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [353042] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7723), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9680), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9682), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [353095] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7724), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9664), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9666), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [353148] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7725), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8002), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8004), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [353201] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9668), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9670), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [353254] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7727), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9672), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9674), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [353307] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7728), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9102), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9104), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [353359] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7729), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9144), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9146), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [353411] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7730), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9588), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9586), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [353463] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [353515] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9780), 1,
      anon_sym_PIPE,
    ACTIONS(9782), 1,
      anon_sym_RBRACK,
    STATE(7732), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16306), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [353615] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9784), 1,
      anon_sym_PIPE,
    ACTIONS(9786), 1,
      anon_sym_RBRACK,
    STATE(7733), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16672), 1,
      sym_tag_specification,
    STATE(19262), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [353715] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7734), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9594), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9592), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [353767] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9788), 1,
      anon_sym_PIPE,
    ACTIONS(9790), 1,
      anon_sym_RBRACK,
    STATE(7735), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16264), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [353867] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7736), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9584), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9582), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [353919] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9580), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9578), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [353971] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9792), 1,
      anon_sym_PIPE,
    ACTIONS(9794), 1,
      anon_sym_RBRACK,
    STATE(7738), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15104), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [354071] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7739), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9638), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9640), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [354123] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7740), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8622), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [354175] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7741), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9576), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9574), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [354227] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7742), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8328), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [354279] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7743), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9630), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9632), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [354331] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7744), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9228), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9230), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [354383] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7745), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9622), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9624), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [354435] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7746), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9626), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9628), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [354487] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7747), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9710), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9712), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [354539] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7748), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8622), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [354591] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7749), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8340), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [354643] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7750), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9634), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9636), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [354695] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7751), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [354747] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9796), 1,
      anon_sym_PIPE,
    ACTIONS(9798), 1,
      anon_sym_RBRACK,
    STATE(7752), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16146), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [354847] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9800), 1,
      anon_sym_PIPE,
    ACTIONS(9802), 1,
      anon_sym_RBRACK,
    STATE(7753), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(15897), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [354947] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7754), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9642), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9644), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [354999] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9804), 1,
      anon_sym_PIPE,
    ACTIONS(9806), 1,
      anon_sym_RBRACK,
    STATE(7755), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15301), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [355099] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9808), 1,
      anon_sym_PIPE,
    ACTIONS(9810), 1,
      anon_sym_RBRACK,
    STATE(7756), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(15892), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [355199] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8318), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [355251] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8264), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [355303] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7759), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8314), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [355355] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7760), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8350), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8352), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [355407] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7761), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8284), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [355459] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7762), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [355511] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7763), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9758), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9760), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [355563] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9812), 1,
      anon_sym_PIPE,
    ACTIONS(9814), 1,
      anon_sym_RBRACK,
    STATE(7764), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16866), 1,
      sym_tag_specification,
    STATE(19551), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [355663] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7765), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8336), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [355715] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9754), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9756), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [355767] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9816), 1,
      anon_sym_PIPE,
    ACTIONS(9818), 1,
      anon_sym_RBRACK,
    STATE(7767), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15363), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [355867] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7768), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8310), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [355919] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8322), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [355971] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7770), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9206), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9208), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [356023] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7771), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9736), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9738), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [356075] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9820), 1,
      anon_sym_PIPE,
    ACTIONS(9822), 1,
      anon_sym_RBRACK,
    STATE(7772), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16502), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [356175] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9824), 1,
      anon_sym_PIPE,
    ACTIONS(9826), 1,
      anon_sym_RBRACK,
    STATE(7773), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15478), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [356275] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7774), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8304), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8306), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [356327] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7775), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8302), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [356379] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(7776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [356433] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7777), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8292), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [356485] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7778), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8288), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [356537] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9828), 1,
      anon_sym_PIPE,
    ACTIONS(9830), 1,
      anon_sym_RBRACK,
    STATE(7779), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15665), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [356637] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(7780), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [356691] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7781), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8356), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [356743] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8360), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [356795] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9832), 1,
      anon_sym_PIPE,
    ACTIONS(9834), 1,
      anon_sym_RBRACK,
    STATE(7783), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(15712), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [356895] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9836), 1,
      anon_sym_PIPE,
    ACTIONS(9838), 1,
      anon_sym_RBRACK,
    STATE(7784), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16918), 1,
      sym_tag_specification,
    STATE(19602), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [356995] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7785), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8364), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [357047] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8622), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [357099] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7787), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9598), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9600), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [357151] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9840), 1,
      anon_sym_PIPE,
    ACTIONS(9842), 1,
      anon_sym_RBRACK,
    STATE(7788), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16427), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [357251] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9844), 1,
      anon_sym_PIPE,
    ACTIONS(9846), 1,
      anon_sym_RBRACK,
    STATE(7789), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16036), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [357351] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9848), 1,
      anon_sym_PIPE,
    ACTIONS(9850), 1,
      anon_sym_RBRACK,
    STATE(7790), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15517), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [357451] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7791), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [357503] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9852), 1,
      anon_sym_PIPE,
    ACTIONS(9854), 1,
      anon_sym_RBRACK,
    STATE(7792), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16755), 1,
      sym_tag_specification,
    STATE(19433), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [357603] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9856), 1,
      anon_sym_PIPE,
    ACTIONS(9858), 1,
      anon_sym_RBRACK,
    STATE(7793), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15288), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [357703] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7794), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9108), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9110), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [357755] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7795), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9140), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9142), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [357807] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7796), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7153), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(7149), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [357859] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8268), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [357911] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9860), 1,
      anon_sym_PIPE,
    ACTIONS(9862), 1,
      anon_sym_RBRACK,
    STATE(7798), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15454), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [358011] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7799), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9718), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9720), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [358063] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7800), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9766), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9768), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [358115] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7801), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9700), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9702), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [358167] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7802), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9684), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9686), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [358219] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9680), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9682), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [358271] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7804), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [358323] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7805), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8622), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [358375] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7806), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8272), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [358427] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7807), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9706), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9708), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [358479] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7808), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8274), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8276), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [358531] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7809), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9672), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9674), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [358583] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9158), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9160), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [358635] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7811), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9668), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9670), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [358687] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9864), 1,
      anon_sym_PIPE,
    ACTIONS(9866), 1,
      anon_sym_RBRACK,
    STATE(7812), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16219), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [358787] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7813), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9664), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9666), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [358839] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7814), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8278), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8280), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [358891] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7815), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9646), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9648), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [358943] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7816), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9696), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9698), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [358995] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7817), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9692), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9694), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [359047] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7818), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9688), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9690), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [359099] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9256), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9258), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [359151] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7820), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8622), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [359203] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9868), 1,
      anon_sym_PIPE,
    ACTIONS(9870), 1,
      anon_sym_RBRACK,
    STATE(7821), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(15723), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [359303] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9872), 1,
      anon_sym_PIPE,
    ACTIONS(9874), 1,
      anon_sym_RBRACK,
    STATE(7822), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16449), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [359403] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9714), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9716), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [359455] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7824), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9656), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9658), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [359507] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7825), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9618), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9620), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [359559] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [359611] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7827), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8622), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [359663] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7828), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9660), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9662), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [359715] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7829), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9174), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9176), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [359767] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9876), 1,
      anon_sym_PIPE,
    ACTIONS(9878), 1,
      anon_sym_RBRACK,
    STATE(7830), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16308), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [359867] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7831), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9676), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9678), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [359919] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9880), 1,
      anon_sym_COLON,
    STATE(7832), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9600), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9598), 20,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [359973] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9882), 1,
      anon_sym_PIPE,
    ACTIONS(9884), 1,
      anon_sym_RBRACK,
    STATE(7833), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16153), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [360073] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7834), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9650), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9652), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [360125] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7835), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8222), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [360176] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7836), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8194), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [360227] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9886), 1,
      anon_sym_RBRACK,
    STATE(7837), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16293), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [360324] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7838), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9694), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9692), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [360375] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9888), 1,
      anon_sym_RBRACK,
    STATE(7839), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16140), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [360472] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7840), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9698), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9696), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [360523] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [360574] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7842), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [360625] = 26,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9890), 1,
      sym__lowercase_identifier,
    ACTIONS(9892), 1,
      anon_sym_let,
    ACTIONS(9894), 1,
      anon_sym_QMARK,
    ACTIONS(9896), 1,
      anon_sym_LBRACK,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(9900), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9902), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(7843), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(10427), 1,
      sym__class_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16572), 1,
      sym__tuple_type,
    STATE(16574), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10656), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(10670), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(9607), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(12249), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [360718] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4951), 1,
      anon_sym_type,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9904), 1,
      sym__lowercase_identifier,
    ACTIONS(9906), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_LBRACK,
    ACTIONS(9910), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9912), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9914), 1,
      anon_sym_LT,
    ACTIONS(9916), 1,
      anon_sym_POUND,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9920), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9922), 1,
      aux_sym_type_variable_token1,
    STATE(7844), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(10568), 1,
      sym__polymorphic_type,
    STATE(10583), 1,
      sym_type_variable,
    STATE(10594), 1,
      sym__simple_type,
    STATE(10698), 1,
      sym_polymorphic_type,
    STATE(11981), 1,
      sym__tuple_type,
    STATE(12259), 1,
      sym__type,
    STATE(14506), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16934), 1,
      sym_extended_module_path,
    STATE(19479), 1,
      sym_typed_label,
    STATE(19958), 1,
      sym__abstract_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(11018), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [360817] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9924), 1,
      anon_sym_PIPE,
    STATE(7845), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14516), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [360914] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9926), 1,
      anon_sym_RBRACK,
    STATE(7846), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16277), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [361011] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7847), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [361062] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9928), 1,
      anon_sym_PIPE,
    STATE(7848), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14922), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [361159] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7849), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [361210] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9930), 1,
      anon_sym_PIPE,
    STATE(7850), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16984), 1,
      sym_tag_specification,
    STATE(19641), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [361307] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7851), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9230), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9228), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [361358] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9932), 1,
      anon_sym_PIPE,
    STATE(7852), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(17111), 1,
      sym_tag_specification,
    STATE(19678), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [361455] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4951), 1,
      anon_sym_type,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    STATE(7853), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(10568), 1,
      sym__polymorphic_type,
    STATE(10698), 1,
      sym_polymorphic_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(12921), 1,
      sym_type_variable,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14892), 1,
      sym__type,
    STATE(14901), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20422), 1,
      sym__abstract_type,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [361554] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7854), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9760), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9758), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [361605] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7855), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9708), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9706), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [361656] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7856), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9716), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9714), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [361707] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [361758] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(3053), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(3051), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [361809] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9934), 1,
      anon_sym_RBRACK,
    STATE(7859), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16423), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [361906] = 19,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6833), 1,
      sym__lowercase_identifier,
    ACTIONS(9940), 1,
      anon_sym_LPAREN,
    ACTIONS(9944), 1,
      anon_sym_LBRACE,
    ACTIONS(9946), 1,
      anon_sym_begin,
    ACTIONS(9948), 1,
      aux_sym_number_token1,
    ACTIONS(9950), 1,
      anon_sym_SQUOTE,
    ACTIONS(9952), 1,
      anon_sym_DQUOTE,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    STATE(7860), 1,
      sym_attribute,
    STATE(10358), 1,
      sym_parenthesized_operator,
    STATE(12067), 1,
      sym_module_path,
    STATE(12605), 1,
      sym__value_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9942), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12374), 2,
      sym__constant,
      sym_value_path,
    ACTIONS(9936), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
    STATE(12289), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    ACTIONS(9938), 9,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
  [361985] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9956), 1,
      anon_sym_PIPE,
    STATE(7861), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(17233), 1,
      sym_tag_specification,
    STATE(19742), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [362082] = 26,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9892), 1,
      anon_sym_let,
    ACTIONS(9896), 1,
      anon_sym_LBRACK,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(9958), 1,
      sym__lowercase_identifier,
    ACTIONS(9960), 1,
      anon_sym_QMARK,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9964), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(7862), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(10400), 1,
      sym__class_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16596), 1,
      sym_extended_module_path,
    STATE(16712), 1,
      sym__tuple_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10213), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(10656), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(9607), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(12249), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [362175] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7863), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9968), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9966), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [362226] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9970), 1,
      anon_sym_RBRACK,
    STATE(7864), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16225), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [362323] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7865), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9690), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9688), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [362374] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9972), 1,
      anon_sym_RBRACK,
    STATE(7866), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15680), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [362471] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7867), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9620), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9618), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [362522] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7868), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9720), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9718), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [362573] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7869), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9702), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9700), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [362624] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9648), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9646), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [362675] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9974), 1,
      anon_sym_RBRACK,
    STATE(7871), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16410), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [362772] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7872), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [362823] = 26,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(9976), 1,
      sym__lowercase_identifier,
    ACTIONS(9978), 1,
      anon_sym_let,
    ACTIONS(9980), 1,
      anon_sym_QMARK,
    ACTIONS(9982), 1,
      anon_sym_LBRACK,
    STATE(7873), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(10400), 1,
      sym__class_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16792), 1,
      sym__tuple_type,
    STATE(16941), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10656), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(14117), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(9607), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(12249), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [362916] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9984), 1,
      anon_sym_RBRACK,
    STATE(7874), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16208), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [363013] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9986), 1,
      anon_sym_RBRACK,
    STATE(7875), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(15860), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [363110] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7876), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9678), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9676), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [363161] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7877), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [363212] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9988), 1,
      anon_sym_RBRACK,
    STATE(7878), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16173), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [363309] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4951), 1,
      anon_sym_type,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9990), 1,
      sym__lowercase_identifier,
    ACTIONS(9992), 1,
      anon_sym_LPAREN,
    ACTIONS(9994), 1,
      anon_sym_LBRACK,
    ACTIONS(9996), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9998), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10000), 1,
      anon_sym_LT,
    ACTIONS(10002), 1,
      anon_sym_POUND,
    ACTIONS(10004), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10006), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10008), 1,
      aux_sym_type_variable_token1,
    STATE(7879), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(10568), 1,
      sym__polymorphic_type,
    STATE(10698), 1,
      sym_polymorphic_type,
    STATE(11068), 1,
      sym__simple_type,
    STATE(11258), 1,
      sym_type_variable,
    STATE(12710), 1,
      sym__tuple_type,
    STATE(12896), 1,
      sym__type,
    STATE(15043), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17058), 1,
      sym_extended_module_path,
    STATE(19394), 1,
      sym_typed_label,
    STATE(19831), 1,
      sym__abstract_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(11773), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [363408] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7880), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [363459] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10010), 1,
      anon_sym_PIPE,
    STATE(7881), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14455), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [363556] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7882), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [363607] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7883), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [363658] = 26,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9892), 1,
      anon_sym_let,
    ACTIONS(9896), 1,
      anon_sym_LBRACK,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(10012), 1,
      sym__lowercase_identifier,
    ACTIONS(10014), 1,
      anon_sym_QMARK,
    ACTIONS(10016), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10018), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(7884), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(10400), 1,
      sym__class_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16751), 1,
      sym__tuple_type,
    STATE(16778), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10656), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(10870), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(9607), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(12249), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [363751] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7885), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8350), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8352), 25,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_with,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [363802] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8356), 25,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_with,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [363853] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [363904] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7888), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8360), 25,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_with,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [363955] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7889), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9158), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [364006] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7890), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8364), 25,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_with,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [364057] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7891), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [364108] = 26,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9890), 1,
      sym__lowercase_identifier,
    ACTIONS(9892), 1,
      anon_sym_let,
    ACTIONS(9894), 1,
      anon_sym_QMARK,
    ACTIONS(9896), 1,
      anon_sym_LBRACK,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(9900), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9902), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(7892), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(10641), 1,
      sym__class_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16572), 1,
      sym__tuple_type,
    STATE(16574), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10656), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(10670), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(9607), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(12249), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [364201] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7893), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [364252] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [364303] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9738), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9736), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [364354] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7896), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9652), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9650), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [364405] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10020), 1,
      anon_sym_PIPE,
    STATE(7897), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16714), 1,
      sym_tag_specification,
    STATE(19359), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [364502] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7898), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7996), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [364553] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9624), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9622), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [364604] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7900), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [364655] = 26,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9890), 1,
      sym__lowercase_identifier,
    ACTIONS(9892), 1,
      anon_sym_let,
    ACTIONS(9894), 1,
      anon_sym_QMARK,
    ACTIONS(9896), 1,
      anon_sym_LBRACK,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(9900), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9902), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(7901), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(10660), 1,
      sym__class_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16572), 1,
      sym__tuple_type,
    STATE(16574), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10656), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(10670), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(9607), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(12249), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [364748] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7902), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [364799] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7911), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [364850] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4951), 1,
      anon_sym_type,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    STATE(7904), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(12906), 1,
      sym_tuple_type,
    STATE(12921), 1,
      sym_type_variable,
    STATE(13657), 1,
      sym__tuple_type,
    STATE(14329), 1,
      sym__type,
    STATE(14572), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16067), 1,
      sym_polymorphic_type,
    STATE(16090), 1,
      sym__polymorphic_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20407), 1,
      sym_typed_label,
    STATE(20439), 1,
      sym__abstract_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12956), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [364949] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8154), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [365000] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7906), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [365051] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4951), 1,
      anon_sym_type,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10022), 1,
      sym__lowercase_identifier,
    ACTIONS(10024), 1,
      anon_sym_LPAREN,
    ACTIONS(10026), 1,
      anon_sym_LBRACK,
    ACTIONS(10028), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10030), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10032), 1,
      anon_sym_LT,
    ACTIONS(10034), 1,
      anon_sym_POUND,
    ACTIONS(10036), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10038), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10040), 1,
      aux_sym_type_variable_token1,
    STATE(7907), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(10568), 1,
      sym__polymorphic_type,
    STATE(10698), 1,
      sym_polymorphic_type,
    STATE(12099), 1,
      sym_type_variable,
    STATE(12149), 1,
      sym__simple_type,
    STATE(12944), 1,
      sym__tuple_type,
    STATE(13144), 1,
      sym__type,
    STATE(14640), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17260), 1,
      sym_extended_module_path,
    STATE(19173), 1,
      sym_typed_label,
    STATE(19693), 1,
      sym__abstract_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12684), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [365150] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [365201] = 26,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9892), 1,
      anon_sym_let,
    ACTIONS(9896), 1,
      anon_sym_LBRACK,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(10012), 1,
      sym__lowercase_identifier,
    ACTIONS(10014), 1,
      anon_sym_QMARK,
    ACTIONS(10016), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10018), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(7909), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(10427), 1,
      sym__class_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16751), 1,
      sym__tuple_type,
    STATE(16778), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10656), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(10870), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(9607), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(12249), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [365294] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10042), 1,
      anon_sym_PIPE,
    STATE(7910), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15000), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [365391] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10044), 1,
      anon_sym_RBRACK,
    STATE(7911), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15555), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [365488] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9756), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9754), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [365539] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10046), 1,
      anon_sym_PIPE,
    STATE(7913), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14823), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [365636] = 26,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9892), 1,
      anon_sym_let,
    ACTIONS(9896), 1,
      anon_sym_LBRACK,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(10012), 1,
      sym__lowercase_identifier,
    ACTIONS(10014), 1,
      anon_sym_QMARK,
    ACTIONS(10016), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10018), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(7914), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(10660), 1,
      sym__class_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16751), 1,
      sym__tuple_type,
    STATE(16778), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10656), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(10870), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(9607), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(12249), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [365729] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7915), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7907), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [365780] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9784), 1,
      anon_sym_PIPE,
    STATE(7916), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16672), 1,
      sym_tag_specification,
    STATE(19262), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [365877] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7917), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9658), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9656), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [365928] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7918), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9662), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9660), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [365979] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10048), 1,
      anon_sym_PIPE,
    STATE(7919), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(17074), 1,
      sym_tag_specification,
    STATE(19660), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [366076] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10052), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10050), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [366127] = 26,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9890), 1,
      sym__lowercase_identifier,
    ACTIONS(9892), 1,
      anon_sym_let,
    ACTIONS(9894), 1,
      anon_sym_QMARK,
    ACTIONS(9896), 1,
      anon_sym_LBRACK,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(9900), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9902), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(7921), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(10400), 1,
      sym__class_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16572), 1,
      sym__tuple_type,
    STATE(16574), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10656), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(10670), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(9607), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(12249), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [366220] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7922), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9632), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9630), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [366271] = 19,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6833), 1,
      sym__lowercase_identifier,
    ACTIONS(9940), 1,
      anon_sym_LPAREN,
    ACTIONS(9944), 1,
      anon_sym_LBRACE,
    ACTIONS(9946), 1,
      anon_sym_begin,
    ACTIONS(9948), 1,
      aux_sym_number_token1,
    ACTIONS(9950), 1,
      anon_sym_SQUOTE,
    ACTIONS(9952), 1,
      anon_sym_DQUOTE,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    STATE(7923), 1,
      sym_attribute,
    STATE(10358), 1,
      sym_parenthesized_operator,
    STATE(12067), 1,
      sym_module_path,
    STATE(12605), 1,
      sym__value_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9942), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12374), 2,
      sym__constant,
      sym_value_path,
    STATE(12289), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    ACTIONS(9936), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
    ACTIONS(9938), 8,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
  [366350] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7924), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9628), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9626), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [366401] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7925), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [366452] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9640), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9638), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [366503] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7927), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [366554] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7928), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10056), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10054), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [366605] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10060), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10058), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [366656] = 26,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9892), 1,
      anon_sym_let,
    ACTIONS(9896), 1,
      anon_sym_LBRACK,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(9958), 1,
      sym__lowercase_identifier,
    ACTIONS(9960), 1,
      anon_sym_QMARK,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9964), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(7930), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(10427), 1,
      sym__class_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16596), 1,
      sym_extended_module_path,
    STATE(16712), 1,
      sym__tuple_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10213), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(10656), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(9607), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(12249), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [366749] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7931), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [366800] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10062), 1,
      anon_sym_PIPE,
    STATE(7932), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14907), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [366897] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10064), 1,
      anon_sym_RBRACK,
    STATE(7933), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16115), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [366994] = 26,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9892), 1,
      anon_sym_let,
    ACTIONS(9896), 1,
      anon_sym_LBRACK,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(10066), 1,
      sym__lowercase_identifier,
    ACTIONS(10068), 1,
      anon_sym_QMARK,
    ACTIONS(10070), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10072), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(7934), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(10641), 1,
      sym__class_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16554), 1,
      sym_extended_module_path,
    STATE(16669), 1,
      sym__tuple_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10149), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(10656), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(9607), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(12249), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [367087] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10074), 1,
      anon_sym_PIPE,
    STATE(7935), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(17399), 1,
      sym_tag_specification,
    STATE(19822), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [367184] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10076), 1,
      anon_sym_PIPE,
    STATE(7936), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14409), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [367281] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7937), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10080), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10078), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [367332] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9142), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9140), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [367383] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10082), 1,
      anon_sym_PIPE,
    STATE(7939), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(17139), 1,
      sym_tag_specification,
    STATE(19694), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [367480] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8198), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [367531] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7941), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9768), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9766), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [367582] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10084), 1,
      anon_sym_PIPE,
    STATE(7942), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14734), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [367679] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9712), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9710), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [367730] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7944), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8158), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [367781] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10086), 1,
      anon_sym_RBRACK,
    STATE(7945), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15474), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [367878] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7946), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8162), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [367929] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7947), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10090), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10088), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [367980] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7948), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10094), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10092), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [368031] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7949), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8166), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [368082] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10096), 1,
      anon_sym_RBRACK,
    STATE(7950), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16023), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [368179] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7951), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10100), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10098), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [368230] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7952), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10104), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10102), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [368281] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7953), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [368332] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7954), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8170), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [368383] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7955), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10108), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10106), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [368434] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10110), 1,
      anon_sym_PIPE,
    STATE(7956), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16938), 1,
      sym_tag_specification,
    STATE(19622), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [368531] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7957), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10114), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10112), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [368582] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10118), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10116), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [368633] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9852), 1,
      anon_sym_PIPE,
    STATE(7959), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16755), 1,
      sym_tag_specification,
    STATE(19433), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [368730] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10120), 1,
      anon_sym_PIPE,
    STATE(7960), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15051), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [368827] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7961), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [368878] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10122), 1,
      anon_sym_PIPE,
    STATE(7962), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(17268), 1,
      sym_tag_specification,
    STATE(19758), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [368975] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10124), 1,
      anon_sym_PIPE,
    STATE(7963), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(14997), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [369072] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7964), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [369123] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7965), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10128), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10126), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [369174] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7966), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [369225] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7967), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [369276] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10130), 1,
      anon_sym_PIPE,
    STATE(7968), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14583), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [369373] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9636), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9634), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [369424] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7970), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7927), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7925), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [369475] = 26,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9892), 1,
      anon_sym_let,
    ACTIONS(9896), 1,
      anon_sym_LBRACK,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(9958), 1,
      sym__lowercase_identifier,
    ACTIONS(9960), 1,
      anon_sym_QMARK,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9964), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(7971), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(10641), 1,
      sym__class_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16596), 1,
      sym_extended_module_path,
    STATE(16712), 1,
      sym__tuple_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10213), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(10656), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(9607), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(12249), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [369568] = 29,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4951), 1,
      anon_sym_type,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10132), 1,
      sym__lowercase_identifier,
    ACTIONS(10134), 1,
      anon_sym_LPAREN,
    ACTIONS(10136), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10140), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10142), 1,
      anon_sym_LT,
    ACTIONS(10144), 1,
      anon_sym_POUND,
    ACTIONS(10146), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10148), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10150), 1,
      aux_sym_type_variable_token1,
    STATE(7972), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(10175), 1,
      sym__simple_type,
    STATE(10302), 1,
      sym_type_variable,
    STATE(10568), 1,
      sym__polymorphic_type,
    STATE(10698), 1,
      sym_polymorphic_type,
    STATE(11805), 1,
      sym__tuple_type,
    STATE(11958), 1,
      sym__type,
    STATE(14978), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16704), 1,
      sym_extended_module_path,
    STATE(19973), 1,
      sym_typed_label,
    STATE(20099), 1,
      sym__abstract_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(10841), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [369667] = 26,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(9976), 1,
      sym__lowercase_identifier,
    ACTIONS(9978), 1,
      anon_sym_let,
    ACTIONS(9980), 1,
      anon_sym_QMARK,
    ACTIONS(9982), 1,
      anon_sym_LBRACK,
    STATE(7973), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(10660), 1,
      sym__class_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16792), 1,
      sym__tuple_type,
    STATE(16941), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10656), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(14117), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(9607), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(12249), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [369760] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7974), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [369811] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10152), 1,
      anon_sym_PIPE,
    STATE(7975), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14436), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [369908] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7976), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10156), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10154), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [369959] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7977), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [370010] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10158), 1,
      anon_sym_PIPE,
    STATE(7978), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(17201), 1,
      sym_tag_specification,
    STATE(19726), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [370107] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [370158] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7980), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8178), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [370209] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(7981), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 14,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [370262] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [370313] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7983), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10162), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10160), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [370364] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10164), 1,
      anon_sym_DOT,
    STATE(7984), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 14,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8174), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [370417] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7985), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8182), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [370468] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7905), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7903), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [370519] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7987), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10168), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10166), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [370570] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10172), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10170), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [370621] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7989), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [370672] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7990), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8202), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [370723] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7991), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [370774] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7992), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8350), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [370825] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7993), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7929), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [370876] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7994), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [370927] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7995), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10176), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10174), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [370978] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10178), 1,
      anon_sym_RBRACK,
    STATE(7996), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(15809), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [371075] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10180), 1,
      anon_sym_PIPE,
    STATE(7997), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16833), 1,
      sym_tag_specification,
    STATE(19523), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [371172] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7998), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7933), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [371223] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7999), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8354), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [371274] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10182), 1,
      anon_sym_PIPE,
    STATE(8000), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14927), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [371371] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8001), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9644), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9642), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [371422] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8002), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8358), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [371473] = 26,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9892), 1,
      anon_sym_let,
    ACTIONS(9896), 1,
      anon_sym_LBRACK,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(10066), 1,
      sym__lowercase_identifier,
    ACTIONS(10068), 1,
      anon_sym_QMARK,
    ACTIONS(10070), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10072), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(8003), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(10427), 1,
      sym__class_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16554), 1,
      sym_extended_module_path,
    STATE(16669), 1,
      sym__tuple_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10149), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(10656), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(9607), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(12249), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [371566] = 26,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9892), 1,
      anon_sym_let,
    ACTIONS(9896), 1,
      anon_sym_LBRACK,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(10066), 1,
      sym__lowercase_identifier,
    ACTIONS(10068), 1,
      anon_sym_QMARK,
    ACTIONS(10070), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10072), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(8004), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(10660), 1,
      sym__class_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16554), 1,
      sym_extended_module_path,
    STATE(16669), 1,
      sym__tuple_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10149), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(10656), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(9607), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(12249), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [371659] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8005), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8218), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [371710] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8006), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [371761] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8007), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9104), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9102), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [371812] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8008), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9686), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9684), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [371863] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8009), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [371914] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8010), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9208), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9206), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [371965] = 26,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9892), 1,
      anon_sym_let,
    ACTIONS(9896), 1,
      anon_sym_LBRACK,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(10012), 1,
      sym__lowercase_identifier,
    ACTIONS(10014), 1,
      anon_sym_QMARK,
    ACTIONS(10016), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10018), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(8011), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(10641), 1,
      sym__class_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16751), 1,
      sym__tuple_type,
    STATE(16778), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10656), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(10870), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(9607), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(12249), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [372058] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8012), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [372109] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8013), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [372160] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8014), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9674), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9672), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [372211] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [372262] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8016), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8190), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [372313] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10186), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10184), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [372364] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(8018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 14,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8294), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [372417] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [372468] = 26,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9892), 1,
      anon_sym_let,
    ACTIONS(9896), 1,
      anon_sym_LBRACK,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(10066), 1,
      sym__lowercase_identifier,
    ACTIONS(10068), 1,
      anon_sym_QMARK,
    ACTIONS(10070), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10072), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(8020), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(10400), 1,
      sym__class_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16554), 1,
      sym_extended_module_path,
    STATE(16669), 1,
      sym__tuple_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10149), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(10656), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(9607), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(12249), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [372561] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10188), 1,
      anon_sym_PIPE,
    STATE(8021), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14517), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [372658] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8022), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8230), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [372709] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8023), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10192), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10190), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [372760] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8234), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [372811] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8025), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8238), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [372862] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8026), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [372913] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9836), 1,
      anon_sym_PIPE,
    STATE(8027), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16918), 1,
      sym_tag_specification,
    STATE(19602), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [373010] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10194), 1,
      anon_sym_PIPE,
    STATE(8028), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14817), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [373107] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8029), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [373158] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8030), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8242), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [373209] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10196), 1,
      anon_sym_RBRACK,
    STATE(8031), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(15825), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [373306] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8286), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [373357] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8033), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8290), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [373408] = 26,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(9976), 1,
      sym__lowercase_identifier,
    ACTIONS(9978), 1,
      anon_sym_let,
    ACTIONS(9980), 1,
      anon_sym_QMARK,
    ACTIONS(9982), 1,
      anon_sym_LBRACK,
    STATE(8034), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(10427), 1,
      sym__class_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16792), 1,
      sym__tuple_type,
    STATE(16941), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10656), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(14117), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(9607), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(12249), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [373501] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8035), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8246), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [373552] = 26,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(9976), 1,
      sym__lowercase_identifier,
    ACTIONS(9978), 1,
      anon_sym_let,
    ACTIONS(9980), 1,
      anon_sym_QMARK,
    ACTIONS(9982), 1,
      anon_sym_LBRACK,
    STATE(8036), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(10641), 1,
      sym__class_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16792), 1,
      sym__tuple_type,
    STATE(16941), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10656), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(14117), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(9607), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(12249), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [373645] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9110), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9108), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [373696] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10198), 1,
      anon_sym_PIPE,
    STATE(8038), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(17304), 1,
      sym_tag_specification,
    STATE(19774), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [373793] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8039), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [373844] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8304), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [373895] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8041), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8308), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [373946] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7923), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7921), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [373997] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8004), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8002), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [374048] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8262), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [374099] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8045), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10202), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10200), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [374150] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [374201] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10204), 1,
      anon_sym_PIPE,
    STATE(8047), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14639), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [374298] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8048), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8312), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [374349] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10206), 1,
      anon_sym_RBRACK,
    STATE(8049), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16238), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [374446] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8050), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8282), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [374497] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10208), 1,
      aux_sym_attribute_id_token1,
    STATE(8051), 1,
      sym_attribute,
    STATE(8056), 1,
      aux_sym_attribute_id_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9052), 15,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9050), 19,
      anon_sym_let,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [374552] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8052), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9682), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9680), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [374603] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8053), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9670), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9668), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [374654] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10210), 1,
      anon_sym_PIPE,
    STATE(8054), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(17373), 1,
      sym_tag_specification,
    STATE(19806), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [374751] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10212), 1,
      anon_sym_PIPE,
    STATE(8055), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(13984), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16578), 1,
      sym_tag_specification,
    STATE(20378), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [374848] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10208), 1,
      aux_sym_attribute_id_token1,
    STATE(8056), 1,
      sym_attribute,
    STATE(8075), 1,
      aux_sym_attribute_id_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8921), 15,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8919), 19,
      anon_sym_let,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [374903] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10214), 1,
      anon_sym_RBRACK,
    STATE(8057), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15368), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [375000] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8058), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8270), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [375051] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8059), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [375102] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8060), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [375153] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8061), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [375204] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8062), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8316), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [375255] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8063), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8320), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [375306] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8064), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7915), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [375357] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8065), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [375408] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8066), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8278), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [375459] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10216), 1,
      anon_sym_PIPE,
    STATE(8067), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14508), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [375556] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10218), 1,
      anon_sym_PIPE,
    STATE(8068), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16895), 1,
      sym_tag_specification,
    STATE(19577), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [375653] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8069), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [375704] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8070), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [375755] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8071), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7937), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [375806] = 26,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9892), 1,
      anon_sym_let,
    ACTIONS(9896), 1,
      anon_sym_LBRACK,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(9958), 1,
      sym__lowercase_identifier,
    ACTIONS(9960), 1,
      anon_sym_QMARK,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9964), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(8072), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(10660), 1,
      sym__class_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16596), 1,
      sym_extended_module_path,
    STATE(16712), 1,
      sym__tuple_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10213), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(10656), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(9607), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(12249), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [375899] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8073), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9666), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9664), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [375950] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10164), 1,
      anon_sym_DOT,
    ACTIONS(10220), 1,
      anon_sym_POUND,
    ACTIONS(10222), 1,
      sym_hash_operator,
    STATE(8074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 13,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [376007] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10224), 1,
      aux_sym_attribute_id_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8075), 2,
      sym_attribute,
      aux_sym_attribute_id_repeat1,
    ACTIONS(8961), 15,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8959), 19,
      anon_sym_let,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [376060] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8076), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8274), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [376111] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9258), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9256), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [376162] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10227), 1,
      anon_sym_RBRACK,
    STATE(8078), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(15841), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [376259] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8079), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [376310] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8080), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [376361] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10229), 1,
      anon_sym_PIPE,
    STATE(8081), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14581), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [376458] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10231), 1,
      anon_sym_PIPE,
    STATE(8082), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16794), 1,
      sym_tag_specification,
    STATE(19489), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [376555] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10212), 1,
      anon_sym_PIPE,
    STATE(8083), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16578), 1,
      sym_tag_specification,
    STATE(20378), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [376652] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10164), 1,
      anon_sym_DOT,
    ACTIONS(10220), 1,
      anon_sym_POUND,
    ACTIONS(10222), 1,
      sym_hash_operator,
    STATE(8084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 13,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [376709] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10233), 1,
      anon_sym_RBRACK,
    STATE(8085), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15170), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [376806] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10235), 1,
      anon_sym_RBRACK,
    STATE(8086), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15491), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [376903] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10237), 1,
      anon_sym_PIPE,
    STATE(8087), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(17339), 1,
      sym_tag_specification,
    STATE(19790), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [377000] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8088), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8266), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [377051] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8089), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7149), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7153), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [377102] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8090), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [377153] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(9812), 1,
      anon_sym_PIPE,
    STATE(8091), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16866), 1,
      sym_tag_specification,
    STATE(19551), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [377250] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(10245), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10247), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(8092), 1,
      sym_attribute,
    STATE(8886), 1,
      sym__simple_module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(10239), 24,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [377311] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8093), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9146), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9144), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [377362] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8094), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9600), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9598), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [377413] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10249), 1,
      anon_sym_PIPE,
    STATE(8095), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(17170), 1,
      sym_tag_specification,
    STATE(19710), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [377510] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10212), 1,
      anon_sym_PIPE,
    STATE(8096), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(13895), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16578), 1,
      sym_tag_specification,
    STATE(20378), 1,
      sym__tag_spec,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [377607] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10251), 1,
      anon_sym_PIPE,
    STATE(8097), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14645), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [377704] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10253), 1,
      anon_sym_RBRACK,
    STATE(8098), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16009), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [377801] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10255), 1,
      anon_sym_PIPE,
    STATE(8099), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14967), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [377898] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8100), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9176), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9174), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [377949] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10257), 1,
      anon_sym_PIPE,
    STATE(8101), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14733), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [378046] = 28,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10259), 1,
      anon_sym_PIPE,
    STATE(8102), 1,
      sym_attribute,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14853), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [378143] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10263), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10261), 34,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [378194] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8104), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [378244] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8105), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15368), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [378338] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10277), 1,
      sym_pow_operator,
    ACTIONS(10279), 1,
      sym_mult_operator,
    ACTIONS(10281), 1,
      sym_concat_operator,
    ACTIONS(10283), 1,
      sym_rel_operator,
    ACTIONS(10285), 1,
      sym_and_operator,
    ACTIONS(10287), 1,
      sym_or_operator,
    STATE(1907), 1,
      sym_add_operator,
    STATE(8106), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10269), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [378406] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8107), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16225), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [378500] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8108), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14545), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [378594] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(8109), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 15,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_as,
      anon_sym_POUND,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8314), 20,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [378644] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9968), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9966), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [378694] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8111), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15272), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [378788] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10277), 1,
      sym_pow_operator,
    ACTIONS(10279), 1,
      sym_mult_operator,
    STATE(1907), 1,
      sym_add_operator,
    STATE(8112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [378844] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8113), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(15825), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [378938] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8114), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14763), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [379032] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8115), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(15962), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [379126] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10100), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10098), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [379176] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8117), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(3053), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(3051), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [379226] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8118), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(15964), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [379320] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8119), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(15860), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [379414] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10293), 1,
      anon_sym_else,
    STATE(8120), 1,
      sym_attribute,
    STATE(8237), 1,
      sym_else_clause,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [379468] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10299), 1,
      anon_sym_else,
    STATE(8121), 1,
      sym_attribute,
    STATE(8123), 1,
      sym_else_clause,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [379522] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(8122), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8961), 16,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
      aux_sym_attribute_id_token1,
    ACTIONS(8959), 19,
      anon_sym_let,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [379572] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10104), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10102), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [379622] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10277), 1,
      sym_pow_operator,
    ACTIONS(10279), 1,
      sym_mult_operator,
    ACTIONS(10281), 1,
      sym_concat_operator,
    ACTIONS(10283), 1,
      sym_rel_operator,
    ACTIONS(10285), 1,
      sym_and_operator,
    STATE(1907), 1,
      sym_add_operator,
    STATE(8124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10269), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [379688] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(8125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8304), 15,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_as,
      anon_sym_POUND,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8306), 20,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [379738] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10108), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10106), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [379788] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8127), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10094), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10092), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [379838] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8128), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(15988), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [379932] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10277), 1,
      sym_pow_operator,
    ACTIONS(10279), 1,
      sym_mult_operator,
    ACTIONS(10281), 1,
      sym_concat_operator,
    ACTIONS(10283), 1,
      sym_rel_operator,
    ACTIONS(10285), 1,
      sym_and_operator,
    ACTIONS(10287), 1,
      sym_or_operator,
    ACTIONS(10305), 1,
      anon_sym_COMMA,
    ACTIONS(10307), 1,
      sym_assign_operator,
    STATE(1907), 1,
      sym_add_operator,
    STATE(8129), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10303), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10301), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [380004] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10313), 1,
      anon_sym_PIPE,
    STATE(8130), 1,
      sym_attribute,
    STATE(8138), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [380058] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8131), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9968), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9966), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [380108] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10299), 1,
      anon_sym_else,
    STATE(8132), 1,
      sym_attribute,
    STATE(8237), 1,
      sym_else_clause,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [380162] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(1907), 1,
      sym_add_operator,
    STATE(8133), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [380214] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10052), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10050), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [380264] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(8135), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 15,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_as,
      anon_sym_POUND,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8296), 19,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [380316] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10277), 1,
      sym_pow_operator,
    ACTIONS(10279), 1,
      sym_mult_operator,
    ACTIONS(10281), 1,
      sym_concat_operator,
    STATE(1907), 1,
      sym_add_operator,
    STATE(8136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 8,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [380378] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10313), 1,
      anon_sym_PIPE,
    STATE(8137), 1,
      sym_attribute,
    STATE(8138), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [380432] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10327), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8138), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [380484] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8139), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14745), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [380578] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10192), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10190), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [380628] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8141), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16115), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [380722] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8142), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16410), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [380816] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10052), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10050), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [380866] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10114), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10112), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [380916] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10277), 1,
      sym_pow_operator,
    ACTIONS(10279), 1,
      sym_mult_operator,
    ACTIONS(10281), 1,
      sym_concat_operator,
    ACTIONS(10283), 1,
      sym_rel_operator,
    ACTIONS(10285), 1,
      sym_and_operator,
    ACTIONS(10287), 1,
      sym_or_operator,
    ACTIONS(10305), 1,
      anon_sym_COMMA,
    ACTIONS(10307), 1,
      sym_assign_operator,
    STATE(1907), 1,
      sym_add_operator,
    STATE(8145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10332), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10330), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [380988] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8146), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10118), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10116), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [381038] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8147), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14460), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [381132] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(10245), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10247), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(8148), 1,
      sym_attribute,
    STATE(8886), 1,
      sym__simple_module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10336), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(10334), 24,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [381192] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8149), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14657), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [381286] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8150), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16238), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [381380] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8151), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16009), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [381474] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8152), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14976), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [381568] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8153), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16396), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [381662] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8154), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(15740), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [381756] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10277), 1,
      sym_pow_operator,
    ACTIONS(10279), 1,
      sym_mult_operator,
    ACTIONS(10281), 1,
      sym_concat_operator,
    ACTIONS(10283), 1,
      sym_rel_operator,
    ACTIONS(10285), 1,
      sym_and_operator,
    ACTIONS(10287), 1,
      sym_or_operator,
    ACTIONS(10305), 1,
      anon_sym_COMMA,
    ACTIONS(10307), 1,
      sym_assign_operator,
    STATE(1907), 1,
      sym_add_operator,
    STATE(8155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10340), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10338), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [381828] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(8156), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 15,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_as,
      anon_sym_POUND,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8296), 19,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [381880] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8157), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10202), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10200), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [381930] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8158), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(15824), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [382024] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10346), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10348), 1,
      sym_pow_operator,
    ACTIONS(10350), 1,
      sym_mult_operator,
    ACTIONS(10352), 1,
      sym_concat_operator,
    ACTIONS(10354), 1,
      sym_rel_operator,
    ACTIONS(10356), 1,
      sym_and_operator,
    ACTIONS(10358), 1,
      sym_or_operator,
    STATE(2158), 1,
      sym_add_operator,
    STATE(8159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10344), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10342), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [382092] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8160), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16472), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [382186] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(8161), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 15,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_as,
      anon_sym_POUND,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8328), 20,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [382236] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10060), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10058), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [382286] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10325), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [382336] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10277), 1,
      sym_pow_operator,
    ACTIONS(10279), 1,
      sym_mult_operator,
    ACTIONS(10281), 1,
      sym_concat_operator,
    STATE(1907), 1,
      sym_add_operator,
    STATE(8164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 8,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [382398] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10364), 1,
      anon_sym_RPAREN,
    STATE(8165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10362), 15,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(10360), 19,
      anon_sym_let,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [382450] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8166), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14592), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [382544] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10366), 1,
      anon_sym_PIPE,
    STATE(8167), 1,
      sym_attribute,
    STATE(8172), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [382598] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8168), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16293), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [382692] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8169), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14519), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [382786] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10370), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10368), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [382836] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10366), 1,
      anon_sym_PIPE,
    STATE(8171), 1,
      sym_attribute,
    STATE(8172), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [382890] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10372), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8172), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [382942] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8173), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15612), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [383036] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8174), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16111), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [383130] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8175), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15052), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [383224] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10377), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10375), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [383274] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8177), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9120), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9118), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [383324] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10313), 1,
      anon_sym_PIPE,
    STATE(8130), 1,
      aux_sym__match_cases_repeat1,
    STATE(8178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [383378] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8179), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15680), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [383472] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10277), 1,
      sym_pow_operator,
    STATE(1907), 1,
      sym_add_operator,
    STATE(8180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [383526] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8181), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16208), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [383620] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8182), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14557), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [383714] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8183), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14849), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [383808] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8184), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10128), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10126), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [383858] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10186), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10184), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [383908] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10313), 1,
      anon_sym_PIPE,
    STATE(8137), 1,
      aux_sym__match_cases_repeat1,
    STATE(8186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [383962] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10346), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10348), 1,
      sym_pow_operator,
    ACTIONS(10350), 1,
      sym_mult_operator,
    ACTIONS(10352), 1,
      sym_concat_operator,
    ACTIONS(10354), 1,
      sym_rel_operator,
    ACTIONS(10356), 1,
      sym_and_operator,
    ACTIONS(10358), 1,
      sym_or_operator,
    ACTIONS(10383), 1,
      anon_sym_COMMA,
    ACTIONS(10385), 1,
      sym_assign_operator,
    STATE(2158), 1,
      sym_add_operator,
    STATE(8187), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10332), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10330), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [384034] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10156), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10154), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [384084] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8189), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15170), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [384178] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10389), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10387), 33,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [384228] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8191), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14911), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [384322] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8192), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14588), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [384416] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8193), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16399), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [384510] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8194), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10393), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10391), 33,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [384560] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10277), 1,
      sym_pow_operator,
    ACTIONS(10279), 1,
      sym_mult_operator,
    ACTIONS(10281), 1,
      sym_concat_operator,
    ACTIONS(10283), 1,
      sym_rel_operator,
    ACTIONS(10285), 1,
      sym_and_operator,
    ACTIONS(10287), 1,
      sym_or_operator,
    ACTIONS(10305), 1,
      anon_sym_COMMA,
    ACTIONS(10307), 1,
      sym_assign_operator,
    STATE(1907), 1,
      sym_add_operator,
    STATE(8195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10269), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [384632] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8196), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14565), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [384726] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8197), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16173), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [384820] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8198), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16118), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [384914] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(8199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 15,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_as,
      anon_sym_POUND,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8284), 20,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [384964] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10056), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10054), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [385014] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8201), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14890), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [385108] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8202), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10168), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10166), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [385158] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10060), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10058), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [385208] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8204), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16423), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [385302] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8205), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14452), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [385396] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8206), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15555), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [385490] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9126), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9124), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [385540] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8208), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16140), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [385634] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8209), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16389), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [385728] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10277), 1,
      sym_pow_operator,
    STATE(1907), 1,
      sym_add_operator,
    STATE(8210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [385782] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10080), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10078), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [385832] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8212), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10172), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10170), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [385882] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8213), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9116), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9114), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [385932] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8214), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15296), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [386026] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8215), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [386076] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8216), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10176), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10174), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [386126] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10377), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10375), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [386176] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10370), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10368), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [386226] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8219), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10090), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10088), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [386276] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8220), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10094), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10092), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [386326] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8221), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10325), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [386376] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8222), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15279), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [386470] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8223), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15641), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [386564] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8224), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(15930), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [386658] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10277), 1,
      sym_pow_operator,
    ACTIONS(10279), 1,
      sym_mult_operator,
    STATE(1907), 1,
      sym_add_operator,
    STATE(8225), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 8,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [386718] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10366), 1,
      anon_sym_PIPE,
    STATE(8167), 1,
      aux_sym__match_cases_repeat1,
    STATE(8226), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [386772] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10277), 1,
      sym_pow_operator,
    ACTIONS(10279), 1,
      sym_mult_operator,
    ACTIONS(10281), 1,
      sym_concat_operator,
    ACTIONS(10283), 1,
      sym_rel_operator,
    ACTIONS(10285), 1,
      sym_and_operator,
    ACTIONS(10287), 1,
      sym_or_operator,
    STATE(1907), 1,
      sym_add_operator,
    STATE(8227), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10344), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10342), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [386840] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10056), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10054), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [386890] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8229), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(15703), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [386984] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(3053), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(3051), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [387034] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8231), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(15841), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [387128] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8232), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14651), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [387222] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8233), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14756), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [387316] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8234), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16246), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [387410] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8235), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(15809), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [387504] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8236), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16023), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [387598] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8237), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10162), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10160), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [387648] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10366), 1,
      anon_sym_PIPE,
    STATE(8171), 1,
      aux_sym__match_cases_repeat1,
    STATE(8238), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [387702] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10346), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10348), 1,
      sym_pow_operator,
    ACTIONS(10350), 1,
      sym_mult_operator,
    ACTIONS(10352), 1,
      sym_concat_operator,
    ACTIONS(10354), 1,
      sym_rel_operator,
    ACTIONS(10356), 1,
      sym_and_operator,
    ACTIONS(10358), 1,
      sym_or_operator,
    ACTIONS(10383), 1,
      anon_sym_COMMA,
    ACTIONS(10385), 1,
      sym_assign_operator,
    ACTIONS(10399), 1,
      anon_sym_SEMI,
    STATE(2158), 1,
      sym_add_operator,
    STATE(8239), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9116), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9114), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [387776] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8240), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14582), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [387870] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10346), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10348), 1,
      sym_pow_operator,
    ACTIONS(10350), 1,
      sym_mult_operator,
    STATE(2158), 1,
      sym_add_operator,
    STATE(8241), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 8,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [387930] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10348), 1,
      sym_pow_operator,
    STATE(2158), 1,
      sym_add_operator,
    STATE(8242), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [387984] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8243), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10090), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10088), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [388034] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8244), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10080), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10078), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [388084] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10346), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10348), 1,
      sym_pow_operator,
    ACTIONS(10350), 1,
      sym_mult_operator,
    ACTIONS(10352), 1,
      sym_concat_operator,
    ACTIONS(10354), 1,
      sym_rel_operator,
    ACTIONS(10356), 1,
      sym_and_operator,
    ACTIONS(10358), 1,
      sym_or_operator,
    ACTIONS(10383), 1,
      anon_sym_COMMA,
    ACTIONS(10385), 1,
      sym_assign_operator,
    STATE(2158), 1,
      sym_add_operator,
    STATE(8245), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10340), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10338), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [388156] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10348), 1,
      sym_pow_operator,
    STATE(2158), 1,
      sym_add_operator,
    STATE(8246), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [388210] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10346), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10348), 1,
      sym_pow_operator,
    ACTIONS(10350), 1,
      sym_mult_operator,
    ACTIONS(10352), 1,
      sym_concat_operator,
    STATE(2158), 1,
      sym_add_operator,
    STATE(8247), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 8,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [388272] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10346), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10348), 1,
      sym_pow_operator,
    ACTIONS(10350), 1,
      sym_mult_operator,
    ACTIONS(10352), 1,
      sym_concat_operator,
    STATE(2158), 1,
      sym_add_operator,
    STATE(8248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 8,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [388334] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8249), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15474), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [388428] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8250), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(15915), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [388522] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8251), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14924), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [388616] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8252), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10192), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10190), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [388666] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8253), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15440), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [388760] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10401), 1,
      anon_sym_else,
    STATE(8123), 1,
      sym_else_clause,
    STATE(8254), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [388814] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10293), 1,
      anon_sym_else,
    STATE(8123), 1,
      sym_else_clause,
    STATE(8255), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [388868] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10346), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10348), 1,
      sym_pow_operator,
    ACTIONS(10350), 1,
      sym_mult_operator,
    ACTIONS(10352), 1,
      sym_concat_operator,
    ACTIONS(10354), 1,
      sym_rel_operator,
    ACTIONS(10356), 1,
      sym_and_operator,
    STATE(2158), 1,
      sym_add_operator,
    STATE(8256), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10269), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [388934] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10100), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10098), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [388984] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10403), 1,
      anon_sym_else,
    STATE(8237), 1,
      sym_else_clause,
    STATE(8258), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [389038] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8259), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10104), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10102), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [389088] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8260), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(15795), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [389182] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2158), 1,
      sym_add_operator,
    STATE(8261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [389234] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8262), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10108), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10106), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [389284] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10114), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10112), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [389334] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10277), 1,
      sym_pow_operator,
    ACTIONS(10279), 1,
      sym_mult_operator,
    ACTIONS(10281), 1,
      sym_concat_operator,
    ACTIONS(10283), 1,
      sym_rel_operator,
    ACTIONS(10285), 1,
      sym_and_operator,
    ACTIONS(10287), 1,
      sym_or_operator,
    ACTIONS(10305), 1,
      anon_sym_COMMA,
    ACTIONS(10307), 1,
      sym_assign_operator,
    ACTIONS(10405), 1,
      anon_sym_SEMI,
    STATE(1907), 1,
      sym_add_operator,
    STATE(8264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9116), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9114), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [389408] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8265), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14530), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [389502] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8266), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10118), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10116), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [389552] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8267), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14771), 1,
      sym__tag_spec,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [389646] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8268), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15099), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [389740] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8269), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10128), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10126), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [389790] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10202), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10200), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [389840] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8271), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10186), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10184), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [389890] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10346), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10348), 1,
      sym_pow_operator,
    ACTIONS(10350), 1,
      sym_mult_operator,
    ACTIONS(10352), 1,
      sym_concat_operator,
    ACTIONS(10354), 1,
      sym_rel_operator,
    ACTIONS(10356), 1,
      sym_and_operator,
    ACTIONS(10358), 1,
      sym_or_operator,
    STATE(2158), 1,
      sym_add_operator,
    STATE(8272), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10269), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [389958] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10346), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10348), 1,
      sym_pow_operator,
    ACTIONS(10350), 1,
      sym_mult_operator,
    ACTIONS(10352), 1,
      sym_concat_operator,
    ACTIONS(10354), 1,
      sym_rel_operator,
    ACTIONS(10356), 1,
      sym_and_operator,
    ACTIONS(10358), 1,
      sym_or_operator,
    ACTIONS(10383), 1,
      anon_sym_COMMA,
    ACTIONS(10385), 1,
      sym_assign_operator,
    STATE(2158), 1,
      sym_add_operator,
    STATE(8273), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10269), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [390030] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10348), 1,
      sym_pow_operator,
    ACTIONS(10350), 1,
      sym_mult_operator,
    STATE(2158), 1,
      sym_add_operator,
    STATE(8274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [390086] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10346), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10348), 1,
      sym_pow_operator,
    ACTIONS(10350), 1,
      sym_mult_operator,
    ACTIONS(10352), 1,
      sym_concat_operator,
    ACTIONS(10354), 1,
      sym_rel_operator,
    ACTIONS(10356), 1,
      sym_and_operator,
    ACTIONS(10358), 1,
      sym_or_operator,
    ACTIONS(10383), 1,
      anon_sym_COMMA,
    ACTIONS(10385), 1,
      sym_assign_operator,
    STATE(2158), 1,
      sym_add_operator,
    STATE(8275), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10303), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10301), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [390158] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10403), 1,
      anon_sym_else,
    STATE(8123), 1,
      sym_else_clause,
    STATE(8276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [390212] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8277), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10156), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10154), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [390262] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10162), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10160), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [390312] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8279), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15491), 1,
      sym__tag_spec,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [390406] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10401), 1,
      anon_sym_else,
    STATE(8237), 1,
      sym_else_clause,
    STATE(8280), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [390460] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8281), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10168), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10166), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [390510] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10172), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10170), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [390560] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8283), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10176), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10174), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [390610] = 27,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9302), 1,
      aux_sym_tag_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8284), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14343), 1,
      sym__type,
    STATE(14987), 1,
      sym_tag,
    STATE(15688), 1,
      sym_tag_specification,
    STATE(16277), 1,
      sym__tag_spec,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [390704] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2102), 1,
      sym_add_operator,
    STATE(8285), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [390755] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10407), 1,
      anon_sym_COMMA,
    ACTIONS(10409), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10411), 1,
      sym_pow_operator,
    ACTIONS(10413), 1,
      sym_mult_operator,
    ACTIONS(10415), 1,
      sym_concat_operator,
    ACTIONS(10417), 1,
      sym_rel_operator,
    ACTIONS(10419), 1,
      sym_and_operator,
    ACTIONS(10421), 1,
      sym_or_operator,
    ACTIONS(10423), 1,
      sym_assign_operator,
    STATE(2102), 1,
      sym_add_operator,
    STATE(8286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10269), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [390826] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(8287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10427), 15,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(10425), 19,
      anon_sym_let,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [390875] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10429), 1,
      anon_sym_COMMA,
    ACTIONS(10431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10433), 1,
      sym_pow_operator,
    ACTIONS(10435), 1,
      sym_mult_operator,
    ACTIONS(10437), 1,
      sym_concat_operator,
    ACTIONS(10439), 1,
      sym_rel_operator,
    ACTIONS(10441), 1,
      sym_and_operator,
    ACTIONS(10443), 1,
      sym_or_operator,
    ACTIONS(10445), 1,
      sym_assign_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(8288), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10269), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [390946] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10433), 1,
      sym_pow_operator,
    ACTIONS(10435), 1,
      sym_mult_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(8289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391001] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10429), 1,
      anon_sym_COMMA,
    ACTIONS(10431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10433), 1,
      sym_pow_operator,
    ACTIONS(10435), 1,
      sym_mult_operator,
    ACTIONS(10437), 1,
      sym_concat_operator,
    ACTIONS(10439), 1,
      sym_rel_operator,
    ACTIONS(10441), 1,
      sym_and_operator,
    ACTIONS(10443), 1,
      sym_or_operator,
    ACTIONS(10445), 1,
      sym_assign_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(8290), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10303), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10301), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391072] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(8291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10364), 15,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(10447), 19,
      anon_sym_let,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [391121] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10449), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10451), 1,
      sym_pow_operator,
    ACTIONS(10453), 1,
      sym_mult_operator,
    ACTIONS(10455), 1,
      sym_concat_operator,
    ACTIONS(10457), 1,
      sym_rel_operator,
    ACTIONS(10459), 1,
      sym_and_operator,
    ACTIONS(10461), 1,
      sym_or_operator,
    STATE(2303), 1,
      sym_add_operator,
    STATE(8292), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10344), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10342), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391188] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10449), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10451), 1,
      sym_pow_operator,
    ACTIONS(10453), 1,
      sym_mult_operator,
    ACTIONS(10455), 1,
      sym_concat_operator,
    ACTIONS(10457), 1,
      sym_rel_operator,
    ACTIONS(10459), 1,
      sym_and_operator,
    ACTIONS(10461), 1,
      sym_or_operator,
    ACTIONS(10463), 1,
      anon_sym_COMMA,
    ACTIONS(10465), 1,
      anon_sym_SEMI,
    ACTIONS(10467), 1,
      sym_assign_operator,
    STATE(2303), 1,
      sym_add_operator,
    STATE(8293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9116), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9114), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391261] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10469), 1,
      anon_sym_else,
    STATE(8123), 1,
      sym_else_clause,
    STATE(8294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391314] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10449), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10451), 1,
      sym_pow_operator,
    ACTIONS(10453), 1,
      sym_mult_operator,
    STATE(2303), 1,
      sym_add_operator,
    STATE(8295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391373] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10433), 1,
      sym_pow_operator,
    ACTIONS(10435), 1,
      sym_mult_operator,
    ACTIONS(10437), 1,
      sym_concat_operator,
    ACTIONS(10439), 1,
      sym_rel_operator,
    ACTIONS(10441), 1,
      sym_and_operator,
    ACTIONS(10443), 1,
      sym_or_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(8296), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10269), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391440] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10471), 1,
      anon_sym_PIPE,
    STATE(8297), 1,
      sym_attribute,
    STATE(8344), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391493] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2303), 1,
      sym_add_operator,
    STATE(8298), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391544] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10407), 1,
      anon_sym_COMMA,
    ACTIONS(10409), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10411), 1,
      sym_pow_operator,
    ACTIONS(10413), 1,
      sym_mult_operator,
    ACTIONS(10415), 1,
      sym_concat_operator,
    ACTIONS(10417), 1,
      sym_rel_operator,
    ACTIONS(10419), 1,
      sym_and_operator,
    ACTIONS(10421), 1,
      sym_or_operator,
    ACTIONS(10423), 1,
      sym_assign_operator,
    ACTIONS(10473), 1,
      anon_sym_SEMI,
    STATE(2102), 1,
      sym_add_operator,
    STATE(8299), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9116), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9114), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391617] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10429), 1,
      anon_sym_COMMA,
    ACTIONS(10431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10433), 1,
      sym_pow_operator,
    ACTIONS(10435), 1,
      sym_mult_operator,
    ACTIONS(10437), 1,
      sym_concat_operator,
    ACTIONS(10439), 1,
      sym_rel_operator,
    ACTIONS(10441), 1,
      sym_and_operator,
    ACTIONS(10443), 1,
      sym_or_operator,
    ACTIONS(10445), 1,
      sym_assign_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(8300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10340), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10338), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391688] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10433), 1,
      sym_pow_operator,
    ACTIONS(10435), 1,
      sym_mult_operator,
    ACTIONS(10437), 1,
      sym_concat_operator,
    ACTIONS(10439), 1,
      sym_rel_operator,
    ACTIONS(10441), 1,
      sym_and_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(8301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10269), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391753] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10433), 1,
      sym_pow_operator,
    ACTIONS(10435), 1,
      sym_mult_operator,
    ACTIONS(10437), 1,
      sym_concat_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(8302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 8,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391814] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10475), 1,
      anon_sym_else,
    STATE(8123), 1,
      sym_else_clause,
    STATE(8303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391867] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10433), 1,
      sym_pow_operator,
    ACTIONS(10435), 1,
      sym_mult_operator,
    ACTIONS(10437), 1,
      sym_concat_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(8304), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 8,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391928] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10433), 1,
      sym_pow_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(8305), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391981] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10429), 1,
      anon_sym_COMMA,
    ACTIONS(10431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10433), 1,
      sym_pow_operator,
    ACTIONS(10435), 1,
      sym_mult_operator,
    ACTIONS(10437), 1,
      sym_concat_operator,
    ACTIONS(10439), 1,
      sym_rel_operator,
    ACTIONS(10441), 1,
      sym_and_operator,
    ACTIONS(10443), 1,
      sym_or_operator,
    ACTIONS(10445), 1,
      sym_assign_operator,
    ACTIONS(10477), 1,
      anon_sym_SEMI,
    STATE(2305), 1,
      sym_add_operator,
    STATE(8306), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9116), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9114), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392054] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10433), 1,
      sym_pow_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(8307), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392107] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10433), 1,
      sym_pow_operator,
    ACTIONS(10435), 1,
      sym_mult_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(8308), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 8,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392166] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10433), 1,
      sym_pow_operator,
    ACTIONS(10435), 1,
      sym_mult_operator,
    ACTIONS(10437), 1,
      sym_concat_operator,
    ACTIONS(10439), 1,
      sym_rel_operator,
    ACTIONS(10441), 1,
      sym_and_operator,
    ACTIONS(10443), 1,
      sym_or_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(8309), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10344), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10342), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392233] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10479), 1,
      anon_sym_PIPE,
    STATE(8310), 1,
      sym_attribute,
    STATE(8350), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392286] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10481), 1,
      anon_sym_COLON,
    STATE(8311), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8550), 13,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8548), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [392337] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10483), 1,
      anon_sym_COMMA,
    ACTIONS(10485), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10487), 1,
      sym_pow_operator,
    ACTIONS(10489), 1,
      sym_mult_operator,
    ACTIONS(10491), 1,
      sym_concat_operator,
    ACTIONS(10493), 1,
      sym_rel_operator,
    ACTIONS(10495), 1,
      sym_and_operator,
    ACTIONS(10497), 1,
      sym_or_operator,
    ACTIONS(10499), 1,
      sym_assign_operator,
    STATE(1792), 1,
      sym_add_operator,
    STATE(8312), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10340), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10338), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392408] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10451), 1,
      sym_pow_operator,
    STATE(2303), 1,
      sym_add_operator,
    STATE(8313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392461] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10501), 1,
      anon_sym_else,
    STATE(8237), 1,
      sym_else_clause,
    STATE(8314), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392514] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10483), 1,
      anon_sym_COMMA,
    ACTIONS(10485), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10487), 1,
      sym_pow_operator,
    ACTIONS(10489), 1,
      sym_mult_operator,
    ACTIONS(10491), 1,
      sym_concat_operator,
    ACTIONS(10493), 1,
      sym_rel_operator,
    ACTIONS(10495), 1,
      sym_and_operator,
    ACTIONS(10497), 1,
      sym_or_operator,
    ACTIONS(10499), 1,
      sym_assign_operator,
    STATE(1792), 1,
      sym_add_operator,
    STATE(8315), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10303), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10301), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392585] = 26,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5279), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9786), 1,
      anon_sym_RPAREN,
    ACTIONS(10503), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8316), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14266), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [392676] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10487), 1,
      sym_pow_operator,
    ACTIONS(10489), 1,
      sym_mult_operator,
    STATE(1792), 1,
      sym_add_operator,
    STATE(8317), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392731] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10483), 1,
      anon_sym_COMMA,
    ACTIONS(10485), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10487), 1,
      sym_pow_operator,
    ACTIONS(10489), 1,
      sym_mult_operator,
    ACTIONS(10491), 1,
      sym_concat_operator,
    ACTIONS(10493), 1,
      sym_rel_operator,
    ACTIONS(10495), 1,
      sym_and_operator,
    ACTIONS(10497), 1,
      sym_or_operator,
    ACTIONS(10499), 1,
      sym_assign_operator,
    STATE(1792), 1,
      sym_add_operator,
    STATE(8318), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10269), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392802] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10451), 1,
      sym_pow_operator,
    STATE(2303), 1,
      sym_add_operator,
    STATE(8319), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392855] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10505), 1,
      anon_sym_PIPE,
    STATE(8320), 1,
      sym_attribute,
    STATE(8334), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392908] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10485), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10487), 1,
      sym_pow_operator,
    ACTIONS(10489), 1,
      sym_mult_operator,
    ACTIONS(10491), 1,
      sym_concat_operator,
    ACTIONS(10493), 1,
      sym_rel_operator,
    ACTIONS(10495), 1,
      sym_and_operator,
    ACTIONS(10497), 1,
      sym_or_operator,
    STATE(1792), 1,
      sym_add_operator,
    STATE(8321), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10269), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392975] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10485), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10487), 1,
      sym_pow_operator,
    ACTIONS(10489), 1,
      sym_mult_operator,
    ACTIONS(10491), 1,
      sym_concat_operator,
    ACTIONS(10493), 1,
      sym_rel_operator,
    ACTIONS(10495), 1,
      sym_and_operator,
    STATE(1792), 1,
      sym_add_operator,
    STATE(8322), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10269), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393040] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10505), 1,
      anon_sym_PIPE,
    STATE(8323), 1,
      sym_attribute,
    STATE(8334), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393093] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10485), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10487), 1,
      sym_pow_operator,
    ACTIONS(10489), 1,
      sym_mult_operator,
    ACTIONS(10491), 1,
      sym_concat_operator,
    STATE(1792), 1,
      sym_add_operator,
    STATE(8324), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393154] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10507), 1,
      anon_sym_else,
    STATE(8123), 1,
      sym_else_clause,
    STATE(8325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393207] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10485), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10487), 1,
      sym_pow_operator,
    ACTIONS(10489), 1,
      sym_mult_operator,
    ACTIONS(10491), 1,
      sym_concat_operator,
    STATE(1792), 1,
      sym_add_operator,
    STATE(8326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393268] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10487), 1,
      sym_pow_operator,
    STATE(1792), 1,
      sym_add_operator,
    STATE(8327), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393321] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10487), 1,
      sym_pow_operator,
    STATE(1792), 1,
      sym_add_operator,
    STATE(8328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393374] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10485), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10487), 1,
      sym_pow_operator,
    ACTIONS(10489), 1,
      sym_mult_operator,
    STATE(1792), 1,
      sym_add_operator,
    STATE(8329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393433] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10485), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10487), 1,
      sym_pow_operator,
    ACTIONS(10489), 1,
      sym_mult_operator,
    ACTIONS(10491), 1,
      sym_concat_operator,
    ACTIONS(10493), 1,
      sym_rel_operator,
    ACTIONS(10495), 1,
      sym_and_operator,
    ACTIONS(10497), 1,
      sym_or_operator,
    STATE(1792), 1,
      sym_add_operator,
    STATE(8330), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10344), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10342), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393500] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10483), 1,
      anon_sym_COMMA,
    ACTIONS(10485), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10487), 1,
      sym_pow_operator,
    ACTIONS(10489), 1,
      sym_mult_operator,
    ACTIONS(10491), 1,
      sym_concat_operator,
    ACTIONS(10493), 1,
      sym_rel_operator,
    ACTIONS(10495), 1,
      sym_and_operator,
    ACTIONS(10497), 1,
      sym_or_operator,
    ACTIONS(10499), 1,
      sym_assign_operator,
    STATE(1792), 1,
      sym_add_operator,
    STATE(8331), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10332), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10330), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393571] = 26,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5279), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9814), 1,
      anon_sym_RPAREN,
    ACTIONS(10509), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8332), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14342), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [393662] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10483), 1,
      anon_sym_COMMA,
    ACTIONS(10485), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10487), 1,
      sym_pow_operator,
    ACTIONS(10489), 1,
      sym_mult_operator,
    ACTIONS(10491), 1,
      sym_concat_operator,
    ACTIONS(10493), 1,
      sym_rel_operator,
    ACTIONS(10495), 1,
      sym_and_operator,
    ACTIONS(10497), 1,
      sym_or_operator,
    ACTIONS(10499), 1,
      sym_assign_operator,
    ACTIONS(10511), 1,
      anon_sym_SEMI,
    STATE(1792), 1,
      sym_add_operator,
    STATE(8333), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9116), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9114), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393735] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10513), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8334), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393786] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10449), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10451), 1,
      sym_pow_operator,
    ACTIONS(10453), 1,
      sym_mult_operator,
    ACTIONS(10455), 1,
      sym_concat_operator,
    STATE(2303), 1,
      sym_add_operator,
    STATE(8335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393847] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10449), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10451), 1,
      sym_pow_operator,
    ACTIONS(10453), 1,
      sym_mult_operator,
    ACTIONS(10455), 1,
      sym_concat_operator,
    STATE(2303), 1,
      sym_add_operator,
    STATE(8336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393908] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(1792), 1,
      sym_add_operator,
    STATE(8337), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393959] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10449), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10451), 1,
      sym_pow_operator,
    ACTIONS(10453), 1,
      sym_mult_operator,
    ACTIONS(10455), 1,
      sym_concat_operator,
    ACTIONS(10457), 1,
      sym_rel_operator,
    ACTIONS(10459), 1,
      sym_and_operator,
    STATE(2303), 1,
      sym_add_operator,
    STATE(8338), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10269), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394024] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10501), 1,
      anon_sym_else,
    STATE(8123), 1,
      sym_else_clause,
    STATE(8339), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394077] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10449), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10451), 1,
      sym_pow_operator,
    ACTIONS(10453), 1,
      sym_mult_operator,
    ACTIONS(10455), 1,
      sym_concat_operator,
    ACTIONS(10457), 1,
      sym_rel_operator,
    ACTIONS(10459), 1,
      sym_and_operator,
    ACTIONS(10461), 1,
      sym_or_operator,
    STATE(2303), 1,
      sym_add_operator,
    STATE(8340), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10269), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394144] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10471), 1,
      anon_sym_PIPE,
    STATE(8341), 1,
      sym_attribute,
    STATE(8359), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394197] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10507), 1,
      anon_sym_else,
    STATE(8237), 1,
      sym_else_clause,
    STATE(8342), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394250] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10516), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8343), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394301] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10471), 1,
      anon_sym_PIPE,
    STATE(8343), 1,
      aux_sym__match_cases_repeat1,
    STATE(8344), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394354] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10519), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8345), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394405] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10449), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10451), 1,
      sym_pow_operator,
    ACTIONS(10453), 1,
      sym_mult_operator,
    ACTIONS(10455), 1,
      sym_concat_operator,
    ACTIONS(10457), 1,
      sym_rel_operator,
    ACTIONS(10459), 1,
      sym_and_operator,
    ACTIONS(10461), 1,
      sym_or_operator,
    ACTIONS(10463), 1,
      anon_sym_COMMA,
    ACTIONS(10467), 1,
      sym_assign_operator,
    STATE(2303), 1,
      sym_add_operator,
    STATE(8346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10269), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394476] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10479), 1,
      anon_sym_PIPE,
    STATE(8345), 1,
      aux_sym__match_cases_repeat1,
    STATE(8347), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394529] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(8348), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10362), 15,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(10360), 19,
      anon_sym_let,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [394578] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10449), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10451), 1,
      sym_pow_operator,
    ACTIONS(10453), 1,
      sym_mult_operator,
    ACTIONS(10455), 1,
      sym_concat_operator,
    ACTIONS(10457), 1,
      sym_rel_operator,
    ACTIONS(10459), 1,
      sym_and_operator,
    ACTIONS(10461), 1,
      sym_or_operator,
    ACTIONS(10463), 1,
      anon_sym_COMMA,
    ACTIONS(10467), 1,
      sym_assign_operator,
    STATE(2303), 1,
      sym_add_operator,
    STATE(8349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10332), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10330), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394649] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10479), 1,
      anon_sym_PIPE,
    STATE(8345), 1,
      aux_sym__match_cases_repeat1,
    STATE(8350), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394702] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10411), 1,
      sym_pow_operator,
    STATE(2102), 1,
      sym_add_operator,
    STATE(8351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394755] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10522), 1,
      anon_sym_PIPE,
    STATE(8352), 1,
      sym_attribute,
    STATE(8353), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394808] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10522), 1,
      anon_sym_PIPE,
    STATE(8353), 1,
      sym_attribute,
    STATE(8357), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394861] = 26,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5279), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9838), 1,
      anon_sym_RPAREN,
    ACTIONS(10524), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8354), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14191), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [394952] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10522), 1,
      anon_sym_PIPE,
    STATE(8355), 1,
      sym_attribute,
    STATE(8357), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395005] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10407), 1,
      anon_sym_COMMA,
    ACTIONS(10409), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10411), 1,
      sym_pow_operator,
    ACTIONS(10413), 1,
      sym_mult_operator,
    ACTIONS(10415), 1,
      sym_concat_operator,
    ACTIONS(10417), 1,
      sym_rel_operator,
    ACTIONS(10419), 1,
      sym_and_operator,
    ACTIONS(10421), 1,
      sym_or_operator,
    ACTIONS(10423), 1,
      sym_assign_operator,
    STATE(2102), 1,
      sym_add_operator,
    STATE(8356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10340), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10338), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395076] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10526), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8357), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395127] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10451), 1,
      sym_pow_operator,
    ACTIONS(10453), 1,
      sym_mult_operator,
    STATE(2303), 1,
      sym_add_operator,
    STATE(8358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395182] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10471), 1,
      anon_sym_PIPE,
    STATE(8343), 1,
      aux_sym__match_cases_repeat1,
    STATE(8359), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395235] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10407), 1,
      anon_sym_COMMA,
    ACTIONS(10409), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10411), 1,
      sym_pow_operator,
    ACTIONS(10413), 1,
      sym_mult_operator,
    ACTIONS(10415), 1,
      sym_concat_operator,
    ACTIONS(10417), 1,
      sym_rel_operator,
    ACTIONS(10419), 1,
      sym_and_operator,
    ACTIONS(10421), 1,
      sym_or_operator,
    ACTIONS(10423), 1,
      sym_assign_operator,
    STATE(2102), 1,
      sym_add_operator,
    STATE(8360), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10303), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10301), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395306] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10411), 1,
      sym_pow_operator,
    ACTIONS(10413), 1,
      sym_mult_operator,
    STATE(2102), 1,
      sym_add_operator,
    STATE(8361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395361] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10475), 1,
      anon_sym_else,
    STATE(8237), 1,
      sym_else_clause,
    STATE(8362), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395414] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10479), 1,
      anon_sym_PIPE,
    STATE(8347), 1,
      aux_sym__match_cases_repeat1,
    STATE(8363), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395467] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10409), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10411), 1,
      sym_pow_operator,
    ACTIONS(10413), 1,
      sym_mult_operator,
    ACTIONS(10415), 1,
      sym_concat_operator,
    ACTIONS(10417), 1,
      sym_rel_operator,
    ACTIONS(10419), 1,
      sym_and_operator,
    ACTIONS(10421), 1,
      sym_or_operator,
    STATE(2102), 1,
      sym_add_operator,
    STATE(8364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10269), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395534] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10449), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10451), 1,
      sym_pow_operator,
    ACTIONS(10453), 1,
      sym_mult_operator,
    ACTIONS(10455), 1,
      sym_concat_operator,
    ACTIONS(10457), 1,
      sym_rel_operator,
    ACTIONS(10459), 1,
      sym_and_operator,
    ACTIONS(10461), 1,
      sym_or_operator,
    ACTIONS(10463), 1,
      anon_sym_COMMA,
    ACTIONS(10467), 1,
      sym_assign_operator,
    STATE(2303), 1,
      sym_add_operator,
    STATE(8365), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10340), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10338), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395605] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10409), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10411), 1,
      sym_pow_operator,
    ACTIONS(10413), 1,
      sym_mult_operator,
    ACTIONS(10415), 1,
      sym_concat_operator,
    ACTIONS(10417), 1,
      sym_rel_operator,
    ACTIONS(10419), 1,
      sym_and_operator,
    STATE(2102), 1,
      sym_add_operator,
    STATE(8366), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10269), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395670] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10522), 1,
      anon_sym_PIPE,
    STATE(8355), 1,
      aux_sym__match_cases_repeat1,
    STATE(8367), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395723] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10449), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10451), 1,
      sym_pow_operator,
    ACTIONS(10453), 1,
      sym_mult_operator,
    ACTIONS(10455), 1,
      sym_concat_operator,
    ACTIONS(10457), 1,
      sym_rel_operator,
    ACTIONS(10459), 1,
      sym_and_operator,
    ACTIONS(10461), 1,
      sym_or_operator,
    ACTIONS(10463), 1,
      anon_sym_COMMA,
    ACTIONS(10467), 1,
      sym_assign_operator,
    STATE(2303), 1,
      sym_add_operator,
    STATE(8368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10303), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10301), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395794] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10505), 1,
      anon_sym_PIPE,
    STATE(8323), 1,
      aux_sym__match_cases_repeat1,
    STATE(8369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395847] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10409), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10411), 1,
      sym_pow_operator,
    ACTIONS(10413), 1,
      sym_mult_operator,
    ACTIONS(10415), 1,
      sym_concat_operator,
    STATE(2102), 1,
      sym_add_operator,
    STATE(8370), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 8,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395908] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10409), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10411), 1,
      sym_pow_operator,
    ACTIONS(10413), 1,
      sym_mult_operator,
    ACTIONS(10415), 1,
      sym_concat_operator,
    STATE(2102), 1,
      sym_add_operator,
    STATE(8371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 8,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395969] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10411), 1,
      sym_pow_operator,
    STATE(2102), 1,
      sym_add_operator,
    STATE(8372), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [396022] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10409), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10411), 1,
      sym_pow_operator,
    ACTIONS(10413), 1,
      sym_mult_operator,
    STATE(2102), 1,
      sym_add_operator,
    STATE(8373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 8,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [396081] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10505), 1,
      anon_sym_PIPE,
    STATE(8320), 1,
      aux_sym__match_cases_repeat1,
    STATE(8374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [396134] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10409), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10411), 1,
      sym_pow_operator,
    ACTIONS(10413), 1,
      sym_mult_operator,
    ACTIONS(10415), 1,
      sym_concat_operator,
    ACTIONS(10417), 1,
      sym_rel_operator,
    ACTIONS(10419), 1,
      sym_and_operator,
    ACTIONS(10421), 1,
      sym_or_operator,
    STATE(2102), 1,
      sym_add_operator,
    STATE(8375), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10344), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10342), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [396201] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10469), 1,
      anon_sym_else,
    STATE(8237), 1,
      sym_else_clause,
    STATE(8376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [396254] = 26,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5279), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9854), 1,
      anon_sym_RPAREN,
    ACTIONS(10529), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8377), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14350), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [396345] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2305), 1,
      sym_add_operator,
    STATE(8378), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [396396] = 23,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(409), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(471), 1,
      aux_sym_directive_token1,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(10531), 1,
      anon_sym_let,
    ACTIONS(10533), 1,
      anon_sym_type,
    ACTIONS(10535), 1,
      anon_sym_exception,
    ACTIONS(10537), 1,
      anon_sym_module,
    ACTIONS(10539), 1,
      anon_sym_include,
    ACTIONS(10541), 1,
      anon_sym_class,
    ACTIONS(10543), 1,
      sym_let_operator,
    STATE(100), 1,
      aux_sym__structure_repeat1,
    STATE(7860), 1,
      sym_directive,
    STATE(8379), 1,
      sym_attribute,
    STATE(8438), 1,
      aux_sym__structure_repeat2,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12362), 2,
      sym_toplevel_directive,
      sym__structure_item,
    STATE(12427), 13,
      sym_value_definition,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_include_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [396480] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10545), 1,
      anon_sym_PIPE,
    STATE(8380), 1,
      sym_attribute,
    STATE(8413), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [396532] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(1948), 1,
      sym_add_operator,
    STATE(8381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [396582] = 23,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(35), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(119), 1,
      aux_sym_directive_token1,
    ACTIONS(749), 1,
      anon_sym_RBRACK,
    ACTIONS(10539), 1,
      anon_sym_include,
    ACTIONS(10547), 1,
      anon_sym_let,
    ACTIONS(10549), 1,
      anon_sym_type,
    ACTIONS(10551), 1,
      anon_sym_exception,
    ACTIONS(10553), 1,
      anon_sym_module,
    ACTIONS(10555), 1,
      anon_sym_class,
    ACTIONS(10557), 1,
      sym_let_operator,
    STATE(97), 1,
      aux_sym__structure_repeat1,
    STATE(7923), 1,
      sym_directive,
    STATE(8382), 1,
      sym_attribute,
    STATE(8409), 1,
      aux_sym__structure_repeat2,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12362), 2,
      sym_toplevel_directive,
      sym__structure_item,
    STATE(12427), 13,
      sym_value_definition,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_include_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [396666] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10407), 1,
      anon_sym_COMMA,
    ACTIONS(10409), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10411), 1,
      sym_pow_operator,
    ACTIONS(10413), 1,
      sym_mult_operator,
    ACTIONS(10415), 1,
      sym_concat_operator,
    ACTIONS(10417), 1,
      sym_rel_operator,
    ACTIONS(10419), 1,
      sym_and_operator,
    ACTIONS(10421), 1,
      sym_or_operator,
    ACTIONS(10423), 1,
      sym_assign_operator,
    ACTIONS(10559), 1,
      anon_sym_SEMI,
    STATE(2102), 1,
      sym_add_operator,
    STATE(8383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9116), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9114), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [396738] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9594), 13,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9592), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [396786] = 22,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10561), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(10564), 1,
      anon_sym_let,
    ACTIONS(10567), 1,
      anon_sym_external,
    ACTIONS(10570), 1,
      anon_sym_type,
    ACTIONS(10573), 1,
      anon_sym_RBRACK,
    ACTIONS(10575), 1,
      anon_sym_exception,
    ACTIONS(10578), 1,
      anon_sym_module,
    ACTIONS(10581), 1,
      anon_sym_open,
    ACTIONS(10584), 1,
      anon_sym_include,
    ACTIONS(10587), 1,
      anon_sym_class,
    ACTIONS(10590), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(10593), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(10596), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(10599), 1,
      sym_let_operator,
    ACTIONS(10602), 1,
      aux_sym_directive_token1,
    STATE(107), 1,
      aux_sym__structure_repeat1,
    STATE(7923), 1,
      sym_directive,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8385), 2,
      sym_attribute,
      aux_sym__structure_repeat2,
    STATE(12362), 2,
      sym_toplevel_directive,
      sym__structure_item,
    STATE(12427), 13,
      sym_value_definition,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_include_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [396868] = 23,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(35), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(119), 1,
      aux_sym_directive_token1,
    ACTIONS(747), 1,
      anon_sym_RBRACK,
    ACTIONS(10539), 1,
      anon_sym_include,
    ACTIONS(10547), 1,
      anon_sym_let,
    ACTIONS(10549), 1,
      anon_sym_type,
    ACTIONS(10551), 1,
      anon_sym_exception,
    ACTIONS(10553), 1,
      anon_sym_module,
    ACTIONS(10555), 1,
      anon_sym_class,
    ACTIONS(10557), 1,
      sym_let_operator,
    STATE(104), 1,
      aux_sym__structure_repeat1,
    STATE(7923), 1,
      sym_directive,
    STATE(8386), 1,
      sym_attribute,
    STATE(8421), 1,
      aux_sym__structure_repeat2,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12362), 2,
      sym_toplevel_directive,
      sym__structure_item,
    STATE(12427), 13,
      sym_value_definition,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_include_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [396952] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10605), 1,
      anon_sym_COMMA,
    ACTIONS(10607), 1,
      anon_sym_SEMI,
    ACTIONS(10609), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10611), 1,
      sym_pow_operator,
    ACTIONS(10613), 1,
      sym_mult_operator,
    ACTIONS(10615), 1,
      sym_concat_operator,
    ACTIONS(10617), 1,
      sym_rel_operator,
    ACTIONS(10619), 1,
      sym_and_operator,
    ACTIONS(10621), 1,
      sym_or_operator,
    ACTIONS(10623), 1,
      sym_assign_operator,
    STATE(1948), 1,
      sym_add_operator,
    STATE(8387), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9116), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9114), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [397024] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10625), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8388), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [397074] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10628), 1,
      anon_sym_COMMA,
    ACTIONS(10630), 1,
      anon_sym_SEMI,
    ACTIONS(10632), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10634), 1,
      sym_pow_operator,
    ACTIONS(10636), 1,
      sym_mult_operator,
    ACTIONS(10638), 1,
      sym_concat_operator,
    ACTIONS(10640), 1,
      sym_rel_operator,
    ACTIONS(10642), 1,
      sym_and_operator,
    ACTIONS(10644), 1,
      sym_or_operator,
    ACTIONS(10646), 1,
      sym_assign_operator,
    STATE(1881), 1,
      sym_add_operator,
    STATE(8389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9116), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9114), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [397146] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9588), 13,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9586), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [397194] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10648), 1,
      anon_sym_PIPE,
    STATE(8391), 1,
      sym_attribute,
    STATE(8424), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [397246] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10605), 1,
      anon_sym_COMMA,
    ACTIONS(10609), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10611), 1,
      sym_pow_operator,
    ACTIONS(10613), 1,
      sym_mult_operator,
    ACTIONS(10615), 1,
      sym_concat_operator,
    ACTIONS(10617), 1,
      sym_rel_operator,
    ACTIONS(10619), 1,
      sym_and_operator,
    ACTIONS(10621), 1,
      sym_or_operator,
    ACTIONS(10623), 1,
      sym_assign_operator,
    STATE(1948), 1,
      sym_add_operator,
    STATE(8392), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10340), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10338), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [397316] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10648), 1,
      anon_sym_PIPE,
    STATE(8393), 1,
      sym_attribute,
    STATE(8422), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [397368] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10605), 1,
      anon_sym_COMMA,
    ACTIONS(10609), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10611), 1,
      sym_pow_operator,
    ACTIONS(10613), 1,
      sym_mult_operator,
    ACTIONS(10615), 1,
      sym_concat_operator,
    ACTIONS(10617), 1,
      sym_rel_operator,
    ACTIONS(10619), 1,
      sym_and_operator,
    ACTIONS(10621), 1,
      sym_or_operator,
    ACTIONS(10623), 1,
      sym_assign_operator,
    STATE(1948), 1,
      sym_add_operator,
    STATE(8394), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10303), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10301), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [397438] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10611), 1,
      sym_pow_operator,
    ACTIONS(10613), 1,
      sym_mult_operator,
    STATE(1948), 1,
      sym_add_operator,
    STATE(8395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [397492] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10605), 1,
      anon_sym_COMMA,
    ACTIONS(10609), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10611), 1,
      sym_pow_operator,
    ACTIONS(10613), 1,
      sym_mult_operator,
    ACTIONS(10615), 1,
      sym_concat_operator,
    ACTIONS(10617), 1,
      sym_rel_operator,
    ACTIONS(10619), 1,
      sym_and_operator,
    ACTIONS(10621), 1,
      sym_or_operator,
    ACTIONS(10623), 1,
      sym_assign_operator,
    STATE(1948), 1,
      sym_add_operator,
    STATE(8396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10269), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [397562] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10609), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10611), 1,
      sym_pow_operator,
    ACTIONS(10613), 1,
      sym_mult_operator,
    ACTIONS(10615), 1,
      sym_concat_operator,
    ACTIONS(10617), 1,
      sym_rel_operator,
    ACTIONS(10619), 1,
      sym_and_operator,
    ACTIONS(10621), 1,
      sym_or_operator,
    STATE(1948), 1,
      sym_add_operator,
    STATE(8397), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10269), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [397628] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10609), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10611), 1,
      sym_pow_operator,
    ACTIONS(10613), 1,
      sym_mult_operator,
    ACTIONS(10615), 1,
      sym_concat_operator,
    ACTIONS(10617), 1,
      sym_rel_operator,
    ACTIONS(10619), 1,
      sym_and_operator,
    STATE(1948), 1,
      sym_add_operator,
    STATE(8398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10269), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [397692] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10609), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10611), 1,
      sym_pow_operator,
    ACTIONS(10613), 1,
      sym_mult_operator,
    ACTIONS(10615), 1,
      sym_concat_operator,
    STATE(1948), 1,
      sym_add_operator,
    STATE(8399), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [397752] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10609), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10611), 1,
      sym_pow_operator,
    ACTIONS(10613), 1,
      sym_mult_operator,
    ACTIONS(10615), 1,
      sym_concat_operator,
    STATE(1948), 1,
      sym_add_operator,
    STATE(8400), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [397812] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10611), 1,
      sym_pow_operator,
    STATE(1948), 1,
      sym_add_operator,
    STATE(8401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [397864] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10611), 1,
      sym_pow_operator,
    STATE(1948), 1,
      sym_add_operator,
    STATE(8402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [397916] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10609), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10611), 1,
      sym_pow_operator,
    ACTIONS(10613), 1,
      sym_mult_operator,
    STATE(1948), 1,
      sym_add_operator,
    STATE(8403), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [397974] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10609), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10611), 1,
      sym_pow_operator,
    ACTIONS(10613), 1,
      sym_mult_operator,
    ACTIONS(10615), 1,
      sym_concat_operator,
    ACTIONS(10617), 1,
      sym_rel_operator,
    ACTIONS(10619), 1,
      sym_and_operator,
    ACTIONS(10621), 1,
      sym_or_operator,
    STATE(1948), 1,
      sym_add_operator,
    STATE(8404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10344), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10342), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [398040] = 23,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(409), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(471), 1,
      aux_sym_directive_token1,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(10531), 1,
      anon_sym_let,
    ACTIONS(10533), 1,
      anon_sym_type,
    ACTIONS(10535), 1,
      anon_sym_exception,
    ACTIONS(10537), 1,
      anon_sym_module,
    ACTIONS(10539), 1,
      anon_sym_include,
    ACTIONS(10541), 1,
      anon_sym_class,
    ACTIONS(10543), 1,
      sym_let_operator,
    STATE(100), 1,
      aux_sym__structure_repeat1,
    STATE(7860), 1,
      sym_directive,
    STATE(8405), 1,
      sym_attribute,
    STATE(8427), 1,
      aux_sym__structure_repeat2,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12362), 2,
      sym_toplevel_directive,
      sym__structure_item,
    STATE(12427), 13,
      sym_value_definition,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_include_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [398124] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(8406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 13,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_as,
      anon_sym_when,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8296), 19,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [398174] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8407), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9584), 13,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9582), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [398222] = 23,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(409), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(471), 1,
      aux_sym_directive_token1,
    ACTIONS(747), 1,
      anon_sym_end,
    ACTIONS(10531), 1,
      anon_sym_let,
    ACTIONS(10533), 1,
      anon_sym_type,
    ACTIONS(10535), 1,
      anon_sym_exception,
    ACTIONS(10537), 1,
      anon_sym_module,
    ACTIONS(10539), 1,
      anon_sym_include,
    ACTIONS(10541), 1,
      anon_sym_class,
    ACTIONS(10543), 1,
      sym_let_operator,
    STATE(102), 1,
      aux_sym__structure_repeat1,
    STATE(7860), 1,
      sym_directive,
    STATE(8405), 1,
      aux_sym__structure_repeat2,
    STATE(8408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12362), 2,
      sym_toplevel_directive,
      sym__structure_item,
    STATE(12427), 13,
      sym_value_definition,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_include_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [398306] = 23,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(35), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(119), 1,
      aux_sym_directive_token1,
    ACTIONS(685), 1,
      anon_sym_RBRACK,
    ACTIONS(10539), 1,
      anon_sym_include,
    ACTIONS(10547), 1,
      anon_sym_let,
    ACTIONS(10549), 1,
      anon_sym_type,
    ACTIONS(10551), 1,
      anon_sym_exception,
    ACTIONS(10553), 1,
      anon_sym_module,
    ACTIONS(10555), 1,
      anon_sym_class,
    ACTIONS(10557), 1,
      sym_let_operator,
    STATE(105), 1,
      aux_sym__structure_repeat1,
    STATE(7923), 1,
      sym_directive,
    STATE(8385), 1,
      aux_sym__structure_repeat2,
    STATE(8409), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12362), 2,
      sym_toplevel_directive,
      sym__structure_item,
    STATE(12427), 13,
      sym_value_definition,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_include_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [398390] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10429), 1,
      anon_sym_COMMA,
    ACTIONS(10431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10433), 1,
      sym_pow_operator,
    ACTIONS(10435), 1,
      sym_mult_operator,
    ACTIONS(10437), 1,
      sym_concat_operator,
    ACTIONS(10439), 1,
      sym_rel_operator,
    ACTIONS(10441), 1,
      sym_and_operator,
    ACTIONS(10443), 1,
      sym_or_operator,
    ACTIONS(10445), 1,
      sym_assign_operator,
    ACTIONS(10650), 1,
      anon_sym_SEMI,
    STATE(2305), 1,
      sym_add_operator,
    STATE(8410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9116), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9114), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [398462] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8411), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9580), 13,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9578), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [398510] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8624), 13,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8622), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [398558] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10545), 1,
      anon_sym_PIPE,
    STATE(8388), 1,
      aux_sym__match_cases_repeat1,
    STATE(8413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [398610] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 13,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8226), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [398658] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10545), 1,
      anon_sym_PIPE,
    STATE(8388), 1,
      aux_sym__match_cases_repeat1,
    STATE(8415), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [398710] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10628), 1,
      anon_sym_COMMA,
    ACTIONS(10632), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10634), 1,
      sym_pow_operator,
    ACTIONS(10636), 1,
      sym_mult_operator,
    ACTIONS(10638), 1,
      sym_concat_operator,
    ACTIONS(10640), 1,
      sym_rel_operator,
    ACTIONS(10642), 1,
      sym_and_operator,
    ACTIONS(10644), 1,
      sym_or_operator,
    ACTIONS(10646), 1,
      sym_assign_operator,
    STATE(1881), 1,
      sym_add_operator,
    STATE(8416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10303), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10301), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [398780] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8417), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9576), 13,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9574), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [398828] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10545), 1,
      anon_sym_PIPE,
    STATE(8415), 1,
      aux_sym__match_cases_repeat1,
    STATE(8418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [398880] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(8419), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 10,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8296), 22,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [398930] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(8420), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 10,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8296), 22,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [398980] = 23,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(35), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(119), 1,
      aux_sym_directive_token1,
    ACTIONS(749), 1,
      anon_sym_RBRACK,
    ACTIONS(10539), 1,
      anon_sym_include,
    ACTIONS(10547), 1,
      anon_sym_let,
    ACTIONS(10549), 1,
      anon_sym_type,
    ACTIONS(10551), 1,
      anon_sym_exception,
    ACTIONS(10553), 1,
      anon_sym_module,
    ACTIONS(10555), 1,
      anon_sym_class,
    ACTIONS(10557), 1,
      sym_let_operator,
    STATE(97), 1,
      aux_sym__structure_repeat1,
    STATE(7923), 1,
      sym_directive,
    STATE(8385), 1,
      aux_sym__structure_repeat2,
    STATE(8421), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12362), 2,
      sym_toplevel_directive,
      sym__structure_item,
    STATE(12427), 13,
      sym_value_definition,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_include_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [399064] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10648), 1,
      anon_sym_PIPE,
    STATE(8422), 1,
      sym_attribute,
    STATE(8425), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [399116] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(1881), 1,
      sym_add_operator,
    STATE(8423), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [399166] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10648), 1,
      anon_sym_PIPE,
    STATE(8424), 1,
      sym_attribute,
    STATE(8425), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [399218] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10652), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8425), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [399268] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10628), 1,
      anon_sym_COMMA,
    ACTIONS(10632), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10634), 1,
      sym_pow_operator,
    ACTIONS(10636), 1,
      sym_mult_operator,
    ACTIONS(10638), 1,
      sym_concat_operator,
    ACTIONS(10640), 1,
      sym_rel_operator,
    ACTIONS(10642), 1,
      sym_and_operator,
    ACTIONS(10644), 1,
      sym_or_operator,
    ACTIONS(10646), 1,
      sym_assign_operator,
    STATE(1881), 1,
      sym_add_operator,
    STATE(8426), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10340), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10338), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [399338] = 22,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10561), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(10567), 1,
      anon_sym_external,
    ACTIONS(10573), 1,
      anon_sym_end,
    ACTIONS(10581), 1,
      anon_sym_open,
    ACTIONS(10584), 1,
      anon_sym_include,
    ACTIONS(10590), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(10593), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(10596), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(10655), 1,
      anon_sym_let,
    ACTIONS(10658), 1,
      anon_sym_type,
    ACTIONS(10661), 1,
      anon_sym_exception,
    ACTIONS(10664), 1,
      anon_sym_module,
    ACTIONS(10667), 1,
      anon_sym_class,
    ACTIONS(10670), 1,
      sym_let_operator,
    ACTIONS(10673), 1,
      aux_sym_directive_token1,
    STATE(110), 1,
      aux_sym__structure_repeat1,
    STATE(7860), 1,
      sym_directive,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8427), 2,
      sym_attribute,
      aux_sym__structure_repeat2,
    STATE(12362), 2,
      sym_toplevel_directive,
      sym__structure_item,
    STATE(12427), 13,
      sym_value_definition,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_include_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [399420] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10632), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10634), 1,
      sym_pow_operator,
    ACTIONS(10636), 1,
      sym_mult_operator,
    ACTIONS(10638), 1,
      sym_concat_operator,
    ACTIONS(10640), 1,
      sym_rel_operator,
    ACTIONS(10642), 1,
      sym_and_operator,
    ACTIONS(10644), 1,
      sym_or_operator,
    STATE(1881), 1,
      sym_add_operator,
    STATE(8428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10344), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10342), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [399486] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10632), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10634), 1,
      sym_pow_operator,
    ACTIONS(10636), 1,
      sym_mult_operator,
    STATE(1881), 1,
      sym_add_operator,
    STATE(8429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [399544] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10634), 1,
      sym_pow_operator,
    STATE(1881), 1,
      sym_add_operator,
    STATE(8430), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [399596] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10634), 1,
      sym_pow_operator,
    STATE(1881), 1,
      sym_add_operator,
    STATE(8431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [399648] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10632), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10634), 1,
      sym_pow_operator,
    ACTIONS(10636), 1,
      sym_mult_operator,
    ACTIONS(10638), 1,
      sym_concat_operator,
    STATE(1881), 1,
      sym_add_operator,
    STATE(8432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [399708] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10632), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10634), 1,
      sym_pow_operator,
    ACTIONS(10636), 1,
      sym_mult_operator,
    ACTIONS(10638), 1,
      sym_concat_operator,
    STATE(1881), 1,
      sym_add_operator,
    STATE(8433), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [399768] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10632), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10634), 1,
      sym_pow_operator,
    ACTIONS(10636), 1,
      sym_mult_operator,
    ACTIONS(10638), 1,
      sym_concat_operator,
    ACTIONS(10640), 1,
      sym_rel_operator,
    ACTIONS(10642), 1,
      sym_and_operator,
    STATE(1881), 1,
      sym_add_operator,
    STATE(8434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10269), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [399832] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10632), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10634), 1,
      sym_pow_operator,
    ACTIONS(10636), 1,
      sym_mult_operator,
    ACTIONS(10638), 1,
      sym_concat_operator,
    ACTIONS(10640), 1,
      sym_rel_operator,
    ACTIONS(10642), 1,
      sym_and_operator,
    ACTIONS(10644), 1,
      sym_or_operator,
    STATE(1881), 1,
      sym_add_operator,
    STATE(8435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10269), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [399898] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10628), 1,
      anon_sym_COMMA,
    ACTIONS(10632), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10634), 1,
      sym_pow_operator,
    ACTIONS(10636), 1,
      sym_mult_operator,
    ACTIONS(10638), 1,
      sym_concat_operator,
    ACTIONS(10640), 1,
      sym_rel_operator,
    ACTIONS(10642), 1,
      sym_and_operator,
    ACTIONS(10644), 1,
      sym_or_operator,
    ACTIONS(10646), 1,
      sym_assign_operator,
    STATE(1881), 1,
      sym_add_operator,
    STATE(8436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10269), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [399968] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10634), 1,
      sym_pow_operator,
    ACTIONS(10636), 1,
      sym_mult_operator,
    STATE(1881), 1,
      sym_add_operator,
    STATE(8437), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [400022] = 23,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(409), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(471), 1,
      aux_sym_directive_token1,
    ACTIONS(685), 1,
      anon_sym_end,
    ACTIONS(10531), 1,
      anon_sym_let,
    ACTIONS(10533), 1,
      anon_sym_type,
    ACTIONS(10535), 1,
      anon_sym_exception,
    ACTIONS(10537), 1,
      anon_sym_module,
    ACTIONS(10539), 1,
      anon_sym_include,
    ACTIONS(10541), 1,
      anon_sym_class,
    ACTIONS(10543), 1,
      sym_let_operator,
    STATE(98), 1,
      aux_sym__structure_repeat1,
    STATE(7860), 1,
      sym_directive,
    STATE(8427), 1,
      aux_sym__structure_repeat2,
    STATE(8438), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12362), 2,
      sym_toplevel_directive,
      sym__structure_item,
    STATE(12427), 13,
      sym_value_definition,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_include_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [400106] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(8439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 13,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_as,
      anon_sym_when,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8296), 19,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [400156] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(8440), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8304), 10,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8306), 22,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [400203] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10676), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8441), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14306), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [400288] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(8442), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8304), 13,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_as,
      anon_sym_when,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8306), 19,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [400335] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10678), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8443), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15788), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [400420] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(8444), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 10,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8284), 22,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [400467] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(8445), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 13,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_as,
      anon_sym_when,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8284), 19,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [400514] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10503), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8446), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15199), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [400599] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9376), 1,
      sym__lowercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9406), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10680), 1,
      anon_sym_LPAREN,
    ACTIONS(10682), 1,
      anon_sym_private,
    ACTIONS(10684), 1,
      anon_sym_LBRACK,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8447), 1,
      sym_attribute,
    STATE(9183), 1,
      sym__simple_type,
    STATE(10587), 1,
      sym__tuple_type,
    STATE(10900), 1,
      sym__type,
    STATE(16745), 1,
      sym_extended_module_path,
    STATE(19846), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9437), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [400684] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(8448), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8296), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [400733] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(8449), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 10,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8328), 22,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [400780] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10686), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8450), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14195), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [400865] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10688), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8451), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14231), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [400950] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10605), 1,
      anon_sym_COMMA,
    ACTIONS(10609), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10611), 1,
      sym_pow_operator,
    ACTIONS(10613), 1,
      sym_mult_operator,
    ACTIONS(10615), 1,
      sym_concat_operator,
    ACTIONS(10617), 1,
      sym_rel_operator,
    ACTIONS(10619), 1,
      sym_and_operator,
    ACTIONS(10621), 1,
      sym_or_operator,
    ACTIONS(10623), 1,
      sym_assign_operator,
    ACTIONS(10690), 1,
      anon_sym_SEMI,
    STATE(1948), 1,
      sym_add_operator,
    STATE(8452), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9116), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9114), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [401021] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9408), 1,
      sym__lowercase_identifier,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9424), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9426), 1,
      anon_sym_LT,
    ACTIONS(9428), 1,
      anon_sym_POUND,
    ACTIONS(9430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9434), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10692), 1,
      anon_sym_LPAREN,
    ACTIONS(10694), 1,
      anon_sym_private,
    ACTIONS(10696), 1,
      anon_sym_LBRACK,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8453), 1,
      sym_attribute,
    STATE(9482), 1,
      sym__simple_type,
    STATE(10815), 1,
      sym__tuple_type,
    STATE(11025), 1,
      sym__type,
    STATE(16665), 1,
      sym_extended_module_path,
    STATE(20113), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9574), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [401106] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10698), 1,
      sym__lowercase_identifier,
    ACTIONS(10700), 1,
      anon_sym_LPAREN,
    ACTIONS(10702), 1,
      anon_sym_private,
    ACTIONS(10704), 1,
      anon_sym_LBRACK,
    ACTIONS(10706), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10708), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10710), 1,
      anon_sym_LT,
    ACTIONS(10712), 1,
      anon_sym_POUND,
    ACTIONS(10714), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10716), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10718), 1,
      aux_sym_type_variable_token1,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8454), 1,
      sym_attribute,
    STATE(8954), 1,
      sym__simple_type,
    STATE(9972), 1,
      sym__tuple_type,
    STATE(10345), 1,
      sym__type,
    STATE(17326), 1,
      sym_extended_module_path,
    STATE(18901), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9339), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [401191] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(8455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 13,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_as,
      anon_sym_when,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8328), 19,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [401238] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9454), 1,
      sym__lowercase_identifier,
    ACTIONS(9468), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9470), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9472), 1,
      anon_sym_LT,
    ACTIONS(9474), 1,
      anon_sym_POUND,
    ACTIONS(9476), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9478), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9480), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10720), 1,
      anon_sym_LPAREN,
    ACTIONS(10722), 1,
      anon_sym_private,
    ACTIONS(10724), 1,
      anon_sym_LBRACK,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8456), 1,
      sym_attribute,
    STATE(9025), 1,
      sym__simple_type,
    STATE(10401), 1,
      sym__tuple_type,
    STATE(10996), 1,
      sym__type,
    STATE(16859), 1,
      sym_extended_module_path,
    STATE(19708), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9377), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [401323] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10726), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8457), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16442), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [401408] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10728), 1,
      sym__lowercase_identifier,
    ACTIONS(10730), 1,
      anon_sym_LPAREN,
    ACTIONS(10732), 1,
      anon_sym_private,
    ACTIONS(10734), 1,
      anon_sym_LBRACK,
    ACTIONS(10736), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10738), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10740), 1,
      anon_sym_LT,
    ACTIONS(10742), 1,
      anon_sym_POUND,
    ACTIONS(10744), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10746), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10748), 1,
      aux_sym_type_variable_token1,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8458), 1,
      sym_attribute,
    STATE(8988), 1,
      sym__simple_type,
    STATE(10150), 1,
      sym__tuple_type,
    STATE(10438), 1,
      sym__type,
    STATE(17101), 1,
      sym_extended_module_path,
    STATE(19318), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9439), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [401493] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10688), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8459), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15255), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [401578] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10750), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8460), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14243), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [401663] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10752), 1,
      anon_sym_PIPE,
    STATE(8461), 1,
      sym_attribute,
    STATE(8509), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [401714] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10754), 1,
      anon_sym_COMMA,
    ACTIONS(10756), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10758), 1,
      sym_pow_operator,
    ACTIONS(10760), 1,
      sym_mult_operator,
    ACTIONS(10762), 1,
      sym_concat_operator,
    ACTIONS(10764), 1,
      sym_rel_operator,
    ACTIONS(10766), 1,
      sym_and_operator,
    ACTIONS(10768), 1,
      sym_or_operator,
    ACTIONS(10770), 1,
      sym_assign_operator,
    STATE(2210), 1,
      sym_add_operator,
    STATE(8462), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10340), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10338), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [401783] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10529), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8463), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14350), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [401868] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10772), 1,
      sym__lowercase_identifier,
    ACTIONS(10774), 1,
      anon_sym_LPAREN,
    ACTIONS(10776), 1,
      anon_sym_private,
    ACTIONS(10778), 1,
      anon_sym_LBRACK,
    ACTIONS(10780), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10782), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10784), 1,
      anon_sym_LT,
    ACTIONS(10786), 1,
      anon_sym_POUND,
    ACTIONS(10788), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10790), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10792), 1,
      aux_sym_type_variable_token1,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8464), 1,
      sym_attribute,
    STATE(12898), 1,
      sym__simple_type,
    STATE(13464), 1,
      sym__tuple_type,
    STATE(13497), 1,
      sym__type,
    STATE(17192), 1,
      sym_extended_module_path,
    STATE(19247), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(13156), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [401953] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10794), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8465), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [402002] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10750), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8466), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15925), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [402087] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10678), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8467), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14363), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [402172] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10754), 1,
      anon_sym_COMMA,
    ACTIONS(10756), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10758), 1,
      sym_pow_operator,
    ACTIONS(10760), 1,
      sym_mult_operator,
    ACTIONS(10762), 1,
      sym_concat_operator,
    ACTIONS(10764), 1,
      sym_rel_operator,
    ACTIONS(10766), 1,
      sym_and_operator,
    ACTIONS(10768), 1,
      sym_or_operator,
    ACTIONS(10770), 1,
      sym_assign_operator,
    ACTIONS(10797), 1,
      anon_sym_SEMI,
    STATE(2210), 1,
      sym_add_operator,
    STATE(8468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9116), 3,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9114), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [402243] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10799), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8469), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14373), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [402328] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10801), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8470), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15428), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [402413] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10803), 1,
      sym__lowercase_identifier,
    ACTIONS(10805), 1,
      anon_sym_LPAREN,
    ACTIONS(10807), 1,
      anon_sym_private,
    ACTIONS(10809), 1,
      anon_sym_LBRACK,
    ACTIONS(10811), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10813), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10815), 1,
      anon_sym_LT,
    ACTIONS(10817), 1,
      anon_sym_POUND,
    ACTIONS(10819), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10821), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10823), 1,
      aux_sym_type_variable_token1,
    STATE(8471), 1,
      sym_attribute,
    STATE(12765), 1,
      sym__simple_type,
    STATE(12906), 1,
      sym_tuple_type,
    STATE(13224), 1,
      sym__tuple_type,
    STATE(13306), 1,
      sym__type,
    STATE(17392), 1,
      sym_extended_module_path,
    STATE(18708), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12956), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12924), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [402498] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10825), 1,
      anon_sym_PIPE,
    STATE(8465), 1,
      aux_sym__match_cases_repeat1,
    STATE(8472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [402549] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10825), 1,
      anon_sym_PIPE,
    STATE(8473), 1,
      sym_attribute,
    STATE(8483), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [402600] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10756), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10758), 1,
      sym_pow_operator,
    ACTIONS(10760), 1,
      sym_mult_operator,
    ACTIONS(10762), 1,
      sym_concat_operator,
    ACTIONS(10764), 1,
      sym_rel_operator,
    ACTIONS(10766), 1,
      sym_and_operator,
    ACTIONS(10768), 1,
      sym_or_operator,
    STATE(2210), 1,
      sym_add_operator,
    STATE(8474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10344), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10342), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [402665] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(8475), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8296), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [402714] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10756), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10758), 1,
      sym_pow_operator,
    ACTIONS(10760), 1,
      sym_mult_operator,
    STATE(2210), 1,
      sym_add_operator,
    STATE(8476), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 6,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [402771] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10758), 1,
      sym_pow_operator,
    STATE(2210), 1,
      sym_add_operator,
    STATE(8477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [402822] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2075), 1,
      sym_add_operator,
    STATE(8478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [402871] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10524), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8479), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16107), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [402956] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10827), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8480), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14327), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [403041] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10829), 1,
      anon_sym_else,
    STATE(8123), 1,
      sym_else_clause,
    STATE(8481), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [403092] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10825), 1,
      anon_sym_PIPE,
    STATE(8472), 1,
      aux_sym__match_cases_repeat1,
    STATE(8482), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [403143] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10825), 1,
      anon_sym_PIPE,
    STATE(8465), 1,
      aux_sym__match_cases_repeat1,
    STATE(8483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [403194] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10799), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8484), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15685), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [403279] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10831), 1,
      anon_sym_else,
    STATE(8123), 1,
      sym_else_clause,
    STATE(8485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [403330] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10524), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8486), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14191), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [403415] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10529), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8487), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15632), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [403500] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10752), 1,
      anon_sym_PIPE,
    STATE(8488), 1,
      sym_attribute,
    STATE(8524), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [403551] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10833), 1,
      anon_sym_else,
    STATE(8237), 1,
      sym_else_clause,
    STATE(8489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [403602] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10503), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8490), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14266), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [403687] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10835), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8491), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16479), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [403772] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10801), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8492), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14275), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [403857] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10837), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8493), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14288), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [403942] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    ACTIONS(10839), 1,
      anon_sym_AMP,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8494), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(13709), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [404027] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10841), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8495), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15635), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [404112] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10843), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8496), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15350), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [404197] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10835), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8497), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14210), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [404282] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10758), 1,
      sym_pow_operator,
    STATE(2210), 1,
      sym_add_operator,
    STATE(8498), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [404333] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10756), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10758), 1,
      sym_pow_operator,
    ACTIONS(10760), 1,
      sym_mult_operator,
    ACTIONS(10762), 1,
      sym_concat_operator,
    STATE(2210), 1,
      sym_add_operator,
    STATE(8499), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 6,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [404392] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10756), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10758), 1,
      sym_pow_operator,
    ACTIONS(10760), 1,
      sym_mult_operator,
    ACTIONS(10762), 1,
      sym_concat_operator,
    STATE(2210), 1,
      sym_add_operator,
    STATE(8500), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 6,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [404451] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10756), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10758), 1,
      sym_pow_operator,
    ACTIONS(10760), 1,
      sym_mult_operator,
    ACTIONS(10762), 1,
      sym_concat_operator,
    ACTIONS(10764), 1,
      sym_rel_operator,
    ACTIONS(10766), 1,
      sym_and_operator,
    STATE(2210), 1,
      sym_add_operator,
    STATE(8501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 5,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10269), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [404514] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10756), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10758), 1,
      sym_pow_operator,
    ACTIONS(10760), 1,
      sym_mult_operator,
    ACTIONS(10762), 1,
      sym_concat_operator,
    ACTIONS(10764), 1,
      sym_rel_operator,
    ACTIONS(10766), 1,
      sym_and_operator,
    ACTIONS(10768), 1,
      sym_or_operator,
    STATE(2210), 1,
      sym_add_operator,
    STATE(8502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10269), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [404579] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10754), 1,
      anon_sym_COMMA,
    ACTIONS(10756), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10758), 1,
      sym_pow_operator,
    ACTIONS(10760), 1,
      sym_mult_operator,
    ACTIONS(10762), 1,
      sym_concat_operator,
    ACTIONS(10764), 1,
      sym_rel_operator,
    ACTIONS(10766), 1,
      sym_and_operator,
    ACTIONS(10768), 1,
      sym_or_operator,
    ACTIONS(10770), 1,
      sym_assign_operator,
    STATE(2210), 1,
      sym_add_operator,
    STATE(8503), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10269), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [404648] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(8504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 10,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8314), 22,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [404695] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10845), 1,
      anon_sym_COMMA,
    ACTIONS(10847), 1,
      anon_sym_SEMI,
    ACTIONS(10849), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10851), 1,
      sym_pow_operator,
    ACTIONS(10853), 1,
      sym_mult_operator,
    ACTIONS(10855), 1,
      sym_concat_operator,
    ACTIONS(10857), 1,
      sym_rel_operator,
    ACTIONS(10859), 1,
      sym_and_operator,
    ACTIONS(10861), 1,
      sym_or_operator,
    ACTIONS(10863), 1,
      sym_assign_operator,
    STATE(2075), 1,
      sym_add_operator,
    STATE(8505), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9116), 3,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9114), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [404766] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10845), 1,
      anon_sym_COMMA,
    ACTIONS(10849), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10851), 1,
      sym_pow_operator,
    ACTIONS(10853), 1,
      sym_mult_operator,
    ACTIONS(10855), 1,
      sym_concat_operator,
    ACTIONS(10857), 1,
      sym_rel_operator,
    ACTIONS(10859), 1,
      sym_and_operator,
    ACTIONS(10861), 1,
      sym_or_operator,
    ACTIONS(10863), 1,
      sym_assign_operator,
    STATE(2075), 1,
      sym_add_operator,
    STATE(8506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10332), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10330), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [404835] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10509), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8507), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15981), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [404920] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10843), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8508), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14346), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [405005] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10752), 1,
      anon_sym_PIPE,
    STATE(8509), 1,
      sym_attribute,
    STATE(8526), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [405056] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10758), 1,
      sym_pow_operator,
    ACTIONS(10760), 1,
      sym_mult_operator,
    STATE(2210), 1,
      sym_add_operator,
    STATE(8510), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 9,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [405109] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10754), 1,
      anon_sym_COMMA,
    ACTIONS(10756), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10758), 1,
      sym_pow_operator,
    ACTIONS(10760), 1,
      sym_mult_operator,
    ACTIONS(10762), 1,
      sym_concat_operator,
    ACTIONS(10764), 1,
      sym_rel_operator,
    ACTIONS(10766), 1,
      sym_and_operator,
    ACTIONS(10768), 1,
      sym_or_operator,
    ACTIONS(10770), 1,
      sym_assign_operator,
    STATE(2210), 1,
      sym_add_operator,
    STATE(8511), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10303), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10301), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [405178] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10837), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8512), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15767), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [405263] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(8513), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 11,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8296), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [405312] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10841), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8514), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14226), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [405397] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10676), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8515), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15986), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [405482] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10865), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8516), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14264), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [405567] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10867), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8517), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15821), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [405652] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10754), 1,
      anon_sym_COMMA,
    ACTIONS(10756), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10758), 1,
      sym_pow_operator,
    ACTIONS(10760), 1,
      sym_mult_operator,
    ACTIONS(10762), 1,
      sym_concat_operator,
    ACTIONS(10764), 1,
      sym_rel_operator,
    ACTIONS(10766), 1,
      sym_and_operator,
    ACTIONS(10768), 1,
      sym_or_operator,
    ACTIONS(10770), 1,
      sym_assign_operator,
    STATE(2210), 1,
      sym_add_operator,
    STATE(8518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10332), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10330), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [405721] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10845), 1,
      anon_sym_COMMA,
    ACTIONS(10849), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10851), 1,
      sym_pow_operator,
    ACTIONS(10853), 1,
      sym_mult_operator,
    ACTIONS(10855), 1,
      sym_concat_operator,
    ACTIONS(10857), 1,
      sym_rel_operator,
    ACTIONS(10859), 1,
      sym_and_operator,
    ACTIONS(10861), 1,
      sym_or_operator,
    ACTIONS(10863), 1,
      sym_assign_operator,
    STATE(2075), 1,
      sym_add_operator,
    STATE(8519), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10340), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10338), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [405790] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10829), 1,
      anon_sym_else,
    STATE(8237), 1,
      sym_else_clause,
    STATE(8520), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [405841] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(8521), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 13,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_as,
      anon_sym_when,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8314), 19,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [405888] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10869), 1,
      anon_sym_else,
    STATE(8237), 1,
      sym_else_clause,
    STATE(8522), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [405939] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10867), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8523), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14356), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [406024] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10752), 1,
      anon_sym_PIPE,
    STATE(8524), 1,
      sym_attribute,
    STATE(8526), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [406075] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10869), 1,
      anon_sym_else,
    STATE(8123), 1,
      sym_else_clause,
    STATE(8525), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [406126] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10871), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8526), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [406175] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10874), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8527), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15951), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [406260] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10876), 1,
      anon_sym_COLON,
    STATE(8528), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9600), 15,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9598), 16,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [406309] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10865), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8529), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16451), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [406394] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(8530), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 11,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8296), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [406443] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10874), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8531), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14319), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [406528] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10878), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8532), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16100), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [406613] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10849), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10851), 1,
      sym_pow_operator,
    ACTIONS(10853), 1,
      sym_mult_operator,
    ACTIONS(10855), 1,
      sym_concat_operator,
    ACTIONS(10857), 1,
      sym_rel_operator,
    ACTIONS(10859), 1,
      sym_and_operator,
    ACTIONS(10861), 1,
      sym_or_operator,
    STATE(2075), 1,
      sym_add_operator,
    STATE(8533), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10344), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10342), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [406678] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10628), 1,
      anon_sym_COMMA,
    ACTIONS(10632), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10634), 1,
      sym_pow_operator,
    ACTIONS(10636), 1,
      sym_mult_operator,
    ACTIONS(10638), 1,
      sym_concat_operator,
    ACTIONS(10640), 1,
      sym_rel_operator,
    ACTIONS(10642), 1,
      sym_and_operator,
    ACTIONS(10644), 1,
      sym_or_operator,
    ACTIONS(10646), 1,
      sym_assign_operator,
    ACTIONS(10880), 1,
      anon_sym_SEMI,
    STATE(1881), 1,
      sym_add_operator,
    STATE(8534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9116), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9114), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [406749] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10882), 1,
      sym__lowercase_identifier,
    ACTIONS(10884), 1,
      anon_sym_LPAREN,
    ACTIONS(10886), 1,
      anon_sym_private,
    ACTIONS(10888), 1,
      anon_sym_LBRACK,
    ACTIONS(10890), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10892), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10894), 1,
      anon_sym_LT,
    ACTIONS(10896), 1,
      anon_sym_POUND,
    ACTIONS(10898), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10900), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10902), 1,
      aux_sym_type_variable_token1,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8535), 1,
      sym_attribute,
    STATE(9122), 1,
      sym__simple_type,
    STATE(10431), 1,
      sym__tuple_type,
    STATE(10799), 1,
      sym__type,
    STATE(17294), 1,
      sym_extended_module_path,
    STATE(19017), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9653), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [406834] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2210), 1,
      sym_add_operator,
    STATE(8536), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [406883] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10904), 1,
      sym__lowercase_identifier,
    ACTIONS(10906), 1,
      anon_sym_LPAREN,
    ACTIONS(10908), 1,
      anon_sym_private,
    ACTIONS(10910), 1,
      anon_sym_LBRACK,
    ACTIONS(10912), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10914), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10916), 1,
      anon_sym_LT,
    ACTIONS(10918), 1,
      anon_sym_POUND,
    ACTIONS(10920), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10922), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10924), 1,
      aux_sym_type_variable_token1,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8537), 1,
      sym_attribute,
    STATE(8946), 1,
      sym__simple_type,
    STATE(9899), 1,
      sym__tuple_type,
    STATE(10219), 1,
      sym__type,
    STATE(17362), 1,
      sym_extended_module_path,
    STATE(18796), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9114), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [406968] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10849), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10851), 1,
      sym_pow_operator,
    ACTIONS(10853), 1,
      sym_mult_operator,
    STATE(2075), 1,
      sym_add_operator,
    STATE(8538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 6,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [407025] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10509), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8539), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14342), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [407110] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10851), 1,
      sym_pow_operator,
    STATE(2075), 1,
      sym_add_operator,
    STATE(8540), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [407161] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10926), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8541), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14344), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [407246] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10851), 1,
      sym_pow_operator,
    STATE(2075), 1,
      sym_add_operator,
    STATE(8542), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [407297] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10726), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8543), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14254), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [407382] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10849), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10851), 1,
      sym_pow_operator,
    ACTIONS(10853), 1,
      sym_mult_operator,
    ACTIONS(10855), 1,
      sym_concat_operator,
    STATE(2075), 1,
      sym_add_operator,
    STATE(8544), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 6,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [407441] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10849), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10851), 1,
      sym_pow_operator,
    ACTIONS(10853), 1,
      sym_mult_operator,
    ACTIONS(10855), 1,
      sym_concat_operator,
    STATE(2075), 1,
      sym_add_operator,
    STATE(8545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 6,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [407500] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10849), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10851), 1,
      sym_pow_operator,
    ACTIONS(10853), 1,
      sym_mult_operator,
    ACTIONS(10855), 1,
      sym_concat_operator,
    ACTIONS(10857), 1,
      sym_rel_operator,
    ACTIONS(10859), 1,
      sym_and_operator,
    STATE(2075), 1,
      sym_add_operator,
    STATE(8546), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 5,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10269), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [407563] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10878), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8547), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14245), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [407648] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10849), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10851), 1,
      sym_pow_operator,
    ACTIONS(10853), 1,
      sym_mult_operator,
    ACTIONS(10855), 1,
      sym_concat_operator,
    ACTIONS(10857), 1,
      sym_rel_operator,
    ACTIONS(10859), 1,
      sym_and_operator,
    ACTIONS(10861), 1,
      sym_or_operator,
    STATE(2075), 1,
      sym_add_operator,
    STATE(8548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10269), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [407713] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10686), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8549), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16242), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [407798] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10845), 1,
      anon_sym_COMMA,
    ACTIONS(10849), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10851), 1,
      sym_pow_operator,
    ACTIONS(10853), 1,
      sym_mult_operator,
    ACTIONS(10855), 1,
      sym_concat_operator,
    ACTIONS(10857), 1,
      sym_rel_operator,
    ACTIONS(10859), 1,
      sym_and_operator,
    ACTIONS(10861), 1,
      sym_or_operator,
    ACTIONS(10863), 1,
      sym_assign_operator,
    STATE(2075), 1,
      sym_add_operator,
    STATE(8550), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10269), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [407867] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10833), 1,
      anon_sym_else,
    STATE(8123), 1,
      sym_else_clause,
    STATE(8551), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [407918] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10851), 1,
      sym_pow_operator,
    ACTIONS(10853), 1,
      sym_mult_operator,
    STATE(2075), 1,
      sym_add_operator,
    STATE(8552), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 9,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [407971] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9486), 1,
      sym__lowercase_identifier,
    ACTIONS(9500), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9502), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9504), 1,
      anon_sym_LT,
    ACTIONS(9506), 1,
      anon_sym_POUND,
    ACTIONS(9508), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9510), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9512), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10928), 1,
      anon_sym_LPAREN,
    ACTIONS(10930), 1,
      anon_sym_private,
    ACTIONS(10932), 1,
      anon_sym_LBRACK,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8553), 1,
      sym_attribute,
    STATE(9760), 1,
      sym__simple_type,
    STATE(11076), 1,
      sym__tuple_type,
    STATE(11453), 1,
      sym__type,
    STATE(16914), 1,
      sym_extended_module_path,
    STATE(19582), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(10076), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [408056] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10845), 1,
      anon_sym_COMMA,
    ACTIONS(10849), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10851), 1,
      sym_pow_operator,
    ACTIONS(10853), 1,
      sym_mult_operator,
    ACTIONS(10855), 1,
      sym_concat_operator,
    ACTIONS(10857), 1,
      sym_rel_operator,
    ACTIONS(10859), 1,
      sym_and_operator,
    ACTIONS(10861), 1,
      sym_or_operator,
    ACTIONS(10863), 1,
      sym_assign_operator,
    STATE(2075), 1,
      sym_add_operator,
    STATE(8554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10303), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10301), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [408125] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10926), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8555), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16376), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [408210] = 24,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7865), 1,
      sym__lowercase_identifier,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10827), 1,
      anon_sym_module,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8556), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15916), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [408295] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10831), 1,
      anon_sym_else,
    STATE(8237), 1,
      sym_else_clause,
    STATE(8557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [408346] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8558), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15176), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [408428] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8559), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15390), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [408510] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8560), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9638), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9640), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [408556] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8561), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9630), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9632), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [408602] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8562), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(12906), 1,
      sym_tuple_type,
    STATE(13657), 1,
      sym__tuple_type,
    STATE(14334), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20407), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12956), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [408684] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8563), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16108), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [408766] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8564), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9618), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9620), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [408812] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8565), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8288), 21,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [408858] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8292), 21,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [408904] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8567), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8302), 21,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [408950] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8568), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8310), 21,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [408996] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8569), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8336), 21,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [409042] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(10245), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10247), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10936), 1,
      anon_sym_let,
    STATE(8570), 1,
      sym_attribute,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10557), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(10934), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [409104] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 11,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8284), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [409150] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8572), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15862), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [409232] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8573), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16283), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [409314] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10938), 1,
      anon_sym_COMMA,
    ACTIONS(10940), 1,
      anon_sym_SEMI,
    ACTIONS(10942), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10944), 1,
      sym_pow_operator,
    ACTIONS(10946), 1,
      sym_mult_operator,
    ACTIONS(10948), 1,
      sym_concat_operator,
    ACTIONS(10950), 1,
      sym_rel_operator,
    ACTIONS(10952), 1,
      sym_and_operator,
    ACTIONS(10954), 1,
      sym_or_operator,
    ACTIONS(10956), 1,
      sym_assign_operator,
    STATE(1790), 1,
      sym_add_operator,
    STATE(8574), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9116), 3,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9114), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [409384] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8575), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(12906), 1,
      sym_tuple_type,
    STATE(13657), 1,
      sym__tuple_type,
    STATE(13912), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20407), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12956), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [409466] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8576), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16249), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [409548] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10884), 1,
      anon_sym_LPAREN,
    ACTIONS(10888), 1,
      anon_sym_LBRACK,
    ACTIONS(10890), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10892), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10894), 1,
      anon_sym_LT,
    ACTIONS(10896), 1,
      anon_sym_POUND,
    ACTIONS(10898), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10900), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10902), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10958), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8577), 1,
      sym_attribute,
    STATE(9122), 1,
      sym__simple_type,
    STATE(10431), 1,
      sym__tuple_type,
    STATE(10858), 1,
      sym__type,
    STATE(17294), 1,
      sym_extended_module_path,
    STATE(19017), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9653), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [409630] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8578), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16392), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [409712] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9646), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9648), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [409758] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10805), 1,
      anon_sym_LPAREN,
    ACTIONS(10809), 1,
      anon_sym_LBRACK,
    ACTIONS(10811), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10813), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10815), 1,
      anon_sym_LT,
    ACTIONS(10817), 1,
      anon_sym_POUND,
    ACTIONS(10819), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10821), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10823), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10960), 1,
      sym__lowercase_identifier,
    STATE(8580), 1,
      sym_attribute,
    STATE(12765), 1,
      sym__simple_type,
    STATE(12906), 1,
      sym_tuple_type,
    STATE(13224), 1,
      sym__tuple_type,
    STATE(13368), 1,
      sym__type,
    STATE(17392), 1,
      sym_extended_module_path,
    STATE(18708), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12956), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12924), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [409840] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8581), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8318), 21,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [409886] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8582), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8340), 21,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [409932] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8583), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15947), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [410014] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9992), 1,
      anon_sym_LPAREN,
    ACTIONS(9994), 1,
      anon_sym_LBRACK,
    ACTIONS(9996), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9998), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10000), 1,
      anon_sym_LT,
    ACTIONS(10002), 1,
      anon_sym_POUND,
    ACTIONS(10004), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10006), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10008), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10962), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8584), 1,
      sym_attribute,
    STATE(11068), 1,
      sym__simple_type,
    STATE(12710), 1,
      sym__tuple_type,
    STATE(12868), 1,
      sym__type,
    STATE(17058), 1,
      sym_extended_module_path,
    STATE(19394), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(11773), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [410096] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9992), 1,
      anon_sym_LPAREN,
    ACTIONS(9994), 1,
      anon_sym_LBRACK,
    ACTIONS(9996), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9998), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10000), 1,
      anon_sym_LT,
    ACTIONS(10002), 1,
      anon_sym_POUND,
    ACTIONS(10004), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10006), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10008), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10962), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8585), 1,
      sym_attribute,
    STATE(11068), 1,
      sym__simple_type,
    STATE(12710), 1,
      sym__tuple_type,
    STATE(12879), 1,
      sym__type,
    STATE(17058), 1,
      sym_extended_module_path,
    STATE(19394), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(11773), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [410178] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8586), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14233), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [410260] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8587), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15515), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [410342] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8588), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16428), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [410424] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9406), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10680), 1,
      anon_sym_LPAREN,
    ACTIONS(10684), 1,
      anon_sym_LBRACK,
    ACTIONS(10964), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8589), 1,
      sym_attribute,
    STATE(9183), 1,
      sym__simple_type,
    STATE(10587), 1,
      sym__tuple_type,
    STATE(10719), 1,
      sym__type,
    STATE(16745), 1,
      sym_extended_module_path,
    STATE(19846), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9437), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [410506] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8590), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16069), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [410588] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10966), 1,
      anon_sym_PIPE,
    STATE(8591), 1,
      sym_attribute,
    STATE(8680), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [410638] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8592), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8322), 21,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [410684] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9992), 1,
      anon_sym_LPAREN,
    ACTIONS(9994), 1,
      anon_sym_LBRACK,
    ACTIONS(9996), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9998), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10000), 1,
      anon_sym_LT,
    ACTIONS(10002), 1,
      anon_sym_POUND,
    ACTIONS(10004), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10006), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10008), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10962), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8593), 1,
      sym_attribute,
    STATE(11068), 1,
      sym__simple_type,
    STATE(12664), 1,
      sym__type,
    STATE(12710), 1,
      sym__tuple_type,
    STATE(17058), 1,
      sym_extended_module_path,
    STATE(19394), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(11773), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [410766] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8594), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16122), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [410848] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8595), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9650), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9652), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [410894] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8596), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15691), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [410976] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10024), 1,
      anon_sym_LPAREN,
    ACTIONS(10026), 1,
      anon_sym_LBRACK,
    ACTIONS(10028), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10030), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10032), 1,
      anon_sym_LT,
    ACTIONS(10034), 1,
      anon_sym_POUND,
    ACTIONS(10036), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10038), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10040), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10968), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8597), 1,
      sym_attribute,
    STATE(12149), 1,
      sym__simple_type,
    STATE(12944), 1,
      sym__tuple_type,
    STATE(13146), 1,
      sym__type,
    STATE(17260), 1,
      sym_extended_module_path,
    STATE(19173), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12684), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [411058] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8598), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16216), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [411140] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9500), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9502), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9504), 1,
      anon_sym_LT,
    ACTIONS(9506), 1,
      anon_sym_POUND,
    ACTIONS(9508), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9510), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9512), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10928), 1,
      anon_sym_LPAREN,
    ACTIONS(10932), 1,
      anon_sym_LBRACK,
    ACTIONS(10970), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8599), 1,
      sym_attribute,
    STATE(9760), 1,
      sym__simple_type,
    STATE(11076), 1,
      sym__tuple_type,
    STATE(11390), 1,
      sym__type,
    STATE(16914), 1,
      sym_extended_module_path,
    STATE(19582), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(10076), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [411222] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8600), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16116), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [411304] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8601), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9656), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9658), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [411350] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9500), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9502), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9504), 1,
      anon_sym_LT,
    ACTIONS(9506), 1,
      anon_sym_POUND,
    ACTIONS(9508), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9510), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9512), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10928), 1,
      anon_sym_LPAREN,
    ACTIONS(10932), 1,
      anon_sym_LBRACK,
    ACTIONS(10970), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8602), 1,
      sym_attribute,
    STATE(9760), 1,
      sym__simple_type,
    STATE(11076), 1,
      sym__tuple_type,
    STATE(11490), 1,
      sym__type,
    STATE(16914), 1,
      sym_extended_module_path,
    STATE(19582), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(10076), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [411432] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8603), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(12906), 1,
      sym_tuple_type,
    STATE(13657), 1,
      sym__tuple_type,
    STATE(14314), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20407), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12956), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [411514] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8604), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(12906), 1,
      sym_tuple_type,
    STATE(13657), 1,
      sym__tuple_type,
    STATE(14401), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20407), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12956), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [411596] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9660), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9662), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [411642] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8606), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9174), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9176), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [411688] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9406), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10680), 1,
      anon_sym_LPAREN,
    ACTIONS(10684), 1,
      anon_sym_LBRACK,
    ACTIONS(10964), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8607), 1,
      sym_attribute,
    STATE(9183), 1,
      sym__simple_type,
    STATE(10587), 1,
      sym__tuple_type,
    STATE(11199), 1,
      sym__type,
    STATE(16745), 1,
      sym_extended_module_path,
    STATE(19846), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9437), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [411770] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8608), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16012), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [411852] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10906), 1,
      anon_sym_LPAREN,
    ACTIONS(10910), 1,
      anon_sym_LBRACK,
    ACTIONS(10912), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10914), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10916), 1,
      anon_sym_LT,
    ACTIONS(10918), 1,
      anon_sym_POUND,
    ACTIONS(10920), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10922), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10924), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10972), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8609), 1,
      sym_attribute,
    STATE(8946), 1,
      sym__simple_type,
    STATE(9899), 1,
      sym__tuple_type,
    STATE(10295), 1,
      sym__type,
    STATE(17362), 1,
      sym_extended_module_path,
    STATE(18796), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9114), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [411934] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10974), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8610), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [411982] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8611), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8304), 11,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8306), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [412028] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8612), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15973), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [412110] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8613), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9758), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9760), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [412156] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8614), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15872), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [412238] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8615), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14312), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [412320] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10700), 1,
      anon_sym_LPAREN,
    ACTIONS(10704), 1,
      anon_sym_LBRACK,
    ACTIONS(10706), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10708), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10710), 1,
      anon_sym_LT,
    ACTIONS(10712), 1,
      anon_sym_POUND,
    ACTIONS(10714), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10716), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10718), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10977), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8616), 1,
      sym_attribute,
    STATE(8954), 1,
      sym__simple_type,
    STATE(9972), 1,
      sym__tuple_type,
    STATE(10172), 1,
      sym__type,
    STATE(17326), 1,
      sym_extended_module_path,
    STATE(18901), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9339), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [412402] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8617), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16364), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [412484] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10979), 1,
      anon_sym_PIPE,
    STATE(8610), 1,
      aux_sym__match_cases_repeat1,
    STATE(8618), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [412534] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8619), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 11,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8314), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [412580] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8620), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(13633), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [412662] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8621), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15743), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [412744] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8622), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8336), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [412790] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9500), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9502), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9504), 1,
      anon_sym_LT,
    ACTIONS(9506), 1,
      anon_sym_POUND,
    ACTIONS(9508), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9510), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9512), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10928), 1,
      anon_sym_LPAREN,
    ACTIONS(10932), 1,
      anon_sym_LBRACK,
    ACTIONS(10970), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8623), 1,
      sym_attribute,
    STATE(9760), 1,
      sym__simple_type,
    STATE(11076), 1,
      sym__tuple_type,
    STATE(11857), 1,
      sym__type,
    STATE(16914), 1,
      sym_extended_module_path,
    STATE(19582), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(10076), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [412872] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8624), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16220), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [412954] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8625), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15870), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [413036] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10805), 1,
      anon_sym_LPAREN,
    ACTIONS(10809), 1,
      anon_sym_LBRACK,
    ACTIONS(10811), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10813), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10815), 1,
      anon_sym_LT,
    ACTIONS(10817), 1,
      anon_sym_POUND,
    ACTIONS(10819), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10821), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10823), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10960), 1,
      sym__lowercase_identifier,
    STATE(8626), 1,
      sym_attribute,
    STATE(12765), 1,
      sym__simple_type,
    STATE(12906), 1,
      sym_tuple_type,
    STATE(13224), 1,
      sym__tuple_type,
    STATE(13240), 1,
      sym__type,
    STATE(17392), 1,
      sym_extended_module_path,
    STATE(18708), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12956), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12924), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [413118] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8627), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15832), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [413200] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9992), 1,
      anon_sym_LPAREN,
    ACTIONS(9994), 1,
      anon_sym_LBRACK,
    ACTIONS(9996), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9998), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10000), 1,
      anon_sym_LT,
    ACTIONS(10002), 1,
      anon_sym_POUND,
    ACTIONS(10004), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10006), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10008), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10962), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8628), 1,
      sym_attribute,
    STATE(11068), 1,
      sym__simple_type,
    STATE(12710), 1,
      sym__tuple_type,
    STATE(12737), 1,
      sym__type,
    STATE(17058), 1,
      sym_extended_module_path,
    STATE(19394), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(11773), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [413282] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9992), 1,
      anon_sym_LPAREN,
    ACTIONS(9994), 1,
      anon_sym_LBRACK,
    ACTIONS(9996), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9998), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10000), 1,
      anon_sym_LT,
    ACTIONS(10002), 1,
      anon_sym_POUND,
    ACTIONS(10004), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10006), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10008), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10962), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8629), 1,
      sym_attribute,
    STATE(11068), 1,
      sym__simple_type,
    STATE(12710), 1,
      sym__tuple_type,
    STATE(12749), 1,
      sym__type,
    STATE(17058), 1,
      sym_extended_module_path,
    STATE(19394), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(11773), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [413364] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10884), 1,
      anon_sym_LPAREN,
    ACTIONS(10888), 1,
      anon_sym_LBRACK,
    ACTIONS(10890), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10892), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10894), 1,
      anon_sym_LT,
    ACTIONS(10896), 1,
      anon_sym_POUND,
    ACTIONS(10898), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10900), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10902), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10958), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8630), 1,
      sym_attribute,
    STATE(9122), 1,
      sym__simple_type,
    STATE(10431), 1,
      sym__tuple_type,
    STATE(10910), 1,
      sym__type,
    STATE(17294), 1,
      sym_extended_module_path,
    STATE(19017), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9653), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [413446] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8631), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14345), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [413528] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10981), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8324), 26,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [413574] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10987), 1,
      anon_sym_DOT,
    STATE(8633), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10985), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10983), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [413622] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10906), 1,
      anon_sym_LPAREN,
    ACTIONS(10910), 1,
      anon_sym_LBRACK,
    ACTIONS(10912), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10914), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10916), 1,
      anon_sym_LT,
    ACTIONS(10918), 1,
      anon_sym_POUND,
    ACTIONS(10920), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10922), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10924), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10972), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8634), 1,
      sym_attribute,
    STATE(8946), 1,
      sym__simple_type,
    STATE(9899), 1,
      sym__tuple_type,
    STATE(10339), 1,
      sym__type,
    STATE(17362), 1,
      sym_extended_module_path,
    STATE(18796), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9114), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [413704] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9992), 1,
      anon_sym_LPAREN,
    ACTIONS(9994), 1,
      anon_sym_LBRACK,
    ACTIONS(9996), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9998), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10000), 1,
      anon_sym_LT,
    ACTIONS(10002), 1,
      anon_sym_POUND,
    ACTIONS(10004), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10006), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10008), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10962), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8635), 1,
      sym_attribute,
    STATE(11068), 1,
      sym__simple_type,
    STATE(12710), 1,
      sym__tuple_type,
    STATE(12837), 1,
      sym__type,
    STATE(17058), 1,
      sym_extended_module_path,
    STATE(19394), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(11773), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [413786] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10938), 1,
      anon_sym_COMMA,
    ACTIONS(10942), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10944), 1,
      sym_pow_operator,
    ACTIONS(10946), 1,
      sym_mult_operator,
    ACTIONS(10948), 1,
      sym_concat_operator,
    ACTIONS(10950), 1,
      sym_rel_operator,
    ACTIONS(10952), 1,
      sym_and_operator,
    ACTIONS(10954), 1,
      sym_or_operator,
    ACTIONS(10956), 1,
      sym_assign_operator,
    STATE(1790), 1,
      sym_add_operator,
    STATE(8636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10340), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10338), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [413854] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8637), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9108), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9110), 21,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [413900] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8638), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15686), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [413982] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 11,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8328), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [414028] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10989), 1,
      anon_sym_COMMA,
    ACTIONS(10991), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10993), 1,
      sym_pow_operator,
    ACTIONS(10995), 1,
      sym_mult_operator,
    ACTIONS(10997), 1,
      sym_concat_operator,
    ACTIONS(10999), 1,
      sym_rel_operator,
    ACTIONS(11001), 1,
      sym_and_operator,
    ACTIONS(11003), 1,
      sym_or_operator,
    ACTIONS(11005), 1,
      sym_assign_operator,
    STATE(2294), 1,
      sym_add_operator,
    STATE(8640), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10340), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10338), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [414096] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8641), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9718), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9720), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [414142] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8642), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15647), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [414224] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8643), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15731), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [414306] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9140), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9142), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [414352] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8645), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9700), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9702), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [414398] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8646), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15819), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [414480] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8647), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11009), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11007), 29,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [414526] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8648), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15694), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [414608] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9144), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9146), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [414654] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8650), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14295), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [414736] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10730), 1,
      anon_sym_LPAREN,
    ACTIONS(10734), 1,
      anon_sym_LBRACK,
    ACTIONS(10736), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10738), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10740), 1,
      anon_sym_LT,
    ACTIONS(10742), 1,
      anon_sym_POUND,
    ACTIONS(10744), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10746), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10748), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11011), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8651), 1,
      sym_attribute,
    STATE(8988), 1,
      sym__simple_type,
    STATE(10150), 1,
      sym__tuple_type,
    STATE(10461), 1,
      sym__type,
    STATE(17101), 1,
      sym_extended_module_path,
    STATE(19318), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9439), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [414818] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8652), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16628), 1,
      sym__type,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [414900] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11013), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8298), 26,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [414946] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8654), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15209), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [415028] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8655), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15479), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [415110] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8656), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15760), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [415192] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8657), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15447), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [415274] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8340), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [415320] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8659), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16079), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [415402] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8660), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15087), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [415484] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8661), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15185), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [415566] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8662), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15260), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [415648] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8663), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15941), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [415730] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8664), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9228), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9230), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [415776] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10024), 1,
      anon_sym_LPAREN,
    ACTIONS(10026), 1,
      anon_sym_LBRACK,
    ACTIONS(10028), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10030), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10032), 1,
      anon_sym_LT,
    ACTIONS(10034), 1,
      anon_sym_POUND,
    ACTIONS(10036), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10038), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10040), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10968), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8665), 1,
      sym_attribute,
    STATE(12149), 1,
      sym__simple_type,
    STATE(12944), 1,
      sym__tuple_type,
    STATE(13165), 1,
      sym__type,
    STATE(17260), 1,
      sym_extended_module_path,
    STATE(19173), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12684), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [415858] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10024), 1,
      anon_sym_LPAREN,
    ACTIONS(10026), 1,
      anon_sym_LBRACK,
    ACTIONS(10028), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10030), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10032), 1,
      anon_sym_LT,
    ACTIONS(10034), 1,
      anon_sym_POUND,
    ACTIONS(10036), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10038), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10040), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10968), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8666), 1,
      sym_attribute,
    STATE(12149), 1,
      sym__simple_type,
    STATE(12944), 1,
      sym__tuple_type,
    STATE(13161), 1,
      sym__type,
    STATE(17260), 1,
      sym_extended_module_path,
    STATE(19173), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12684), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [415940] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9102), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9104), 21,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [415986] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9468), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9470), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9472), 1,
      anon_sym_LT,
    ACTIONS(9474), 1,
      anon_sym_POUND,
    ACTIONS(9476), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9478), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9480), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10720), 1,
      anon_sym_LPAREN,
    ACTIONS(10724), 1,
      anon_sym_LBRACK,
    ACTIONS(11015), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8668), 1,
      sym_attribute,
    STATE(9025), 1,
      sym__simple_type,
    STATE(10401), 1,
      sym__tuple_type,
    STATE(11125), 1,
      sym__type,
    STATE(16859), 1,
      sym_extended_module_path,
    STATE(19708), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9377), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [416068] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10805), 1,
      anon_sym_LPAREN,
    ACTIONS(10809), 1,
      anon_sym_LBRACK,
    ACTIONS(10811), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10813), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10815), 1,
      anon_sym_LT,
    ACTIONS(10817), 1,
      anon_sym_POUND,
    ACTIONS(10819), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10821), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10823), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10960), 1,
      sym__lowercase_identifier,
    STATE(8669), 1,
      sym_attribute,
    STATE(12765), 1,
      sym__simple_type,
    STATE(12906), 1,
      sym_tuple_type,
    STATE(13224), 1,
      sym__tuple_type,
    STATE(13325), 1,
      sym__type,
    STATE(17392), 1,
      sym_extended_module_path,
    STATE(18708), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12956), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12924), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [416150] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8670), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15218), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [416232] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9406), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10680), 1,
      anon_sym_LPAREN,
    ACTIONS(10684), 1,
      anon_sym_LBRACK,
    ACTIONS(10964), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8671), 1,
      sym_attribute,
    STATE(9183), 1,
      sym__simple_type,
    STATE(10587), 1,
      sym__tuple_type,
    STATE(10778), 1,
      sym__type,
    STATE(16745), 1,
      sym_extended_module_path,
    STATE(19846), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9437), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [416314] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9906), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_LBRACK,
    ACTIONS(9910), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9912), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9914), 1,
      anon_sym_LT,
    ACTIONS(9916), 1,
      anon_sym_POUND,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9920), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9922), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11017), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8672), 1,
      sym_attribute,
    STATE(10594), 1,
      sym__simple_type,
    STATE(11981), 1,
      sym__tuple_type,
    STATE(12282), 1,
      sym__type,
    STATE(16934), 1,
      sym_extended_module_path,
    STATE(19479), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(11018), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [416396] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10024), 1,
      anon_sym_LPAREN,
    ACTIONS(10026), 1,
      anon_sym_LBRACK,
    ACTIONS(10028), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10030), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10032), 1,
      anon_sym_LT,
    ACTIONS(10034), 1,
      anon_sym_POUND,
    ACTIONS(10036), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10038), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10040), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10968), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8673), 1,
      sym_attribute,
    STATE(12149), 1,
      sym__simple_type,
    STATE(12919), 1,
      sym__type,
    STATE(12944), 1,
      sym__tuple_type,
    STATE(17260), 1,
      sym_extended_module_path,
    STATE(19173), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12684), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [416478] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10966), 1,
      anon_sym_PIPE,
    STATE(8591), 1,
      aux_sym__match_cases_repeat1,
    STATE(8674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [416528] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8675), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15258), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [416610] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8676), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16179), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [416692] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8677), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15101), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [416774] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(8678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 3,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8296), 27,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [416822] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10966), 1,
      anon_sym_PIPE,
    STATE(8679), 1,
      sym_attribute,
    STATE(8680), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [416872] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11019), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8680), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [416920] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8681), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14035), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [417002] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10979), 1,
      anon_sym_PIPE,
    STATE(8682), 1,
      sym_attribute,
    STATE(8862), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [417052] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8683), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16048), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [417134] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8684), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15352), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [417216] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8685), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16286), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [417298] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8686), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15896), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [417380] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8687), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15803), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [417462] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10906), 1,
      anon_sym_LPAREN,
    ACTIONS(10910), 1,
      anon_sym_LBRACK,
    ACTIONS(10912), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10914), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10916), 1,
      anon_sym_LT,
    ACTIONS(10918), 1,
      anon_sym_POUND,
    ACTIONS(10920), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10922), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10924), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10972), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8688), 1,
      sym_attribute,
    STATE(8946), 1,
      sym__simple_type,
    STATE(9899), 1,
      sym__tuple_type,
    STATE(10299), 1,
      sym__type,
    STATE(17362), 1,
      sym_extended_module_path,
    STATE(18796), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9114), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [417544] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8689), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16040), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [417626] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10700), 1,
      anon_sym_LPAREN,
    ACTIONS(10704), 1,
      anon_sym_LBRACK,
    ACTIONS(10706), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10708), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10710), 1,
      anon_sym_LT,
    ACTIONS(10712), 1,
      anon_sym_POUND,
    ACTIONS(10714), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10716), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10718), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10977), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8690), 1,
      sym_attribute,
    STATE(8954), 1,
      sym__simple_type,
    STATE(9972), 1,
      sym__tuple_type,
    STATE(10288), 1,
      sym__type,
    STATE(17326), 1,
      sym_extended_module_path,
    STATE(18901), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9339), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [417708] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9424), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9426), 1,
      anon_sym_LT,
    ACTIONS(9428), 1,
      anon_sym_POUND,
    ACTIONS(9430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9434), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10692), 1,
      anon_sym_LPAREN,
    ACTIONS(10696), 1,
      anon_sym_LBRACK,
    ACTIONS(11022), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8691), 1,
      sym_attribute,
    STATE(9482), 1,
      sym__simple_type,
    STATE(10815), 1,
      sym__tuple_type,
    STATE(11082), 1,
      sym__type,
    STATE(16665), 1,
      sym_extended_module_path,
    STATE(20113), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9574), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [417790] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8692), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15408), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [417872] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8693), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8328), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [417918] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9468), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9470), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9472), 1,
      anon_sym_LT,
    ACTIONS(9474), 1,
      anon_sym_POUND,
    ACTIONS(9476), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9478), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9480), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10720), 1,
      anon_sym_LPAREN,
    ACTIONS(10724), 1,
      anon_sym_LBRACK,
    ACTIONS(11015), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8694), 1,
      sym_attribute,
    STATE(9025), 1,
      sym__simple_type,
    STATE(10401), 1,
      sym__tuple_type,
    STATE(10906), 1,
      sym__type,
    STATE(16859), 1,
      sym_extended_module_path,
    STATE(19708), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9377), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [418000] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8695), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15190), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [418082] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9992), 1,
      anon_sym_LPAREN,
    ACTIONS(9994), 1,
      anon_sym_LBRACK,
    ACTIONS(9996), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9998), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10000), 1,
      anon_sym_LT,
    ACTIONS(10002), 1,
      anon_sym_POUND,
    ACTIONS(10004), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10006), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10008), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10962), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8696), 1,
      sym_attribute,
    STATE(11068), 1,
      sym__simple_type,
    STATE(12710), 1,
      sym__tuple_type,
    STATE(12734), 1,
      sym__type,
    STATE(17058), 1,
      sym_extended_module_path,
    STATE(19394), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(11773), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [418164] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8697), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14339), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [418246] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9992), 1,
      anon_sym_LPAREN,
    ACTIONS(9994), 1,
      anon_sym_LBRACK,
    ACTIONS(9996), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9998), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10000), 1,
      anon_sym_LT,
    ACTIONS(10002), 1,
      anon_sym_POUND,
    ACTIONS(10004), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10006), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10008), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10962), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8698), 1,
      sym_attribute,
    STATE(11068), 1,
      sym__simple_type,
    STATE(12710), 1,
      sym__tuple_type,
    STATE(12733), 1,
      sym__type,
    STATE(17058), 1,
      sym_extended_module_path,
    STATE(19394), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(11773), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [418328] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8699), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9766), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9768), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [418374] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8700), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15616), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [418456] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8701), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9102), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9104), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [418502] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9206), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9208), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [418548] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8703), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15666), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [418630] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8704), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15284), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [418712] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8705), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15888), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [418794] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8706), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15867), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [418876] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8707), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9108), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9110), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [418922] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(8708), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 3,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8296), 27,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [418970] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8709), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16272), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [419052] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8710), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15377), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [419134] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(1790), 1,
      sym_add_operator,
    STATE(8711), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [419182] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10989), 1,
      anon_sym_COMMA,
    ACTIONS(10991), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10993), 1,
      sym_pow_operator,
    ACTIONS(10995), 1,
      sym_mult_operator,
    ACTIONS(10997), 1,
      sym_concat_operator,
    ACTIONS(10999), 1,
      sym_rel_operator,
    ACTIONS(11001), 1,
      sym_and_operator,
    ACTIONS(11003), 1,
      sym_or_operator,
    ACTIONS(11005), 1,
      sym_assign_operator,
    ACTIONS(11024), 1,
      anon_sym_SEMI,
    STATE(2294), 1,
      sym_add_operator,
    STATE(8712), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9116), 3,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9114), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [419252] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(10245), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10247), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11028), 1,
      anon_sym_let,
    STATE(8713), 1,
      sym_attribute,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10684), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11026), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [419314] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10966), 1,
      anon_sym_PIPE,
    STATE(8679), 1,
      aux_sym__match_cases_repeat1,
    STATE(8714), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [419364] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8715), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8322), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [419410] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10700), 1,
      anon_sym_LPAREN,
    ACTIONS(10704), 1,
      anon_sym_LBRACK,
    ACTIONS(10706), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10708), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10710), 1,
      anon_sym_LT,
    ACTIONS(10712), 1,
      anon_sym_POUND,
    ACTIONS(10714), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10716), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10718), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10977), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8716), 1,
      sym_attribute,
    STATE(8954), 1,
      sym__simple_type,
    STATE(9972), 1,
      sym__tuple_type,
    STATE(10174), 1,
      sym__type,
    STATE(17326), 1,
      sym_extended_module_path,
    STATE(18901), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9339), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [419492] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8717), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15934), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [419574] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8718), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8318), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [419620] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10730), 1,
      anon_sym_LPAREN,
    ACTIONS(10734), 1,
      anon_sym_LBRACK,
    ACTIONS(10736), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10738), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10740), 1,
      anon_sym_LT,
    ACTIONS(10742), 1,
      anon_sym_POUND,
    ACTIONS(10744), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10746), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10748), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11011), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8719), 1,
      sym_attribute,
    STATE(8988), 1,
      sym__simple_type,
    STATE(10150), 1,
      sym__tuple_type,
    STATE(10412), 1,
      sym__type,
    STATE(17101), 1,
      sym_extended_module_path,
    STATE(19318), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9439), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [419702] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(10245), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10247), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11032), 1,
      anon_sym_let,
    STATE(8720), 1,
      sym_attribute,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10478), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11030), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [419764] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8721), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8314), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [419810] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10774), 1,
      anon_sym_LPAREN,
    ACTIONS(10778), 1,
      anon_sym_LBRACK,
    ACTIONS(10780), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10782), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10784), 1,
      anon_sym_LT,
    ACTIONS(10786), 1,
      anon_sym_POUND,
    ACTIONS(10788), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10790), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10792), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11034), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8722), 1,
      sym_attribute,
    STATE(12898), 1,
      sym__simple_type,
    STATE(13464), 1,
      sym__tuple_type,
    STATE(13523), 1,
      sym__type,
    STATE(17192), 1,
      sym_extended_module_path,
    STATE(19247), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(13156), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [419892] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8723), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16243), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [419974] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8724), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15745), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [420056] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8725), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16369), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [420138] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8350), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8352), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [420184] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8727), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8310), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [420230] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8728), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15404), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [420312] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8729), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15728), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [420394] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8730), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16138), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [420476] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8731), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14341), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [420558] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8732), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16403), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [420640] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8733), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15500), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [420722] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8734), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15654), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [420804] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8735), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16316), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [420886] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8736), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16244), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [420968] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8737), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14205), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [421050] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9992), 1,
      anon_sym_LPAREN,
    ACTIONS(9994), 1,
      anon_sym_LBRACK,
    ACTIONS(9996), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9998), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10000), 1,
      anon_sym_LT,
    ACTIONS(10002), 1,
      anon_sym_POUND,
    ACTIONS(10004), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10006), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10008), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10962), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8738), 1,
      sym_attribute,
    STATE(11068), 1,
      sym__simple_type,
    STATE(12708), 1,
      sym__type,
    STATE(12710), 1,
      sym__tuple_type,
    STATE(17058), 1,
      sym_extended_module_path,
    STATE(19394), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(11773), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [421132] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8739), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16420), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [421214] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8740), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16321), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [421296] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8741), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14292), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [421378] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8742), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16448), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [421460] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8743), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14399), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [421542] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9468), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9470), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9472), 1,
      anon_sym_LT,
    ACTIONS(9474), 1,
      anon_sym_POUND,
    ACTIONS(9476), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9478), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9480), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10720), 1,
      anon_sym_LPAREN,
    ACTIONS(10724), 1,
      anon_sym_LBRACK,
    ACTIONS(11015), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8744), 1,
      sym_attribute,
    STATE(9025), 1,
      sym__simple_type,
    STATE(10401), 1,
      sym__tuple_type,
    STATE(10974), 1,
      sym__type,
    STATE(16859), 1,
      sym_extended_module_path,
    STATE(19708), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9377), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [421624] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8745), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16457), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [421706] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10730), 1,
      anon_sym_LPAREN,
    ACTIONS(10734), 1,
      anon_sym_LBRACK,
    ACTIONS(10736), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10738), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10740), 1,
      anon_sym_LT,
    ACTIONS(10742), 1,
      anon_sym_POUND,
    ACTIONS(10744), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10746), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10748), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11011), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8746), 1,
      sym_attribute,
    STATE(8988), 1,
      sym__simple_type,
    STATE(10150), 1,
      sym__tuple_type,
    STATE(10378), 1,
      sym__type,
    STATE(17101), 1,
      sym_extended_module_path,
    STATE(19318), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9439), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [421788] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8747), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16407), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [421870] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8748), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8304), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8306), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [421916] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8749), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15117), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [421998] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8750), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15138), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [422080] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8751), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16366), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [422162] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8752), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16180), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [422244] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9424), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9426), 1,
      anon_sym_LT,
    ACTIONS(9428), 1,
      anon_sym_POUND,
    ACTIONS(9430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9434), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10692), 1,
      anon_sym_LPAREN,
    ACTIONS(10696), 1,
      anon_sym_LBRACK,
    ACTIONS(11022), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8753), 1,
      sym_attribute,
    STATE(9482), 1,
      sym__simple_type,
    STATE(10815), 1,
      sym__tuple_type,
    STATE(11510), 1,
      sym__type,
    STATE(16665), 1,
      sym_extended_module_path,
    STATE(20113), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9574), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [422326] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8754), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15197), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [422408] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8755), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16148), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [422490] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8756), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8302), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [422536] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9126), 11,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9124), 20,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_with,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [422582] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9598), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9600), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [422628] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8759), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8356), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [422674] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8760), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8264), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [422720] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8761), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15637), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [422802] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8762), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7153), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(7149), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [422848] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8763), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15991), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [422930] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8764), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8360), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [422976] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8765), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15968), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [423058] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8292), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [423104] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8767), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15815), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [423186] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8768), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15786), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [423268] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9116), 11,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9114), 20,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_with,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [423314] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8770), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8288), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [423360] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2294), 1,
      sym_add_operator,
    STATE(8771), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [423408] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8772), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15493), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [423490] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8773), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16218), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [423572] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10134), 1,
      anon_sym_LPAREN,
    ACTIONS(10136), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10140), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10142), 1,
      anon_sym_LT,
    ACTIONS(10144), 1,
      anon_sym_POUND,
    ACTIONS(10146), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10148), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10150), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11036), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8774), 1,
      sym_attribute,
    STATE(10175), 1,
      sym__simple_type,
    STATE(11805), 1,
      sym__tuple_type,
    STATE(12035), 1,
      sym__type,
    STATE(16704), 1,
      sym_extended_module_path,
    STATE(19973), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(10841), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [423654] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8775), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15581), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [423736] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8776), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15859), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [423818] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8777), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9714), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9716), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [423864] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11038), 1,
      anon_sym_DOT_DOT,
    STATE(8778), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5079), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(5077), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [423912] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8779), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9754), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9756), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [423958] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8780), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15561), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [424040] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8781), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15382), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [424122] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9736), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9738), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [424168] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8783), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15336), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [424250] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9992), 1,
      anon_sym_LPAREN,
    ACTIONS(9994), 1,
      anon_sym_LBRACK,
    ACTIONS(9996), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9998), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10000), 1,
      anon_sym_LT,
    ACTIONS(10002), 1,
      anon_sym_POUND,
    ACTIONS(10004), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10006), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10008), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10962), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8784), 1,
      sym_attribute,
    STATE(11068), 1,
      sym__simple_type,
    STATE(12710), 1,
      sym__tuple_type,
    STATE(12828), 1,
      sym__type,
    STATE(17058), 1,
      sym_extended_module_path,
    STATE(19394), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(11773), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [424332] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8785), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16604), 1,
      sym__type,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [424414] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8786), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15544), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [424496] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8787), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 3,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8314), 28,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_of,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [424542] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8788), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15128), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [424624] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8789), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15088), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [424706] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8364), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [424752] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8791), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(13209), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [424834] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10774), 1,
      anon_sym_LPAREN,
    ACTIONS(10778), 1,
      anon_sym_LBRACK,
    ACTIONS(10780), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10782), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10784), 1,
      anon_sym_LT,
    ACTIONS(10786), 1,
      anon_sym_POUND,
    ACTIONS(10788), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10790), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10792), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11034), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8792), 1,
      sym_attribute,
    STATE(12898), 1,
      sym__simple_type,
    STATE(13464), 1,
      sym__tuple_type,
    STATE(13578), 1,
      sym__type,
    STATE(17192), 1,
      sym_extended_module_path,
    STATE(19247), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(13156), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [424916] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8793), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9706), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9708), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [424962] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10991), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10993), 1,
      sym_pow_operator,
    ACTIONS(10995), 1,
      sym_mult_operator,
    ACTIONS(10997), 1,
      sym_concat_operator,
    ACTIONS(10999), 1,
      sym_rel_operator,
    ACTIONS(11001), 1,
      sym_and_operator,
    STATE(2294), 1,
      sym_add_operator,
    STATE(8794), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 5,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10269), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [425024] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10024), 1,
      anon_sym_LPAREN,
    ACTIONS(10026), 1,
      anon_sym_LBRACK,
    ACTIONS(10028), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10030), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10032), 1,
      anon_sym_LT,
    ACTIONS(10034), 1,
      anon_sym_POUND,
    ACTIONS(10036), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10038), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10040), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10968), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8795), 1,
      sym_attribute,
    STATE(12149), 1,
      sym__simple_type,
    STATE(12944), 1,
      sym__tuple_type,
    STATE(13145), 1,
      sym__type,
    STATE(17260), 1,
      sym_extended_module_path,
    STATE(19173), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12684), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [425106] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8796), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15800), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [425188] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8797), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14846), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [425270] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8798), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14845), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [425352] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8799), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8284), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [425398] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9906), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_LBRACK,
    ACTIONS(9910), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9912), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9914), 1,
      anon_sym_LT,
    ACTIONS(9916), 1,
      anon_sym_POUND,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9920), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9922), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11017), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8800), 1,
      sym_attribute,
    STATE(10594), 1,
      sym__simple_type,
    STATE(11981), 1,
      sym__tuple_type,
    STATE(12578), 1,
      sym__type,
    STATE(16934), 1,
      sym_extended_module_path,
    STATE(19479), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(11018), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [425480] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9906), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_LBRACK,
    ACTIONS(9910), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9912), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9914), 1,
      anon_sym_LT,
    ACTIONS(9916), 1,
      anon_sym_POUND,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9920), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9922), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11017), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8801), 1,
      sym_attribute,
    STATE(10594), 1,
      sym__simple_type,
    STATE(11981), 1,
      sym__tuple_type,
    STATE(12577), 1,
      sym__type,
    STATE(16934), 1,
      sym_extended_module_path,
    STATE(19479), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(11018), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [425562] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8802), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16341), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [425644] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8803), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15844), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [425726] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8804), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15921), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [425808] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8805), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8278), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8280), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [425854] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8806), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8274), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8276), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [425900] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10989), 1,
      anon_sym_COMMA,
    ACTIONS(10991), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10993), 1,
      sym_pow_operator,
    ACTIONS(10995), 1,
      sym_mult_operator,
    ACTIONS(10997), 1,
      sym_concat_operator,
    ACTIONS(10999), 1,
      sym_rel_operator,
    ACTIONS(11001), 1,
      sym_and_operator,
    ACTIONS(11003), 1,
      sym_or_operator,
    ACTIONS(11005), 1,
      sym_assign_operator,
    STATE(2294), 1,
      sym_add_operator,
    STATE(8807), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10303), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10301), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [425968] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8808), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15467), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [426050] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8809), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15595), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [426132] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10993), 1,
      sym_pow_operator,
    ACTIONS(10995), 1,
      sym_mult_operator,
    STATE(2294), 1,
      sym_add_operator,
    STATE(8810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 9,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [426184] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8811), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8272), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [426230] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10989), 1,
      anon_sym_COMMA,
    ACTIONS(10991), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10993), 1,
      sym_pow_operator,
    ACTIONS(10995), 1,
      sym_mult_operator,
    ACTIONS(10997), 1,
      sym_concat_operator,
    ACTIONS(10999), 1,
      sym_rel_operator,
    ACTIONS(11001), 1,
      sym_and_operator,
    ACTIONS(11003), 1,
      sym_or_operator,
    ACTIONS(11005), 1,
      sym_assign_operator,
    STATE(2294), 1,
      sym_add_operator,
    STATE(8812), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10269), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [426298] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8813), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9684), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9686), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [426344] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8814), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9680), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9682), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [426390] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8815), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9672), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9674), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [426436] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8816), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15450), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [426518] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8817), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9668), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9670), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [426564] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8818), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16211), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [426646] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9664), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9666), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [426692] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8820), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8268), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [426738] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10134), 1,
      anon_sym_LPAREN,
    ACTIONS(10136), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10140), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10142), 1,
      anon_sym_LT,
    ACTIONS(10144), 1,
      anon_sym_POUND,
    ACTIONS(10146), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10148), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10150), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11036), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8821), 1,
      sym_attribute,
    STATE(10175), 1,
      sym__simple_type,
    STATE(11805), 1,
      sym__tuple_type,
    STATE(12131), 1,
      sym__type,
    STATE(16704), 1,
      sym_extended_module_path,
    STATE(19973), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(10841), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [426820] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8822), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15165), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [426902] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9256), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9258), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [426948] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8824), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15182), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [427030] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8825), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15562), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [427112] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10991), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10993), 1,
      sym_pow_operator,
    ACTIONS(10995), 1,
      sym_mult_operator,
    ACTIONS(10997), 1,
      sym_concat_operator,
    ACTIONS(10999), 1,
      sym_rel_operator,
    ACTIONS(11001), 1,
      sym_and_operator,
    ACTIONS(11003), 1,
      sym_or_operator,
    STATE(2294), 1,
      sym_add_operator,
    STATE(8826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10269), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [427176] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10134), 1,
      anon_sym_LPAREN,
    ACTIONS(10136), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10140), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10142), 1,
      anon_sym_LT,
    ACTIONS(10144), 1,
      anon_sym_POUND,
    ACTIONS(10146), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10148), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10150), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11036), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8827), 1,
      sym_attribute,
    STATE(10175), 1,
      sym__simple_type,
    STATE(11805), 1,
      sym__tuple_type,
    STATE(12133), 1,
      sym__type,
    STATE(16704), 1,
      sym_extended_module_path,
    STATE(19973), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(10841), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [427258] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8828), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16262), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [427340] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10938), 1,
      anon_sym_COMMA,
    ACTIONS(10942), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10944), 1,
      sym_pow_operator,
    ACTIONS(10946), 1,
      sym_mult_operator,
    ACTIONS(10948), 1,
      sym_concat_operator,
    ACTIONS(10950), 1,
      sym_rel_operator,
    ACTIONS(10952), 1,
      sym_and_operator,
    ACTIONS(10954), 1,
      sym_or_operator,
    ACTIONS(10956), 1,
      sym_assign_operator,
    STATE(1790), 1,
      sym_add_operator,
    STATE(8829), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10303), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10301), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [427408] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10944), 1,
      sym_pow_operator,
    ACTIONS(10946), 1,
      sym_mult_operator,
    STATE(1790), 1,
      sym_add_operator,
    STATE(8830), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 9,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [427460] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10938), 1,
      anon_sym_COMMA,
    ACTIONS(10942), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10944), 1,
      sym_pow_operator,
    ACTIONS(10946), 1,
      sym_mult_operator,
    ACTIONS(10948), 1,
      sym_concat_operator,
    ACTIONS(10950), 1,
      sym_rel_operator,
    ACTIONS(10952), 1,
      sym_and_operator,
    ACTIONS(10954), 1,
      sym_or_operator,
    ACTIONS(10956), 1,
      sym_assign_operator,
    STATE(1790), 1,
      sym_add_operator,
    STATE(8831), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10269), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [427528] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10942), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10944), 1,
      sym_pow_operator,
    ACTIONS(10946), 1,
      sym_mult_operator,
    ACTIONS(10948), 1,
      sym_concat_operator,
    ACTIONS(10950), 1,
      sym_rel_operator,
    ACTIONS(10952), 1,
      sym_and_operator,
    ACTIONS(10954), 1,
      sym_or_operator,
    STATE(1790), 1,
      sym_add_operator,
    STATE(8832), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10269), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [427592] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10991), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10993), 1,
      sym_pow_operator,
    ACTIONS(10995), 1,
      sym_mult_operator,
    ACTIONS(10997), 1,
      sym_concat_operator,
    STATE(2294), 1,
      sym_add_operator,
    STATE(8833), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 6,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [427650] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10942), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10944), 1,
      sym_pow_operator,
    ACTIONS(10946), 1,
      sym_mult_operator,
    ACTIONS(10948), 1,
      sym_concat_operator,
    ACTIONS(10950), 1,
      sym_rel_operator,
    ACTIONS(10952), 1,
      sym_and_operator,
    STATE(1790), 1,
      sym_add_operator,
    STATE(8834), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 5,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10269), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [427712] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8835), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15373), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [427794] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10991), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10993), 1,
      sym_pow_operator,
    ACTIONS(10995), 1,
      sym_mult_operator,
    ACTIONS(10997), 1,
      sym_concat_operator,
    STATE(2294), 1,
      sym_add_operator,
    STATE(8836), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 6,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [427852] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10942), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10944), 1,
      sym_pow_operator,
    ACTIONS(10946), 1,
      sym_mult_operator,
    ACTIONS(10948), 1,
      sym_concat_operator,
    STATE(1790), 1,
      sym_add_operator,
    STATE(8837), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 6,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [427910] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8838), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9696), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9698), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [427956] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8839), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9692), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9694), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [428002] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8840), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9688), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9690), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [428048] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9676), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9678), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [428094] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10942), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10944), 1,
      sym_pow_operator,
    ACTIONS(10946), 1,
      sym_mult_operator,
    ACTIONS(10948), 1,
      sym_concat_operator,
    STATE(1790), 1,
      sym_add_operator,
    STATE(8842), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 6,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [428152] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10944), 1,
      sym_pow_operator,
    STATE(1790), 1,
      sym_add_operator,
    STATE(8843), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [428202] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10993), 1,
      sym_pow_operator,
    STATE(2294), 1,
      sym_add_operator,
    STATE(8844), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [428252] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10944), 1,
      sym_pow_operator,
    STATE(1790), 1,
      sym_add_operator,
    STATE(8845), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [428302] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10942), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10944), 1,
      sym_pow_operator,
    ACTIONS(10946), 1,
      sym_mult_operator,
    STATE(1790), 1,
      sym_add_operator,
    STATE(8846), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 6,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [428358] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10993), 1,
      sym_pow_operator,
    STATE(2294), 1,
      sym_add_operator,
    STATE(8847), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [428408] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8848), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16134), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [428490] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10991), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10993), 1,
      sym_pow_operator,
    ACTIONS(10995), 1,
      sym_mult_operator,
    STATE(2294), 1,
      sym_add_operator,
    STATE(8849), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 6,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [428546] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10884), 1,
      anon_sym_LPAREN,
    ACTIONS(10888), 1,
      anon_sym_LBRACK,
    ACTIONS(10890), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10892), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10894), 1,
      anon_sym_LT,
    ACTIONS(10896), 1,
      anon_sym_POUND,
    ACTIONS(10898), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10900), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10902), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10958), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8850), 1,
      sym_attribute,
    STATE(9122), 1,
      sym__simple_type,
    STATE(10431), 1,
      sym__tuple_type,
    STATE(10856), 1,
      sym__type,
    STATE(17294), 1,
      sym_extended_module_path,
    STATE(19017), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9653), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [428628] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8851), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9120), 11,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9118), 20,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_with,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [428674] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10991), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10993), 1,
      sym_pow_operator,
    ACTIONS(10995), 1,
      sym_mult_operator,
    ACTIONS(10997), 1,
      sym_concat_operator,
    ACTIONS(10999), 1,
      sym_rel_operator,
    ACTIONS(11001), 1,
      sym_and_operator,
    ACTIONS(11003), 1,
      sym_or_operator,
    STATE(2294), 1,
      sym_add_operator,
    STATE(8852), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10344), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10342), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [428738] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10942), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10944), 1,
      sym_pow_operator,
    ACTIONS(10946), 1,
      sym_mult_operator,
    ACTIONS(10948), 1,
      sym_concat_operator,
    ACTIONS(10950), 1,
      sym_rel_operator,
    ACTIONS(10952), 1,
      sym_and_operator,
    ACTIONS(10954), 1,
      sym_or_operator,
    STATE(1790), 1,
      sym_add_operator,
    STATE(8853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10344), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10342), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [428802] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8854), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15261), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [428884] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8855), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15356), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [428966] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8856), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9158), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9160), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [429012] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8857), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15194), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [429094] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8858), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15486), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [429176] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8859), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(14198), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [429258] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9992), 1,
      anon_sym_LPAREN,
    ACTIONS(9994), 1,
      anon_sym_LBRACK,
    ACTIONS(9996), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9998), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10000), 1,
      anon_sym_LT,
    ACTIONS(10002), 1,
      anon_sym_POUND,
    ACTIONS(10004), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10006), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10008), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10962), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8860), 1,
      sym_attribute,
    STATE(11068), 1,
      sym__simple_type,
    STATE(12710), 1,
      sym__tuple_type,
    STATE(12830), 1,
      sym__type,
    STATE(17058), 1,
      sym_extended_module_path,
    STATE(19394), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(11773), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [429340] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10979), 1,
      anon_sym_PIPE,
    STATE(8618), 1,
      aux_sym__match_cases_repeat1,
    STATE(8861), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [429390] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10979), 1,
      anon_sym_PIPE,
    STATE(8610), 1,
      aux_sym__match_cases_repeat1,
    STATE(8862), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [429440] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8863), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(16273), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [429522] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10774), 1,
      anon_sym_LPAREN,
    ACTIONS(10778), 1,
      anon_sym_LBRACK,
    ACTIONS(10780), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10782), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10784), 1,
      anon_sym_LT,
    ACTIONS(10786), 1,
      anon_sym_POUND,
    ACTIONS(10788), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10790), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10792), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11034), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8864), 1,
      sym_attribute,
    STATE(12898), 1,
      sym__simple_type,
    STATE(13464), 1,
      sym__tuple_type,
    STATE(13582), 1,
      sym__type,
    STATE(17192), 1,
      sym_extended_module_path,
    STATE(19247), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(13156), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [429604] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9424), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9426), 1,
      anon_sym_LT,
    ACTIONS(9428), 1,
      anon_sym_POUND,
    ACTIONS(9430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9434), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10692), 1,
      anon_sym_LPAREN,
    ACTIONS(10696), 1,
      anon_sym_LBRACK,
    ACTIONS(11022), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8865), 1,
      sym_attribute,
    STATE(9482), 1,
      sym__simple_type,
    STATE(10815), 1,
      sym__tuple_type,
    STATE(11156), 1,
      sym__type,
    STATE(16665), 1,
      sym_extended_module_path,
    STATE(20113), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(9574), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [429686] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8866), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9710), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9712), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [429732] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8867), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9626), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9628), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [429778] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8868), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9622), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9624), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [429824] = 23,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7867), 1,
      anon_sym_QMARK,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9778), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(8869), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(13155), 1,
      sym__tuple_type,
    STATE(15278), 1,
      sym__type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(20444), 1,
      sym_typed_label,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8194), 2,
      sym_function_type,
      sym_aliased_type,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [429906] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9642), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9644), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [429952] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8871), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9634), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9636), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [429998] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8872), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9198), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9200), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430043] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8873), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9228), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9230), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430088] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9140), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9142), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430133] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9590), 1,
      anon_sym_DOT,
    ACTIONS(11040), 1,
      anon_sym_POUND,
    ACTIONS(11042), 1,
      sym_hash_operator,
    STATE(8875), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9724), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9722), 17,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [430184] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9590), 1,
      anon_sym_DOT,
    ACTIONS(11040), 1,
      anon_sym_POUND,
    ACTIONS(11042), 1,
      sym_hash_operator,
    STATE(8876), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9734), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9732), 17,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [430235] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10938), 1,
      anon_sym_COMMA,
    ACTIONS(10942), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10944), 1,
      sym_pow_operator,
    ACTIONS(10946), 1,
      sym_mult_operator,
    ACTIONS(10948), 1,
      sym_concat_operator,
    ACTIONS(10950), 1,
      sym_rel_operator,
    ACTIONS(10952), 1,
      sym_and_operator,
    ACTIONS(10954), 1,
      sym_or_operator,
    ACTIONS(10956), 1,
      sym_assign_operator,
    ACTIONS(11044), 1,
      anon_sym_SEMI,
    STATE(1790), 1,
      sym_add_operator,
    STATE(8877), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9116), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9114), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [430304] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8878), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9132), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9134), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430349] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10989), 1,
      anon_sym_COMMA,
    ACTIONS(10991), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10993), 1,
      sym_pow_operator,
    ACTIONS(10995), 1,
      sym_mult_operator,
    ACTIONS(10997), 1,
      sym_concat_operator,
    ACTIONS(10999), 1,
      sym_rel_operator,
    ACTIONS(11001), 1,
      sym_and_operator,
    ACTIONS(11003), 1,
      sym_or_operator,
    ACTIONS(11005), 1,
      sym_assign_operator,
    ACTIONS(11046), 1,
      anon_sym_SEMI,
    STATE(2294), 1,
      sym_add_operator,
    STATE(8879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9116), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9114), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [430418] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8880), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11050), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11048), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [430463] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8881), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9150), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9152), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430508] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8882), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9162), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9164), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430553] = 21,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11052), 1,
      anon_sym_type,
    ACTIONS(11054), 1,
      anon_sym_exception,
    ACTIONS(11056), 1,
      anon_sym_module,
    ACTIONS(11058), 1,
      anon_sym_include,
    ACTIONS(11060), 1,
      anon_sym_class,
    ACTIONS(11062), 1,
      anon_sym_val,
    ACTIONS(11064), 1,
      anon_sym_end,
    STATE(8883), 1,
      sym_attribute,
    STATE(8953), 1,
      aux_sym__signature_repeat1,
    STATE(8961), 1,
      aux_sym__structure_repeat1,
    STATE(12650), 1,
      sym__signature_item,
    STATE(20463), 1,
      sym__signature,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12649), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [430630] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8884), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9170), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9172), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430675] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8885), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9186), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9188), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430720] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11068), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11066), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [430765] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11072), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11070), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [430810] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8888), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8350), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8352), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430855] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8889), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9158), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9160), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430900] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8890), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9144), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9146), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430945] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8891), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9174), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9176), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430990] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8892), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9240), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9242), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431035] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(10245), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10247), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11076), 1,
      anon_sym_let,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(8893), 1,
      sym_attribute,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10889), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11074), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [431096] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9244), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9246), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431141] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9202), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9204), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431186] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8896), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9256), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9258), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431231] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8897), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5079), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(5077), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431276] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8898), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9136), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9138), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431321] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11080), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11078), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [431366] = 21,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11052), 1,
      anon_sym_type,
    ACTIONS(11054), 1,
      anon_sym_exception,
    ACTIONS(11056), 1,
      anon_sym_module,
    ACTIONS(11058), 1,
      anon_sym_include,
    ACTIONS(11060), 1,
      anon_sym_class,
    ACTIONS(11062), 1,
      anon_sym_val,
    ACTIONS(11082), 1,
      anon_sym_end,
    STATE(8900), 1,
      sym_attribute,
    STATE(8953), 1,
      aux_sym__signature_repeat1,
    STATE(8961), 1,
      aux_sym__structure_repeat1,
    STATE(12650), 1,
      sym__signature_item,
    STATE(20121), 1,
      sym__signature,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12649), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [431443] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8901), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9270), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9272), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431488] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9590), 1,
      anon_sym_DOT,
    ACTIONS(11040), 1,
      anon_sym_POUND,
    ACTIONS(11042), 1,
      sym_hash_operator,
    STATE(8902), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9752), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9750), 17,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [431539] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9590), 1,
      anon_sym_DOT,
    ACTIONS(11040), 1,
      anon_sym_POUND,
    ACTIONS(11042), 1,
      sym_hash_operator,
    STATE(8903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9742), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9740), 17,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [431590] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8904), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11086), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11084), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [431635] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8278), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8280), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431680] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8906), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9274), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9276), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431725] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8907), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8274), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8276), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431770] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11090), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11088), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [431815] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11094), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11092), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [431860] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9278), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9280), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431905] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8911), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8272), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431950] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9248), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9250), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431995] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8913), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9260), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9262), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432040] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8914), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8060), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8062), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432085] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8915), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10985), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10983), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [432130] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8916), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7996), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(7998), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432175] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7757), 1,
      anon_sym_COLON_COLON,
    STATE(8917), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9282), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9284), 19,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432222] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8918), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11098), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11096), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [432267] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(10245), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10247), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11102), 1,
      anon_sym_let,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(8919), 1,
      sym_attribute,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10955), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11100), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [432328] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9236), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9238), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432373] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8268), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432418] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8922), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11106), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11104), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [432463] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8304), 3,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8306), 27,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [432508] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8924), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8356), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432553] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8925), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11110), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11108), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [432598] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11114), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11112), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [432643] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8927), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8360), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432688] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8928), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9206), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9208), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432733] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7751), 1,
      anon_sym_COMMA,
    ACTIONS(7757), 1,
      anon_sym_COLON_COLON,
    STATE(8929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9194), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9196), 18,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432782] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8930), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9190), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9192), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432827] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8931), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9252), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9254), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432872] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8932), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9184), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432917] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(10245), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10247), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11118), 1,
      anon_sym_let,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(8933), 1,
      sym_attribute,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10733), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11116), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [432978] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8934), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9178), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9180), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [433023] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7757), 1,
      anon_sym_COLON_COLON,
    STATE(8935), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9266), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9268), 19,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [433070] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 3,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8328), 27,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [433115] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8937), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9216), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9218), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [433160] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9128), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9130), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [433205] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8939), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8364), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [433250] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8264), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [433295] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8941), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9220), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9222), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [433340] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8942), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9166), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9168), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [433385] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9226), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [433430] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8944), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9154), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9156), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [433475] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8945), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9210), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9212), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [433520] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11120), 1,
      sym__lowercase_identifier,
    ACTIONS(11122), 1,
      anon_sym_POUND,
    STATE(8946), 1,
      sym_attribute,
    STATE(9212), 1,
      sym_type_constructor_path,
    STATE(17230), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10261), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(10263), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [433574] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11120), 1,
      sym__lowercase_identifier,
    ACTIONS(11122), 1,
      anon_sym_POUND,
    STATE(8947), 1,
      sym_attribute,
    STATE(9212), 1,
      sym_type_constructor_path,
    STATE(17230), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11124), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11126), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [433628] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11120), 1,
      sym__lowercase_identifier,
    ACTIONS(11132), 1,
      anon_sym_POUND,
    STATE(8948), 1,
      sym_attribute,
    STATE(9294), 1,
      sym_type_constructor_path,
    STATE(17230), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11128), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11130), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [433682] = 19,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11134), 1,
      ts_builtin_sym_end,
    ACTIONS(11136), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11139), 1,
      anon_sym_external,
    ACTIONS(11142), 1,
      anon_sym_type,
    ACTIONS(11145), 1,
      anon_sym_exception,
    ACTIONS(11148), 1,
      anon_sym_module,
    ACTIONS(11151), 1,
      anon_sym_open,
    ACTIONS(11154), 1,
      anon_sym_include,
    ACTIONS(11157), 1,
      anon_sym_class,
    ACTIONS(11160), 1,
      anon_sym_val,
    ACTIONS(11163), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(11166), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(11169), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    STATE(9258), 1,
      aux_sym__structure_repeat1,
    STATE(12650), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8949), 2,
      sym_attribute,
      aux_sym__signature_repeat1,
    STATE(12649), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [433754] = 19,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11134), 1,
      anon_sym_end,
    ACTIONS(11136), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11139), 1,
      anon_sym_external,
    ACTIONS(11151), 1,
      anon_sym_open,
    ACTIONS(11163), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(11166), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(11169), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11172), 1,
      anon_sym_type,
    ACTIONS(11175), 1,
      anon_sym_exception,
    ACTIONS(11178), 1,
      anon_sym_module,
    ACTIONS(11181), 1,
      anon_sym_include,
    ACTIONS(11184), 1,
      anon_sym_class,
    ACTIONS(11187), 1,
      anon_sym_val,
    STATE(9256), 1,
      aux_sym__structure_repeat1,
    STATE(12650), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8950), 2,
      sym_attribute,
      aux_sym__signature_repeat1,
    STATE(12649), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [433826] = 20,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(13), 1,
      anon_sym_type,
    ACTIONS(17), 1,
      anon_sym_module,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(21), 1,
      anon_sym_include,
    ACTIONS(25), 1,
      anon_sym_val,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11190), 1,
      anon_sym_RBRACK,
    ACTIONS(11192), 1,
      anon_sym_exception,
    ACTIONS(11194), 1,
      anon_sym_class,
    STATE(8951), 1,
      sym_attribute,
    STATE(8955), 1,
      aux_sym__signature_repeat1,
    STATE(8976), 1,
      aux_sym__structure_repeat1,
    STATE(12650), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12649), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [433900] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8952), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9158), 13,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON2,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(9160), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [433944] = 20,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11052), 1,
      anon_sym_type,
    ACTIONS(11054), 1,
      anon_sym_exception,
    ACTIONS(11056), 1,
      anon_sym_module,
    ACTIONS(11058), 1,
      anon_sym_include,
    ACTIONS(11060), 1,
      anon_sym_class,
    ACTIONS(11062), 1,
      anon_sym_val,
    ACTIONS(11190), 1,
      anon_sym_end,
    STATE(8950), 1,
      aux_sym__signature_repeat1,
    STATE(8953), 1,
      sym_attribute,
    STATE(8989), 1,
      aux_sym__structure_repeat1,
    STATE(12650), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12649), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [434018] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11196), 1,
      sym__lowercase_identifier,
    ACTIONS(11198), 1,
      anon_sym_POUND,
    STATE(8954), 1,
      sym_attribute,
    STATE(9174), 1,
      sym_type_constructor_path,
    STATE(17243), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10261), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(10263), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [434072] = 19,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11134), 1,
      anon_sym_RBRACK,
    ACTIONS(11136), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11139), 1,
      anon_sym_external,
    ACTIONS(11142), 1,
      anon_sym_type,
    ACTIONS(11148), 1,
      anon_sym_module,
    ACTIONS(11151), 1,
      anon_sym_open,
    ACTIONS(11154), 1,
      anon_sym_include,
    ACTIONS(11160), 1,
      anon_sym_val,
    ACTIONS(11163), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(11166), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(11169), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11200), 1,
      anon_sym_exception,
    ACTIONS(11203), 1,
      anon_sym_class,
    STATE(9213), 1,
      aux_sym__structure_repeat1,
    STATE(12650), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8955), 2,
      sym_attribute,
      aux_sym__signature_repeat1,
    STATE(12649), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [434144] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11196), 1,
      sym__lowercase_identifier,
    ACTIONS(11198), 1,
      anon_sym_POUND,
    STATE(8956), 1,
      sym_attribute,
    STATE(9174), 1,
      sym_type_constructor_path,
    STATE(17243), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11124), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11126), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [434198] = 20,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(13), 1,
      anon_sym_type,
    ACTIONS(15), 1,
      anon_sym_exception,
    ACTIONS(17), 1,
      anon_sym_module,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(21), 1,
      anon_sym_include,
    ACTIONS(23), 1,
      anon_sym_class,
    ACTIONS(25), 1,
      anon_sym_val,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11190), 1,
      ts_builtin_sym_end,
    STATE(8949), 1,
      aux_sym__signature_repeat1,
    STATE(8957), 1,
      sym_attribute,
    STATE(9003), 1,
      aux_sym__structure_repeat1,
    STATE(12650), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12649), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [434272] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11196), 1,
      sym__lowercase_identifier,
    ACTIONS(11206), 1,
      anon_sym_POUND,
    STATE(8958), 1,
      sym_attribute,
    STATE(9171), 1,
      sym_type_constructor_path,
    STATE(17243), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11128), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11130), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [434326] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9424), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9426), 1,
      anon_sym_LT,
    ACTIONS(9428), 1,
      anon_sym_POUND,
    ACTIONS(9430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9434), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10692), 1,
      anon_sym_LPAREN,
    ACTIONS(10696), 1,
      anon_sym_LBRACK,
    ACTIONS(11208), 1,
      sym__lowercase_identifier,
    STATE(8959), 1,
      sym_attribute,
    STATE(9426), 1,
      sym__simple_type,
    STATE(9721), 1,
      sym_type_variable,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(14504), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16665), 1,
      sym_extended_module_path,
    STATE(19923), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9574), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [434403] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10016), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10018), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11210), 1,
      sym__lowercase_identifier,
    ACTIONS(11212), 1,
      anon_sym_LPAREN,
    ACTIONS(11214), 1,
      anon_sym_LBRACK,
    ACTIONS(11216), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11218), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11220), 1,
      anon_sym_LT,
    ACTIONS(11222), 1,
      anon_sym_POUND,
    ACTIONS(11224), 1,
      aux_sym_type_variable_token1,
    STATE(8960), 1,
      sym_attribute,
    STATE(9957), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10268), 1,
      sym_type_variable,
    STATE(14604), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17224), 1,
      sym_extended_module_path,
    STATE(18864), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10848), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [434480] = 19,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11052), 1,
      anon_sym_type,
    ACTIONS(11054), 1,
      anon_sym_exception,
    ACTIONS(11056), 1,
      anon_sym_module,
    ACTIONS(11058), 1,
      anon_sym_include,
    ACTIONS(11060), 1,
      anon_sym_class,
    ACTIONS(11062), 1,
      anon_sym_val,
    ACTIONS(11190), 1,
      anon_sym_end,
    STATE(8961), 1,
      sym_attribute,
    STATE(12369), 1,
      aux_sym__structure_repeat1,
    STATE(12815), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12649), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [434551] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(11226), 1,
      sym__lowercase_identifier,
    ACTIONS(11228), 1,
      anon_sym_LPAREN,
    ACTIONS(11230), 1,
      anon_sym_LBRACK,
    ACTIONS(11232), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11234), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11236), 1,
      anon_sym_LT,
    ACTIONS(11238), 1,
      anon_sym_POUND,
    ACTIONS(11240), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11242), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11244), 1,
      aux_sym_type_variable_token1,
    STATE(8962), 1,
      sym_attribute,
    STATE(10036), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10226), 1,
      sym_type_variable,
    STATE(14638), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16889), 1,
      sym_extended_module_path,
    STATE(19692), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10886), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [434628] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(11226), 1,
      sym__lowercase_identifier,
    ACTIONS(11228), 1,
      anon_sym_LPAREN,
    ACTIONS(11230), 1,
      anon_sym_LBRACK,
    ACTIONS(11232), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11234), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11236), 1,
      anon_sym_LT,
    ACTIONS(11238), 1,
      anon_sym_POUND,
    ACTIONS(11240), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11242), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11244), 1,
      aux_sym_type_variable_token1,
    STATE(8963), 1,
      sym_attribute,
    STATE(10039), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10226), 1,
      sym_type_variable,
    STATE(14637), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16889), 1,
      sym_extended_module_path,
    STATE(19691), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10886), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [434705] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9500), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9502), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9504), 1,
      anon_sym_LT,
    ACTIONS(9506), 1,
      anon_sym_POUND,
    ACTIONS(9508), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9510), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9512), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10928), 1,
      anon_sym_LPAREN,
    ACTIONS(10932), 1,
      anon_sym_LBRACK,
    ACTIONS(11246), 1,
      sym__lowercase_identifier,
    STATE(8964), 1,
      sym_attribute,
    STATE(9790), 1,
      sym__simple_type,
    STATE(10032), 1,
      sym_type_variable,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(14836), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16914), 1,
      sym_extended_module_path,
    STATE(18992), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10076), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [434782] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(10245), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10247), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11250), 1,
      anon_sym_let,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(8965), 1,
      sym_attribute,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(11450), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11248), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [434841] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9406), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10680), 1,
      anon_sym_LPAREN,
    ACTIONS(10684), 1,
      anon_sym_LBRACK,
    ACTIONS(11252), 1,
      sym__lowercase_identifier,
    STATE(8966), 1,
      sym_attribute,
    STATE(9140), 1,
      sym__simple_type,
    STATE(9410), 1,
      sym_type_variable,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(14477), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16745), 1,
      sym_extended_module_path,
    STATE(19366), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9437), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [434918] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11254), 1,
      sym__lowercase_identifier,
    ACTIONS(11256), 1,
      anon_sym_POUND,
    STATE(8967), 1,
      sym_attribute,
    STATE(9470), 1,
      sym_type_constructor_path,
    STATE(17458), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11128), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11130), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [434971] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9500), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9502), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9504), 1,
      anon_sym_LT,
    ACTIONS(9506), 1,
      anon_sym_POUND,
    ACTIONS(9508), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9510), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9512), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10928), 1,
      anon_sym_LPAREN,
    ACTIONS(10932), 1,
      anon_sym_LBRACK,
    ACTIONS(11246), 1,
      sym__lowercase_identifier,
    STATE(8968), 1,
      sym_attribute,
    STATE(9793), 1,
      sym__simple_type,
    STATE(10032), 1,
      sym_type_variable,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(14838), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16914), 1,
      sym_extended_module_path,
    STATE(18997), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10076), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [435048] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11260), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11262), 2,
      anon_sym_LPAREN,
      anon_sym_DOT,
    ACTIONS(11258), 24,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [435093] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11264), 1,
      anon_sym_COLON2,
    STATE(8970), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9158), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [435138] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(10245), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10247), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11268), 1,
      anon_sym_let,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(8971), 1,
      sym_attribute,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(11573), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11266), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [435197] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(11276), 1,
      anon_sym_DOT,
    STATE(8972), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11272), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11270), 24,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [435244] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(11278), 1,
      sym__lowercase_identifier,
    ACTIONS(11280), 1,
      anon_sym_LPAREN,
    ACTIONS(11282), 1,
      anon_sym_LBRACK,
    ACTIONS(11284), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11286), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11288), 1,
      anon_sym_LT,
    ACTIONS(11290), 1,
      anon_sym_POUND,
    ACTIONS(11292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11296), 1,
      aux_sym_type_variable_token1,
    STATE(8973), 1,
      sym_attribute,
    STATE(10014), 1,
      sym__simple_type,
    STATE(10194), 1,
      sym_type_variable,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(15018), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16787), 1,
      sym_extended_module_path,
    STATE(20070), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10877), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [435321] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10070), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10072), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11298), 1,
      sym__lowercase_identifier,
    ACTIONS(11300), 1,
      anon_sym_LPAREN,
    ACTIONS(11302), 1,
      anon_sym_LBRACK,
    ACTIONS(11304), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11306), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11308), 1,
      anon_sym_LT,
    ACTIONS(11310), 1,
      anon_sym_POUND,
    ACTIONS(11312), 1,
      aux_sym_type_variable_token1,
    STATE(8974), 1,
      sym_attribute,
    STATE(9467), 1,
      sym__simple_type,
    STATE(9768), 1,
      sym_type_variable,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(14549), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17129), 1,
      sym_extended_module_path,
    STATE(19294), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10286), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [435398] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9500), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9502), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9504), 1,
      anon_sym_LT,
    ACTIONS(9506), 1,
      anon_sym_POUND,
    ACTIONS(9508), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9510), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9512), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10928), 1,
      anon_sym_LPAREN,
    ACTIONS(10932), 1,
      anon_sym_LBRACK,
    ACTIONS(11246), 1,
      sym__lowercase_identifier,
    STATE(8975), 1,
      sym_attribute,
    STATE(9693), 1,
      sym__simple_type,
    STATE(10032), 1,
      sym_type_variable,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(14788), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16914), 1,
      sym_extended_module_path,
    STATE(18966), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10076), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [435475] = 19,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(13), 1,
      anon_sym_type,
    ACTIONS(17), 1,
      anon_sym_module,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(21), 1,
      anon_sym_include,
    ACTIONS(25), 1,
      anon_sym_val,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11192), 1,
      anon_sym_exception,
    ACTIONS(11194), 1,
      anon_sym_class,
    ACTIONS(11314), 1,
      anon_sym_RBRACK,
    STATE(8976), 1,
      sym_attribute,
    STATE(12369), 1,
      aux_sym__structure_repeat1,
    STATE(12815), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12649), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [435546] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10134), 1,
      anon_sym_LPAREN,
    ACTIONS(10136), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10140), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10142), 1,
      anon_sym_LT,
    ACTIONS(10144), 1,
      anon_sym_POUND,
    ACTIONS(10146), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10148), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10150), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11316), 1,
      sym__lowercase_identifier,
    STATE(8977), 1,
      sym_attribute,
    STATE(10203), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10302), 1,
      sym_type_variable,
    STATE(14955), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16704), 1,
      sym_extended_module_path,
    STATE(20418), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10841), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [435623] = 19,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(13), 1,
      anon_sym_type,
    ACTIONS(17), 1,
      anon_sym_module,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(21), 1,
      anon_sym_include,
    ACTIONS(25), 1,
      anon_sym_val,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11190), 1,
      anon_sym_RBRACK,
    ACTIONS(11192), 1,
      anon_sym_exception,
    ACTIONS(11194), 1,
      anon_sym_class,
    STATE(8978), 1,
      sym_attribute,
    STATE(12369), 1,
      aux_sym__structure_repeat1,
    STATE(12815), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12649), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [435694] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10134), 1,
      anon_sym_LPAREN,
    ACTIONS(10136), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10140), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10142), 1,
      anon_sym_LT,
    ACTIONS(10144), 1,
      anon_sym_POUND,
    ACTIONS(10146), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10148), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10150), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11316), 1,
      sym__lowercase_identifier,
    STATE(8979), 1,
      sym_attribute,
    STATE(10192), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10302), 1,
      sym_type_variable,
    STATE(14966), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16704), 1,
      sym_extended_module_path,
    STATE(20417), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10841), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [435771] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9424), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9426), 1,
      anon_sym_LT,
    ACTIONS(9428), 1,
      anon_sym_POUND,
    ACTIONS(9430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9434), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10692), 1,
      anon_sym_LPAREN,
    ACTIONS(10696), 1,
      anon_sym_LBRACK,
    ACTIONS(11208), 1,
      sym__lowercase_identifier,
    STATE(8980), 1,
      sym_attribute,
    STATE(9397), 1,
      sym__simple_type,
    STATE(9721), 1,
      sym_type_variable,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(14498), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16665), 1,
      sym_extended_module_path,
    STATE(19956), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9574), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [435848] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9906), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_LBRACK,
    ACTIONS(9910), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9912), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9914), 1,
      anon_sym_LT,
    ACTIONS(9916), 1,
      anon_sym_POUND,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9920), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9922), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11318), 1,
      sym__lowercase_identifier,
    STATE(8981), 1,
      sym_attribute,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10583), 1,
      sym_type_variable,
    STATE(10628), 1,
      sym__simple_type,
    STATE(15041), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16934), 1,
      sym_extended_module_path,
    STATE(19570), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11018), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [435925] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11264), 1,
      anon_sym_COLON2,
    STATE(8982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9158), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [435970] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(11320), 1,
      sym__lowercase_identifier,
    ACTIONS(11322), 1,
      anon_sym_LPAREN,
    ACTIONS(11324), 1,
      anon_sym_LBRACK,
    ACTIONS(11326), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11328), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11330), 1,
      anon_sym_LT,
    ACTIONS(11332), 1,
      anon_sym_POUND,
    ACTIONS(11334), 1,
      aux_sym_type_variable_token1,
    STATE(8983), 1,
      sym_attribute,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(13234), 1,
      sym__simple_type,
    STATE(13333), 1,
      sym_type_variable,
    STATE(14923), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16970), 1,
      sym_extended_module_path,
    STATE(19467), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13564), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [436047] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8984), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11338), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11336), 26,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [436090] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(11320), 1,
      sym__lowercase_identifier,
    ACTIONS(11322), 1,
      anon_sym_LPAREN,
    ACTIONS(11324), 1,
      anon_sym_LBRACK,
    ACTIONS(11326), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11328), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11330), 1,
      anon_sym_LT,
    ACTIONS(11332), 1,
      anon_sym_POUND,
    ACTIONS(11334), 1,
      aux_sym_type_variable_token1,
    STATE(8985), 1,
      sym_attribute,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(13235), 1,
      sym__simple_type,
    STATE(13333), 1,
      sym_type_variable,
    STATE(14981), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16970), 1,
      sym_extended_module_path,
    STATE(19466), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13564), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [436167] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9906), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_LBRACK,
    ACTIONS(9910), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9912), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9914), 1,
      anon_sym_LT,
    ACTIONS(9916), 1,
      anon_sym_POUND,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9920), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9922), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11318), 1,
      sym__lowercase_identifier,
    STATE(8986), 1,
      sym_attribute,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10583), 1,
      sym_type_variable,
    STATE(10629), 1,
      sym__simple_type,
    STATE(15034), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16934), 1,
      sym_extended_module_path,
    STATE(19569), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11018), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [436244] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9468), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9470), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9472), 1,
      anon_sym_LT,
    ACTIONS(9474), 1,
      anon_sym_POUND,
    ACTIONS(9476), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9478), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9480), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10720), 1,
      anon_sym_LPAREN,
    ACTIONS(10724), 1,
      anon_sym_LBRACK,
    ACTIONS(11340), 1,
      sym__lowercase_identifier,
    STATE(8987), 1,
      sym_attribute,
    STATE(9288), 1,
      sym__simple_type,
    STATE(9349), 1,
      sym_type_variable,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(14815), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16859), 1,
      sym_extended_module_path,
    STATE(19224), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9377), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [436321] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11342), 1,
      sym__lowercase_identifier,
    ACTIONS(11344), 1,
      anon_sym_POUND,
    STATE(8988), 1,
      sym_attribute,
    STATE(9415), 1,
      sym_type_constructor_path,
    STATE(17359), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10261), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(10263), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [436374] = 19,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11052), 1,
      anon_sym_type,
    ACTIONS(11054), 1,
      anon_sym_exception,
    ACTIONS(11056), 1,
      anon_sym_module,
    ACTIONS(11058), 1,
      anon_sym_include,
    ACTIONS(11060), 1,
      anon_sym_class,
    ACTIONS(11062), 1,
      anon_sym_val,
    ACTIONS(11314), 1,
      anon_sym_end,
    STATE(8989), 1,
      sym_attribute,
    STATE(12369), 1,
      aux_sym__structure_repeat1,
    STATE(12815), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12649), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [436445] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11346), 1,
      sym__lowercase_identifier,
    ACTIONS(11348), 1,
      anon_sym_POUND,
    STATE(8990), 1,
      sym_attribute,
    STATE(9364), 1,
      sym_type_constructor_path,
    STATE(17537), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11128), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11130), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [436498] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9468), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9470), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9472), 1,
      anon_sym_LT,
    ACTIONS(9474), 1,
      anon_sym_POUND,
    ACTIONS(9476), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9478), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9480), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10720), 1,
      anon_sym_LPAREN,
    ACTIONS(10724), 1,
      anon_sym_LBRACK,
    ACTIONS(11340), 1,
      sym__lowercase_identifier,
    STATE(8991), 1,
      sym_attribute,
    STATE(9054), 1,
      sym__simple_type,
    STATE(9349), 1,
      sym_type_variable,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(14722), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16859), 1,
      sym_extended_module_path,
    STATE(19235), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9377), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [436575] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11342), 1,
      sym__lowercase_identifier,
    ACTIONS(11350), 1,
      anon_sym_POUND,
    STATE(8992), 1,
      sym_attribute,
    STATE(9367), 1,
      sym_type_constructor_path,
    STATE(17359), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11128), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11130), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [436628] = 19,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(13), 1,
      anon_sym_type,
    ACTIONS(15), 1,
      anon_sym_exception,
    ACTIONS(17), 1,
      anon_sym_module,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(21), 1,
      anon_sym_include,
    ACTIONS(23), 1,
      anon_sym_class,
    ACTIONS(25), 1,
      anon_sym_val,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11190), 1,
      ts_builtin_sym_end,
    STATE(8993), 1,
      sym_attribute,
    STATE(12369), 1,
      aux_sym__structure_repeat1,
    STATE(12815), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12649), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [436699] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9406), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10680), 1,
      anon_sym_LPAREN,
    ACTIONS(10684), 1,
      anon_sym_LBRACK,
    ACTIONS(11252), 1,
      sym__lowercase_identifier,
    STATE(8994), 1,
      sym_attribute,
    STATE(9208), 1,
      sym__simple_type,
    STATE(9410), 1,
      sym_type_variable,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(14525), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16745), 1,
      sym_extended_module_path,
    STATE(19382), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9437), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [436776] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10070), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10072), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11298), 1,
      sym__lowercase_identifier,
    ACTIONS(11300), 1,
      anon_sym_LPAREN,
    ACTIONS(11302), 1,
      anon_sym_LBRACK,
    ACTIONS(11304), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11306), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11308), 1,
      anon_sym_LT,
    ACTIONS(11310), 1,
      anon_sym_POUND,
    ACTIONS(11312), 1,
      aux_sym_type_variable_token1,
    STATE(8995), 1,
      sym_attribute,
    STATE(9393), 1,
      sym__simple_type,
    STATE(9768), 1,
      sym_type_variable,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(14511), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17129), 1,
      sym_extended_module_path,
    STATE(19307), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10286), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [436853] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9406), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10680), 1,
      anon_sym_LPAREN,
    ACTIONS(10684), 1,
      anon_sym_LBRACK,
    ACTIONS(11252), 1,
      sym__lowercase_identifier,
    STATE(8996), 1,
      sym_attribute,
    STATE(9111), 1,
      sym__simple_type,
    STATE(9410), 1,
      sym_type_variable,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(14526), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16745), 1,
      sym_extended_module_path,
    STATE(19383), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9437), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [436930] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9964), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11352), 1,
      sym__lowercase_identifier,
    ACTIONS(11354), 1,
      anon_sym_LPAREN,
    ACTIONS(11356), 1,
      anon_sym_LBRACK,
    ACTIONS(11358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11362), 1,
      anon_sym_LT,
    ACTIONS(11364), 1,
      anon_sym_POUND,
    ACTIONS(11366), 1,
      aux_sym_type_variable_token1,
    STATE(8997), 1,
      sym_attribute,
    STATE(9405), 1,
      sym__simple_type,
    STATE(9783), 1,
      sym_type_variable,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(14906), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17160), 1,
      sym_extended_module_path,
    STATE(19157), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10274), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [437007] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9900), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9902), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11368), 1,
      sym__lowercase_identifier,
    ACTIONS(11370), 1,
      anon_sym_LPAREN,
    ACTIONS(11372), 1,
      anon_sym_LBRACK,
    ACTIONS(11374), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11376), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11378), 1,
      anon_sym_LT,
    ACTIONS(11380), 1,
      anon_sym_POUND,
    ACTIONS(11382), 1,
      aux_sym_type_variable_token1,
    STATE(8998), 1,
      sym_attribute,
    STATE(9547), 1,
      sym__simple_type,
    STATE(10024), 1,
      sym_type_variable,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(14989), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16829), 1,
      sym_extended_module_path,
    STATE(19802), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10613), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [437084] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(11226), 1,
      sym__lowercase_identifier,
    ACTIONS(11228), 1,
      anon_sym_LPAREN,
    ACTIONS(11230), 1,
      anon_sym_LBRACK,
    ACTIONS(11232), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11234), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11236), 1,
      anon_sym_LT,
    ACTIONS(11238), 1,
      anon_sym_POUND,
    ACTIONS(11240), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11242), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11244), 1,
      aux_sym_type_variable_token1,
    STATE(8999), 1,
      sym_attribute,
    STATE(10064), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10226), 1,
      sym_type_variable,
    STATE(14564), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16889), 1,
      sym_extended_module_path,
    STATE(19673), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10886), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [437161] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10070), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10072), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11298), 1,
      sym__lowercase_identifier,
    ACTIONS(11300), 1,
      anon_sym_LPAREN,
    ACTIONS(11302), 1,
      anon_sym_LBRACK,
    ACTIONS(11304), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11306), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11308), 1,
      anon_sym_LT,
    ACTIONS(11310), 1,
      anon_sym_POUND,
    ACTIONS(11312), 1,
      aux_sym_type_variable_token1,
    STATE(9000), 1,
      sym_attribute,
    STATE(9396), 1,
      sym__simple_type,
    STATE(9768), 1,
      sym_type_variable,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(14509), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17129), 1,
      sym_extended_module_path,
    STATE(19308), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10286), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [437238] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9964), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11352), 1,
      sym__lowercase_identifier,
    ACTIONS(11354), 1,
      anon_sym_LPAREN,
    ACTIONS(11356), 1,
      anon_sym_LBRACK,
    ACTIONS(11358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11362), 1,
      anon_sym_LT,
    ACTIONS(11364), 1,
      anon_sym_POUND,
    ACTIONS(11366), 1,
      aux_sym_type_variable_token1,
    STATE(9001), 1,
      sym_attribute,
    STATE(9449), 1,
      sym__simple_type,
    STATE(9783), 1,
      sym_type_variable,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(14902), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17160), 1,
      sym_extended_module_path,
    STATE(19158), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10274), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [437315] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10134), 1,
      anon_sym_LPAREN,
    ACTIONS(10136), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10140), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10142), 1,
      anon_sym_LT,
    ACTIONS(10144), 1,
      anon_sym_POUND,
    ACTIONS(10146), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10148), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10150), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11316), 1,
      sym__lowercase_identifier,
    STATE(9002), 1,
      sym_attribute,
    STATE(10113), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10302), 1,
      sym_type_variable,
    STATE(14625), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16704), 1,
      sym_extended_module_path,
    STATE(20308), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10841), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [437392] = 19,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(13), 1,
      anon_sym_type,
    ACTIONS(15), 1,
      anon_sym_exception,
    ACTIONS(17), 1,
      anon_sym_module,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(21), 1,
      anon_sym_include,
    ACTIONS(23), 1,
      anon_sym_class,
    ACTIONS(25), 1,
      anon_sym_val,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11314), 1,
      ts_builtin_sym_end,
    STATE(9003), 1,
      sym_attribute,
    STATE(12369), 1,
      aux_sym__structure_repeat1,
    STATE(12815), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12649), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [437463] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9004), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11386), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11384), 26,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [437506] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(11278), 1,
      sym__lowercase_identifier,
    ACTIONS(11280), 1,
      anon_sym_LPAREN,
    ACTIONS(11282), 1,
      anon_sym_LBRACK,
    ACTIONS(11284), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11286), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11288), 1,
      anon_sym_LT,
    ACTIONS(11290), 1,
      anon_sym_POUND,
    ACTIONS(11292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11296), 1,
      aux_sym_type_variable_token1,
    STATE(9005), 1,
      sym_attribute,
    STATE(10052), 1,
      sym__simple_type,
    STATE(10194), 1,
      sym_type_variable,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(14984), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16787), 1,
      sym_extended_module_path,
    STATE(20093), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10877), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [437583] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10016), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10018), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11210), 1,
      sym__lowercase_identifier,
    ACTIONS(11212), 1,
      anon_sym_LPAREN,
    ACTIONS(11214), 1,
      anon_sym_LBRACK,
    ACTIONS(11216), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11218), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11220), 1,
      anon_sym_LT,
    ACTIONS(11222), 1,
      anon_sym_POUND,
    ACTIONS(11224), 1,
      aux_sym_type_variable_token1,
    STATE(9006), 1,
      sym_attribute,
    STATE(10021), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10268), 1,
      sym_type_variable,
    STATE(14427), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17224), 1,
      sym_extended_module_path,
    STATE(18879), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10848), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [437660] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9007), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11384), 2,
      anon_sym_LPAREN,
      anon_sym_DOT,
    ACTIONS(11390), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11388), 24,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [437705] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(11278), 1,
      sym__lowercase_identifier,
    ACTIONS(11280), 1,
      anon_sym_LPAREN,
    ACTIONS(11282), 1,
      anon_sym_LBRACK,
    ACTIONS(11284), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11286), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11288), 1,
      anon_sym_LT,
    ACTIONS(11290), 1,
      anon_sym_POUND,
    ACTIONS(11292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11296), 1,
      aux_sym_type_variable_token1,
    STATE(9008), 1,
      sym_attribute,
    STATE(9877), 1,
      sym__simple_type,
    STATE(10194), 1,
      sym_type_variable,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(14983), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16787), 1,
      sym_extended_module_path,
    STATE(20097), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10877), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [437782] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10016), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10018), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11210), 1,
      sym__lowercase_identifier,
    ACTIONS(11212), 1,
      anon_sym_LPAREN,
    ACTIONS(11214), 1,
      anon_sym_LBRACK,
    ACTIONS(11216), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11218), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11220), 1,
      anon_sym_LT,
    ACTIONS(11222), 1,
      anon_sym_POUND,
    ACTIONS(11224), 1,
      aux_sym_type_variable_token1,
    STATE(9009), 1,
      sym_attribute,
    STATE(10023), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10268), 1,
      sym_type_variable,
    STATE(14424), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17224), 1,
      sym_extended_module_path,
    STATE(18880), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10848), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [437859] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9906), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_LBRACK,
    ACTIONS(9910), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9912), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9914), 1,
      anon_sym_LT,
    ACTIONS(9916), 1,
      anon_sym_POUND,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9920), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9922), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11318), 1,
      sym__lowercase_identifier,
    STATE(9010), 1,
      sym_attribute,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10583), 1,
      sym_type_variable,
    STATE(10665), 1,
      sym__simple_type,
    STATE(14595), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16934), 1,
      sym_extended_module_path,
    STATE(19494), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11018), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [437936] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9011), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11392), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11262), 26,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [437979] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9012), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11007), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
    ACTIONS(11009), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [438022] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9013), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11007), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
    ACTIONS(11009), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [438065] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11342), 1,
      sym__lowercase_identifier,
    ACTIONS(11344), 1,
      anon_sym_POUND,
    STATE(9014), 1,
      sym_attribute,
    STATE(9415), 1,
      sym_type_constructor_path,
    STATE(17359), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11124), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11126), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [438118] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9900), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9902), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11368), 1,
      sym__lowercase_identifier,
    ACTIONS(11370), 1,
      anon_sym_LPAREN,
    ACTIONS(11372), 1,
      anon_sym_LBRACK,
    ACTIONS(11374), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11376), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11378), 1,
      anon_sym_LT,
    ACTIONS(11380), 1,
      anon_sym_POUND,
    ACTIONS(11382), 1,
      aux_sym_type_variable_token1,
    STATE(9015), 1,
      sym_attribute,
    STATE(9699), 1,
      sym__simple_type,
    STATE(10024), 1,
      sym_type_variable,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(15067), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16829), 1,
      sym_extended_module_path,
    STATE(19829), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10613), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [438195] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9900), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9902), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11368), 1,
      sym__lowercase_identifier,
    ACTIONS(11370), 1,
      anon_sym_LPAREN,
    ACTIONS(11372), 1,
      anon_sym_LBRACK,
    ACTIONS(11374), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11376), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11378), 1,
      anon_sym_LT,
    ACTIONS(11380), 1,
      anon_sym_POUND,
    ACTIONS(11382), 1,
      aux_sym_type_variable_token1,
    STATE(9016), 1,
      sym_attribute,
    STATE(9701), 1,
      sym__simple_type,
    STATE(10024), 1,
      sym_type_variable,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(15053), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16829), 1,
      sym_extended_module_path,
    STATE(19830), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10613), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [438272] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9468), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9470), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9472), 1,
      anon_sym_LT,
    ACTIONS(9474), 1,
      anon_sym_POUND,
    ACTIONS(9476), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9478), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9480), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10720), 1,
      anon_sym_LPAREN,
    ACTIONS(10724), 1,
      anon_sym_LBRACK,
    ACTIONS(11340), 1,
      sym__lowercase_identifier,
    STATE(9017), 1,
      sym_attribute,
    STATE(9052), 1,
      sym__simple_type,
    STATE(9349), 1,
      sym_type_variable,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(14721), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16859), 1,
      sym_extended_module_path,
    STATE(19236), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9377), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [438349] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(11320), 1,
      sym__lowercase_identifier,
    ACTIONS(11322), 1,
      anon_sym_LPAREN,
    ACTIONS(11324), 1,
      anon_sym_LBRACK,
    ACTIONS(11326), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11328), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11330), 1,
      anon_sym_LT,
    ACTIONS(11332), 1,
      anon_sym_POUND,
    ACTIONS(11334), 1,
      aux_sym_type_variable_token1,
    STATE(9018), 1,
      sym_attribute,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(13194), 1,
      sym__simple_type,
    STATE(13333), 1,
      sym_type_variable,
    STATE(14811), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16970), 1,
      sym_extended_module_path,
    STATE(19448), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13564), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [438426] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9964), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11352), 1,
      sym__lowercase_identifier,
    ACTIONS(11354), 1,
      anon_sym_LPAREN,
    ACTIONS(11356), 1,
      anon_sym_LBRACK,
    ACTIONS(11358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11362), 1,
      anon_sym_LT,
    ACTIONS(11364), 1,
      anon_sym_POUND,
    ACTIONS(11366), 1,
      aux_sym_type_variable_token1,
    STATE(9019), 1,
      sym_attribute,
    STATE(9354), 1,
      sym__simple_type,
    STATE(9783), 1,
      sym_type_variable,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(14965), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17160), 1,
      sym_extended_module_path,
    STATE(19140), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10274), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [438503] = 22,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9424), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9426), 1,
      anon_sym_LT,
    ACTIONS(9428), 1,
      anon_sym_POUND,
    ACTIONS(9430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9434), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10692), 1,
      anon_sym_LPAREN,
    ACTIONS(10696), 1,
      anon_sym_LBRACK,
    ACTIONS(11208), 1,
      sym__lowercase_identifier,
    STATE(9020), 1,
      sym_attribute,
    STATE(9343), 1,
      sym__simple_type,
    STATE(9721), 1,
      sym_type_variable,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(14461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16665), 1,
      sym_extended_module_path,
    STATE(19935), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9574), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [438580] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(11278), 1,
      sym__lowercase_identifier,
    ACTIONS(11280), 1,
      anon_sym_LPAREN,
    ACTIONS(11282), 1,
      anon_sym_LBRACK,
    ACTIONS(11284), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11286), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11288), 1,
      anon_sym_LT,
    ACTIONS(11290), 1,
      anon_sym_POUND,
    ACTIONS(11292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11296), 1,
      aux_sym_type_variable_token1,
    STATE(9021), 1,
      sym_attribute,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10346), 1,
      sym__simple_type,
    STATE(10496), 1,
      sym__constructor_argument,
    STATE(16787), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10877), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [438652] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9406), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10680), 1,
      anon_sym_LPAREN,
    ACTIONS(10684), 1,
      anon_sym_LBRACK,
    ACTIONS(11252), 1,
      sym__lowercase_identifier,
    STATE(9022), 1,
      sym_attribute,
    STATE(9161), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(16745), 1,
      sym_extended_module_path,
    STATE(19353), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9437), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [438724] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10134), 1,
      anon_sym_LPAREN,
    ACTIONS(10136), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10140), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10142), 1,
      anon_sym_LT,
    ACTIONS(10144), 1,
      anon_sym_POUND,
    ACTIONS(10146), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10148), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10150), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11316), 1,
      sym__lowercase_identifier,
    STATE(9023), 1,
      sym_attribute,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10347), 1,
      sym__simple_type,
    STATE(16704), 1,
      sym_extended_module_path,
    STATE(20223), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10841), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [438796] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11396), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11398), 1,
      anon_sym_GT,
    STATE(9024), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [438868] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11254), 1,
      sym__lowercase_identifier,
    ACTIONS(11400), 1,
      anon_sym_POUND,
    STATE(9025), 1,
      sym_attribute,
    STATE(9379), 1,
      sym_type_constructor_path,
    STATE(17458), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10261), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(10263), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [438920] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10016), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10018), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11210), 1,
      sym__lowercase_identifier,
    ACTIONS(11212), 1,
      anon_sym_LPAREN,
    ACTIONS(11214), 1,
      anon_sym_LBRACK,
    ACTIONS(11216), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11218), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11220), 1,
      anon_sym_LT,
    ACTIONS(11222), 1,
      anon_sym_POUND,
    ACTIONS(11224), 1,
      aux_sym_type_variable_token1,
    STATE(9026), 1,
      sym_attribute,
    STATE(10207), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10473), 1,
      sym__constructor_argument,
    STATE(17224), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10848), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [438992] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10070), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10072), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11298), 1,
      sym__lowercase_identifier,
    ACTIONS(11300), 1,
      anon_sym_LPAREN,
    ACTIONS(11302), 1,
      anon_sym_LBRACK,
    ACTIONS(11304), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11306), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11308), 1,
      anon_sym_LT,
    ACTIONS(11310), 1,
      anon_sym_POUND,
    ACTIONS(11312), 1,
      aux_sym_type_variable_token1,
    STATE(9027), 1,
      sym_attribute,
    STATE(9443), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(17129), 1,
      sym_extended_module_path,
    STATE(19244), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10286), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [439064] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11402), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11404), 1,
      anon_sym_GT,
    STATE(9028), 1,
      sym_attribute,
    STATE(13456), 1,
      sym__simple_type,
    STATE(16445), 1,
      sym_method_type,
    STATE(16552), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [439136] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11406), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11408), 1,
      anon_sym_GT,
    STATE(9029), 1,
      sym_attribute,
    STATE(13432), 1,
      sym__simple_type,
    STATE(16360), 1,
      sym_method_type,
    STATE(16552), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [439208] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10016), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10018), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11210), 1,
      sym__lowercase_identifier,
    ACTIONS(11212), 1,
      anon_sym_LPAREN,
    ACTIONS(11214), 1,
      anon_sym_LBRACK,
    ACTIONS(11216), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11218), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11220), 1,
      anon_sym_LT,
    ACTIONS(11222), 1,
      anon_sym_POUND,
    ACTIONS(11224), 1,
      aux_sym_type_variable_token1,
    STATE(9030), 1,
      sym_attribute,
    STATE(10207), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10496), 1,
      sym__constructor_argument,
    STATE(17224), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10848), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [439280] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11410), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11412), 1,
      anon_sym_GT,
    STATE(9031), 1,
      sym_attribute,
    STATE(13465), 1,
      sym__simple_type,
    STATE(16302), 1,
      sym_method_type,
    STATE(16552), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [439352] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8056), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8058), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [439394] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9033), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8116), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8118), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [439436] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9034), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11416), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11414), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [439478] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9035), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11009), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11007), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
  [439520] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11418), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11420), 1,
      anon_sym_GT,
    STATE(9036), 1,
      sym_attribute,
    STATE(13442), 1,
      sym__simple_type,
    STATE(15473), 1,
      sym_method_type,
    STATE(16552), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [439592] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11422), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11424), 1,
      anon_sym_GT,
    STATE(9037), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [439664] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11428), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11426), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [439706] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9039), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8322), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [439748] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7925), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(7927), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [439790] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(11320), 1,
      sym__lowercase_identifier,
    ACTIONS(11322), 1,
      anon_sym_LPAREN,
    ACTIONS(11324), 1,
      anon_sym_LBRACK,
    ACTIONS(11326), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11328), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11330), 1,
      anon_sym_LT,
    ACTIONS(11332), 1,
      anon_sym_POUND,
    ACTIONS(11334), 1,
      aux_sym_type_variable_token1,
    STATE(9041), 1,
      sym_attribute,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(13201), 1,
      sym__simple_type,
    STATE(16970), 1,
      sym_extended_module_path,
    STATE(19434), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13564), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [439862] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9468), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9470), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9472), 1,
      anon_sym_LT,
    ACTIONS(9474), 1,
      anon_sym_POUND,
    ACTIONS(9476), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9478), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9480), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10720), 1,
      anon_sym_LPAREN,
    ACTIONS(10724), 1,
      anon_sym_LBRACK,
    ACTIONS(11340), 1,
      sym__lowercase_identifier,
    STATE(9042), 1,
      sym_attribute,
    STATE(9328), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(16859), 1,
      sym_extended_module_path,
    STATE(19200), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9377), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [439934] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7929), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(7931), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [439976] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11430), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11432), 1,
      anon_sym_GT,
    STATE(9044), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [440048] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9045), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11436), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11434), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [440090] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8074), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [440132] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9047), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11440), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11438), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [440174] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(9048), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 11,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      sym__lowercase_identifier,
    ACTIONS(8296), 15,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [440218] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9049), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11444), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11442), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [440260] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9050), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11448), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11446), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [440302] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11450), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11452), 1,
      anon_sym_GT,
    STATE(9051), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [440374] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11254), 1,
      sym__lowercase_identifier,
    ACTIONS(11400), 1,
      anon_sym_POUND,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    STATE(9052), 1,
      sym_attribute,
    STATE(9379), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17458), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11454), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11456), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [440432] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9053), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9158), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [440474] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11254), 1,
      sym__lowercase_identifier,
    ACTIONS(11400), 1,
      anon_sym_POUND,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    STATE(9054), 1,
      sym_attribute,
    STATE(9379), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17458), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11462), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11464), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [440532] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11466), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11468), 1,
      anon_sym_GT,
    STATE(9055), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [440604] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9964), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11352), 1,
      sym__lowercase_identifier,
    ACTIONS(11354), 1,
      anon_sym_LPAREN,
    ACTIONS(11356), 1,
      anon_sym_LBRACK,
    ACTIONS(11358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11362), 1,
      anon_sym_LT,
    ACTIONS(11364), 1,
      anon_sym_POUND,
    ACTIONS(11366), 1,
      aux_sym_type_variable_token1,
    STATE(9056), 1,
      sym_attribute,
    STATE(9763), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10353), 1,
      sym__constructor_argument,
    STATE(17160), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10274), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [440676] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9057), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11472), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11470), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [440718] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9058), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8076), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8078), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [440760] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9059), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11476), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11474), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [440802] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9060), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11480), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11478), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [440844] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(11278), 1,
      sym__lowercase_identifier,
    ACTIONS(11280), 1,
      anon_sym_LPAREN,
    ACTIONS(11282), 1,
      anon_sym_LBRACK,
    ACTIONS(11284), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11286), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11288), 1,
      anon_sym_LT,
    ACTIONS(11290), 1,
      anon_sym_POUND,
    ACTIONS(11292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11296), 1,
      aux_sym_type_variable_token1,
    STATE(9061), 1,
      sym_attribute,
    STATE(10107), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(16787), 1,
      sym_extended_module_path,
    STATE(20020), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10877), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [440916] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9062), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8302), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [440958] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11482), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11484), 1,
      anon_sym_GT,
    STATE(9063), 1,
      sym_attribute,
    STATE(13460), 1,
      sym__simple_type,
    STATE(15332), 1,
      sym_method_type,
    STATE(16552), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [441030] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11486), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11488), 1,
      anon_sym_GT,
    STATE(9064), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [441102] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11490), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11492), 1,
      anon_sym_GT,
    STATE(9065), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [441174] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9066), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8340), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [441216] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10016), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10018), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11210), 1,
      sym__lowercase_identifier,
    ACTIONS(11212), 1,
      anon_sym_LPAREN,
    ACTIONS(11214), 1,
      anon_sym_LBRACK,
    ACTIONS(11216), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11218), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11220), 1,
      anon_sym_LT,
    ACTIONS(11222), 1,
      anon_sym_POUND,
    ACTIONS(11224), 1,
      aux_sym_type_variable_token1,
    STATE(9067), 1,
      sym_attribute,
    STATE(9973), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(17224), 1,
      sym_extended_module_path,
    STATE(18828), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10848), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [441288] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9068), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11496), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11494), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [441330] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11320), 1,
      sym__lowercase_identifier,
    ACTIONS(11322), 1,
      anon_sym_LPAREN,
    ACTIONS(11324), 1,
      anon_sym_LBRACK,
    ACTIONS(11326), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11328), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11330), 1,
      anon_sym_LT,
    ACTIONS(11332), 1,
      anon_sym_POUND,
    ACTIONS(11334), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11498), 1,
      anon_sym_LBRACE,
    STATE(9069), 1,
      sym_attribute,
    STATE(13262), 1,
      sym__simple_type,
    STATE(16646), 1,
      sym_record_declaration,
    STATE(16650), 1,
      sym__constructor_argument,
    STATE(16970), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13564), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [441402] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9070), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8084), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8086), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [441444] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9071), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11416), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11414), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [441486] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8060), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8062), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [441528] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11254), 1,
      sym__lowercase_identifier,
    ACTIONS(11400), 1,
      anon_sym_POUND,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    STATE(9073), 1,
      sym_attribute,
    STATE(9379), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17458), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11500), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11502), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [441586] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8088), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8090), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [441628] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(11278), 1,
      sym__lowercase_identifier,
    ACTIONS(11280), 1,
      anon_sym_LPAREN,
    ACTIONS(11282), 1,
      anon_sym_LBRACK,
    ACTIONS(11284), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11286), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11288), 1,
      anon_sym_LT,
    ACTIONS(11290), 1,
      anon_sym_POUND,
    ACTIONS(11292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11296), 1,
      aux_sym_type_variable_token1,
    STATE(9075), 1,
      sym_attribute,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10346), 1,
      sym__simple_type,
    STATE(10473), 1,
      sym__constructor_argument,
    STATE(16787), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10877), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [441700] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9468), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9470), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9472), 1,
      anon_sym_LT,
    ACTIONS(9474), 1,
      anon_sym_POUND,
    ACTIONS(9476), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9478), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9480), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10720), 1,
      anon_sym_LPAREN,
    ACTIONS(10724), 1,
      anon_sym_LBRACK,
    ACTIONS(11340), 1,
      sym__lowercase_identifier,
    STATE(9073), 1,
      sym__simple_type,
    STATE(9076), 1,
      sym_attribute,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(16859), 1,
      sym_extended_module_path,
    STATE(19211), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9377), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [441772] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8092), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8094), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [441814] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9078), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(7939), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [441856] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11504), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11506), 1,
      anon_sym_GT,
    STATE(9079), 1,
      sym_attribute,
    STATE(13433), 1,
      sym__simple_type,
    STATE(16151), 1,
      sym_method_type,
    STATE(16552), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [441928] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9080), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(7923), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [441970] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(7935), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [442012] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9082), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11510), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11508), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [442054] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9083), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8268), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [442096] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8108), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8110), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [442138] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9085), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11007), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11009), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [442180] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11512), 1,
      anon_sym_DOT,
    ACTIONS(11514), 1,
      anon_sym_POUND,
    ACTIONS(11516), 1,
      sym_hash_operator,
    STATE(9086), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8100), 10,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8102), 14,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [442228] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9087), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8112), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8114), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [442270] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10016), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10018), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11210), 1,
      sym__lowercase_identifier,
    ACTIONS(11212), 1,
      anon_sym_LPAREN,
    ACTIONS(11214), 1,
      anon_sym_LBRACK,
    ACTIONS(11216), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11218), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11220), 1,
      anon_sym_LT,
    ACTIONS(11222), 1,
      anon_sym_POUND,
    ACTIONS(11224), 1,
      aux_sym_type_variable_token1,
    STATE(9088), 1,
      sym_attribute,
    STATE(9988), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(17224), 1,
      sym_extended_module_path,
    STATE(18818), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10848), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [442342] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9468), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9470), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9472), 1,
      anon_sym_LT,
    ACTIONS(9474), 1,
      anon_sym_POUND,
    ACTIONS(9476), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9478), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9480), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10720), 1,
      anon_sym_LPAREN,
    ACTIONS(10724), 1,
      anon_sym_LBRACK,
    ACTIONS(11340), 1,
      sym__lowercase_identifier,
    STATE(9089), 1,
      sym_attribute,
    STATE(9420), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10353), 1,
      sym__constructor_argument,
    STATE(16859), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9377), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [442414] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9468), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9470), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9472), 1,
      anon_sym_LT,
    ACTIONS(9474), 1,
      anon_sym_POUND,
    ACTIONS(9476), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9478), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9480), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10720), 1,
      anon_sym_LPAREN,
    ACTIONS(10724), 1,
      anon_sym_LBRACK,
    ACTIONS(11340), 1,
      sym__lowercase_identifier,
    STATE(9090), 1,
      sym_attribute,
    STATE(9137), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(16859), 1,
      sym_extended_module_path,
    STATE(19214), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9377), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [442486] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11518), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11520), 1,
      anon_sym_GT,
    STATE(9091), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [442558] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11522), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11524), 1,
      anon_sym_GT,
    STATE(9092), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [442630] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9900), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9902), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11368), 1,
      sym__lowercase_identifier,
    ACTIONS(11370), 1,
      anon_sym_LPAREN,
    ACTIONS(11372), 1,
      anon_sym_LBRACK,
    ACTIONS(11374), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11376), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11378), 1,
      anon_sym_LT,
    ACTIONS(11380), 1,
      anon_sym_POUND,
    ACTIONS(11382), 1,
      aux_sym_type_variable_token1,
    STATE(9093), 1,
      sym_attribute,
    STATE(10096), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10496), 1,
      sym__constructor_argument,
    STATE(16829), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10613), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [442702] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10016), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10018), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11210), 1,
      sym__lowercase_identifier,
    ACTIONS(11212), 1,
      anon_sym_LPAREN,
    ACTIONS(11214), 1,
      anon_sym_LBRACK,
    ACTIONS(11216), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11218), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11220), 1,
      anon_sym_LT,
    ACTIONS(11222), 1,
      anon_sym_POUND,
    ACTIONS(11224), 1,
      aux_sym_type_variable_token1,
    STATE(9094), 1,
      sym_attribute,
    STATE(9904), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(17224), 1,
      sym_extended_module_path,
    STATE(18843), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10848), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [442774] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11526), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11528), 1,
      anon_sym_GT,
    STATE(9095), 1,
      sym_attribute,
    STATE(13452), 1,
      sym__simple_type,
    STATE(15477), 1,
      sym_method_type,
    STATE(16552), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [442846] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11530), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11532), 1,
      anon_sym_GT,
    STATE(9096), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [442918] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9900), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9902), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11368), 1,
      sym__lowercase_identifier,
    ACTIONS(11370), 1,
      anon_sym_LPAREN,
    ACTIONS(11372), 1,
      anon_sym_LBRACK,
    ACTIONS(11374), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11376), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11378), 1,
      anon_sym_LT,
    ACTIONS(11380), 1,
      anon_sym_POUND,
    ACTIONS(11382), 1,
      aux_sym_type_variable_token1,
    STATE(9097), 1,
      sym_attribute,
    STATE(10096), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10473), 1,
      sym__constructor_argument,
    STATE(16829), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10613), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [442990] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9468), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9470), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9472), 1,
      anon_sym_LT,
    ACTIONS(9474), 1,
      anon_sym_POUND,
    ACTIONS(9476), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9478), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9480), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10720), 1,
      anon_sym_LPAREN,
    ACTIONS(10724), 1,
      anon_sym_LBRACK,
    ACTIONS(11340), 1,
      sym__lowercase_identifier,
    STATE(9098), 1,
      sym_attribute,
    STATE(9420), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10496), 1,
      sym__constructor_argument,
    STATE(16859), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9377), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [443062] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9099), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11536), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11534), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [443104] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9100), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11540), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11538), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [443146] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9101), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8318), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [443188] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11542), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11544), 1,
      anon_sym_GT,
    STATE(9102), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [443260] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8120), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8122), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [443302] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11546), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11548), 1,
      anon_sym_GT,
    STATE(9104), 1,
      sym_attribute,
    STATE(13486), 1,
      sym__simple_type,
    STATE(15994), 1,
      sym_method_type,
    STATE(16552), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [443374] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9105), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8124), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8126), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [443416] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9106), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8128), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8130), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [443458] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9900), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9902), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11368), 1,
      sym__lowercase_identifier,
    ACTIONS(11370), 1,
      anon_sym_LPAREN,
    ACTIONS(11372), 1,
      anon_sym_LBRACK,
    ACTIONS(11374), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11376), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11378), 1,
      anon_sym_LT,
    ACTIONS(11380), 1,
      anon_sym_POUND,
    ACTIONS(11382), 1,
      aux_sym_type_variable_token1,
    STATE(9107), 1,
      sym_attribute,
    STATE(9715), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(16829), 1,
      sym_extended_module_path,
    STATE(19756), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10613), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [443530] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11552), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11550), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [443572] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11554), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11556), 1,
      anon_sym_GT,
    STATE(9109), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [443644] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10134), 1,
      anon_sym_LPAREN,
    ACTIONS(10136), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10140), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10142), 1,
      anon_sym_LT,
    ACTIONS(10144), 1,
      anon_sym_POUND,
    ACTIONS(10146), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10148), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10150), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11316), 1,
      sym__lowercase_identifier,
    STATE(9110), 1,
      sym_attribute,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10353), 1,
      sym__constructor_argument,
    STATE(10489), 1,
      sym__simple_type,
    STATE(16704), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10841), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [443716] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11346), 1,
      sym__lowercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11558), 1,
      anon_sym_POUND,
    STATE(9111), 1,
      sym_attribute,
    STATE(9468), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17537), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11454), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11456), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [443774] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(11226), 1,
      sym__lowercase_identifier,
    ACTIONS(11228), 1,
      anon_sym_LPAREN,
    ACTIONS(11230), 1,
      anon_sym_LBRACK,
    ACTIONS(11232), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11234), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11236), 1,
      anon_sym_LT,
    ACTIONS(11238), 1,
      anon_sym_POUND,
    ACTIONS(11240), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11242), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11244), 1,
      aux_sym_type_variable_token1,
    STATE(9112), 1,
      sym_attribute,
    STATE(10208), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10353), 1,
      sym__constructor_argument,
    STATE(16889), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10886), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [443846] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8144), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8146), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [443888] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9114), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11562), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11560), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [443930] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8272), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [443972] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11564), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11566), 1,
      anon_sym_GT,
    STATE(9116), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [444044] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9406), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10680), 1,
      anon_sym_LPAREN,
    ACTIONS(10684), 1,
      anon_sym_LBRACK,
    ACTIONS(11252), 1,
      sym__lowercase_identifier,
    STATE(9117), 1,
      sym_attribute,
    STATE(9519), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10496), 1,
      sym__constructor_argument,
    STATE(16745), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9437), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [444116] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9900), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9902), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11368), 1,
      sym__lowercase_identifier,
    ACTIONS(11370), 1,
      anon_sym_LPAREN,
    ACTIONS(11372), 1,
      anon_sym_LBRACK,
    ACTIONS(11374), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11376), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11378), 1,
      anon_sym_LT,
    ACTIONS(11380), 1,
      anon_sym_POUND,
    ACTIONS(11382), 1,
      aux_sym_type_variable_token1,
    STATE(9118), 1,
      sym_attribute,
    STATE(9845), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(16829), 1,
      sym_extended_module_path,
    STATE(19781), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10613), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [444188] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9406), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10680), 1,
      anon_sym_LPAREN,
    ACTIONS(10684), 1,
      anon_sym_LBRACK,
    ACTIONS(11252), 1,
      sym__lowercase_identifier,
    STATE(9119), 1,
      sym_attribute,
    STATE(9519), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10473), 1,
      sym__constructor_argument,
    STATE(16745), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9437), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [444260] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11346), 1,
      sym__lowercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11558), 1,
      anon_sym_POUND,
    STATE(9120), 1,
      sym_attribute,
    STATE(9468), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17537), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11500), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11502), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [444318] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9900), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9902), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11368), 1,
      sym__lowercase_identifier,
    ACTIONS(11370), 1,
      anon_sym_LPAREN,
    ACTIONS(11372), 1,
      anon_sym_LBRACK,
    ACTIONS(11374), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11376), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11378), 1,
      anon_sym_LT,
    ACTIONS(11380), 1,
      anon_sym_POUND,
    ACTIONS(11382), 1,
      aux_sym_type_variable_token1,
    STATE(9121), 1,
      sym_attribute,
    STATE(9830), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(16829), 1,
      sym_extended_module_path,
    STATE(19782), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10613), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [444390] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11568), 1,
      sym__lowercase_identifier,
    ACTIONS(11570), 1,
      anon_sym_POUND,
    STATE(9122), 1,
      sym_attribute,
    STATE(9625), 1,
      sym_type_constructor_path,
    STATE(17263), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10261), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(10263), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [444442] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10016), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10018), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11210), 1,
      sym__lowercase_identifier,
    ACTIONS(11212), 1,
      anon_sym_LPAREN,
    ACTIONS(11214), 1,
      anon_sym_LBRACK,
    ACTIONS(11216), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11218), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11220), 1,
      anon_sym_LT,
    ACTIONS(11222), 1,
      anon_sym_POUND,
    ACTIONS(11224), 1,
      aux_sym_type_variable_token1,
    STATE(9123), 1,
      sym_attribute,
    STATE(10207), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10353), 1,
      sym__constructor_argument,
    STATE(17224), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10848), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [444514] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11572), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11574), 1,
      anon_sym_GT,
    STATE(9124), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [444586] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11578), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11576), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [444628] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10134), 1,
      anon_sym_LPAREN,
    ACTIONS(10136), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10140), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10142), 1,
      anon_sym_LT,
    ACTIONS(10144), 1,
      anon_sym_POUND,
    ACTIONS(10146), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10148), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10150), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11316), 1,
      sym__lowercase_identifier,
    STATE(9126), 1,
      sym_attribute,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10322), 1,
      sym__simple_type,
    STATE(16704), 1,
      sym_extended_module_path,
    STATE(20262), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10841), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [444700] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11264), 1,
      anon_sym_COLON2,
    STATE(9127), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9158), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [444744] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11580), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11582), 1,
      anon_sym_GT,
    STATE(9128), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [444816] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9129), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8274), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8276), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [444858] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9130), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8132), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8134), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [444900] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10070), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10072), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11298), 1,
      sym__lowercase_identifier,
    ACTIONS(11300), 1,
      anon_sym_LPAREN,
    ACTIONS(11302), 1,
      anon_sym_LBRACK,
    ACTIONS(11304), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11306), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11308), 1,
      anon_sym_LT,
    ACTIONS(11310), 1,
      anon_sym_POUND,
    ACTIONS(11312), 1,
      aux_sym_type_variable_token1,
    STATE(9131), 1,
      sym_attribute,
    STATE(9387), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(17129), 1,
      sym_extended_module_path,
    STATE(19268), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10286), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [444972] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8136), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8138), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [445014] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11584), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11586), 1,
      anon_sym_GT,
    STATE(9133), 1,
      sym_attribute,
    STATE(13479), 1,
      sym__simple_type,
    STATE(15179), 1,
      sym_method_type,
    STATE(16552), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [445086] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8278), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8280), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [445128] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9135), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9258), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9256), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [445170] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9964), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11352), 1,
      sym__lowercase_identifier,
    ACTIONS(11354), 1,
      anon_sym_LPAREN,
    ACTIONS(11356), 1,
      anon_sym_LBRACK,
    ACTIONS(11358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11362), 1,
      anon_sym_LT,
    ACTIONS(11364), 1,
      anon_sym_POUND,
    ACTIONS(11366), 1,
      aux_sym_type_variable_token1,
    STATE(9136), 1,
      sym_attribute,
    STATE(9763), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10496), 1,
      sym__constructor_argument,
    STATE(17160), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10274), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [445242] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11254), 1,
      sym__lowercase_identifier,
    ACTIONS(11400), 1,
      anon_sym_POUND,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    STATE(9137), 1,
      sym_attribute,
    STATE(9379), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17458), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11588), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11590), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [445300] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11592), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11594), 1,
      anon_sym_GT,
    STATE(9138), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [445372] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10134), 1,
      anon_sym_LPAREN,
    ACTIONS(10136), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10140), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10142), 1,
      anon_sym_LT,
    ACTIONS(10144), 1,
      anon_sym_POUND,
    ACTIONS(10146), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10148), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10150), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11316), 1,
      sym__lowercase_identifier,
    STATE(9139), 1,
      sym_attribute,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10316), 1,
      sym__simple_type,
    STATE(16704), 1,
      sym_extended_module_path,
    STATE(20261), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10841), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [445444] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11346), 1,
      sym__lowercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11558), 1,
      anon_sym_POUND,
    STATE(9140), 1,
      sym_attribute,
    STATE(9468), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17537), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11596), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11598), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [445502] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(9141), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 11,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      sym__lowercase_identifier,
    ACTIONS(8296), 15,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [445546] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8140), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8142), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [445588] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9906), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_LBRACK,
    ACTIONS(9910), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9912), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9914), 1,
      anon_sym_LT,
    ACTIONS(9916), 1,
      anon_sym_POUND,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9920), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9922), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11318), 1,
      sym__lowercase_identifier,
    STATE(9143), 1,
      sym_attribute,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10693), 1,
      sym__simple_type,
    STATE(16934), 1,
      sym_extended_module_path,
    STATE(19537), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11018), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [445660] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11600), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [445702] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11604), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11606), 1,
      anon_sym_GT,
    STATE(9145), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [445774] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9146), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8180), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [445816] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8148), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8150), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [445858] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8156), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [445900] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11608), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11610), 1,
      anon_sym_GT,
    STATE(9149), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [445972] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(11320), 1,
      sym__lowercase_identifier,
    ACTIONS(11322), 1,
      anon_sym_LPAREN,
    ACTIONS(11324), 1,
      anon_sym_LBRACK,
    ACTIONS(11326), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11328), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11330), 1,
      anon_sym_LT,
    ACTIONS(11332), 1,
      anon_sym_POUND,
    ACTIONS(11334), 1,
      aux_sym_type_variable_token1,
    STATE(9150), 1,
      sym_attribute,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(13200), 1,
      sym__simple_type,
    STATE(16970), 1,
      sym_extended_module_path,
    STATE(19432), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13564), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [446044] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(11320), 1,
      sym__lowercase_identifier,
    ACTIONS(11322), 1,
      anon_sym_LPAREN,
    ACTIONS(11324), 1,
      anon_sym_LBRACK,
    ACTIONS(11326), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11328), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11330), 1,
      anon_sym_LT,
    ACTIONS(11332), 1,
      anon_sym_POUND,
    ACTIONS(11334), 1,
      aux_sym_type_variable_token1,
    STATE(9151), 1,
      sym_attribute,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(13220), 1,
      sym__simple_type,
    STATE(16970), 1,
      sym_extended_module_path,
    STATE(19421), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13564), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [446116] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9152), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11578), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11576), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [446158] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11612), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11614), 1,
      anon_sym_GT,
    STATE(9153), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [446230] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9906), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_LBRACK,
    ACTIONS(9910), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9912), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9914), 1,
      anon_sym_LT,
    ACTIONS(9916), 1,
      anon_sym_POUND,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9920), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9922), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11318), 1,
      sym__lowercase_identifier,
    STATE(9154), 1,
      sym_attribute,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10694), 1,
      sym__simple_type,
    STATE(16934), 1,
      sym_extended_module_path,
    STATE(19536), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11018), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [446302] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11618), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11616), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [446344] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9156), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11540), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11538), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [446386] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9157), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11622), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11620), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [446428] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11624), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11626), 1,
      anon_sym_GT,
    STATE(9158), 1,
      sym_attribute,
    STATE(13448), 1,
      sym__simple_type,
    STATE(16158), 1,
      sym_method_type,
    STATE(16552), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [446500] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7911), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(7913), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [446542] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8192), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [446584] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11346), 1,
      sym__lowercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11558), 1,
      anon_sym_POUND,
    STATE(9161), 1,
      sym_attribute,
    STATE(9468), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17537), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11588), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11590), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [446642] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10070), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10072), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11298), 1,
      sym__lowercase_identifier,
    ACTIONS(11300), 1,
      anon_sym_LPAREN,
    ACTIONS(11302), 1,
      anon_sym_LBRACK,
    ACTIONS(11304), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11306), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11308), 1,
      anon_sym_LT,
    ACTIONS(11310), 1,
      anon_sym_POUND,
    ACTIONS(11312), 1,
      aux_sym_type_variable_token1,
    STATE(9162), 1,
      sym_attribute,
    STATE(9831), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10496), 1,
      sym__constructor_argument,
    STATE(17129), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10286), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [446714] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8160), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [446756] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(7917), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [446798] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8292), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [446840] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9424), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9426), 1,
      anon_sym_LT,
    ACTIONS(9428), 1,
      anon_sym_POUND,
    ACTIONS(9430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9434), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10692), 1,
      anon_sym_LPAREN,
    ACTIONS(10696), 1,
      anon_sym_LBRACK,
    ACTIONS(11208), 1,
      sym__lowercase_identifier,
    STATE(9166), 1,
      sym_attribute,
    STATE(9638), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10496), 1,
      sym__constructor_argument,
    STATE(16665), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9574), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [446912] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11628), 1,
      sym__lowercase_identifier,
    ACTIONS(11630), 1,
      anon_sym_POUND,
    STATE(9167), 1,
      sym_attribute,
    STATE(9767), 1,
      sym_type_constructor_path,
    STATE(16902), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11128), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11130), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [446964] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9906), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_LBRACK,
    ACTIONS(9910), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9912), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9914), 1,
      anon_sym_LT,
    ACTIONS(9916), 1,
      anon_sym_POUND,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9920), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9922), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11318), 1,
      sym__lowercase_identifier,
    STATE(9168), 1,
      sym_attribute,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10647), 1,
      sym__simple_type,
    STATE(16934), 1,
      sym_extended_module_path,
    STATE(19516), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11018), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [447036] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9424), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9426), 1,
      anon_sym_LT,
    ACTIONS(9428), 1,
      anon_sym_POUND,
    ACTIONS(9430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9434), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10692), 1,
      anon_sym_LPAREN,
    ACTIONS(10696), 1,
      anon_sym_LBRACK,
    ACTIONS(11208), 1,
      sym__lowercase_identifier,
    STATE(9169), 1,
      sym_attribute,
    STATE(9638), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10473), 1,
      sym__constructor_argument,
    STATE(16665), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9574), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [447108] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9258), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9256), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [447150] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11634), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11632), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [447192] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9590), 1,
      anon_sym_DOT,
    ACTIONS(11040), 1,
      anon_sym_POUND,
    ACTIONS(11636), 1,
      sym_hash_operator,
    STATE(9172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9752), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9750), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [447240] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9158), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [447282] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11640), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11638), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [447324] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9175), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11644), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11642), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [447366] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8196), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [447408] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9177), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7907), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(7909), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [447450] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8052), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8054), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [447492] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8064), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8066), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [447534] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9590), 1,
      anon_sym_DOT,
    ACTIONS(11040), 1,
      anon_sym_POUND,
    ACTIONS(11636), 1,
      sym_hash_operator,
    STATE(9180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9742), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9740), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [447582] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11646), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11648), 1,
      anon_sym_GT,
    STATE(9181), 1,
      sym_attribute,
    STATE(13468), 1,
      sym__simple_type,
    STATE(15293), 1,
      sym_method_type,
    STATE(16552), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [447654] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9590), 1,
      anon_sym_DOT,
    ACTIONS(11040), 1,
      anon_sym_POUND,
    ACTIONS(11636), 1,
      sym_hash_operator,
    STATE(9182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9734), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9732), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [447702] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11346), 1,
      sym__lowercase_identifier,
    ACTIONS(11558), 1,
      anon_sym_POUND,
    STATE(9183), 1,
      sym_attribute,
    STATE(9468), 1,
      sym_type_constructor_path,
    STATE(17537), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10261), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(10263), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [447754] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9184), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8096), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8098), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [447796] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9964), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11352), 1,
      sym__lowercase_identifier,
    ACTIONS(11354), 1,
      anon_sym_LPAREN,
    ACTIONS(11356), 1,
      anon_sym_LBRACK,
    ACTIONS(11358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11362), 1,
      anon_sym_LT,
    ACTIONS(11364), 1,
      anon_sym_POUND,
    ACTIONS(11366), 1,
      aux_sym_type_variable_token1,
    STATE(9185), 1,
      sym_attribute,
    STATE(9763), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10473), 1,
      sym__constructor_argument,
    STATE(17160), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10274), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [447868] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9500), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9502), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9504), 1,
      anon_sym_LT,
    ACTIONS(9506), 1,
      anon_sym_POUND,
    ACTIONS(9508), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9510), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9512), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10928), 1,
      anon_sym_LPAREN,
    ACTIONS(10932), 1,
      anon_sym_LBRACK,
    ACTIONS(11246), 1,
      sym__lowercase_identifier,
    STATE(9186), 1,
      sym_attribute,
    STATE(9995), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10353), 1,
      sym__constructor_argument,
    STATE(16914), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10076), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [447940] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11568), 1,
      sym__lowercase_identifier,
    ACTIONS(11650), 1,
      anon_sym_POUND,
    STATE(9187), 1,
      sym_attribute,
    STATE(9554), 1,
      sym_type_constructor_path,
    STATE(17263), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11128), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11130), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [447992] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8070), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [448034] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9900), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9902), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11368), 1,
      sym__lowercase_identifier,
    ACTIONS(11370), 1,
      anon_sym_LPAREN,
    ACTIONS(11372), 1,
      anon_sym_LBRACK,
    ACTIONS(11374), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11376), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11378), 1,
      anon_sym_LT,
    ACTIONS(11380), 1,
      anon_sym_POUND,
    ACTIONS(11382), 1,
      aux_sym_type_variable_token1,
    STATE(9189), 1,
      sym_attribute,
    STATE(10096), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10353), 1,
      sym__constructor_argument,
    STATE(16829), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10613), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [448106] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11652), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11654), 1,
      anon_sym_GT,
    STATE(9190), 1,
      sym_attribute,
    STATE(13475), 1,
      sym__simple_type,
    STATE(15878), 1,
      sym_method_type,
    STATE(16552), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [448178] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9590), 1,
      anon_sym_DOT,
    ACTIONS(11040), 1,
      anon_sym_POUND,
    ACTIONS(11636), 1,
      sym_hash_operator,
    STATE(9191), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9724), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9722), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [448226] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9468), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9470), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9472), 1,
      anon_sym_LT,
    ACTIONS(9474), 1,
      anon_sym_POUND,
    ACTIONS(9476), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9478), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9480), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10720), 1,
      anon_sym_LPAREN,
    ACTIONS(10724), 1,
      anon_sym_LBRACK,
    ACTIONS(11340), 1,
      sym__lowercase_identifier,
    STATE(9192), 1,
      sym_attribute,
    STATE(9420), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10473), 1,
      sym__constructor_argument,
    STATE(16859), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9377), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [448298] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11658), 1,
      anon_sym_GT,
    STATE(9193), 1,
      sym_attribute,
    STATE(13444), 1,
      sym__simple_type,
    STATE(16145), 1,
      sym_method_type,
    STATE(16552), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [448370] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11660), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11662), 1,
      anon_sym_GT,
    STATE(9194), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [448442] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11664), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11666), 1,
      anon_sym_GT,
    STATE(9195), 1,
      sym_attribute,
    STATE(13462), 1,
      sym__simple_type,
    STATE(15672), 1,
      sym_method_type,
    STATE(16552), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [448514] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8080), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8082), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [448556] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8164), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [448598] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11668), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11670), 1,
      anon_sym_GT,
    STATE(9198), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [448670] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11672), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11674), 1,
      anon_sym_GT,
    STATE(9199), 1,
      sym_attribute,
    STATE(13485), 1,
      sym__simple_type,
    STATE(16503), 1,
      sym_method_type,
    STATE(16552), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [448742] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8168), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [448784] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11436), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11434), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [448826] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9202), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11007), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11009), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [448868] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(11226), 1,
      sym__lowercase_identifier,
    ACTIONS(11228), 1,
      anon_sym_LPAREN,
    ACTIONS(11230), 1,
      anon_sym_LBRACK,
    ACTIONS(11232), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11234), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11236), 1,
      anon_sym_LT,
    ACTIONS(11238), 1,
      anon_sym_POUND,
    ACTIONS(11240), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11242), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11244), 1,
      aux_sym_type_variable_token1,
    STATE(9203), 1,
      sym_attribute,
    STATE(10208), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10473), 1,
      sym__constructor_argument,
    STATE(16889), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10886), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [448940] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9204), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11496), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11494), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [448982] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(11226), 1,
      sym__lowercase_identifier,
    ACTIONS(11228), 1,
      anon_sym_LPAREN,
    ACTIONS(11230), 1,
      anon_sym_LBRACK,
    ACTIONS(11232), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11234), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11236), 1,
      anon_sym_LT,
    ACTIONS(11238), 1,
      anon_sym_POUND,
    ACTIONS(11240), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11242), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11244), 1,
      aux_sym_type_variable_token1,
    STATE(9205), 1,
      sym_attribute,
    STATE(10208), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10496), 1,
      sym__constructor_argument,
    STATE(16889), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10886), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [449054] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9500), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9502), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9504), 1,
      anon_sym_LT,
    ACTIONS(9506), 1,
      anon_sym_POUND,
    ACTIONS(9508), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9510), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9512), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10928), 1,
      anon_sym_LPAREN,
    ACTIONS(10932), 1,
      anon_sym_LBRACK,
    ACTIONS(11246), 1,
      sym__lowercase_identifier,
    STATE(9206), 1,
      sym_attribute,
    STATE(9695), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(16914), 1,
      sym_extended_module_path,
    STATE(18948), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10076), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [449126] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8172), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [449168] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11346), 1,
      sym__lowercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11558), 1,
      anon_sym_POUND,
    STATE(9208), 1,
      sym_attribute,
    STATE(9468), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17537), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11462), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11464), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [449226] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9500), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9502), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9504), 1,
      anon_sym_LT,
    ACTIONS(9506), 1,
      anon_sym_POUND,
    ACTIONS(9508), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9510), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9512), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10928), 1,
      anon_sym_LPAREN,
    ACTIONS(10932), 1,
      anon_sym_LBRACK,
    ACTIONS(11246), 1,
      sym__lowercase_identifier,
    STATE(9209), 1,
      sym_attribute,
    STATE(9708), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(16914), 1,
      sym_extended_module_path,
    STATE(18944), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10076), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [449298] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11536), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11534), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [449340] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11254), 1,
      sym__lowercase_identifier,
    ACTIONS(11400), 1,
      anon_sym_POUND,
    STATE(9211), 1,
      sym_attribute,
    STATE(9379), 1,
      sym_type_constructor_path,
    STATE(17458), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11124), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11126), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [449392] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9212), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11640), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11638), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [449434] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(13), 1,
      anon_sym_type,
    ACTIONS(17), 1,
      anon_sym_module,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(21), 1,
      anon_sym_include,
    ACTIONS(25), 1,
      anon_sym_val,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11192), 1,
      anon_sym_exception,
    ACTIONS(11194), 1,
      anon_sym_class,
    STATE(9213), 1,
      sym_attribute,
    STATE(12369), 1,
      aux_sym__structure_repeat1,
    STATE(12815), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12649), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [449502] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9214), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11480), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11478), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [449544] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11346), 1,
      sym__lowercase_identifier,
    ACTIONS(11558), 1,
      anon_sym_POUND,
    STATE(9215), 1,
      sym_attribute,
    STATE(9468), 1,
      sym_type_constructor_path,
    STATE(17537), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11124), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11126), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [449596] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10070), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10072), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11298), 1,
      sym__lowercase_identifier,
    ACTIONS(11300), 1,
      anon_sym_LPAREN,
    ACTIONS(11302), 1,
      anon_sym_LBRACK,
    ACTIONS(11304), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11306), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11308), 1,
      anon_sym_LT,
    ACTIONS(11310), 1,
      anon_sym_POUND,
    ACTIONS(11312), 1,
      aux_sym_type_variable_token1,
    STATE(9216), 1,
      sym_attribute,
    STATE(9831), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10473), 1,
      sym__constructor_argument,
    STATE(17129), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10286), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [449668] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11678), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11676), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [449710] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11680), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11682), 1,
      anon_sym_GT,
    STATE(9218), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [449782] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9219), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8104), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8106), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [449824] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11684), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11686), 1,
      anon_sym_GT,
    STATE(9220), 1,
      sym_attribute,
    STATE(13480), 1,
      sym__simple_type,
    STATE(15891), 1,
      sym_method_type,
    STATE(16552), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [449896] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11512), 1,
      anon_sym_DOT,
    STATE(9221), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8176), 15,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [449940] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9222), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11448), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11446), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [449982] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9223), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8264), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [450024] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8184), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [450066] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9225), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7903), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(7905), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [450108] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9226), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8200), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [450150] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9227), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8204), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [450192] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11512), 1,
      anon_sym_DOT,
    ACTIONS(11514), 1,
      anon_sym_POUND,
    ACTIONS(11516), 1,
      sym_hash_operator,
    STATE(9228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 10,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8228), 14,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [450240] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9229), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8208), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8210), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [450282] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11688), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11690), 1,
      anon_sym_GT,
    STATE(9230), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [450354] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9231), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8212), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8214), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [450396] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9232), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11444), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11442), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [450438] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9233), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8288), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [450480] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9424), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9426), 1,
      anon_sym_LT,
    ACTIONS(9428), 1,
      anon_sym_POUND,
    ACTIONS(9430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9434), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10692), 1,
      anon_sym_LPAREN,
    ACTIONS(10696), 1,
      anon_sym_LBRACK,
    ACTIONS(11208), 1,
      sym__lowercase_identifier,
    STATE(9234), 1,
      sym_attribute,
    STATE(9638), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10353), 1,
      sym__constructor_argument,
    STATE(16665), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9574), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [450552] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9235), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11476), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11474), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [450594] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5585), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(5583), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [450636] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9237), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8220), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [450678] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9238), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8224), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [450720] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11320), 1,
      sym__lowercase_identifier,
    ACTIONS(11322), 1,
      anon_sym_LPAREN,
    ACTIONS(11324), 1,
      anon_sym_LBRACK,
    ACTIONS(11326), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11328), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11330), 1,
      anon_sym_LT,
    ACTIONS(11332), 1,
      anon_sym_POUND,
    ACTIONS(11334), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11498), 1,
      anon_sym_LBRACE,
    STATE(9239), 1,
      sym_attribute,
    STATE(13262), 1,
      sym__simple_type,
    STATE(16646), 1,
      sym_record_declaration,
    STATE(16651), 1,
      sym__constructor_argument,
    STATE(16970), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13564), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [450792] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9240), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8336), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [450834] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9241), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11600), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [450876] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9242), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11694), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11692), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [450918] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9243), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8232), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [450960] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11696), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11698), 1,
      anon_sym_GT,
    STATE(9244), 1,
      sym_attribute,
    STATE(13492), 1,
      sym__simple_type,
    STATE(16331), 1,
      sym_method_type,
    STATE(16552), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [451032] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9245), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8236), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [451074] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9246), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8240), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [451116] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11700), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11702), 1,
      anon_sym_GT,
    STATE(9247), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [451188] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11706), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11704), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [451230] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11708), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11710), 1,
      anon_sym_GT,
    STATE(9249), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [451302] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11712), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11714), 1,
      anon_sym_GT,
    STATE(9250), 1,
      sym_attribute,
    STATE(13422), 1,
      sym__simple_type,
    STATE(16300), 1,
      sym_method_type,
    STATE(16552), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [451374] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11716), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11718), 1,
      anon_sym_GT,
    STATE(9251), 1,
      sym_attribute,
    STATE(13461), 1,
      sym__simple_type,
    STATE(15720), 1,
      sym_method_type,
    STATE(16552), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [451446] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11568), 1,
      sym__lowercase_identifier,
    ACTIONS(11570), 1,
      anon_sym_POUND,
    STATE(9252), 1,
      sym_attribute,
    STATE(9625), 1,
      sym_type_constructor_path,
    STATE(17263), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11124), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11126), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [451498] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9500), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9502), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9504), 1,
      anon_sym_LT,
    ACTIONS(9506), 1,
      anon_sym_POUND,
    ACTIONS(9508), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9510), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9512), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10928), 1,
      anon_sym_LPAREN,
    ACTIONS(10932), 1,
      anon_sym_LBRACK,
    ACTIONS(11246), 1,
      sym__lowercase_identifier,
    STATE(9253), 1,
      sym_attribute,
    STATE(9995), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10496), 1,
      sym__constructor_argument,
    STATE(16914), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10076), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [451570] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9406), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10680), 1,
      anon_sym_LPAREN,
    ACTIONS(10684), 1,
      anon_sym_LBRACK,
    ACTIONS(11252), 1,
      sym__lowercase_identifier,
    STATE(9254), 1,
      sym_attribute,
    STATE(9255), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(16745), 1,
      sym_extended_module_path,
    STATE(19342), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9437), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [451642] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11346), 1,
      sym__lowercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11558), 1,
      anon_sym_POUND,
    STATE(9255), 1,
      sym_attribute,
    STATE(9468), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17537), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11720), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11722), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [451700] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11052), 1,
      anon_sym_type,
    ACTIONS(11054), 1,
      anon_sym_exception,
    ACTIONS(11056), 1,
      anon_sym_module,
    ACTIONS(11058), 1,
      anon_sym_include,
    ACTIONS(11060), 1,
      anon_sym_class,
    ACTIONS(11062), 1,
      anon_sym_val,
    STATE(9256), 1,
      sym_attribute,
    STATE(12369), 1,
      aux_sym__structure_repeat1,
    STATE(12815), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12649), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [451768] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8364), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [451810] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(13), 1,
      anon_sym_type,
    ACTIONS(15), 1,
      anon_sym_exception,
    ACTIONS(17), 1,
      anon_sym_module,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(21), 1,
      anon_sym_include,
    ACTIONS(23), 1,
      anon_sym_class,
    ACTIONS(25), 1,
      anon_sym_val,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    STATE(9258), 1,
      sym_attribute,
    STATE(12369), 1,
      aux_sym__structure_repeat1,
    STATE(12815), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12649), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [451878] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11724), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11726), 1,
      anon_sym_GT,
    STATE(9259), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [451950] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9260), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8310), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [451992] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9906), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_LBRACK,
    ACTIONS(9910), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9912), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9914), 1,
      anon_sym_LT,
    ACTIONS(9916), 1,
      anon_sym_POUND,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9920), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9922), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11318), 1,
      sym__lowercase_identifier,
    STATE(9261), 1,
      sym_attribute,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10496), 1,
      sym__constructor_argument,
    STATE(10770), 1,
      sym__simple_type,
    STATE(16934), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11018), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [452064] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9406), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10680), 1,
      anon_sym_LPAREN,
    ACTIONS(10684), 1,
      anon_sym_LBRACK,
    ACTIONS(11252), 1,
      sym__lowercase_identifier,
    STATE(9120), 1,
      sym__simple_type,
    STATE(9262), 1,
      sym_attribute,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(16745), 1,
      sym_extended_module_path,
    STATE(19352), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9437), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [452136] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9500), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9502), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9504), 1,
      anon_sym_LT,
    ACTIONS(9506), 1,
      anon_sym_POUND,
    ACTIONS(9508), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9510), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9512), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10928), 1,
      anon_sym_LPAREN,
    ACTIONS(10932), 1,
      anon_sym_LBRACK,
    ACTIONS(11246), 1,
      sym__lowercase_identifier,
    STATE(9263), 1,
      sym_attribute,
    STATE(9995), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10473), 1,
      sym__constructor_argument,
    STATE(16914), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10076), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [452208] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11320), 1,
      sym__lowercase_identifier,
    ACTIONS(11322), 1,
      anon_sym_LPAREN,
    ACTIONS(11324), 1,
      anon_sym_LBRACK,
    ACTIONS(11326), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11328), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11330), 1,
      anon_sym_LT,
    ACTIONS(11332), 1,
      anon_sym_POUND,
    ACTIONS(11334), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11498), 1,
      anon_sym_LBRACE,
    STATE(9264), 1,
      sym_attribute,
    STATE(13262), 1,
      sym__simple_type,
    STATE(16646), 1,
      sym_record_declaration,
    STATE(16647), 1,
      sym__constructor_argument,
    STATE(16970), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13564), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [452280] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9265), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8244), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [452322] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9266), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8356), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [452364] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9406), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10680), 1,
      anon_sym_LPAREN,
    ACTIONS(10684), 1,
      anon_sym_LBRACK,
    ACTIONS(11252), 1,
      sym__lowercase_identifier,
    STATE(9267), 1,
      sym_attribute,
    STATE(9519), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10353), 1,
      sym__constructor_argument,
    STATE(16745), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9437), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [452436] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9268), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8360), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [452478] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11728), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11730), 1,
      anon_sym_GT,
    STATE(9269), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [452550] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8248), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [452592] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9500), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9502), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9504), 1,
      anon_sym_LT,
    ACTIONS(9506), 1,
      anon_sym_POUND,
    ACTIONS(9508), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9510), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9512), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10928), 1,
      anon_sym_LPAREN,
    ACTIONS(10932), 1,
      anon_sym_LBRACK,
    ACTIONS(11246), 1,
      sym__lowercase_identifier,
    STATE(9271), 1,
      sym_attribute,
    STATE(9762), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(16914), 1,
      sym_extended_module_path,
    STATE(18931), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10076), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [452664] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11736), 1,
      anon_sym_LPAREN,
    STATE(9766), 1,
      sym_module_parameter,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9272), 2,
      sym_attribute,
      aux_sym_module_binding_repeat1,
    ACTIONS(11734), 3,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11732), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [452710] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11739), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11741), 1,
      anon_sym_GT,
    STATE(9273), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [452782] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10070), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10072), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11298), 1,
      sym__lowercase_identifier,
    ACTIONS(11300), 1,
      anon_sym_LPAREN,
    ACTIONS(11302), 1,
      anon_sym_LBRACK,
    ACTIONS(11304), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11306), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11308), 1,
      anon_sym_LT,
    ACTIONS(11310), 1,
      anon_sym_POUND,
    ACTIONS(11312), 1,
      aux_sym_type_variable_token1,
    STATE(9274), 1,
      sym_attribute,
    STATE(9452), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(17129), 1,
      sym_extended_module_path,
    STATE(19277), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10286), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [452854] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11743), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11745), 1,
      anon_sym_GT,
    STATE(9275), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [452926] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11440), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11438), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [452968] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9906), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_LBRACK,
    ACTIONS(9910), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9912), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9914), 1,
      anon_sym_LT,
    ACTIONS(9916), 1,
      anon_sym_POUND,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9920), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9922), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11318), 1,
      sym__lowercase_identifier,
    STATE(9277), 1,
      sym_attribute,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10473), 1,
      sym__constructor_argument,
    STATE(10770), 1,
      sym__simple_type,
    STATE(16934), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11018), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [453040] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8002), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8004), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [453082] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11747), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11749), 1,
      anon_sym_GT,
    STATE(9279), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [453154] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9280), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11694), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11692), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [453196] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9964), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11352), 1,
      sym__lowercase_identifier,
    ACTIONS(11354), 1,
      anon_sym_LPAREN,
    ACTIONS(11356), 1,
      anon_sym_LBRACK,
    ACTIONS(11358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11362), 1,
      anon_sym_LT,
    ACTIONS(11364), 1,
      anon_sym_POUND,
    ACTIONS(11366), 1,
      aux_sym_type_variable_token1,
    STATE(9281), 1,
      sym_attribute,
    STATE(9509), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(17160), 1,
      sym_extended_module_path,
    STATE(19077), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10274), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [453268] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11644), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11642), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [453310] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9424), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9426), 1,
      anon_sym_LT,
    ACTIONS(9428), 1,
      anon_sym_POUND,
    ACTIONS(9430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9434), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10692), 1,
      anon_sym_LPAREN,
    ACTIONS(10696), 1,
      anon_sym_LBRACK,
    ACTIONS(11208), 1,
      sym__lowercase_identifier,
    STATE(9283), 1,
      sym_attribute,
    STATE(9460), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(16665), 1,
      sym_extended_module_path,
    STATE(19912), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9574), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [453382] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9906), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_LBRACK,
    ACTIONS(9910), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9912), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9914), 1,
      anon_sym_LT,
    ACTIONS(9916), 1,
      anon_sym_POUND,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9920), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9922), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11318), 1,
      sym__lowercase_identifier,
    STATE(9284), 1,
      sym_attribute,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10353), 1,
      sym__constructor_argument,
    STATE(10770), 1,
      sym__simple_type,
    STATE(16934), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11018), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [453454] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11751), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11753), 1,
      anon_sym_GT,
    STATE(9285), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [453526] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10070), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10072), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11298), 1,
      sym__lowercase_identifier,
    ACTIONS(11300), 1,
      anon_sym_LPAREN,
    ACTIONS(11302), 1,
      anon_sym_LBRACK,
    ACTIONS(11304), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11306), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11308), 1,
      anon_sym_LT,
    ACTIONS(11310), 1,
      anon_sym_POUND,
    ACTIONS(11312), 1,
      aux_sym_type_variable_token1,
    STATE(9286), 1,
      sym_attribute,
    STATE(9831), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10353), 1,
      sym__constructor_argument,
    STATE(17129), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10286), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [453598] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11755), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11757), 1,
      anon_sym_GT,
    STATE(9287), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [453670] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11254), 1,
      sym__lowercase_identifier,
    ACTIONS(11400), 1,
      anon_sym_POUND,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    STATE(9288), 1,
      sym_attribute,
    STATE(9379), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17458), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11596), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11598), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [453728] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11510), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11508), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [453770] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9290), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8350), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [453812] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9424), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9426), 1,
      anon_sym_LT,
    ACTIONS(9428), 1,
      anon_sym_POUND,
    ACTIONS(9430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9434), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10692), 1,
      anon_sym_LPAREN,
    ACTIONS(10696), 1,
      anon_sym_LBRACK,
    ACTIONS(11208), 1,
      sym__lowercase_identifier,
    STATE(9291), 1,
      sym_attribute,
    STATE(9432), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(16665), 1,
      sym_extended_module_path,
    STATE(19911), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9574), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [453884] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9964), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11352), 1,
      sym__lowercase_identifier,
    ACTIONS(11354), 1,
      anon_sym_LPAREN,
    ACTIONS(11356), 1,
      anon_sym_LBRACK,
    ACTIONS(11358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11362), 1,
      anon_sym_LT,
    ACTIONS(11364), 1,
      anon_sym_POUND,
    ACTIONS(11366), 1,
      aux_sym_type_variable_token1,
    STATE(9292), 1,
      sym_attribute,
    STATE(9453), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(17160), 1,
      sym_extended_module_path,
    STATE(19107), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10274), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [453956] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9964), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11352), 1,
      sym__lowercase_identifier,
    ACTIONS(11354), 1,
      anon_sym_LPAREN,
    ACTIONS(11356), 1,
      anon_sym_LBRACK,
    ACTIONS(11358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11362), 1,
      anon_sym_LT,
    ACTIONS(11364), 1,
      anon_sym_POUND,
    ACTIONS(11366), 1,
      aux_sym_type_variable_token1,
    STATE(9293), 1,
      sym_attribute,
    STATE(9448), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(17160), 1,
      sym_extended_module_path,
    STATE(19108), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10274), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [454028] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11634), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11632), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [454070] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8354), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [454112] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11759), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11761), 1,
      anon_sym_GT,
    STATE(9296), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [454184] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11765), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11763), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [454226] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9298), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11706), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11704), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [454268] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9299), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11552), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11550), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [454310] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8358), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [454352] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(11226), 1,
      sym__lowercase_identifier,
    ACTIONS(11228), 1,
      anon_sym_LPAREN,
    ACTIONS(11230), 1,
      anon_sym_LBRACK,
    ACTIONS(11232), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11234), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11236), 1,
      anon_sym_LT,
    ACTIONS(11238), 1,
      anon_sym_POUND,
    ACTIONS(11240), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11242), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11244), 1,
      aux_sym_type_variable_token1,
    STATE(9301), 1,
      sym_attribute,
    STATE(9935), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(16889), 1,
      sym_extended_module_path,
    STATE(19631), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10886), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [454424] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8350), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8352), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [454466] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11767), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11769), 1,
      anon_sym_GT,
    STATE(9303), 1,
      sym_attribute,
    STATE(13483), 1,
      sym__simple_type,
    STATE(15397), 1,
      sym_method_type,
    STATE(16552), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [454538] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11771), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11773), 1,
      anon_sym_GT,
    STATE(9304), 1,
      sym_attribute,
    STATE(13427), 1,
      sym__simple_type,
    STATE(15717), 1,
      sym_method_type,
    STATE(16552), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [454610] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9305), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11777), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11775), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [454652] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(11226), 1,
      sym__lowercase_identifier,
    ACTIONS(11228), 1,
      anon_sym_LPAREN,
    ACTIONS(11230), 1,
      anon_sym_LBRACK,
    ACTIONS(11232), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11234), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11236), 1,
      anon_sym_LT,
    ACTIONS(11238), 1,
      anon_sym_POUND,
    ACTIONS(11240), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11242), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11244), 1,
      aux_sym_type_variable_token1,
    STATE(9306), 1,
      sym_attribute,
    STATE(9979), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(16889), 1,
      sym_extended_module_path,
    STATE(19652), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10886), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [454724] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11779), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11781), 1,
      anon_sym_GT,
    STATE(9307), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [454796] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9308), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11428), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11426), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [454838] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(11226), 1,
      sym__lowercase_identifier,
    ACTIONS(11228), 1,
      anon_sym_LPAREN,
    ACTIONS(11230), 1,
      anon_sym_LBRACK,
    ACTIONS(11232), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11234), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11236), 1,
      anon_sym_LT,
    ACTIONS(11238), 1,
      anon_sym_POUND,
    ACTIONS(11240), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11242), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11244), 1,
      aux_sym_type_variable_token1,
    STATE(9309), 1,
      sym_attribute,
    STATE(9981), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(16889), 1,
      sym_extended_module_path,
    STATE(19653), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10886), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [454910] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9310), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11765), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11763), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [454952] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11783), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11785), 1,
      anon_sym_GT,
    STATE(9311), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [455024] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11787), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11789), 1,
      anon_sym_GT,
    STATE(9312), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [455096] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11793), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11791), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [455138] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9314), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11678), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11676), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [455180] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9315), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11797), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11795), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [455222] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9316), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8362), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [455264] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9317), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8350), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [455306] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9318), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8354), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [455348] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11799), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11801), 1,
      anon_sym_GT,
    STATE(9319), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [455420] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9320), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11472), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11470), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [455462] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11803), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11805), 1,
      anon_sym_GT,
    STATE(9321), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [455534] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(11278), 1,
      sym__lowercase_identifier,
    ACTIONS(11280), 1,
      anon_sym_LPAREN,
    ACTIONS(11282), 1,
      anon_sym_LBRACK,
    ACTIONS(11284), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11286), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11288), 1,
      anon_sym_LT,
    ACTIONS(11290), 1,
      anon_sym_POUND,
    ACTIONS(11292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11296), 1,
      aux_sym_type_variable_token1,
    STATE(9322), 1,
      sym_attribute,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10346), 1,
      sym__simple_type,
    STATE(10353), 1,
      sym__constructor_argument,
    STATE(16787), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10877), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [455606] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9424), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9426), 1,
      anon_sym_LT,
    ACTIONS(9428), 1,
      anon_sym_POUND,
    ACTIONS(9430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9434), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10692), 1,
      anon_sym_LPAREN,
    ACTIONS(10696), 1,
      anon_sym_LBRACK,
    ACTIONS(11208), 1,
      sym__lowercase_identifier,
    STATE(9323), 1,
      sym_attribute,
    STATE(9493), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(16665), 1,
      sym_extended_module_path,
    STATE(19892), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9574), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [455678] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11807), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11809), 1,
      anon_sym_GT,
    STATE(9324), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [455750] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11811), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11813), 1,
      anon_sym_GT,
    STATE(9325), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [455822] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11797), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11795), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [455864] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11815), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11817), 1,
      anon_sym_GT,
    STATE(9327), 1,
      sym_attribute,
    STATE(13438), 1,
      sym__simple_type,
    STATE(15512), 1,
      sym_method_type,
    STATE(16552), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [455936] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11254), 1,
      sym__lowercase_identifier,
    ACTIONS(11400), 1,
      anon_sym_POUND,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    STATE(9328), 1,
      sym_attribute,
    STATE(9379), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17458), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11720), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11722), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [455994] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11819), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11821), 1,
      anon_sym_GT,
    STATE(9329), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [456066] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11823), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11825), 1,
      anon_sym_GT,
    STATE(9330), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [456138] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11827), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11829), 1,
      anon_sym_GT,
    STATE(9331), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [456210] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    ACTIONS(11831), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11833), 1,
      anon_sym_GT,
    STATE(9332), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [456282] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9333), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8358), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [456324] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(11278), 1,
      sym__lowercase_identifier,
    ACTIONS(11280), 1,
      anon_sym_LPAREN,
    ACTIONS(11282), 1,
      anon_sym_LBRACK,
    ACTIONS(11284), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11286), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11288), 1,
      anon_sym_LT,
    ACTIONS(11290), 1,
      anon_sym_POUND,
    ACTIONS(11292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11296), 1,
      aux_sym_type_variable_token1,
    STATE(9334), 1,
      sym_attribute,
    STATE(9876), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(16787), 1,
      sym_extended_module_path,
    STATE(20044), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10877), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [456396] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8362), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [456438] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7996), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(7998), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [456480] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10134), 1,
      anon_sym_LPAREN,
    ACTIONS(10136), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10140), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10142), 1,
      anon_sym_LT,
    ACTIONS(10144), 1,
      anon_sym_POUND,
    ACTIONS(10146), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10148), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10150), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11316), 1,
      sym__lowercase_identifier,
    STATE(9337), 1,
      sym_attribute,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10473), 1,
      sym__constructor_argument,
    STATE(10489), 1,
      sym__simple_type,
    STATE(16704), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10841), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [456552] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9338), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11262), 2,
      anon_sym_LPAREN,
      anon_sym_DOT,
    ACTIONS(8296), 23,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_of,
      anon_sym_COLON2,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [456596] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9339), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11562), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11560), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [456638] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(11278), 1,
      sym__lowercase_identifier,
    ACTIONS(11280), 1,
      anon_sym_LPAREN,
    ACTIONS(11282), 1,
      anon_sym_LBRACK,
    ACTIONS(11284), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11286), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11288), 1,
      anon_sym_LT,
    ACTIONS(11290), 1,
      anon_sym_POUND,
    ACTIONS(11292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11296), 1,
      aux_sym_type_variable_token1,
    STATE(9340), 1,
      sym_attribute,
    STATE(9874), 1,
      sym__simple_type,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(16787), 1,
      sym_extended_module_path,
    STATE(20043), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10877), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [456710] = 20,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9390), 1,
      anon_sym_LBRACE,
    ACTIONS(10134), 1,
      anon_sym_LPAREN,
    ACTIONS(10136), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10140), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10142), 1,
      anon_sym_LT,
    ACTIONS(10144), 1,
      anon_sym_POUND,
    ACTIONS(10146), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10148), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10150), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11316), 1,
      sym__lowercase_identifier,
    STATE(9341), 1,
      sym_attribute,
    STATE(10225), 1,
      sym_record_declaration,
    STATE(10489), 1,
      sym__simple_type,
    STATE(10496), 1,
      sym__constructor_argument,
    STATE(16704), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10841), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [456782] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(9342), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16688), 1,
      sym__tuple_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [456851] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11628), 1,
      sym__lowercase_identifier,
    ACTIONS(11837), 1,
      anon_sym_POUND,
    STATE(9343), 1,
      sym_attribute,
    STATE(9731), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(16902), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11596), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11598), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [456908] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9344), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11472), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11470), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [456949] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9345), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11510), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11508), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [456990] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11694), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11692), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [457031] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11839), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11841), 1,
      sym_pow_operator,
    ACTIONS(11843), 1,
      sym_mult_operator,
    STATE(1923), 1,
      sym_add_operator,
    STATE(9347), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 4,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 15,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [457082] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9348), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11600), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [457123] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11845), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11562), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11560), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [457166] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9350), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11797), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11795), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [457207] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11440), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11438), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [457248] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9352), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11472), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11470), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [457289] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9353), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11510), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11508), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [457330] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11847), 1,
      sym__lowercase_identifier,
    ACTIONS(11849), 1,
      anon_sym_POUND,
    STATE(9354), 1,
      sym_attribute,
    STATE(10244), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17325), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11596), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11598), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [457387] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11853), 1,
      anon_sym_let,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(11859), 1,
      anon_sym_COLON2,
    STATE(9355), 1,
      sym_attribute,
    STATE(9404), 1,
      aux_sym_module_binding_repeat1,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10040), 1,
      sym__module_typed,
    STATE(10596), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11855), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(11851), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [457446] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11428), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11426), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [457487] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 3,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8268), 23,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
  [457528] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11428), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11426), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [457569] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9359), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11694), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11692), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [457610] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9360), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11440), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11438), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [457651] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11444), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11442), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [457692] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(11863), 1,
      anon_sym_let,
    ACTIONS(11867), 1,
      anon_sym_COLON2,
    STATE(9272), 1,
      aux_sym_module_binding_repeat1,
    STATE(9362), 1,
      sym_attribute,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(9955), 1,
      sym__module_typed,
    STATE(10395), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11865), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(11861), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [457751] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9363), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11552), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11550), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [457792] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11634), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11632), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [457833] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9365), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11552), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11550), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [457874] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(9366), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16764), 1,
      sym__tuple_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [457943] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9367), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11634), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11632), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [457984] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11644), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11642), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [458025] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11448), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11446), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [458066] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9370), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11678), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11676), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [458107] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11578), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11576), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [458148] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9372), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11007), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
    ACTIONS(11009), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [458189] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11540), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11538), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [458230] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11480), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11478), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [458271] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11853), 1,
      anon_sym_let,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(11867), 1,
      anon_sym_COLON2,
    STATE(9362), 1,
      aux_sym_module_binding_repeat1,
    STATE(9375), 1,
      sym_attribute,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10040), 1,
      sym__module_typed,
    STATE(10596), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11855), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(11851), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [458330] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9158), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [458371] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11562), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11560), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [458412] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9378), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11536), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11534), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [458453] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9379), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11640), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11638), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [458494] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11476), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11474), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [458535] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11797), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11795), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [458576] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11444), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11442), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [458617] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11869), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9383), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [458660] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11706), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11704), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [458701] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9385), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11416), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11414), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [458742] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9386), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11644), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11642), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [458783] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11872), 1,
      sym__lowercase_identifier,
    ACTIONS(11874), 1,
      anon_sym_POUND,
    STATE(9387), 1,
      sym_attribute,
    STATE(10127), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17343), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11720), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11722), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [458840] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9388), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11496), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11494), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [458881] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11876), 1,
      anon_sym_PIPE,
    STATE(9383), 1,
      aux_sym__match_cases_repeat1,
    STATE(9389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [458926] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11876), 1,
      anon_sym_PIPE,
    STATE(9383), 1,
      aux_sym__match_cases_repeat1,
    STATE(9390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [458971] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11765), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11763), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [459012] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9392), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11880), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11878), 24,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [459053] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11872), 1,
      sym__lowercase_identifier,
    ACTIONS(11874), 1,
      anon_sym_POUND,
    STATE(9393), 1,
      sym_attribute,
    STATE(10127), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17343), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11462), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11464), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [459110] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11876), 1,
      anon_sym_PIPE,
    STATE(9389), 1,
      aux_sym__match_cases_repeat1,
    STATE(9394), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [459155] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11876), 1,
      anon_sym_PIPE,
    STATE(9390), 1,
      aux_sym__match_cases_repeat1,
    STATE(9395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [459200] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11872), 1,
      sym__lowercase_identifier,
    ACTIONS(11874), 1,
      anon_sym_POUND,
    STATE(9396), 1,
      sym_attribute,
    STATE(10127), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17343), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11454), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11456), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [459257] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11628), 1,
      sym__lowercase_identifier,
    ACTIONS(11837), 1,
      anon_sym_POUND,
    STATE(9397), 1,
      sym_attribute,
    STATE(9731), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(16902), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11462), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11464), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [459314] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11007), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11009), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [459355] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(9399), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16806), 1,
      sym__tuple_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [459424] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9400), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11578), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11576), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [459465] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 3,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8264), 23,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
  [459506] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(9402), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16621), 1,
      sym__tuple_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [459575] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9160), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(11884), 1,
      anon_sym_let,
    ACTIONS(11886), 1,
      anon_sym_EQ,
    ACTIONS(11888), 1,
      anon_sym_COLON_EQ,
    ACTIONS(11890), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9403), 1,
      sym_attribute,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10164), 1,
      sym__type_equation,
    STATE(10403), 1,
      aux_sym_type_binding_repeat1,
    STATE(10486), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11882), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [459636] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(11859), 1,
      anon_sym_COLON2,
    ACTIONS(11863), 1,
      anon_sym_let,
    STATE(9272), 1,
      aux_sym_module_binding_repeat1,
    STATE(9404), 1,
      sym_attribute,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(9955), 1,
      sym__module_typed,
    STATE(10395), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11865), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(11861), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [459695] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11847), 1,
      sym__lowercase_identifier,
    ACTIONS(11849), 1,
      anon_sym_POUND,
    STATE(9405), 1,
      sym_attribute,
    STATE(10244), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17325), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11462), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11464), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [459752] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8354), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [459793] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(9407), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16729), 1,
      sym__tuple_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [459862] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11841), 1,
      sym_pow_operator,
    STATE(1923), 1,
      sym_add_operator,
    STATE(9408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 8,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [459907] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11841), 1,
      sym_pow_operator,
    STATE(1923), 1,
      sym_add_operator,
    STATE(9409), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 8,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [459952] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11845), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11562), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11560), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [459995] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9411), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 11,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      sym__lowercase_identifier,
    ACTIONS(8284), 15,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [460036] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9258), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9256), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [460077] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11894), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11892), 24,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [460118] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9258), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9256), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [460159] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9415), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11640), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11638), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [460200] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11448), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11446), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [460241] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9417), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11536), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11534), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [460282] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11416), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11414), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [460323] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9419), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11540), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11538), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [460364] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11254), 1,
      sym__lowercase_identifier,
    ACTIONS(11400), 1,
      anon_sym_POUND,
    ACTIONS(11898), 1,
      anon_sym_STAR,
    STATE(9379), 1,
      sym_type_constructor_path,
    STATE(9420), 1,
      sym_attribute,
    STATE(10933), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17458), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11458), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11896), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [460419] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11839), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11841), 1,
      sym_pow_operator,
    ACTIONS(11843), 1,
      sym_mult_operator,
    ACTIONS(11900), 1,
      sym_concat_operator,
    STATE(1923), 1,
      sym_add_operator,
    STATE(9421), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 4,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
  [460472] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9422), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11578), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11576), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [460513] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9423), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11706), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11704), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [460554] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9424), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11600), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [460595] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11839), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11841), 1,
      sym_pow_operator,
    ACTIONS(11843), 1,
      sym_mult_operator,
    ACTIONS(11900), 1,
      sym_concat_operator,
    ACTIONS(11902), 1,
      anon_sym_COMMA,
    ACTIONS(11904), 1,
      sym_rel_operator,
    ACTIONS(11906), 1,
      sym_and_operator,
    ACTIONS(11908), 1,
      sym_or_operator,
    ACTIONS(11910), 1,
      sym_assign_operator,
    STATE(1923), 1,
      sym_add_operator,
    STATE(9425), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10332), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10330), 11,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [460658] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11628), 1,
      sym__lowercase_identifier,
    ACTIONS(11837), 1,
      anon_sym_POUND,
    STATE(9426), 1,
      sym_attribute,
    STATE(9731), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(16902), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11454), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11456), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [460715] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11436), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11434), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [460756] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8362), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [460797] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11476), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11474), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [460838] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9430), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11678), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11676), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [460879] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11839), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11841), 1,
      sym_pow_operator,
    ACTIONS(11843), 1,
      sym_mult_operator,
    ACTIONS(11900), 1,
      sym_concat_operator,
    STATE(1923), 1,
      sym_add_operator,
    STATE(9431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 4,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
  [460932] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11628), 1,
      sym__lowercase_identifier,
    ACTIONS(11837), 1,
      anon_sym_POUND,
    STATE(9432), 1,
      sym_attribute,
    STATE(9731), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(16902), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11500), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11502), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [460989] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11839), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11841), 1,
      sym_pow_operator,
    ACTIONS(11843), 1,
      sym_mult_operator,
    ACTIONS(11900), 1,
      sym_concat_operator,
    ACTIONS(11904), 1,
      sym_rel_operator,
    ACTIONS(11906), 1,
      sym_and_operator,
    ACTIONS(11908), 1,
      sym_or_operator,
    STATE(1923), 1,
      sym_add_operator,
    STATE(9433), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10344), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 13,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
  [461048] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11839), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11841), 1,
      sym_pow_operator,
    ACTIONS(11843), 1,
      sym_mult_operator,
    ACTIONS(11900), 1,
      sym_concat_operator,
    ACTIONS(11902), 1,
      anon_sym_COMMA,
    ACTIONS(11904), 1,
      sym_rel_operator,
    ACTIONS(11906), 1,
      sym_and_operator,
    ACTIONS(11908), 1,
      sym_or_operator,
    ACTIONS(11910), 1,
      sym_assign_operator,
    ACTIONS(11912), 1,
      anon_sym_SEMI,
    STATE(1923), 1,
      sym_add_operator,
    STATE(9434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9116), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9114), 10,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [461113] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8358), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [461154] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11496), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11494), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [461195] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9437), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11562), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11560), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [461236] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9438), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8354), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [461277] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11562), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11560), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [461318] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9440), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11416), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11414), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [461359] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9441), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11706), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11704), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [461400] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9442), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11916), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11914), 24,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [461441] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11872), 1,
      sym__lowercase_identifier,
    ACTIONS(11874), 1,
      anon_sym_POUND,
    STATE(9443), 1,
      sym_attribute,
    STATE(10127), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17343), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11588), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11590), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [461498] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(9444), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16636), 1,
      sym__tuple_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [461567] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9445), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11600), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [461608] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9446), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 3,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8272), 23,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
  [461649] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11476), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11474), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [461690] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11847), 1,
      sym__lowercase_identifier,
    ACTIONS(11849), 1,
      anon_sym_POUND,
    STATE(9448), 1,
      sym_attribute,
    STATE(10244), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17325), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11588), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11590), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [461747] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11847), 1,
      sym__lowercase_identifier,
    ACTIONS(11849), 1,
      anon_sym_POUND,
    STATE(9449), 1,
      sym_attribute,
    STATE(10244), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17325), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11454), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11456), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [461804] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11918), 1,
      anon_sym_COLON2,
    STATE(9450), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9158), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [461847] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9451), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11480), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11478), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [461888] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11872), 1,
      sym__lowercase_identifier,
    ACTIONS(11874), 1,
      anon_sym_POUND,
    STATE(9452), 1,
      sym_attribute,
    STATE(10127), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17343), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11500), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11502), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [461945] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11847), 1,
      sym__lowercase_identifier,
    ACTIONS(11849), 1,
      anon_sym_POUND,
    STATE(9453), 1,
      sym_attribute,
    STATE(10244), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17325), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11500), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11502), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [462002] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9160), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(11922), 1,
      anon_sym_let,
    ACTIONS(11924), 1,
      anon_sym_EQ,
    ACTIONS(11926), 1,
      anon_sym_COLON_EQ,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9454), 1,
      sym_attribute,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10206), 1,
      sym__type_equation,
    STATE(10476), 1,
      aux_sym_expression_item_repeat1,
    STATE(10595), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11920), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [462063] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11839), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11841), 1,
      sym_pow_operator,
    ACTIONS(11843), 1,
      sym_mult_operator,
    ACTIONS(11900), 1,
      sym_concat_operator,
    ACTIONS(11904), 1,
      sym_rel_operator,
    ACTIONS(11906), 1,
      sym_and_operator,
    STATE(1923), 1,
      sym_add_operator,
    STATE(9455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 13,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
  [462120] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11930), 1,
      anon_sym_else,
    STATE(8259), 1,
      sym_else_clause,
    STATE(9456), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 8,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [462165] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9457), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 11,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      sym__lowercase_identifier,
    ACTIONS(8328), 15,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [462206] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11839), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11841), 1,
      sym_pow_operator,
    ACTIONS(11843), 1,
      sym_mult_operator,
    ACTIONS(11900), 1,
      sym_concat_operator,
    ACTIONS(11904), 1,
      sym_rel_operator,
    ACTIONS(11906), 1,
      sym_and_operator,
    ACTIONS(11908), 1,
      sym_or_operator,
    STATE(1923), 1,
      sym_add_operator,
    STATE(9458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 13,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
  [462265] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8350), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [462306] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11628), 1,
      sym__lowercase_identifier,
    ACTIONS(11837), 1,
      anon_sym_POUND,
    STATE(9460), 1,
      sym_attribute,
    STATE(9731), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(16902), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11588), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11590), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [462363] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9461), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8362), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [462404] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(9462), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16814), 1,
      sym__tuple_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [462473] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11436), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11434), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [462514] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11934), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11932), 24,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [462555] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11841), 1,
      sym_pow_operator,
    ACTIONS(11843), 1,
      sym_mult_operator,
    STATE(1923), 1,
      sym_add_operator,
    STATE(9465), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [462602] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9466), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11644), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11642), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [462643] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11872), 1,
      sym__lowercase_identifier,
    ACTIONS(11874), 1,
      anon_sym_POUND,
    STATE(9467), 1,
      sym_attribute,
    STATE(10127), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17343), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11596), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11598), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [462700] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11640), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11638), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [462741] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11536), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11534), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [462782] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11634), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11632), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [462823] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11552), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11550), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [462864] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11428), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11426), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [462905] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11839), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11841), 1,
      sym_pow_operator,
    ACTIONS(11843), 1,
      sym_mult_operator,
    ACTIONS(11900), 1,
      sym_concat_operator,
    ACTIONS(11902), 1,
      anon_sym_COMMA,
    ACTIONS(11904), 1,
      sym_rel_operator,
    ACTIONS(11906), 1,
      sym_and_operator,
    ACTIONS(11908), 1,
      sym_or_operator,
    ACTIONS(11910), 1,
      sym_assign_operator,
    STATE(1923), 1,
      sym_add_operator,
    STATE(9473), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10303), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10301), 11,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [462968] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11264), 1,
      anon_sym_COLON2,
    STATE(9474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9158), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [463011] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9475), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9158), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [463052] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11628), 1,
      sym__lowercase_identifier,
    ACTIONS(11837), 1,
      anon_sym_POUND,
    STATE(9476), 1,
      sym_attribute,
    STATE(9731), 1,
      sym_type_constructor_path,
    STATE(16902), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11124), 9,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11126), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [463103] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11938), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11936), 24,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [463144] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8350), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [463185] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11942), 1,
      anon_sym_let,
    ACTIONS(11944), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9479), 2,
      sym_attribute,
      aux_sym_expression_item_repeat1,
    ACTIONS(11940), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [463230] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11947), 1,
      anon_sym_else,
    STATE(8278), 1,
      sym_else_clause,
    STATE(9480), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 8,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [463275] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(9481), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16726), 1,
      sym__tuple_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [463344] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11628), 1,
      sym__lowercase_identifier,
    ACTIONS(11837), 1,
      anon_sym_POUND,
    STATE(9482), 1,
      sym_attribute,
    STATE(9731), 1,
      sym_type_constructor_path,
    STATE(16902), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10261), 9,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(10263), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [463395] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11540), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11538), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [463436] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11839), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11841), 1,
      sym_pow_operator,
    ACTIONS(11843), 1,
      sym_mult_operator,
    ACTIONS(11900), 1,
      sym_concat_operator,
    ACTIONS(11902), 1,
      anon_sym_COMMA,
    ACTIONS(11904), 1,
      sym_rel_operator,
    ACTIONS(11906), 1,
      sym_and_operator,
    ACTIONS(11908), 1,
      sym_or_operator,
    ACTIONS(11910), 1,
      sym_assign_operator,
    STATE(1923), 1,
      sym_add_operator,
    STATE(9484), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10340), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10338), 11,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [463499] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11260), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11258), 24,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [463540] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9486), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11797), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11795), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [463581] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11472), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11470), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [463622] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9488), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11510), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11508), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [463663] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11694), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11692), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [463704] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9490), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11440), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11438), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [463745] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9491), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11444), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11442), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [463786] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9492), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8274), 3,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8276), 23,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
  [463827] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11628), 1,
      sym__lowercase_identifier,
    ACTIONS(11837), 1,
      anon_sym_POUND,
    STATE(9493), 1,
      sym_attribute,
    STATE(9731), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(16902), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11720), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11722), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [463884] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9494), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11448), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11446), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [463925] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9495), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11678), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11676), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [463966] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9496), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11390), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11388), 24,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [464007] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9497), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11480), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11478), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [464048] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(9498), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16686), 1,
      sym__tuple_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [464117] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9499), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8362), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [464158] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9500), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 11,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      sym__lowercase_identifier,
    ACTIONS(8314), 15,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [464199] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9258), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9256), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [464240] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8350), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [464281] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9503), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11496), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11494), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [464322] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11436), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11434), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [464363] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9505), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11765), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11763), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [464404] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11949), 1,
      sym__lowercase_identifier,
    ACTIONS(11951), 1,
      anon_sym_POUND,
    STATE(9506), 1,
      sym_attribute,
    STATE(10090), 1,
      sym_type_constructor_path,
    STATE(17413), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11128), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11130), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [464455] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11839), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11841), 1,
      sym_pow_operator,
    ACTIONS(11843), 1,
      sym_mult_operator,
    ACTIONS(11900), 1,
      sym_concat_operator,
    ACTIONS(11902), 1,
      anon_sym_COMMA,
    ACTIONS(11904), 1,
      sym_rel_operator,
    ACTIONS(11906), 1,
      sym_and_operator,
    ACTIONS(11908), 1,
      sym_or_operator,
    ACTIONS(11910), 1,
      sym_assign_operator,
    STATE(1923), 1,
      sym_add_operator,
    STATE(9507), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 11,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [464518] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9508), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8358), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [464559] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11847), 1,
      sym__lowercase_identifier,
    ACTIONS(11849), 1,
      anon_sym_POUND,
    STATE(9509), 1,
      sym_attribute,
    STATE(10244), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17325), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11720), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11722), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [464616] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9510), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8304), 11,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      sym__lowercase_identifier,
    ACTIONS(8306), 15,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [464657] = 20,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6951), 1,
      anon_sym_object,
    ACTIONS(8652), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8654), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(11953), 1,
      sym__lowercase_identifier,
    ACTIONS(11955), 1,
      anon_sym_let,
    ACTIONS(11957), 1,
      anon_sym_LPAREN,
    ACTIONS(11959), 1,
      anon_sym_BANG,
    ACTIONS(11961), 1,
      anon_sym_LBRACK,
    ACTIONS(11963), 1,
      anon_sym_fun,
    STATE(2537), 1,
      sym__simple_class_expression,
    STATE(9511), 1,
      sym_attribute,
    STATE(12863), 1,
      sym__class_expression,
    STATE(19003), 1,
      sym_module_path,
    STATE(20443), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8384), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [464728] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    STATE(8103), 1,
      sym_tuple_type,
    STATE(9512), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16769), 1,
      sym__tuple_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [464797] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9513), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11967), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11965), 24,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [464838] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9160), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(11888), 1,
      anon_sym_COLON_EQ,
    ACTIONS(11890), 1,
      anon_sym_constraint,
    ACTIONS(11922), 1,
      anon_sym_let,
    ACTIONS(11969), 1,
      anon_sym_EQ,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9514), 1,
      sym_attribute,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10182), 1,
      sym__type_equation,
    STATE(10455), 1,
      aux_sym_type_binding_repeat1,
    STATE(10476), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11920), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [464899] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9515), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8278), 3,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8280), 23,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
  [464940] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11930), 1,
      anon_sym_else,
    STATE(8278), 1,
      sym_else_clause,
    STATE(9516), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 8,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [464985] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9517), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8354), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [465026] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8358), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [465067] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11346), 1,
      sym__lowercase_identifier,
    ACTIONS(11558), 1,
      anon_sym_POUND,
    ACTIONS(11971), 1,
      anon_sym_STAR,
    STATE(9468), 1,
      sym_type_constructor_path,
    STATE(9519), 1,
      sym_attribute,
    STATE(10972), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17537), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11458), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11896), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [465122] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9160), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(11884), 1,
      anon_sym_let,
    ACTIONS(11926), 1,
      anon_sym_COLON_EQ,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(11973), 1,
      anon_sym_EQ,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9520), 1,
      sym_attribute,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10320), 1,
      sym__type_equation,
    STATE(10486), 1,
      aux_sym_expression_item_repeat1,
    STATE(10689), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11882), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [465183] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9521), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9158), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [465224] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11947), 1,
      anon_sym_else,
    STATE(8259), 1,
      sym_else_clause,
    STATE(9522), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 8,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [465269] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11918), 1,
      anon_sym_COLON2,
    STATE(9523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9158), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [465312] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9524), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11765), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11763), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [465353] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(1923), 1,
      sym_add_operator,
    STATE(9525), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 8,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [465396] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9526), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8124), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8126), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [465436] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6245), 1,
      anon_sym_object,
    ACTIONS(8656), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8658), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(11975), 1,
      sym__lowercase_identifier,
    ACTIONS(11977), 1,
      anon_sym_let,
    ACTIONS(11979), 1,
      anon_sym_LPAREN,
    ACTIONS(11981), 1,
      anon_sym_LBRACK,
    ACTIONS(11983), 1,
      anon_sym_fun,
    STATE(2513), 1,
      sym__simple_class_expression,
    STATE(9527), 1,
      sym_attribute,
    STATE(10414), 1,
      sym__class_expression,
    STATE(17795), 1,
      sym_module_path,
    STATE(18988), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7734), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [465504] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9528), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11510), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11508), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [465544] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9529), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11472), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11470), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [465584] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9530), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8362), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [465624] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9531), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11797), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11795), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [465664] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10340), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11985), 1,
      anon_sym_COMMA,
    ACTIONS(11987), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11989), 1,
      sym_pow_operator,
    ACTIONS(11991), 1,
      sym_mult_operator,
    ACTIONS(11993), 1,
      sym_concat_operator,
    ACTIONS(11995), 1,
      sym_rel_operator,
    ACTIONS(11997), 1,
      sym_and_operator,
    ACTIONS(11999), 1,
      sym_or_operator,
    ACTIONS(12001), 1,
      sym_assign_operator,
    STATE(2233), 1,
      sym_add_operator,
    STATE(9532), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10338), 11,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [465726] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9533), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11440), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11438), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [465766] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12003), 1,
      anon_sym_else,
    STATE(7983), 1,
      sym_else_clause,
    STATE(9534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [465810] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9535), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11428), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11426), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [465850] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10303), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11985), 1,
      anon_sym_COMMA,
    ACTIONS(11987), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11989), 1,
      sym_pow_operator,
    ACTIONS(11991), 1,
      sym_mult_operator,
    ACTIONS(11993), 1,
      sym_concat_operator,
    ACTIONS(11995), 1,
      sym_rel_operator,
    ACTIONS(11997), 1,
      sym_and_operator,
    ACTIONS(11999), 1,
      sym_or_operator,
    ACTIONS(12001), 1,
      sym_assign_operator,
    STATE(2233), 1,
      sym_add_operator,
    STATE(9536), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10301), 11,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [465912] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9537), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11694), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11692), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [465952] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8264), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [465992] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11989), 1,
      sym_pow_operator,
    ACTIONS(11991), 1,
      sym_mult_operator,
    STATE(2233), 1,
      sym_add_operator,
    STATE(9539), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [466038] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9540), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11510), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11508), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [466078] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9541), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11472), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11470), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [466118] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9542), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11797), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11795), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [466158] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11985), 1,
      anon_sym_COMMA,
    ACTIONS(11987), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11989), 1,
      sym_pow_operator,
    ACTIONS(11991), 1,
      sym_mult_operator,
    ACTIONS(11993), 1,
      sym_concat_operator,
    ACTIONS(11995), 1,
      sym_rel_operator,
    ACTIONS(11997), 1,
      sym_and_operator,
    ACTIONS(11999), 1,
      sym_or_operator,
    ACTIONS(12001), 1,
      sym_assign_operator,
    STATE(2233), 1,
      sym_add_operator,
    STATE(9543), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 11,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [466220] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11987), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11989), 1,
      sym_pow_operator,
    ACTIONS(11991), 1,
      sym_mult_operator,
    ACTIONS(11993), 1,
      sym_concat_operator,
    ACTIONS(11995), 1,
      sym_rel_operator,
    ACTIONS(11997), 1,
      sym_and_operator,
    ACTIONS(11999), 1,
      sym_or_operator,
    STATE(2233), 1,
      sym_add_operator,
    STATE(9544), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 13,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
  [466278] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11987), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11989), 1,
      sym_pow_operator,
    ACTIONS(11991), 1,
      sym_mult_operator,
    ACTIONS(11993), 1,
      sym_concat_operator,
    ACTIONS(11995), 1,
      sym_rel_operator,
    ACTIONS(11997), 1,
      sym_and_operator,
    STATE(2233), 1,
      sym_add_operator,
    STATE(9545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 13,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
  [466334] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11987), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11989), 1,
      sym_pow_operator,
    ACTIONS(11991), 1,
      sym_mult_operator,
    ACTIONS(11993), 1,
      sym_concat_operator,
    STATE(2233), 1,
      sym_add_operator,
    STATE(9546), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
  [466386] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12005), 1,
      sym__lowercase_identifier,
    ACTIONS(12007), 1,
      anon_sym_POUND,
    STATE(9547), 1,
      sym_attribute,
    STATE(10644), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17478), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11596), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11598), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [466442] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11987), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11989), 1,
      sym_pow_operator,
    ACTIONS(11991), 1,
      sym_mult_operator,
    ACTIONS(11993), 1,
      sym_concat_operator,
    STATE(2233), 1,
      sym_add_operator,
    STATE(9548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
  [466494] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11989), 1,
      sym_pow_operator,
    STATE(2233), 1,
      sym_add_operator,
    STATE(9549), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [466538] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11989), 1,
      sym_pow_operator,
    STATE(2233), 1,
      sym_add_operator,
    STATE(9550), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [466582] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11987), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11989), 1,
      sym_pow_operator,
    ACTIONS(11991), 1,
      sym_mult_operator,
    STATE(2233), 1,
      sym_add_operator,
    STATE(9551), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 3,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 15,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [466632] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10344), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11987), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11989), 1,
      sym_pow_operator,
    ACTIONS(11991), 1,
      sym_mult_operator,
    ACTIONS(11993), 1,
      sym_concat_operator,
    ACTIONS(11995), 1,
      sym_rel_operator,
    ACTIONS(11997), 1,
      sym_and_operator,
    ACTIONS(11999), 1,
      sym_or_operator,
    STATE(2233), 1,
      sym_add_operator,
    STATE(9552), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 13,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
  [466690] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9553), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11552), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11550), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [466730] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11634), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11632), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [466770] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9555), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11644), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11642), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [466810] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9556), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11440), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11438), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [466850] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11476), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11474), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [466890] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9558), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11600), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [466930] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9559), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11706), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11704), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [466970] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9560), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11444), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11442), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [467010] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9561), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11444), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11442), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [467050] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9562), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11448), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11446), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [467090] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9563), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8070), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [467130] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12009), 1,
      anon_sym_PIPE,
    STATE(9564), 1,
      sym_attribute,
    STATE(9671), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [467174] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9565), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11678), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11676), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [467214] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7929), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7931), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [467254] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9567), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7935), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [467294] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12013), 1,
      anon_sym_let,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12019), 1,
      anon_sym_fun,
    STATE(2511), 1,
      sym__simple_class_expression,
    STATE(9157), 1,
      sym__class_expression,
    STATE(9568), 1,
      sym_attribute,
    STATE(18667), 1,
      sym_value_definition,
    STATE(20390), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [467362] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12021), 1,
      sym__lowercase_identifier,
    ACTIONS(12023), 1,
      anon_sym_let,
    ACTIONS(12025), 1,
      anon_sym_LPAREN,
    ACTIONS(12027), 1,
      anon_sym_LBRACK,
    ACTIONS(12029), 1,
      anon_sym_object,
    ACTIONS(12031), 1,
      anon_sym_fun,
    ACTIONS(12033), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12035), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2488), 1,
      sym__simple_class_expression,
    STATE(9569), 1,
      sym_attribute,
    STATE(10499), 1,
      sym__class_expression,
    STATE(17641), 1,
      sym_module_path,
    STATE(19743), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7432), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [467430] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9570), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12039), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(12037), 14,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      sym__lowercase_identifier,
  [467470] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8076), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8078), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [467510] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9572), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8084), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8086), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [467550] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9573), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8088), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8090), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [467590] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9574), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11562), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11560), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [467630] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9575), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11009), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(11007), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
  [467670] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9576), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8056), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8058), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [467710] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9577), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8092), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8094), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [467750] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11918), 1,
      anon_sym_COLON2,
    STATE(9578), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9158), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [467792] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7939), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [467832] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9580), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7923), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [467872] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12013), 1,
      anon_sym_let,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12019), 1,
      anon_sym_fun,
    STATE(2511), 1,
      sym__simple_class_expression,
    STATE(9581), 1,
      sym_attribute,
    STATE(10375), 1,
      sym__class_expression,
    STATE(18667), 1,
      sym_value_definition,
    STATE(20390), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [467940] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9582), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8318), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [467980] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9583), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7911), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7913), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [468020] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12013), 1,
      anon_sym_let,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12019), 1,
      anon_sym_fun,
    STATE(2511), 1,
      sym__simple_class_expression,
    STATE(9584), 1,
      sym_attribute,
    STATE(10383), 1,
      sym__class_expression,
    STATE(18667), 1,
      sym_value_definition,
    STATE(20390), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [468088] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12013), 1,
      anon_sym_let,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12019), 1,
      anon_sym_fun,
    STATE(2511), 1,
      sym__simple_class_expression,
    STATE(9585), 1,
      sym_attribute,
    STATE(10386), 1,
      sym__class_expression,
    STATE(18667), 1,
      sym_value_definition,
    STATE(20390), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [468156] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9586), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8108), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8110), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [468196] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9587), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8112), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8114), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [468236] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9588), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8116), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8118), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [468276] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11872), 1,
      sym__lowercase_identifier,
    ACTIONS(12041), 1,
      anon_sym_POUND,
    STATE(9589), 1,
      sym_attribute,
    STATE(10350), 1,
      sym_type_constructor_path,
    STATE(17343), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11128), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11130), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [468326] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12043), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12045), 1,
      sym_pow_operator,
    ACTIONS(12047), 1,
      sym_mult_operator,
    ACTIONS(12049), 1,
      sym_concat_operator,
    ACTIONS(12051), 1,
      sym_rel_operator,
    ACTIONS(12053), 1,
      sym_and_operator,
    ACTIONS(12055), 1,
      sym_or_operator,
    STATE(2251), 1,
      sym_add_operator,
    STATE(9590), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10344), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 12,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
  [468384] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12013), 1,
      anon_sym_let,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12019), 1,
      anon_sym_fun,
    STATE(2511), 1,
      sym__simple_class_expression,
    STATE(9591), 1,
      sym_attribute,
    STATE(10406), 1,
      sym__class_expression,
    STATE(18667), 1,
      sym_value_definition,
    STATE(20390), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [468452] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9592), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8358), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [468492] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12013), 1,
      anon_sym_let,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12019), 1,
      anon_sym_fun,
    STATE(2511), 1,
      sym__simple_class_expression,
    STATE(9593), 1,
      sym_attribute,
    STATE(10414), 1,
      sym__class_expression,
    STATE(18667), 1,
      sym_value_definition,
    STATE(20390), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [468560] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12013), 1,
      anon_sym_let,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12019), 1,
      anon_sym_fun,
    STATE(2511), 1,
      sym__simple_class_expression,
    STATE(9594), 1,
      sym_attribute,
    STATE(10416), 1,
      sym__class_expression,
    STATE(18667), 1,
      sym_value_definition,
    STATE(20390), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [468628] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12043), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12045), 1,
      sym_pow_operator,
    ACTIONS(12047), 1,
      sym_mult_operator,
    STATE(2251), 1,
      sym_add_operator,
    STATE(9595), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 4,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [468678] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12009), 1,
      anon_sym_PIPE,
    STATE(9596), 1,
      sym_attribute,
    STATE(9748), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [468722] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9597), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7917), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [468762] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11949), 1,
      sym__lowercase_identifier,
    ACTIONS(12057), 1,
      anon_sym_POUND,
    STATE(9598), 1,
      sym_attribute,
    STATE(10027), 1,
      sym_type_constructor_path,
    STATE(17413), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11124), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11126), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [468812] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12045), 1,
      sym_pow_operator,
    STATE(2251), 1,
      sym_add_operator,
    STATE(9599), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 8,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 15,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [468856] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9600), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8354), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [468896] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12045), 1,
      sym_pow_operator,
    STATE(2251), 1,
      sym_add_operator,
    STATE(9601), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 8,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 15,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [468940] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12043), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12045), 1,
      sym_pow_operator,
    ACTIONS(12047), 1,
      sym_mult_operator,
    ACTIONS(12049), 1,
      sym_concat_operator,
    STATE(2251), 1,
      sym_add_operator,
    STATE(9602), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 4,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 13,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
  [468992] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12043), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12045), 1,
      sym_pow_operator,
    ACTIONS(12047), 1,
      sym_mult_operator,
    ACTIONS(12049), 1,
      sym_concat_operator,
    STATE(2251), 1,
      sym_add_operator,
    STATE(9603), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 4,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 13,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
  [469044] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12061), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9604), 1,
      sym_attribute,
    STATE(9924), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12059), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [469090] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12043), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12045), 1,
      sym_pow_operator,
    ACTIONS(12047), 1,
      sym_mult_operator,
    ACTIONS(12049), 1,
      sym_concat_operator,
    ACTIONS(12051), 1,
      sym_rel_operator,
    ACTIONS(12053), 1,
      sym_and_operator,
    ACTIONS(12055), 1,
      sym_or_operator,
    ACTIONS(12063), 1,
      anon_sym_COMMA,
    ACTIONS(12065), 1,
      anon_sym_SEMI,
    ACTIONS(12067), 1,
      sym_assign_operator,
    STATE(2251), 1,
      sym_add_operator,
    STATE(9605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9116), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9114), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [469154] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12043), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12045), 1,
      sym_pow_operator,
    ACTIONS(12047), 1,
      sym_mult_operator,
    ACTIONS(12049), 1,
      sym_concat_operator,
    ACTIONS(12051), 1,
      sym_rel_operator,
    ACTIONS(12053), 1,
      sym_and_operator,
    STATE(2251), 1,
      sym_add_operator,
    STATE(9606), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 12,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
  [469210] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12071), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12069), 23,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [469250] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12077), 1,
      anon_sym_LPAREN,
    ACTIONS(12079), 1,
      anon_sym_LBRACK,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    STATE(9608), 1,
      sym_attribute,
    STATE(10650), 1,
      sym__constructor_name,
    STATE(11137), 1,
      sym_constructor_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12075), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12081), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(12073), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [469302] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9609), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8322), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [469342] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11254), 1,
      sym__lowercase_identifier,
    ACTIONS(11400), 1,
      anon_sym_POUND,
    STATE(9379), 1,
      sym_type_constructor_path,
    STATE(9610), 1,
      sym_attribute,
    STATE(17458), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12085), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12087), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [469392] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12043), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12045), 1,
      sym_pow_operator,
    ACTIONS(12047), 1,
      sym_mult_operator,
    ACTIONS(12049), 1,
      sym_concat_operator,
    ACTIONS(12051), 1,
      sym_rel_operator,
    ACTIONS(12053), 1,
      sym_and_operator,
    ACTIONS(12055), 1,
      sym_or_operator,
    STATE(2251), 1,
      sym_add_operator,
    STATE(9611), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 12,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
  [469450] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12043), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12045), 1,
      sym_pow_operator,
    ACTIONS(12047), 1,
      sym_mult_operator,
    ACTIONS(12049), 1,
      sym_concat_operator,
    ACTIONS(12051), 1,
      sym_rel_operator,
    ACTIONS(12053), 1,
      sym_and_operator,
    ACTIONS(12055), 1,
      sym_or_operator,
    ACTIONS(12063), 1,
      anon_sym_COMMA,
    ACTIONS(12067), 1,
      sym_assign_operator,
    STATE(2251), 1,
      sym_add_operator,
    STATE(9612), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 10,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [469512] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12045), 1,
      sym_pow_operator,
    ACTIONS(12047), 1,
      sym_mult_operator,
    STATE(2251), 1,
      sym_add_operator,
    STATE(9613), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 15,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [469558] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6245), 1,
      anon_sym_object,
    ACTIONS(8656), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8658), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(11975), 1,
      sym__lowercase_identifier,
    ACTIONS(11977), 1,
      anon_sym_let,
    ACTIONS(11979), 1,
      anon_sym_LPAREN,
    ACTIONS(11981), 1,
      anon_sym_LBRACK,
    ACTIONS(11983), 1,
      anon_sym_fun,
    STATE(2513), 1,
      sym__simple_class_expression,
    STATE(9614), 1,
      sym_attribute,
    STATE(10558), 1,
      sym__class_expression,
    STATE(17795), 1,
      sym_module_path,
    STATE(18988), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7734), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [469626] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12013), 1,
      anon_sym_let,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12019), 1,
      anon_sym_fun,
    STATE(2511), 1,
      sym__simple_class_expression,
    STATE(9615), 1,
      sym_attribute,
    STATE(10435), 1,
      sym__class_expression,
    STATE(18667), 1,
      sym_value_definition,
    STATE(20390), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [469694] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12013), 1,
      anon_sym_let,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12019), 1,
      anon_sym_fun,
    STATE(2511), 1,
      sym__simple_class_expression,
    STATE(9616), 1,
      sym_attribute,
    STATE(10439), 1,
      sym__class_expression,
    STATE(18667), 1,
      sym_value_definition,
    STATE(20390), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [469762] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12043), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12045), 1,
      sym_pow_operator,
    ACTIONS(12047), 1,
      sym_mult_operator,
    ACTIONS(12049), 1,
      sym_concat_operator,
    ACTIONS(12051), 1,
      sym_rel_operator,
    ACTIONS(12053), 1,
      sym_and_operator,
    ACTIONS(12055), 1,
      sym_or_operator,
    ACTIONS(12063), 1,
      anon_sym_COMMA,
    ACTIONS(12067), 1,
      sym_assign_operator,
    STATE(2251), 1,
      sym_add_operator,
    STATE(9617), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10303), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10301), 10,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [469824] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12061), 1,
      anon_sym_let,
    STATE(9618), 1,
      sym_attribute,
    STATE(9865), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12059), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [469870] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9619), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8120), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8122), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [469910] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12043), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12045), 1,
      sym_pow_operator,
    ACTIONS(12047), 1,
      sym_mult_operator,
    ACTIONS(12049), 1,
      sym_concat_operator,
    ACTIONS(12051), 1,
      sym_rel_operator,
    ACTIONS(12053), 1,
      sym_and_operator,
    ACTIONS(12055), 1,
      sym_or_operator,
    ACTIONS(12063), 1,
      anon_sym_COMMA,
    ACTIONS(12067), 1,
      sym_assign_operator,
    STATE(2251), 1,
      sym_add_operator,
    STATE(9620), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10340), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10338), 10,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [469972] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12021), 1,
      sym__lowercase_identifier,
    ACTIONS(12023), 1,
      anon_sym_let,
    ACTIONS(12025), 1,
      anon_sym_LPAREN,
    ACTIONS(12027), 1,
      anon_sym_LBRACK,
    ACTIONS(12029), 1,
      anon_sym_object,
    ACTIONS(12031), 1,
      anon_sym_fun,
    ACTIONS(12033), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12035), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2488), 1,
      sym__simple_class_expression,
    STATE(9621), 1,
      sym_attribute,
    STATE(10490), 1,
      sym__class_expression,
    STATE(17641), 1,
      sym_module_path,
    STATE(19743), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7432), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [470040] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9622), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8052), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8054), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [470080] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9623), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8128), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8130), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [470120] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9624), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12091), 3,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12089), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [470160] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9625), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11640), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11638), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [470200] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9626), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8268), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [470240] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12021), 1,
      sym__lowercase_identifier,
    ACTIONS(12023), 1,
      anon_sym_let,
    ACTIONS(12025), 1,
      anon_sym_LPAREN,
    ACTIONS(12027), 1,
      anon_sym_LBRACK,
    ACTIONS(12029), 1,
      anon_sym_object,
    ACTIONS(12031), 1,
      anon_sym_fun,
    ACTIONS(12033), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12035), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2488), 1,
      sym__simple_class_expression,
    STATE(9627), 1,
      sym_attribute,
    STATE(10501), 1,
      sym__class_expression,
    STATE(17641), 1,
      sym_module_path,
    STATE(19743), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7432), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [470308] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11536), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11534), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [470348] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9629), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8132), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8134), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [470388] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9630), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8136), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8138), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [470428] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9631), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8148), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8150), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [470468] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8272), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [470508] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9633), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11540), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11538), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [470548] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12021), 1,
      sym__lowercase_identifier,
    ACTIONS(12023), 1,
      anon_sym_let,
    ACTIONS(12025), 1,
      anon_sym_LPAREN,
    ACTIONS(12027), 1,
      anon_sym_LBRACK,
    ACTIONS(12029), 1,
      anon_sym_object,
    ACTIONS(12031), 1,
      anon_sym_fun,
    ACTIONS(12033), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12035), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2488), 1,
      sym__simple_class_expression,
    STATE(9634), 1,
      sym_attribute,
    STATE(10533), 1,
      sym__class_expression,
    STATE(17641), 1,
      sym_module_path,
    STATE(19743), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7432), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [470616] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6951), 1,
      anon_sym_object,
    ACTIONS(8652), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8654), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(11953), 1,
      sym__lowercase_identifier,
    ACTIONS(11955), 1,
      anon_sym_let,
    ACTIONS(11957), 1,
      anon_sym_LPAREN,
    ACTIONS(11961), 1,
      anon_sym_LBRACK,
    ACTIONS(11963), 1,
      anon_sym_fun,
    STATE(2537), 1,
      sym__simple_class_expression,
    STATE(9313), 1,
      sym__class_expression,
    STATE(9635), 1,
      sym_attribute,
    STATE(19003), 1,
      sym_module_path,
    STATE(20443), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8384), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [470684] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12093), 1,
      anon_sym_let,
    ACTIONS(12095), 1,
      anon_sym_fun,
    STATE(2519), 1,
      sym__simple_class_expression,
    STATE(9636), 1,
      sym_attribute,
    STATE(10501), 1,
      sym__class_expression,
    STATE(20390), 1,
      sym_module_path,
    STATE(20409), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [470752] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9637), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11578), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11576), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [470792] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11628), 1,
      sym__lowercase_identifier,
    ACTIONS(11837), 1,
      anon_sym_POUND,
    ACTIONS(12097), 1,
      anon_sym_STAR,
    STATE(9638), 1,
      sym_attribute,
    STATE(9731), 1,
      sym_type_constructor_path,
    STATE(11184), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(16902), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11458), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11896), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [470846] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8156), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [470886] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6951), 1,
      anon_sym_object,
    ACTIONS(8652), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8654), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(11953), 1,
      sym__lowercase_identifier,
    ACTIONS(11955), 1,
      anon_sym_let,
    ACTIONS(11957), 1,
      anon_sym_LPAREN,
    ACTIONS(11961), 1,
      anon_sym_LBRACK,
    ACTIONS(11963), 1,
      anon_sym_fun,
    STATE(2537), 1,
      sym__simple_class_expression,
    STATE(9305), 1,
      sym__class_expression,
    STATE(9640), 1,
      sym_attribute,
    STATE(19003), 1,
      sym_module_path,
    STATE(20443), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8384), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [470954] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9641), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8160), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [470994] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12093), 1,
      anon_sym_let,
    ACTIONS(12095), 1,
      anon_sym_fun,
    STATE(2519), 1,
      sym__simple_class_expression,
    STATE(9642), 1,
      sym_attribute,
    STATE(10533), 1,
      sym__class_expression,
    STATE(20390), 1,
      sym_module_path,
    STATE(20409), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [471062] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11480), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11478), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [471102] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8164), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [471142] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9645), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8274), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8276), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [471182] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12093), 1,
      anon_sym_let,
    ACTIONS(12095), 1,
      anon_sym_fun,
    STATE(2519), 1,
      sym__simple_class_expression,
    STATE(9313), 1,
      sym__class_expression,
    STATE(9646), 1,
      sym_attribute,
    STATE(20390), 1,
      sym_module_path,
    STATE(20409), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [471250] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9647), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8168), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [471290] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2251), 1,
      sym_add_operator,
    STATE(9648), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 8,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [471332] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8278), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8280), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [471372] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12099), 1,
      sym__lowercase_identifier,
    ACTIONS(12101), 1,
      anon_sym_let,
    ACTIONS(12103), 1,
      anon_sym_LPAREN,
    ACTIONS(12105), 1,
      anon_sym_LBRACK,
    ACTIONS(12107), 1,
      anon_sym_object,
    ACTIONS(12109), 1,
      anon_sym_fun,
    ACTIONS(12111), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12113), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2495), 1,
      sym__simple_class_expression,
    STATE(9305), 1,
      sym__class_expression,
    STATE(9650), 1,
      sym_attribute,
    STATE(17741), 1,
      sym_module_path,
    STATE(19232), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7336), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [471440] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12093), 1,
      anon_sym_let,
    ACTIONS(12095), 1,
      anon_sym_fun,
    STATE(2519), 1,
      sym__simple_class_expression,
    STATE(9305), 1,
      sym__class_expression,
    STATE(9651), 1,
      sym_attribute,
    STATE(20390), 1,
      sym_module_path,
    STATE(20409), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [471508] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12099), 1,
      sym__lowercase_identifier,
    ACTIONS(12101), 1,
      anon_sym_let,
    ACTIONS(12103), 1,
      anon_sym_LPAREN,
    ACTIONS(12105), 1,
      anon_sym_LBRACK,
    ACTIONS(12107), 1,
      anon_sym_object,
    ACTIONS(12109), 1,
      anon_sym_fun,
    ACTIONS(12111), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12113), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2495), 1,
      sym__simple_class_expression,
    STATE(9652), 1,
      sym_attribute,
    STATE(10375), 1,
      sym__class_expression,
    STATE(17741), 1,
      sym_module_path,
    STATE(19232), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7336), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [471576] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11562), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11560), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [471616] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12099), 1,
      sym__lowercase_identifier,
    ACTIONS(12101), 1,
      anon_sym_let,
    ACTIONS(12103), 1,
      anon_sym_LPAREN,
    ACTIONS(12105), 1,
      anon_sym_LBRACK,
    ACTIONS(12107), 1,
      anon_sym_object,
    ACTIONS(12109), 1,
      anon_sym_fun,
    ACTIONS(12111), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12113), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2495), 1,
      sym__simple_class_expression,
    STATE(9313), 1,
      sym__class_expression,
    STATE(9654), 1,
      sym_attribute,
    STATE(17741), 1,
      sym_module_path,
    STATE(19232), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7336), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [471684] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12013), 1,
      anon_sym_let,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12019), 1,
      anon_sym_fun,
    STATE(2511), 1,
      sym__simple_class_expression,
    STATE(9655), 1,
      sym_attribute,
    STATE(10533), 1,
      sym__class_expression,
    STATE(18667), 1,
      sym_value_definition,
    STATE(20390), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [471752] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12013), 1,
      anon_sym_let,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12019), 1,
      anon_sym_fun,
    STATE(2511), 1,
      sym__simple_class_expression,
    STATE(9656), 1,
      sym_attribute,
    STATE(10501), 1,
      sym__class_expression,
    STATE(18667), 1,
      sym_value_definition,
    STATE(20390), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [471820] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9657), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8172), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [471860] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11847), 1,
      sym__lowercase_identifier,
    ACTIONS(12115), 1,
      anon_sym_POUND,
    STATE(9658), 1,
      sym_attribute,
    STATE(10183), 1,
      sym_type_constructor_path,
    STATE(17325), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11128), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11130), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [471910] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9659), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7907), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7909), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [471950] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12093), 1,
      anon_sym_let,
    ACTIONS(12095), 1,
      anon_sym_fun,
    STATE(2519), 1,
      sym__simple_class_expression,
    STATE(9660), 1,
      sym_attribute,
    STATE(10375), 1,
      sym__class_expression,
    STATE(20390), 1,
      sym_module_path,
    STATE(20409), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [472018] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12117), 1,
      anon_sym_DOT,
    STATE(9661), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8176), 15,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [472060] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7925), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7927), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [472100] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12099), 1,
      sym__lowercase_identifier,
    ACTIONS(12101), 1,
      anon_sym_let,
    ACTIONS(12103), 1,
      anon_sym_LPAREN,
    ACTIONS(12105), 1,
      anon_sym_LBRACK,
    ACTIONS(12107), 1,
      anon_sym_object,
    ACTIONS(12109), 1,
      anon_sym_fun,
    ACTIONS(12111), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12113), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2495), 1,
      sym__simple_class_expression,
    STATE(9663), 1,
      sym_attribute,
    STATE(10383), 1,
      sym__class_expression,
    STATE(17741), 1,
      sym_module_path,
    STATE(19232), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7336), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [472168] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12013), 1,
      anon_sym_let,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12019), 1,
      anon_sym_fun,
    STATE(2511), 1,
      sym__simple_class_expression,
    STATE(9664), 1,
      sym_attribute,
    STATE(10558), 1,
      sym__class_expression,
    STATE(18667), 1,
      sym_value_definition,
    STATE(20390), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [472236] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12099), 1,
      sym__lowercase_identifier,
    ACTIONS(12101), 1,
      anon_sym_let,
    ACTIONS(12103), 1,
      anon_sym_LPAREN,
    ACTIONS(12105), 1,
      anon_sym_LBRACK,
    ACTIONS(12107), 1,
      anon_sym_object,
    ACTIONS(12109), 1,
      anon_sym_fun,
    ACTIONS(12111), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12113), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2495), 1,
      sym__simple_class_expression,
    STATE(9665), 1,
      sym_attribute,
    STATE(10386), 1,
      sym__class_expression,
    STATE(17741), 1,
      sym_module_path,
    STATE(19232), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7336), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [472304] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9666), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8336), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [472344] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11496), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11494), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [472384] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7777), 1,
      anon_sym_object,
    ACTIONS(7789), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7791), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12119), 1,
      sym__lowercase_identifier,
    ACTIONS(12121), 1,
      anon_sym_let,
    ACTIONS(12123), 1,
      anon_sym_LPAREN,
    ACTIONS(12125), 1,
      anon_sym_LBRACK,
    ACTIONS(12127), 1,
      anon_sym_fun,
    STATE(2854), 1,
      sym__simple_class_expression,
    STATE(9668), 1,
      sym_attribute,
    STATE(16035), 1,
      sym__class_expression,
    STATE(17854), 1,
      sym_module_path,
    STATE(20314), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(9895), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [472452] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7903), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7905), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [472492] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9670), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11007), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11009), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [472532] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12009), 1,
      anon_sym_PIPE,
    STATE(9671), 1,
      sym_attribute,
    STATE(9753), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [472576] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9672), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8140), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8142), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [472616] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9673), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8200), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [472656] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8284), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [472696] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9675), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8184), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [472736] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12099), 1,
      sym__lowercase_identifier,
    ACTIONS(12101), 1,
      anon_sym_let,
    ACTIONS(12103), 1,
      anon_sym_LPAREN,
    ACTIONS(12105), 1,
      anon_sym_LBRACK,
    ACTIONS(12107), 1,
      anon_sym_object,
    ACTIONS(12109), 1,
      anon_sym_fun,
    ACTIONS(12111), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12113), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2495), 1,
      sym__simple_class_expression,
    STATE(9676), 1,
      sym_attribute,
    STATE(10406), 1,
      sym__class_expression,
    STATE(17741), 1,
      sym_module_path,
    STATE(19232), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7336), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [472804] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12099), 1,
      sym__lowercase_identifier,
    ACTIONS(12101), 1,
      anon_sym_let,
    ACTIONS(12103), 1,
      anon_sym_LPAREN,
    ACTIONS(12105), 1,
      anon_sym_LBRACK,
    ACTIONS(12107), 1,
      anon_sym_object,
    ACTIONS(12109), 1,
      anon_sym_fun,
    ACTIONS(12111), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12113), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2495), 1,
      sym__simple_class_expression,
    STATE(9677), 1,
      sym_attribute,
    STATE(10414), 1,
      sym__class_expression,
    STATE(17741), 1,
      sym_module_path,
    STATE(19232), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7336), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [472872] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8064), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8066), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [472912] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12099), 1,
      sym__lowercase_identifier,
    ACTIONS(12101), 1,
      anon_sym_let,
    ACTIONS(12103), 1,
      anon_sym_LPAREN,
    ACTIONS(12105), 1,
      anon_sym_LBRACK,
    ACTIONS(12107), 1,
      anon_sym_object,
    ACTIONS(12109), 1,
      anon_sym_fun,
    ACTIONS(12111), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12113), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2495), 1,
      sym__simple_class_expression,
    STATE(9679), 1,
      sym_attribute,
    STATE(10416), 1,
      sym__class_expression,
    STATE(17741), 1,
      sym_module_path,
    STATE(19232), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7336), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [472980] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8204), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [473020] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9681), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8340), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [473060] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6245), 1,
      anon_sym_object,
    ACTIONS(8656), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8658), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(11975), 1,
      sym__lowercase_identifier,
    ACTIONS(11977), 1,
      anon_sym_let,
    ACTIONS(11979), 1,
      anon_sym_LPAREN,
    ACTIONS(11981), 1,
      anon_sym_LBRACK,
    ACTIONS(11983), 1,
      anon_sym_fun,
    STATE(2513), 1,
      sym__simple_class_expression,
    STATE(9682), 1,
      sym_attribute,
    STATE(10490), 1,
      sym__class_expression,
    STATE(17795), 1,
      sym_module_path,
    STATE(18988), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7734), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [473128] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12129), 1,
      anon_sym_else,
    STATE(7983), 1,
      sym_else_clause,
    STATE(9683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [473172] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12133), 1,
      anon_sym_let,
    STATE(9684), 1,
      sym_attribute,
    STATE(9853), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12131), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [473218] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9685), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12137), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12135), 23,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [473258] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9686), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8208), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8210), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [473298] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10332), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11985), 1,
      anon_sym_COMMA,
    ACTIONS(11987), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11989), 1,
      sym_pow_operator,
    ACTIONS(11991), 1,
      sym_mult_operator,
    ACTIONS(11993), 1,
      sym_concat_operator,
    ACTIONS(11995), 1,
      sym_rel_operator,
    ACTIONS(11997), 1,
      sym_and_operator,
    ACTIONS(11999), 1,
      sym_or_operator,
    ACTIONS(12001), 1,
      sym_assign_operator,
    STATE(2233), 1,
      sym_add_operator,
    STATE(9687), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10330), 11,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [473360] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(12139), 1,
      anon_sym_COLON2,
    STATE(9688), 1,
      sym_attribute,
    STATE(9742), 1,
      aux_sym_module_binding_repeat1,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10040), 1,
      sym__module_typed,
    STATE(10596), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11855), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(11851), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [473416] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6245), 1,
      anon_sym_object,
    ACTIONS(8656), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8658), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(11975), 1,
      sym__lowercase_identifier,
    ACTIONS(11977), 1,
      anon_sym_let,
    ACTIONS(11979), 1,
      anon_sym_LPAREN,
    ACTIONS(11981), 1,
      anon_sym_LBRACK,
    ACTIONS(11983), 1,
      anon_sym_fun,
    STATE(2513), 1,
      sym__simple_class_expression,
    STATE(9689), 1,
      sym_attribute,
    STATE(10499), 1,
      sym__class_expression,
    STATE(17795), 1,
      sym_module_path,
    STATE(18988), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7734), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [473484] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9690), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12143), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12141), 23,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [473524] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12013), 1,
      anon_sym_let,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12019), 1,
      anon_sym_fun,
    STATE(2511), 1,
      sym__simple_class_expression,
    STATE(9691), 1,
      sym_attribute,
    STATE(10633), 1,
      sym__class_expression,
    STATE(18667), 1,
      sym_value_definition,
    STATE(20390), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [473592] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9692), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8074), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [473632] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11949), 1,
      sym__lowercase_identifier,
    ACTIONS(12057), 1,
      anon_sym_POUND,
    STATE(9693), 1,
      sym_attribute,
    STATE(10027), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17413), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11596), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11598), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [473688] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12093), 1,
      anon_sym_let,
    ACTIONS(12095), 1,
      anon_sym_fun,
    STATE(2519), 1,
      sym__simple_class_expression,
    STATE(9694), 1,
      sym_attribute,
    STATE(10383), 1,
      sym__class_expression,
    STATE(20390), 1,
      sym_module_path,
    STATE(20409), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [473756] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11949), 1,
      sym__lowercase_identifier,
    ACTIONS(12057), 1,
      anon_sym_POUND,
    STATE(9695), 1,
      sym_attribute,
    STATE(10027), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17413), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11588), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11590), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [473812] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9696), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8212), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8214), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [473852] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12099), 1,
      sym__lowercase_identifier,
    ACTIONS(12101), 1,
      anon_sym_let,
    ACTIONS(12103), 1,
      anon_sym_LPAREN,
    ACTIONS(12105), 1,
      anon_sym_LBRACK,
    ACTIONS(12107), 1,
      anon_sym_object,
    ACTIONS(12109), 1,
      anon_sym_fun,
    ACTIONS(12111), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12113), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2495), 1,
      sym__simple_class_expression,
    STATE(9157), 1,
      sym__class_expression,
    STATE(9697), 1,
      sym_attribute,
    STATE(17741), 1,
      sym_module_path,
    STATE(19232), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7336), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [473920] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12013), 1,
      anon_sym_let,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12019), 1,
      anon_sym_fun,
    STATE(2511), 1,
      sym__simple_class_expression,
    STATE(9698), 1,
      sym_attribute,
    STATE(10657), 1,
      sym__class_expression,
    STATE(18667), 1,
      sym_value_definition,
    STATE(20390), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [473988] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12005), 1,
      sym__lowercase_identifier,
    ACTIONS(12007), 1,
      anon_sym_POUND,
    STATE(9699), 1,
      sym_attribute,
    STATE(10644), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17478), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11462), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11464), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [474044] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12093), 1,
      anon_sym_let,
    ACTIONS(12095), 1,
      anon_sym_fun,
    STATE(2519), 1,
      sym__simple_class_expression,
    STATE(9700), 1,
      sym_attribute,
    STATE(10386), 1,
      sym__class_expression,
    STATE(20390), 1,
      sym_module_path,
    STATE(20409), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [474112] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12005), 1,
      sym__lowercase_identifier,
    ACTIONS(12007), 1,
      anon_sym_POUND,
    STATE(9701), 1,
      sym_attribute,
    STATE(10644), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17478), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11454), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11456), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [474168] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8220), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [474208] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9703), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8224), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [474248] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12147), 1,
      anon_sym_let,
    STATE(9604), 1,
      aux_sym_expression_item_repeat1,
    STATE(9704), 1,
      sym_attribute,
    STATE(9924), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12145), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [474294] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8296), 23,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_of,
      anon_sym_COLON2,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [474334] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12129), 1,
      anon_sym_else,
    STATE(7952), 1,
      sym_else_clause,
    STATE(9706), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [474378] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9707), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11578), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11576), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [474418] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11949), 1,
      sym__lowercase_identifier,
    ACTIONS(12057), 1,
      anon_sym_POUND,
    STATE(9708), 1,
      sym_attribute,
    STATE(10027), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17413), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11500), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11502), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [474474] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12013), 1,
      anon_sym_let,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12019), 1,
      anon_sym_fun,
    STATE(2511), 1,
      sym__simple_class_expression,
    STATE(9313), 1,
      sym__class_expression,
    STATE(9709), 1,
      sym_attribute,
    STATE(18667), 1,
      sym_value_definition,
    STATE(20390), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [474542] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12013), 1,
      anon_sym_let,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12019), 1,
      anon_sym_fun,
    STATE(2511), 1,
      sym__simple_class_expression,
    STATE(9305), 1,
      sym__class_expression,
    STATE(9710), 1,
      sym_attribute,
    STATE(18667), 1,
      sym_value_definition,
    STATE(20390), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [474610] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9711), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11007), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
    ACTIONS(11009), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [474650] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12151), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9712), 1,
      sym_attribute,
    STATE(9924), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12149), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [474696] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9713), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11540), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11538), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [474736] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9714), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11436), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11434), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [474776] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12005), 1,
      sym__lowercase_identifier,
    ACTIONS(12007), 1,
      anon_sym_POUND,
    STATE(9715), 1,
      sym_attribute,
    STATE(10644), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17478), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11720), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11722), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [474832] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9716), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11436), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11434), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [474872] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9717), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8096), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8098), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [474912] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12093), 1,
      anon_sym_let,
    ACTIONS(12095), 1,
      anon_sym_fun,
    STATE(2519), 1,
      sym__simple_class_expression,
    STATE(9718), 1,
      sym_attribute,
    STATE(10499), 1,
      sym__class_expression,
    STATE(20390), 1,
      sym_module_path,
    STATE(20409), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [474980] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9719), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8232), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [475020] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9720), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8236), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [475060] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9721), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11845), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11562), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11560), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [475102] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9722), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8240), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [475142] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12099), 1,
      sym__lowercase_identifier,
    ACTIONS(12101), 1,
      anon_sym_let,
    ACTIONS(12103), 1,
      anon_sym_LPAREN,
    ACTIONS(12105), 1,
      anon_sym_LBRACK,
    ACTIONS(12107), 1,
      anon_sym_object,
    ACTIONS(12109), 1,
      anon_sym_fun,
    ACTIONS(12111), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12113), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2495), 1,
      sym__simple_class_expression,
    STATE(9723), 1,
      sym_attribute,
    STATE(10435), 1,
      sym__class_expression,
    STATE(17741), 1,
      sym_module_path,
    STATE(19232), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7336), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [475210] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9724), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11536), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11534), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [475250] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12099), 1,
      sym__lowercase_identifier,
    ACTIONS(12101), 1,
      anon_sym_let,
    ACTIONS(12103), 1,
      anon_sym_LPAREN,
    ACTIONS(12105), 1,
      anon_sym_LBRACK,
    ACTIONS(12107), 1,
      anon_sym_object,
    ACTIONS(12109), 1,
      anon_sym_fun,
    ACTIONS(12111), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12113), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2495), 1,
      sym__simple_class_expression,
    STATE(9725), 1,
      sym_attribute,
    STATE(10439), 1,
      sym__class_expression,
    STATE(17741), 1,
      sym_module_path,
    STATE(19232), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7336), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [475318] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9116), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11985), 1,
      anon_sym_COMMA,
    ACTIONS(11987), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11989), 1,
      sym_pow_operator,
    ACTIONS(11991), 1,
      sym_mult_operator,
    ACTIONS(11993), 1,
      sym_concat_operator,
    ACTIONS(11995), 1,
      sym_rel_operator,
    ACTIONS(11997), 1,
      sym_and_operator,
    ACTIONS(11999), 1,
      sym_or_operator,
    ACTIONS(12001), 1,
      sym_assign_operator,
    ACTIONS(12153), 1,
      anon_sym_SEMI,
    STATE(2233), 1,
      sym_add_operator,
    STATE(9726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9114), 10,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [475382] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9727), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8104), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8106), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [475422] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9160), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(12155), 1,
      anon_sym_EQ,
    ACTIONS(12157), 1,
      anon_sym_COLON_EQ,
    ACTIONS(12159), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9728), 1,
      sym_attribute,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10398), 1,
      sym__type_equation,
    STATE(10486), 1,
      aux_sym_expression_item_repeat1,
    STATE(10980), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11882), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [475480] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9729), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8144), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8146), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [475520] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9730), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9158), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [475560] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11640), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11638), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [475600] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9732), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8350), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [475640] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9733), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8244), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [475680] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9734), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12163), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12161), 23,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [475720] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9735), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12167), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12165), 23,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [475760] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(9736), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8296), 15,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [475802] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8248), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [475842] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7777), 1,
      anon_sym_object,
    ACTIONS(7789), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7791), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12119), 1,
      sym__lowercase_identifier,
    ACTIONS(12121), 1,
      anon_sym_let,
    ACTIONS(12123), 1,
      anon_sym_LPAREN,
    ACTIONS(12125), 1,
      anon_sym_LBRACK,
    ACTIONS(12127), 1,
      anon_sym_fun,
    STATE(2854), 1,
      sym__simple_class_expression,
    STATE(9738), 1,
      sym_attribute,
    STATE(16384), 1,
      sym__class_expression,
    STATE(17854), 1,
      sym_module_path,
    STATE(20314), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(9895), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [475910] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9739), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8304), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8306), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [475950] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9740), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8002), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8004), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [475990] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9741), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8314), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [476030] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(12139), 1,
      anon_sym_COLON2,
    STATE(9272), 1,
      aux_sym_module_binding_repeat1,
    STATE(9742), 1,
      sym_attribute,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(9955), 1,
      sym__module_typed,
    STATE(10395), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11865), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(11861), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [476086] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12013), 1,
      anon_sym_let,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12019), 1,
      anon_sym_fun,
    STATE(2511), 1,
      sym__simple_class_expression,
    STATE(9743), 1,
      sym_attribute,
    STATE(10499), 1,
      sym__class_expression,
    STATE(18667), 1,
      sym_value_definition,
    STATE(20390), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [476154] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9744), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11448), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11446), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [476194] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12093), 1,
      anon_sym_let,
    ACTIONS(12095), 1,
      anon_sym_fun,
    STATE(2519), 1,
      sym__simple_class_expression,
    STATE(9745), 1,
      sym_attribute,
    STATE(10406), 1,
      sym__class_expression,
    STATE(20390), 1,
      sym_module_path,
    STATE(20409), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [476262] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9746), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11678), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11676), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [476302] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9747), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11480), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11478), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [476342] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12009), 1,
      anon_sym_PIPE,
    STATE(9748), 1,
      sym_attribute,
    STATE(9753), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [476386] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6245), 1,
      anon_sym_object,
    ACTIONS(8656), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8658), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(11975), 1,
      sym__lowercase_identifier,
    ACTIONS(11977), 1,
      anon_sym_let,
    ACTIONS(11979), 1,
      anon_sym_LPAREN,
    ACTIONS(11981), 1,
      anon_sym_LBRACK,
    ACTIONS(11983), 1,
      anon_sym_fun,
    STATE(2513), 1,
      sym__simple_class_expression,
    STATE(9749), 1,
      sym_attribute,
    STATE(10657), 1,
      sym__class_expression,
    STATE(17795), 1,
      sym_module_path,
    STATE(18988), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7734), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [476454] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12093), 1,
      anon_sym_let,
    ACTIONS(12095), 1,
      anon_sym_fun,
    STATE(2519), 1,
      sym__simple_class_expression,
    STATE(9750), 1,
      sym_attribute,
    STATE(10414), 1,
      sym__class_expression,
    STATE(20390), 1,
      sym_module_path,
    STATE(20409), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [476522] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12021), 1,
      sym__lowercase_identifier,
    ACTIONS(12023), 1,
      anon_sym_let,
    ACTIONS(12025), 1,
      anon_sym_LPAREN,
    ACTIONS(12027), 1,
      anon_sym_LBRACK,
    ACTIONS(12029), 1,
      anon_sym_object,
    ACTIONS(12031), 1,
      anon_sym_fun,
    ACTIONS(12033), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12035), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2488), 1,
      sym__simple_class_expression,
    STATE(9157), 1,
      sym__class_expression,
    STATE(9751), 1,
      sym_attribute,
    STATE(17641), 1,
      sym_module_path,
    STATE(19743), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7432), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [476590] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(9752), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8296), 15,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [476632] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12169), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9753), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [476674] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12021), 1,
      sym__lowercase_identifier,
    ACTIONS(12023), 1,
      anon_sym_let,
    ACTIONS(12025), 1,
      anon_sym_LPAREN,
    ACTIONS(12027), 1,
      anon_sym_LBRACK,
    ACTIONS(12029), 1,
      anon_sym_object,
    ACTIONS(12031), 1,
      anon_sym_fun,
    ACTIONS(12033), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12035), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2488), 1,
      sym__simple_class_expression,
    STATE(9754), 1,
      sym_attribute,
    STATE(10633), 1,
      sym__class_expression,
    STATE(17641), 1,
      sym_module_path,
    STATE(19743), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7432), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [476742] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9755), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8180), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [476782] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9756), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8328), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [476822] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11765), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11763), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [476862] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11428), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11426), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [476902] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9759), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11552), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11550), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [476942] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11949), 1,
      sym__lowercase_identifier,
    ACTIONS(12057), 1,
      anon_sym_POUND,
    STATE(9760), 1,
      sym_attribute,
    STATE(10027), 1,
      sym_type_constructor_path,
    STATE(17413), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10261), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(10263), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [476992] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12093), 1,
      anon_sym_let,
    ACTIONS(12095), 1,
      anon_sym_fun,
    STATE(2519), 1,
      sym__simple_class_expression,
    STATE(9761), 1,
      sym_attribute,
    STATE(10416), 1,
      sym__class_expression,
    STATE(20390), 1,
      sym_module_path,
    STATE(20409), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [477060] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11949), 1,
      sym__lowercase_identifier,
    ACTIONS(12057), 1,
      anon_sym_POUND,
    STATE(9762), 1,
      sym_attribute,
    STATE(10027), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17413), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11720), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11722), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [477116] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11847), 1,
      sym__lowercase_identifier,
    ACTIONS(11849), 1,
      anon_sym_POUND,
    ACTIONS(12172), 1,
      anon_sym_STAR,
    STATE(9763), 1,
      sym_attribute,
    STATE(10244), 1,
      sym_type_constructor_path,
    STATE(11066), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17325), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11458), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11896), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [477170] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6245), 1,
      anon_sym_object,
    ACTIONS(8656), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8658), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(11975), 1,
      sym__lowercase_identifier,
    ACTIONS(11977), 1,
      anon_sym_let,
    ACTIONS(11979), 1,
      anon_sym_LPAREN,
    ACTIONS(11981), 1,
      anon_sym_LBRACK,
    ACTIONS(11983), 1,
      anon_sym_fun,
    STATE(2513), 1,
      sym__simple_class_expression,
    STATE(9764), 1,
      sym_attribute,
    STATE(10633), 1,
      sym__class_expression,
    STATE(17795), 1,
      sym_module_path,
    STATE(18988), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7734), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [477238] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11346), 1,
      sym__lowercase_identifier,
    ACTIONS(11558), 1,
      anon_sym_POUND,
    STATE(9468), 1,
      sym_type_constructor_path,
    STATE(9765), 1,
      sym_attribute,
    STATE(17537), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12085), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12087), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [477288] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12176), 3,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12174), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [477328] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9767), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11634), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11632), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [477368] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9768), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11845), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11562), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11560), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [477410] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11644), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11642), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [477450] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9770), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8192), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [477490] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7777), 1,
      anon_sym_object,
    ACTIONS(7789), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7791), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12119), 1,
      sym__lowercase_identifier,
    ACTIONS(12121), 1,
      anon_sym_let,
    ACTIONS(12123), 1,
      anon_sym_LPAREN,
    ACTIONS(12125), 1,
      anon_sym_LBRACK,
    ACTIONS(12127), 1,
      anon_sym_fun,
    STATE(2854), 1,
      sym__simple_class_expression,
    STATE(9771), 1,
      sym_attribute,
    STATE(15321), 1,
      sym__class_expression,
    STATE(17854), 1,
      sym_module_path,
    STATE(20314), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(9895), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [477558] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9772), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8196), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [477598] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7996), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7998), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [477638] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7777), 1,
      anon_sym_object,
    ACTIONS(7789), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7791), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12119), 1,
      sym__lowercase_identifier,
    ACTIONS(12121), 1,
      anon_sym_let,
    ACTIONS(12123), 1,
      anon_sym_LPAREN,
    ACTIONS(12125), 1,
      anon_sym_LBRACK,
    ACTIONS(12127), 1,
      anon_sym_fun,
    STATE(2854), 1,
      sym__simple_class_expression,
    STATE(9774), 1,
      sym_attribute,
    STATE(16191), 1,
      sym__class_expression,
    STATE(17854), 1,
      sym_module_path,
    STATE(20314), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(9895), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [477706] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9775), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9258), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9256), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [477746] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7777), 1,
      anon_sym_object,
    ACTIONS(7789), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7791), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12119), 1,
      sym__lowercase_identifier,
    ACTIONS(12121), 1,
      anon_sym_let,
    ACTIONS(12123), 1,
      anon_sym_LPAREN,
    ACTIONS(12125), 1,
      anon_sym_LBRACK,
    ACTIONS(12127), 1,
      anon_sym_fun,
    STATE(2854), 1,
      sym__simple_class_expression,
    STATE(9305), 1,
      sym__class_expression,
    STATE(9776), 1,
      sym_attribute,
    STATE(17854), 1,
      sym_module_path,
    STATE(20314), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(9895), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [477814] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12099), 1,
      sym__lowercase_identifier,
    ACTIONS(12101), 1,
      anon_sym_let,
    ACTIONS(12103), 1,
      anon_sym_LPAREN,
    ACTIONS(12105), 1,
      anon_sym_LBRACK,
    ACTIONS(12107), 1,
      anon_sym_object,
    ACTIONS(12109), 1,
      anon_sym_fun,
    ACTIONS(12111), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12113), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2495), 1,
      sym__simple_class_expression,
    STATE(9777), 1,
      sym_attribute,
    STATE(10558), 1,
      sym__class_expression,
    STATE(17741), 1,
      sym_module_path,
    STATE(19232), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7336), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [477882] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7777), 1,
      anon_sym_object,
    ACTIONS(7789), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7791), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12119), 1,
      sym__lowercase_identifier,
    ACTIONS(12121), 1,
      anon_sym_let,
    ACTIONS(12123), 1,
      anon_sym_LPAREN,
    ACTIONS(12125), 1,
      anon_sym_LBRACK,
    ACTIONS(12127), 1,
      anon_sym_fun,
    STATE(2854), 1,
      sym__simple_class_expression,
    STATE(9313), 1,
      sym__class_expression,
    STATE(9778), 1,
      sym_attribute,
    STATE(17854), 1,
      sym_module_path,
    STATE(20314), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(9895), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [477950] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12099), 1,
      sym__lowercase_identifier,
    ACTIONS(12101), 1,
      anon_sym_let,
    ACTIONS(12103), 1,
      anon_sym_LPAREN,
    ACTIONS(12105), 1,
      anon_sym_LBRACK,
    ACTIONS(12107), 1,
      anon_sym_object,
    ACTIONS(12109), 1,
      anon_sym_fun,
    ACTIONS(12111), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12113), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2495), 1,
      sym__simple_class_expression,
    STATE(9779), 1,
      sym_attribute,
    STATE(10533), 1,
      sym__class_expression,
    STATE(17741), 1,
      sym_module_path,
    STATE(19232), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7336), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [478018] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9780), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11416), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11414), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [478058] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12093), 1,
      anon_sym_let,
    ACTIONS(12095), 1,
      anon_sym_fun,
    STATE(2519), 1,
      sym__simple_class_expression,
    STATE(9781), 1,
      sym_attribute,
    STATE(10558), 1,
      sym__class_expression,
    STATE(20390), 1,
      sym_module_path,
    STATE(20409), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [478126] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2233), 1,
      sym_add_operator,
    STATE(9782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [478168] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9783), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11845), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11562), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11560), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [478210] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9784), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8060), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8062), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [478250] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12099), 1,
      sym__lowercase_identifier,
    ACTIONS(12101), 1,
      anon_sym_let,
    ACTIONS(12103), 1,
      anon_sym_LPAREN,
    ACTIONS(12105), 1,
      anon_sym_LBRACK,
    ACTIONS(12107), 1,
      anon_sym_object,
    ACTIONS(12109), 1,
      anon_sym_fun,
    ACTIONS(12111), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12113), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2495), 1,
      sym__simple_class_expression,
    STATE(9785), 1,
      sym_attribute,
    STATE(10501), 1,
      sym__class_expression,
    STATE(17741), 1,
      sym_module_path,
    STATE(19232), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7336), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [478318] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9258), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9256), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [478358] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9787), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12180), 3,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12178), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [478398] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9788), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9158), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [478438] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12003), 1,
      anon_sym_else,
    STATE(7952), 1,
      sym_else_clause,
    STATE(9789), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [478482] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11949), 1,
      sym__lowercase_identifier,
    ACTIONS(12057), 1,
      anon_sym_POUND,
    STATE(9790), 1,
      sym_attribute,
    STATE(10027), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17413), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11462), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11464), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [478538] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9791), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8350), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [478578] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9792), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8354), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [478618] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11949), 1,
      sym__lowercase_identifier,
    ACTIONS(12057), 1,
      anon_sym_POUND,
    STATE(9793), 1,
      sym_attribute,
    STATE(10027), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17413), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11454), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11456), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [478674] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9160), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(12157), 1,
      anon_sym_COLON_EQ,
    ACTIONS(12159), 1,
      anon_sym_constraint,
    ACTIONS(12182), 1,
      anon_sym_EQ,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9794), 1,
      sym_attribute,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10476), 1,
      aux_sym_expression_item_repeat1,
    STATE(10511), 1,
      sym__type_equation,
    STATE(10958), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11920), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [478732] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9795), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8358), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [478772] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12117), 1,
      anon_sym_DOT,
    ACTIONS(12184), 1,
      anon_sym_POUND,
    ACTIONS(12186), 1,
      sym_hash_operator,
    STATE(9796), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9742), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9740), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [478818] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12117), 1,
      anon_sym_DOT,
    ACTIONS(12184), 1,
      anon_sym_POUND,
    ACTIONS(12186), 1,
      sym_hash_operator,
    STATE(9797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9752), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9750), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [478864] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7777), 1,
      anon_sym_object,
    ACTIONS(7789), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7791), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12119), 1,
      sym__lowercase_identifier,
    ACTIONS(12121), 1,
      anon_sym_let,
    ACTIONS(12123), 1,
      anon_sym_LPAREN,
    ACTIONS(12125), 1,
      anon_sym_LBRACK,
    ACTIONS(12127), 1,
      anon_sym_fun,
    STATE(2854), 1,
      sym__simple_class_expression,
    STATE(9798), 1,
      sym_attribute,
    STATE(15227), 1,
      sym__class_expression,
    STATE(17854), 1,
      sym_module_path,
    STATE(20314), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(9895), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [478932] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12093), 1,
      anon_sym_let,
    ACTIONS(12095), 1,
      anon_sym_fun,
    STATE(2519), 1,
      sym__simple_class_expression,
    STATE(9799), 1,
      sym_attribute,
    STATE(10657), 1,
      sym__class_expression,
    STATE(20390), 1,
      sym_module_path,
    STATE(20409), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [479000] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12021), 1,
      sym__lowercase_identifier,
    ACTIONS(12023), 1,
      anon_sym_let,
    ACTIONS(12025), 1,
      anon_sym_LPAREN,
    ACTIONS(12027), 1,
      anon_sym_LBRACK,
    ACTIONS(12029), 1,
      anon_sym_object,
    ACTIONS(12031), 1,
      anon_sym_fun,
    ACTIONS(12033), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12035), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2488), 1,
      sym__simple_class_expression,
    STATE(9800), 1,
      sym_attribute,
    STATE(10558), 1,
      sym__class_expression,
    STATE(17641), 1,
      sym_module_path,
    STATE(19743), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7432), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [479068] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12013), 1,
      anon_sym_let,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12019), 1,
      anon_sym_fun,
    STATE(2511), 1,
      sym__simple_class_expression,
    STATE(9801), 1,
      sym_attribute,
    STATE(10490), 1,
      sym__class_expression,
    STATE(18667), 1,
      sym_value_definition,
    STATE(20390), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [479136] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12093), 1,
      anon_sym_let,
    ACTIONS(12095), 1,
      anon_sym_fun,
    STATE(2519), 1,
      sym__simple_class_expression,
    STATE(9157), 1,
      sym__class_expression,
    STATE(9802), 1,
      sym_attribute,
    STATE(20390), 1,
      sym_module_path,
    STATE(20409), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [479204] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8362), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [479244] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9804), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12039), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(12037), 13,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      sym__lowercase_identifier,
  [479284] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12099), 1,
      sym__lowercase_identifier,
    ACTIONS(12101), 1,
      anon_sym_let,
    ACTIONS(12103), 1,
      anon_sym_LPAREN,
    ACTIONS(12105), 1,
      anon_sym_LBRACK,
    ACTIONS(12107), 1,
      anon_sym_object,
    ACTIONS(12109), 1,
      anon_sym_fun,
    ACTIONS(12111), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12113), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2495), 1,
      sym__simple_class_expression,
    STATE(9805), 1,
      sym_attribute,
    STATE(10490), 1,
      sym__class_expression,
    STATE(17741), 1,
      sym_module_path,
    STATE(19232), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7336), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [479352] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6245), 1,
      anon_sym_object,
    ACTIONS(8656), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8658), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(11975), 1,
      sym__lowercase_identifier,
    ACTIONS(11977), 1,
      anon_sym_let,
    ACTIONS(11979), 1,
      anon_sym_LPAREN,
    ACTIONS(11981), 1,
      anon_sym_LBRACK,
    ACTIONS(11983), 1,
      anon_sym_fun,
    STATE(2513), 1,
      sym__simple_class_expression,
    STATE(9806), 1,
      sym_attribute,
    STATE(10501), 1,
      sym__class_expression,
    STATE(17795), 1,
      sym_module_path,
    STATE(18988), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7734), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [479420] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6951), 1,
      anon_sym_object,
    ACTIONS(8652), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8654), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(11953), 1,
      sym__lowercase_identifier,
    ACTIONS(11955), 1,
      anon_sym_let,
    ACTIONS(11957), 1,
      anon_sym_LPAREN,
    ACTIONS(11961), 1,
      anon_sym_LBRACK,
    ACTIONS(11963), 1,
      anon_sym_fun,
    STATE(2537), 1,
      sym__simple_class_expression,
    STATE(9157), 1,
      sym__class_expression,
    STATE(9807), 1,
      sym_attribute,
    STATE(19003), 1,
      sym_module_path,
    STATE(20443), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8384), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [479488] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6245), 1,
      anon_sym_object,
    ACTIONS(8656), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8658), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(11975), 1,
      sym__lowercase_identifier,
    ACTIONS(11977), 1,
      anon_sym_let,
    ACTIONS(11979), 1,
      anon_sym_LPAREN,
    ACTIONS(11981), 1,
      anon_sym_LBRACK,
    ACTIONS(11983), 1,
      anon_sym_fun,
    STATE(2513), 1,
      sym__simple_class_expression,
    STATE(9808), 1,
      sym_attribute,
    STATE(10533), 1,
      sym__class_expression,
    STATE(17795), 1,
      sym_module_path,
    STATE(18988), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7734), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [479556] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12021), 1,
      sym__lowercase_identifier,
    ACTIONS(12023), 1,
      anon_sym_let,
    ACTIONS(12025), 1,
      anon_sym_LPAREN,
    ACTIONS(12027), 1,
      anon_sym_LBRACK,
    ACTIONS(12029), 1,
      anon_sym_object,
    ACTIONS(12031), 1,
      anon_sym_fun,
    ACTIONS(12033), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12035), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2488), 1,
      sym__simple_class_expression,
    STATE(9313), 1,
      sym__class_expression,
    STATE(9809), 1,
      sym_attribute,
    STATE(17641), 1,
      sym_module_path,
    STATE(19743), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7432), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [479624] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12099), 1,
      sym__lowercase_identifier,
    ACTIONS(12101), 1,
      anon_sym_let,
    ACTIONS(12103), 1,
      anon_sym_LPAREN,
    ACTIONS(12105), 1,
      anon_sym_LBRACK,
    ACTIONS(12107), 1,
      anon_sym_object,
    ACTIONS(12109), 1,
      anon_sym_fun,
    ACTIONS(12111), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12113), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2495), 1,
      sym__simple_class_expression,
    STATE(9810), 1,
      sym_attribute,
    STATE(10499), 1,
      sym__class_expression,
    STATE(17741), 1,
      sym_module_path,
    STATE(19232), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7336), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [479692] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9811), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8302), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [479732] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12021), 1,
      sym__lowercase_identifier,
    ACTIONS(12023), 1,
      anon_sym_let,
    ACTIONS(12025), 1,
      anon_sym_LPAREN,
    ACTIONS(12027), 1,
      anon_sym_LBRACK,
    ACTIONS(12029), 1,
      anon_sym_object,
    ACTIONS(12031), 1,
      anon_sym_fun,
    ACTIONS(12033), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12035), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2488), 1,
      sym__simple_class_expression,
    STATE(9305), 1,
      sym__class_expression,
    STATE(9812), 1,
      sym_attribute,
    STATE(17641), 1,
      sym_module_path,
    STATE(19743), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7432), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [479800] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9813), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8292), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [479840] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9814), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8288), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [479880] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9815), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12190), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12188), 23,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [479920] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12021), 1,
      sym__lowercase_identifier,
    ACTIONS(12023), 1,
      anon_sym_let,
    ACTIONS(12025), 1,
      anon_sym_LPAREN,
    ACTIONS(12027), 1,
      anon_sym_LBRACK,
    ACTIONS(12029), 1,
      anon_sym_object,
    ACTIONS(12031), 1,
      anon_sym_fun,
    ACTIONS(12033), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12035), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2488), 1,
      sym__simple_class_expression,
    STATE(9816), 1,
      sym_attribute,
    STATE(10657), 1,
      sym__class_expression,
    STATE(17641), 1,
      sym_module_path,
    STATE(19743), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7432), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [479988] = 18,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11394), 1,
      sym__lowercase_identifier,
    STATE(9817), 1,
      sym_attribute,
    STATE(13684), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    STATE(16631), 1,
      sym_method_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [480054] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6951), 1,
      anon_sym_object,
    ACTIONS(8652), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8654), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(11953), 1,
      sym__lowercase_identifier,
    ACTIONS(11955), 1,
      anon_sym_let,
    ACTIONS(11957), 1,
      anon_sym_LPAREN,
    ACTIONS(11961), 1,
      anon_sym_LBRACK,
    ACTIONS(11963), 1,
      anon_sym_fun,
    STATE(2537), 1,
      sym__simple_class_expression,
    STATE(9818), 1,
      sym_attribute,
    STATE(12877), 1,
      sym__class_expression,
    STATE(19003), 1,
      sym_module_path,
    STATE(20443), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8384), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [480122] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12093), 1,
      anon_sym_let,
    ACTIONS(12095), 1,
      anon_sym_fun,
    STATE(2519), 1,
      sym__simple_class_expression,
    STATE(9819), 1,
      sym_attribute,
    STATE(10633), 1,
      sym__class_expression,
    STATE(20390), 1,
      sym_module_path,
    STATE(20409), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [480190] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9820), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11694), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11692), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [480230] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12021), 1,
      sym__lowercase_identifier,
    ACTIONS(12023), 1,
      anon_sym_let,
    ACTIONS(12025), 1,
      anon_sym_LPAREN,
    ACTIONS(12027), 1,
      anon_sym_LBRACK,
    ACTIONS(12029), 1,
      anon_sym_object,
    ACTIONS(12031), 1,
      anon_sym_fun,
    ACTIONS(12033), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12035), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2488), 1,
      sym__simple_class_expression,
    STATE(9821), 1,
      sym_attribute,
    STATE(10439), 1,
      sym__class_expression,
    STATE(17641), 1,
      sym_module_path,
    STATE(19743), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7432), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [480298] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6245), 1,
      anon_sym_object,
    ACTIONS(8656), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8658), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(11975), 1,
      sym__lowercase_identifier,
    ACTIONS(11977), 1,
      anon_sym_let,
    ACTIONS(11979), 1,
      anon_sym_LPAREN,
    ACTIONS(11981), 1,
      anon_sym_LBRACK,
    ACTIONS(11983), 1,
      anon_sym_fun,
    STATE(2513), 1,
      sym__simple_class_expression,
    STATE(9157), 1,
      sym__class_expression,
    STATE(9822), 1,
      sym_attribute,
    STATE(17795), 1,
      sym_module_path,
    STATE(18988), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7734), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [480366] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12194), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12192), 23,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [480406] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9824), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12198), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12196), 23,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [480446] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12202), 1,
      anon_sym_let,
    STATE(9712), 1,
      aux_sym_expression_item_repeat1,
    STATE(9825), 1,
      sym_attribute,
    STATE(9924), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12200), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [480492] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12204), 1,
      anon_sym_COLON,
    STATE(9826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8548), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8550), 13,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [480534] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12021), 1,
      sym__lowercase_identifier,
    ACTIONS(12023), 1,
      anon_sym_let,
    ACTIONS(12025), 1,
      anon_sym_LPAREN,
    ACTIONS(12027), 1,
      anon_sym_LBRACK,
    ACTIONS(12029), 1,
      anon_sym_object,
    ACTIONS(12031), 1,
      anon_sym_fun,
    ACTIONS(12033), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12035), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2488), 1,
      sym__simple_class_expression,
    STATE(9827), 1,
      sym_attribute,
    STATE(10375), 1,
      sym__class_expression,
    STATE(17641), 1,
      sym_module_path,
    STATE(19743), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7432), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [480602] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12021), 1,
      sym__lowercase_identifier,
    ACTIONS(12023), 1,
      anon_sym_let,
    ACTIONS(12025), 1,
      anon_sym_LPAREN,
    ACTIONS(12027), 1,
      anon_sym_LBRACK,
    ACTIONS(12029), 1,
      anon_sym_object,
    ACTIONS(12031), 1,
      anon_sym_fun,
    ACTIONS(12033), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12035), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2488), 1,
      sym__simple_class_expression,
    STATE(9828), 1,
      sym_attribute,
    STATE(10383), 1,
      sym__class_expression,
    STATE(17641), 1,
      sym_module_path,
    STATE(19743), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7432), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [480670] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6245), 1,
      anon_sym_object,
    ACTIONS(8656), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8658), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(11975), 1,
      sym__lowercase_identifier,
    ACTIONS(11977), 1,
      anon_sym_let,
    ACTIONS(11979), 1,
      anon_sym_LPAREN,
    ACTIONS(11981), 1,
      anon_sym_LBRACK,
    ACTIONS(11983), 1,
      anon_sym_fun,
    STATE(2513), 1,
      sym__simple_class_expression,
    STATE(9829), 1,
      sym_attribute,
    STATE(10406), 1,
      sym__class_expression,
    STATE(17795), 1,
      sym_module_path,
    STATE(18988), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7734), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [480738] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12005), 1,
      sym__lowercase_identifier,
    ACTIONS(12007), 1,
      anon_sym_POUND,
    STATE(9830), 1,
      sym_attribute,
    STATE(10644), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17478), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11588), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11590), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [480794] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11872), 1,
      sym__lowercase_identifier,
    ACTIONS(11874), 1,
      anon_sym_POUND,
    ACTIONS(12206), 1,
      anon_sym_STAR,
    STATE(9831), 1,
      sym_attribute,
    STATE(10127), 1,
      sym_type_constructor_path,
    STATE(11057), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17343), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11458), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11896), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [480848] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7777), 1,
      anon_sym_object,
    ACTIONS(7789), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7791), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12119), 1,
      sym__lowercase_identifier,
    ACTIONS(12121), 1,
      anon_sym_let,
    ACTIONS(12123), 1,
      anon_sym_LPAREN,
    ACTIONS(12125), 1,
      anon_sym_LBRACK,
    ACTIONS(12127), 1,
      anon_sym_fun,
    STATE(2854), 1,
      sym__simple_class_expression,
    STATE(9832), 1,
      sym_attribute,
    STATE(16340), 1,
      sym__class_expression,
    STATE(17854), 1,
      sym_module_path,
    STATE(20314), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(9895), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [480916] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6245), 1,
      anon_sym_object,
    ACTIONS(8656), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8658), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(11975), 1,
      sym__lowercase_identifier,
    ACTIONS(11977), 1,
      anon_sym_let,
    ACTIONS(11979), 1,
      anon_sym_LPAREN,
    ACTIONS(11981), 1,
      anon_sym_LBRACK,
    ACTIONS(11983), 1,
      anon_sym_fun,
    STATE(2513), 1,
      sym__simple_class_expression,
    STATE(9305), 1,
      sym__class_expression,
    STATE(9833), 1,
      sym_attribute,
    STATE(17795), 1,
      sym_module_path,
    STATE(18988), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7734), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [480984] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12021), 1,
      sym__lowercase_identifier,
    ACTIONS(12023), 1,
      anon_sym_let,
    ACTIONS(12025), 1,
      anon_sym_LPAREN,
    ACTIONS(12027), 1,
      anon_sym_LBRACK,
    ACTIONS(12029), 1,
      anon_sym_object,
    ACTIONS(12031), 1,
      anon_sym_fun,
    ACTIONS(12033), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12035), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2488), 1,
      sym__simple_class_expression,
    STATE(9834), 1,
      sym_attribute,
    STATE(10386), 1,
      sym__class_expression,
    STATE(17641), 1,
      sym_module_path,
    STATE(19743), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7432), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [481052] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9835), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8080), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8082), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [481092] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9836), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11600), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [481132] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6245), 1,
      anon_sym_object,
    ACTIONS(8656), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8658), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(11975), 1,
      sym__lowercase_identifier,
    ACTIONS(11977), 1,
      anon_sym_let,
    ACTIONS(11979), 1,
      anon_sym_LPAREN,
    ACTIONS(11981), 1,
      anon_sym_LBRACK,
    ACTIONS(11983), 1,
      anon_sym_fun,
    STATE(2513), 1,
      sym__simple_class_expression,
    STATE(9313), 1,
      sym__class_expression,
    STATE(9837), 1,
      sym_attribute,
    STATE(17795), 1,
      sym_module_path,
    STATE(18988), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7734), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [481200] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9838), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11476), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11474), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [481240] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12093), 1,
      anon_sym_let,
    ACTIONS(12095), 1,
      anon_sym_fun,
    STATE(2519), 1,
      sym__simple_class_expression,
    STATE(9839), 1,
      sym_attribute,
    STATE(10435), 1,
      sym__class_expression,
    STATE(20390), 1,
      sym_module_path,
    STATE(20409), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [481308] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12021), 1,
      sym__lowercase_identifier,
    ACTIONS(12023), 1,
      anon_sym_let,
    ACTIONS(12025), 1,
      anon_sym_LPAREN,
    ACTIONS(12027), 1,
      anon_sym_LBRACK,
    ACTIONS(12029), 1,
      anon_sym_object,
    ACTIONS(12031), 1,
      anon_sym_fun,
    ACTIONS(12033), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12035), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2488), 1,
      sym__simple_class_expression,
    STATE(9840), 1,
      sym_attribute,
    STATE(10435), 1,
      sym__class_expression,
    STATE(17641), 1,
      sym_module_path,
    STATE(19743), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7432), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [481376] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12021), 1,
      sym__lowercase_identifier,
    ACTIONS(12023), 1,
      anon_sym_let,
    ACTIONS(12025), 1,
      anon_sym_LPAREN,
    ACTIONS(12027), 1,
      anon_sym_LBRACK,
    ACTIONS(12029), 1,
      anon_sym_object,
    ACTIONS(12031), 1,
      anon_sym_fun,
    ACTIONS(12033), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12035), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2488), 1,
      sym__simple_class_expression,
    STATE(9841), 1,
      sym_attribute,
    STATE(10416), 1,
      sym__class_expression,
    STATE(17641), 1,
      sym_module_path,
    STATE(19743), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7432), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [481444] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12099), 1,
      sym__lowercase_identifier,
    ACTIONS(12101), 1,
      anon_sym_let,
    ACTIONS(12103), 1,
      anon_sym_LPAREN,
    ACTIONS(12105), 1,
      anon_sym_LBRACK,
    ACTIONS(12107), 1,
      anon_sym_object,
    ACTIONS(12109), 1,
      anon_sym_fun,
    ACTIONS(12111), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12113), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2495), 1,
      sym__simple_class_expression,
    STATE(9842), 1,
      sym_attribute,
    STATE(10633), 1,
      sym__class_expression,
    STATE(17741), 1,
      sym_module_path,
    STATE(19232), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7336), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [481512] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12021), 1,
      sym__lowercase_identifier,
    ACTIONS(12023), 1,
      anon_sym_let,
    ACTIONS(12025), 1,
      anon_sym_LPAREN,
    ACTIONS(12027), 1,
      anon_sym_LBRACK,
    ACTIONS(12029), 1,
      anon_sym_object,
    ACTIONS(12031), 1,
      anon_sym_fun,
    ACTIONS(12033), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12035), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2488), 1,
      sym__simple_class_expression,
    STATE(9843), 1,
      sym_attribute,
    STATE(10414), 1,
      sym__class_expression,
    STATE(17641), 1,
      sym_module_path,
    STATE(19743), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7432), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [481580] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6245), 1,
      anon_sym_object,
    ACTIONS(8656), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8658), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(11975), 1,
      sym__lowercase_identifier,
    ACTIONS(11977), 1,
      anon_sym_let,
    ACTIONS(11979), 1,
      anon_sym_LPAREN,
    ACTIONS(11981), 1,
      anon_sym_LBRACK,
    ACTIONS(11983), 1,
      anon_sym_fun,
    STATE(2513), 1,
      sym__simple_class_expression,
    STATE(9844), 1,
      sym_attribute,
    STATE(10386), 1,
      sym__class_expression,
    STATE(17795), 1,
      sym_module_path,
    STATE(18988), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7734), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [481648] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12005), 1,
      sym__lowercase_identifier,
    ACTIONS(12007), 1,
      anon_sym_POUND,
    STATE(9845), 1,
      sym_attribute,
    STATE(10644), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17478), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11500), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11502), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [481704] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6245), 1,
      anon_sym_object,
    ACTIONS(8656), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8658), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(11975), 1,
      sym__lowercase_identifier,
    ACTIONS(11977), 1,
      anon_sym_let,
    ACTIONS(11979), 1,
      anon_sym_LPAREN,
    ACTIONS(11981), 1,
      anon_sym_LBRACK,
    ACTIONS(11983), 1,
      anon_sym_fun,
    STATE(2513), 1,
      sym__simple_class_expression,
    STATE(9846), 1,
      sym_attribute,
    STATE(10383), 1,
      sym__class_expression,
    STATE(17795), 1,
      sym_module_path,
    STATE(18988), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7734), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [481772] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12021), 1,
      sym__lowercase_identifier,
    ACTIONS(12023), 1,
      anon_sym_let,
    ACTIONS(12025), 1,
      anon_sym_LPAREN,
    ACTIONS(12027), 1,
      anon_sym_LBRACK,
    ACTIONS(12029), 1,
      anon_sym_object,
    ACTIONS(12031), 1,
      anon_sym_fun,
    ACTIONS(12033), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12035), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2488), 1,
      sym__simple_class_expression,
    STATE(9847), 1,
      sym_attribute,
    STATE(10406), 1,
      sym__class_expression,
    STATE(17641), 1,
      sym_module_path,
    STATE(19743), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7432), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [481840] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9848), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8310), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [481880] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6245), 1,
      anon_sym_object,
    ACTIONS(8656), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8658), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(11975), 1,
      sym__lowercase_identifier,
    ACTIONS(11977), 1,
      anon_sym_let,
    ACTIONS(11979), 1,
      anon_sym_LPAREN,
    ACTIONS(11981), 1,
      anon_sym_LBRACK,
    ACTIONS(11983), 1,
      anon_sym_fun,
    STATE(2513), 1,
      sym__simple_class_expression,
    STATE(9849), 1,
      sym_attribute,
    STATE(10375), 1,
      sym__class_expression,
    STATE(17795), 1,
      sym_module_path,
    STATE(18988), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7734), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [481948] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6245), 1,
      anon_sym_object,
    ACTIONS(8656), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8658), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(11975), 1,
      sym__lowercase_identifier,
    ACTIONS(11977), 1,
      anon_sym_let,
    ACTIONS(11979), 1,
      anon_sym_LPAREN,
    ACTIONS(11981), 1,
      anon_sym_LBRACK,
    ACTIONS(11983), 1,
      anon_sym_fun,
    STATE(2513), 1,
      sym__simple_class_expression,
    STATE(9850), 1,
      sym_attribute,
    STATE(10439), 1,
      sym__class_expression,
    STATE(17795), 1,
      sym_module_path,
    STATE(18988), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7734), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [482016] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6245), 1,
      anon_sym_object,
    ACTIONS(8656), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8658), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(11975), 1,
      sym__lowercase_identifier,
    ACTIONS(11977), 1,
      anon_sym_let,
    ACTIONS(11979), 1,
      anon_sym_LPAREN,
    ACTIONS(11981), 1,
      anon_sym_LBRACK,
    ACTIONS(11983), 1,
      anon_sym_fun,
    STATE(2513), 1,
      sym__simple_class_expression,
    STATE(9851), 1,
      sym_attribute,
    STATE(10435), 1,
      sym__class_expression,
    STATE(17795), 1,
      sym_module_path,
    STATE(18988), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7734), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [482084] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9852), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11765), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11763), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [482124] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12202), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9853), 1,
      sym_attribute,
    STATE(9924), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12200), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [482170] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12208), 1,
      anon_sym_LPAREN,
    ACTIONS(12210), 1,
      anon_sym_LBRACK,
    STATE(9854), 1,
      sym_attribute,
    STATE(10408), 1,
      sym__constructor_name,
    STATE(11064), 1,
      sym_constructor_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12075), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12212), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(12073), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [482222] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7777), 1,
      anon_sym_object,
    ACTIONS(7789), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7791), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12119), 1,
      sym__lowercase_identifier,
    ACTIONS(12121), 1,
      anon_sym_let,
    ACTIONS(12123), 1,
      anon_sym_LPAREN,
    ACTIONS(12125), 1,
      anon_sym_LBRACK,
    ACTIONS(12127), 1,
      anon_sym_fun,
    STATE(2854), 1,
      sym__simple_class_expression,
    STATE(9157), 1,
      sym__class_expression,
    STATE(9855), 1,
      sym_attribute,
    STATE(17854), 1,
      sym_module_path,
    STATE(20314), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(9895), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [482290] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9856), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11416), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11414), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [482330] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12117), 1,
      anon_sym_DOT,
    ACTIONS(12184), 1,
      anon_sym_POUND,
    ACTIONS(12186), 1,
      sym_hash_operator,
    STATE(9857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9724), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9722), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [482376] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8350), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8352), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [482416] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9859), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8364), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [482456] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12117), 1,
      anon_sym_DOT,
    ACTIONS(12184), 1,
      anon_sym_POUND,
    ACTIONS(12186), 1,
      sym_hash_operator,
    STATE(9860), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9734), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9732), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [482502] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12099), 1,
      sym__lowercase_identifier,
    ACTIONS(12101), 1,
      anon_sym_let,
    ACTIONS(12103), 1,
      anon_sym_LPAREN,
    ACTIONS(12105), 1,
      anon_sym_LBRACK,
    ACTIONS(12107), 1,
      anon_sym_object,
    ACTIONS(12109), 1,
      anon_sym_fun,
    ACTIONS(12111), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12113), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2495), 1,
      sym__simple_class_expression,
    STATE(9861), 1,
      sym_attribute,
    STATE(10657), 1,
      sym__class_expression,
    STATE(17741), 1,
      sym_module_path,
    STATE(19232), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7336), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [482570] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12093), 1,
      anon_sym_let,
    ACTIONS(12095), 1,
      anon_sym_fun,
    STATE(2519), 1,
      sym__simple_class_expression,
    STATE(9862), 1,
      sym_attribute,
    STATE(10490), 1,
      sym__class_expression,
    STATE(20390), 1,
      sym_module_path,
    STATE(20409), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [482638] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9863), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8356), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [482678] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9864), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11496), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11494), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [482718] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12216), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9865), 1,
      sym_attribute,
    STATE(9924), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12214), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [482764] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9866), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11706), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11704), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [482804] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6565), 1,
      anon_sym_object,
    ACTIONS(8632), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8634), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(12011), 1,
      sym__lowercase_identifier,
    ACTIONS(12015), 1,
      anon_sym_LPAREN,
    ACTIONS(12017), 1,
      anon_sym_LBRACK,
    ACTIONS(12093), 1,
      anon_sym_let,
    ACTIONS(12095), 1,
      anon_sym_fun,
    STATE(2519), 1,
      sym__simple_class_expression,
    STATE(9867), 1,
      sym_attribute,
    STATE(10439), 1,
      sym__class_expression,
    STATE(20390), 1,
      sym_module_path,
    STATE(20409), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7584), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [482872] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9868), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8360), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [482912] = 19,
    ACTIONS(347), 1,
      sym_let_operator,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6245), 1,
      anon_sym_object,
    ACTIONS(8656), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8658), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(11975), 1,
      sym__lowercase_identifier,
    ACTIONS(11977), 1,
      anon_sym_let,
    ACTIONS(11979), 1,
      anon_sym_LPAREN,
    ACTIONS(11981), 1,
      anon_sym_LBRACK,
    ACTIONS(11983), 1,
      anon_sym_fun,
    STATE(2513), 1,
      sym__simple_class_expression,
    STATE(9869), 1,
      sym_attribute,
    STATE(10416), 1,
      sym__class_expression,
    STATE(17795), 1,
      sym_module_path,
    STATE(18988), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9236), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7734), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [482980] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9468), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9470), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9472), 1,
      anon_sym_LT,
    ACTIONS(9474), 1,
      anon_sym_POUND,
    ACTIONS(9476), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9478), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9480), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10720), 1,
      anon_sym_LPAREN,
    ACTIONS(10724), 1,
      anon_sym_LBRACK,
    ACTIONS(11340), 1,
      sym__lowercase_identifier,
    STATE(9870), 1,
      sym_attribute,
    STATE(9879), 1,
      sym__simple_type,
    STATE(16859), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9377), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [483043] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2236), 1,
      sym_add_operator,
    STATE(9871), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [483084] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9872), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11765), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11763), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [483123] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10070), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10072), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11298), 1,
      sym__lowercase_identifier,
    ACTIONS(11300), 1,
      anon_sym_LPAREN,
    ACTIONS(11302), 1,
      anon_sym_LBRACK,
    ACTIONS(11304), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11306), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11308), 1,
      anon_sym_LT,
    ACTIONS(11310), 1,
      anon_sym_POUND,
    ACTIONS(11312), 1,
      aux_sym_type_variable_token1,
    STATE(9873), 1,
      sym_attribute,
    STATE(10229), 1,
      sym__simple_type,
    STATE(17129), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10286), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [483186] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12218), 1,
      sym__lowercase_identifier,
    ACTIONS(12220), 1,
      anon_sym_POUND,
    STATE(9874), 1,
      sym_attribute,
    STATE(10903), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17519), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11500), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11502), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [483241] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12222), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12224), 1,
      sym_pow_operator,
    ACTIONS(12226), 1,
      sym_mult_operator,
    ACTIONS(12228), 1,
      sym_concat_operator,
    ACTIONS(12230), 1,
      sym_rel_operator,
    ACTIONS(12232), 1,
      sym_and_operator,
    ACTIONS(12234), 1,
      sym_or_operator,
    STATE(2236), 1,
      sym_add_operator,
    STATE(9875), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 12,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
  [483298] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12218), 1,
      sym__lowercase_identifier,
    ACTIONS(12220), 1,
      anon_sym_POUND,
    STATE(9876), 1,
      sym_attribute,
    STATE(10903), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17519), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11588), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11590), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [483353] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12218), 1,
      sym__lowercase_identifier,
    ACTIONS(12220), 1,
      anon_sym_POUND,
    STATE(9877), 1,
      sym_attribute,
    STATE(10903), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17519), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11454), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11456), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [483408] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10134), 1,
      anon_sym_LPAREN,
    ACTIONS(10136), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10140), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10142), 1,
      anon_sym_LT,
    ACTIONS(10144), 1,
      anon_sym_POUND,
    ACTIONS(10146), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10148), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10150), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11316), 1,
      sym__lowercase_identifier,
    STATE(9878), 1,
      sym_attribute,
    STATE(11037), 1,
      sym__simple_type,
    STATE(16704), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10841), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [483471] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11254), 1,
      sym__lowercase_identifier,
    ACTIONS(11400), 1,
      anon_sym_POUND,
    STATE(9379), 1,
      sym_type_constructor_path,
    STATE(9879), 1,
      sym_attribute,
    STATE(17458), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11720), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11722), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [483520] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12222), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12224), 1,
      sym_pow_operator,
    ACTIONS(12226), 1,
      sym_mult_operator,
    ACTIONS(12228), 1,
      sym_concat_operator,
    ACTIONS(12230), 1,
      sym_rel_operator,
    ACTIONS(12232), 1,
      sym_and_operator,
    STATE(2236), 1,
      sym_add_operator,
    STATE(9880), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 12,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
  [483575] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11278), 1,
      sym__lowercase_identifier,
    ACTIONS(11280), 1,
      anon_sym_LPAREN,
    ACTIONS(11282), 1,
      anon_sym_LBRACK,
    ACTIONS(11284), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11286), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11288), 1,
      anon_sym_LT,
    ACTIONS(11290), 1,
      anon_sym_POUND,
    ACTIONS(11292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11296), 1,
      aux_sym_type_variable_token1,
    STATE(9881), 1,
      sym_attribute,
    STATE(10731), 1,
      sym__simple_type,
    STATE(16787), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10877), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [483638] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10134), 1,
      anon_sym_LPAREN,
    ACTIONS(10136), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10140), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10142), 1,
      anon_sym_LT,
    ACTIONS(10144), 1,
      anon_sym_POUND,
    ACTIONS(10146), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10148), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10150), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11316), 1,
      sym__lowercase_identifier,
    STATE(9882), 1,
      sym_attribute,
    STATE(11039), 1,
      sym__simple_type,
    STATE(16704), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10841), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [483701] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12222), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12224), 1,
      sym_pow_operator,
    ACTIONS(12226), 1,
      sym_mult_operator,
    ACTIONS(12228), 1,
      sym_concat_operator,
    STATE(2236), 1,
      sym_add_operator,
    STATE(9883), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 13,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
  [483752] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9500), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9502), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9504), 1,
      anon_sym_LT,
    ACTIONS(9506), 1,
      anon_sym_POUND,
    ACTIONS(9508), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9510), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9512), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10928), 1,
      anon_sym_LPAREN,
    ACTIONS(10932), 1,
      anon_sym_LBRACK,
    ACTIONS(11246), 1,
      sym__lowercase_identifier,
    STATE(9884), 1,
      sym_attribute,
    STATE(10437), 1,
      sym__simple_type,
    STATE(16914), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10076), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [483815] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12224), 1,
      sym_pow_operator,
    STATE(2236), 1,
      sym_add_operator,
    STATE(9885), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 15,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [483858] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12224), 1,
      sym_pow_operator,
    STATE(2236), 1,
      sym_add_operator,
    STATE(9886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 15,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [483901] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10070), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10072), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11298), 1,
      sym__lowercase_identifier,
    ACTIONS(11300), 1,
      anon_sym_LPAREN,
    ACTIONS(11302), 1,
      anon_sym_LBRACK,
    ACTIONS(11304), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11306), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11308), 1,
      anon_sym_LT,
    ACTIONS(11310), 1,
      anon_sym_POUND,
    ACTIONS(11312), 1,
      aux_sym_type_variable_token1,
    STATE(9887), 1,
      sym_attribute,
    STATE(10166), 1,
      sym__simple_type,
    STATE(17129), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10286), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [483964] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10134), 1,
      anon_sym_LPAREN,
    ACTIONS(10136), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10140), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10142), 1,
      anon_sym_LT,
    ACTIONS(10144), 1,
      anon_sym_POUND,
    ACTIONS(10146), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10148), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10150), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11316), 1,
      sym__lowercase_identifier,
    STATE(9888), 1,
      sym_attribute,
    STATE(11093), 1,
      sym__simple_type,
    STATE(16704), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10841), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [484027] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10070), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10072), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11298), 1,
      sym__lowercase_identifier,
    ACTIONS(11300), 1,
      anon_sym_LPAREN,
    ACTIONS(11302), 1,
      anon_sym_LBRACK,
    ACTIONS(11304), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11306), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11308), 1,
      anon_sym_LT,
    ACTIONS(11310), 1,
      anon_sym_POUND,
    ACTIONS(11312), 1,
      aux_sym_type_variable_token1,
    STATE(9889), 1,
      sym_attribute,
    STATE(10270), 1,
      sym__simple_type,
    STATE(17129), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10286), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [484090] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9406), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10680), 1,
      anon_sym_LPAREN,
    ACTIONS(10684), 1,
      anon_sym_LBRACK,
    ACTIONS(11252), 1,
      sym__lowercase_identifier,
    STATE(9765), 1,
      sym__simple_type,
    STATE(9890), 1,
      sym_attribute,
    STATE(16745), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9437), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [484153] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12222), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12224), 1,
      sym_pow_operator,
    ACTIONS(12226), 1,
      sym_mult_operator,
    STATE(2236), 1,
      sym_add_operator,
    STATE(9891), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 3,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [484202] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9892), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8622), 10,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8624), 14,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [484241] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10344), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12222), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12224), 1,
      sym_pow_operator,
    ACTIONS(12226), 1,
      sym_mult_operator,
    ACTIONS(12228), 1,
      sym_concat_operator,
    ACTIONS(12230), 1,
      sym_rel_operator,
    ACTIONS(12232), 1,
      sym_and_operator,
    ACTIONS(12234), 1,
      sym_or_operator,
    STATE(2236), 1,
      sym_add_operator,
    STATE(9893), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 12,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
  [484298] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12240), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9894), 1,
      sym_attribute,
    STATE(10016), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12238), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12236), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [484343] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9592), 10,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9594), 14,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [484382] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9500), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9502), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9504), 1,
      anon_sym_LT,
    ACTIONS(9506), 1,
      anon_sym_POUND,
    ACTIONS(9508), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9510), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9512), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10928), 1,
      anon_sym_LPAREN,
    ACTIONS(10932), 1,
      anon_sym_LBRACK,
    ACTIONS(11246), 1,
      sym__lowercase_identifier,
    STATE(9896), 1,
      sym_attribute,
    STATE(10418), 1,
      sym__simple_type,
    STATE(16914), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10076), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [484445] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9500), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9502), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9504), 1,
      anon_sym_LT,
    ACTIONS(9506), 1,
      anon_sym_POUND,
    ACTIONS(9508), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9510), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9512), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10928), 1,
      anon_sym_LPAREN,
    ACTIONS(10932), 1,
      anon_sym_LBRACK,
    ACTIONS(11246), 1,
      sym__lowercase_identifier,
    STATE(9897), 1,
      sym_attribute,
    STATE(10389), 1,
      sym__simple_type,
    STATE(16914), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10076), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [484508] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11346), 1,
      sym__lowercase_identifier,
    ACTIONS(11558), 1,
      anon_sym_POUND,
    STATE(9468), 1,
      sym_type_constructor_path,
    STATE(9898), 1,
      sym_attribute,
    STATE(17537), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12242), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12244), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [484557] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12246), 1,
      anon_sym_STAR,
    STATE(9899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10393), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10391), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [484598] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9900), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9902), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11368), 1,
      sym__lowercase_identifier,
    ACTIONS(11370), 1,
      anon_sym_LPAREN,
    ACTIONS(11372), 1,
      anon_sym_LBRACK,
    ACTIONS(11374), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11376), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11378), 1,
      anon_sym_LT,
    ACTIONS(11380), 1,
      anon_sym_POUND,
    ACTIONS(11382), 1,
      aux_sym_type_variable_token1,
    STATE(9900), 1,
      sym_attribute,
    STATE(10221), 1,
      sym__simple_type,
    STATE(16829), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10613), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [484661] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9964), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11352), 1,
      sym__lowercase_identifier,
    ACTIONS(11354), 1,
      anon_sym_LPAREN,
    ACTIONS(11356), 1,
      anon_sym_LBRACK,
    ACTIONS(11358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11362), 1,
      anon_sym_LT,
    ACTIONS(11364), 1,
      anon_sym_POUND,
    ACTIONS(11366), 1,
      aux_sym_type_variable_token1,
    STATE(9901), 1,
      sym_attribute,
    STATE(9989), 1,
      sym__simple_type,
    STATE(17160), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10274), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [484724] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11226), 1,
      sym__lowercase_identifier,
    ACTIONS(11228), 1,
      anon_sym_LPAREN,
    ACTIONS(11230), 1,
      anon_sym_LBRACK,
    ACTIONS(11232), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11234), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11236), 1,
      anon_sym_LT,
    ACTIONS(11238), 1,
      anon_sym_POUND,
    ACTIONS(11240), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11242), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11244), 1,
      aux_sym_type_variable_token1,
    STATE(9902), 1,
      sym_attribute,
    STATE(10993), 1,
      sym__simple_type,
    STATE(16889), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10886), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [484787] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11226), 1,
      sym__lowercase_identifier,
    ACTIONS(11228), 1,
      anon_sym_LPAREN,
    ACTIONS(11230), 1,
      anon_sym_LBRACK,
    ACTIONS(11232), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11234), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11236), 1,
      anon_sym_LT,
    ACTIONS(11238), 1,
      anon_sym_POUND,
    ACTIONS(11240), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11242), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11244), 1,
      aux_sym_type_variable_token1,
    STATE(9903), 1,
      sym_attribute,
    STATE(10988), 1,
      sym__simple_type,
    STATE(16889), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10886), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [484850] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12248), 1,
      sym__lowercase_identifier,
    ACTIONS(12250), 1,
      anon_sym_POUND,
    STATE(9904), 1,
      sym_attribute,
    STATE(10881), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17296), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11588), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11590), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [484905] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8364), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
  [484944] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11226), 1,
      sym__lowercase_identifier,
    ACTIONS(11228), 1,
      anon_sym_LPAREN,
    ACTIONS(11230), 1,
      anon_sym_LBRACK,
    ACTIONS(11232), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11234), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11236), 1,
      anon_sym_LT,
    ACTIONS(11238), 1,
      anon_sym_POUND,
    ACTIONS(11240), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11242), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11244), 1,
      aux_sym_type_variable_token1,
    STATE(9906), 1,
      sym_attribute,
    STATE(10945), 1,
      sym__simple_type,
    STATE(16889), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10886), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [485007] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12254), 1,
      anon_sym_let,
    ACTIONS(12256), 1,
      anon_sym_DQUOTE,
    STATE(9907), 1,
      sym_attribute,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10666), 1,
      aux_sym_external_repeat1,
    STATE(10734), 1,
      aux_sym_expression_item_repeat1,
    STATE(11083), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12252), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [485058] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11226), 1,
      sym__lowercase_identifier,
    ACTIONS(11228), 1,
      anon_sym_LPAREN,
    ACTIONS(11230), 1,
      anon_sym_LBRACK,
    ACTIONS(11232), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11234), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11236), 1,
      anon_sym_LT,
    ACTIONS(11238), 1,
      anon_sym_POUND,
    ACTIONS(11240), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11242), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11244), 1,
      aux_sym_type_variable_token1,
    STATE(9908), 1,
      sym_attribute,
    STATE(10884), 1,
      sym__simple_type,
    STATE(16889), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10886), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [485121] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11226), 1,
      sym__lowercase_identifier,
    ACTIONS(11228), 1,
      anon_sym_LPAREN,
    ACTIONS(11230), 1,
      anon_sym_LBRACK,
    ACTIONS(11232), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11234), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11236), 1,
      anon_sym_LT,
    ACTIONS(11238), 1,
      anon_sym_POUND,
    ACTIONS(11240), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11242), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11244), 1,
      aux_sym_type_variable_token1,
    STATE(9909), 1,
      sym_attribute,
    STATE(10882), 1,
      sym__simple_type,
    STATE(16889), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10886), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [485184] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11226), 1,
      sym__lowercase_identifier,
    ACTIONS(11228), 1,
      anon_sym_LPAREN,
    ACTIONS(11230), 1,
      anon_sym_LBRACK,
    ACTIONS(11232), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11234), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11236), 1,
      anon_sym_LT,
    ACTIONS(11238), 1,
      anon_sym_POUND,
    ACTIONS(11240), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11242), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11244), 1,
      aux_sym_type_variable_token1,
    STATE(9910), 1,
      sym_attribute,
    STATE(10836), 1,
      sym__simple_type,
    STATE(16889), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10886), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [485247] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9964), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11352), 1,
      sym__lowercase_identifier,
    ACTIONS(11354), 1,
      anon_sym_LPAREN,
    ACTIONS(11356), 1,
      anon_sym_LBRACK,
    ACTIONS(11358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11362), 1,
      anon_sym_LT,
    ACTIONS(11364), 1,
      anon_sym_POUND,
    ACTIONS(11366), 1,
      aux_sym_type_variable_token1,
    STATE(9911), 1,
      sym_attribute,
    STATE(10311), 1,
      sym__simple_type,
    STATE(17160), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10274), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [485310] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9964), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11352), 1,
      sym__lowercase_identifier,
    ACTIONS(11354), 1,
      anon_sym_LPAREN,
    ACTIONS(11356), 1,
      anon_sym_LBRACK,
    ACTIONS(11358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11362), 1,
      anon_sym_LT,
    ACTIONS(11364), 1,
      anon_sym_POUND,
    ACTIONS(11366), 1,
      aux_sym_type_variable_token1,
    STATE(9912), 1,
      sym_attribute,
    STATE(10313), 1,
      sym__simple_type,
    STATE(17160), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10274), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [485373] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10016), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10018), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11210), 1,
      sym__lowercase_identifier,
    ACTIONS(11212), 1,
      anon_sym_LPAREN,
    ACTIONS(11214), 1,
      anon_sym_LBRACK,
    ACTIONS(11216), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11218), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11220), 1,
      anon_sym_LT,
    ACTIONS(11222), 1,
      anon_sym_POUND,
    ACTIONS(11224), 1,
      aux_sym_type_variable_token1,
    STATE(9913), 1,
      sym_attribute,
    STATE(10821), 1,
      sym__simple_type,
    STATE(17224), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10848), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [485436] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9964), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11352), 1,
      sym__lowercase_identifier,
    ACTIONS(11354), 1,
      anon_sym_LPAREN,
    ACTIONS(11356), 1,
      anon_sym_LBRACK,
    ACTIONS(11358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11362), 1,
      anon_sym_LT,
    ACTIONS(11364), 1,
      anon_sym_POUND,
    ACTIONS(11366), 1,
      aux_sym_type_variable_token1,
    STATE(9914), 1,
      sym_attribute,
    STATE(10323), 1,
      sym__simple_type,
    STATE(17160), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10274), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [485499] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10016), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10018), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11210), 1,
      sym__lowercase_identifier,
    ACTIONS(11212), 1,
      anon_sym_LPAREN,
    ACTIONS(11214), 1,
      anon_sym_LBRACK,
    ACTIONS(11216), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11218), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11220), 1,
      anon_sym_LT,
    ACTIONS(11222), 1,
      anon_sym_POUND,
    ACTIONS(11224), 1,
      aux_sym_type_variable_token1,
    STATE(9915), 1,
      sym_attribute,
    STATE(10796), 1,
      sym__simple_type,
    STATE(17224), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10848), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [485562] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9916), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12260), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12258), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [485601] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12222), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12224), 1,
      sym_pow_operator,
    ACTIONS(12226), 1,
      sym_mult_operator,
    ACTIONS(12228), 1,
      sym_concat_operator,
    ACTIONS(12230), 1,
      sym_rel_operator,
    ACTIONS(12232), 1,
      sym_and_operator,
    ACTIONS(12234), 1,
      sym_or_operator,
    ACTIONS(12262), 1,
      anon_sym_COMMA,
    ACTIONS(12264), 1,
      sym_assign_operator,
    STATE(2236), 1,
      sym_add_operator,
    STATE(9917), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 10,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [485662] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9906), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_LBRACK,
    ACTIONS(9910), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9912), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9914), 1,
      anon_sym_LT,
    ACTIONS(9916), 1,
      anon_sym_POUND,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9920), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9922), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11318), 1,
      sym__lowercase_identifier,
    STATE(9918), 1,
      sym_attribute,
    STATE(11542), 1,
      sym__simple_type,
    STATE(16934), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11018), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [485725] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10774), 1,
      anon_sym_LPAREN,
    ACTIONS(10778), 1,
      anon_sym_LBRACK,
    ACTIONS(10780), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10782), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10784), 1,
      anon_sym_LT,
    ACTIONS(10786), 1,
      anon_sym_POUND,
    ACTIONS(10788), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10790), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10792), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12266), 1,
      sym__lowercase_identifier,
    STATE(9919), 1,
      sym_attribute,
    STATE(12918), 1,
      sym__simple_type,
    STATE(17192), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13156), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [485788] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11628), 1,
      sym__lowercase_identifier,
    ACTIONS(11837), 1,
      anon_sym_POUND,
    STATE(9731), 1,
      sym_type_constructor_path,
    STATE(9920), 1,
      sym_attribute,
    STATE(16902), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12085), 8,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12087), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [485837] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9906), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_LBRACK,
    ACTIONS(9910), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9912), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9914), 1,
      anon_sym_LT,
    ACTIONS(9916), 1,
      anon_sym_POUND,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9920), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9922), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11318), 1,
      sym__lowercase_identifier,
    STATE(9921), 1,
      sym_attribute,
    STATE(11517), 1,
      sym__simple_type,
    STATE(16934), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11018), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [485900] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9906), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_LBRACK,
    ACTIONS(9910), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9912), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9914), 1,
      anon_sym_LT,
    ACTIONS(9916), 1,
      anon_sym_POUND,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9920), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9922), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11318), 1,
      sym__lowercase_identifier,
    STATE(9922), 1,
      sym_attribute,
    STATE(11515), 1,
      sym__simple_type,
    STATE(16934), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11018), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [485963] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12224), 1,
      sym_pow_operator,
    ACTIONS(12226), 1,
      sym_mult_operator,
    STATE(2236), 1,
      sym_add_operator,
    STATE(9923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 15,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [486008] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9924), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12270), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12268), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [486047] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9906), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_LBRACK,
    ACTIONS(9910), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9912), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9914), 1,
      anon_sym_LT,
    ACTIONS(9916), 1,
      anon_sym_POUND,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9920), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9922), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11318), 1,
      sym__lowercase_identifier,
    STATE(9925), 1,
      sym_attribute,
    STATE(11507), 1,
      sym__simple_type,
    STATE(16934), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11018), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [486110] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10303), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12222), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12224), 1,
      sym_pow_operator,
    ACTIONS(12226), 1,
      sym_mult_operator,
    ACTIONS(12228), 1,
      sym_concat_operator,
    ACTIONS(12230), 1,
      sym_rel_operator,
    ACTIONS(12232), 1,
      sym_and_operator,
    ACTIONS(12234), 1,
      sym_or_operator,
    ACTIONS(12262), 1,
      anon_sym_COMMA,
    ACTIONS(12264), 1,
      sym_assign_operator,
    STATE(2236), 1,
      sym_add_operator,
    STATE(9926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10301), 10,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [486171] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    STATE(9927), 1,
      sym_attribute,
    STATE(11765), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [486234] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9964), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11352), 1,
      sym__lowercase_identifier,
    ACTIONS(11354), 1,
      anon_sym_LPAREN,
    ACTIONS(11356), 1,
      anon_sym_LBRACK,
    ACTIONS(11358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11362), 1,
      anon_sym_LT,
    ACTIONS(11364), 1,
      anon_sym_POUND,
    ACTIONS(11366), 1,
      aux_sym_type_variable_token1,
    STATE(9928), 1,
      sym_attribute,
    STATE(10240), 1,
      sym__simple_type,
    STATE(17160), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10274), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [486297] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10906), 1,
      anon_sym_LPAREN,
    ACTIONS(10910), 1,
      anon_sym_LBRACK,
    ACTIONS(10912), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10914), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10916), 1,
      anon_sym_LT,
    ACTIONS(10918), 1,
      anon_sym_POUND,
    ACTIONS(10920), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10922), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10924), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12272), 1,
      sym__lowercase_identifier,
    STATE(8947), 1,
      sym__simple_type,
    STATE(9929), 1,
      sym_attribute,
    STATE(17362), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9114), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [486360] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9930), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11436), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11434), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [486399] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9906), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_LBRACK,
    ACTIONS(9910), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9912), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9914), 1,
      anon_sym_LT,
    ACTIONS(9916), 1,
      anon_sym_POUND,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9920), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9922), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11318), 1,
      sym__lowercase_identifier,
    STATE(9931), 1,
      sym_attribute,
    STATE(11489), 1,
      sym__simple_type,
    STATE(16934), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11018), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [486462] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9964), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11352), 1,
      sym__lowercase_identifier,
    ACTIONS(11354), 1,
      anon_sym_LPAREN,
    ACTIONS(11356), 1,
      anon_sym_LBRACK,
    ACTIONS(11358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11362), 1,
      anon_sym_LT,
    ACTIONS(11364), 1,
      anon_sym_POUND,
    ACTIONS(11366), 1,
      aux_sym_type_variable_token1,
    STATE(9932), 1,
      sym_attribute,
    STATE(10232), 1,
      sym__simple_type,
    STATE(17160), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10274), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [486525] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10070), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10072), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11298), 1,
      sym__lowercase_identifier,
    ACTIONS(11300), 1,
      anon_sym_LPAREN,
    ACTIONS(11302), 1,
      anon_sym_LBRACK,
    ACTIONS(11304), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11306), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11308), 1,
      anon_sym_LT,
    ACTIONS(11310), 1,
      anon_sym_POUND,
    ACTIONS(11312), 1,
      aux_sym_type_variable_token1,
    STATE(9933), 1,
      sym_attribute,
    STATE(10106), 1,
      sym__simple_type,
    STATE(17129), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10286), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [486588] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9468), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9470), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9472), 1,
      anon_sym_LT,
    ACTIONS(9474), 1,
      anon_sym_POUND,
    ACTIONS(9476), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9478), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9480), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10720), 1,
      anon_sym_LPAREN,
    ACTIONS(10724), 1,
      anon_sym_LBRACK,
    ACTIONS(11340), 1,
      sym__lowercase_identifier,
    STATE(9934), 1,
      sym_attribute,
    STATE(10080), 1,
      sym__simple_type,
    STATE(16859), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9377), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [486651] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12274), 1,
      sym__lowercase_identifier,
    ACTIONS(12276), 1,
      anon_sym_POUND,
    STATE(9935), 1,
      sym_attribute,
    STATE(10867), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17441), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11720), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11722), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [486706] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9906), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_LBRACK,
    ACTIONS(9910), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9912), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9914), 1,
      anon_sym_LT,
    ACTIONS(9916), 1,
      anon_sym_POUND,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9920), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9922), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11318), 1,
      sym__lowercase_identifier,
    STATE(9936), 1,
      sym_attribute,
    STATE(11475), 1,
      sym__simple_type,
    STATE(16934), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11018), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [486769] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9468), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9470), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9472), 1,
      anon_sym_LT,
    ACTIONS(9474), 1,
      anon_sym_POUND,
    ACTIONS(9476), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9478), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9480), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10720), 1,
      anon_sym_LPAREN,
    ACTIONS(10724), 1,
      anon_sym_LBRACK,
    ACTIONS(11340), 1,
      sym__lowercase_identifier,
    STATE(9937), 1,
      sym_attribute,
    STATE(10068), 1,
      sym__simple_type,
    STATE(16859), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9377), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [486832] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10016), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10018), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11210), 1,
      sym__lowercase_identifier,
    ACTIONS(11212), 1,
      anon_sym_LPAREN,
    ACTIONS(11214), 1,
      anon_sym_LBRACK,
    ACTIONS(11216), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11218), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11220), 1,
      anon_sym_LT,
    ACTIONS(11222), 1,
      anon_sym_POUND,
    ACTIONS(11224), 1,
      aux_sym_type_variable_token1,
    STATE(9938), 1,
      sym_attribute,
    STATE(10814), 1,
      sym__simple_type,
    STATE(17224), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10848), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [486895] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10016), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10018), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11210), 1,
      sym__lowercase_identifier,
    ACTIONS(11212), 1,
      anon_sym_LPAREN,
    ACTIONS(11214), 1,
      anon_sym_LBRACK,
    ACTIONS(11216), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11218), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11220), 1,
      anon_sym_LT,
    ACTIONS(11222), 1,
      anon_sym_POUND,
    ACTIONS(11224), 1,
      aux_sym_type_variable_token1,
    STATE(9939), 1,
      sym_attribute,
    STATE(10816), 1,
      sym__simple_type,
    STATE(17224), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10848), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [486958] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11278), 1,
      sym__lowercase_identifier,
    ACTIONS(11280), 1,
      anon_sym_LPAREN,
    ACTIONS(11282), 1,
      anon_sym_LBRACK,
    ACTIONS(11284), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11286), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11288), 1,
      anon_sym_LT,
    ACTIONS(11290), 1,
      anon_sym_POUND,
    ACTIONS(11292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11296), 1,
      aux_sym_type_variable_token1,
    STATE(9940), 1,
      sym_attribute,
    STATE(10602), 1,
      sym__simple_type,
    STATE(16787), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10877), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [487021] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11226), 1,
      sym__lowercase_identifier,
    ACTIONS(11228), 1,
      anon_sym_LPAREN,
    ACTIONS(11230), 1,
      anon_sym_LBRACK,
    ACTIONS(11232), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11234), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11236), 1,
      anon_sym_LT,
    ACTIONS(11238), 1,
      anon_sym_POUND,
    ACTIONS(11240), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11242), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11244), 1,
      aux_sym_type_variable_token1,
    STATE(9941), 1,
      sym_attribute,
    STATE(10691), 1,
      sym__simple_type,
    STATE(16889), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10886), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [487084] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9468), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9470), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9472), 1,
      anon_sym_LT,
    ACTIONS(9474), 1,
      anon_sym_POUND,
    ACTIONS(9476), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9478), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9480), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10720), 1,
      anon_sym_LPAREN,
    ACTIONS(10724), 1,
      anon_sym_LBRACK,
    ACTIONS(11340), 1,
      sym__lowercase_identifier,
    STATE(9942), 1,
      sym_attribute,
    STATE(9949), 1,
      sym__simple_type,
    STATE(16859), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9377), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [487147] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9468), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9470), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9472), 1,
      anon_sym_LT,
    ACTIONS(9474), 1,
      anon_sym_POUND,
    ACTIONS(9476), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9478), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9480), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10720), 1,
      anon_sym_LPAREN,
    ACTIONS(10724), 1,
      anon_sym_LBRACK,
    ACTIONS(11340), 1,
      sym__lowercase_identifier,
    STATE(9943), 1,
      sym_attribute,
    STATE(9971), 1,
      sym__simple_type,
    STATE(16859), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9377), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [487210] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9424), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9426), 1,
      anon_sym_LT,
    ACTIONS(9428), 1,
      anon_sym_POUND,
    ACTIONS(9430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9434), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10692), 1,
      anon_sym_LPAREN,
    ACTIONS(10696), 1,
      anon_sym_LBRACK,
    ACTIONS(11208), 1,
      sym__lowercase_identifier,
    STATE(9944), 1,
      sym_attribute,
    STATE(10136), 1,
      sym__simple_type,
    STATE(16665), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9574), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [487273] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9468), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9470), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9472), 1,
      anon_sym_LT,
    ACTIONS(9474), 1,
      anon_sym_POUND,
    ACTIONS(9476), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9478), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9480), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10720), 1,
      anon_sym_LPAREN,
    ACTIONS(10724), 1,
      anon_sym_LBRACK,
    ACTIONS(11340), 1,
      sym__lowercase_identifier,
    STATE(9945), 1,
      sym_attribute,
    STATE(10010), 1,
      sym__simple_type,
    STATE(16859), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9377), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [487336] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9424), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9426), 1,
      anon_sym_LT,
    ACTIONS(9428), 1,
      anon_sym_POUND,
    ACTIONS(9430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9434), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10692), 1,
      anon_sym_LPAREN,
    ACTIONS(10696), 1,
      anon_sym_LBRACK,
    ACTIONS(11208), 1,
      sym__lowercase_identifier,
    STATE(9946), 1,
      sym_attribute,
    STATE(10121), 1,
      sym__simple_type,
    STATE(16665), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9574), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [487399] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11346), 1,
      sym__lowercase_identifier,
    ACTIONS(11558), 1,
      anon_sym_POUND,
    STATE(9468), 1,
      sym_type_constructor_path,
    STATE(9947), 1,
      sym_attribute,
    STATE(17537), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12278), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12280), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [487448] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12286), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12284), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(9948), 2,
      sym_attribute,
      aux_sym_type_binding_repeat1,
    ACTIONS(12282), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [487491] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11254), 1,
      sym__lowercase_identifier,
    ACTIONS(11400), 1,
      anon_sym_POUND,
    STATE(9379), 1,
      sym_type_constructor_path,
    STATE(9949), 1,
      sym_attribute,
    STATE(17458), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12278), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12280), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [487540] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9406), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10680), 1,
      anon_sym_LPAREN,
    ACTIONS(10684), 1,
      anon_sym_LBRACK,
    ACTIONS(11252), 1,
      sym__lowercase_identifier,
    STATE(9215), 1,
      sym__simple_type,
    STATE(9950), 1,
      sym_attribute,
    STATE(16745), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9437), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [487603] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9951), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11578), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11576), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [487642] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9424), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9426), 1,
      anon_sym_LT,
    ACTIONS(9428), 1,
      anon_sym_POUND,
    ACTIONS(9430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9434), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10692), 1,
      anon_sym_LPAREN,
    ACTIONS(10696), 1,
      anon_sym_LBRACK,
    ACTIONS(11208), 1,
      sym__lowercase_identifier,
    STATE(9952), 1,
      sym_attribute,
    STATE(10216), 1,
      sym__simple_type,
    STATE(16665), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9574), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [487705] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9964), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11352), 1,
      sym__lowercase_identifier,
    ACTIONS(11354), 1,
      anon_sym_LPAREN,
    ACTIONS(11356), 1,
      anon_sym_LBRACK,
    ACTIONS(11358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11362), 1,
      anon_sym_LT,
    ACTIONS(11364), 1,
      anon_sym_POUND,
    ACTIONS(11366), 1,
      aux_sym_type_variable_token1,
    STATE(9953), 1,
      sym_attribute,
    STATE(10249), 1,
      sym__simple_type,
    STATE(17160), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10274), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [487768] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11278), 1,
      sym__lowercase_identifier,
    ACTIONS(11280), 1,
      anon_sym_LPAREN,
    ACTIONS(11282), 1,
      anon_sym_LBRACK,
    ACTIONS(11284), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11286), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11288), 1,
      anon_sym_LT,
    ACTIONS(11290), 1,
      anon_sym_POUND,
    ACTIONS(11292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11296), 1,
      aux_sym_type_variable_token1,
    STATE(9954), 1,
      sym_attribute,
    STATE(10738), 1,
      sym__simple_type,
    STATE(16787), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10877), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [487831] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12291), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(9955), 1,
      sym_attribute,
    STATE(10472), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12293), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(12289), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [487878] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9424), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9426), 1,
      anon_sym_LT,
    ACTIONS(9428), 1,
      anon_sym_POUND,
    ACTIONS(9430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9434), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10692), 1,
      anon_sym_LPAREN,
    ACTIONS(10696), 1,
      anon_sym_LBRACK,
    ACTIONS(11208), 1,
      sym__lowercase_identifier,
    STATE(9956), 1,
      sym_attribute,
    STATE(10279), 1,
      sym__simple_type,
    STATE(16665), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9574), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [487941] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12248), 1,
      sym__lowercase_identifier,
    ACTIONS(12250), 1,
      anon_sym_POUND,
    STATE(9957), 1,
      sym_attribute,
    STATE(10881), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17296), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11596), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11598), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [487996] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9424), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9426), 1,
      anon_sym_LT,
    ACTIONS(9428), 1,
      anon_sym_POUND,
    ACTIONS(9430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9434), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10692), 1,
      anon_sym_LPAREN,
    ACTIONS(10696), 1,
      anon_sym_LBRACK,
    ACTIONS(11208), 1,
      sym__lowercase_identifier,
    STATE(9958), 1,
      sym_attribute,
    STATE(10197), 1,
      sym__simple_type,
    STATE(16665), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9574), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [488059] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9424), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9426), 1,
      anon_sym_LT,
    ACTIONS(9428), 1,
      anon_sym_POUND,
    ACTIONS(9430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9434), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10692), 1,
      anon_sym_LPAREN,
    ACTIONS(10696), 1,
      anon_sym_LBRACK,
    ACTIONS(11208), 1,
      sym__lowercase_identifier,
    STATE(9959), 1,
      sym_attribute,
    STATE(10324), 1,
      sym__simple_type,
    STATE(16665), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9574), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [488122] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9160), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(12295), 1,
      anon_sym_EQ,
    ACTIONS(12297), 1,
      anon_sym_COLON_EQ,
    ACTIONS(12299), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(9960), 1,
      sym_attribute,
    STATE(10476), 1,
      aux_sym_expression_item_repeat1,
    STATE(10943), 1,
      sym__type_equation,
    STATE(11036), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11920), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [488179] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10070), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10072), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11298), 1,
      sym__lowercase_identifier,
    ACTIONS(11300), 1,
      anon_sym_LPAREN,
    ACTIONS(11302), 1,
      anon_sym_LBRACK,
    ACTIONS(11304), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11306), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11308), 1,
      anon_sym_LT,
    ACTIONS(11310), 1,
      anon_sym_POUND,
    ACTIONS(11312), 1,
      aux_sym_type_variable_token1,
    STATE(9961), 1,
      sym_attribute,
    STATE(10131), 1,
      sym__simple_type,
    STATE(17129), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10286), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [488242] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12005), 1,
      sym__lowercase_identifier,
    ACTIONS(12301), 1,
      anon_sym_POUND,
    STATE(9962), 1,
      sym_attribute,
    STATE(10696), 1,
      sym_type_constructor_path,
    STATE(17478), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11128), 9,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11130), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [488291] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9468), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9470), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9472), 1,
      anon_sym_LT,
    ACTIONS(9474), 1,
      anon_sym_POUND,
    ACTIONS(9476), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9478), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9480), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10720), 1,
      anon_sym_LPAREN,
    ACTIONS(10724), 1,
      anon_sym_LBRACK,
    ACTIONS(11340), 1,
      sym__lowercase_identifier,
    STATE(9610), 1,
      sym__simple_type,
    STATE(9963), 1,
      sym_attribute,
    STATE(16859), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9377), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [488354] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9964), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8350), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [488393] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9965), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11797), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11795), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [488432] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9900), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9902), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11368), 1,
      sym__lowercase_identifier,
    ACTIONS(11370), 1,
      anon_sym_LPAREN,
    ACTIONS(11372), 1,
      anon_sym_LBRACK,
    ACTIONS(11374), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11376), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11378), 1,
      anon_sym_LT,
    ACTIONS(11380), 1,
      anon_sym_POUND,
    ACTIONS(11382), 1,
      aux_sym_type_variable_token1,
    STATE(9966), 1,
      sym_attribute,
    STATE(10357), 1,
      sym__simple_type,
    STATE(16829), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10613), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [488495] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9900), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9902), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11368), 1,
      sym__lowercase_identifier,
    ACTIONS(11370), 1,
      anon_sym_LPAREN,
    ACTIONS(11372), 1,
      anon_sym_LBRACK,
    ACTIONS(11374), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11376), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11378), 1,
      anon_sym_LT,
    ACTIONS(11380), 1,
      anon_sym_POUND,
    ACTIONS(11382), 1,
      aux_sym_type_variable_token1,
    STATE(9967), 1,
      sym_attribute,
    STATE(10355), 1,
      sym__simple_type,
    STATE(16829), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10613), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [488558] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9968), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11472), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11470), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [488597] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11434), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11436), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [488636] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9500), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9502), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9504), 1,
      anon_sym_LT,
    ACTIONS(9506), 1,
      anon_sym_POUND,
    ACTIONS(9508), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9510), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9512), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10928), 1,
      anon_sym_LPAREN,
    ACTIONS(10932), 1,
      anon_sym_LBRACK,
    ACTIONS(11246), 1,
      sym__lowercase_identifier,
    STATE(9970), 1,
      sym_attribute,
    STATE(10452), 1,
      sym__simple_type,
    STATE(16914), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10076), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [488699] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11254), 1,
      sym__lowercase_identifier,
    ACTIONS(11400), 1,
      anon_sym_POUND,
    STATE(9379), 1,
      sym_type_constructor_path,
    STATE(9971), 1,
      sym_attribute,
    STATE(17458), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12303), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12305), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [488748] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12307), 1,
      anon_sym_STAR,
    STATE(9972), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10393), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10391), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [488789] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12248), 1,
      sym__lowercase_identifier,
    ACTIONS(12250), 1,
      anon_sym_POUND,
    STATE(9973), 1,
      sym_attribute,
    STATE(10881), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17296), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11720), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11722), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [488844] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10070), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10072), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11298), 1,
      sym__lowercase_identifier,
    ACTIONS(11300), 1,
      anon_sym_LPAREN,
    ACTIONS(11302), 1,
      anon_sym_LBRACK,
    ACTIONS(11304), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11306), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11308), 1,
      anon_sym_LT,
    ACTIONS(11310), 1,
      anon_sym_POUND,
    ACTIONS(11312), 1,
      aux_sym_type_variable_token1,
    STATE(9974), 1,
      sym_attribute,
    STATE(10124), 1,
      sym__simple_type,
    STATE(17129), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10286), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [488907] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9900), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9902), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11368), 1,
      sym__lowercase_identifier,
    ACTIONS(11370), 1,
      anon_sym_LPAREN,
    ACTIONS(11372), 1,
      anon_sym_LBRACK,
    ACTIONS(11374), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11376), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11378), 1,
      anon_sym_LT,
    ACTIONS(11380), 1,
      anon_sym_POUND,
    ACTIONS(11382), 1,
      aux_sym_type_variable_token1,
    STATE(9975), 1,
      sym_attribute,
    STATE(10356), 1,
      sym__simple_type,
    STATE(16829), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10613), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [488970] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9976), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11510), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11508), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [489009] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10070), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10072), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11298), 1,
      sym__lowercase_identifier,
    ACTIONS(11300), 1,
      anon_sym_LPAREN,
    ACTIONS(11302), 1,
      anon_sym_LBRACK,
    ACTIONS(11304), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11306), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11308), 1,
      anon_sym_LT,
    ACTIONS(11310), 1,
      anon_sym_POUND,
    ACTIONS(11312), 1,
      aux_sym_type_variable_token1,
    STATE(9977), 1,
      sym_attribute,
    STATE(10133), 1,
      sym__simple_type,
    STATE(17129), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10286), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [489072] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9978), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9578), 10,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9580), 14,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [489111] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12274), 1,
      sym__lowercase_identifier,
    ACTIONS(12276), 1,
      anon_sym_POUND,
    STATE(9979), 1,
      sym_attribute,
    STATE(10867), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17441), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11500), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11502), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [489166] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9980), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9582), 10,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9584), 14,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [489205] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12274), 1,
      sym__lowercase_identifier,
    ACTIONS(12276), 1,
      anon_sym_POUND,
    STATE(9981), 1,
      sym_attribute,
    STATE(10867), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17441), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11588), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11590), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [489260] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11763), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11765), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [489299] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10016), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10018), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11210), 1,
      sym__lowercase_identifier,
    ACTIONS(11212), 1,
      anon_sym_LPAREN,
    ACTIONS(11214), 1,
      anon_sym_LBRACK,
    ACTIONS(11216), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11218), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11220), 1,
      anon_sym_LT,
    ACTIONS(11222), 1,
      anon_sym_POUND,
    ACTIONS(11224), 1,
      aux_sym_type_variable_token1,
    STATE(9983), 1,
      sym_attribute,
    STATE(10895), 1,
      sym__simple_type,
    STATE(17224), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10848), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [489362] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9984), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8362), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [489401] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9900), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9902), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11368), 1,
      sym__lowercase_identifier,
    ACTIONS(11370), 1,
      anon_sym_LPAREN,
    ACTIONS(11372), 1,
      anon_sym_LBRACK,
    ACTIONS(11374), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11376), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11378), 1,
      anon_sym_LT,
    ACTIONS(11380), 1,
      anon_sym_POUND,
    ACTIONS(11382), 1,
      aux_sym_type_variable_token1,
    STATE(9985), 1,
      sym_attribute,
    STATE(10421), 1,
      sym__simple_type,
    STATE(16829), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10613), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [489464] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11540), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11538), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [489503] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9160), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(12297), 1,
      anon_sym_COLON_EQ,
    ACTIONS(12299), 1,
      anon_sym_constraint,
    ACTIONS(12309), 1,
      anon_sym_EQ,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(9987), 1,
      sym_attribute,
    STATE(10486), 1,
      aux_sym_expression_item_repeat1,
    STATE(10964), 1,
      sym__type_equation,
    STATE(11019), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11882), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [489560] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12248), 1,
      sym__lowercase_identifier,
    ACTIONS(12250), 1,
      anon_sym_POUND,
    STATE(9988), 1,
      sym_attribute,
    STATE(10881), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17296), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11500), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11502), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [489615] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11847), 1,
      sym__lowercase_identifier,
    ACTIONS(11849), 1,
      anon_sym_POUND,
    STATE(9989), 1,
      sym_attribute,
    STATE(10244), 1,
      sym_type_constructor_path,
    STATE(17325), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12085), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12087), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [489664] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9990), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11476), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11474), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [489703] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10016), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10018), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11210), 1,
      sym__lowercase_identifier,
    ACTIONS(11212), 1,
      anon_sym_LPAREN,
    ACTIONS(11214), 1,
      anon_sym_LBRACK,
    ACTIONS(11216), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11218), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11220), 1,
      anon_sym_LT,
    ACTIONS(11222), 1,
      anon_sym_POUND,
    ACTIONS(11224), 1,
      aux_sym_type_variable_token1,
    STATE(9991), 1,
      sym_attribute,
    STATE(10505), 1,
      sym__simple_type,
    STATE(17224), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10848), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [489766] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9906), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_LBRACK,
    ACTIONS(9910), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9912), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9914), 1,
      anon_sym_LT,
    ACTIONS(9916), 1,
      anon_sym_POUND,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9920), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9922), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11318), 1,
      sym__lowercase_identifier,
    STATE(9992), 1,
      sym_attribute,
    STATE(10479), 1,
      sym__simple_type,
    STATE(16934), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11018), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [489829] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12311), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9993), 1,
      sym_attribute,
    STATE(10030), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12238), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12236), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [489874] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9900), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9902), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11368), 1,
      sym__lowercase_identifier,
    ACTIONS(11370), 1,
      anon_sym_LPAREN,
    ACTIONS(11372), 1,
      anon_sym_LBRACK,
    ACTIONS(11374), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11376), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11378), 1,
      anon_sym_LT,
    ACTIONS(11380), 1,
      anon_sym_POUND,
    ACTIONS(11382), 1,
      aux_sym_type_variable_token1,
    STATE(9994), 1,
      sym_attribute,
    STATE(10563), 1,
      sym__simple_type,
    STATE(16829), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10613), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [489937] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11949), 1,
      sym__lowercase_identifier,
    ACTIONS(12057), 1,
      anon_sym_POUND,
    ACTIONS(12313), 1,
      anon_sym_STAR,
    STATE(9995), 1,
      sym_attribute,
    STATE(10027), 1,
      sym_type_constructor_path,
    STATE(11538), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17413), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11458), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11896), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [489990] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9900), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9902), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11368), 1,
      sym__lowercase_identifier,
    ACTIONS(11370), 1,
      anon_sym_LPAREN,
    ACTIONS(11372), 1,
      anon_sym_LBRACK,
    ACTIONS(11374), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11376), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11378), 1,
      anon_sym_LT,
    ACTIONS(11380), 1,
      anon_sym_POUND,
    ACTIONS(11382), 1,
      aux_sym_type_variable_token1,
    STATE(9996), 1,
      sym_attribute,
    STATE(10575), 1,
      sym__simple_type,
    STATE(16829), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10613), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [490053] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11278), 1,
      sym__lowercase_identifier,
    ACTIONS(11280), 1,
      anon_sym_LPAREN,
    ACTIONS(11282), 1,
      anon_sym_LBRACK,
    ACTIONS(11284), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11286), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11288), 1,
      anon_sym_LT,
    ACTIONS(11290), 1,
      anon_sym_POUND,
    ACTIONS(11292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11296), 1,
      aux_sym_type_variable_token1,
    STATE(9997), 1,
      sym_attribute,
    STATE(10756), 1,
      sym__simple_type,
    STATE(16787), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10877), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [490116] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12240), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9998), 1,
      sym_attribute,
    STATE(10044), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12317), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12315), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [490161] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10016), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10018), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11210), 1,
      sym__lowercase_identifier,
    ACTIONS(11212), 1,
      anon_sym_LPAREN,
    ACTIONS(11214), 1,
      anon_sym_LBRACK,
    ACTIONS(11216), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11218), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11220), 1,
      anon_sym_LT,
    ACTIONS(11222), 1,
      anon_sym_POUND,
    ACTIONS(11224), 1,
      aux_sym_type_variable_token1,
    STATE(9999), 1,
      sym_attribute,
    STATE(10908), 1,
      sym__simple_type,
    STATE(17224), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10848), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [490224] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9406), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10680), 1,
      anon_sym_LPAREN,
    ACTIONS(10684), 1,
      anon_sym_LBRACK,
    ACTIONS(11252), 1,
      sym__lowercase_identifier,
    STATE(9898), 1,
      sym__simple_type,
    STATE(10000), 1,
      sym_attribute,
    STATE(16745), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9437), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [490287] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9406), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10680), 1,
      anon_sym_LPAREN,
    ACTIONS(10684), 1,
      anon_sym_LBRACK,
    ACTIONS(11252), 1,
      sym__lowercase_identifier,
    STATE(10001), 1,
      sym_attribute,
    STATE(10066), 1,
      sym__simple_type,
    STATE(16745), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9437), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [490350] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9158), 1,
      sym__lowercase_identifier,
    ACTIONS(12319), 1,
      anon_sym_COLON2,
    STATE(10002), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 4,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
    ACTIONS(11436), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11434), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [490395] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9406), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10680), 1,
      anon_sym_LPAREN,
    ACTIONS(10684), 1,
      anon_sym_LBRACK,
    ACTIONS(11252), 1,
      sym__lowercase_identifier,
    STATE(9947), 1,
      sym__simple_type,
    STATE(10003), 1,
      sym_attribute,
    STATE(16745), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9437), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [490458] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9406), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10680), 1,
      anon_sym_LPAREN,
    ACTIONS(10684), 1,
      anon_sym_LBRACK,
    ACTIONS(11252), 1,
      sym__lowercase_identifier,
    STATE(10004), 1,
      sym_attribute,
    STATE(10046), 1,
      sym__simple_type,
    STATE(16745), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9437), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [490521] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10730), 1,
      anon_sym_LPAREN,
    ACTIONS(10734), 1,
      anon_sym_LBRACK,
    ACTIONS(10736), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10738), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10740), 1,
      anon_sym_LT,
    ACTIONS(10742), 1,
      anon_sym_POUND,
    ACTIONS(10744), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10746), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10748), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12321), 1,
      sym__lowercase_identifier,
    STATE(9014), 1,
      sym__simple_type,
    STATE(10005), 1,
      sym_attribute,
    STATE(17101), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9439), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [490584] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11278), 1,
      sym__lowercase_identifier,
    ACTIONS(11280), 1,
      anon_sym_LPAREN,
    ACTIONS(11282), 1,
      anon_sym_LBRACK,
    ACTIONS(11284), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11286), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11288), 1,
      anon_sym_LT,
    ACTIONS(11290), 1,
      anon_sym_POUND,
    ACTIONS(11292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11296), 1,
      aux_sym_type_variable_token1,
    STATE(10006), 1,
      sym_attribute,
    STATE(10757), 1,
      sym__simple_type,
    STATE(16787), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10877), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [490647] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    STATE(10007), 1,
      sym_attribute,
    STATE(13583), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [490710] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9406), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10680), 1,
      anon_sym_LPAREN,
    ACTIONS(10684), 1,
      anon_sym_LBRACK,
    ACTIONS(11252), 1,
      sym__lowercase_identifier,
    STATE(10008), 1,
      sym_attribute,
    STATE(10095), 1,
      sym__simple_type,
    STATE(16745), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9437), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [490773] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9500), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9502), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9504), 1,
      anon_sym_LT,
    ACTIONS(9506), 1,
      anon_sym_POUND,
    ACTIONS(9508), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9510), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9512), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10928), 1,
      anon_sym_LPAREN,
    ACTIONS(10932), 1,
      anon_sym_LBRACK,
    ACTIONS(11246), 1,
      sym__lowercase_identifier,
    STATE(10009), 1,
      sym_attribute,
    STATE(10309), 1,
      sym__simple_type,
    STATE(16914), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10076), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [490836] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11254), 1,
      sym__lowercase_identifier,
    ACTIONS(11400), 1,
      anon_sym_POUND,
    STATE(9379), 1,
      sym_type_constructor_path,
    STATE(10010), 1,
      sym_attribute,
    STATE(17458), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12242), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12244), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [490885] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12311), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(10011), 1,
      sym_attribute,
    STATE(10043), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12317), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12315), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [490930] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9406), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10680), 1,
      anon_sym_LPAREN,
    ACTIONS(10684), 1,
      anon_sym_LBRACK,
    ACTIONS(11252), 1,
      sym__lowercase_identifier,
    STATE(10012), 1,
      sym_attribute,
    STATE(10094), 1,
      sym__simple_type,
    STATE(16745), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9437), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [490993] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11320), 1,
      sym__lowercase_identifier,
    ACTIONS(11322), 1,
      anon_sym_LPAREN,
    ACTIONS(11324), 1,
      anon_sym_LBRACK,
    ACTIONS(11326), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11328), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11330), 1,
      anon_sym_LT,
    ACTIONS(11332), 1,
      anon_sym_POUND,
    ACTIONS(11334), 1,
      aux_sym_type_variable_token1,
    STATE(10013), 1,
      sym_attribute,
    STATE(13491), 1,
      sym__simple_type,
    STATE(16970), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13564), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [491056] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12218), 1,
      sym__lowercase_identifier,
    ACTIONS(12220), 1,
      anon_sym_POUND,
    STATE(10014), 1,
      sym_attribute,
    STATE(10903), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17519), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11596), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11598), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [491111] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9158), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [491150] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12240), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9948), 1,
      aux_sym_type_binding_repeat1,
    STATE(10016), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12317), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12315), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [491195] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8354), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [491234] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8358), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [491273] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12222), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12224), 1,
      sym_pow_operator,
    ACTIONS(12226), 1,
      sym_mult_operator,
    ACTIONS(12228), 1,
      sym_concat_operator,
    STATE(2236), 1,
      sym_add_operator,
    STATE(10019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 13,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
  [491324] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10020), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11416), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11414), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [491363] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12248), 1,
      sym__lowercase_identifier,
    ACTIONS(12250), 1,
      anon_sym_POUND,
    STATE(10021), 1,
      sym_attribute,
    STATE(10881), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17296), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11462), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11464), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [491418] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10022), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11694), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11692), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [491457] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12248), 1,
      sym__lowercase_identifier,
    ACTIONS(12250), 1,
      anon_sym_POUND,
    STATE(10023), 1,
      sym_attribute,
    STATE(10881), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17296), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11454), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11456), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [491512] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11845), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11560), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11562), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [491553] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9424), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9426), 1,
      anon_sym_LT,
    ACTIONS(9428), 1,
      anon_sym_POUND,
    ACTIONS(9430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9434), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10692), 1,
      anon_sym_LPAREN,
    ACTIONS(10696), 1,
      anon_sym_LBRACK,
    ACTIONS(11208), 1,
      sym__lowercase_identifier,
    STATE(9920), 1,
      sym__simple_type,
    STATE(10025), 1,
      sym_attribute,
    STATE(16665), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9574), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [491616] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10026), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11536), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11534), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [491655] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10027), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11640), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11638), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [491694] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10028), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8358), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [491733] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12256), 1,
      anon_sym_DQUOTE,
    ACTIONS(12325), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10029), 1,
      sym_attribute,
    STATE(10666), 1,
      aux_sym_external_repeat1,
    STATE(10819), 1,
      aux_sym_expression_item_repeat1,
    STATE(11083), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12323), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [491784] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12311), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(10030), 1,
      sym_attribute,
    STATE(10079), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12317), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12315), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [491829] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10031), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9574), 10,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9576), 14,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [491868] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11845), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11562), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11560), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [491909] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11320), 1,
      sym__lowercase_identifier,
    ACTIONS(11322), 1,
      anon_sym_LPAREN,
    ACTIONS(11324), 1,
      anon_sym_LBRACK,
    ACTIONS(11326), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11328), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11330), 1,
      anon_sym_LT,
    ACTIONS(11332), 1,
      anon_sym_POUND,
    ACTIONS(11334), 1,
      aux_sym_type_variable_token1,
    STATE(10033), 1,
      sym_attribute,
    STATE(13610), 1,
      sym__simple_type,
    STATE(16970), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13564), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [491972] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7405), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7407), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7869), 1,
      anon_sym_LPAREN,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7891), 1,
      anon_sym_LT,
    ACTIONS(7893), 1,
      anon_sym_POUND,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    STATE(10034), 1,
      sym_attribute,
    STATE(14143), 1,
      sym__simple_type,
    STATE(16552), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12249), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [492035] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10035), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8362), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [492074] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12274), 1,
      sym__lowercase_identifier,
    ACTIONS(12276), 1,
      anon_sym_POUND,
    STATE(10036), 1,
      sym_attribute,
    STATE(10867), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17441), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11454), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11456), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [492129] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11706), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11704), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [492168] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8360), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
  [492207] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12274), 1,
      sym__lowercase_identifier,
    ACTIONS(12276), 1,
      anon_sym_POUND,
    STATE(10039), 1,
      sym_attribute,
    STATE(10867), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17441), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11462), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11464), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [492262] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11863), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10040), 1,
      sym_attribute,
    STATE(10395), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11865), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(11861), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [492309] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10041), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11600), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [492348] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9116), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12222), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12224), 1,
      sym_pow_operator,
    ACTIONS(12226), 1,
      sym_mult_operator,
    ACTIONS(12228), 1,
      sym_concat_operator,
    ACTIONS(12230), 1,
      sym_rel_operator,
    ACTIONS(12232), 1,
      sym_and_operator,
    ACTIONS(12234), 1,
      sym_or_operator,
    ACTIONS(12262), 1,
      anon_sym_COMMA,
    ACTIONS(12264), 1,
      sym_assign_operator,
    ACTIONS(12327), 1,
      anon_sym_SEMI,
    STATE(2236), 1,
      sym_add_operator,
    STATE(10042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9114), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [492411] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12311), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(10043), 1,
      sym_attribute,
    STATE(10079), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12331), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12329), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [492456] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12240), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9948), 1,
      aux_sym_type_binding_repeat1,
    STATE(10044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12331), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12329), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [492501] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10045), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11440), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11438), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [492540] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11346), 1,
      sym__lowercase_identifier,
    ACTIONS(11558), 1,
      anon_sym_POUND,
    STATE(9468), 1,
      sym_type_constructor_path,
    STATE(10046), 1,
      sym_attribute,
    STATE(17537), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11720), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11722), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [492589] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10884), 1,
      anon_sym_LPAREN,
    ACTIONS(10888), 1,
      anon_sym_LBRACK,
    ACTIONS(10890), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10892), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10894), 1,
      anon_sym_LT,
    ACTIONS(10896), 1,
      anon_sym_POUND,
    ACTIONS(10898), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10900), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10902), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12333), 1,
      sym__lowercase_identifier,
    STATE(9252), 1,
      sym__simple_type,
    STATE(10047), 1,
      sym_attribute,
    STATE(17294), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9653), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [492652] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(12335), 1,
      anon_sym_COLON2,
    STATE(9272), 1,
      aux_sym_module_binding_repeat1,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(9955), 1,
      sym__module_typed,
    STATE(10048), 1,
      sym_attribute,
    STATE(10395), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11865), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(11861), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [492707] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10340), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12222), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12224), 1,
      sym_pow_operator,
    ACTIONS(12226), 1,
      sym_mult_operator,
    ACTIONS(12228), 1,
      sym_concat_operator,
    ACTIONS(12230), 1,
      sym_rel_operator,
    ACTIONS(12232), 1,
      sym_and_operator,
    ACTIONS(12234), 1,
      sym_or_operator,
    ACTIONS(12262), 1,
      anon_sym_COMMA,
    ACTIONS(12264), 1,
      sym_assign_operator,
    STATE(2236), 1,
      sym_add_operator,
    STATE(10049), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10338), 10,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [492768] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10050), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11444), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11442), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [492807] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10051), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8356), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
  [492846] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12218), 1,
      sym__lowercase_identifier,
    ACTIONS(12220), 1,
      anon_sym_POUND,
    STATE(10052), 1,
      sym_attribute,
    STATE(10903), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17519), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11462), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11464), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [492901] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12337), 1,
      anon_sym_LPAREN,
    ACTIONS(12339), 1,
      anon_sym_LBRACK,
    STATE(10053), 1,
      sym_attribute,
    STATE(10775), 1,
      sym__constructor_name,
    STATE(11658), 1,
      sym_constructor_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12075), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12341), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(12073), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [492952] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10054), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8354), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [492991] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10134), 1,
      anon_sym_LPAREN,
    ACTIONS(10136), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10140), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10142), 1,
      anon_sym_LT,
    ACTIONS(10144), 1,
      anon_sym_POUND,
    ACTIONS(10146), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10148), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10150), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11316), 1,
      sym__lowercase_identifier,
    STATE(10055), 1,
      sym_attribute,
    STATE(11052), 1,
      sym__simple_type,
    STATE(16704), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10841), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [493054] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11320), 1,
      sym__lowercase_identifier,
    ACTIONS(11322), 1,
      anon_sym_LPAREN,
    ACTIONS(11324), 1,
      anon_sym_LBRACK,
    ACTIONS(11326), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11328), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11330), 1,
      anon_sym_LT,
    ACTIONS(11332), 1,
      anon_sym_POUND,
    ACTIONS(11334), 1,
      aux_sym_type_variable_token1,
    STATE(10056), 1,
      sym_attribute,
    STATE(13609), 1,
      sym__simple_type,
    STATE(16970), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13564), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [493117] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9424), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9426), 1,
      anon_sym_LT,
    ACTIONS(9428), 1,
      anon_sym_POUND,
    ACTIONS(9430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9434), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10692), 1,
      anon_sym_LPAREN,
    ACTIONS(10696), 1,
      anon_sym_LBRACK,
    ACTIONS(11208), 1,
      sym__lowercase_identifier,
    STATE(9476), 1,
      sym__simple_type,
    STATE(10057), 1,
      sym_attribute,
    STATE(16665), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9574), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [493180] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(12335), 1,
      anon_sym_COLON2,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10040), 1,
      sym__module_typed,
    STATE(10048), 1,
      aux_sym_module_binding_repeat1,
    STATE(10058), 1,
      sym_attribute,
    STATE(10596), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11855), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(11851), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [493235] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11320), 1,
      sym__lowercase_identifier,
    ACTIONS(11322), 1,
      anon_sym_LPAREN,
    ACTIONS(11324), 1,
      anon_sym_LBRACK,
    ACTIONS(11326), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11328), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11330), 1,
      anon_sym_LT,
    ACTIONS(11332), 1,
      anon_sym_POUND,
    ACTIONS(11334), 1,
      aux_sym_type_variable_token1,
    STATE(10059), 1,
      sym_attribute,
    STATE(13602), 1,
      sym__simple_type,
    STATE(16970), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13564), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [493298] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10060), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11428), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11426), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [493337] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10061), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8350), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8352), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
  [493376] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10062), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 10,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8228), 14,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [493415] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10063), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12345), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12343), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [493454] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12274), 1,
      sym__lowercase_identifier,
    ACTIONS(12276), 1,
      anon_sym_POUND,
    STATE(10064), 1,
      sym_attribute,
    STATE(10867), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17441), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11596), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11598), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [493509] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9500), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9502), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9504), 1,
      anon_sym_LT,
    ACTIONS(9506), 1,
      anon_sym_POUND,
    ACTIONS(9508), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9510), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9512), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10928), 1,
      anon_sym_LPAREN,
    ACTIONS(10932), 1,
      anon_sym_LBRACK,
    ACTIONS(11246), 1,
      sym__lowercase_identifier,
    STATE(10065), 1,
      sym_attribute,
    STATE(10454), 1,
      sym__simple_type,
    STATE(16914), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10076), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [493572] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11346), 1,
      sym__lowercase_identifier,
    ACTIONS(11558), 1,
      anon_sym_POUND,
    STATE(9468), 1,
      sym_type_constructor_path,
    STATE(10066), 1,
      sym_attribute,
    STATE(17537), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12303), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12305), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [493621] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9992), 1,
      anon_sym_LPAREN,
    ACTIONS(9994), 1,
      anon_sym_LBRACK,
    ACTIONS(9996), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9998), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10000), 1,
      anon_sym_LT,
    ACTIONS(10002), 1,
      anon_sym_POUND,
    ACTIONS(10004), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10006), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10008), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12347), 1,
      sym__lowercase_identifier,
    STATE(10067), 1,
      sym_attribute,
    STATE(11098), 1,
      sym__simple_type,
    STATE(17058), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11773), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [493684] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11254), 1,
      sym__lowercase_identifier,
    ACTIONS(11400), 1,
      anon_sym_POUND,
    STATE(9379), 1,
      sym_type_constructor_path,
    STATE(10068), 1,
      sym_attribute,
    STATE(17458), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11500), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11502), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [493733] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10134), 1,
      anon_sym_LPAREN,
    ACTIONS(10136), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10140), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10142), 1,
      anon_sym_LT,
    ACTIONS(10144), 1,
      anon_sym_POUND,
    ACTIONS(10146), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10148), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10150), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11316), 1,
      sym__lowercase_identifier,
    STATE(10069), 1,
      sym_attribute,
    STATE(11202), 1,
      sym__simple_type,
    STATE(16704), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10841), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [493796] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10070), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11552), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11550), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [493835] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10700), 1,
      anon_sym_LPAREN,
    ACTIONS(10704), 1,
      anon_sym_LBRACK,
    ACTIONS(10706), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10708), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10710), 1,
      anon_sym_LT,
    ACTIONS(10712), 1,
      anon_sym_POUND,
    ACTIONS(10714), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10716), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10718), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    STATE(8956), 1,
      sym__simple_type,
    STATE(10071), 1,
      sym_attribute,
    STATE(17326), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9339), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [493898] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12351), 1,
      anon_sym_LPAREN,
    ACTIONS(12353), 1,
      anon_sym_LBRACK,
    STATE(10072), 1,
      sym_attribute,
    STATE(10915), 1,
      sym__constructor_name,
    STATE(11560), 1,
      sym_constructor_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12075), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12355), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(12073), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [493949] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11320), 1,
      sym__lowercase_identifier,
    ACTIONS(11322), 1,
      anon_sym_LPAREN,
    ACTIONS(11324), 1,
      anon_sym_LBRACK,
    ACTIONS(11326), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11328), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11330), 1,
      anon_sym_LT,
    ACTIONS(11332), 1,
      anon_sym_POUND,
    ACTIONS(11334), 1,
      aux_sym_type_variable_token1,
    STATE(10073), 1,
      sym_attribute,
    STATE(13590), 1,
      sym__simple_type,
    STATE(16970), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13564), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [494012] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12075), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12357), 1,
      anon_sym_LPAREN,
    ACTIONS(12359), 1,
      anon_sym_LBRACK,
    STATE(10074), 1,
      sym_attribute,
    STATE(10928), 1,
      sym__constructor_name,
    STATE(11692), 1,
      sym_constructor_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12361), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(12073), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [494063] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10075), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11496), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11494), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [494102] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10076), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11562), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11560), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [494141] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11320), 1,
      sym__lowercase_identifier,
    ACTIONS(11322), 1,
      anon_sym_LPAREN,
    ACTIONS(11324), 1,
      anon_sym_LBRACK,
    ACTIONS(11326), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11328), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11330), 1,
      anon_sym_LT,
    ACTIONS(11332), 1,
      anon_sym_POUND,
    ACTIONS(11334), 1,
      aux_sym_type_variable_token1,
    STATE(10077), 1,
      sym_attribute,
    STATE(13575), 1,
      sym__simple_type,
    STATE(16970), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13564), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [494204] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10078), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11009), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11007), 13,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
  [494243] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12363), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12284), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(10079), 2,
      sym_attribute,
      aux_sym_type_binding_repeat1,
    ACTIONS(12282), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [494286] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11254), 1,
      sym__lowercase_identifier,
    ACTIONS(11400), 1,
      anon_sym_POUND,
    STATE(9379), 1,
      sym_type_constructor_path,
    STATE(10080), 1,
      sym_attribute,
    STATE(17458), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11588), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11590), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [494335] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12366), 1,
      anon_sym_COLON,
    STATE(10081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9598), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9600), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [494376] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11918), 1,
      anon_sym_COLON2,
    STATE(10082), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9158), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [494417] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9500), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9502), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9504), 1,
      anon_sym_LT,
    ACTIONS(9506), 1,
      anon_sym_POUND,
    ACTIONS(9508), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9510), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9512), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10928), 1,
      anon_sym_LPAREN,
    ACTIONS(10932), 1,
      anon_sym_LBRACK,
    ACTIONS(11246), 1,
      sym__lowercase_identifier,
    STATE(10083), 1,
      sym_attribute,
    STATE(10464), 1,
      sym__simple_type,
    STATE(16914), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10076), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [494480] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9158), 1,
      sym__lowercase_identifier,
    ACTIONS(12368), 1,
      anon_sym_COLON2,
    STATE(10084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 4,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
    ACTIONS(11436), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11434), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [494525] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10024), 1,
      anon_sym_LPAREN,
    ACTIONS(10026), 1,
      anon_sym_LBRACK,
    ACTIONS(10028), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10030), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10032), 1,
      anon_sym_LT,
    ACTIONS(10034), 1,
      anon_sym_POUND,
    ACTIONS(10036), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10038), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10040), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12370), 1,
      sym__lowercase_identifier,
    STATE(10085), 1,
      sym_attribute,
    STATE(12209), 1,
      sym__simple_type,
    STATE(17260), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12684), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [494588] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10134), 1,
      anon_sym_LPAREN,
    ACTIONS(10136), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10140), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10142), 1,
      anon_sym_LT,
    ACTIONS(10144), 1,
      anon_sym_POUND,
    ACTIONS(10146), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10148), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10150), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11316), 1,
      sym__lowercase_identifier,
    STATE(10086), 1,
      sym_attribute,
    STATE(11203), 1,
      sym__simple_type,
    STATE(16704), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10841), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [494651] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7569), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7571), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11320), 1,
      sym__lowercase_identifier,
    ACTIONS(11322), 1,
      anon_sym_LPAREN,
    ACTIONS(11324), 1,
      anon_sym_LBRACK,
    ACTIONS(11326), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11328), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11330), 1,
      anon_sym_LT,
    ACTIONS(11332), 1,
      anon_sym_POUND,
    ACTIONS(11334), 1,
      aux_sym_type_variable_token1,
    STATE(10087), 1,
      sym_attribute,
    STATE(13572), 1,
      sym__simple_type,
    STATE(16970), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13564), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [494714] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9906), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_LBRACK,
    ACTIONS(9910), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9912), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9914), 1,
      anon_sym_LT,
    ACTIONS(9916), 1,
      anon_sym_POUND,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9920), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9922), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11318), 1,
      sym__lowercase_identifier,
    STATE(10088), 1,
      sym_attribute,
    STATE(11063), 1,
      sym__simple_type,
    STATE(16934), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11018), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [494777] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10089), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11644), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11642), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [494816] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10090), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11634), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11632), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [494855] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10805), 1,
      anon_sym_LPAREN,
    ACTIONS(10809), 1,
      anon_sym_LBRACK,
    ACTIONS(10811), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10813), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10815), 1,
      anon_sym_LT,
    ACTIONS(10817), 1,
      anon_sym_POUND,
    ACTIONS(10819), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10821), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10823), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12372), 1,
      sym__lowercase_identifier,
    STATE(10091), 1,
      sym_attribute,
    STATE(12741), 1,
      sym__simple_type,
    STATE(17392), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12924), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [494918] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10134), 1,
      anon_sym_LPAREN,
    ACTIONS(10136), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10140), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10142), 1,
      anon_sym_LT,
    ACTIONS(10144), 1,
      anon_sym_POUND,
    ACTIONS(10146), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10148), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10150), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11316), 1,
      sym__lowercase_identifier,
    STATE(10092), 1,
      sym_attribute,
    STATE(10297), 1,
      sym__simple_type,
    STATE(16704), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10841), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [494981] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10093), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9258), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9256), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [495020] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11346), 1,
      sym__lowercase_identifier,
    ACTIONS(11558), 1,
      anon_sym_POUND,
    STATE(9468), 1,
      sym_type_constructor_path,
    STATE(10094), 1,
      sym_attribute,
    STATE(17537), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11588), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11590), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [495069] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11346), 1,
      sym__lowercase_identifier,
    ACTIONS(11558), 1,
      anon_sym_POUND,
    STATE(9468), 1,
      sym_type_constructor_path,
    STATE(10095), 1,
      sym_attribute,
    STATE(17537), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11500), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11502), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [495118] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12005), 1,
      sym__lowercase_identifier,
    ACTIONS(12007), 1,
      anon_sym_POUND,
    ACTIONS(12374), 1,
      anon_sym_STAR,
    STATE(10096), 1,
      sym_attribute,
    STATE(10644), 1,
      sym_type_constructor_path,
    STATE(11349), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17478), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11458), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11896), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [495171] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10097), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8350), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [495210] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10098), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11448), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11446), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [495249] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11278), 1,
      sym__lowercase_identifier,
    ACTIONS(11280), 1,
      anon_sym_LPAREN,
    ACTIONS(11282), 1,
      anon_sym_LBRACK,
    ACTIONS(11284), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11286), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11288), 1,
      anon_sym_LT,
    ACTIONS(11290), 1,
      anon_sym_POUND,
    ACTIONS(11292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11296), 1,
      aux_sym_type_variable_token1,
    STATE(10099), 1,
      sym_attribute,
    STATE(10727), 1,
      sym__simple_type,
    STATE(16787), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10877), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [495312] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10100), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9586), 10,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9588), 14,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [495351] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9500), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9502), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9504), 1,
      anon_sym_LT,
    ACTIONS(9506), 1,
      anon_sym_POUND,
    ACTIONS(9508), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9510), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9512), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10928), 1,
      anon_sym_LPAREN,
    ACTIONS(10932), 1,
      anon_sym_LBRACK,
    ACTIONS(11246), 1,
      sym__lowercase_identifier,
    STATE(9598), 1,
      sym__simple_type,
    STATE(10101), 1,
      sym_attribute,
    STATE(16914), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10076), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [495414] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9468), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9470), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9472), 1,
      anon_sym_LT,
    ACTIONS(9474), 1,
      anon_sym_POUND,
    ACTIONS(9476), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9478), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9480), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10720), 1,
      anon_sym_LPAREN,
    ACTIONS(10724), 1,
      anon_sym_LBRACK,
    ACTIONS(11340), 1,
      sym__lowercase_identifier,
    STATE(9211), 1,
      sym__simple_type,
    STATE(10102), 1,
      sym_attribute,
    STATE(16859), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9377), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [495477] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11278), 1,
      sym__lowercase_identifier,
    ACTIONS(11280), 1,
      anon_sym_LPAREN,
    ACTIONS(11282), 1,
      anon_sym_LBRACK,
    ACTIONS(11284), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11286), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11288), 1,
      anon_sym_LT,
    ACTIONS(11290), 1,
      anon_sym_POUND,
    ACTIONS(11292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11296), 1,
      aux_sym_type_variable_token1,
    STATE(10103), 1,
      sym_attribute,
    STATE(10726), 1,
      sym__simple_type,
    STATE(16787), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10877), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [495540] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10104), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11678), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11676), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [495579] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10105), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11480), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11478), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [495618] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11872), 1,
      sym__lowercase_identifier,
    ACTIONS(11874), 1,
      anon_sym_POUND,
    STATE(10106), 1,
      sym_attribute,
    STATE(10127), 1,
      sym_type_constructor_path,
    STATE(17343), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12085), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12087), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [495667] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12218), 1,
      sym__lowercase_identifier,
    ACTIONS(12220), 1,
      anon_sym_POUND,
    STATE(10107), 1,
      sym_attribute,
    STATE(10903), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17519), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11720), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11722), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [495722] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9116), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12222), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12224), 1,
      sym_pow_operator,
    ACTIONS(12226), 1,
      sym_mult_operator,
    ACTIONS(12228), 1,
      sym_concat_operator,
    ACTIONS(12230), 1,
      sym_rel_operator,
    ACTIONS(12232), 1,
      sym_and_operator,
    ACTIONS(12234), 1,
      sym_or_operator,
    ACTIONS(12262), 1,
      anon_sym_COMMA,
    ACTIONS(12264), 1,
      sym_assign_operator,
    ACTIONS(12376), 1,
      anon_sym_SEMI,
    STATE(2236), 1,
      sym_add_operator,
    STATE(10108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9114), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [495785] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10134), 1,
      anon_sym_LPAREN,
    ACTIONS(10136), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10140), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10142), 1,
      anon_sym_LT,
    ACTIONS(10144), 1,
      anon_sym_POUND,
    ACTIONS(10146), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10148), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10150), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11316), 1,
      sym__lowercase_identifier,
    STATE(10109), 1,
      sym_attribute,
    STATE(10713), 1,
      sym__simple_type,
    STATE(16704), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10841), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [495848] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9754), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9756), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [495886] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12382), 1,
      anon_sym_RPAREN,
    ACTIONS(12384), 1,
      anon_sym__,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12394), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10111), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(16059), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [495952] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9630), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9632), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [495990] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12396), 1,
      sym__lowercase_identifier,
    ACTIONS(12398), 1,
      anon_sym_POUND,
    STATE(10113), 1,
      sym_attribute,
    STATE(10926), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17037), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11596), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11598), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [496044] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10114), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11578), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11576), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [496082] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9256), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9258), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [496120] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9622), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9624), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [496158] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12400), 1,
      anon_sym_DASH_GT,
    ACTIONS(12402), 1,
      anon_sym_functor,
    ACTIONS(12404), 1,
      anon_sym_PERCENT,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10117), 1,
      sym_attribute,
    STATE(10812), 1,
      sym__attribute,
    STATE(11300), 1,
      sym__module_type,
    STATE(14484), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [496224] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10118), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11540), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11538), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [496262] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10119), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9646), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9648), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [496300] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10120), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8302), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [496338] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11628), 1,
      sym__lowercase_identifier,
    ACTIONS(11837), 1,
      anon_sym_POUND,
    STATE(9731), 1,
      sym_type_constructor_path,
    STATE(10121), 1,
      sym_attribute,
    STATE(16902), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11500), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11502), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [496386] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10122), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11436), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11434), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [496424] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9626), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9628), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [496462] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11872), 1,
      sym__lowercase_identifier,
    ACTIONS(11874), 1,
      anon_sym_POUND,
    STATE(10124), 1,
      sym_attribute,
    STATE(10127), 1,
      sym_type_constructor_path,
    STATE(17343), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12303), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12305), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [496510] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11536), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11534), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [496548] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8288), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [496586] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10127), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11640), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11638), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [496624] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9256), 1,
      sym__lowercase_identifier,
    STATE(10128), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9258), 4,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
    ACTIONS(11765), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11763), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [496666] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12404), 1,
      anon_sym_PERCENT,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10129), 1,
      sym_attribute,
    STATE(10746), 1,
      sym__attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(16142), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [496732] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10130), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8272), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [496770] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11872), 1,
      sym__lowercase_identifier,
    ACTIONS(11874), 1,
      anon_sym_POUND,
    STATE(10127), 1,
      sym_type_constructor_path,
    STATE(10131), 1,
      sym_attribute,
    STATE(17343), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12278), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12280), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [496818] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11496), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11494), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [496856] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11872), 1,
      sym__lowercase_identifier,
    ACTIONS(11874), 1,
      anon_sym_POUND,
    STATE(10127), 1,
      sym_type_constructor_path,
    STATE(10133), 1,
      sym_attribute,
    STATE(17343), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12242), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12244), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [496904] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9710), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9712), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [496942] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12404), 1,
      anon_sym_PERCENT,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10135), 1,
      sym_attribute,
    STATE(10764), 1,
      sym__attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(16011), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [497008] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11628), 1,
      sym__lowercase_identifier,
    ACTIONS(11837), 1,
      anon_sym_POUND,
    STATE(9731), 1,
      sym_type_constructor_path,
    STATE(10136), 1,
      sym_attribute,
    STATE(16902), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11588), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11590), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [497056] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12408), 1,
      anon_sym_else,
    STATE(8259), 1,
      sym_else_clause,
    STATE(10137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [497098] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9144), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9146), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [497136] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10139), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11480), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11478), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [497174] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9634), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9636), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [497212] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12404), 1,
      anon_sym_PERCENT,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10141), 1,
      sym_attribute,
    STATE(10787), 1,
      sym__attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15864), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [497278] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8274), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8276), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [497316] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11678), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11676), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [497354] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12404), 1,
      anon_sym_PERCENT,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10144), 1,
      sym_attribute,
    STATE(10714), 1,
      sym__attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15820), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [497420] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11448), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11446), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [497458] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10146), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11444), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11442), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [497496] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7153), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(7149), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [497534] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11440), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11438), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [497572] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11560), 1,
      sym__lowercase_identifier,
    STATE(10149), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11562), 4,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
    ACTIONS(12069), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12071), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [497614] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10393), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12410), 1,
      anon_sym_STAR,
    STATE(10150), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10391), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [497654] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10151), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9638), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9640), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [497692] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12404), 1,
      anon_sym_PERCENT,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10152), 1,
      sym_attribute,
    STATE(10773), 1,
      sym__attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(16224), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [497758] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10153), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9650), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9652), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [497796] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10154), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9642), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9644), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [497834] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9758), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9760), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [497872] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10156), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11694), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11692), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [497910] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10157), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11510), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11508), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [497948] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10158), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8278), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8280), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [497986] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12412), 1,
      aux_sym_attribute_id_token1,
    STATE(10159), 1,
      sym_attribute,
    STATE(10177), 1,
      aux_sym_attribute_id_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9050), 9,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      sym__lowercase_identifier,
    ACTIONS(9052), 12,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [498028] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8268), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [498066] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12075), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12414), 1,
      anon_sym_LPAREN,
    ACTIONS(12416), 1,
      anon_sym_LBRACK,
    STATE(10161), 1,
      sym_attribute,
    STATE(11081), 1,
      sym__constructor_name,
    STATE(11816), 1,
      sym_constructor_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12418), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(12073), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [498116] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11472), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11470), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [498154] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8364), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [498192] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11890), 1,
      anon_sym_constraint,
    ACTIONS(12422), 1,
      anon_sym_let,
    ACTIONS(12424), 1,
      anon_sym_EQ,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10164), 1,
      sym_attribute,
    STATE(10449), 1,
      aux_sym_type_binding_repeat1,
    STATE(10475), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12420), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [498244] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(8364), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [498282] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11872), 1,
      sym__lowercase_identifier,
    ACTIONS(11874), 1,
      anon_sym_POUND,
    STATE(10127), 1,
      sym_type_constructor_path,
    STATE(10166), 1,
      sym_attribute,
    STATE(17343), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11500), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11502), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [498330] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10167), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9598), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9600), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [498368] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11797), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11795), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [498406] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12404), 1,
      anon_sym_PERCENT,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10169), 1,
      sym_attribute,
    STATE(10754), 1,
      sym__attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(16409), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [498472] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11009), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11007), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
  [498510] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11765), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11763), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [498548] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12430), 1,
      anon_sym_DASH_GT,
    ACTIONS(12432), 1,
      anon_sym_as,
    STATE(10172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12428), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12426), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [498590] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12331), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12434), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(10173), 1,
      sym_attribute,
    STATE(10342), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12329), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [498634] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12430), 1,
      anon_sym_DASH_GT,
    ACTIONS(12432), 1,
      anon_sym_as,
    STATE(10174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12438), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12436), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [498676] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12396), 1,
      sym__lowercase_identifier,
    ACTIONS(12398), 1,
      anon_sym_POUND,
    STATE(10175), 1,
      sym_attribute,
    STATE(10926), 1,
      sym_type_constructor_path,
    STATE(17037), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10261), 8,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(10263), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [498724] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9736), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9738), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [498762] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12412), 1,
      aux_sym_attribute_id_token1,
    STATE(10177), 1,
      sym_attribute,
    STATE(10196), 1,
      aux_sym_attribute_id_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8919), 9,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      sym__lowercase_identifier,
    ACTIONS(8921), 12,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [498804] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12404), 1,
      anon_sym_PERCENT,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10178), 1,
      sym_attribute,
    STATE(10865), 1,
      sym__attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15681), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [498870] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8310), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [498908] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11428), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11426), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [498946] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10181), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11552), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11550), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [498984] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11890), 1,
      anon_sym_constraint,
    ACTIONS(12442), 1,
      anon_sym_let,
    ACTIONS(12444), 1,
      anon_sym_EQ,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10182), 1,
      sym_attribute,
    STATE(10397), 1,
      aux_sym_expression_item_repeat1,
    STATE(10521), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12440), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [499036] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10183), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11634), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11632), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [499074] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12274), 1,
      sym__lowercase_identifier,
    ACTIONS(12446), 1,
      anon_sym_POUND,
    STATE(10184), 1,
      sym_attribute,
    STATE(10833), 1,
      sym_type_constructor_path,
    STATE(17441), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11128), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11130), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [499122] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11644), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11642), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [499160] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9258), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9256), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [499198] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12404), 1,
      anon_sym_PERCENT,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10187), 1,
      sym_attribute,
    STATE(10789), 1,
      sym__attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15487), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [499264] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12404), 1,
      anon_sym_PERCENT,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10188), 1,
      sym_attribute,
    STATE(10732), 1,
      sym__attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(16181), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [499330] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11600), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [499368] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11706), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11704), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [499406] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10191), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11416), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11414), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [499444] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12396), 1,
      sym__lowercase_identifier,
    ACTIONS(12398), 1,
      anon_sym_POUND,
    STATE(10192), 1,
      sym_attribute,
    STATE(10926), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17037), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11462), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11464), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [499498] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12404), 1,
      anon_sym_PERCENT,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10193), 1,
      sym_attribute,
    STATE(10940), 1,
      sym__attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15372), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [499564] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10194), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11845), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11562), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11560), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [499604] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12404), 1,
      anon_sym_PERCENT,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10195), 1,
      sym_attribute,
    STATE(10911), 1,
      sym__attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(16215), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [499670] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12448), 1,
      aux_sym_attribute_id_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10196), 2,
      sym_attribute,
      aux_sym_attribute_id_repeat1,
    ACTIONS(8959), 9,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      sym__lowercase_identifier,
    ACTIONS(8961), 12,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [499710] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11628), 1,
      sym__lowercase_identifier,
    ACTIONS(11837), 1,
      anon_sym_POUND,
    STATE(9731), 1,
      sym_type_constructor_path,
    STATE(10197), 1,
      sym_attribute,
    STATE(16902), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12303), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12305), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [499758] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12382), 1,
      anon_sym_RPAREN,
    ACTIONS(12384), 1,
      anon_sym__,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12394), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10198), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15435), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [499824] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12453), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12451), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [499862] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12455), 1,
      anon_sym_else,
    STATE(8259), 1,
      sym_else_clause,
    STATE(10200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [499904] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9158), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [499942] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10202), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9696), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9698), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [499980] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12396), 1,
      sym__lowercase_identifier,
    ACTIONS(12398), 1,
      anon_sym_POUND,
    STATE(10203), 1,
      sym_attribute,
    STATE(10926), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17037), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11454), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11456), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [500034] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10204), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(8360), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [500072] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10205), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(8356), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [500110] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(12442), 1,
      anon_sym_let,
    ACTIONS(12457), 1,
      anon_sym_EQ,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10206), 1,
      sym_attribute,
    STATE(10397), 1,
      aux_sym_expression_item_repeat1,
    STATE(10593), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12440), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [500162] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12248), 1,
      sym__lowercase_identifier,
    ACTIONS(12250), 1,
      anon_sym_POUND,
    ACTIONS(12459), 1,
      anon_sym_STAR,
    STATE(10207), 1,
      sym_attribute,
    STATE(10881), 1,
      sym_type_constructor_path,
    STATE(11847), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17296), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11458), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11896), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [500214] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12274), 1,
      sym__lowercase_identifier,
    ACTIONS(12276), 1,
      anon_sym_POUND,
    ACTIONS(12461), 1,
      anon_sym_STAR,
    STATE(10208), 1,
      sym_attribute,
    STATE(10867), 1,
      sym_type_constructor_path,
    STATE(11869), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17441), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11458), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11896), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [500266] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10209), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9158), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9160), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [500304] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12218), 1,
      sym__lowercase_identifier,
    ACTIONS(12463), 1,
      anon_sym_POUND,
    STATE(10210), 1,
      sym_attribute,
    STATE(10707), 1,
      sym_type_constructor_path,
    STATE(17519), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11128), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11130), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [500352] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9256), 1,
      sym__lowercase_identifier,
    STATE(10211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9258), 4,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
    ACTIONS(11765), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11763), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [500394] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12404), 1,
      anon_sym_PERCENT,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10212), 1,
      sym_attribute,
    STATE(10998), 1,
      sym__attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(16292), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [500460] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11560), 1,
      sym__lowercase_identifier,
    STATE(10213), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11562), 4,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
    ACTIONS(12069), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12071), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [500502] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12404), 1,
      anon_sym_PERCENT,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10214), 1,
      sym_attribute,
    STATE(10897), 1,
      sym__attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15173), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [500568] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10215), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8336), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [500606] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11628), 1,
      sym__lowercase_identifier,
    ACTIONS(11837), 1,
      anon_sym_POUND,
    STATE(9731), 1,
      sym_type_constructor_path,
    STATE(10216), 1,
      sym_attribute,
    STATE(16902), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11720), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11722), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [500654] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9158), 1,
      sym__lowercase_identifier,
    ACTIONS(12465), 1,
      anon_sym_COLON2,
    STATE(10217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 4,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
    ACTIONS(11436), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11434), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [500698] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12404), 1,
      anon_sym_PERCENT,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10218), 1,
      sym_attribute,
    STATE(10806), 1,
      sym__attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(16209), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [500764] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(12471), 1,
      anon_sym_DASH_GT,
    STATE(10219), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12469), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12467), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [500806] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10220), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11765), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11763), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [500844] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12005), 1,
      sym__lowercase_identifier,
    ACTIONS(12007), 1,
      anon_sym_POUND,
    STATE(10221), 1,
      sym_attribute,
    STATE(10644), 1,
      sym_type_constructor_path,
    STATE(17478), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12085), 8,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12087), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [500892] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12404), 1,
      anon_sym_PERCENT,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10222), 1,
      sym_attribute,
    STATE(10725), 1,
      sym__attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(16426), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [500958] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12404), 1,
      anon_sym_PERCENT,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10223), 1,
      sym_attribute,
    STATE(10862), 1,
      sym__attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15842), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [501024] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12473), 1,
      anon_sym_COMMA,
    ACTIONS(12475), 1,
      anon_sym_SEMI,
    ACTIONS(12477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12479), 1,
      sym_pow_operator,
    ACTIONS(12481), 1,
      sym_mult_operator,
    ACTIONS(12483), 1,
      sym_concat_operator,
    ACTIONS(12485), 1,
      sym_rel_operator,
    ACTIONS(12487), 1,
      sym_and_operator,
    ACTIONS(12489), 1,
      sym_or_operator,
    ACTIONS(12491), 1,
      sym_assign_operator,
    STATE(2349), 1,
      sym_add_operator,
    STATE(10224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9116), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9114), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
  [501086] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10225), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11896), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11458), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [501124] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10226), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11845), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11562), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11560), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [501164] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10227), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11007), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
    ACTIONS(11009), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [501202] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12404), 1,
      anon_sym_PERCENT,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10228), 1,
      sym_attribute,
    STATE(10813), 1,
      sym__attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15543), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [501268] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11872), 1,
      sym__lowercase_identifier,
    ACTIONS(11874), 1,
      anon_sym_POUND,
    STATE(10127), 1,
      sym_type_constructor_path,
    STATE(10229), 1,
      sym_attribute,
    STATE(17343), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11720), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11722), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [501316] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8350), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8352), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [501354] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10231), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8292), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [501392] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11847), 1,
      sym__lowercase_identifier,
    ACTIONS(11849), 1,
      anon_sym_POUND,
    STATE(10232), 1,
      sym_attribute,
    STATE(10244), 1,
      sym_type_constructor_path,
    STATE(17325), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11500), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11502), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [501440] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10233), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9158), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [501478] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10234), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12495), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12493), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [501516] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10235), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9766), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9768), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [501554] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8350), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(8352), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [501592] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10237), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9684), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9686), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [501630] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10238), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9680), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9682), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [501668] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12404), 1,
      anon_sym_PERCENT,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10239), 1,
      sym_attribute,
    STATE(10981), 1,
      sym__attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15808), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [501734] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11847), 1,
      sym__lowercase_identifier,
    ACTIONS(11849), 1,
      anon_sym_POUND,
    STATE(10240), 1,
      sym_attribute,
    STATE(10244), 1,
      sym_type_constructor_path,
    STATE(17325), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11720), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11722), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [501782] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10241), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11600), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [501820] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12238), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12434), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(10242), 1,
      sym_attribute,
    STATE(10335), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12236), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [501864] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10243), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9672), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9674), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [501902] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10244), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11640), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11638), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [501940] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12473), 1,
      anon_sym_COMMA,
    ACTIONS(12477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12479), 1,
      sym_pow_operator,
    ACTIONS(12481), 1,
      sym_mult_operator,
    ACTIONS(12483), 1,
      sym_concat_operator,
    ACTIONS(12485), 1,
      sym_rel_operator,
    ACTIONS(12487), 1,
      sym_and_operator,
    ACTIONS(12489), 1,
      sym_or_operator,
    ACTIONS(12491), 1,
      sym_assign_operator,
    STATE(2349), 1,
      sym_add_operator,
    STATE(10245), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10332), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10330), 7,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
  [502000] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10246), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9668), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9670), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [502038] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10247), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11536), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11534), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [502076] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9664), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9666), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [502114] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11847), 1,
      sym__lowercase_identifier,
    ACTIONS(11849), 1,
      anon_sym_POUND,
    STATE(10244), 1,
      sym_type_constructor_path,
    STATE(10249), 1,
      sym_attribute,
    STATE(17325), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11588), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11590), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [502162] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10250), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9108), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9110), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [502200] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10251), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8340), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [502238] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12404), 1,
      anon_sym_PERCENT,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10252), 1,
      sym_attribute,
    STATE(10823), 1,
      sym__attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(16284), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [502304] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10253), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11436), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11434), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [502342] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10254), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9618), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9620), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [502380] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10255), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12499), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12497), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [502418] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10256), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11007), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
    ACTIONS(11009), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [502456] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8322), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [502494] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10258), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9692), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9694), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [502532] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10259), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11476), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11474), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [502570] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10260), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11578), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11576), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [502608] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9688), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9690), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [502646] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12501), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10262), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 12,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [502686] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12504), 1,
      anon_sym_PIPE,
    STATE(10262), 1,
      aux_sym__match_cases_repeat1,
    STATE(10263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 12,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [502728] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12504), 1,
      anon_sym_PIPE,
    STATE(10262), 1,
      aux_sym__match_cases_repeat1,
    STATE(10264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 12,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [502770] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12404), 1,
      anon_sym_PERCENT,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10265), 1,
      sym_attribute,
    STATE(10728), 1,
      sym__attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(16282), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [502836] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10266), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9700), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9702), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [502874] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9718), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9720), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [502912] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10268), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11845), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11562), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11560), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [502952] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10269), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9706), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9708), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [502990] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11872), 1,
      sym__lowercase_identifier,
    ACTIONS(11874), 1,
      anon_sym_POUND,
    STATE(10127), 1,
      sym_type_constructor_path,
    STATE(10270), 1,
      sym_attribute,
    STATE(17343), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11588), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11590), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [503038] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12479), 1,
      sym_pow_operator,
    ACTIONS(12481), 1,
      sym_mult_operator,
    ACTIONS(12483), 1,
      sym_concat_operator,
    ACTIONS(12485), 1,
      sym_rel_operator,
    ACTIONS(12487), 1,
      sym_and_operator,
    ACTIONS(12489), 1,
      sym_or_operator,
    STATE(2349), 1,
      sym_add_operator,
    STATE(10271), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10344), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10342), 9,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [503094] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12479), 1,
      sym_pow_operator,
    ACTIONS(12481), 1,
      sym_mult_operator,
    STATE(2349), 1,
      sym_add_operator,
    STATE(10272), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 6,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 10,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [503142] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12479), 1,
      sym_pow_operator,
    STATE(2349), 1,
      sym_add_operator,
    STATE(10273), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [503184] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11562), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11560), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [503222] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12479), 1,
      sym_pow_operator,
    STATE(2349), 1,
      sym_add_operator,
    STATE(10275), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [503264] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12479), 1,
      sym_pow_operator,
    ACTIONS(12481), 1,
      sym_mult_operator,
    ACTIONS(12483), 1,
      sym_concat_operator,
    STATE(2349), 1,
      sym_add_operator,
    STATE(10276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 6,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 9,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [503314] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12506), 1,
      aux_sym_attribute_id_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10277), 2,
      sym_attribute,
      aux_sym_attribute_id_repeat1,
    ACTIONS(8959), 8,
      anon_sym_rec,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_lazy,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8961), 13,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [503354] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9676), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9678), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [503392] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11628), 1,
      sym__lowercase_identifier,
    ACTIONS(11837), 1,
      anon_sym_POUND,
    STATE(9731), 1,
      sym_type_constructor_path,
    STATE(10279), 1,
      sym_attribute,
    STATE(16902), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12278), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12280), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [503440] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10280), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8360), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [503478] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12479), 1,
      sym_pow_operator,
    ACTIONS(12481), 1,
      sym_mult_operator,
    ACTIONS(12483), 1,
      sym_concat_operator,
    STATE(2349), 1,
      sym_add_operator,
    STATE(10281), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 6,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 9,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [503528] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8356), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [503566] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10283), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9660), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9662), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [503604] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10284), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9656), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9658), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [503642] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10285), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9258), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9256), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [503680] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11562), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11560), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [503718] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9206), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9208), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [503756] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12430), 1,
      anon_sym_DASH_GT,
    STATE(10288), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12511), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12509), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [503796] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11416), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11414), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [503834] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10290), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8264), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [503872] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8318), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [503910] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(2349), 1,
      sym_add_operator,
    STATE(10292), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 12,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [503950] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11706), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11704), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [503988] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12408), 1,
      anon_sym_else,
    STATE(8278), 1,
      sym_else_clause,
    STATE(10294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [504030] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12471), 1,
      anon_sym_DASH_GT,
    STATE(10295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12511), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12509), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [504070] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10296), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11476), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11474), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [504108] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12396), 1,
      sym__lowercase_identifier,
    ACTIONS(12398), 1,
      anon_sym_POUND,
    STATE(10297), 1,
      sym_attribute,
    STATE(10926), 1,
      sym_type_constructor_path,
    STATE(17037), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11124), 8,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11126), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [504156] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12075), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12513), 1,
      anon_sym_LPAREN,
    ACTIONS(12515), 1,
      anon_sym_LBRACK,
    STATE(10298), 1,
      sym_attribute,
    STATE(11003), 1,
      sym__constructor_name,
    STATE(11793), 1,
      sym_constructor_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12517), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(12073), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [504206] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(12471), 1,
      anon_sym_DASH_GT,
    STATE(10299), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12428), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12426), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [504248] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12479), 1,
      sym_pow_operator,
    ACTIONS(12481), 1,
      sym_mult_operator,
    ACTIONS(12483), 1,
      sym_concat_operator,
    ACTIONS(12485), 1,
      sym_rel_operator,
    ACTIONS(12487), 1,
      sym_and_operator,
    STATE(2349), 1,
      sym_add_operator,
    STATE(10300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 4,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_or_operator,
    ACTIONS(10269), 9,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [504302] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12479), 1,
      sym_pow_operator,
    ACTIONS(12481), 1,
      sym_mult_operator,
    ACTIONS(12483), 1,
      sym_concat_operator,
    ACTIONS(12485), 1,
      sym_rel_operator,
    ACTIONS(12487), 1,
      sym_and_operator,
    ACTIONS(12489), 1,
      sym_or_operator,
    STATE(2349), 1,
      sym_add_operator,
    STATE(10301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 9,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [504358] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11845), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11562), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11560), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [504398] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11496), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11494), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [504436] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10304), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11480), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11478), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [504474] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12248), 1,
      sym__lowercase_identifier,
    ACTIONS(12519), 1,
      anon_sym_POUND,
    STATE(10305), 1,
      sym_attribute,
    STATE(10934), 1,
      sym_type_constructor_path,
    STATE(17296), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11128), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11130), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [504522] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10306), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9174), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9176), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [504560] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10307), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11009), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(11007), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
  [504598] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10308), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9714), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9716), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [504636] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11949), 1,
      sym__lowercase_identifier,
    ACTIONS(12057), 1,
      anon_sym_POUND,
    STATE(10027), 1,
      sym_type_constructor_path,
    STATE(10309), 1,
      sym_attribute,
    STATE(17413), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12085), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12087), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [504684] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12473), 1,
      anon_sym_COMMA,
    ACTIONS(12477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12479), 1,
      sym_pow_operator,
    ACTIONS(12481), 1,
      sym_mult_operator,
    ACTIONS(12483), 1,
      sym_concat_operator,
    ACTIONS(12485), 1,
      sym_rel_operator,
    ACTIONS(12487), 1,
      sym_and_operator,
    ACTIONS(12489), 1,
      sym_or_operator,
    ACTIONS(12491), 1,
      sym_assign_operator,
    STATE(2349), 1,
      sym_add_operator,
    STATE(10310), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 7,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
  [504744] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11847), 1,
      sym__lowercase_identifier,
    ACTIONS(11849), 1,
      anon_sym_POUND,
    STATE(10244), 1,
      sym_type_constructor_path,
    STATE(10311), 1,
      sym_attribute,
    STATE(17325), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12242), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12244), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [504792] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10312), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9102), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9104), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [504830] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11847), 1,
      sym__lowercase_identifier,
    ACTIONS(11849), 1,
      anon_sym_POUND,
    STATE(10244), 1,
      sym_type_constructor_path,
    STATE(10313), 1,
      sym_attribute,
    STATE(17325), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12303), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12305), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [504878] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12479), 1,
      sym_pow_operator,
    ACTIONS(12481), 1,
      sym_mult_operator,
    STATE(2349), 1,
      sym_add_operator,
    STATE(10314), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 9,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [504922] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12473), 1,
      anon_sym_COMMA,
    ACTIONS(12477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12479), 1,
      sym_pow_operator,
    ACTIONS(12481), 1,
      sym_mult_operator,
    ACTIONS(12483), 1,
      sym_concat_operator,
    ACTIONS(12485), 1,
      sym_rel_operator,
    ACTIONS(12487), 1,
      sym_and_operator,
    ACTIONS(12489), 1,
      sym_or_operator,
    ACTIONS(12491), 1,
      sym_assign_operator,
    STATE(2349), 1,
      sym_add_operator,
    STATE(10315), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10303), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10301), 7,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
  [504982] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12396), 1,
      sym__lowercase_identifier,
    ACTIONS(12398), 1,
      anon_sym_POUND,
    STATE(10316), 1,
      sym_attribute,
    STATE(10926), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17037), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11500), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11502), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [505036] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12521), 1,
      aux_sym_attribute_id_token1,
    STATE(10277), 1,
      aux_sym_attribute_id_repeat1,
    STATE(10317), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8919), 8,
      anon_sym_rec,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_lazy,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8921), 13,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [505078] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12521), 1,
      aux_sym_attribute_id_token1,
    STATE(10317), 1,
      aux_sym_attribute_id_repeat1,
    STATE(10318), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9050), 8,
      anon_sym_rec,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_lazy,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9052), 13,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [505120] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10319), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11678), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11676), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [505158] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(12422), 1,
      anon_sym_let,
    ACTIONS(12523), 1,
      anon_sym_EQ,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10320), 1,
      sym_attribute,
    STATE(10475), 1,
      aux_sym_expression_item_repeat1,
    STATE(10664), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12420), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [505210] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10321), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11448), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11446), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [505248] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12396), 1,
      sym__lowercase_identifier,
    ACTIONS(12398), 1,
      anon_sym_POUND,
    STATE(10322), 1,
      sym_attribute,
    STATE(10926), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17037), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11588), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11590), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [505302] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11847), 1,
      sym__lowercase_identifier,
    ACTIONS(11849), 1,
      anon_sym_POUND,
    STATE(10244), 1,
      sym_type_constructor_path,
    STATE(10323), 1,
      sym_attribute,
    STATE(17325), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12278), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12280), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [505350] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11628), 1,
      sym__lowercase_identifier,
    ACTIONS(11837), 1,
      anon_sym_POUND,
    STATE(9731), 1,
      sym_type_constructor_path,
    STATE(10324), 1,
      sym_attribute,
    STATE(16902), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12242), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12244), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [505398] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11444), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11442), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [505436] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11440), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11438), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [505474] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10327), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11694), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11692), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [505512] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11510), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11508), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [505550] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11472), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11470), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [505588] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10330), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11797), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11795), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [505626] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12504), 1,
      anon_sym_PIPE,
    STATE(10263), 1,
      aux_sym__match_cases_repeat1,
    STATE(10331), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 12,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [505668] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11540), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11538), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [505706] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12455), 1,
      anon_sym_else,
    STATE(8278), 1,
      sym_else_clause,
    STATE(10333), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [505748] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12473), 1,
      anon_sym_COMMA,
    ACTIONS(12477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12479), 1,
      sym_pow_operator,
    ACTIONS(12481), 1,
      sym_mult_operator,
    ACTIONS(12483), 1,
      sym_concat_operator,
    ACTIONS(12485), 1,
      sym_rel_operator,
    ACTIONS(12487), 1,
      sym_and_operator,
    ACTIONS(12489), 1,
      sym_or_operator,
    ACTIONS(12491), 1,
      sym_assign_operator,
    STATE(2349), 1,
      sym_add_operator,
    STATE(10334), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10340), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10338), 7,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
  [505808] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12317), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12434), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(10335), 1,
      sym_attribute,
    STATE(10342), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12315), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [505852] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12317), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12434), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(10173), 1,
      aux_sym_type_binding_repeat1,
    STATE(10336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12315), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [505896] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12404), 1,
      anon_sym_PERCENT,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10337), 1,
      sym_attribute,
    STATE(10859), 1,
      sym__attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(16043), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [505962] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12504), 1,
      anon_sym_PIPE,
    STATE(10264), 1,
      aux_sym__match_cases_repeat1,
    STATE(10338), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 12,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [506004] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(12471), 1,
      anon_sym_DASH_GT,
    STATE(10339), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12438), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12436), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [506046] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10340), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9228), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9230), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [506084] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10341), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11428), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11426), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [506122] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12284), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12525), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10342), 2,
      sym_attribute,
      aux_sym_type_binding_repeat1,
    ACTIONS(12282), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [506164] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10343), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11552), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11550), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [506202] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12396), 1,
      sym__lowercase_identifier,
    ACTIONS(12528), 1,
      anon_sym_POUND,
    STATE(10344), 1,
      sym_attribute,
    STATE(10802), 1,
      sym_type_constructor_path,
    STATE(17037), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11128), 8,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11130), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [506250] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12430), 1,
      anon_sym_DASH_GT,
    ACTIONS(12432), 1,
      anon_sym_as,
    STATE(10345), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12469), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12467), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [506292] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12218), 1,
      sym__lowercase_identifier,
    ACTIONS(12220), 1,
      anon_sym_POUND,
    ACTIONS(12530), 1,
      anon_sym_STAR,
    STATE(10346), 1,
      sym_attribute,
    STATE(10903), 1,
      sym_type_constructor_path,
    STATE(11825), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17519), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11458), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11896), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [506344] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12396), 1,
      sym__lowercase_identifier,
    ACTIONS(12398), 1,
      anon_sym_POUND,
    STATE(10347), 1,
      sym_attribute,
    STATE(10926), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17037), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11720), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11722), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [506398] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12404), 1,
      anon_sym_PERCENT,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(12532), 1,
      anon_sym_DASH_GT,
    ACTIONS(12534), 1,
      anon_sym_functor,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10348), 1,
      sym_attribute,
    STATE(10808), 1,
      sym__attribute,
    STATE(11756), 1,
      sym__module_type,
    STATE(14827), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [506464] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9140), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9142), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [506502] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10350), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11634), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11632), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [506540] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11644), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11642), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [506578] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12404), 1,
      anon_sym_PERCENT,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10352), 1,
      sym_attribute,
    STATE(10860), 1,
      sym__attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15476), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [506644] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10353), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11598), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11596), 20,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [506681] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10354), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10192), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10190), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [506718] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12005), 1,
      sym__lowercase_identifier,
    ACTIONS(12007), 1,
      anon_sym_POUND,
    STATE(10355), 1,
      sym_attribute,
    STATE(10644), 1,
      sym_type_constructor_path,
    STATE(17478), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12303), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12305), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [506765] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12005), 1,
      sym__lowercase_identifier,
    ACTIONS(12007), 1,
      anon_sym_POUND,
    STATE(10356), 1,
      sym_attribute,
    STATE(10644), 1,
      sym_type_constructor_path,
    STATE(17478), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12278), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12280), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [506812] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12005), 1,
      sym__lowercase_identifier,
    ACTIONS(12007), 1,
      anon_sym_POUND,
    STATE(10357), 1,
      sym_attribute,
    STATE(10644), 1,
      sym_type_constructor_path,
    STATE(17478), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12242), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12244), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [506859] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8060), 2,
      anon_sym_let,
      anon_sym_COLON2,
    ACTIONS(8062), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [506896] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12538), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10359), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12536), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [506939] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10360), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10202), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10200), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [506976] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7996), 2,
      anon_sym_let,
      anon_sym_COLON2,
    ACTIONS(7998), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [507013] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12544), 1,
      anon_sym_and,
    STATE(10362), 1,
      sym_attribute,
    STATE(10453), 1,
      aux_sym_module_type_constraint_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12542), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12540), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [507054] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12546), 1,
      anon_sym_LPAREN,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12552), 1,
      anon_sym_end,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    STATE(10363), 1,
      sym_attribute,
    STATE(11090), 1,
      sym__attribute,
    STATE(11681), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [507117] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12562), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(11071), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10364), 2,
      sym_attribute,
      aux_sym_expression_item_repeat1,
    ACTIONS(11942), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(11940), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [507158] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5501), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10365), 1,
      sym_attribute,
    STATE(10380), 1,
      aux_sym_expression_item_repeat1,
    STATE(11071), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12567), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(12565), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [507201] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12569), 1,
      anon_sym_PIPE,
    STATE(10366), 1,
      sym_attribute,
    STATE(10446), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [507242] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10367), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8959), 8,
      anon_sym_rec,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_lazy,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8961), 14,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
      aux_sym_attribute_id_token1,
  [507279] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9158), 1,
      sym__lowercase_identifier,
    ACTIONS(12571), 1,
      anon_sym_COLON2,
    STATE(10368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 4,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
    ACTIONS(11436), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11434), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [507322] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9598), 2,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9600), 20,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [507359] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(12573), 1,
      anon_sym_LPAREN,
    ACTIONS(12575), 1,
      anon_sym_end,
    STATE(10370), 1,
      sym_attribute,
    STATE(11078), 1,
      sym__attribute,
    STATE(11221), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [507422] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10186), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10184), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [507459] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12579), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10372), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12577), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [507502] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12583), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12581), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [507545] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(12585), 1,
      anon_sym_LPAREN,
    ACTIONS(12587), 1,
      anon_sym_end,
    STATE(10374), 1,
      sym_attribute,
    STATE(11067), 1,
      sym__attribute,
    STATE(11238), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [507608] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12591), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10373), 1,
      aux_sym_expression_item_repeat1,
    STATE(10375), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12589), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [507651] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12595), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12593), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [507694] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12599), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12597), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [507737] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12428), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(12601), 1,
      anon_sym_DASH_GT,
    STATE(10378), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12426), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [507778] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(1970), 1,
      sym_add_operator,
    STATE(10379), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [507817] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5501), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10364), 1,
      aux_sym_expression_item_repeat1,
    STATE(10380), 1,
      sym_attribute,
    STATE(11071), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12605), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(12603), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [507860] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8959), 9,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      sym__lowercase_identifier,
    ACTIONS(8961), 13,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
      aux_sym_attribute_id_token1,
  [507897] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12609), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12607), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [507940] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12613), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10376), 1,
      aux_sym_expression_item_repeat1,
    STATE(10383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12611), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [507983] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12617), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12615), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [508026] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(12619), 1,
      anon_sym_LPAREN,
    ACTIONS(12621), 1,
      anon_sym_end,
    STATE(10385), 1,
      sym_attribute,
    STATE(11103), 1,
      sym__attribute,
    STATE(11409), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [508089] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12625), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10377), 1,
      aux_sym_expression_item_repeat1,
    STATE(10386), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12623), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [508132] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12629), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10387), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12627), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [508175] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(12631), 1,
      anon_sym_LPAREN,
    ACTIONS(12633), 1,
      anon_sym_end,
    STATE(10388), 1,
      sym_attribute,
    STATE(11086), 1,
      sym__attribute,
    STATE(11315), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [508238] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11949), 1,
      sym__lowercase_identifier,
    ACTIONS(12057), 1,
      anon_sym_POUND,
    STATE(10027), 1,
      sym_type_constructor_path,
    STATE(10389), 1,
      sym_attribute,
    STATE(17413), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11588), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11590), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [508285] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12637), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12635), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [508328] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12641), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10372), 1,
      aux_sym_expression_item_repeat1,
    STATE(10391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12639), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [508371] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12645), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10392), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12643), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [508414] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11918), 1,
      anon_sym_COLON2,
    STATE(10393), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9158), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [508453] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12651), 1,
      anon_sym_and,
    STATE(10394), 1,
      sym_attribute,
    STATE(10625), 1,
      aux_sym_module_type_constraint_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12649), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12647), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [508494] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12291), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12289), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [508537] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12655), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12653), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [508580] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12659), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10397), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12657), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [508623] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12159), 1,
      anon_sym_constraint,
    ACTIONS(12661), 1,
      anon_sym_EQ,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10398), 1,
      sym_attribute,
    STATE(10475), 1,
      aux_sym_expression_item_repeat1,
    STATE(10930), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12420), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [508672] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5501), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10364), 1,
      aux_sym_expression_item_repeat1,
    STATE(10399), 1,
      sym_attribute,
    STATE(11071), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12665), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(12663), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [508715] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10400), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12669), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12667), 20,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [508752] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12671), 1,
      anon_sym_STAR,
    STATE(10401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10393), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10391), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [508791] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(12673), 1,
      anon_sym_LPAREN,
    ACTIONS(12675), 1,
      anon_sym_end,
    STATE(10402), 1,
      sym_attribute,
    STATE(11119), 1,
      sym__attribute,
    STATE(11654), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [508854] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11890), 1,
      anon_sym_constraint,
    ACTIONS(12422), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10403), 1,
      sym_attribute,
    STATE(10475), 1,
      aux_sym_expression_item_repeat1,
    STATE(11041), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12420), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [508903] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(12677), 1,
      anon_sym_LPAREN,
    ACTIONS(12679), 1,
      anon_sym_end,
    STATE(10404), 1,
      sym_attribute,
    STATE(11054), 1,
      sym__attribute,
    STATE(11279), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [508966] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12683), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10405), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12681), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [509009] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12687), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10384), 1,
      aux_sym_expression_item_repeat1,
    STATE(10406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12685), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [509052] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12693), 1,
      anon_sym_EQ,
    ACTIONS(12695), 1,
      anon_sym_of,
    ACTIONS(12697), 1,
      anon_sym_COLON2,
    STATE(10407), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12691), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12689), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [509095] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12703), 1,
      anon_sym_EQ,
    ACTIONS(12705), 1,
      anon_sym_of,
    ACTIONS(12707), 1,
      anon_sym_COLON2,
    STATE(10408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12701), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12699), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [509138] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12711), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10409), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12709), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [509181] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12715), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10410), 1,
      sym_attribute,
    STATE(10701), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12713), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [509224] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12721), 1,
      anon_sym_EQ,
    ACTIONS(12723), 1,
      anon_sym_of,
    ACTIONS(12725), 1,
      anon_sym_COLON2,
    STATE(10411), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12719), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12717), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [509267] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(12438), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12601), 1,
      anon_sym_DASH_GT,
    STATE(10412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12436), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [509308] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12729), 1,
      anon_sym_let,
    STATE(10413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12727), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [509345] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12733), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10387), 1,
      aux_sym_expression_item_repeat1,
    STATE(10414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12731), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [509388] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12737), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10415), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12735), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [509431] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12741), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10390), 1,
      aux_sym_expression_item_repeat1,
    STATE(10416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12739), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [509474] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12745), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10417), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12743), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [509517] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11949), 1,
      sym__lowercase_identifier,
    ACTIONS(12057), 1,
      anon_sym_POUND,
    STATE(10027), 1,
      sym_type_constructor_path,
    STATE(10418), 1,
      sym_attribute,
    STATE(17413), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11500), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11502), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [509564] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12749), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10392), 1,
      aux_sym_expression_item_repeat1,
    STATE(10419), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12747), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [509607] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12753), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10420), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12751), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [509650] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12005), 1,
      sym__lowercase_identifier,
    ACTIONS(12007), 1,
      anon_sym_POUND,
    STATE(10421), 1,
      sym_attribute,
    STATE(10644), 1,
      sym_type_constructor_path,
    STATE(17478), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11720), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11722), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [509697] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12757), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10422), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12755), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [509740] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12761), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10423), 1,
      sym_attribute,
    STATE(10699), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12759), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [509783] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12765), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10424), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12763), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [509826] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5501), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10399), 1,
      aux_sym_expression_item_repeat1,
    STATE(10425), 1,
      sym_attribute,
    STATE(11071), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12769), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(12767), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [509869] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5501), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10364), 1,
      aux_sym_expression_item_repeat1,
    STATE(10426), 1,
      sym_attribute,
    STATE(11071), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12773), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(12771), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [509912] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12777), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12775), 20,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [509949] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(12779), 1,
      anon_sym_LPAREN,
    ACTIONS(12781), 1,
      anon_sym_end,
    STATE(10428), 1,
      sym_attribute,
    STATE(11046), 1,
      sym__attribute,
    STATE(11311), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [510012] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11890), 1,
      anon_sym_constraint,
    ACTIONS(12785), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10359), 1,
      aux_sym_expression_item_repeat1,
    STATE(10429), 1,
      sym_attribute,
    STATE(10518), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12783), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [510061] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12787), 1,
      anon_sym_else,
    STATE(7952), 1,
      sym_else_clause,
    STATE(10430), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [510102] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10393), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12789), 1,
      anon_sym_STAR,
    STATE(10431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10391), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [510141] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12793), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12791), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [510184] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7135), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10433), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7133), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [510227] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12797), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12795), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [510270] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12801), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10415), 1,
      aux_sym_expression_item_repeat1,
    STATE(10435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12799), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [510313] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12805), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12803), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [510356] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11949), 1,
      sym__lowercase_identifier,
    ACTIONS(12057), 1,
      anon_sym_POUND,
    STATE(10027), 1,
      sym_type_constructor_path,
    STATE(10437), 1,
      sym_attribute,
    STATE(17413), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11720), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11722), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [510403] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(12469), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12601), 1,
      anon_sym_DASH_GT,
    STATE(10438), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12467), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [510444] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12809), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10417), 1,
      aux_sym_expression_item_repeat1,
    STATE(10439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12807), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [510487] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12075), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12811), 1,
      anon_sym_LPAREN,
    ACTIONS(12813), 1,
      anon_sym_LBRACK,
    STATE(10440), 1,
      sym_attribute,
    STATE(11639), 1,
      sym__constructor_name,
    STATE(11983), 1,
      sym_constructor_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12815), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(12073), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [510536] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10441), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11763), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11765), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [510573] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12569), 1,
      anon_sym_PIPE,
    STATE(10442), 1,
      sym_attribute,
    STATE(10573), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [510614] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12819), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10443), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12817), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [510657] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12823), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10420), 1,
      aux_sym_expression_item_repeat1,
    STATE(10444), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12821), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [510700] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(12825), 1,
      anon_sym_LPAREN,
    ACTIONS(12827), 1,
      anon_sym_end,
    STATE(10445), 1,
      sym_attribute,
    STATE(11051), 1,
      sym__attribute,
    STATE(11713), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [510763] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12569), 1,
      anon_sym_PIPE,
    STATE(10446), 1,
      sym_attribute,
    STATE(10545), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [510804] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(12829), 1,
      anon_sym_LPAREN,
    ACTIONS(12831), 1,
      anon_sym_end,
    STATE(10447), 1,
      sym_attribute,
    STATE(11085), 1,
      sym__attribute,
    STATE(11435), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [510867] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(12833), 1,
      anon_sym_LPAREN,
    ACTIONS(12835), 1,
      anon_sym_end,
    STATE(10448), 1,
      sym_attribute,
    STATE(11121), 1,
      sym__attribute,
    STATE(11532), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [510930] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11890), 1,
      anon_sym_constraint,
    ACTIONS(12839), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10396), 1,
      aux_sym_expression_item_repeat1,
    STATE(10449), 1,
      sym_attribute,
    STATE(11041), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12837), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [510979] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(12841), 1,
      anon_sym_LPAREN,
    ACTIONS(12843), 1,
      anon_sym_end,
    STATE(10450), 1,
      sym_attribute,
    STATE(11021), 1,
      sym__attribute,
    STATE(11694), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [511042] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5501), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10364), 1,
      aux_sym_expression_item_repeat1,
    STATE(10451), 1,
      sym_attribute,
    STATE(11071), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12847), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(12845), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [511085] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11949), 1,
      sym__lowercase_identifier,
    ACTIONS(12057), 1,
      anon_sym_POUND,
    STATE(10027), 1,
      sym_type_constructor_path,
    STATE(10452), 1,
      sym_attribute,
    STATE(17413), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12278), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12280), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [511132] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12849), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11938), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(10453), 2,
      sym_attribute,
      aux_sym_module_type_constraint_repeat1,
    ACTIONS(11936), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [511171] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11949), 1,
      sym__lowercase_identifier,
    ACTIONS(12057), 1,
      anon_sym_POUND,
    STATE(10027), 1,
      sym_type_constructor_path,
    STATE(10454), 1,
      sym_attribute,
    STATE(17413), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12303), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12305), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [511218] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11890), 1,
      anon_sym_constraint,
    ACTIONS(12442), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10397), 1,
      aux_sym_expression_item_repeat1,
    STATE(10455), 1,
      sym_attribute,
    STATE(11041), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12440), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [511267] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10456), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10176), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10174), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [511304] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(12852), 1,
      anon_sym_LPAREN,
    ACTIONS(12854), 1,
      anon_sym_end,
    STATE(10457), 1,
      sym_attribute,
    STATE(11016), 1,
      sym__attribute,
    STATE(11503), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [511367] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [511404] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10172), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10170), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [511441] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10460), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10168), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10166), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [511478] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12511), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12601), 1,
      anon_sym_DASH_GT,
    STATE(10461), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12509), 20,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [511517] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10462), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8350), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [511554] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12858), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12856), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [511597] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11949), 1,
      sym__lowercase_identifier,
    ACTIONS(12057), 1,
      anon_sym_POUND,
    STATE(10027), 1,
      sym_type_constructor_path,
    STATE(10464), 1,
      sym_attribute,
    STATE(17413), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12242), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12244), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [511644] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12862), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10465), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12860), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [511687] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12866), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10466), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12864), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [511730] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(12868), 1,
      anon_sym_LPAREN,
    ACTIONS(12870), 1,
      anon_sym_end,
    STATE(10467), 1,
      sym_attribute,
    STATE(11105), 1,
      sym__attribute,
    STATE(11412), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [511793] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8354), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [511830] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8358), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [511867] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10162), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10160), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [511904] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8362), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [511941] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12874), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12872), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [511984] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10473), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11464), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11462), 20,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [512021] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10156), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10154), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [512058] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12839), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10475), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12837), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [512101] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12442), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10476), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12440), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [512144] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11007), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
    ACTIONS(11009), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [512181] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12878), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12876), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [512224] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12880), 1,
      sym__lowercase_identifier,
    ACTIONS(12882), 1,
      anon_sym_POUND,
    STATE(10479), 1,
      sym_attribute,
    STATE(11040), 1,
      sym_type_constructor_path,
    STATE(17395), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11124), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11126), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [512271] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(12884), 1,
      anon_sym_LPAREN,
    ACTIONS(12886), 1,
      anon_sym_end,
    STATE(10480), 1,
      sym_attribute,
    STATE(11050), 1,
      sym__attribute,
    STATE(11690), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [512334] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(12888), 1,
      anon_sym_LPAREN,
    ACTIONS(12890), 1,
      anon_sym_end,
    STATE(10481), 1,
      sym_attribute,
    STATE(11048), 1,
      sym__attribute,
    STATE(11535), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [512397] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(2001), 1,
      sym_add_operator,
    STATE(10482), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 12,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [512436] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12892), 1,
      anon_sym_else,
    STATE(7952), 1,
      sym_else_clause,
    STATE(10483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [512477] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(12894), 1,
      anon_sym_LPAREN,
    ACTIONS(12896), 1,
      anon_sym_end,
    STATE(10484), 1,
      sym_attribute,
    STATE(11007), 1,
      sym__attribute,
    STATE(11329), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [512540] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12900), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10485), 1,
      sym_attribute,
    STATE(10662), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12898), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [512583] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12422), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10486), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12420), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [512626] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(12902), 1,
      anon_sym_LPAREN,
    ACTIONS(12904), 1,
      anon_sym_end,
    STATE(10487), 1,
      sym_attribute,
    STATE(11035), 1,
      sym__attribute,
    STATE(11318), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [512689] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10488), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9968), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9966), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [512726] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12396), 1,
      sym__lowercase_identifier,
    ACTIONS(12398), 1,
      anon_sym_POUND,
    ACTIONS(12906), 1,
      anon_sym_STAR,
    STATE(10489), 1,
      sym_attribute,
    STATE(10926), 1,
      sym_type_constructor_path,
    STATE(12122), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17037), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11458), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11896), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [512777] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12910), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10490), 1,
      sym_attribute,
    STATE(10661), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12908), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [512820] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12912), 1,
      anon_sym_COMMA,
    ACTIONS(12914), 1,
      anon_sym_SEMI,
    ACTIONS(12916), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12918), 1,
      sym_pow_operator,
    ACTIONS(12920), 1,
      sym_mult_operator,
    ACTIONS(12922), 1,
      sym_concat_operator,
    ACTIONS(12924), 1,
      sym_rel_operator,
    ACTIONS(12926), 1,
      sym_and_operator,
    ACTIONS(12928), 1,
      sym_or_operator,
    ACTIONS(12930), 1,
      sym_assign_operator,
    STATE(2001), 1,
      sym_add_operator,
    STATE(10491), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9116), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9114), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
  [512881] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10492), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9158), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(9160), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [512918] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10114), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10112), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [512955] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(12932), 1,
      anon_sym_LPAREN,
    ACTIONS(12934), 1,
      anon_sym_end,
    STATE(10494), 1,
      sym_attribute,
    STATE(11014), 1,
      sym__attribute,
    STATE(11679), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [513018] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12938), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10495), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12936), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [513061] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10496), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11456), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11454), 20,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [513098] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12942), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10497), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12940), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [513141] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12544), 1,
      anon_sym_and,
    STATE(10362), 1,
      aux_sym_module_type_constraint_repeat1,
    STATE(10498), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12649), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12647), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [513182] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12946), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10499), 1,
      sym_attribute,
    STATE(10634), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12944), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [513225] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5501), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10426), 1,
      aux_sym_expression_item_repeat1,
    STATE(10500), 1,
      sym_attribute,
    STATE(11071), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12950), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(12948), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [513268] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12954), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10443), 1,
      aux_sym_expression_item_repeat1,
    STATE(10501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12952), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [513311] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12958), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12956), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [513354] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(12960), 1,
      anon_sym_LPAREN,
    ACTIONS(12962), 1,
      anon_sym_end,
    STATE(10503), 1,
      sym_attribute,
    STATE(11148), 1,
      sym__attribute,
    STATE(11446), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [513417] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(12964), 1,
      anon_sym_LPAREN,
    ACTIONS(12966), 1,
      anon_sym_end,
    STATE(10504), 1,
      sym_attribute,
    STATE(11012), 1,
      sym__attribute,
    STATE(11651), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [513480] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12248), 1,
      sym__lowercase_identifier,
    ACTIONS(12250), 1,
      anon_sym_POUND,
    STATE(10505), 1,
      sym_attribute,
    STATE(10881), 1,
      sym_type_constructor_path,
    STATE(17296), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12085), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12087), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [513527] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12970), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10424), 1,
      aux_sym_expression_item_repeat1,
    STATE(10506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12968), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [513570] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12974), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10507), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12972), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [513613] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12976), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12978), 1,
      sym_pow_operator,
    ACTIONS(12980), 1,
      sym_mult_operator,
    ACTIONS(12982), 1,
      sym_concat_operator,
    ACTIONS(12984), 1,
      sym_rel_operator,
    ACTIONS(12986), 1,
      sym_and_operator,
    STATE(1970), 1,
      sym_add_operator,
    STATE(10508), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 4,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [513666] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(12988), 1,
      anon_sym_LPAREN,
    ACTIONS(12990), 1,
      anon_sym_end,
    STATE(10509), 1,
      sym_attribute,
    STATE(11065), 1,
      sym__attribute,
    STATE(11381), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [513729] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10510), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(3053), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(3051), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [513766] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12159), 1,
      anon_sym_constraint,
    ACTIONS(12992), 1,
      anon_sym_EQ,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10397), 1,
      aux_sym_expression_item_repeat1,
    STATE(10511), 1,
      sym_attribute,
    STATE(10896), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12440), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [513815] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12976), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12978), 1,
      sym_pow_operator,
    ACTIONS(12980), 1,
      sym_mult_operator,
    ACTIONS(12982), 1,
      sym_concat_operator,
    ACTIONS(12984), 1,
      sym_rel_operator,
    ACTIONS(12986), 1,
      sym_and_operator,
    ACTIONS(12994), 1,
      anon_sym_COMMA,
    ACTIONS(12996), 1,
      sym_or_operator,
    ACTIONS(12998), 1,
      sym_assign_operator,
    STATE(1970), 1,
      sym_add_operator,
    STATE(10512), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10340), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10338), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
  [513874] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(13000), 1,
      anon_sym_LPAREN,
    ACTIONS(13002), 1,
      anon_sym_end,
    STATE(10513), 1,
      sym_attribute,
    STATE(11075), 1,
      sym__attribute,
    STATE(11566), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [513937] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12284), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13004), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10514), 2,
      sym_attribute,
      aux_sym_type_binding_repeat1,
    ACTIONS(12282), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [513978] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(13007), 1,
      anon_sym_LPAREN,
    ACTIONS(13009), 1,
      anon_sym_end,
    STATE(10515), 1,
      sym_attribute,
    STATE(11030), 1,
      sym__attribute,
    STATE(11497), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [514041] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11890), 1,
      anon_sym_constraint,
    ACTIONS(13013), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10516), 1,
      sym_attribute,
    STATE(10526), 1,
      aux_sym_type_binding_repeat1,
    STATE(10667), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13011), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [514090] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(13015), 1,
      anon_sym_LPAREN,
    ACTIONS(13017), 1,
      anon_sym_end,
    STATE(10517), 1,
      sym_attribute,
    STATE(11061), 1,
      sym__attribute,
    STATE(11348), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [514153] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11890), 1,
      anon_sym_constraint,
    ACTIONS(12538), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10518), 1,
      sym_attribute,
    STATE(10668), 1,
      aux_sym_expression_item_repeat1,
    STATE(11041), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12536), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [514202] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10519), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11434), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11436), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [514239] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11890), 1,
      anon_sym_constraint,
    ACTIONS(13021), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10520), 1,
      sym_attribute,
    STATE(10540), 1,
      aux_sym_type_binding_repeat1,
    STATE(10706), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13019), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [514288] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11890), 1,
      anon_sym_constraint,
    ACTIONS(12659), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10521), 1,
      sym_attribute,
    STATE(10703), 1,
      aux_sym_expression_item_repeat1,
    STATE(11041), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12657), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [514337] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(13023), 1,
      anon_sym_LPAREN,
    ACTIONS(13025), 1,
      anon_sym_end,
    STATE(10522), 1,
      sym_attribute,
    STATE(11084), 1,
      sym__attribute,
    STATE(11617), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [514400] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12976), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12978), 1,
      sym_pow_operator,
    ACTIONS(12980), 1,
      sym_mult_operator,
    ACTIONS(12982), 1,
      sym_concat_operator,
    ACTIONS(12984), 1,
      sym_rel_operator,
    ACTIONS(12986), 1,
      sym_and_operator,
    ACTIONS(12994), 1,
      anon_sym_COMMA,
    ACTIONS(12996), 1,
      sym_or_operator,
    ACTIONS(12998), 1,
      sym_assign_operator,
    STATE(1970), 1,
      sym_add_operator,
    STATE(10523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10303), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10301), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
  [514459] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12978), 1,
      sym_pow_operator,
    ACTIONS(12980), 1,
      sym_mult_operator,
    STATE(1970), 1,
      sym_add_operator,
    STATE(10524), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 9,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 10,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [514502] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(12858), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10422), 1,
      aux_sym_expression_item_repeat1,
    STATE(10525), 1,
      sym_attribute,
    STATE(11182), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12856), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [514551] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11890), 1,
      anon_sym_constraint,
    ACTIONS(13029), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10526), 1,
      sym_attribute,
    STATE(10588), 1,
      aux_sym_expression_item_repeat1,
    STATE(11041), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13027), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [514600] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11890), 1,
      anon_sym_constraint,
    ACTIONS(13033), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10527), 1,
      sym_attribute,
    STATE(10562), 1,
      aux_sym_type_binding_repeat1,
    STATE(10584), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13031), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [514649] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13037), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10463), 1,
      aux_sym_expression_item_repeat1,
    STATE(10525), 1,
      aux_sym_type_binding_repeat1,
    STATE(10528), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13035), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [514698] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13041), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10465), 1,
      aux_sym_expression_item_repeat1,
    STATE(10529), 1,
      sym_attribute,
    STATE(11182), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13039), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [514747] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12976), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12978), 1,
      sym_pow_operator,
    ACTIONS(12980), 1,
      sym_mult_operator,
    ACTIONS(12982), 1,
      sym_concat_operator,
    ACTIONS(12984), 1,
      sym_rel_operator,
    ACTIONS(12986), 1,
      sym_and_operator,
    ACTIONS(12994), 1,
      anon_sym_COMMA,
    ACTIONS(12996), 1,
      sym_or_operator,
    ACTIONS(12998), 1,
      sym_assign_operator,
    STATE(1970), 1,
      sym_add_operator,
    STATE(10530), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
  [514806] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12912), 1,
      anon_sym_COMMA,
    ACTIONS(12916), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12918), 1,
      sym_pow_operator,
    ACTIONS(12920), 1,
      sym_mult_operator,
    ACTIONS(12922), 1,
      sym_concat_operator,
    ACTIONS(12924), 1,
      sym_rel_operator,
    ACTIONS(12926), 1,
      sym_and_operator,
    ACTIONS(12928), 1,
      sym_or_operator,
    ACTIONS(12930), 1,
      sym_assign_operator,
    STATE(2001), 1,
      sym_add_operator,
    STATE(10531), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10332), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10330), 7,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
  [514865] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12976), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12978), 1,
      sym_pow_operator,
    ACTIONS(12980), 1,
      sym_mult_operator,
    ACTIONS(12982), 1,
      sym_concat_operator,
    ACTIONS(12984), 1,
      sym_rel_operator,
    ACTIONS(12986), 1,
      sym_and_operator,
    ACTIONS(12996), 1,
      sym_or_operator,
    STATE(1970), 1,
      sym_add_operator,
    STATE(10532), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 8,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [514920] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13045), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10432), 1,
      aux_sym_expression_item_repeat1,
    STATE(10533), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13043), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [514963] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13049), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13047), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [515006] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10535), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10052), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10050), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [515043] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7101), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10536), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7099), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [515086] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13053), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10466), 1,
      aux_sym_expression_item_repeat1,
    STATE(10537), 1,
      sym_attribute,
    STATE(11182), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13051), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [515135] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7111), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7109), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [515178] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11890), 1,
      anon_sym_constraint,
    ACTIONS(13057), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10539), 1,
      sym_attribute,
    STATE(10574), 1,
      aux_sym_type_binding_repeat1,
    STATE(10580), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13055), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [515227] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11890), 1,
      anon_sym_constraint,
    ACTIONS(13061), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10540), 1,
      sym_attribute,
    STATE(10578), 1,
      aux_sym_expression_item_repeat1,
    STATE(11041), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13059), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [515276] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12976), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12978), 1,
      sym_pow_operator,
    ACTIONS(12980), 1,
      sym_mult_operator,
    ACTIONS(12982), 1,
      sym_concat_operator,
    STATE(1970), 1,
      sym_add_operator,
    STATE(10541), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 6,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [515325] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7117), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10542), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [515368] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12976), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12978), 1,
      sym_pow_operator,
    ACTIONS(12980), 1,
      sym_mult_operator,
    ACTIONS(12982), 1,
      sym_concat_operator,
    STATE(1970), 1,
      sym_add_operator,
    STATE(10543), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 6,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [515417] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13065), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10544), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13063), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [515460] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13067), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10545), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [515499] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12978), 1,
      sym_pow_operator,
    STATE(1970), 1,
      sym_add_operator,
    STATE(10546), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 10,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
    ACTIONS(10271), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
  [515540] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10547), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10056), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10054), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [515577] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12978), 1,
      sym_pow_operator,
    STATE(1970), 1,
      sym_add_operator,
    STATE(10548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 10,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
    ACTIONS(10271), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
  [515618] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13070), 1,
      aux_sym_attribute_id_token1,
    STATE(10549), 1,
      sym_attribute,
    STATE(10555), 1,
      aux_sym_attribute_id_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9050), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9052), 12,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [515659] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13074), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10550), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13072), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [515702] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5501), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10551), 1,
      sym_attribute,
    STATE(10632), 1,
      aux_sym_expression_item_repeat1,
    STATE(11071), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13078), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(13076), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [515745] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(13080), 1,
      anon_sym_LPAREN,
    ACTIONS(13082), 1,
      anon_sym_end,
    STATE(10552), 1,
      sym_attribute,
    STATE(11158), 1,
      sym__attribute,
    STATE(11661), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [515808] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12976), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12978), 1,
      sym_pow_operator,
    ACTIONS(12980), 1,
      sym_mult_operator,
    STATE(1970), 1,
      sym_add_operator,
    STATE(10553), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 6,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 9,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [515855] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12976), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12978), 1,
      sym_pow_operator,
    ACTIONS(12980), 1,
      sym_mult_operator,
    ACTIONS(12982), 1,
      sym_concat_operator,
    ACTIONS(12984), 1,
      sym_rel_operator,
    ACTIONS(12986), 1,
      sym_and_operator,
    ACTIONS(12996), 1,
      sym_or_operator,
    STATE(1970), 1,
      sym_add_operator,
    STATE(10554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10344), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10342), 8,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [515910] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13070), 1,
      aux_sym_attribute_id_token1,
    STATE(10555), 1,
      sym_attribute,
    STATE(10624), 1,
      aux_sym_attribute_id_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8919), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8921), 12,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [515951] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13061), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10556), 1,
      sym_attribute,
    STATE(10578), 1,
      aux_sym_expression_item_repeat1,
    STATE(11182), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13059), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [516000] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13086), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13084), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [516043] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13090), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10497), 1,
      aux_sym_expression_item_repeat1,
    STATE(10558), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13088), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [516086] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13057), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10529), 1,
      aux_sym_type_binding_repeat1,
    STATE(10559), 1,
      sym_attribute,
    STATE(10580), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13055), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [516135] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(13092), 1,
      anon_sym_LPAREN,
    ACTIONS(13094), 1,
      anon_sym_end,
    STATE(10560), 1,
      sym_attribute,
    STATE(11172), 1,
      sym__attribute,
    STATE(11245), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [516198] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13033), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10537), 1,
      aux_sym_type_binding_repeat1,
    STATE(10561), 1,
      sym_attribute,
    STATE(10584), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13031), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [516247] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11890), 1,
      anon_sym_constraint,
    ACTIONS(13053), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10466), 1,
      aux_sym_expression_item_repeat1,
    STATE(10562), 1,
      sym_attribute,
    STATE(11041), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13051), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [516296] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12005), 1,
      sym__lowercase_identifier,
    ACTIONS(12007), 1,
      anon_sym_POUND,
    STATE(10563), 1,
      sym_attribute,
    STATE(10644), 1,
      sym_type_constructor_path,
    STATE(17478), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11500), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11502), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [516343] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12331), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13096), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(10514), 1,
      aux_sym_type_binding_repeat1,
    STATE(10564), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12329), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [516386] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10565), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10060), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10058), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [516423] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12317), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13096), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(10514), 1,
      aux_sym_type_binding_repeat1,
    STATE(10566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12315), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [516466] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(13098), 1,
      anon_sym_LPAREN,
    ACTIONS(13100), 1,
      anon_sym_end,
    STATE(10567), 1,
      sym_attribute,
    STATE(11045), 1,
      sym__attribute,
    STATE(11693), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [516529] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10568), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13102), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [516566] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13029), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10569), 1,
      sym_attribute,
    STATE(10588), 1,
      aux_sym_expression_item_repeat1,
    STATE(11182), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13027), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [516615] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10570), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9256), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(9258), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [516652] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12317), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13096), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(10564), 1,
      aux_sym_type_binding_repeat1,
    STATE(10571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12315), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [516695] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13108), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10572), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13106), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [516738] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12569), 1,
      anon_sym_PIPE,
    STATE(10545), 1,
      aux_sym__match_cases_repeat1,
    STATE(10573), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [516779] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11890), 1,
      anon_sym_constraint,
    ACTIONS(13041), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10465), 1,
      aux_sym_expression_item_repeat1,
    STATE(10574), 1,
      sym_attribute,
    STATE(11041), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13039), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [516828] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12005), 1,
      sym__lowercase_identifier,
    ACTIONS(12007), 1,
      anon_sym_POUND,
    STATE(10575), 1,
      sym_attribute,
    STATE(10644), 1,
      sym_type_constructor_path,
    STATE(17478), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11588), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11590), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [516875] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12976), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12978), 1,
      sym_pow_operator,
    ACTIONS(12980), 1,
      sym_mult_operator,
    ACTIONS(12982), 1,
      sym_concat_operator,
    ACTIONS(12984), 1,
      sym_rel_operator,
    ACTIONS(12986), 1,
      sym_and_operator,
    ACTIONS(12994), 1,
      anon_sym_COMMA,
    ACTIONS(12996), 1,
      sym_or_operator,
    ACTIONS(12998), 1,
      sym_assign_operator,
    ACTIONS(13110), 1,
      anon_sym_SEMI,
    STATE(1970), 1,
      sym_add_operator,
    STATE(10576), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9116), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9114), 5,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
  [516936] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11890), 1,
      anon_sym_constraint,
    ACTIONS(13037), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10463), 1,
      aux_sym_expression_item_repeat1,
    STATE(10577), 1,
      sym_attribute,
    STATE(10581), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13035), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [516985] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13114), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10578), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13112), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [517028] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12892), 1,
      anon_sym_else,
    STATE(7983), 1,
      sym_else_clause,
    STATE(10579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [517069] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13041), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10580), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13039), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [517112] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11890), 1,
      anon_sym_constraint,
    ACTIONS(12858), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10422), 1,
      aux_sym_expression_item_repeat1,
    STATE(10581), 1,
      sym_attribute,
    STATE(11041), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12856), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [517161] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(13116), 1,
      anon_sym_LPAREN,
    ACTIONS(13118), 1,
      anon_sym_end,
    STATE(10582), 1,
      sym_attribute,
    STATE(11114), 1,
      sym__attribute,
    STATE(11371), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [517224] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10583), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11845), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11562), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11560), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [517263] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13053), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10584), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13051), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [517306] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10585), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11446), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11448), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [517343] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(13120), 1,
      anon_sym_LPAREN,
    ACTIONS(13122), 1,
      anon_sym_end,
    STATE(10586), 1,
      sym_attribute,
    STATE(11192), 1,
      sym__attribute,
    STATE(11649), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [517406] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13124), 1,
      anon_sym_STAR,
    STATE(10587), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10393), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10391), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [517445] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13128), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10588), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13126), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [517488] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12912), 1,
      anon_sym_COMMA,
    ACTIONS(12916), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12918), 1,
      sym_pow_operator,
    ACTIONS(12920), 1,
      sym_mult_operator,
    ACTIONS(12922), 1,
      sym_concat_operator,
    ACTIONS(12924), 1,
      sym_rel_operator,
    ACTIONS(12926), 1,
      sym_and_operator,
    ACTIONS(12928), 1,
      sym_or_operator,
    ACTIONS(12930), 1,
      sym_assign_operator,
    STATE(2001), 1,
      sym_add_operator,
    STATE(10589), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10340), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10338), 7,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
  [517547] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10590), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9116), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9114), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [517584] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12787), 1,
      anon_sym_else,
    STATE(7983), 1,
      sym_else_clause,
    STATE(10591), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [517625] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12880), 1,
      sym__lowercase_identifier,
    ACTIONS(13130), 1,
      anon_sym_POUND,
    STATE(10592), 1,
      sym_attribute,
    STATE(11072), 1,
      sym_type_constructor_path,
    STATE(17395), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11128), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11130), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [517672] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(12659), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10593), 1,
      sym_attribute,
    STATE(10703), 1,
      aux_sym_expression_item_repeat1,
    STATE(11182), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12657), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [517721] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12880), 1,
      sym__lowercase_identifier,
    ACTIONS(12882), 1,
      anon_sym_POUND,
    STATE(10594), 1,
      sym_attribute,
    STATE(11040), 1,
      sym_type_constructor_path,
    STATE(17395), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10261), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(10263), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [517768] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(12442), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10397), 1,
      aux_sym_expression_item_repeat1,
    STATE(10595), 1,
      sym_attribute,
    STATE(11182), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12440), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [517817] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11863), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10596), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11861), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [517860] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13021), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10556), 1,
      aux_sym_type_binding_repeat1,
    STATE(10597), 1,
      sym_attribute,
    STATE(10706), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13019), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [517909] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12912), 1,
      anon_sym_COMMA,
    ACTIONS(12916), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12918), 1,
      sym_pow_operator,
    ACTIONS(12920), 1,
      sym_mult_operator,
    ACTIONS(12922), 1,
      sym_concat_operator,
    ACTIONS(12924), 1,
      sym_rel_operator,
    ACTIONS(12926), 1,
      sym_and_operator,
    ACTIONS(12928), 1,
      sym_or_operator,
    ACTIONS(12930), 1,
      sym_assign_operator,
    STATE(2001), 1,
      sym_add_operator,
    STATE(10598), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10303), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10301), 7,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
  [517968] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12918), 1,
      sym_pow_operator,
    ACTIONS(12920), 1,
      sym_mult_operator,
    STATE(2001), 1,
      sym_add_operator,
    STATE(10599), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 8,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [518011] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12912), 1,
      anon_sym_COMMA,
    ACTIONS(12916), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12918), 1,
      sym_pow_operator,
    ACTIONS(12920), 1,
      sym_mult_operator,
    ACTIONS(12922), 1,
      sym_concat_operator,
    ACTIONS(12924), 1,
      sym_rel_operator,
    ACTIONS(12926), 1,
      sym_and_operator,
    ACTIONS(12928), 1,
      sym_or_operator,
    ACTIONS(12930), 1,
      sym_assign_operator,
    STATE(2001), 1,
      sym_add_operator,
    STATE(10600), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 7,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
  [518070] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(13132), 1,
      anon_sym_LPAREN,
    ACTIONS(13134), 1,
      anon_sym_end,
    STATE(10601), 1,
      sym_attribute,
    STATE(11129), 1,
      sym__attribute,
    STATE(11582), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [518133] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12218), 1,
      sym__lowercase_identifier,
    ACTIONS(12220), 1,
      anon_sym_POUND,
    STATE(10602), 1,
      sym_attribute,
    STATE(10903), 1,
      sym_type_constructor_path,
    STATE(17519), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12085), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12087), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [518180] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12916), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12918), 1,
      sym_pow_operator,
    ACTIONS(12920), 1,
      sym_mult_operator,
    ACTIONS(12922), 1,
      sym_concat_operator,
    ACTIONS(12924), 1,
      sym_rel_operator,
    ACTIONS(12926), 1,
      sym_and_operator,
    ACTIONS(12928), 1,
      sym_or_operator,
    STATE(2001), 1,
      sym_add_operator,
    STATE(10603), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 9,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [518235] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10604), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10128), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10126), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [518272] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10377), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10375), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [518309] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(13136), 1,
      anon_sym_LPAREN,
    ACTIONS(13138), 1,
      anon_sym_end,
    STATE(10606), 1,
      sym_attribute,
    STATE(11145), 1,
      sym__attribute,
    STATE(11388), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [518372] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10370), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10368), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [518409] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(12538), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10608), 1,
      sym_attribute,
    STATE(10668), 1,
      aux_sym_expression_item_repeat1,
    STATE(11182), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12536), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [518458] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5501), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10364), 1,
      aux_sym_expression_item_repeat1,
    STATE(10609), 1,
      sym_attribute,
    STATE(11071), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13142), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(13140), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [518501] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12916), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12918), 1,
      sym_pow_operator,
    ACTIONS(12920), 1,
      sym_mult_operator,
    ACTIONS(12922), 1,
      sym_concat_operator,
    ACTIONS(12924), 1,
      sym_rel_operator,
    ACTIONS(12926), 1,
      sym_and_operator,
    STATE(2001), 1,
      sym_add_operator,
    STATE(10610), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 9,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [518554] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10611), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10325), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [518591] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13013), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10569), 1,
      aux_sym_type_binding_repeat1,
    STATE(10612), 1,
      sym_attribute,
    STATE(10667), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13011), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [518640] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10613), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11560), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11562), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [518677] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12916), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12918), 1,
      sym_pow_operator,
    ACTIONS(12920), 1,
      sym_mult_operator,
    ACTIONS(12922), 1,
      sym_concat_operator,
    STATE(2001), 1,
      sym_add_operator,
    STATE(10614), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 5,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 9,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [518726] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10615), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10118), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10116), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [518763] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12916), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12918), 1,
      sym_pow_operator,
    ACTIONS(12920), 1,
      sym_mult_operator,
    ACTIONS(12922), 1,
      sym_concat_operator,
    STATE(2001), 1,
      sym_add_operator,
    STATE(10616), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 5,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 9,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [518812] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(13144), 1,
      anon_sym_LPAREN,
    ACTIONS(13146), 1,
      anon_sym_end,
    STATE(10617), 1,
      sym_attribute,
    STATE(11152), 1,
      sym__attribute,
    STATE(11443), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [518875] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(13148), 1,
      anon_sym_LPAREN,
    ACTIONS(13150), 1,
      anon_sym_end,
    STATE(10618), 1,
      sym_attribute,
    STATE(11113), 1,
      sym__attribute,
    STATE(11683), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [518938] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12918), 1,
      sym_pow_operator,
    STATE(2001), 1,
      sym_add_operator,
    STATE(10619), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [518979] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13152), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11938), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(10620), 2,
      sym_attribute,
      aux_sym_module_type_constraint_repeat1,
    ACTIONS(11936), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [519018] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12918), 1,
      sym_pow_operator,
    STATE(2001), 1,
      sym_add_operator,
    STATE(10621), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [519059] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12916), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12918), 1,
      sym_pow_operator,
    ACTIONS(12920), 1,
      sym_mult_operator,
    STATE(2001), 1,
      sym_add_operator,
    STATE(10622), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 5,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 10,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [519106] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12916), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12918), 1,
      sym_pow_operator,
    ACTIONS(12920), 1,
      sym_mult_operator,
    ACTIONS(12922), 1,
      sym_concat_operator,
    ACTIONS(12924), 1,
      sym_rel_operator,
    ACTIONS(12926), 1,
      sym_and_operator,
    ACTIONS(12928), 1,
      sym_or_operator,
    STATE(2001), 1,
      sym_add_operator,
    STATE(10623), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10344), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 9,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [519161] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13155), 1,
      aux_sym_attribute_id_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10624), 2,
      sym_attribute,
      aux_sym_attribute_id_repeat1,
    ACTIONS(8959), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8961), 12,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [519200] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12651), 1,
      anon_sym_and,
    STATE(10620), 1,
      aux_sym_module_type_constraint_repeat1,
    STATE(10625), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12542), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12540), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [519241] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(13158), 1,
      anon_sym_LPAREN,
    ACTIONS(13160), 1,
      anon_sym_end,
    STATE(10626), 1,
      sym_attribute,
    STATE(11169), 1,
      sym__attribute,
    STATE(11351), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [519304] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(13162), 1,
      anon_sym_LPAREN,
    ACTIONS(13164), 1,
      anon_sym_end,
    STATE(10627), 1,
      sym_attribute,
    STATE(11122), 1,
      sym__attribute,
    STATE(11314), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [519367] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12880), 1,
      sym__lowercase_identifier,
    ACTIONS(12882), 1,
      anon_sym_POUND,
    STATE(10628), 1,
      sym_attribute,
    STATE(11040), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17395), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11454), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11456), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [519420] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12880), 1,
      sym__lowercase_identifier,
    ACTIONS(12882), 1,
      anon_sym_POUND,
    STATE(10629), 1,
      sym_attribute,
    STATE(11040), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17395), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11462), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11464), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [519473] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5501), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10451), 1,
      aux_sym_expression_item_repeat1,
    STATE(10630), 1,
      sym_attribute,
    STATE(11071), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13168), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(13166), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [519516] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(13170), 1,
      anon_sym_LPAREN,
    ACTIONS(13172), 1,
      anon_sym_end,
    STATE(10631), 1,
      sym_attribute,
    STATE(11163), 1,
      sym__attribute,
    STATE(11406), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [519579] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5501), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10364), 1,
      aux_sym_expression_item_repeat1,
    STATE(10632), 1,
      sym_attribute,
    STATE(11071), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13176), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(13174), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [519622] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13180), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10502), 1,
      aux_sym_expression_item_repeat1,
    STATE(10633), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13178), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [519665] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13184), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10634), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13182), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [519708] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(13186), 1,
      anon_sym_LPAREN,
    ACTIONS(13188), 1,
      anon_sym_end,
    STATE(10635), 1,
      sym_attribute,
    STATE(11208), 1,
      sym__attribute,
    STATE(11618), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [519771] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11576), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11578), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [519808] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12693), 1,
      anon_sym_EQ,
    ACTIONS(13190), 1,
      anon_sym_of,
    ACTIONS(13192), 1,
      anon_sym_COLON2,
    STATE(10637), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12691), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12689), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [519851] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11538), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11540), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [519888] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6899), 1,
      anon_sym_let,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6897), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [519931] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9256), 1,
      sym__lowercase_identifier,
    STATE(10640), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9258), 4,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
    ACTIONS(11765), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11763), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [519972] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10641), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13196), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13194), 20,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [520009] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10642), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11534), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11536), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [520046] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12238), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13096), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(10566), 1,
      aux_sym_type_binding_repeat1,
    STATE(10643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12236), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [520089] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11638), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11640), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [520126] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(13198), 1,
      anon_sym_LPAREN,
    ACTIONS(13200), 1,
      anon_sym_end,
    STATE(10645), 1,
      sym_attribute,
    STATE(11173), 1,
      sym__attribute,
    STATE(11546), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [520189] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(13202), 1,
      anon_sym_LPAREN,
    ACTIONS(13204), 1,
      anon_sym_end,
    STATE(10646), 1,
      sym_attribute,
    STATE(11181), 1,
      sym__attribute,
    STATE(11454), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [520252] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12880), 1,
      sym__lowercase_identifier,
    ACTIONS(12882), 1,
      anon_sym_POUND,
    STATE(10647), 1,
      sym_attribute,
    STATE(11040), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17395), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11720), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11722), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [520305] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10648), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9120), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9118), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [520342] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11478), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11480), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [520379] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12703), 1,
      anon_sym_EQ,
    ACTIONS(13206), 1,
      anon_sym_of,
    ACTIONS(13208), 1,
      anon_sym_COLON2,
    STATE(10650), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12701), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12699), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [520422] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10651), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10108), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10106), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [520459] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12721), 1,
      anon_sym_EQ,
    ACTIONS(13210), 1,
      anon_sym_of,
    ACTIONS(13212), 1,
      anon_sym_COLON2,
    STATE(10652), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12719), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12717), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [520502] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11676), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11678), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [520539] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10654), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10104), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10102), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [520576] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13216), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13214), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [520619] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10656), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13220), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13218), 20,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [520656] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13224), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10534), 1,
      aux_sym_expression_item_repeat1,
    STATE(10657), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13222), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [520699] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(13226), 1,
      anon_sym_LPAREN,
    ACTIONS(13228), 1,
      anon_sym_end,
    STATE(10658), 1,
      sym_attribute,
    STATE(11020), 1,
      sym__attribute,
    STATE(11260), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [520762] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10659), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10100), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10098), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [520799] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10660), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13232), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13230), 20,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [520836] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13236), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10661), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13234), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [520879] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13240), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13238), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [520922] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13244), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10550), 1,
      aux_sym_expression_item_repeat1,
    STATE(10663), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13242), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [520965] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(12839), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10396), 1,
      aux_sym_expression_item_repeat1,
    STATE(10664), 1,
      sym_attribute,
    STATE(11182), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12837), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [521014] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12880), 1,
      sym__lowercase_identifier,
    ACTIONS(12882), 1,
      anon_sym_POUND,
    STATE(10665), 1,
      sym_attribute,
    STATE(11040), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17395), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11596), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11598), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [521067] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13250), 1,
      anon_sym_DQUOTE,
    STATE(11083), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13248), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(10666), 2,
      sym_attribute,
      aux_sym_external_repeat1,
    ACTIONS(13246), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [521108] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13029), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13027), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [521151] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13255), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13253), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [521194] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11414), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11416), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [521231] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11560), 1,
      sym__lowercase_identifier,
    STATE(10670), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11562), 4,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
    ACTIONS(12069), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12071), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [521272] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13259), 1,
      anon_sym_let,
    STATE(10671), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13257), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [521309] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10672), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11704), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11706), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [521346] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(12785), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10359), 1,
      aux_sym_expression_item_repeat1,
    STATE(10608), 1,
      aux_sym_type_binding_repeat1,
    STATE(10673), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12783), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [521395] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11600), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11602), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [521432] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10675), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11474), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11476), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [521469] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(13261), 1,
      anon_sym_LPAREN,
    ACTIONS(13263), 1,
      anon_sym_end,
    STATE(10676), 1,
      sym_attribute,
    STATE(11183), 1,
      sym__attribute,
    STATE(11459), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [521532] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13267), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13265), 20,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [521569] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10094), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10092), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [521606] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10679), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10090), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10088), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [521643] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10080), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10078), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [521680] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10681), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11442), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11444), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [521717] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10682), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11438), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11440), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [521754] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11692), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11694), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [521791] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13271), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10684), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13269), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [521834] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10685), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11508), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11510), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [521871] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10686), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11470), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11472), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [521908] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10687), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9126), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9124), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [521945] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10688), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11795), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11797), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [521982] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(12422), 1,
      anon_sym_let,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10475), 1,
      aux_sym_expression_item_repeat1,
    STATE(10689), 1,
      sym_attribute,
    STATE(11182), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12420), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [522031] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10690), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11494), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11496), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [522068] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12274), 1,
      sym__lowercase_identifier,
    ACTIONS(12276), 1,
      anon_sym_POUND,
    STATE(10691), 1,
      sym_attribute,
    STATE(10867), 1,
      sym_type_constructor_path,
    STATE(17441), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12085), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12087), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [522115] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(13273), 1,
      anon_sym_LPAREN,
    ACTIONS(13275), 1,
      anon_sym_end,
    STATE(10692), 1,
      sym_attribute,
    STATE(11205), 1,
      sym__attribute,
    STATE(11505), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [522178] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12880), 1,
      sym__lowercase_identifier,
    ACTIONS(12882), 1,
      anon_sym_POUND,
    STATE(10693), 1,
      sym_attribute,
    STATE(11040), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17395), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11588), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11590), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [522231] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(12880), 1,
      sym__lowercase_identifier,
    ACTIONS(12882), 1,
      anon_sym_POUND,
    STATE(10694), 1,
      sym_attribute,
    STATE(11040), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17395), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11500), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11502), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [522284] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10695), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11642), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11644), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [522321] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10696), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11632), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11634), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [522358] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10697), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11550), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11552), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [522395] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13279), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10698), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13277), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [522432] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13283), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10699), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13281), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [522475] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(12560), 1,
      anon_sym_PERCENT,
    ACTIONS(13285), 1,
      anon_sym_LPAREN,
    ACTIONS(13287), 1,
      anon_sym_end,
    STATE(10700), 1,
      sym_attribute,
    STATE(11201), 1,
      sym__attribute,
    STATE(11496), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [522538] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13291), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10701), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13289), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [522581] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13295), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10572), 1,
      aux_sym_expression_item_repeat1,
    STATE(10702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13293), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [522624] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13299), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10703), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13297), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [522667] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10704), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11426), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11428), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [522704] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13303), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13301), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [522747] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13061), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10706), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13059), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [522790] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10707), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11634), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11632), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [522826] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10708), 1,
      sym_attribute,
    STATE(14170), 1,
      sym__module_type,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [522886] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10709), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11765), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11763), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [522922] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10710), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9158), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [522958] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12159), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10578), 1,
      aux_sym_expression_item_repeat1,
    STATE(10711), 1,
      sym_attribute,
    STATE(11557), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13059), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [523004] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(12532), 1,
      anon_sym_DASH_GT,
    ACTIONS(12534), 1,
      anon_sym_functor,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10712), 1,
      sym_attribute,
    STATE(11589), 1,
      sym__module_type,
    STATE(14827), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [523064] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12396), 1,
      sym__lowercase_identifier,
    ACTIONS(12398), 1,
      anon_sym_POUND,
    STATE(10713), 1,
      sym_attribute,
    STATE(10926), 1,
      sym_type_constructor_path,
    STATE(17037), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12085), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12087), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [523110] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10714), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15957), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [523170] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(13305), 1,
      anon_sym_DASH_GT,
    ACTIONS(13307), 1,
      anon_sym_functor,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10715), 1,
      sym_attribute,
    STATE(11174), 1,
      sym__module_type,
    STATE(14535), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [523230] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12159), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10584), 1,
      aux_sym_expression_item_repeat1,
    STATE(10716), 1,
      sym_attribute,
    STATE(10827), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13031), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [523276] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13311), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10717), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13309), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [523318] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10718), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8350), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [523354] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13313), 1,
      anon_sym_DASH_GT,
    STATE(10719), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12511), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12509), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [523392] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(13305), 1,
      anon_sym_DASH_GT,
    ACTIONS(13307), 1,
      anon_sym_functor,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10720), 1,
      sym_attribute,
    STATE(11168), 1,
      sym__module_type,
    STATE(14535), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [523452] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(12532), 1,
      anon_sym_DASH_GT,
    ACTIONS(12534), 1,
      anon_sym_functor,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10721), 1,
      sym_attribute,
    STATE(11553), 1,
      sym__module_type,
    STATE(14827), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [523512] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10722), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11436), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11434), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [523548] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10723), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15673), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [523608] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13315), 1,
      sym__lowercase_identifier,
    ACTIONS(13317), 1,
      anon_sym_LPAREN,
    ACTIONS(13319), 1,
      anon_sym_DASH_GT,
    ACTIONS(13321), 1,
      anon_sym_module,
    ACTIONS(13323), 1,
      anon_sym_sig,
    ACTIONS(13325), 1,
      anon_sym_functor,
    ACTIONS(13327), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13329), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13331), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10724), 1,
      sym_attribute,
    STATE(13825), 1,
      sym__module_type,
    STATE(14915), 1,
      aux_sym_module_binding_repeat1,
    STATE(16581), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13540), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [523668] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10725), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(16391), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [523728] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12218), 1,
      sym__lowercase_identifier,
    ACTIONS(12220), 1,
      anon_sym_POUND,
    STATE(10726), 1,
      sym_attribute,
    STATE(10903), 1,
      sym_type_constructor_path,
    STATE(17519), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12278), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12280), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [523774] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12218), 1,
      sym__lowercase_identifier,
    ACTIONS(12220), 1,
      anon_sym_POUND,
    STATE(10727), 1,
      sym_attribute,
    STATE(10903), 1,
      sym_type_constructor_path,
    STATE(17519), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12303), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12305), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [523820] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10728), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(16248), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [523880] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12159), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10588), 1,
      aux_sym_expression_item_repeat1,
    STATE(10729), 1,
      sym_attribute,
    STATE(11557), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13027), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [523926] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(13305), 1,
      anon_sym_DASH_GT,
    ACTIONS(13307), 1,
      anon_sym_functor,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10730), 1,
      sym_attribute,
    STATE(10745), 1,
      sym__module_type,
    STATE(14535), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [523986] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12218), 1,
      sym__lowercase_identifier,
    ACTIONS(12220), 1,
      anon_sym_POUND,
    STATE(10731), 1,
      sym_attribute,
    STATE(10903), 1,
      sym_type_constructor_path,
    STATE(17519), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11720), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11722), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [524032] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10732), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15936), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [524092] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11076), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10733), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11074), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [524134] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12325), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10734), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12323), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [524176] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10735), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8350), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [524212] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11938), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13333), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10736), 2,
      sym_attribute,
      aux_sym_module_type_constraint_repeat1,
    ACTIONS(11936), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [524250] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8354), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [524286] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12218), 1,
      sym__lowercase_identifier,
    ACTIONS(12220), 1,
      anon_sym_POUND,
    STATE(10738), 1,
      sym_attribute,
    STATE(10903), 1,
      sym_type_constructor_path,
    STATE(17519), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12242), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12244), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [524332] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10739), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8959), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8961), 13,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
      aux_sym_attribute_id_token1,
  [524368] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(13336), 1,
      anon_sym_DASH_GT,
    ACTIONS(13338), 1,
      anon_sym_functor,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10740), 1,
      sym_attribute,
    STATE(10783), 1,
      sym__module_type,
    STATE(14678), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [524428] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13344), 1,
      anon_sym_DASH_GT,
    ACTIONS(13346), 1,
      anon_sym_with,
    STATE(10741), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13342), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13340), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [524468] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12159), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10580), 1,
      aux_sym_expression_item_repeat1,
    STATE(10742), 1,
      sym_attribute,
    STATE(10835), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13055), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [524514] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10743), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8362), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [524550] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(13336), 1,
      anon_sym_DASH_GT,
    ACTIONS(13338), 1,
      anon_sym_functor,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10744), 1,
      sym_attribute,
    STATE(10978), 1,
      sym__module_type,
    STATE(14678), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [524610] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13352), 1,
      anon_sym_DASH_GT,
    ACTIONS(13354), 1,
      anon_sym_with,
    STATE(10745), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13350), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13348), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [524650] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10746), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(16114), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [524710] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13366), 1,
      sym_rel_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    STATE(2268), 1,
      sym_add_operator,
    STATE(10747), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10340), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10338), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
  [524768] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10748), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11765), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11763), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [524804] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12400), 1,
      anon_sym_DASH_GT,
    ACTIONS(12402), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10749), 1,
      sym_attribute,
    STATE(11120), 1,
      sym__module_type,
    STATE(14484), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [524864] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(12532), 1,
      anon_sym_DASH_GT,
    ACTIONS(12534), 1,
      anon_sym_functor,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10750), 1,
      sym_attribute,
    STATE(11873), 1,
      sym__module_type,
    STATE(14827), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [524924] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10751), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11428), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11426), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [524960] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10752), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11552), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11550), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [524996] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10753), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11644), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11642), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [525032] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10754), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(16458), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [525092] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(13336), 1,
      anon_sym_DASH_GT,
    ACTIONS(13338), 1,
      anon_sym_functor,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10755), 1,
      sym_attribute,
    STATE(11194), 1,
      sym__module_type,
    STATE(14678), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [525152] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12218), 1,
      sym__lowercase_identifier,
    ACTIONS(12220), 1,
      anon_sym_POUND,
    STATE(10756), 1,
      sym_attribute,
    STATE(10903), 1,
      sym_type_constructor_path,
    STATE(17519), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11500), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11502), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [525198] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12218), 1,
      sym__lowercase_identifier,
    ACTIONS(12220), 1,
      anon_sym_POUND,
    STATE(10757), 1,
      sym_attribute,
    STATE(10903), 1,
      sym_type_constructor_path,
    STATE(17519), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11588), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11590), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [525244] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11797), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11795), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [525280] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10759), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11472), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11470), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [525316] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10760), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11436), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11434), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [525352] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(13336), 1,
      anon_sym_DASH_GT,
    ACTIONS(13338), 1,
      anon_sym_functor,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10761), 1,
      sym_attribute,
    STATE(10987), 1,
      sym__module_type,
    STATE(14678), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [525412] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10762), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8354), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [525448] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10763), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8358), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [525484] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10764), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15970), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [525544] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10765), 1,
      sym_attribute,
    STATE(14301), 1,
      sym__module_type,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [525604] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(13336), 1,
      anon_sym_DASH_GT,
    ACTIONS(13338), 1,
      anon_sym_functor,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10766), 1,
      sym_attribute,
    STATE(11188), 1,
      sym__module_type,
    STATE(14678), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [525664] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10767), 1,
      sym_attribute,
    STATE(14374), 1,
      sym__module_type,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [525724] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9256), 1,
      sym__lowercase_identifier,
    STATE(10768), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9258), 4,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
    ACTIONS(11765), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11763), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [525764] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11496), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11494), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [525800] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12880), 1,
      sym__lowercase_identifier,
    ACTIONS(12882), 1,
      anon_sym_POUND,
    ACTIONS(13374), 1,
      anon_sym_STAR,
    STATE(10770), 1,
      sym_attribute,
    STATE(11040), 1,
      sym_type_constructor_path,
    STATE(12515), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17395), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11458), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11896), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [525850] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(12532), 1,
      anon_sym_DASH_GT,
    ACTIONS(12534), 1,
      anon_sym_functor,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10771), 1,
      sym_attribute,
    STATE(11861), 1,
      sym__module_type,
    STATE(14827), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [525910] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12721), 1,
      anon_sym_EQ,
    ACTIONS(13376), 1,
      anon_sym_of,
    ACTIONS(13378), 1,
      anon_sym_COLON2,
    STATE(10772), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12719), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12717), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [525952] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10773), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(16253), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [526012] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10774), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9258), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9256), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [526048] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12703), 1,
      anon_sym_EQ,
    ACTIONS(13380), 1,
      anon_sym_of,
    ACTIONS(13382), 1,
      anon_sym_COLON2,
    STATE(10775), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12701), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12699), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [526090] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8362), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [526126] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10777), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11480), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11478), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [526162] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(13313), 1,
      anon_sym_DASH_GT,
    STATE(10778), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12438), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12436), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [526202] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10779), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11678), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11676), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [526238] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10780), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11510), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11508), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [526274] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10781), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9258), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9256), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [526310] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(12532), 1,
      anon_sym_DASH_GT,
    ACTIONS(12534), 1,
      anon_sym_functor,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10782), 1,
      sym_attribute,
    STATE(11648), 1,
      sym__module_type,
    STATE(14827), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [526370] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13344), 1,
      anon_sym_DASH_GT,
    ACTIONS(13346), 1,
      anon_sym_with,
    STATE(10783), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13350), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13348), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [526410] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10784), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11448), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11446), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [526446] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10785), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11694), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11692), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [526482] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11440), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11438), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [526518] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10787), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15827), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [526578] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12693), 1,
      anon_sym_EQ,
    ACTIONS(13384), 1,
      anon_sym_of,
    ACTIONS(13386), 1,
      anon_sym_COLON2,
    STATE(10788), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12691), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12689), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [526620] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10789), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15600), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [526680] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11444), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11442), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [526716] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10791), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11444), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11442), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [526752] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10792), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11440), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11438), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [526788] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10793), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11694), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11692), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [526824] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12159), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10359), 1,
      aux_sym_expression_item_repeat1,
    STATE(10794), 1,
      sym_attribute,
    STATE(10880), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12783), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [526870] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10795), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11510), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11508), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [526906] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12248), 1,
      sym__lowercase_identifier,
    ACTIONS(12250), 1,
      anon_sym_POUND,
    STATE(10796), 1,
      sym_attribute,
    STATE(10881), 1,
      sym_type_constructor_path,
    STATE(17296), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12242), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12244), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [526952] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11472), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11470), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [526988] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10798), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11797), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11795), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [527024] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(12469), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13388), 1,
      anon_sym_DASH_GT,
    STATE(10799), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12467), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [527064] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(12532), 1,
      anon_sym_DASH_GT,
    ACTIONS(12534), 1,
      anon_sym_functor,
    STATE(9464), 1,
      sym__module_type,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10800), 1,
      sym_attribute,
    STATE(14827), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [527124] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12649), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13390), 1,
      anon_sym_and,
    STATE(10801), 1,
      sym_attribute,
    STATE(10973), 1,
      aux_sym_module_type_constraint_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12647), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [527164] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10802), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11634), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11632), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [527200] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9258), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9256), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [527236] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10804), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15046), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [527296] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11918), 1,
      anon_sym_COLON2,
    STATE(10805), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9158), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [527334] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10806), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(16129), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [527394] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10807), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8358), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [527430] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(12532), 1,
      anon_sym_DASH_GT,
    ACTIONS(12534), 1,
      anon_sym_functor,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10808), 1,
      sym_attribute,
    STATE(11843), 1,
      sym__module_type,
    STATE(14827), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [527490] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12400), 1,
      anon_sym_DASH_GT,
    ACTIONS(12402), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10809), 1,
      sym_attribute,
    STATE(11056), 1,
      sym__module_type,
    STATE(14484), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [527550] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8350), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [527586] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12400), 1,
      anon_sym_DASH_GT,
    ACTIONS(12402), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10811), 1,
      sym_attribute,
    STATE(11015), 1,
      sym__module_type,
    STATE(14484), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [527646] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12400), 1,
      anon_sym_DASH_GT,
    ACTIONS(12402), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10812), 1,
      sym_attribute,
    STATE(11452), 1,
      sym__module_type,
    STATE(14484), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [527706] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10813), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15735), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [527766] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12248), 1,
      sym__lowercase_identifier,
    ACTIONS(12250), 1,
      anon_sym_POUND,
    STATE(10814), 1,
      sym_attribute,
    STATE(10881), 1,
      sym_type_constructor_path,
    STATE(17296), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12303), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12305), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [527812] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10393), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13392), 1,
      anon_sym_STAR,
    STATE(10815), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10391), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [527850] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12248), 1,
      sym__lowercase_identifier,
    ACTIONS(12250), 1,
      anon_sym_POUND,
    STATE(10816), 1,
      sym_attribute,
    STATE(10881), 1,
      sym_type_constructor_path,
    STATE(17296), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12278), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12280), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [527896] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10817), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10425), 8,
      anon_sym_rec,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_lazy,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(10427), 13,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [527932] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10818), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10425), 9,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      sym__lowercase_identifier,
    ACTIONS(10427), 12,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [527968] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13396), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13394), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [528010] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13400), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10820), 1,
      sym_attribute,
    STATE(10954), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13398), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [528052] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12248), 1,
      sym__lowercase_identifier,
    ACTIONS(12250), 1,
      anon_sym_POUND,
    STATE(10821), 1,
      sym_attribute,
    STATE(10881), 1,
      sym_type_constructor_path,
    STATE(17296), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11720), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11722), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [528098] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13400), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10822), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13398), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [528140] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10823), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15230), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [528200] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10824), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11765), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11763), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [528236] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10825), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11644), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11642), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [528272] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11552), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11550), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [528308] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12159), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10466), 1,
      aux_sym_expression_item_repeat1,
    STATE(10827), 1,
      sym_attribute,
    STATE(11557), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13051), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [528354] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(13305), 1,
      anon_sym_DASH_GT,
    ACTIONS(13307), 1,
      anon_sym_functor,
    STATE(9464), 1,
      sym__module_type,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10828), 1,
      sym_attribute,
    STATE(14535), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [528414] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10829), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8354), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [528450] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10830), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11496), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11494), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [528486] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10831), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11476), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11474), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [528522] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10832), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8358), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [528558] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10833), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11634), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11632), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [528594] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(2268), 1,
      sym_add_operator,
    STATE(10834), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [528632] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12159), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10465), 1,
      aux_sym_expression_item_repeat1,
    STATE(10835), 1,
      sym_attribute,
    STATE(11557), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13039), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [528678] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12274), 1,
      sym__lowercase_identifier,
    ACTIONS(12276), 1,
      anon_sym_POUND,
    STATE(10836), 1,
      sym_attribute,
    STATE(10867), 1,
      sym_type_constructor_path,
    STATE(17441), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12242), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12244), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [528724] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(13336), 1,
      anon_sym_DASH_GT,
    ACTIONS(13338), 1,
      anon_sym_functor,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10741), 1,
      sym__module_type,
    STATE(10837), 1,
      sym_attribute,
    STATE(14678), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [528784] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10838), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11448), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11446), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [528820] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10839), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11476), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11474), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [528856] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10840), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11678), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11676), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [528892] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11562), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11560), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [528928] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10842), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11480), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11478), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [528964] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13315), 1,
      sym__lowercase_identifier,
    ACTIONS(13317), 1,
      anon_sym_LPAREN,
    ACTIONS(13319), 1,
      anon_sym_DASH_GT,
    ACTIONS(13321), 1,
      anon_sym_module,
    ACTIONS(13323), 1,
      anon_sym_sig,
    ACTIONS(13325), 1,
      anon_sym_functor,
    ACTIONS(13327), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13329), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13331), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10843), 1,
      sym_attribute,
    STATE(13692), 1,
      sym__module_type,
    STATE(14915), 1,
      aux_sym_module_binding_repeat1,
    STATE(16581), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13540), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [529024] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10844), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11600), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [529060] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12400), 1,
      anon_sym_DASH_GT,
    ACTIONS(12402), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10845), 1,
      sym_attribute,
    STATE(11200), 1,
      sym__module_type,
    STATE(14484), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [529120] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10846), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11706), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11704), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [529156] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10847), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11416), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11414), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [529192] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10848), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11562), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11560), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [529228] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12159), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10463), 1,
      aux_sym_expression_item_repeat1,
    STATE(10849), 1,
      sym_attribute,
    STATE(10947), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13035), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [529274] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10850), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11600), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [529310] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10851), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11428), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11426), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [529346] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10852), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11578), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11576), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [529382] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13352), 1,
      anon_sym_DASH_GT,
    ACTIONS(13354), 1,
      anon_sym_with,
    STATE(10853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13342), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13340), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [529422] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10854), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11706), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11704), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [529458] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10855), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11540), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11538), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [529494] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12511), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13388), 1,
      anon_sym_DASH_GT,
    STATE(10856), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12509), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [529532] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11416), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11414), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [529568] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(12438), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13388), 1,
      anon_sym_DASH_GT,
    STATE(10858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12436), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [529608] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10859), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15615), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [529668] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10860), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15446), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [529728] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10861), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11480), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11478), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [529764] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10862), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15799), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [529824] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12159), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10667), 1,
      aux_sym_expression_item_repeat1,
    STATE(10729), 1,
      aux_sym_type_binding_repeat1,
    STATE(10863), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13011), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [529870] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10864), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11678), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11676), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [529906] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10865), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15643), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [529966] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13352), 1,
      anon_sym_DASH_GT,
    ACTIONS(13354), 1,
      anon_sym_with,
    STATE(10866), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13404), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13402), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [530006] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10867), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11640), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11638), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [530042] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(13305), 1,
      anon_sym_DASH_GT,
    ACTIONS(13307), 1,
      anon_sym_functor,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10866), 1,
      sym__module_type,
    STATE(10868), 1,
      sym_attribute,
    STATE(14535), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [530102] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10869), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11536), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11534), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [530138] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11560), 1,
      sym__lowercase_identifier,
    STATE(10870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11562), 4,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
    ACTIONS(12069), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12071), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [530178] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(13305), 1,
      anon_sym_DASH_GT,
    ACTIONS(13307), 1,
      anon_sym_functor,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10871), 1,
      sym_attribute,
    STATE(10949), 1,
      sym__module_type,
    STATE(14535), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [530238] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10872), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11540), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11538), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [530274] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10873), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11578), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11576), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [530310] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13408), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13406), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [530352] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13315), 1,
      sym__lowercase_identifier,
    ACTIONS(13317), 1,
      anon_sym_LPAREN,
    ACTIONS(13319), 1,
      anon_sym_DASH_GT,
    ACTIONS(13321), 1,
      anon_sym_module,
    ACTIONS(13323), 1,
      anon_sym_sig,
    ACTIONS(13325), 1,
      anon_sym_functor,
    ACTIONS(13327), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13329), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13331), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10875), 1,
      sym_attribute,
    STATE(13661), 1,
      sym__module_type,
    STATE(14915), 1,
      aux_sym_module_binding_repeat1,
    STATE(16581), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13540), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [530412] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13315), 1,
      sym__lowercase_identifier,
    ACTIONS(13317), 1,
      anon_sym_LPAREN,
    ACTIONS(13319), 1,
      anon_sym_DASH_GT,
    ACTIONS(13321), 1,
      anon_sym_module,
    ACTIONS(13323), 1,
      anon_sym_sig,
    ACTIONS(13325), 1,
      anon_sym_functor,
    ACTIONS(13327), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13329), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13331), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10876), 1,
      sym_attribute,
    STATE(13813), 1,
      sym__module_type,
    STATE(14915), 1,
      aux_sym_module_binding_repeat1,
    STATE(16581), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13540), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [530472] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10877), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11562), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11560), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [530508] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10878), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11644), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11642), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [530544] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11536), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11534), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [530580] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12159), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10668), 1,
      aux_sym_expression_item_repeat1,
    STATE(10880), 1,
      sym_attribute,
    STATE(11557), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12536), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [530626] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10881), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11640), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11638), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [530662] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12274), 1,
      sym__lowercase_identifier,
    ACTIONS(12276), 1,
      anon_sym_POUND,
    STATE(10867), 1,
      sym_type_constructor_path,
    STATE(10882), 1,
      sym_attribute,
    STATE(17441), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12303), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12305), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [530708] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12400), 1,
      anon_sym_DASH_GT,
    ACTIONS(12402), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9464), 1,
      sym__module_type,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10883), 1,
      sym_attribute,
    STATE(14484), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [530768] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12274), 1,
      sym__lowercase_identifier,
    ACTIONS(12276), 1,
      anon_sym_POUND,
    STATE(10867), 1,
      sym_type_constructor_path,
    STATE(10884), 1,
      sym_attribute,
    STATE(17441), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12278), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12280), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [530814] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10885), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11444), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11442), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [530850] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11562), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11560), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [530886] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9258), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9256), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [530922] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10888), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11440), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11438), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [530958] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11102), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10889), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11100), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [531000] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10890), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15271), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [531060] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10891), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8362), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [531096] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10892), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11694), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11692), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [531132] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10893), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11510), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11508), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [531168] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(12532), 1,
      anon_sym_DASH_GT,
    ACTIONS(12534), 1,
      anon_sym_functor,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10894), 1,
      sym_attribute,
    STATE(11254), 1,
      sym__module_type,
    STATE(14827), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [531228] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12248), 1,
      sym__lowercase_identifier,
    ACTIONS(12250), 1,
      anon_sym_POUND,
    STATE(10881), 1,
      sym_type_constructor_path,
    STATE(10895), 1,
      sym_attribute,
    STATE(17296), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11500), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11502), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [531274] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12159), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10703), 1,
      aux_sym_expression_item_repeat1,
    STATE(10896), 1,
      sym_attribute,
    STATE(11557), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12657), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [531320] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10897), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15143), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [531380] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13412), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10822), 1,
      aux_sym_expression_item_repeat1,
    STATE(10898), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13410), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [531422] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11578), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11576), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [531458] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(13313), 1,
      anon_sym_DASH_GT,
    STATE(10900), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12469), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12467), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [531498] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10901), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11540), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11538), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [531534] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10902), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11536), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11534), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [531570] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11640), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11638), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [531606] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10904), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11578), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11576), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [531642] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11472), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11470), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [531678] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(13414), 1,
      anon_sym_DASH_GT,
    STATE(10906), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12438), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12436), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [531718] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10907), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11540), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11538), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [531754] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12248), 1,
      sym__lowercase_identifier,
    ACTIONS(12250), 1,
      anon_sym_POUND,
    STATE(10881), 1,
      sym_type_constructor_path,
    STATE(10908), 1,
      sym_attribute,
    STATE(17296), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11588), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11590), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [531800] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12719), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12721), 1,
      anon_sym_EQ,
    ACTIONS(13416), 1,
      anon_sym_of,
    ACTIONS(13418), 1,
      anon_sym_COLON2,
    STATE(10909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12717), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [531842] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12428), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(13388), 1,
      anon_sym_DASH_GT,
    STATE(10910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12426), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [531882] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10911), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15992), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [531942] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11797), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11795), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [531978] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12721), 1,
      anon_sym_EQ,
    ACTIONS(13420), 1,
      anon_sym_of,
    ACTIONS(13422), 1,
      anon_sym_COLON2,
    STATE(10913), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12719), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12717), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [532020] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10914), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11448), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11446), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [532056] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12703), 1,
      anon_sym_EQ,
    ACTIONS(13424), 1,
      anon_sym_of,
    ACTIONS(13426), 1,
      anon_sym_COLON2,
    STATE(10915), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12701), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12699), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [532098] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10916), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11706), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11704), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [532134] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10917), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11496), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11494), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [532170] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10918), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11600), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [532206] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13430), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10919), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13428), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [532248] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12693), 1,
      anon_sym_EQ,
    ACTIONS(13432), 1,
      anon_sym_of,
    ACTIONS(13434), 1,
      anon_sym_COLON2,
    STATE(10920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12691), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12689), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [532290] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11436), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11434), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [532326] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10922), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11765), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11763), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [532362] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11536), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11534), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [532398] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10924), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11476), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11474), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [532434] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10925), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15113), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [532494] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11640), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11638), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [532530] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12400), 1,
      anon_sym_DASH_GT,
    ACTIONS(12402), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10927), 1,
      sym_attribute,
    STATE(11706), 1,
      sym__module_type,
    STATE(14484), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [532590] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12701), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12703), 1,
      anon_sym_EQ,
    ACTIONS(13436), 1,
      anon_sym_of,
    ACTIONS(13438), 1,
      anon_sym_COLON2,
    STATE(10928), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12699), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [532632] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13315), 1,
      sym__lowercase_identifier,
    ACTIONS(13317), 1,
      anon_sym_LPAREN,
    ACTIONS(13319), 1,
      anon_sym_DASH_GT,
    ACTIONS(13321), 1,
      anon_sym_module,
    ACTIONS(13323), 1,
      anon_sym_sig,
    ACTIONS(13325), 1,
      anon_sym_functor,
    ACTIONS(13327), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13329), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13331), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10929), 1,
      sym_attribute,
    STATE(13501), 1,
      sym__module_type,
    STATE(14915), 1,
      aux_sym_module_binding_repeat1,
    STATE(16581), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13540), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [532692] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12159), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10396), 1,
      aux_sym_expression_item_repeat1,
    STATE(10930), 1,
      sym_attribute,
    STATE(11557), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12837), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [532738] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13440), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12087), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(10931), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(12085), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [532776] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10932), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11644), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11642), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [532812] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11898), 1,
      anon_sym_STAR,
    STATE(10931), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(10933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13445), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13443), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [532852] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10934), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11634), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11632), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [532888] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10935), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9158), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [532924] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12400), 1,
      anon_sym_DASH_GT,
    ACTIONS(12402), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10936), 1,
      sym_attribute,
    STATE(11474), 1,
      sym__module_type,
    STATE(14484), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [532984] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13449), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10937), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13447), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [533026] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11552), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11550), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [533062] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10939), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11428), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11426), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [533098] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10940), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15282), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [533158] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12159), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10706), 1,
      aux_sym_expression_item_repeat1,
    STATE(10711), 1,
      aux_sym_type_binding_repeat1,
    STATE(10941), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13019), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [533204] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10942), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11797), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11795), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [533240] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12299), 1,
      anon_sym_constraint,
    ACTIONS(13451), 1,
      anon_sym_EQ,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10397), 1,
      aux_sym_expression_item_repeat1,
    STATE(10943), 1,
      sym_attribute,
    STATE(11079), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12440), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [533288] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10944), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11472), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11470), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [533324] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12274), 1,
      sym__lowercase_identifier,
    ACTIONS(12276), 1,
      anon_sym_POUND,
    STATE(10867), 1,
      sym_type_constructor_path,
    STATE(10945), 1,
      sym_attribute,
    STATE(17441), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11720), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11722), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [533370] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10946), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11510), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11508), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [533406] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12159), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10422), 1,
      aux_sym_expression_item_repeat1,
    STATE(10947), 1,
      sym_attribute,
    STATE(11557), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12856), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [533452] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10948), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11694), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11692), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [533488] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13352), 1,
      anon_sym_DASH_GT,
    ACTIONS(13354), 1,
      anon_sym_with,
    STATE(10949), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13455), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13453), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [533528] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10950), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11440), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11438), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [533564] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10951), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15434), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [533624] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10952), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11444), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11442), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [533660] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10953), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11416), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11414), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [533696] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13459), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10954), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13457), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [533738] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13463), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10955), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13461), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [533780] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10956), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11448), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11446), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [533816] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10957), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9158), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [533852] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12159), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10397), 1,
      aux_sym_expression_item_repeat1,
    STATE(10958), 1,
      sym_attribute,
    STATE(11557), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12440), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [533898] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10959), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11678), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11676), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [533934] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10960), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11416), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11414), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [533970] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10961), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11428), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11426), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [534006] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13366), 1,
      sym_rel_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    STATE(2268), 1,
      sym_add_operator,
    STATE(10962), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10344), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 8,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [534060] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10963), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9256), 4,
      anon_sym_COLON2,
      anon_sym_as,
      anon_sym_when,
      sym__lowercase_identifier,
    ACTIONS(9258), 17,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      sym__uppercase_identifier,
  [534096] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12299), 1,
      anon_sym_constraint,
    ACTIONS(13465), 1,
      anon_sym_EQ,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10475), 1,
      aux_sym_expression_item_repeat1,
    STATE(10964), 1,
      sym_attribute,
    STATE(11033), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12420), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [534144] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13366), 1,
      sym_rel_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13467), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(10965), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9116), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9114), 5,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
  [534204] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10966), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11706), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11704), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [534240] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    STATE(2268), 1,
      sym_add_operator,
    STATE(10967), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 5,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 9,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [534286] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10968), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11552), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11550), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [534322] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11600), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [534358] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10970), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11480), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11478), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [534394] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10971), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11496), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11494), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [534430] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11971), 1,
      anon_sym_STAR,
    STATE(10972), 1,
      sym_attribute,
    STATE(10979), 1,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13445), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13443), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [534470] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12542), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13390), 1,
      anon_sym_and,
    STATE(10736), 1,
      aux_sym_module_type_constraint_repeat1,
    STATE(10973), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12540), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [534510] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13414), 1,
      anon_sym_DASH_GT,
    STATE(10974), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12511), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12509), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [534548] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10975), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11476), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11474), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [534584] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9464), 1,
      sym__module_type,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10976), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [534644] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(13336), 1,
      anon_sym_DASH_GT,
    ACTIONS(13338), 1,
      anon_sym_functor,
    STATE(9464), 1,
      sym__module_type,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10977), 1,
      sym_attribute,
    STATE(14678), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [534704] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13344), 1,
      anon_sym_DASH_GT,
    ACTIONS(13346), 1,
      anon_sym_with,
    STATE(10978), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13404), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13402), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [534744] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13469), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12087), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(10979), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(12085), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [534782] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12159), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10475), 1,
      aux_sym_expression_item_repeat1,
    STATE(10980), 1,
      sym_attribute,
    STATE(11557), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12420), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [534828] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10981), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(15910), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [534888] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(13305), 1,
      anon_sym_DASH_GT,
    ACTIONS(13307), 1,
      anon_sym_functor,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10853), 1,
      sym__module_type,
    STATE(10982), 1,
      sym_attribute,
    STATE(14535), 1,
      aux_sym_module_binding_repeat1,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [534948] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13360), 1,
      sym_pow_operator,
    STATE(2268), 1,
      sym_add_operator,
    STATE(10983), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 10,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [534988] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13360), 1,
      sym_pow_operator,
    STATE(2268), 1,
      sym_add_operator,
    STATE(10984), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 10,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [535028] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    STATE(2268), 1,
      sym_add_operator,
    STATE(10985), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 5,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [535076] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    STATE(2268), 1,
      sym_add_operator,
    STATE(10986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 5,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [535124] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13344), 1,
      anon_sym_DASH_GT,
    ACTIONS(13346), 1,
      anon_sym_with,
    STATE(10987), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13455), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13453), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [535164] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12274), 1,
      sym__lowercase_identifier,
    ACTIONS(12276), 1,
      anon_sym_POUND,
    STATE(10867), 1,
      sym_type_constructor_path,
    STATE(10988), 1,
      sym_attribute,
    STATE(17441), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11500), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11502), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [535210] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13366), 1,
      sym_rel_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    STATE(2268), 1,
      sym_add_operator,
    STATE(10989), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 8,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [535262] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13366), 1,
      sym_rel_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    STATE(2268), 1,
      sym_add_operator,
    STATE(10990), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 8,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [535316] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13366), 1,
      sym_rel_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    STATE(2268), 1,
      sym_add_operator,
    STATE(10991), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
  [535374] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    STATE(2268), 1,
      sym_add_operator,
    STATE(10992), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 8,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 10,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [535416] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12274), 1,
      sym__lowercase_identifier,
    ACTIONS(12276), 1,
      anon_sym_POUND,
    STATE(10867), 1,
      sym_type_constructor_path,
    STATE(10993), 1,
      sym_attribute,
    STATE(17441), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11588), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11590), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [535462] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10994), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11436), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11434), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [535498] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13366), 1,
      sym_rel_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    STATE(2268), 1,
      sym_add_operator,
    STATE(10995), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10303), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10301), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
  [535556] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(13414), 1,
      anon_sym_DASH_GT,
    STATE(10996), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12469), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12467), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [535596] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12691), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12693), 1,
      anon_sym_EQ,
    ACTIONS(13472), 1,
      anon_sym_of,
    ACTIONS(13474), 1,
      anon_sym_COLON2,
    STATE(10997), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12689), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [535638] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12378), 1,
      sym__lowercase_identifier,
    ACTIONS(12380), 1,
      anon_sym_LPAREN,
    ACTIONS(12386), 1,
      anon_sym_DASH_GT,
    ACTIONS(12388), 1,
      anon_sym_module,
    ACTIONS(12390), 1,
      anon_sym_sig,
    ACTIONS(12392), 1,
      anon_sym_functor,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(10998), 1,
      sym_attribute,
    STATE(14940), 1,
      aux_sym_module_binding_repeat1,
    STATE(16344), 1,
      sym__module_type,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9392), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [535698] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13478), 1,
      anon_sym_let,
    ACTIONS(13480), 1,
      anon_sym_and,
    STATE(10999), 1,
      sym_attribute,
    STATE(11011), 1,
      aux_sym_class_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13476), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [535737] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13303), 1,
      anon_sym_let,
    ACTIONS(13482), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10507), 1,
      aux_sym_expression_item_repeat1,
    STATE(11000), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13301), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [535780] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12683), 1,
      anon_sym_let,
    ACTIONS(13484), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10382), 1,
      aux_sym_expression_item_repeat1,
    STATE(11001), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12681), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [535823] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7111), 1,
      anon_sym_let,
    ACTIONS(7113), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10495), 1,
      aux_sym_expression_item_repeat1,
    STATE(11002), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7109), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [535866] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12701), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12703), 1,
      anon_sym_EQ,
    ACTIONS(13486), 1,
      anon_sym_of,
    ACTIONS(13488), 1,
      anon_sym_COLON2,
    STATE(11003), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12699), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [535907] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12719), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12721), 1,
      anon_sym_EQ,
    ACTIONS(13490), 1,
      anon_sym_of,
    ACTIONS(13492), 1,
      anon_sym_COLON2,
    STATE(11004), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12717), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [535948] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13496), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10937), 1,
      aux_sym_expression_item_repeat1,
    STATE(11005), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13498), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(13494), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [535991] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(11006), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9766), 9,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      sym__lowercase_identifier,
    ACTIONS(9768), 11,
      anon_sym_LPAREN,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [536026] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13500), 1,
      anon_sym_LPAREN,
    ACTIONS(13502), 1,
      anon_sym_end,
    STATE(11007), 1,
      sym_attribute,
    STATE(11332), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [536083] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7117), 1,
      anon_sym_let,
    ACTIONS(7119), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10705), 1,
      aux_sym_expression_item_repeat1,
    STATE(11008), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [536126] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12691), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12693), 1,
      anon_sym_EQ,
    ACTIONS(13504), 1,
      anon_sym_of,
    ACTIONS(13506), 1,
      anon_sym_COLON2,
    STATE(11009), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12689), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [536167] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11010), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11678), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11676), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [536202] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13510), 1,
      anon_sym_let,
    ACTIONS(13512), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11011), 2,
      sym_attribute,
      aux_sym_class_type_definition_repeat1,
    ACTIONS(13508), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [536239] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13515), 1,
      anon_sym_LPAREN,
    ACTIONS(13517), 1,
      anon_sym_end,
    STATE(11012), 1,
      sym_attribute,
    STATE(11653), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [536296] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11013), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11480), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11478), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [536331] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13519), 1,
      anon_sym_LPAREN,
    ACTIONS(13521), 1,
      anon_sym_end,
    STATE(11014), 1,
      sym_attribute,
    STATE(11689), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [536388] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13455), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13523), 1,
      anon_sym_DASH_GT,
    ACTIONS(13525), 1,
      anon_sym_with,
    STATE(11015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13453), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [536427] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13527), 1,
      anon_sym_LPAREN,
    ACTIONS(13529), 1,
      anon_sym_end,
    STATE(11016), 1,
      sym_attribute,
    STATE(11527), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [536484] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11448), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11446), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [536519] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11562), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11560), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [536554] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12299), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10475), 1,
      aux_sym_expression_item_repeat1,
    STATE(11019), 1,
      sym_attribute,
    STATE(11800), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12420), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [536599] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13531), 1,
      anon_sym_LPAREN,
    ACTIONS(13533), 1,
      anon_sym_end,
    STATE(11020), 1,
      sym_attribute,
    STATE(11262), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [536656] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13535), 1,
      anon_sym_LPAREN,
    ACTIONS(13537), 1,
      anon_sym_end,
    STATE(11021), 1,
      sym_attribute,
    STATE(11647), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [536713] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11022), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11444), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11442), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [536748] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13480), 1,
      anon_sym_and,
    ACTIONS(13541), 1,
      anon_sym_let,
    STATE(11023), 1,
      sym_attribute,
    STATE(11153), 1,
      aux_sym_class_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13539), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [536787] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11440), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11438), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [536822] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(12469), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13543), 1,
      anon_sym_DASH_GT,
    STATE(11025), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12467), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [536861] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11026), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11009), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11007), 11,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
  [536896] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11027), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11694), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11692), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [536931] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13545), 1,
      anon_sym_COMMA,
    ACTIONS(13547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13549), 1,
      sym_pow_operator,
    ACTIONS(13551), 1,
      sym_mult_operator,
    ACTIONS(13553), 1,
      sym_concat_operator,
    ACTIONS(13555), 1,
      sym_rel_operator,
    ACTIONS(13557), 1,
      sym_and_operator,
    ACTIONS(13559), 1,
      sym_or_operator,
    ACTIONS(13561), 1,
      sym_assign_operator,
    STATE(1796), 1,
      sym_add_operator,
    STATE(11028), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10332), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10330), 5,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [536988] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12299), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10359), 1,
      aux_sym_expression_item_repeat1,
    STATE(11029), 1,
      sym_attribute,
    STATE(11062), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12783), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [537033] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13563), 1,
      anon_sym_LPAREN,
    ACTIONS(13565), 1,
      anon_sym_end,
    STATE(11030), 1,
      sym_attribute,
    STATE(11420), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [537090] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11031), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11510), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11508), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [537125] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11578), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11576), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [537160] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12299), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10396), 1,
      aux_sym_expression_item_repeat1,
    STATE(11033), 1,
      sym_attribute,
    STATE(11800), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12837), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [537205] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11034), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11540), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11538), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [537240] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13567), 1,
      anon_sym_LPAREN,
    ACTIONS(13569), 1,
      anon_sym_end,
    STATE(11035), 1,
      sym_attribute,
    STATE(11281), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [537297] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12299), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10397), 1,
      aux_sym_expression_item_repeat1,
    STATE(11036), 1,
      sym_attribute,
    STATE(11800), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12440), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [537342] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12396), 1,
      sym__lowercase_identifier,
    ACTIONS(12398), 1,
      anon_sym_POUND,
    STATE(10926), 1,
      sym_type_constructor_path,
    STATE(11037), 1,
      sym_attribute,
    STATE(17037), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12278), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12280), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [537387] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11536), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11534), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [537422] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12396), 1,
      sym__lowercase_identifier,
    ACTIONS(12398), 1,
      anon_sym_POUND,
    STATE(10926), 1,
      sym_type_constructor_path,
    STATE(11039), 1,
      sym_attribute,
    STATE(17037), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12303), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12305), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [537467] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11640), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11638), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [537502] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13571), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12284), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(11041), 2,
      sym_attribute,
      aux_sym_type_binding_repeat1,
    ACTIONS(12282), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [537541] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11472), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11470), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [537576] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(1796), 1,
      sym_add_operator,
    STATE(11043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [537613] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13574), 1,
      anon_sym_else,
    STATE(10654), 1,
      sym_else_clause,
    STATE(11044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [537652] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13576), 1,
      anon_sym_LPAREN,
    ACTIONS(13578), 1,
      anon_sym_end,
    STATE(11045), 1,
      sym_attribute,
    STATE(11731), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [537709] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13580), 1,
      anon_sym_LPAREN,
    ACTIONS(13582), 1,
      anon_sym_end,
    STATE(11046), 1,
      sym_attribute,
    STATE(11316), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [537766] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13584), 1,
      anon_sym_else,
    STATE(10654), 1,
      sym_else_clause,
    STATE(11047), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [537805] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13586), 1,
      anon_sym_LPAREN,
    ACTIONS(13588), 1,
      anon_sym_end,
    STATE(11048), 1,
      sym_attribute,
    STATE(11577), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [537862] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12719), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12721), 1,
      anon_sym_EQ,
    ACTIONS(13590), 1,
      anon_sym_of,
    ACTIONS(13592), 1,
      anon_sym_COLON2,
    STATE(11049), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12717), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [537903] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13594), 1,
      anon_sym_LPAREN,
    ACTIONS(13596), 1,
      anon_sym_end,
    STATE(11050), 1,
      sym_attribute,
    STATE(11685), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [537960] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13598), 1,
      anon_sym_LPAREN,
    ACTIONS(13600), 1,
      anon_sym_end,
    STATE(11051), 1,
      sym_attribute,
    STATE(11716), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [538017] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12396), 1,
      sym__lowercase_identifier,
    ACTIONS(12398), 1,
      anon_sym_POUND,
    STATE(10926), 1,
      sym_type_constructor_path,
    STATE(11052), 1,
      sym_attribute,
    STATE(17037), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12242), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12244), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [538062] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13602), 1,
      anon_sym_PIPE,
    STATE(11053), 1,
      sym_attribute,
    STATE(11193), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12075), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12073), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [538101] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13604), 1,
      anon_sym_LPAREN,
    ACTIONS(13606), 1,
      anon_sym_end,
    STATE(11054), 1,
      sym_attribute,
    STATE(11297), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [538158] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12938), 1,
      anon_sym_let,
    ACTIONS(13608), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10655), 1,
      aux_sym_expression_item_repeat1,
    STATE(11055), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12936), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [538201] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13350), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13523), 1,
      anon_sym_DASH_GT,
    ACTIONS(13525), 1,
      anon_sym_with,
    STATE(11056), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13348), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [538240] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12206), 1,
      anon_sym_STAR,
    STATE(11057), 1,
      sym_attribute,
    STATE(11131), 1,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13445), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13443), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [538279] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11058), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11797), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11795), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [538314] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8596), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8598), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13610), 1,
      anon_sym_LPAREN,
    ACTIONS(13612), 1,
      anon_sym_BANG,
    ACTIONS(13614), 1,
      anon_sym_functor,
    ACTIONS(13616), 1,
      anon_sym_struct,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13620), 1,
      sym__uppercase_identifier,
    STATE(11059), 1,
      sym_attribute,
    STATE(11930), 1,
      sym__attribute,
    STATE(12872), 1,
      sym__module_expression,
    STATE(13140), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13223), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(13238), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [538371] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12299), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10667), 1,
      aux_sym_expression_item_repeat1,
    STATE(11060), 1,
      sym_attribute,
    STATE(11095), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13011), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [538416] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13622), 1,
      anon_sym_LPAREN,
    ACTIONS(13624), 1,
      anon_sym_end,
    STATE(11061), 1,
      sym_attribute,
    STATE(11354), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [538473] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12299), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10668), 1,
      aux_sym_expression_item_repeat1,
    STATE(11062), 1,
      sym_attribute,
    STATE(11800), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12536), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [538518] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12880), 1,
      sym__lowercase_identifier,
    ACTIONS(12882), 1,
      anon_sym_POUND,
    STATE(11040), 1,
      sym_type_constructor_path,
    STATE(11063), 1,
      sym_attribute,
    STATE(17395), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12085), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12087), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [538563] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13602), 1,
      anon_sym_PIPE,
    STATE(11064), 1,
      sym_attribute,
    STATE(11187), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13628), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13626), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [538602] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13630), 1,
      anon_sym_LPAREN,
    ACTIONS(13632), 1,
      anon_sym_end,
    STATE(11065), 1,
      sym_attribute,
    STATE(11323), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [538659] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12172), 1,
      anon_sym_STAR,
    STATE(11066), 1,
      sym_attribute,
    STATE(11170), 1,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13445), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13443), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [538698] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13634), 1,
      anon_sym_LPAREN,
    ACTIONS(13636), 1,
      anon_sym_end,
    STATE(11067), 1,
      sym_attribute,
    STATE(11266), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [538755] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(13638), 1,
      sym__lowercase_identifier,
    ACTIONS(13640), 1,
      anon_sym_POUND,
    STATE(11068), 1,
      sym_attribute,
    STATE(11771), 1,
      sym_type_constructor_path,
    STATE(17375), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10261), 7,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(10263), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
  [538800] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6899), 1,
      anon_sym_let,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7145), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10544), 1,
      aux_sym_expression_item_repeat1,
    STATE(11069), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6897), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [538843] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12299), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10706), 1,
      aux_sym_expression_item_repeat1,
    STATE(11070), 1,
      sym_attribute,
    STATE(11107), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13019), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [538888] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11071), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12270), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12268), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [538923] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11634), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11632), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [538958] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11938), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13642), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11073), 2,
      sym_attribute,
      aux_sym_module_type_constraint_repeat1,
    ACTIONS(11936), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [538995] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7135), 1,
      anon_sym_let,
    ACTIONS(7137), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10405), 1,
      aux_sym_expression_item_repeat1,
    STATE(11074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7133), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [539038] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13645), 1,
      anon_sym_LPAREN,
    ACTIONS(13647), 1,
      anon_sym_end,
    STATE(11075), 1,
      sym_attribute,
    STATE(11575), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [539095] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10393), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13649), 1,
      anon_sym_STAR,
    STATE(11076), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10391), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [539132] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13584), 1,
      anon_sym_else,
    STATE(10470), 1,
      sym_else_clause,
    STATE(11077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [539171] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13651), 1,
      anon_sym_LPAREN,
    ACTIONS(13653), 1,
      anon_sym_end,
    STATE(11078), 1,
      sym_attribute,
    STATE(11227), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [539228] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12299), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10703), 1,
      aux_sym_expression_item_repeat1,
    STATE(11079), 1,
      sym_attribute,
    STATE(11800), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12657), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [539273] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13655), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13267), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(11080), 2,
      sym_attribute,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(13265), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [539310] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12701), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12703), 1,
      anon_sym_EQ,
    ACTIONS(13658), 1,
      anon_sym_of,
    ACTIONS(13660), 1,
      anon_sym_COLON2,
    STATE(11081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12699), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [539351] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(12438), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13543), 1,
      anon_sym_DASH_GT,
    STATE(11082), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12436), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [539390] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11083), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13664), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13662), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      anon_sym_DQUOTE,
      sym_let_operator,
      aux_sym_directive_token1,
  [539425] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13666), 1,
      anon_sym_LPAREN,
    ACTIONS(13668), 1,
      anon_sym_end,
    STATE(11084), 1,
      sym_attribute,
    STATE(11619), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [539482] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13670), 1,
      anon_sym_LPAREN,
    ACTIONS(13672), 1,
      anon_sym_end,
    STATE(11085), 1,
      sym_attribute,
    STATE(11444), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [539539] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13674), 1,
      anon_sym_LPAREN,
    ACTIONS(13676), 1,
      anon_sym_end,
    STATE(11086), 1,
      sym_attribute,
    STATE(11280), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [539596] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13682), 1,
      anon_sym_PIPE,
    STATE(11080), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(11087), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13680), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13678), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [539635] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11088), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8358), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [539670] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11089), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8350), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [539705] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13684), 1,
      anon_sym_LPAREN,
    ACTIONS(13686), 1,
      anon_sym_end,
    STATE(11090), 1,
      sym_attribute,
    STATE(11650), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [539762] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11091), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8354), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [539797] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12542), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13688), 1,
      anon_sym_and,
    STATE(11073), 1,
      aux_sym_module_type_constraint_repeat1,
    STATE(11092), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12540), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [539836] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12396), 1,
      sym__lowercase_identifier,
    ACTIONS(12398), 1,
      anon_sym_POUND,
    STATE(10926), 1,
      sym_type_constructor_path,
    STATE(11093), 1,
      sym_attribute,
    STATE(17037), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11720), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11722), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [539881] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11094), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11428), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11426), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [539916] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12299), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10588), 1,
      aux_sym_expression_item_repeat1,
    STATE(11095), 1,
      sym_attribute,
    STATE(11800), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13027), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [539961] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11096), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8362), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [539996] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(13638), 1,
      sym__lowercase_identifier,
    ACTIONS(13690), 1,
      anon_sym_POUND,
    STATE(11097), 1,
      sym_attribute,
    STATE(11797), 1,
      sym_type_constructor_path,
    STATE(17375), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11128), 7,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11130), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
  [540041] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(13638), 1,
      sym__lowercase_identifier,
    ACTIONS(13640), 1,
      anon_sym_POUND,
    STATE(11098), 1,
      sym_attribute,
    STATE(11771), 1,
      sym_type_constructor_path,
    STATE(17375), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11124), 7,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11126), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
  [540086] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12691), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12693), 1,
      anon_sym_EQ,
    ACTIONS(13692), 1,
      anon_sym_of,
    ACTIONS(13694), 1,
      anon_sym_COLON2,
    STATE(11099), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12689), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [540127] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11100), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8336), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      anon_sym_DQUOTE,
      sym_let_operator,
      aux_sym_directive_token1,
  [540162] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13696), 1,
      aux_sym_attribute_id_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11101), 2,
      sym_attribute,
      aux_sym_attribute_id_repeat1,
    ACTIONS(8961), 8,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
    ACTIONS(8959), 10,
      anon_sym_rec,
      anon_sym_nonrec,
      anon_sym__,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_virtual,
      anon_sym_functor,
      anon_sym_struct,
      sym__lowercase_identifier,
  [540199] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12299), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10584), 1,
      aux_sym_expression_item_repeat1,
    STATE(11102), 1,
      sym_attribute,
    STATE(11128), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13031), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [540244] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13699), 1,
      anon_sym_LPAREN,
    ACTIONS(13701), 1,
      anon_sym_end,
    STATE(11103), 1,
      sym_attribute,
    STATE(11506), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [540301] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12299), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10580), 1,
      aux_sym_expression_item_repeat1,
    STATE(11104), 1,
      sym_attribute,
    STATE(11130), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13055), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [540346] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13703), 1,
      anon_sym_LPAREN,
    ACTIONS(13705), 1,
      anon_sym_end,
    STATE(11105), 1,
      sym_attribute,
    STATE(11385), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [540403] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11106), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8340), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      anon_sym_DQUOTE,
      sym_let_operator,
      aux_sym_directive_token1,
  [540438] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12299), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10578), 1,
      aux_sym_expression_item_repeat1,
    STATE(11107), 1,
      sym_attribute,
    STATE(11800), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13059), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [540483] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7101), 1,
      anon_sym_let,
    ACTIONS(7103), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10434), 1,
      aux_sym_expression_item_repeat1,
    STATE(11108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7099), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [540526] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12797), 1,
      anon_sym_let,
    ACTIONS(13707), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10409), 1,
      aux_sym_expression_item_repeat1,
    STATE(11109), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12795), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [540569] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11552), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11550), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [540604] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11111), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11436), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11434), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [540639] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7135), 1,
      anon_sym_let,
    ACTIONS(7139), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10405), 1,
      aux_sym_expression_item_repeat1,
    STATE(11112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7133), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [540682] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13709), 1,
      anon_sym_LPAREN,
    ACTIONS(13711), 1,
      anon_sym_end,
    STATE(11113), 1,
      sym_attribute,
    STATE(11499), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [540739] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13713), 1,
      anon_sym_LPAREN,
    ACTIONS(13715), 1,
      anon_sym_end,
    STATE(11114), 1,
      sym_attribute,
    STATE(11375), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [540796] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7117), 1,
      anon_sym_let,
    ACTIONS(7131), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10705), 1,
      aux_sym_expression_item_repeat1,
    STATE(11115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [540839] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12683), 1,
      anon_sym_let,
    ACTIONS(13717), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10382), 1,
      aux_sym_expression_item_repeat1,
    STATE(11116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12681), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [540882] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13719), 1,
      anon_sym_PIPE,
    STATE(11117), 1,
      sym_attribute,
    STATE(11126), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [540921] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13719), 1,
      anon_sym_PIPE,
    STATE(11118), 1,
      sym_attribute,
    STATE(11127), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [540960] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13721), 1,
      anon_sym_LPAREN,
    ACTIONS(13723), 1,
      anon_sym_end,
    STATE(11119), 1,
      sym_attribute,
    STATE(11533), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [541017] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13404), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13523), 1,
      anon_sym_DASH_GT,
    ACTIONS(13525), 1,
      anon_sym_with,
    STATE(11120), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13402), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [541056] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13725), 1,
      anon_sym_LPAREN,
    ACTIONS(13727), 1,
      anon_sym_end,
    STATE(11121), 1,
      sym_attribute,
    STATE(11513), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [541113] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13729), 1,
      anon_sym_LPAREN,
    ACTIONS(13731), 1,
      anon_sym_end,
    STATE(11122), 1,
      sym_attribute,
    STATE(11357), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [541170] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11416), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11414), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [541205] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11706), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11704), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [541240] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(13414), 1,
      anon_sym_DASH_GT,
    STATE(11125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12428), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12426), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [541279] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13719), 1,
      anon_sym_PIPE,
    STATE(11126), 1,
      sym_attribute,
    STATE(11133), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [541318] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13719), 1,
      anon_sym_PIPE,
    STATE(11127), 1,
      sym_attribute,
    STATE(11133), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [541357] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12299), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10466), 1,
      aux_sym_expression_item_repeat1,
    STATE(11128), 1,
      sym_attribute,
    STATE(11800), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13051), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [541402] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13733), 1,
      anon_sym_LPAREN,
    ACTIONS(13735), 1,
      anon_sym_end,
    STATE(11129), 1,
      sym_attribute,
    STATE(11588), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [541459] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12299), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10465), 1,
      aux_sym_expression_item_repeat1,
    STATE(11130), 1,
      sym_attribute,
    STATE(11800), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13039), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [541504] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13737), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12087), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(11131), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(12085), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [541541] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13682), 1,
      anon_sym_PIPE,
    STATE(11080), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(11132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13628), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13626), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [541580] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13740), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11133), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [541617] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11600), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [541652] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12299), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10463), 1,
      aux_sym_expression_item_repeat1,
    STATE(11135), 1,
      sym_attribute,
    STATE(11140), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13035), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [541697] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11476), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11474), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [541732] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13682), 1,
      anon_sym_PIPE,
    STATE(11087), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(11137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13628), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13626), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [541771] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12797), 1,
      anon_sym_let,
    ACTIONS(13743), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10409), 1,
      aux_sym_expression_item_repeat1,
    STATE(11138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12795), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [541814] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7101), 1,
      anon_sym_let,
    ACTIONS(7105), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10434), 1,
      aux_sym_expression_item_repeat1,
    STATE(11139), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7099), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [541857] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12299), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10422), 1,
      aux_sym_expression_item_repeat1,
    STATE(11140), 1,
      sym_attribute,
    STATE(11800), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12856), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [541902] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(11141), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10425), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(10427), 12,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [541937] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12345), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12343), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [541972] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13747), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10919), 1,
      aux_sym_expression_item_repeat1,
    STATE(11143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13749), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(13745), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [542015] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13751), 1,
      aux_sym_attribute_id_token1,
    STATE(11101), 1,
      aux_sym_attribute_id_repeat1,
    STATE(11144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8921), 8,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
    ACTIONS(8919), 10,
      anon_sym_rec,
      anon_sym_nonrec,
      anon_sym__,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_virtual,
      anon_sym_functor,
      anon_sym_struct,
      sym__lowercase_identifier,
  [542054] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13753), 1,
      anon_sym_LPAREN,
    ACTIONS(13755), 1,
      anon_sym_end,
    STATE(11145), 1,
      sym_attribute,
    STATE(11389), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [542111] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13751), 1,
      aux_sym_attribute_id_token1,
    STATE(11144), 1,
      aux_sym_attribute_id_repeat1,
    STATE(11146), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9052), 8,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
    ACTIONS(9050), 10,
      anon_sym_rec,
      anon_sym_nonrec,
      anon_sym__,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_virtual,
      anon_sym_functor,
      anon_sym_struct,
      sym__lowercase_identifier,
  [542150] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13065), 1,
      anon_sym_let,
    ACTIONS(13757), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10436), 1,
      aux_sym_expression_item_repeat1,
    STATE(11147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13063), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [542193] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13759), 1,
      anon_sym_LPAREN,
    ACTIONS(13761), 1,
      anon_sym_end,
    STATE(11148), 1,
      sym_attribute,
    STATE(11434), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [542250] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12649), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13688), 1,
      anon_sym_and,
    STATE(11092), 1,
      aux_sym_module_type_constraint_repeat1,
    STATE(11149), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12647), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [542289] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13747), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10919), 1,
      aux_sym_expression_item_repeat1,
    STATE(11150), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13763), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(13745), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [542332] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7111), 1,
      anon_sym_let,
    ACTIONS(7129), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10495), 1,
      aux_sym_expression_item_repeat1,
    STATE(11151), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7109), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [542375] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13765), 1,
      anon_sym_LPAREN,
    ACTIONS(13767), 1,
      anon_sym_end,
    STATE(11152), 1,
      sym_attribute,
    STATE(11698), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [542432] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13480), 1,
      anon_sym_and,
    ACTIONS(13771), 1,
      anon_sym_let,
    STATE(11011), 1,
      aux_sym_class_type_definition_repeat1,
    STATE(11153), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13769), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [542471] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11154), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9158), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [542506] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13480), 1,
      anon_sym_and,
    ACTIONS(13771), 1,
      anon_sym_let,
    STATE(10999), 1,
      aux_sym_class_type_definition_repeat1,
    STATE(11155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13769), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [542545] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12511), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13543), 1,
      anon_sym_DASH_GT,
    STATE(11156), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12509), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [542582] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13775), 1,
      anon_sym_BANG,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(8933), 1,
      sym__module_expression,
    STATE(11157), 1,
      sym_attribute,
    STATE(11979), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [542639] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13781), 1,
      anon_sym_LPAREN,
    ACTIONS(13783), 1,
      anon_sym_end,
    STATE(11158), 1,
      sym_attribute,
    STATE(11608), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [542696] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13496), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10937), 1,
      aux_sym_expression_item_repeat1,
    STATE(11159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13785), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(13494), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [542739] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13303), 1,
      anon_sym_let,
    ACTIONS(13787), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10507), 1,
      aux_sym_expression_item_repeat1,
    STATE(11160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13301), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [542782] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13549), 1,
      sym_pow_operator,
    ACTIONS(13551), 1,
      sym_mult_operator,
    STATE(1796), 1,
      sym_add_operator,
    STATE(11161), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 4,
      anon_sym_and,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [542827] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13065), 1,
      anon_sym_let,
    ACTIONS(13789), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10436), 1,
      aux_sym_expression_item_repeat1,
    STATE(11162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13063), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [542870] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13791), 1,
      anon_sym_LPAREN,
    ACTIONS(13793), 1,
      anon_sym_end,
    STATE(11163), 1,
      sym_attribute,
    STATE(11415), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [542927] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13549), 1,
      sym_pow_operator,
    STATE(1796), 1,
      sym_add_operator,
    STATE(11164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [542966] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12260), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12258), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [543001] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13549), 1,
      sym_pow_operator,
    ACTIONS(13551), 1,
      sym_mult_operator,
    ACTIONS(13553), 1,
      sym_concat_operator,
    STATE(1796), 1,
      sym_add_operator,
    STATE(11166), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 4,
      anon_sym_and,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [543048] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13549), 1,
      sym_pow_operator,
    ACTIONS(13551), 1,
      sym_mult_operator,
    ACTIONS(13553), 1,
      sym_concat_operator,
    STATE(1796), 1,
      sym_add_operator,
    STATE(11167), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 4,
      anon_sym_and,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [543095] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13352), 1,
      anon_sym_DASH_GT,
    ACTIONS(13354), 1,
      anon_sym_with,
    ACTIONS(13797), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10717), 1,
      aux_sym_expression_item_repeat1,
    STATE(11168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13795), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [543140] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13799), 1,
      anon_sym_LPAREN,
    ACTIONS(13801), 1,
      anon_sym_end,
    STATE(11169), 1,
      sym_attribute,
    STATE(11386), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [543197] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13803), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12087), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(11170), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(12085), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [543234] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13549), 1,
      sym_pow_operator,
    ACTIONS(13551), 1,
      sym_mult_operator,
    ACTIONS(13553), 1,
      sym_concat_operator,
    ACTIONS(13555), 1,
      sym_rel_operator,
    ACTIONS(13557), 1,
      sym_and_operator,
    STATE(1796), 1,
      sym_add_operator,
    STATE(11171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_and,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_assign_operator,
      sym_let_and_operator,
  [543285] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13806), 1,
      anon_sym_LPAREN,
    ACTIONS(13808), 1,
      anon_sym_end,
    STATE(11172), 1,
      sym_attribute,
    STATE(11246), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [543342] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13810), 1,
      anon_sym_LPAREN,
    ACTIONS(13812), 1,
      anon_sym_end,
    STATE(11173), 1,
      sym_attribute,
    STATE(11551), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [543399] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13352), 1,
      anon_sym_DASH_GT,
    ACTIONS(13354), 1,
      anon_sym_with,
    ACTIONS(13816), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10874), 1,
      aux_sym_expression_item_repeat1,
    STATE(11174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13814), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [543444] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11175), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11765), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11763), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [543479] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6899), 1,
      anon_sym_let,
    ACTIONS(6901), 1,
      anon_sym_EQ,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10544), 1,
      aux_sym_expression_item_repeat1,
    STATE(11176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6897), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [543522] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13682), 1,
      anon_sym_PIPE,
    STATE(11132), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(11177), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12075), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12073), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [543561] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9258), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9256), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [543596] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13545), 1,
      anon_sym_COMMA,
    ACTIONS(13547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13549), 1,
      sym_pow_operator,
    ACTIONS(13551), 1,
      sym_mult_operator,
    ACTIONS(13553), 1,
      sym_concat_operator,
    ACTIONS(13555), 1,
      sym_rel_operator,
    ACTIONS(13557), 1,
      sym_and_operator,
    ACTIONS(13559), 1,
      sym_or_operator,
    ACTIONS(13561), 1,
      sym_assign_operator,
    ACTIONS(13818), 1,
      anon_sym_SEMI,
    STATE(1796), 1,
      sym_add_operator,
    STATE(11179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9116), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9114), 4,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [543655] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13574), 1,
      anon_sym_else,
    STATE(10470), 1,
      sym_else_clause,
    STATE(11180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [543694] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13820), 1,
      anon_sym_LPAREN,
    ACTIONS(13822), 1,
      anon_sym_end,
    STATE(11181), 1,
      sym_attribute,
    STATE(11462), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [543751] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13824), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12284), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(11182), 2,
      sym_attribute,
      aux_sym_type_binding_repeat1,
    ACTIONS(12282), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [543790] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13827), 1,
      anon_sym_LPAREN,
    ACTIONS(13829), 1,
      anon_sym_end,
    STATE(11183), 1,
      sym_attribute,
    STATE(11405), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [543847] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12097), 1,
      anon_sym_STAR,
    ACTIONS(13445), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(11184), 1,
      sym_attribute,
    STATE(11191), 1,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13443), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [543886] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13549), 1,
      sym_pow_operator,
    ACTIONS(13551), 1,
      sym_mult_operator,
    ACTIONS(13553), 1,
      sym_concat_operator,
    ACTIONS(13555), 1,
      sym_rel_operator,
    ACTIONS(13557), 1,
      sym_and_operator,
    ACTIONS(13559), 1,
      sym_or_operator,
    STATE(1796), 1,
      sym_add_operator,
    STATE(11185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_assign_operator,
      sym_let_and_operator,
  [543939] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13831), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13267), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(11186), 2,
      sym_attribute,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(13265), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [543976] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13602), 1,
      anon_sym_PIPE,
    STATE(11186), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(11187), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13680), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13678), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [544015] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13344), 1,
      anon_sym_DASH_GT,
    ACTIONS(13346), 1,
      anon_sym_with,
    ACTIONS(13797), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10717), 1,
      aux_sym_expression_item_repeat1,
    STATE(11188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13795), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [544060] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12938), 1,
      anon_sym_let,
    ACTIONS(13834), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10655), 1,
      aux_sym_expression_item_repeat1,
    STATE(11189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12936), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [544103] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13545), 1,
      anon_sym_COMMA,
    ACTIONS(13547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13549), 1,
      sym_pow_operator,
    ACTIONS(13551), 1,
      sym_mult_operator,
    ACTIONS(13553), 1,
      sym_concat_operator,
    ACTIONS(13555), 1,
      sym_rel_operator,
    ACTIONS(13557), 1,
      sym_and_operator,
    ACTIONS(13559), 1,
      sym_or_operator,
    ACTIONS(13561), 1,
      sym_assign_operator,
    STATE(1796), 1,
      sym_add_operator,
    STATE(11190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [544160] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12087), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13836), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11191), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(12085), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [544197] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13839), 1,
      anon_sym_LPAREN,
    ACTIONS(13841), 1,
      anon_sym_end,
    STATE(11192), 1,
      sym_attribute,
    STATE(11640), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [544254] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13602), 1,
      anon_sym_PIPE,
    STATE(11186), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(11193), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13628), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13626), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [544293] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13344), 1,
      anon_sym_DASH_GT,
    ACTIONS(13346), 1,
      anon_sym_with,
    ACTIONS(13816), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10874), 1,
      aux_sym_expression_item_repeat1,
    STATE(11194), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13814), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [544338] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13549), 1,
      sym_pow_operator,
    ACTIONS(13551), 1,
      sym_mult_operator,
    STATE(1796), 1,
      sym_add_operator,
    STATE(11195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [544379] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13545), 1,
      anon_sym_COMMA,
    ACTIONS(13547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13549), 1,
      sym_pow_operator,
    ACTIONS(13551), 1,
      sym_mult_operator,
    ACTIONS(13553), 1,
      sym_concat_operator,
    ACTIONS(13555), 1,
      sym_rel_operator,
    ACTIONS(13557), 1,
      sym_and_operator,
    ACTIONS(13559), 1,
      sym_or_operator,
    ACTIONS(13561), 1,
      sym_assign_operator,
    STATE(1796), 1,
      sym_add_operator,
    STATE(11196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10303), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10301), 5,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [544436] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11496), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11494), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [544471] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13549), 1,
      sym_pow_operator,
    ACTIONS(13551), 1,
      sym_mult_operator,
    ACTIONS(13553), 1,
      sym_concat_operator,
    ACTIONS(13555), 1,
      sym_rel_operator,
    ACTIONS(13557), 1,
      sym_and_operator,
    ACTIONS(13559), 1,
      sym_or_operator,
    STATE(1796), 1,
      sym_add_operator,
    STATE(11198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10344), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_assign_operator,
      sym_let_and_operator,
  [544524] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(13313), 1,
      anon_sym_DASH_GT,
    STATE(11199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12428), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12426), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [544563] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13342), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13523), 1,
      anon_sym_DASH_GT,
    ACTIONS(13525), 1,
      anon_sym_with,
    STATE(11200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13340), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [544602] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13843), 1,
      anon_sym_LPAREN,
    ACTIONS(13845), 1,
      anon_sym_end,
    STATE(11201), 1,
      sym_attribute,
    STATE(11559), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [544659] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12396), 1,
      sym__lowercase_identifier,
    ACTIONS(12398), 1,
      anon_sym_POUND,
    STATE(10926), 1,
      sym_type_constructor_path,
    STATE(11202), 1,
      sym_attribute,
    STATE(17037), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11500), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11502), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [544704] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12396), 1,
      sym__lowercase_identifier,
    ACTIONS(12398), 1,
      anon_sym_POUND,
    STATE(10926), 1,
      sym_type_constructor_path,
    STATE(11203), 1,
      sym_attribute,
    STATE(17037), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11588), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11590), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [544749] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13545), 1,
      anon_sym_COMMA,
    ACTIONS(13547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13549), 1,
      sym_pow_operator,
    ACTIONS(13551), 1,
      sym_mult_operator,
    ACTIONS(13553), 1,
      sym_concat_operator,
    ACTIONS(13555), 1,
      sym_rel_operator,
    ACTIONS(13557), 1,
      sym_and_operator,
    ACTIONS(13559), 1,
      sym_or_operator,
    ACTIONS(13561), 1,
      sym_assign_operator,
    STATE(1796), 1,
      sym_add_operator,
    STATE(11204), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10340), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10338), 5,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [544806] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13847), 1,
      anon_sym_LPAREN,
    ACTIONS(13849), 1,
      anon_sym_end,
    STATE(11205), 1,
      sym_attribute,
    STATE(11509), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [544863] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13549), 1,
      sym_pow_operator,
    STATE(1796), 1,
      sym_add_operator,
    STATE(11206), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [544902] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11644), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11642), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [544937] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13851), 1,
      anon_sym_LPAREN,
    ACTIONS(13853), 1,
      anon_sym_end,
    STATE(11208), 1,
      sym_attribute,
    STATE(11615), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [544994] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13680), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13855), 1,
      anon_sym_PIPE,
    STATE(11209), 1,
      sym_attribute,
    STATE(11514), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13678), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [545032] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13857), 1,
      anon_sym_end,
    STATE(11210), 1,
      sym_attribute,
    STATE(11555), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [545086] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13859), 1,
      anon_sym_end,
    STATE(11211), 1,
      sym_attribute,
    STATE(11212), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [545140] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13861), 1,
      anon_sym_end,
    STATE(11212), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [545194] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13863), 1,
      anon_sym_end,
    STATE(11213), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [545248] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13865), 1,
      anon_sym_end,
    STATE(11214), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [545302] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13865), 1,
      anon_sym_end,
    STATE(11215), 1,
      sym_attribute,
    STATE(11219), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [545356] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13867), 1,
      anon_sym_end,
    STATE(11214), 1,
      aux_sym_object_expression_repeat1,
    STATE(11216), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [545410] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13869), 1,
      anon_sym_end,
    STATE(11213), 1,
      aux_sym_object_expression_repeat1,
    STATE(11217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [545464] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13869), 1,
      anon_sym_end,
    STATE(11218), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [545518] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13871), 1,
      anon_sym_end,
    STATE(11219), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [545572] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11220), 1,
      sym_attribute,
    STATE(11914), 1,
      sym__attribute,
    STATE(13130), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [545626] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13653), 1,
      anon_sym_end,
    STATE(11221), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [545680] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13873), 1,
      anon_sym_end,
    STATE(11218), 1,
      aux_sym_object_expression_repeat1,
    STATE(11222), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [545734] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13873), 1,
      anon_sym_end,
    STATE(11223), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [545788] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11224), 1,
      sym_attribute,
    STATE(11917), 1,
      sym__attribute,
    STATE(13007), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [545842] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13875), 1,
      anon_sym_end,
    STATE(11225), 1,
      sym_attribute,
    STATE(11243), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [545896] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13875), 1,
      anon_sym_end,
    STATE(11226), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [545950] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13877), 1,
      anon_sym_end,
    STATE(11227), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [546004] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9116), 1,
      anon_sym_COLON2,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13879), 1,
      anon_sym_SEMI,
    ACTIONS(13881), 1,
      sym_rel_operator,
    STATE(2268), 1,
      sym_add_operator,
    STATE(11228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9114), 4,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [546062] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13883), 1,
      anon_sym_end,
    STATE(11229), 1,
      sym_attribute,
    STATE(11230), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [546116] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13885), 1,
      anon_sym_end,
    STATE(11230), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [546170] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13885), 1,
      anon_sym_end,
    STATE(11231), 1,
      sym_attribute,
    STATE(11234), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [546224] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13867), 1,
      anon_sym_end,
    STATE(11232), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [546278] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11233), 1,
      sym_attribute,
    STATE(11933), 1,
      sym__attribute,
    STATE(12942), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [546332] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13887), 1,
      anon_sym_end,
    STATE(11234), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [546386] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13887), 1,
      anon_sym_end,
    STATE(11235), 1,
      sym_attribute,
    STATE(11237), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [546440] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13889), 1,
      anon_sym_else,
    STATE(10654), 1,
      sym_else_clause,
    STATE(11236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [546478] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13891), 1,
      anon_sym_end,
    STATE(11237), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [546532] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13636), 1,
      anon_sym_end,
    STATE(11238), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [546586] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11239), 1,
      sym_attribute,
    STATE(11942), 1,
      sym__attribute,
    STATE(13122), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [546640] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13893), 1,
      anon_sym_end,
    STATE(11223), 1,
      aux_sym_object_expression_repeat1,
    STATE(11240), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [546694] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13895), 1,
      anon_sym_end,
    STATE(11226), 1,
      aux_sym_object_expression_repeat1,
    STATE(11241), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [546748] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13897), 1,
      anon_sym_end,
    STATE(11242), 1,
      sym_attribute,
    STATE(11430), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [546802] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13859), 1,
      anon_sym_end,
    STATE(11243), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [546856] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13897), 1,
      anon_sym_end,
    STATE(11244), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [546910] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13808), 1,
      anon_sym_end,
    STATE(11245), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [546964] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13899), 1,
      anon_sym_end,
    STATE(11246), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [547018] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13905), 1,
      anon_sym_and,
    ACTIONS(13907), 1,
      sym_let_and_operator,
    STATE(11247), 1,
      sym_attribute,
    STATE(11620), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13903), 2,
      anon_sym_let,
      anon_sym_in,
    ACTIONS(13901), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [547058] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13913), 1,
      anon_sym_and,
    ACTIONS(13915), 1,
      sym_let_and_operator,
    STATE(11248), 1,
      sym_attribute,
    STATE(11312), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13911), 2,
      anon_sym_let,
      anon_sym_in,
    ACTIONS(13909), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [547098] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13917), 1,
      anon_sym_end,
    STATE(11249), 1,
      sym_attribute,
    STATE(11251), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [547152] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11250), 1,
      sym_attribute,
    STATE(11910), 1,
      sym__attribute,
    STATE(13098), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [547206] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13919), 1,
      anon_sym_end,
    STATE(11251), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [547260] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13919), 1,
      anon_sym_end,
    STATE(11252), 1,
      sym_attribute,
    STATE(11255), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [547314] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13905), 1,
      anon_sym_and,
    ACTIONS(13907), 1,
      sym_let_and_operator,
    STATE(11253), 1,
      sym_attribute,
    STATE(11634), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13903), 2,
      anon_sym_let,
      anon_sym_in,
    ACTIONS(13901), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [547354] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13342), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13921), 1,
      anon_sym_DASH_GT,
    ACTIONS(13923), 1,
      anon_sym_with,
    STATE(11254), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13340), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [547392] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13925), 1,
      anon_sym_end,
    STATE(11255), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [547446] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13925), 1,
      anon_sym_end,
    STATE(11256), 1,
      sym_attribute,
    STATE(11257), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [547500] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13927), 1,
      anon_sym_end,
    STATE(11257), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [547554] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11258), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11845), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11562), 8,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11560), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [547590] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13931), 1,
      anon_sym_let,
    STATE(11259), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13929), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [547624] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13533), 1,
      anon_sym_end,
    STATE(11260), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [547678] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13933), 1,
      anon_sym_end,
    STATE(11244), 1,
      aux_sym_object_expression_repeat1,
    STATE(11261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [547732] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13935), 1,
      anon_sym_end,
    STATE(11262), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [547786] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13937), 1,
      anon_sym_end,
    STATE(11263), 1,
      sym_attribute,
    STATE(11264), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [547840] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13939), 1,
      anon_sym_end,
    STATE(11264), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [547894] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13939), 1,
      anon_sym_end,
    STATE(11265), 1,
      sym_attribute,
    STATE(11299), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [547948] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13941), 1,
      anon_sym_end,
    STATE(11266), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [548002] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13943), 1,
      anon_sym_end,
    STATE(11232), 1,
      aux_sym_object_expression_repeat1,
    STATE(11267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [548056] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13945), 1,
      anon_sym_end,
    STATE(11268), 1,
      sym_attribute,
    STATE(11270), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [548110] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11269), 1,
      sym_attribute,
    STATE(11950), 1,
      sym__attribute,
    STATE(13058), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [548164] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13947), 1,
      anon_sym_end,
    STATE(11270), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [548218] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13947), 1,
      anon_sym_end,
    STATE(11271), 1,
      sym_attribute,
    STATE(11272), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [548272] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13949), 1,
      anon_sym_end,
    STATE(11272), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [548326] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13951), 1,
      anon_sym_end,
    STATE(11273), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [548380] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13949), 1,
      anon_sym_end,
    STATE(11274), 1,
      sym_attribute,
    STATE(11275), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [548434] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13953), 1,
      anon_sym_end,
    STATE(11275), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [548488] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13913), 1,
      anon_sym_and,
    ACTIONS(13915), 1,
      sym_let_and_operator,
    STATE(11248), 1,
      aux_sym_value_definition_repeat1,
    STATE(11276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13957), 2,
      anon_sym_let,
      anon_sym_in,
    ACTIONS(13955), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [548528] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11277), 1,
      sym_attribute,
    STATE(11964), 1,
      sym__attribute,
    STATE(12976), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [548582] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13959), 1,
      anon_sym_end,
    STATE(11273), 1,
      aux_sym_object_expression_repeat1,
    STATE(11278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [548636] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13606), 1,
      anon_sym_end,
    STATE(11279), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [548690] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13961), 1,
      anon_sym_end,
    STATE(11280), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [548744] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13963), 1,
      anon_sym_end,
    STATE(11281), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [548798] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13959), 1,
      anon_sym_end,
    STATE(11282), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [548852] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(8893), 1,
      sym__module_expression,
    STATE(11283), 1,
      sym_attribute,
    STATE(12092), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [548906] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13965), 1,
      anon_sym_COMMA,
    ACTIONS(13967), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13969), 1,
      sym_pow_operator,
    ACTIONS(13971), 1,
      sym_mult_operator,
    ACTIONS(13973), 1,
      sym_concat_operator,
    ACTIONS(13975), 1,
      sym_rel_operator,
    ACTIONS(13977), 1,
      sym_and_operator,
    ACTIONS(13979), 1,
      sym_or_operator,
    ACTIONS(13981), 1,
      sym_assign_operator,
    STATE(1966), 1,
      sym_add_operator,
    STATE(11284), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10340), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10338), 4,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [548962] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13965), 1,
      anon_sym_COMMA,
    ACTIONS(13967), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13969), 1,
      sym_pow_operator,
    ACTIONS(13971), 1,
      sym_mult_operator,
    ACTIONS(13973), 1,
      sym_concat_operator,
    ACTIONS(13975), 1,
      sym_rel_operator,
    ACTIONS(13977), 1,
      sym_and_operator,
    ACTIONS(13979), 1,
      sym_or_operator,
    ACTIONS(13981), 1,
      sym_assign_operator,
    STATE(1966), 1,
      sym_add_operator,
    STATE(11285), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10303), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10301), 4,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [549018] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13969), 1,
      sym_pow_operator,
    ACTIONS(13971), 1,
      sym_mult_operator,
    STATE(1966), 1,
      sym_add_operator,
    STATE(11286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [549058] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13965), 1,
      anon_sym_COMMA,
    ACTIONS(13967), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13969), 1,
      sym_pow_operator,
    ACTIONS(13971), 1,
      sym_mult_operator,
    ACTIONS(13973), 1,
      sym_concat_operator,
    ACTIONS(13975), 1,
      sym_rel_operator,
    ACTIONS(13977), 1,
      sym_and_operator,
    ACTIONS(13979), 1,
      sym_or_operator,
    ACTIONS(13981), 1,
      sym_assign_operator,
    STATE(1966), 1,
      sym_add_operator,
    STATE(11287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 4,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [549114] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13983), 1,
      anon_sym_end,
    STATE(11288), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [549168] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13967), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13969), 1,
      sym_pow_operator,
    ACTIONS(13971), 1,
      sym_mult_operator,
    ACTIONS(13973), 1,
      sym_concat_operator,
    ACTIONS(13975), 1,
      sym_rel_operator,
    ACTIONS(13977), 1,
      sym_and_operator,
    ACTIONS(13979), 1,
      sym_or_operator,
    STATE(1966), 1,
      sym_add_operator,
    STATE(11289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_assign_operator,
      sym_let_and_operator,
  [549220] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13967), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13969), 1,
      sym_pow_operator,
    ACTIONS(13971), 1,
      sym_mult_operator,
    ACTIONS(13973), 1,
      sym_concat_operator,
    ACTIONS(13975), 1,
      sym_rel_operator,
    ACTIONS(13977), 1,
      sym_and_operator,
    STATE(1966), 1,
      sym_add_operator,
    STATE(11290), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_and,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_assign_operator,
      sym_let_and_operator,
  [549270] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13967), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13969), 1,
      sym_pow_operator,
    ACTIONS(13971), 1,
      sym_mult_operator,
    ACTIONS(13973), 1,
      sym_concat_operator,
    STATE(1966), 1,
      sym_add_operator,
    STATE(11291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 4,
      anon_sym_and,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [549316] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13967), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13969), 1,
      sym_pow_operator,
    ACTIONS(13971), 1,
      sym_mult_operator,
    ACTIONS(13973), 1,
      sym_concat_operator,
    STATE(1966), 1,
      sym_add_operator,
    STATE(11292), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 4,
      anon_sym_and,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [549362] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13969), 1,
      sym_pow_operator,
    STATE(1966), 1,
      sym_add_operator,
    STATE(11293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [549400] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13969), 1,
      sym_pow_operator,
    STATE(1966), 1,
      sym_add_operator,
    STATE(11294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [549438] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13967), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13969), 1,
      sym_pow_operator,
    ACTIONS(13971), 1,
      sym_mult_operator,
    STATE(1966), 1,
      sym_add_operator,
    STATE(11295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 4,
      anon_sym_and,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [549482] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13967), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13969), 1,
      sym_pow_operator,
    ACTIONS(13971), 1,
      sym_mult_operator,
    ACTIONS(13973), 1,
      sym_concat_operator,
    ACTIONS(13975), 1,
      sym_rel_operator,
    ACTIONS(13977), 1,
      sym_and_operator,
    ACTIONS(13979), 1,
      sym_or_operator,
    STATE(1966), 1,
      sym_add_operator,
    STATE(11296), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10344), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_assign_operator,
      sym_let_and_operator,
  [549534] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13985), 1,
      anon_sym_end,
    STATE(11297), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [549588] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13987), 1,
      anon_sym_end,
    STATE(11298), 1,
      sym_attribute,
    STATE(11304), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [549642] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13989), 1,
      anon_sym_end,
    STATE(11299), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [549696] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13523), 1,
      anon_sym_DASH_GT,
    ACTIONS(13525), 1,
      anon_sym_with,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(11300), 1,
      sym_attribute,
    STATE(11823), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13991), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [549738] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11301), 1,
      sym_attribute,
    STATE(11980), 1,
      sym__attribute,
    STATE(13075), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [549792] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11302), 1,
      sym_attribute,
    STATE(11997), 1,
      sym__attribute,
    STATE(12975), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [549846] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13989), 1,
      anon_sym_end,
    STATE(11303), 1,
      sym_attribute,
    STATE(11309), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [549900] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13993), 1,
      anon_sym_end,
    STATE(11304), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [549954] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13993), 1,
      anon_sym_end,
    STATE(11305), 1,
      sym_attribute,
    STATE(11306), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [550008] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13995), 1,
      anon_sym_end,
    STATE(11306), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [550062] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13995), 1,
      anon_sym_end,
    STATE(11307), 1,
      sym_attribute,
    STATE(11308), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [550116] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13997), 1,
      anon_sym_end,
    STATE(11308), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [550170] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13999), 1,
      anon_sym_end,
    STATE(11309), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [550224] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11310), 1,
      sym_attribute,
    STATE(12002), 1,
      sym__attribute,
    STATE(12974), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [550278] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13582), 1,
      anon_sym_end,
    STATE(11311), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [550332] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14005), 1,
      anon_sym_and,
    ACTIONS(14008), 1,
      sym_let_and_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14003), 2,
      anon_sym_let,
      anon_sym_in,
    STATE(11312), 2,
      sym_attribute,
      aux_sym_value_definition_repeat1,
    ACTIONS(14001), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [550370] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13913), 1,
      anon_sym_and,
    ACTIONS(13915), 1,
      sym_let_and_operator,
    STATE(11312), 1,
      aux_sym_value_definition_repeat1,
    STATE(11313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13957), 2,
      anon_sym_let,
      anon_sym_in,
    ACTIONS(13955), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [550410] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13731), 1,
      anon_sym_end,
    STATE(11314), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [550464] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13676), 1,
      anon_sym_end,
    STATE(11315), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [550518] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14011), 1,
      anon_sym_end,
    STATE(11316), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [550572] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11317), 1,
      sym_attribute,
    STATE(12008), 1,
      sym__attribute,
    STATE(12941), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [550626] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13569), 1,
      anon_sym_end,
    STATE(11318), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [550680] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14013), 1,
      anon_sym_end,
    STATE(11319), 1,
      sym_attribute,
    STATE(11320), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [550734] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14015), 1,
      anon_sym_end,
    STATE(11320), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [550788] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14015), 1,
      anon_sym_end,
    STATE(11321), 1,
      sym_attribute,
    STATE(11324), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [550842] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14017), 1,
      anon_sym_end,
    STATE(11288), 1,
      aux_sym_object_expression_repeat1,
    STATE(11322), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [550896] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14019), 1,
      anon_sym_end,
    STATE(11323), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [550950] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14021), 1,
      anon_sym_end,
    STATE(11324), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [551004] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14021), 1,
      anon_sym_end,
    STATE(11325), 1,
      sym_attribute,
    STATE(11326), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [551058] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14023), 1,
      anon_sym_end,
    STATE(11326), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [551112] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11327), 1,
      sym_attribute,
    STATE(12021), 1,
      sym__attribute,
    STATE(13120), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [551166] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11328), 1,
      sym_attribute,
    STATE(12013), 1,
      sym__attribute,
    STATE(13065), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [551220] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13502), 1,
      anon_sym_end,
    STATE(11329), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [551274] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14017), 1,
      anon_sym_end,
    STATE(11330), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [551328] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11331), 1,
      sym_attribute,
    STATE(12019), 1,
      sym__attribute,
    STATE(13032), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [551382] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14025), 1,
      anon_sym_end,
    STATE(11332), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [551436] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14027), 1,
      anon_sym_end,
    STATE(11333), 1,
      sym_attribute,
    STATE(11337), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [551490] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14029), 1,
      anon_sym_end,
    STATE(11334), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [551544] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14031), 1,
      anon_sym_end,
    STATE(11334), 1,
      aux_sym_object_expression_repeat1,
    STATE(11335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [551598] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14031), 1,
      anon_sym_end,
    STATE(11336), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [551652] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14033), 1,
      anon_sym_end,
    STATE(11337), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [551706] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14033), 1,
      anon_sym_end,
    STATE(11338), 1,
      sym_attribute,
    STATE(11339), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [551760] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14035), 1,
      anon_sym_end,
    STATE(11339), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [551814] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14035), 1,
      anon_sym_end,
    STATE(11340), 1,
      sym_attribute,
    STATE(11345), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [551868] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11341), 1,
      sym_attribute,
    STATE(12027), 1,
      sym__attribute,
    STATE(13123), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [551922] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(8965), 1,
      sym__module_expression,
    STATE(11342), 1,
      sym_attribute,
    STATE(12162), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [551976] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14037), 1,
      anon_sym_end,
    STATE(11336), 1,
      aux_sym_object_expression_repeat1,
    STATE(11343), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [552030] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14037), 1,
      anon_sym_end,
    STATE(11344), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [552084] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14039), 1,
      anon_sym_end,
    STATE(11345), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [552138] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(1966), 1,
      sym_add_operator,
    STATE(11346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [552174] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12087), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14041), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11347), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(12085), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [552210] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13624), 1,
      anon_sym_end,
    STATE(11348), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [552264] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12374), 1,
      anon_sym_STAR,
    ACTIONS(13445), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(11347), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(11349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13443), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [552302] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11350), 1,
      sym_attribute,
    STATE(12038), 1,
      sym__attribute,
    STATE(13094), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [552356] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13801), 1,
      anon_sym_end,
    STATE(11351), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [552410] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14044), 1,
      anon_sym_end,
    STATE(11352), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [552464] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11353), 1,
      sym_attribute,
    STATE(11907), 1,
      sym__attribute,
    STATE(12946), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [552518] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14046), 1,
      anon_sym_end,
    STATE(11354), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [552572] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14048), 1,
      anon_sym_end,
    STATE(11352), 1,
      aux_sym_object_expression_repeat1,
    STATE(11355), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [552626] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14048), 1,
      anon_sym_end,
    STATE(11356), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [552680] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14050), 1,
      anon_sym_end,
    STATE(11357), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [552734] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14052), 1,
      anon_sym_end,
    STATE(11358), 1,
      sym_attribute,
    STATE(11362), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [552788] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14054), 1,
      anon_sym_end,
    STATE(11356), 1,
      aux_sym_object_expression_repeat1,
    STATE(11359), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [552842] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14054), 1,
      anon_sym_end,
    STATE(11360), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [552896] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14056), 1,
      anon_sym_end,
    STATE(11344), 1,
      aux_sym_object_expression_repeat1,
    STATE(11361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [552950] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14058), 1,
      anon_sym_end,
    STATE(11362), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [553004] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14062), 1,
      anon_sym_let,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(11363), 1,
      sym_attribute,
    STATE(11732), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14060), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [553044] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14058), 1,
      anon_sym_end,
    STATE(11364), 1,
      sym_attribute,
    STATE(11365), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [553098] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14064), 1,
      anon_sym_end,
    STATE(11365), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [553152] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14064), 1,
      anon_sym_end,
    STATE(11366), 1,
      sym_attribute,
    STATE(11367), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [553206] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14066), 1,
      anon_sym_end,
    STATE(11367), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [553260] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11368), 1,
      sym_attribute,
    STATE(12054), 1,
      sym__attribute,
    STATE(12964), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [553314] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14068), 1,
      anon_sym_end,
    STATE(11282), 1,
      aux_sym_object_expression_repeat1,
    STATE(11369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [553368] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14068), 1,
      anon_sym_end,
    STATE(11370), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [553422] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13715), 1,
      anon_sym_end,
    STATE(11371), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [553476] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14070), 1,
      anon_sym_end,
    STATE(11372), 1,
      sym_attribute,
    STATE(11554), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [553530] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14072), 1,
      anon_sym_end,
    STATE(11360), 1,
      aux_sym_object_expression_repeat1,
    STATE(11373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [553584] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11374), 1,
      sym_attribute,
    STATE(12063), 1,
      sym__attribute,
    STATE(13103), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [553638] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14074), 1,
      anon_sym_end,
    STATE(11375), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [553692] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14076), 1,
      anon_sym_end,
    STATE(11376), 1,
      sym_attribute,
    STATE(11377), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [553746] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14078), 1,
      anon_sym_end,
    STATE(11377), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [553800] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14078), 1,
      anon_sym_end,
    STATE(11378), 1,
      sym_attribute,
    STATE(11380), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [553854] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11379), 1,
      sym_attribute,
    STATE(12061), 1,
      sym__attribute,
    STATE(12986), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [553908] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14080), 1,
      anon_sym_end,
    STATE(11380), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [553962] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13632), 1,
      anon_sym_end,
    STATE(11381), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [554016] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14080), 1,
      anon_sym_end,
    STATE(11382), 1,
      sym_attribute,
    STATE(11383), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [554070] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14082), 1,
      anon_sym_end,
    STATE(11383), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [554124] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14084), 1,
      anon_sym_end,
    STATE(11330), 1,
      aux_sym_object_expression_repeat1,
    STATE(11384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [554178] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14086), 1,
      anon_sym_end,
    STATE(11385), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [554232] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14088), 1,
      anon_sym_end,
    STATE(11386), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [554286] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14084), 1,
      anon_sym_end,
    STATE(11387), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [554340] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13755), 1,
      anon_sym_end,
    STATE(11388), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [554394] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14090), 1,
      anon_sym_end,
    STATE(11389), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [554448] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(12438), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14092), 1,
      anon_sym_DASH_GT,
    STATE(11390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12436), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [554486] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13913), 1,
      anon_sym_and,
    ACTIONS(13915), 1,
      sym_let_and_operator,
    STATE(11313), 1,
      aux_sym_value_definition_repeat1,
    STATE(11391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13903), 2,
      anon_sym_let,
      anon_sym_in,
    ACTIONS(13901), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [554526] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11392), 1,
      sym_attribute,
    STATE(12065), 1,
      sym__attribute,
    STATE(12925), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [554580] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14094), 1,
      anon_sym_end,
    STATE(11393), 1,
      sym_attribute,
    STATE(11394), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [554634] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14096), 1,
      anon_sym_end,
    STATE(11394), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [554688] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14098), 1,
      anon_sym_end,
    STATE(11395), 1,
      sym_attribute,
    STATE(11425), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [554742] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14070), 1,
      anon_sym_end,
    STATE(11396), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [554796] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14096), 1,
      anon_sym_end,
    STATE(11397), 1,
      sym_attribute,
    STATE(11398), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [554850] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14100), 1,
      anon_sym_end,
    STATE(11398), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [554904] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14100), 1,
      anon_sym_end,
    STATE(11399), 1,
      sym_attribute,
    STATE(11400), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [554958] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14102), 1,
      anon_sym_end,
    STATE(11400), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [555012] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14104), 1,
      anon_sym_end,
    STATE(11396), 1,
      aux_sym_object_expression_repeat1,
    STATE(11401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [555066] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13905), 1,
      anon_sym_and,
    ACTIONS(13907), 1,
      sym_let_and_operator,
    STATE(11402), 1,
      sym_attribute,
    STATE(11620), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13911), 2,
      anon_sym_let,
      anon_sym_in,
    ACTIONS(13909), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [555106] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14106), 1,
      anon_sym_end,
    STATE(11403), 1,
      sym_attribute,
    STATE(11416), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [555160] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11404), 1,
      sym_attribute,
    STATE(12090), 1,
      sym__attribute,
    STATE(12952), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [555214] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14108), 1,
      anon_sym_end,
    STATE(11405), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [555268] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13793), 1,
      anon_sym_end,
    STATE(11406), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [555322] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11407), 1,
      sym_attribute,
    STATE(12064), 1,
      sym__attribute,
    STATE(13095), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [555376] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13913), 1,
      anon_sym_and,
    ACTIONS(13915), 1,
      sym_let_and_operator,
    STATE(11408), 1,
      sym_attribute,
    STATE(11433), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14112), 2,
      anon_sym_let,
      anon_sym_in,
    ACTIONS(14110), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [555416] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13701), 1,
      anon_sym_end,
    STATE(11409), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [555470] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12693), 1,
      anon_sym_EQ,
    ACTIONS(14114), 1,
      anon_sym_of,
    ACTIONS(14116), 1,
      anon_sym_COLON2,
    STATE(11410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12691), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12689), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [555510] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10919), 1,
      aux_sym_expression_item_repeat1,
    STATE(11411), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14118), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(13745), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [555550] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13705), 1,
      anon_sym_end,
    STATE(11412), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [555604] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14104), 1,
      anon_sym_end,
    STATE(11413), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [555658] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11414), 1,
      sym_attribute,
    STATE(12079), 1,
      sym__attribute,
    STATE(13129), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [555712] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14120), 1,
      anon_sym_end,
    STATE(11415), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [555766] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14122), 1,
      anon_sym_end,
    STATE(11416), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [555820] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12703), 1,
      anon_sym_EQ,
    ACTIONS(14124), 1,
      anon_sym_of,
    ACTIONS(14126), 1,
      anon_sym_COLON2,
    STATE(11417), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12701), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12699), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [555860] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12721), 1,
      anon_sym_EQ,
    ACTIONS(14128), 1,
      anon_sym_of,
    ACTIONS(14130), 1,
      anon_sym_COLON2,
    STATE(11418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12719), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12717), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [555900] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14122), 1,
      anon_sym_end,
    STATE(11419), 1,
      sym_attribute,
    STATE(11422), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [555954] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14132), 1,
      anon_sym_end,
    STATE(11420), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [556008] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14134), 1,
      anon_sym_end,
    STATE(11421), 1,
      sym_attribute,
    STATE(11423), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [556062] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14136), 1,
      anon_sym_end,
    STATE(11422), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [556116] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14138), 1,
      anon_sym_end,
    STATE(11423), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [556170] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14136), 1,
      anon_sym_end,
    STATE(11424), 1,
      sym_attribute,
    STATE(11427), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [556224] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14140), 1,
      anon_sym_end,
    STATE(11425), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [556278] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14140), 1,
      anon_sym_end,
    STATE(11426), 1,
      sym_attribute,
    STATE(11438), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [556332] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14142), 1,
      anon_sym_end,
    STATE(11427), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [556386] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13889), 1,
      anon_sym_else,
    STATE(10470), 1,
      sym_else_clause,
    STATE(11428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [556424] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11429), 1,
      sym_attribute,
    STATE(12095), 1,
      sym__attribute,
    STATE(13088), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [556478] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14144), 1,
      anon_sym_end,
    STATE(11430), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [556532] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14138), 1,
      anon_sym_end,
    STATE(11431), 1,
      sym_attribute,
    STATE(11440), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [556586] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14146), 1,
      anon_sym_end,
    STATE(11413), 1,
      aux_sym_object_expression_repeat1,
    STATE(11432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [556640] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13913), 1,
      anon_sym_and,
    ACTIONS(13915), 1,
      sym_let_and_operator,
    STATE(11312), 1,
      aux_sym_value_definition_repeat1,
    STATE(11433), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13903), 2,
      anon_sym_let,
      anon_sym_in,
    ACTIONS(13901), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [556680] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14148), 1,
      anon_sym_end,
    STATE(11434), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [556734] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13672), 1,
      anon_sym_end,
    STATE(11435), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [556788] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14150), 1,
      anon_sym_end,
    STATE(11436), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [556842] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    ACTIONS(14152), 1,
      anon_sym_RPAREN,
    ACTIONS(14154), 1,
      anon_sym_val,
    STATE(8633), 1,
      sym_module_path,
    STATE(11437), 1,
      sym_attribute,
    STATE(13053), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [556896] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14156), 1,
      anon_sym_end,
    STATE(11438), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [556950] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14156), 1,
      anon_sym_end,
    STATE(11439), 1,
      sym_attribute,
    STATE(11442), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [557004] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14158), 1,
      anon_sym_end,
    STATE(11440), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [557058] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14160), 1,
      anon_sym_end,
    STATE(11441), 1,
      sym_attribute,
    STATE(11581), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [557112] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14162), 1,
      anon_sym_end,
    STATE(11442), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [557166] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13767), 1,
      anon_sym_end,
    STATE(11443), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [557220] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14164), 1,
      anon_sym_end,
    STATE(11444), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [557274] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14158), 1,
      anon_sym_end,
    STATE(11445), 1,
      sym_attribute,
    STATE(11448), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [557328] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13761), 1,
      anon_sym_end,
    STATE(11446), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [557382] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14166), 1,
      anon_sym_end,
    STATE(11370), 1,
      aux_sym_object_expression_repeat1,
    STATE(11447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [557436] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14168), 1,
      anon_sym_end,
    STATE(11448), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [557490] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11449), 1,
      sym_attribute,
    STATE(11957), 1,
      sym__attribute,
    STATE(13128), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [557544] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11268), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(11450), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11266), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [557584] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14172), 1,
      anon_sym_let,
    STATE(11451), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14170), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [557618] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13523), 1,
      anon_sym_DASH_GT,
    ACTIONS(13525), 1,
      anon_sym_with,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(11452), 1,
      sym_attribute,
    STATE(11842), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14174), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [557660] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(12469), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14092), 1,
      anon_sym_DASH_GT,
    STATE(11453), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12467), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [557698] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13822), 1,
      anon_sym_end,
    STATE(11454), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [557752] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14176), 1,
      anon_sym_end,
    STATE(11455), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [557806] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14180), 1,
      anon_sym_let,
    STATE(11456), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14178), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [557840] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14182), 1,
      anon_sym_end,
    STATE(11457), 1,
      sym_attribute,
    STATE(11468), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [557894] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14184), 1,
      anon_sym_end,
    STATE(11455), 1,
      aux_sym_object_expression_repeat1,
    STATE(11458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [557948] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13829), 1,
      anon_sym_end,
    STATE(11459), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [558002] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13965), 1,
      anon_sym_COMMA,
    ACTIONS(13967), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13969), 1,
      sym_pow_operator,
    ACTIONS(13971), 1,
      sym_mult_operator,
    ACTIONS(13973), 1,
      sym_concat_operator,
    ACTIONS(13975), 1,
      sym_rel_operator,
    ACTIONS(13977), 1,
      sym_and_operator,
    ACTIONS(13979), 1,
      sym_or_operator,
    ACTIONS(13981), 1,
      sym_assign_operator,
    ACTIONS(14186), 1,
      anon_sym_SEMI,
    STATE(1966), 1,
      sym_add_operator,
    STATE(11460), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9116), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(9114), 3,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [558060] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11461), 1,
      sym_attribute,
    STATE(12096), 1,
      sym__attribute,
    STATE(12982), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [558114] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14188), 1,
      anon_sym_end,
    STATE(11462), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [558168] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14184), 1,
      anon_sym_end,
    STATE(11463), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [558222] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10937), 1,
      aux_sym_expression_item_repeat1,
    STATE(11464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14190), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(13494), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [558262] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14192), 1,
      anon_sym_end,
    STATE(11465), 1,
      sym_attribute,
    STATE(11466), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [558316] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14194), 1,
      anon_sym_end,
    STATE(11466), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [558370] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14194), 1,
      anon_sym_end,
    STATE(11467), 1,
      sym_attribute,
    STATE(11469), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [558424] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14196), 1,
      anon_sym_end,
    STATE(11468), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [558478] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14198), 1,
      anon_sym_end,
    STATE(11469), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [558532] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14198), 1,
      anon_sym_end,
    STATE(11470), 1,
      sym_attribute,
    STATE(11473), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [558586] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14196), 1,
      anon_sym_end,
    STATE(11471), 1,
      sym_attribute,
    STATE(11472), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [558640] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14200), 1,
      anon_sym_end,
    STATE(11472), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [558694] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14202), 1,
      anon_sym_end,
    STATE(11473), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [558748] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13523), 1,
      anon_sym_DASH_GT,
    ACTIONS(13525), 1,
      anon_sym_with,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10874), 1,
      aux_sym_expression_item_repeat1,
    STATE(11474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13814), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [558790] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12880), 1,
      sym__lowercase_identifier,
    ACTIONS(12882), 1,
      anon_sym_POUND,
    STATE(11040), 1,
      sym_type_constructor_path,
    STATE(11475), 1,
      sym_attribute,
    STATE(17395), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11588), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11590), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [558834] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10344), 1,
      anon_sym_and,
    ACTIONS(14204), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14206), 1,
      sym_pow_operator,
    ACTIONS(14208), 1,
      sym_mult_operator,
    ACTIONS(14210), 1,
      sym_concat_operator,
    ACTIONS(14212), 1,
      sym_rel_operator,
    ACTIONS(14214), 1,
      sym_and_operator,
    ACTIONS(14216), 1,
      sym_or_operator,
    STATE(2314), 1,
      sym_add_operator,
    STATE(11476), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_assign_operator,
      sym_let_and_operator,
  [558886] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14204), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14206), 1,
      sym_pow_operator,
    ACTIONS(14208), 1,
      sym_mult_operator,
    STATE(2314), 1,
      sym_add_operator,
    STATE(11477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 3,
      anon_sym_and,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [558930] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14206), 1,
      sym_pow_operator,
    STATE(2314), 1,
      sym_add_operator,
    STATE(11478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [558968] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14206), 1,
      sym_pow_operator,
    STATE(2314), 1,
      sym_add_operator,
    STATE(11479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [559006] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14204), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14206), 1,
      sym_pow_operator,
    ACTIONS(14208), 1,
      sym_mult_operator,
    ACTIONS(14210), 1,
      sym_concat_operator,
    STATE(2314), 1,
      sym_add_operator,
    STATE(11480), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_and,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [559052] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14204), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14206), 1,
      sym_pow_operator,
    ACTIONS(14208), 1,
      sym_mult_operator,
    ACTIONS(14210), 1,
      sym_concat_operator,
    STATE(2314), 1,
      sym_add_operator,
    STATE(11481), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_and,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [559098] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14204), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14206), 1,
      sym_pow_operator,
    ACTIONS(14208), 1,
      sym_mult_operator,
    ACTIONS(14210), 1,
      sym_concat_operator,
    ACTIONS(14212), 1,
      sym_rel_operator,
    ACTIONS(14214), 1,
      sym_and_operator,
    STATE(2314), 1,
      sym_add_operator,
    STATE(11482), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_and,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_assign_operator,
      sym_let_and_operator,
  [559148] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_and,
    ACTIONS(14204), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14206), 1,
      sym_pow_operator,
    ACTIONS(14208), 1,
      sym_mult_operator,
    ACTIONS(14210), 1,
      sym_concat_operator,
    ACTIONS(14212), 1,
      sym_rel_operator,
    ACTIONS(14214), 1,
      sym_and_operator,
    ACTIONS(14216), 1,
      sym_or_operator,
    STATE(2314), 1,
      sym_add_operator,
    STATE(11483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_assign_operator,
      sym_let_and_operator,
  [559200] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14200), 1,
      anon_sym_end,
    STATE(11484), 1,
      sym_attribute,
    STATE(11491), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [559254] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_and,
    ACTIONS(14204), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14206), 1,
      sym_pow_operator,
    ACTIONS(14208), 1,
      sym_mult_operator,
    ACTIONS(14210), 1,
      sym_concat_operator,
    ACTIONS(14212), 1,
      sym_rel_operator,
    ACTIONS(14214), 1,
      sym_and_operator,
    ACTIONS(14216), 1,
      sym_or_operator,
    ACTIONS(14218), 1,
      anon_sym_COMMA,
    ACTIONS(14220), 1,
      sym_assign_operator,
    STATE(2314), 1,
      sym_add_operator,
    STATE(11485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [559310] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14206), 1,
      sym_pow_operator,
    ACTIONS(14208), 1,
      sym_mult_operator,
    STATE(2314), 1,
      sym_add_operator,
    STATE(11486), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [559350] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10303), 1,
      anon_sym_and,
    ACTIONS(14204), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14206), 1,
      sym_pow_operator,
    ACTIONS(14208), 1,
      sym_mult_operator,
    ACTIONS(14210), 1,
      sym_concat_operator,
    ACTIONS(14212), 1,
      sym_rel_operator,
    ACTIONS(14214), 1,
      sym_and_operator,
    ACTIONS(14216), 1,
      sym_or_operator,
    ACTIONS(14218), 1,
      anon_sym_COMMA,
    ACTIONS(14220), 1,
      sym_assign_operator,
    STATE(2314), 1,
      sym_add_operator,
    STATE(11487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10301), 5,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [559406] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14222), 1,
      anon_sym_else,
    STATE(10470), 1,
      sym_else_clause,
    STATE(11488), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [559444] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12880), 1,
      sym__lowercase_identifier,
    ACTIONS(12882), 1,
      anon_sym_POUND,
    STATE(11040), 1,
      sym_type_constructor_path,
    STATE(11489), 1,
      sym_attribute,
    STATE(17395), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11500), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11502), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [559488] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12511), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14092), 1,
      anon_sym_DASH_GT,
    STATE(11490), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12509), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [559524] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14224), 1,
      anon_sym_end,
    STATE(11491), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [559578] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14226), 1,
      anon_sym_end,
    STATE(11463), 1,
      aux_sym_object_expression_repeat1,
    STATE(11492), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [559632] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10340), 1,
      anon_sym_and,
    ACTIONS(14204), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14206), 1,
      sym_pow_operator,
    ACTIONS(14208), 1,
      sym_mult_operator,
    ACTIONS(14210), 1,
      sym_concat_operator,
    ACTIONS(14212), 1,
      sym_rel_operator,
    ACTIONS(14214), 1,
      sym_and_operator,
    ACTIONS(14216), 1,
      sym_or_operator,
    ACTIONS(14218), 1,
      anon_sym_COMMA,
    ACTIONS(14220), 1,
      sym_assign_operator,
    STATE(2314), 1,
      sym_add_operator,
    STATE(11493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10338), 5,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [559688] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14226), 1,
      anon_sym_end,
    STATE(11494), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [559742] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14228), 1,
      anon_sym_end,
    STATE(11495), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [559796] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13845), 1,
      anon_sym_end,
    STATE(11496), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [559850] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13565), 1,
      anon_sym_end,
    STATE(11497), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [559904] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14230), 1,
      anon_sym_end,
    STATE(11494), 1,
      aux_sym_object_expression_repeat1,
    STATE(11498), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [559958] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14232), 1,
      anon_sym_end,
    STATE(11499), 1,
      sym_attribute,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [560012] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14234), 1,
      anon_sym_constraint,
    ACTIONS(14237), 1,
      anon_sym_val,
    ACTIONS(14240), 1,
      anon_sym_end,
    ACTIONS(14242), 1,
      anon_sym_inherit,
    ACTIONS(14245), 1,
      anon_sym_method,
    ACTIONS(14248), 1,
      anon_sym_initializer,
    ACTIONS(14251), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(14254), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(14257), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11500), 2,
      sym_attribute,
      aux_sym_object_expression_repeat1,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [560064] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14260), 1,
      anon_sym_end,
    STATE(11495), 1,
      aux_sym_object_expression_repeat1,
    STATE(11501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [560118] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11502), 1,
      sym_attribute,
    STATE(12117), 1,
      sym__attribute,
    STATE(13118), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [560172] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13529), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11503), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [560226] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14260), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [560280] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13849), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11505), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [560334] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14262), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [560388] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12880), 1,
      sym__lowercase_identifier,
    ACTIONS(12882), 1,
      anon_sym_POUND,
    STATE(11040), 1,
      sym_type_constructor_path,
    STATE(11507), 1,
      sym_attribute,
    STATE(17395), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11720), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11722), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [560432] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14264), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11508), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [560486] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14266), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11509), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [560540] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12428), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(13543), 1,
      anon_sym_DASH_GT,
    STATE(11510), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12426), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [560578] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14268), 1,
      anon_sym_end,
    STATE(11508), 1,
      aux_sym_object_expression_repeat1,
    STATE(11511), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [560632] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14268), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11512), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [560686] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14270), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11513), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [560740] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13267), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14272), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11514), 2,
      sym_attribute,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(13265), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [560776] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12880), 1,
      sym__lowercase_identifier,
    ACTIONS(12882), 1,
      anon_sym_POUND,
    STATE(11040), 1,
      sym_type_constructor_path,
    STATE(11515), 1,
      sym_attribute,
    STATE(17395), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12278), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12280), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [560820] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14275), 1,
      anon_sym_end,
    STATE(11516), 1,
      sym_attribute,
    STATE(11524), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [560874] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12880), 1,
      sym__lowercase_identifier,
    ACTIONS(12882), 1,
      anon_sym_POUND,
    STATE(11040), 1,
      sym_type_constructor_path,
    STATE(11517), 1,
      sym_attribute,
    STATE(17395), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12303), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12305), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [560918] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14277), 1,
      anon_sym_end,
    STATE(11504), 1,
      aux_sym_object_expression_repeat1,
    STATE(11518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [560972] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14277), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11519), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [561026] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11520), 1,
      sym_attribute,
    STATE(12165), 1,
      sym__attribute,
    STATE(13041), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [561080] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14279), 1,
      anon_sym_end,
    STATE(11512), 1,
      aux_sym_object_expression_repeat1,
    STATE(11521), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [561134] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14279), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11522), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [561188] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11523), 1,
      sym_attribute,
    STATE(11967), 1,
      sym__attribute,
    STATE(13119), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [561242] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14281), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11524), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [561296] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14281), 1,
      anon_sym_end,
    STATE(11525), 1,
      sym_attribute,
    STATE(11526), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [561350] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14283), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11526), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [561404] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14285), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11527), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [561458] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14283), 1,
      anon_sym_end,
    STATE(11528), 1,
      sym_attribute,
    STATE(11539), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [561512] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    ACTIONS(14287), 1,
      anon_sym_RPAREN,
    ACTIONS(14289), 1,
      anon_sym_val,
    STATE(8633), 1,
      sym_module_path,
    STATE(11529), 1,
      sym_attribute,
    STATE(13022), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [561566] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14144), 1,
      anon_sym_end,
    STATE(11436), 1,
      aux_sym_object_expression_repeat1,
    STATE(11530), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [561620] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14291), 1,
      anon_sym_end,
    STATE(11531), 1,
      sym_attribute,
    STATE(11534), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [561674] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13727), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11532), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [561728] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14293), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11533), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [561782] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14295), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [561836] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13588), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11535), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [561890] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14295), 1,
      anon_sym_end,
    STATE(11536), 1,
      sym_attribute,
    STATE(11540), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [561944] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12087), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14297), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11537), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(12085), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [561980] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12313), 1,
      anon_sym_STAR,
    ACTIONS(13445), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(11537), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(11538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13443), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [562018] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14300), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11539), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562072] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14302), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11540), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562126] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14302), 1,
      anon_sym_end,
    STATE(11541), 1,
      sym_attribute,
    STATE(11549), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562180] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12880), 1,
      sym__lowercase_identifier,
    ACTIONS(12882), 1,
      anon_sym_POUND,
    STATE(11040), 1,
      sym_type_constructor_path,
    STATE(11542), 1,
      sym_attribute,
    STATE(17395), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12242), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12244), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [562224] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11543), 1,
      sym_attribute,
    STATE(12185), 1,
      sym__attribute,
    STATE(13121), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [562278] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11544), 1,
      sym_attribute,
    STATE(12156), 1,
      sym__attribute,
    STATE(13069), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [562332] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14304), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562386] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13812), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11546), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562440] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14306), 1,
      anon_sym_end,
    STATE(11545), 1,
      aux_sym_object_expression_repeat1,
    STATE(11547), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562494] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14306), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562548] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14308), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11549), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562602] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14310), 1,
      anon_sym_end,
    STATE(11548), 1,
      aux_sym_object_expression_repeat1,
    STATE(11550), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562656] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14312), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11551), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562710] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14310), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11552), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562764] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13404), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13921), 1,
      anon_sym_DASH_GT,
    ACTIONS(13923), 1,
      anon_sym_with,
    STATE(11553), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13402), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [562802] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14314), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562856] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14316), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11555), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562910] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14316), 1,
      anon_sym_end,
    STATE(11556), 1,
      sym_attribute,
    STATE(11561), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562964] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12284), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14318), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11557), 2,
      sym_attribute,
      aux_sym_type_binding_repeat1,
    ACTIONS(12282), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [563002] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11558), 1,
      sym_attribute,
    STATE(12180), 1,
      sym__attribute,
    STATE(13063), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [563056] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14321), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11559), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [563110] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14323), 1,
      anon_sym_PIPE,
    STATE(11560), 1,
      sym_attribute,
    STATE(11709), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13628), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13626), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [563148] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14325), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11561), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [563202] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14327), 1,
      anon_sym_end,
    STATE(11522), 1,
      aux_sym_object_expression_repeat1,
    STATE(11562), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [563256] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14329), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11563), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [563310] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8596), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8598), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13610), 1,
      anon_sym_LPAREN,
    ACTIONS(13614), 1,
      anon_sym_functor,
    ACTIONS(13616), 1,
      anon_sym_struct,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13620), 1,
      sym__uppercase_identifier,
    STATE(11564), 1,
      sym_attribute,
    STATE(11908), 1,
      sym__attribute,
    STATE(12915), 1,
      sym__module_expression,
    STATE(13140), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13223), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(13238), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [563364] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14331), 1,
      anon_sym_end,
    STATE(11563), 1,
      aux_sym_object_expression_repeat1,
    STATE(11565), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [563418] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13647), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [563472] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14325), 1,
      anon_sym_end,
    STATE(11567), 1,
      sym_attribute,
    STATE(11571), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [563526] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14331), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11568), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [563580] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12075), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13855), 1,
      anon_sym_PIPE,
    STATE(11569), 1,
      sym_attribute,
    STATE(11720), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12073), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [563618] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13905), 1,
      anon_sym_and,
    ACTIONS(13907), 1,
      sym_let_and_operator,
    STATE(11247), 1,
      aux_sym_value_definition_repeat1,
    STATE(11570), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14112), 2,
      anon_sym_let,
      anon_sym_in,
    ACTIONS(14110), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [563658] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14333), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [563712] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14335), 1,
      anon_sym_end,
    STATE(11387), 1,
      aux_sym_object_expression_repeat1,
    STATE(11572), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [563766] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14339), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(11573), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14337), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [563806] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13905), 1,
      anon_sym_and,
    ACTIONS(13907), 1,
      sym_let_and_operator,
    STATE(11402), 1,
      aux_sym_value_definition_repeat1,
    STATE(11574), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13957), 2,
      anon_sym_let,
      anon_sym_in,
    ACTIONS(13955), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [563846] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14341), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11575), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [563900] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14343), 1,
      anon_sym_end,
    STATE(11568), 1,
      aux_sym_object_expression_repeat1,
    STATE(11576), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [563954] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14345), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11577), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564008] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14347), 1,
      anon_sym_PIPE,
    STATE(11578), 1,
      sym_attribute,
    STATE(11696), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13628), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13626), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [564046] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14349), 1,
      anon_sym_end,
    STATE(11519), 1,
      aux_sym_object_expression_repeat1,
    STATE(11579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564100] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14351), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11580), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [564136] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14354), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11581), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564190] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13735), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11582), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564244] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14356), 1,
      anon_sym_PIPE,
    STATE(11580), 1,
      aux_sym__match_cases_repeat1,
    STATE(11583), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [564282] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14356), 1,
      anon_sym_PIPE,
    STATE(11580), 1,
      aux_sym__match_cases_repeat1,
    STATE(11584), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [564320] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11585), 1,
      sym_attribute,
    STATE(11901), 1,
      sym__attribute,
    STATE(12990), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [564374] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14358), 1,
      anon_sym_end,
    STATE(11586), 1,
      sym_attribute,
    STATE(11604), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564428] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14356), 1,
      anon_sym_PIPE,
    STATE(11583), 1,
      aux_sym__match_cases_repeat1,
    STATE(11587), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [564466] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14360), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11588), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564520] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13455), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13921), 1,
      anon_sym_DASH_GT,
    ACTIONS(13923), 1,
      anon_sym_with,
    STATE(11589), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13453), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [564558] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14362), 1,
      anon_sym_end,
    STATE(11552), 1,
      aux_sym_object_expression_repeat1,
    STATE(11590), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564612] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14364), 1,
      anon_sym_end,
    STATE(11591), 1,
      sym_attribute,
    STATE(11593), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564666] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11592), 1,
      sym_attribute,
    STATE(12204), 1,
      sym__attribute,
    STATE(13106), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [564720] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14366), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11593), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564774] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14366), 1,
      anon_sym_end,
    STATE(11594), 1,
      sym_attribute,
    STATE(11596), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564828] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14356), 1,
      anon_sym_PIPE,
    STATE(11584), 1,
      aux_sym__match_cases_repeat1,
    STATE(11595), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [564866] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14368), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11596), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564920] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14368), 1,
      anon_sym_end,
    STATE(11597), 1,
      sym_attribute,
    STATE(11598), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564974] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14370), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11598), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565028] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14343), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11599), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565082] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14323), 1,
      anon_sym_PIPE,
    STATE(11600), 1,
      sym_attribute,
    STATE(11710), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12075), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12073), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [565120] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14160), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11601), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565174] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11602), 1,
      sym_attribute,
    STATE(12045), 1,
      sym__attribute,
    STATE(13137), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [565228] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10332), 1,
      anon_sym_and,
    ACTIONS(14204), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14206), 1,
      sym_pow_operator,
    ACTIONS(14208), 1,
      sym_mult_operator,
    ACTIONS(14210), 1,
      sym_concat_operator,
    ACTIONS(14212), 1,
      sym_rel_operator,
    ACTIONS(14214), 1,
      sym_and_operator,
    ACTIONS(14216), 1,
      sym_or_operator,
    ACTIONS(14218), 1,
      anon_sym_COMMA,
    ACTIONS(14220), 1,
      sym_assign_operator,
    STATE(2314), 1,
      sym_add_operator,
    STATE(11603), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10330), 5,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [565284] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14372), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11604), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565338] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14372), 1,
      anon_sym_end,
    STATE(11605), 1,
      sym_attribute,
    STATE(11638), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565392] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14374), 1,
      anon_sym_end,
    STATE(11599), 1,
      aux_sym_object_expression_repeat1,
    STATE(11606), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565446] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14376), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565500] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14378), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11608), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565554] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14380), 1,
      anon_sym_end,
    STATE(11607), 1,
      aux_sym_object_expression_repeat1,
    STATE(11609), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565608] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14380), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11610), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565662] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14382), 1,
      anon_sym_end,
    STATE(11610), 1,
      aux_sym_object_expression_repeat1,
    STATE(11611), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565716] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14382), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11612), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565770] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14384), 1,
      anon_sym_end,
    STATE(11613), 1,
      sym_attribute,
    STATE(11642), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565824] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14386), 1,
      anon_sym_end,
    STATE(11612), 1,
      aux_sym_object_expression_repeat1,
    STATE(11614), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565878] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14388), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11615), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565932] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14390), 1,
      anon_sym_end,
    STATE(11616), 1,
      sym_attribute,
    STATE(11687), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565986] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13668), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11617), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566040] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13853), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11618), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566094] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14392), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11619), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566148] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14394), 1,
      anon_sym_and,
    ACTIONS(14397), 1,
      sym_let_and_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14003), 2,
      anon_sym_let,
      anon_sym_in,
    STATE(11620), 2,
      sym_attribute,
      aux_sym_value_definition_repeat1,
    ACTIONS(14001), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [566186] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11621), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14003), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(14001), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [566220] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11622), 1,
      sym_attribute,
    STATE(12207), 1,
      sym__attribute,
    STATE(12963), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [566274] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14400), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11623), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566328] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14402), 1,
      anon_sym_end,
    STATE(11624), 1,
      sym_attribute,
    STATE(11636), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566382] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11625), 1,
      sym_attribute,
    STATE(12194), 1,
      sym__attribute,
    STATE(12961), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [566436] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14404), 1,
      anon_sym_end,
    STATE(11623), 1,
      aux_sym_object_expression_repeat1,
    STATE(11626), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566490] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14404), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11627), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566544] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2314), 1,
      sym_add_operator,
    STATE(11628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [566580] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14406), 1,
      anon_sym_end,
    STATE(11627), 1,
      aux_sym_object_expression_repeat1,
    STATE(11629), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566634] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14406), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11630), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566688] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14222), 1,
      anon_sym_else,
    STATE(10654), 1,
      sym_else_clause,
    STATE(11631), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [566726] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12691), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12693), 1,
      anon_sym_EQ,
    ACTIONS(14408), 1,
      anon_sym_of,
    ACTIONS(14410), 1,
      anon_sym_COLON2,
    STATE(11632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12689), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [566766] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14347), 1,
      anon_sym_PIPE,
    STATE(11578), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(11633), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12075), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12073), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [566804] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13905), 1,
      anon_sym_and,
    ACTIONS(13907), 1,
      sym_let_and_operator,
    STATE(11620), 1,
      aux_sym_value_definition_repeat1,
    STATE(11634), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13957), 2,
      anon_sym_let,
      anon_sym_in,
    ACTIONS(13955), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [566844] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14412), 1,
      anon_sym_end,
    STATE(11630), 1,
      aux_sym_object_expression_repeat1,
    STATE(11635), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566898] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14414), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566952] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14414), 1,
      anon_sym_end,
    STATE(11637), 1,
      sym_attribute,
    STATE(11644), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567006] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14416), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567060] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12701), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12703), 1,
      anon_sym_EQ,
    ACTIONS(14418), 1,
      anon_sym_of,
    ACTIONS(14420), 1,
      anon_sym_COLON2,
    STATE(11639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12699), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [567100] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14422), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11640), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567154] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12719), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12721), 1,
      anon_sym_EQ,
    ACTIONS(14424), 1,
      anon_sym_of,
    ACTIONS(14426), 1,
      anon_sym_COLON2,
    STATE(11641), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12717), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [567194] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14428), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11642), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567248] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14428), 1,
      anon_sym_end,
    STATE(11643), 1,
      sym_attribute,
    STATE(11655), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567302] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14430), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567356] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14430), 1,
      anon_sym_end,
    STATE(11645), 1,
      sym_attribute,
    STATE(11646), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567410] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14432), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11646), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567464] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14434), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11647), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567518] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13350), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13921), 1,
      anon_sym_DASH_GT,
    ACTIONS(13923), 1,
      anon_sym_with,
    STATE(11648), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13348), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [567556] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13841), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567610] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14436), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11650), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567664] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13517), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11651), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567718] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14416), 1,
      anon_sym_end,
    STATE(11652), 1,
      sym_attribute,
    STATE(11667), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567772] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14438), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567826] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13723), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11654), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567880] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14440), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567934] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14440), 1,
      anon_sym_end,
    STATE(11656), 1,
      sym_attribute,
    STATE(11659), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567988] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14442), 1,
      anon_sym_end,
    STATE(11657), 1,
      sym_attribute,
    STATE(11660), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568042] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14347), 1,
      anon_sym_PIPE,
    STATE(11658), 1,
      sym_attribute,
    STATE(11691), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13628), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13626), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [568080] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14444), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11659), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568134] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14446), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11660), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568188] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13783), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11661), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568242] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14446), 1,
      anon_sym_end,
    STATE(11662), 1,
      sym_attribute,
    STATE(11664), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568296] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11663), 1,
      sym_attribute,
    STATE(12177), 1,
      sym__attribute,
    STATE(12995), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [568350] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14448), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11664), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568404] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14448), 1,
      anon_sym_end,
    STATE(11665), 1,
      sym_attribute,
    STATE(11666), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568458] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14450), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11666), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568512] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14452), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568566] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13510), 1,
      anon_sym_let,
    STATE(11668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13508), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [568600] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14454), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568654] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14456), 1,
      anon_sym_end,
    STATE(11669), 1,
      aux_sym_object_expression_repeat1,
    STATE(11670), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568708] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14456), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11671), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568762] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11672), 1,
      sym_attribute,
    STATE(12047), 1,
      sym__attribute,
    STATE(12971), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [568816] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12721), 1,
      anon_sym_EQ,
    ACTIONS(14458), 1,
      anon_sym_of,
    ACTIONS(14460), 1,
      anon_sym_COLON2,
    STATE(11673), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12719), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12717), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [568856] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12703), 1,
      anon_sym_EQ,
    ACTIONS(14462), 1,
      anon_sym_of,
    ACTIONS(14464), 1,
      anon_sym_COLON2,
    STATE(11674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12701), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12699), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [568896] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14466), 1,
      anon_sym_end,
    STATE(11671), 1,
      aux_sym_object_expression_repeat1,
    STATE(11675), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568950] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14466), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11676), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569004] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9116), 1,
      anon_sym_and,
    ACTIONS(14204), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14206), 1,
      sym_pow_operator,
    ACTIONS(14208), 1,
      sym_mult_operator,
    ACTIONS(14210), 1,
      sym_concat_operator,
    ACTIONS(14212), 1,
      sym_rel_operator,
    ACTIONS(14214), 1,
      sym_and_operator,
    ACTIONS(14216), 1,
      sym_or_operator,
    ACTIONS(14218), 1,
      anon_sym_COMMA,
    ACTIONS(14220), 1,
      sym_assign_operator,
    ACTIONS(14468), 1,
      anon_sym_SEMI,
    STATE(2314), 1,
      sym_add_operator,
    STATE(11677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9114), 4,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [569062] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12693), 1,
      anon_sym_EQ,
    ACTIONS(14470), 1,
      anon_sym_of,
    ACTIONS(14472), 1,
      anon_sym_COLON2,
    STATE(11678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12691), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12689), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [569102] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13521), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11679), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569156] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14474), 1,
      anon_sym_end,
    STATE(11676), 1,
      aux_sym_object_expression_repeat1,
    STATE(11680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569210] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13686), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11681), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569264] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11682), 1,
      sym_attribute,
    STATE(12138), 1,
      sym__attribute,
    STATE(13067), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [569318] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13711), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569372] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11684), 1,
      sym_attribute,
    STATE(12144), 1,
      sym__attribute,
    STATE(12930), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [569426] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14476), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11685), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569480] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14478), 1,
      anon_sym_end,
    STATE(11601), 1,
      aux_sym_object_expression_repeat1,
    STATE(11686), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569534] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14480), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11687), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569588] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14480), 1,
      anon_sym_end,
    STATE(11688), 1,
      sym_attribute,
    STATE(11727), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569642] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14482), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11689), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569696] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13596), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11690), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569750] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14347), 1,
      anon_sym_PIPE,
    STATE(11691), 1,
      sym_attribute,
    STATE(11696), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13680), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13678), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [569788] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13628), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13855), 1,
      anon_sym_PIPE,
    STATE(11209), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(11692), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13626), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [569826] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13578), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11693), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569880] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13537), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11694), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569934] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14484), 1,
      anon_sym_end,
    STATE(11695), 1,
      sym_attribute,
    STATE(11697), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569988] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14486), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13267), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(11696), 2,
      sym_attribute,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(13265), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [570024] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14489), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11697), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570078] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14491), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11698), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570132] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14493), 1,
      anon_sym_RPAREN,
    ACTIONS(14495), 1,
      anon_sym_DOT,
    STATE(11699), 1,
      sym_attribute,
    STATE(18915), 1,
      sym__infix_operator,
    STATE(20475), 1,
      sym_add_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1469), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(1471), 3,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
    ACTIONS(1467), 4,
      sym_mult_operator,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(14497), 5,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym_match_operator,
  [570178] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14489), 1,
      anon_sym_end,
    STATE(11700), 1,
      sym_attribute,
    STATE(11702), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570232] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14499), 1,
      anon_sym_end,
    STATE(11701), 1,
      sym_attribute,
    STATE(11728), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570286] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14501), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570340] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14501), 1,
      anon_sym_end,
    STATE(11703), 1,
      sym_attribute,
    STATE(11704), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570394] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14503), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11704), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570448] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11264), 1,
      anon_sym_COLON2,
    STATE(11705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9158), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(9160), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [570484] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13523), 1,
      anon_sym_DASH_GT,
    ACTIONS(13525), 1,
      anon_sym_with,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10717), 1,
      aux_sym_expression_item_repeat1,
    STATE(11706), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13795), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [570526] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(11707), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8961), 9,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
      aux_sym_attribute_id_token1,
    ACTIONS(8959), 10,
      anon_sym_rec,
      anon_sym_nonrec,
      anon_sym__,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_virtual,
      anon_sym_functor,
      anon_sym_struct,
      sym__lowercase_identifier,
  [570560] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14505), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13267), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(11708), 2,
      sym_attribute,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(13265), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [570596] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14323), 1,
      anon_sym_PIPE,
    STATE(11708), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(11709), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13680), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13678), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [570634] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14323), 1,
      anon_sym_PIPE,
    STATE(11708), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(11710), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13628), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13626), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [570672] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11711), 1,
      sym_attribute,
    STATE(12137), 1,
      sym__attribute,
    STATE(12973), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [570726] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14508), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11712), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570780] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(13600), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11713), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570834] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14510), 1,
      anon_sym_end,
    STATE(11712), 1,
      aux_sym_object_expression_repeat1,
    STATE(11714), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570888] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14510), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11715), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570942] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14512), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11716), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570996] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14514), 1,
      anon_sym_end,
    STATE(11715), 1,
      aux_sym_object_expression_repeat1,
    STATE(11717), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571050] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14514), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11718), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571104] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14516), 1,
      anon_sym_end,
    STATE(11719), 1,
      sym_attribute,
    STATE(11722), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571158] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13628), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13855), 1,
      anon_sym_PIPE,
    STATE(11514), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(11720), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13626), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [571196] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14518), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11721), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571250] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14520), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11722), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571304] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14520), 1,
      anon_sym_end,
    STATE(11723), 1,
      sym_attribute,
    STATE(11730), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571358] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14522), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11724), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571412] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14524), 1,
      anon_sym_end,
    STATE(11724), 1,
      aux_sym_object_expression_repeat1,
    STATE(11725), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571466] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14526), 1,
      anon_sym_end,
    STATE(11718), 1,
      aux_sym_object_expression_repeat1,
    STATE(11726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571520] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14524), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11727), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571574] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14478), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11728), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571628] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14528), 1,
      anon_sym_end,
    STATE(11721), 1,
      aux_sym_object_expression_repeat1,
    STATE(11729), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571682] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14528), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11730), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571736] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12548), 1,
      anon_sym_constraint,
    ACTIONS(12550), 1,
      anon_sym_val,
    ACTIONS(12554), 1,
      anon_sym_inherit,
    ACTIONS(12556), 1,
      anon_sym_method,
    ACTIONS(12558), 1,
      anon_sym_initializer,
    ACTIONS(14530), 1,
      anon_sym_end,
    STATE(11500), 1,
      aux_sym_object_expression_repeat1,
    STATE(11731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13405), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(13403), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571790] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14534), 1,
      anon_sym_let,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(11732), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14532), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [571830] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5223), 1,
      aux_sym_number_token1,
    ACTIONS(5225), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5227), 1,
      anon_sym_SQUOTE,
    ACTIONS(5229), 1,
      anon_sym_DQUOTE,
    ACTIONS(14536), 1,
      anon_sym_LPAREN,
    ACTIONS(14540), 1,
      anon_sym_LBRACE,
    ACTIONS(14542), 1,
      anon_sym_begin,
    STATE(5635), 1,
      sym__signed_constant,
    STATE(11733), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14538), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5523), 2,
      sym__constant,
      sym_signed_number,
    STATE(5445), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
  [571881] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11734), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8350), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(8352), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [571914] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7197), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10544), 1,
      aux_sym_expression_item_repeat1,
    STATE(11735), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6897), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [571953] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14544), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10655), 1,
      aux_sym_expression_item_repeat1,
    STATE(11736), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12936), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [571992] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14546), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10507), 1,
      aux_sym_expression_item_repeat1,
    STATE(11737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13301), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [572031] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7273), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10495), 1,
      aux_sym_expression_item_repeat1,
    STATE(11738), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7109), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [572070] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13628), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14548), 1,
      anon_sym_PIPE,
    STATE(11739), 1,
      sym_attribute,
    STATE(11812), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13626), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [572107] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11740), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(8364), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [572140] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11741), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(8360), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [572173] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11742), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(8356), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [572206] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14550), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10436), 1,
      aux_sym_expression_item_repeat1,
    STATE(11743), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13063), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [572245] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7255), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10434), 1,
      aux_sym_expression_item_repeat1,
    STATE(11744), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7099), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [572284] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14552), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10409), 1,
      aux_sym_expression_item_repeat1,
    STATE(11745), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12795), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [572323] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7253), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10405), 1,
      aux_sym_expression_item_repeat1,
    STATE(11746), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7133), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [572362] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7279), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10705), 1,
      aux_sym_expression_item_repeat1,
    STATE(11747), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [572401] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5125), 1,
      anon_sym_DOT,
    STATE(11748), 1,
      sym_attribute,
    STATE(18720), 1,
      sym__infix_operator,
    STATE(20475), 1,
      sym_add_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1469), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(1471), 3,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
    ACTIONS(1467), 4,
      sym_mult_operator,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(5131), 5,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym_match_operator,
  [572444] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14554), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10655), 1,
      aux_sym_expression_item_repeat1,
    STATE(11749), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12936), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [572483] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14556), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10382), 1,
      aux_sym_expression_item_repeat1,
    STATE(11750), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12681), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [572522] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13903), 1,
      anon_sym_let,
    ACTIONS(14558), 1,
      anon_sym_and,
    ACTIONS(14560), 1,
      sym_let_and_operator,
    STATE(11751), 1,
      sym_attribute,
    STATE(11757), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13901), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [572561] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5101), 1,
      aux_sym_number_token1,
    ACTIONS(5103), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5105), 1,
      anon_sym_SQUOTE,
    ACTIONS(5107), 1,
      anon_sym_DQUOTE,
    ACTIONS(14562), 1,
      anon_sym_LPAREN,
    ACTIONS(14566), 1,
      anon_sym_LBRACE,
    ACTIONS(14568), 1,
      anon_sym_begin,
    STATE(5505), 1,
      sym__signed_constant,
    STATE(11752), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14564), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5356), 2,
      sym__constant,
      sym_signed_number,
    STATE(5423), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
  [572612] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(11753), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14570), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [572649] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(10263), 1,
      anon_sym_as,
    ACTIONS(14572), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    STATE(11754), 1,
      sym_attribute,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10261), 12,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
  [572692] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13957), 1,
      anon_sym_let,
    ACTIONS(14558), 1,
      anon_sym_and,
    ACTIONS(14560), 1,
      sym_let_and_operator,
    STATE(11755), 1,
      sym_attribute,
    STATE(11757), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13955), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [572731] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13921), 1,
      anon_sym_DASH_GT,
    ACTIONS(13923), 1,
      anon_sym_with,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(11756), 1,
      sym_attribute,
    STATE(11823), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13991), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [572772] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14003), 1,
      anon_sym_let,
    ACTIONS(14576), 1,
      anon_sym_and,
    ACTIONS(14579), 1,
      sym_let_and_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11757), 2,
      sym_attribute,
      aux_sym_value_definition_repeat1,
    ACTIONS(14001), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [572809] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14582), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11758), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [572844] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14585), 1,
      anon_sym_PIPE,
    STATE(11758), 1,
      aux_sym__match_cases_repeat1,
    STATE(11759), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [572881] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14585), 1,
      anon_sym_PIPE,
    STATE(11758), 1,
      aux_sym__match_cases_repeat1,
    STATE(11760), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [572918] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14585), 1,
      anon_sym_PIPE,
    STATE(11759), 1,
      aux_sym__match_cases_repeat1,
    STATE(11761), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [572955] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14585), 1,
      anon_sym_PIPE,
    STATE(11760), 1,
      aux_sym__match_cases_repeat1,
    STATE(11762), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [572992] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13957), 1,
      anon_sym_let,
    ACTIONS(14558), 1,
      anon_sym_and,
    ACTIONS(14560), 1,
      sym_let_and_operator,
    STATE(11763), 1,
      sym_attribute,
    STATE(11786), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13955), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [573031] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11130), 1,
      anon_sym_as,
    ACTIONS(14572), 1,
      sym__lowercase_identifier,
    ACTIONS(14587), 1,
      anon_sym_POUND,
    STATE(11764), 1,
      sym_attribute,
    STATE(12378), 1,
      sym_type_constructor_path,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11128), 12,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
  [573074] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11126), 1,
      anon_sym_as,
    ACTIONS(14572), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    STATE(11765), 1,
      sym_attribute,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11124), 12,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
  [573117] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14589), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10382), 1,
      aux_sym_expression_item_repeat1,
    STATE(11766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12681), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [573156] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7271), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10405), 1,
      aux_sym_expression_item_repeat1,
    STATE(11767), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7133), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [573195] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14591), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10409), 1,
      aux_sym_expression_item_repeat1,
    STATE(11768), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12795), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [573234] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7201), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10434), 1,
      aux_sym_expression_item_repeat1,
    STATE(11769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7099), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [573273] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14593), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10436), 1,
      aux_sym_expression_item_repeat1,
    STATE(11770), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13063), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [573312] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11771), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11638), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11640), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [573345] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7281), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10544), 1,
      aux_sym_expression_item_repeat1,
    STATE(11772), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6897), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [573384] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11560), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11562), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [573417] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14595), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10655), 1,
      aux_sym_expression_item_repeat1,
    STATE(11774), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12936), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [573456] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11775), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11576), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11578), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [573489] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11538), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11540), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [573522] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11777), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11534), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11536), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [573555] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14597), 1,
      anon_sym_else,
    STATE(10470), 1,
      sym_else_clause,
    STATE(11778), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [573592] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13903), 1,
      anon_sym_let,
    ACTIONS(14599), 1,
      anon_sym_and,
    ACTIONS(14601), 1,
      sym_let_and_operator,
    STATE(11779), 1,
      sym_attribute,
    STATE(11890), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13901), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [573631] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14603), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10507), 1,
      aux_sym_expression_item_repeat1,
    STATE(11780), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13301), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [573670] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7245), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10495), 1,
      aux_sym_expression_item_repeat1,
    STATE(11781), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7109), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [573709] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(11782), 1,
      sym_attribute,
    STATE(11881), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14605), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [573746] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14112), 1,
      anon_sym_let,
    ACTIONS(14599), 1,
      anon_sym_and,
    ACTIONS(14601), 1,
      sym_let_and_operator,
    STATE(11783), 1,
      sym_attribute,
    STATE(11889), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14110), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [573785] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7239), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10705), 1,
      aux_sym_expression_item_repeat1,
    STATE(11784), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [573824] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11785), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11704), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11706), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [573857] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13911), 1,
      anon_sym_let,
    ACTIONS(14558), 1,
      anon_sym_and,
    ACTIONS(14560), 1,
      sym_let_and_operator,
    STATE(11757), 1,
      aux_sym_value_definition_repeat1,
    STATE(11786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13909), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [573896] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12075), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14548), 1,
      anon_sym_PIPE,
    STATE(11739), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(11787), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12073), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [573933] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6887), 1,
      anon_sym_DOT,
    STATE(11788), 1,
      sym_attribute,
    STATE(18636), 1,
      sym__infix_operator,
    STATE(20475), 1,
      sym_add_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1469), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(1471), 3,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
    ACTIONS(1467), 4,
      sym_mult_operator,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(6893), 5,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym_match_operator,
  [573976] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11789), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11600), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11602), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [574009] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11474), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11476), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [574042] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9116), 1,
      anon_sym_PIPE,
    ACTIONS(14607), 1,
      anon_sym_COMMA,
    ACTIONS(14609), 1,
      anon_sym_SEMI,
    ACTIONS(14611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14613), 1,
      sym_pow_operator,
    ACTIONS(14615), 1,
      sym_mult_operator,
    ACTIONS(14617), 1,
      sym_concat_operator,
    ACTIONS(14619), 1,
      sym_rel_operator,
    ACTIONS(14621), 1,
      sym_and_operator,
    ACTIONS(14623), 1,
      sym_or_operator,
    ACTIONS(14625), 1,
      sym_assign_operator,
    STATE(2022), 1,
      sym_add_operator,
    STATE(11791), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9114), 3,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [574099] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11792), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11795), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11797), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [574132] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13628), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14548), 1,
      anon_sym_PIPE,
    STATE(11793), 1,
      sym_attribute,
    STATE(11811), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13626), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [574169] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11794), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11642), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11644), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [574202] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6841), 1,
      anon_sym_DOT,
    STATE(11795), 1,
      sym_attribute,
    STATE(18810), 1,
      sym__infix_operator,
    STATE(20475), 1,
      sym_add_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1469), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(1471), 3,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
    ACTIONS(1467), 4,
      sym_mult_operator,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(6853), 5,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym_match_operator,
  [574245] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7243), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10705), 1,
      aux_sym_expression_item_repeat1,
    STATE(11796), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [574284] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11632), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11634), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [574317] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11798), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11550), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11552), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [574350] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11799), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11414), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11416), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [574383] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12284), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14627), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11800), 2,
      sym_attribute,
      aux_sym_type_binding_repeat1,
    ACTIONS(12282), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [574420] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14597), 1,
      anon_sym_else,
    STATE(10654), 1,
      sym_else_clause,
    STATE(11801), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [574457] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11802), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11446), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11448), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [574490] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11470), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11472), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [574523] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11804), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11508), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11510), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [574556] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10393), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14630), 1,
      anon_sym_STAR,
    STATE(11805), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10391), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [574591] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11806), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11692), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11694), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [574624] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11807), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11438), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11440), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [574657] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11808), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11442), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11444), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [574690] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11809), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11763), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11765), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [574723] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9116), 1,
      anon_sym_and,
    ACTIONS(14632), 1,
      anon_sym_COMMA,
    ACTIONS(14634), 1,
      anon_sym_SEMI,
    ACTIONS(14636), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14638), 1,
      sym_pow_operator,
    ACTIONS(14640), 1,
      sym_mult_operator,
    ACTIONS(14642), 1,
      sym_concat_operator,
    ACTIONS(14644), 1,
      sym_rel_operator,
    ACTIONS(14646), 1,
      sym_and_operator,
    ACTIONS(14648), 1,
      sym_or_operator,
    ACTIONS(14650), 1,
      sym_assign_operator,
    STATE(2033), 1,
      sym_add_operator,
    STATE(11810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9114), 3,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [574780] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13680), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14548), 1,
      anon_sym_PIPE,
    STATE(11811), 1,
      sym_attribute,
    STATE(11812), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13678), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [574817] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13267), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14652), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11812), 2,
      sym_attribute,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(13265), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [574852] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11813), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11676), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11678), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [574885] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11814), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11478), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11480), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [574918] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5267), 1,
      aux_sym_number_token1,
    ACTIONS(5269), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5271), 1,
      anon_sym_SQUOTE,
    ACTIONS(5273), 1,
      anon_sym_DQUOTE,
    ACTIONS(14655), 1,
      anon_sym_LPAREN,
    ACTIONS(14659), 1,
      anon_sym_LBRACE,
    ACTIONS(14661), 1,
      anon_sym_begin,
    STATE(5696), 1,
      sym__signed_constant,
    STATE(11815), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14657), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5522), 2,
      sym__constant,
      sym_signed_number,
    STATE(5551), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
  [574969] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13628), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14663), 1,
      anon_sym_PIPE,
    STATE(11816), 1,
      sym_attribute,
    STATE(11851), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13626), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [575006] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14665), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12087), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(11817), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(12085), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [575041] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7285), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10544), 1,
      aux_sym_expression_item_repeat1,
    STATE(11818), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6897), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [575080] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11494), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11496), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [575113] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11820), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11426), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11428), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [575146] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10919), 1,
      aux_sym_expression_item_repeat1,
    STATE(11821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14668), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(13745), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [575185] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11822), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11434), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11436), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [575218] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(11823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14174), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [575255] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10344), 1,
      anon_sym_and,
    ACTIONS(14636), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14638), 1,
      sym_pow_operator,
    ACTIONS(14640), 1,
      sym_mult_operator,
    ACTIONS(14642), 1,
      sym_concat_operator,
    ACTIONS(14644), 1,
      sym_rel_operator,
    ACTIONS(14646), 1,
      sym_and_operator,
    ACTIONS(14648), 1,
      sym_or_operator,
    STATE(2033), 1,
      sym_add_operator,
    STATE(11824), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_assign_operator,
      sym_let_and_operator,
  [575306] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12530), 1,
      anon_sym_STAR,
    STATE(11817), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(11825), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13445), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13443), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [575343] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14636), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14638), 1,
      sym_pow_operator,
    ACTIONS(14640), 1,
      sym_mult_operator,
    STATE(2033), 1,
      sym_add_operator,
    STATE(11826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 3,
      anon_sym_and,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [575386] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14638), 1,
      sym_pow_operator,
    STATE(2033), 1,
      sym_add_operator,
    STATE(11827), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [575423] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14638), 1,
      sym_pow_operator,
    STATE(2033), 1,
      sym_add_operator,
    STATE(11828), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [575460] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14636), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14638), 1,
      sym_pow_operator,
    ACTIONS(14640), 1,
      sym_mult_operator,
    ACTIONS(14642), 1,
      sym_concat_operator,
    STATE(2033), 1,
      sym_add_operator,
    STATE(11829), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_and,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [575505] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14636), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14638), 1,
      sym_pow_operator,
    ACTIONS(14640), 1,
      sym_mult_operator,
    ACTIONS(14642), 1,
      sym_concat_operator,
    STATE(2033), 1,
      sym_add_operator,
    STATE(11830), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_and,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [575550] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14636), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14638), 1,
      sym_pow_operator,
    ACTIONS(14640), 1,
      sym_mult_operator,
    ACTIONS(14642), 1,
      sym_concat_operator,
    ACTIONS(14644), 1,
      sym_rel_operator,
    ACTIONS(14646), 1,
      sym_and_operator,
    STATE(2033), 1,
      sym_add_operator,
    STATE(11831), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_and,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_assign_operator,
      sym_let_and_operator,
  [575599] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10937), 1,
      aux_sym_expression_item_repeat1,
    STATE(11832), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14670), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(13494), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [575638] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_and,
    ACTIONS(14636), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14638), 1,
      sym_pow_operator,
    ACTIONS(14640), 1,
      sym_mult_operator,
    ACTIONS(14642), 1,
      sym_concat_operator,
    ACTIONS(14644), 1,
      sym_rel_operator,
    ACTIONS(14646), 1,
      sym_and_operator,
    ACTIONS(14648), 1,
      sym_or_operator,
    STATE(2033), 1,
      sym_add_operator,
    STATE(11833), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_assign_operator,
      sym_let_and_operator,
  [575689] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_and,
    ACTIONS(14632), 1,
      anon_sym_COMMA,
    ACTIONS(14636), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14638), 1,
      sym_pow_operator,
    ACTIONS(14640), 1,
      sym_mult_operator,
    ACTIONS(14642), 1,
      sym_concat_operator,
    ACTIONS(14644), 1,
      sym_rel_operator,
    ACTIONS(14646), 1,
      sym_and_operator,
    ACTIONS(14648), 1,
      sym_or_operator,
    ACTIONS(14650), 1,
      sym_assign_operator,
    STATE(2033), 1,
      sym_add_operator,
    STATE(11834), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 4,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [575744] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14638), 1,
      sym_pow_operator,
    ACTIONS(14640), 1,
      sym_mult_operator,
    STATE(2033), 1,
      sym_add_operator,
    STATE(11835), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [575783] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10303), 1,
      anon_sym_and,
    ACTIONS(14632), 1,
      anon_sym_COMMA,
    ACTIONS(14636), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14638), 1,
      sym_pow_operator,
    ACTIONS(14640), 1,
      sym_mult_operator,
    ACTIONS(14642), 1,
      sym_concat_operator,
    ACTIONS(14644), 1,
      sym_rel_operator,
    ACTIONS(14646), 1,
      sym_and_operator,
    ACTIONS(14648), 1,
      sym_or_operator,
    ACTIONS(14650), 1,
      sym_assign_operator,
    STATE(2033), 1,
      sym_add_operator,
    STATE(11836), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10301), 4,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [575838] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4981), 1,
      aux_sym_number_token1,
    ACTIONS(4985), 1,
      anon_sym_SQUOTE,
    ACTIONS(4987), 1,
      anon_sym_DQUOTE,
    ACTIONS(7409), 1,
      aux_sym_signed_number_token1,
    ACTIONS(14672), 1,
      anon_sym_LPAREN,
    ACTIONS(14676), 1,
      anon_sym_LBRACE,
    ACTIONS(14678), 1,
      anon_sym_begin,
    STATE(11837), 1,
      sym_attribute,
    STATE(13048), 1,
      sym__signed_constant,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14674), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12920), 2,
      sym__constant,
      sym_signed_number,
    STATE(12006), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
  [575889] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13628), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14663), 1,
      anon_sym_PIPE,
    STATE(11838), 1,
      sym_attribute,
    STATE(11852), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13626), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [575926] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13903), 1,
      anon_sym_let,
    ACTIONS(14558), 1,
      anon_sym_and,
    ACTIONS(14560), 1,
      sym_let_and_operator,
    STATE(11755), 1,
      aux_sym_value_definition_repeat1,
    STATE(11839), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13901), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [575965] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10340), 1,
      anon_sym_and,
    ACTIONS(14632), 1,
      anon_sym_COMMA,
    ACTIONS(14636), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14638), 1,
      sym_pow_operator,
    ACTIONS(14640), 1,
      sym_mult_operator,
    ACTIONS(14642), 1,
      sym_concat_operator,
    ACTIONS(14644), 1,
      sym_rel_operator,
    ACTIONS(14646), 1,
      sym_and_operator,
    ACTIONS(14648), 1,
      sym_or_operator,
    ACTIONS(14650), 1,
      sym_assign_operator,
    STATE(2033), 1,
      sym_add_operator,
    STATE(11840), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10338), 4,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [576020] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12075), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14663), 1,
      anon_sym_PIPE,
    STATE(11838), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(11841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12073), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [576057] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(11842), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14680), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [576094] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13921), 1,
      anon_sym_DASH_GT,
    ACTIONS(13923), 1,
      anon_sym_with,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(11842), 1,
      aux_sym_expression_item_repeat1,
    STATE(11843), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14174), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [576135] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6867), 1,
      anon_sym_DOT,
    STATE(11844), 1,
      sym_attribute,
    STATE(19722), 1,
      sym__infix_operator,
    STATE(20475), 1,
      sym_add_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1469), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(1471), 3,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
    ACTIONS(1467), 4,
      sym_mult_operator,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(6873), 5,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym_match_operator,
  [576178] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    ACTIONS(14289), 1,
      anon_sym_val,
    STATE(8633), 1,
      sym_module_path,
    STATE(11845), 1,
      sym_attribute,
    STATE(13022), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [576229] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7573), 1,
      aux_sym_number_token1,
    ACTIONS(7575), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7577), 1,
      anon_sym_SQUOTE,
    ACTIONS(7579), 1,
      anon_sym_DQUOTE,
    ACTIONS(14682), 1,
      anon_sym_LPAREN,
    ACTIONS(14686), 1,
      anon_sym_LBRACE,
    ACTIONS(14688), 1,
      anon_sym_begin,
    STATE(11846), 1,
      sym_attribute,
    STATE(14045), 1,
      sym__signed_constant,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14684), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13604), 2,
      sym__constant,
      sym_signed_number,
    STATE(13737), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
  [576280] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12459), 1,
      anon_sym_STAR,
    ACTIONS(13445), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(11847), 1,
      sym_attribute,
    STATE(11848), 1,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13443), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [576317] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12087), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14690), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11848), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(12085), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [576352] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14112), 1,
      anon_sym_let,
    ACTIONS(14558), 1,
      anon_sym_and,
    ACTIONS(14560), 1,
      sym_let_and_operator,
    STATE(11751), 1,
      aux_sym_value_definition_repeat1,
    STATE(11849), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14110), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [576391] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6877), 1,
      anon_sym_DOT,
    STATE(11850), 1,
      sym_attribute,
    STATE(18285), 1,
      sym__infix_operator,
    STATE(20475), 1,
      sym_add_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1469), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(1471), 3,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
    ACTIONS(1467), 4,
      sym_mult_operator,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(6883), 5,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym_match_operator,
  [576434] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13680), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14663), 1,
      anon_sym_PIPE,
    STATE(11851), 1,
      sym_attribute,
    STATE(11852), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13678), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [576471] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13267), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14693), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11852), 2,
      sym_attribute,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(13265), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [576506] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7265), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10495), 1,
      aux_sym_expression_item_repeat1,
    STATE(11853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7109), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [576545] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(11854), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11009), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11007), 16,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
  [576578] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(11855), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10427), 8,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
    ACTIONS(10425), 10,
      anon_sym_rec,
      anon_sym_nonrec,
      anon_sym__,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_virtual,
      anon_sym_functor,
      anon_sym_struct,
      sym__lowercase_identifier,
  [576611] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14495), 1,
      anon_sym_DOT,
    STATE(11856), 1,
      sym_attribute,
    STATE(18915), 1,
      sym__infix_operator,
    STATE(20475), 1,
      sym_add_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1469), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(1471), 3,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
    ACTIONS(1467), 4,
      sym_mult_operator,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(14497), 5,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym_match_operator,
  [576654] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12428), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(14092), 1,
      anon_sym_DASH_GT,
    STATE(11857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12426), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [576691] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14696), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10436), 1,
      aux_sym_expression_item_repeat1,
    STATE(11858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13063), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [576730] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7289), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10434), 1,
      aux_sym_expression_item_repeat1,
    STATE(11859), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7099), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [576769] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14698), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10409), 1,
      aux_sym_expression_item_repeat1,
    STATE(11860), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12795), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [576808] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13921), 1,
      anon_sym_DASH_GT,
    ACTIONS(13923), 1,
      anon_sym_with,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10874), 1,
      aux_sym_expression_item_repeat1,
    STATE(11861), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13814), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [576849] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7259), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10405), 1,
      aux_sym_expression_item_repeat1,
    STATE(11862), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7133), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [576888] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7535), 1,
      aux_sym_number_token1,
    ACTIONS(7537), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7539), 1,
      anon_sym_SQUOTE,
    ACTIONS(7541), 1,
      anon_sym_DQUOTE,
    ACTIONS(14700), 1,
      anon_sym_LPAREN,
    ACTIONS(14704), 1,
      anon_sym_LBRACE,
    ACTIONS(14706), 1,
      anon_sym_begin,
    STATE(8937), 1,
      sym__signed_constant,
    STATE(11863), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14702), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8637), 2,
      sym__constant,
      sym_signed_number,
    STATE(8567), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
  [576939] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10332), 1,
      anon_sym_PIPE,
    ACTIONS(14607), 1,
      anon_sym_COMMA,
    ACTIONS(14611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14613), 1,
      sym_pow_operator,
    ACTIONS(14615), 1,
      sym_mult_operator,
    ACTIONS(14617), 1,
      sym_concat_operator,
    ACTIONS(14619), 1,
      sym_rel_operator,
    ACTIONS(14621), 1,
      sym_and_operator,
    ACTIONS(14623), 1,
      sym_or_operator,
    ACTIONS(14625), 1,
      sym_assign_operator,
    STATE(2022), 1,
      sym_add_operator,
    STATE(11864), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10330), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
  [576994] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11865), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9158), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(9160), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [577027] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    ACTIONS(14154), 1,
      anon_sym_val,
    STATE(8633), 1,
      sym_module_path,
    STATE(11866), 1,
      sym_attribute,
    STATE(13053), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [577078] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14708), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12087), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(11867), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(12085), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [577113] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14711), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10382), 1,
      aux_sym_expression_item_repeat1,
    STATE(11868), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12681), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [577152] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12461), 1,
      anon_sym_STAR,
    STATE(11867), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(11869), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13445), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13443), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [577189] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10344), 1,
      anon_sym_PIPE,
    ACTIONS(14611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14613), 1,
      sym_pow_operator,
    ACTIONS(14615), 1,
      sym_mult_operator,
    ACTIONS(14617), 1,
      sym_concat_operator,
    ACTIONS(14619), 1,
      sym_rel_operator,
    ACTIONS(14621), 1,
      sym_and_operator,
    ACTIONS(14623), 1,
      sym_or_operator,
    STATE(2022), 1,
      sym_add_operator,
    STATE(11870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_assign_operator,
  [577240] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14613), 1,
      sym_pow_operator,
    ACTIONS(14615), 1,
      sym_mult_operator,
    STATE(2022), 1,
      sym_add_operator,
    STATE(11871), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [577283] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(14713), 1,
      anon_sym_LPAREN,
    ACTIONS(14715), 1,
      anon_sym_constraint,
    ACTIONS(14717), 1,
      anon_sym_val,
    ACTIONS(14719), 1,
      anon_sym_end,
    ACTIONS(14721), 1,
      anon_sym_inherit,
    ACTIONS(14723), 1,
      anon_sym_method,
    STATE(11872), 1,
      sym_attribute,
    STATE(12181), 1,
      aux_sym_class_body_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13437), 2,
      sym__class_field_specification,
      sym_floating_attribute,
    STATE(13441), 6,
      sym_inheritance_specification,
      sym_instance_variable_specification,
      sym_method_specification,
      sym_type_parameter_constraint,
      sym_item_extension,
      sym_quoted_item_extension,
  [577336] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13921), 1,
      anon_sym_DASH_GT,
    ACTIONS(13923), 1,
      anon_sym_with,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10717), 1,
      aux_sym_expression_item_repeat1,
    STATE(11873), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13795), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [577377] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14613), 1,
      sym_pow_operator,
    STATE(2022), 1,
      sym_add_operator,
    STATE(11874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [577414] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14613), 1,
      sym_pow_operator,
    STATE(2022), 1,
      sym_add_operator,
    STATE(11875), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [577451] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14613), 1,
      sym_pow_operator,
    ACTIONS(14615), 1,
      sym_mult_operator,
    ACTIONS(14617), 1,
      sym_concat_operator,
    STATE(2022), 1,
      sym_add_operator,
    STATE(11876), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_rel_operator,
      sym_assign_operator,
  [577496] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14725), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(10507), 1,
      aux_sym_expression_item_repeat1,
    STATE(11877), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13301), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [577535] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14613), 1,
      sym_pow_operator,
    ACTIONS(14615), 1,
      sym_mult_operator,
    ACTIONS(14617), 1,
      sym_concat_operator,
    STATE(2022), 1,
      sym_add_operator,
    STATE(11878), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_rel_operator,
      sym_assign_operator,
  [577580] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14613), 1,
      sym_pow_operator,
    ACTIONS(14615), 1,
      sym_mult_operator,
    ACTIONS(14617), 1,
      sym_concat_operator,
    ACTIONS(14619), 1,
      sym_rel_operator,
    ACTIONS(14621), 1,
      sym_and_operator,
    STATE(2022), 1,
      sym_add_operator,
    STATE(11879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_assign_operator,
  [577629] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(11753), 1,
      aux_sym_expression_item_repeat1,
    STATE(11880), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14727), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [577666] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(11881), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14727), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [577703] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(14611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14613), 1,
      sym_pow_operator,
    ACTIONS(14615), 1,
      sym_mult_operator,
    ACTIONS(14617), 1,
      sym_concat_operator,
    ACTIONS(14619), 1,
      sym_rel_operator,
    ACTIONS(14621), 1,
      sym_and_operator,
    ACTIONS(14623), 1,
      sym_or_operator,
    STATE(2022), 1,
      sym_add_operator,
    STATE(11882), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_assign_operator,
  [577754] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6857), 1,
      anon_sym_DOT,
    STATE(11883), 1,
      sym_attribute,
    STATE(18115), 1,
      sym__infix_operator,
    STATE(20475), 1,
      sym_add_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1469), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(1471), 3,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
    ACTIONS(1467), 4,
      sym_mult_operator,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(6863), 5,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym_match_operator,
  [577797] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(14607), 1,
      anon_sym_COMMA,
    ACTIONS(14611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14613), 1,
      sym_pow_operator,
    ACTIONS(14615), 1,
      sym_mult_operator,
    ACTIONS(14617), 1,
      sym_concat_operator,
    ACTIONS(14619), 1,
      sym_rel_operator,
    ACTIONS(14621), 1,
      sym_and_operator,
    ACTIONS(14623), 1,
      sym_or_operator,
    ACTIONS(14625), 1,
      sym_assign_operator,
    STATE(2022), 1,
      sym_add_operator,
    STATE(11884), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
  [577852] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14613), 1,
      sym_pow_operator,
    ACTIONS(14615), 1,
      sym_mult_operator,
    STATE(2022), 1,
      sym_add_operator,
    STATE(11885), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [577891] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10303), 1,
      anon_sym_PIPE,
    ACTIONS(14607), 1,
      anon_sym_COMMA,
    ACTIONS(14611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14613), 1,
      sym_pow_operator,
    ACTIONS(14615), 1,
      sym_mult_operator,
    ACTIONS(14617), 1,
      sym_concat_operator,
    ACTIONS(14619), 1,
      sym_rel_operator,
    ACTIONS(14621), 1,
      sym_and_operator,
    ACTIONS(14623), 1,
      sym_or_operator,
    ACTIONS(14625), 1,
      sym_assign_operator,
    STATE(2022), 1,
      sym_add_operator,
    STATE(11886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10301), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
  [577946] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14729), 1,
      anon_sym_else,
    STATE(10470), 1,
      sym_else_clause,
    STATE(11887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [577983] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10340), 1,
      anon_sym_PIPE,
    ACTIONS(14607), 1,
      anon_sym_COMMA,
    ACTIONS(14611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14613), 1,
      sym_pow_operator,
    ACTIONS(14615), 1,
      sym_mult_operator,
    ACTIONS(14617), 1,
      sym_concat_operator,
    ACTIONS(14619), 1,
      sym_rel_operator,
    ACTIONS(14621), 1,
      sym_and_operator,
    ACTIONS(14623), 1,
      sym_or_operator,
    ACTIONS(14625), 1,
      sym_assign_operator,
    STATE(2022), 1,
      sym_add_operator,
    STATE(11888), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10338), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
  [578038] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13903), 1,
      anon_sym_let,
    ACTIONS(14599), 1,
      anon_sym_and,
    ACTIONS(14601), 1,
      sym_let_and_operator,
    STATE(11889), 1,
      sym_attribute,
    STATE(11891), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13901), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [578077] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13957), 1,
      anon_sym_let,
    ACTIONS(14599), 1,
      anon_sym_and,
    ACTIONS(14601), 1,
      sym_let_and_operator,
    STATE(11890), 1,
      sym_attribute,
    STATE(11891), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13955), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [578116] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14003), 1,
      anon_sym_let,
    ACTIONS(14731), 1,
      anon_sym_and,
    ACTIONS(14734), 1,
      sym_let_and_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11891), 2,
      sym_attribute,
      aux_sym_value_definition_repeat1,
    ACTIONS(14001), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [578153] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13957), 1,
      anon_sym_let,
    ACTIONS(14599), 1,
      anon_sym_and,
    ACTIONS(14601), 1,
      sym_let_and_operator,
    STATE(11892), 1,
      sym_attribute,
    STATE(11894), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13955), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [578192] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11893), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9256), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(9258), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [578225] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13911), 1,
      anon_sym_let,
    ACTIONS(14599), 1,
      anon_sym_and,
    ACTIONS(14601), 1,
      sym_let_and_operator,
    STATE(11891), 1,
      aux_sym_value_definition_repeat1,
    STATE(11894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13909), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [578264] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5179), 1,
      aux_sym_number_token1,
    ACTIONS(5181), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5183), 1,
      anon_sym_SQUOTE,
    ACTIONS(5185), 1,
      anon_sym_DQUOTE,
    ACTIONS(14737), 1,
      anon_sym_LPAREN,
    ACTIONS(14741), 1,
      anon_sym_LBRACE,
    ACTIONS(14743), 1,
      anon_sym_begin,
    STATE(5484), 1,
      sym__signed_constant,
    STATE(11895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14739), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5408), 2,
      sym__constant,
      sym_signed_number,
    STATE(5367), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
  [578315] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(2022), 1,
      sym_add_operator,
    STATE(11896), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [578350] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14729), 1,
      anon_sym_else,
    STATE(10654), 1,
      sym_else_clause,
    STATE(11897), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [578387] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1941), 1,
      anon_sym_DOT,
    STATE(11898), 1,
      sym_attribute,
    STATE(20475), 1,
      sym_add_operator,
    STATE(20476), 1,
      sym__infix_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1469), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(1471), 3,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
    ACTIONS(1467), 4,
      sym_mult_operator,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(1949), 5,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym_match_operator,
  [578430] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2033), 1,
      sym_add_operator,
    STATE(11899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [578465] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9116), 1,
      anon_sym_and,
    ACTIONS(14632), 1,
      anon_sym_COMMA,
    ACTIONS(14636), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14638), 1,
      sym_pow_operator,
    ACTIONS(14640), 1,
      sym_mult_operator,
    ACTIONS(14642), 1,
      sym_concat_operator,
    ACTIONS(14644), 1,
      sym_rel_operator,
    ACTIONS(14646), 1,
      sym_and_operator,
    ACTIONS(14648), 1,
      sym_or_operator,
    ACTIONS(14650), 1,
      sym_assign_operator,
    ACTIONS(14745), 1,
      anon_sym_SEMI,
    STATE(2033), 1,
      sym_add_operator,
    STATE(11900), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9114), 3,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [578522] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11901), 1,
      sym_attribute,
    STATE(13091), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [578570] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9116), 1,
      anon_sym_PIPE,
    ACTIONS(14747), 1,
      anon_sym_COMMA,
    ACTIONS(14749), 1,
      anon_sym_SEMI,
    ACTIONS(14751), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14753), 1,
      sym_pow_operator,
    ACTIONS(14755), 1,
      sym_mult_operator,
    ACTIONS(14757), 1,
      sym_concat_operator,
    ACTIONS(14759), 1,
      sym_rel_operator,
    ACTIONS(14761), 1,
      sym_and_operator,
    ACTIONS(14763), 1,
      sym_or_operator,
    ACTIONS(14765), 1,
      sym_assign_operator,
    STATE(2130), 1,
      sym_add_operator,
    STATE(11902), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9114), 2,
      anon_sym_to,
      anon_sym_downto,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [578626] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14767), 1,
      anon_sym_else,
    STATE(7952), 1,
      sym_else_clause,
    STATE(11903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [578662] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(1954), 1,
      sym_add_operator,
    STATE(11904), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [578696] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10340), 1,
      anon_sym_PIPE,
    ACTIONS(14769), 1,
      anon_sym_COMMA,
    ACTIONS(14771), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14773), 1,
      sym_pow_operator,
    ACTIONS(14775), 1,
      sym_mult_operator,
    ACTIONS(14777), 1,
      sym_concat_operator,
    ACTIONS(14779), 1,
      sym_rel_operator,
    ACTIONS(14781), 1,
      sym_and_operator,
    ACTIONS(14783), 1,
      sym_or_operator,
    ACTIONS(14785), 1,
      sym_assign_operator,
    STATE(2231), 1,
      sym_add_operator,
    STATE(11905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10338), 3,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
  [578750] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14787), 1,
      anon_sym_else,
    STATE(8278), 1,
      sym_else_clause,
    STATE(11906), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [578786] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11907), 1,
      sym_attribute,
    STATE(13085), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [578834] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8596), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8598), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13610), 1,
      anon_sym_LPAREN,
    ACTIONS(13614), 1,
      anon_sym_functor,
    ACTIONS(13616), 1,
      anon_sym_struct,
    ACTIONS(13620), 1,
      sym__uppercase_identifier,
    STATE(11908), 1,
      sym_attribute,
    STATE(12881), 1,
      sym__module_expression,
    STATE(13140), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13223), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(13238), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [578882] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14789), 1,
      anon_sym_else,
    STATE(10654), 1,
      sym_else_clause,
    STATE(11909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [578918] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11910), 1,
      sym_attribute,
    STATE(13127), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [578966] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8596), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8598), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13610), 1,
      anon_sym_LPAREN,
    ACTIONS(13614), 1,
      anon_sym_functor,
    ACTIONS(13616), 1,
      anon_sym_struct,
    ACTIONS(13620), 1,
      sym__uppercase_identifier,
    STATE(11911), 1,
      sym_attribute,
    STATE(12846), 1,
      sym__module_expression,
    STATE(13140), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13223), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(13238), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [579014] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10303), 1,
      anon_sym_PIPE,
    ACTIONS(14769), 1,
      anon_sym_COMMA,
    ACTIONS(14771), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14773), 1,
      sym_pow_operator,
    ACTIONS(14775), 1,
      sym_mult_operator,
    ACTIONS(14777), 1,
      sym_concat_operator,
    ACTIONS(14779), 1,
      sym_rel_operator,
    ACTIONS(14781), 1,
      sym_and_operator,
    ACTIONS(14783), 1,
      sym_or_operator,
    ACTIONS(14785), 1,
      sym_assign_operator,
    STATE(2231), 1,
      sym_add_operator,
    STATE(11912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10301), 3,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
  [579068] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14793), 1,
      anon_sym_let,
    ACTIONS(14795), 1,
      anon_sym_and,
    STATE(11913), 1,
      sym_attribute,
    STATE(12058), 1,
      aux_sym_class_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14791), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [579104] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11914), 1,
      sym_attribute,
    STATE(13134), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [579152] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14773), 1,
      sym_pow_operator,
    ACTIONS(14775), 1,
      sym_mult_operator,
    STATE(2231), 1,
      sym_add_operator,
    STATE(11915), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [579190] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(14769), 1,
      anon_sym_COMMA,
    ACTIONS(14771), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14773), 1,
      sym_pow_operator,
    ACTIONS(14775), 1,
      sym_mult_operator,
    ACTIONS(14777), 1,
      sym_concat_operator,
    ACTIONS(14779), 1,
      sym_rel_operator,
    ACTIONS(14781), 1,
      sym_and_operator,
    ACTIONS(14783), 1,
      sym_or_operator,
    ACTIONS(14785), 1,
      sym_assign_operator,
    STATE(2231), 1,
      sym_add_operator,
    STATE(11916), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 3,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [579244] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11917), 1,
      sym_attribute,
    STATE(13051), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [579292] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14799), 1,
      anon_sym_let,
    ACTIONS(14801), 1,
      anon_sym_and,
    STATE(11918), 1,
      sym_attribute,
    STATE(12081), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14797), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [579328] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(14771), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14773), 1,
      sym_pow_operator,
    ACTIONS(14775), 1,
      sym_mult_operator,
    ACTIONS(14777), 1,
      sym_concat_operator,
    ACTIONS(14779), 1,
      sym_rel_operator,
    ACTIONS(14781), 1,
      sym_and_operator,
    ACTIONS(14783), 1,
      sym_or_operator,
    STATE(2231), 1,
      sym_add_operator,
    STATE(11919), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      sym_assign_operator,
  [579378] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12719), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14803), 1,
      anon_sym_EQ,
    ACTIONS(14805), 1,
      anon_sym_of,
    ACTIONS(14807), 1,
      anon_sym_COLON2,
    STATE(11920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12717), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [579416] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12691), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14809), 1,
      anon_sym_EQ,
    ACTIONS(14811), 1,
      anon_sym_of,
    ACTIONS(14813), 1,
      anon_sym_COLON2,
    STATE(11921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12689), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [579454] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12701), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14815), 1,
      anon_sym_EQ,
    ACTIONS(14817), 1,
      anon_sym_of,
    ACTIONS(14819), 1,
      anon_sym_COLON2,
    STATE(11922), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12699), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [579492] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12691), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14809), 1,
      anon_sym_EQ,
    ACTIONS(14821), 1,
      anon_sym_of,
    ACTIONS(14823), 1,
      anon_sym_COLON2,
    STATE(11923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12689), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [579530] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14825), 1,
      anon_sym_PIPE,
    STATE(11924), 1,
      sym_attribute,
    STATE(11926), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [579566] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14825), 1,
      anon_sym_PIPE,
    STATE(11925), 1,
      sym_attribute,
    STATE(11929), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [579602] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14825), 1,
      anon_sym_PIPE,
    STATE(11926), 1,
      sym_attribute,
    STATE(11932), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [579638] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14771), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14773), 1,
      sym_pow_operator,
    ACTIONS(14775), 1,
      sym_mult_operator,
    ACTIONS(14777), 1,
      sym_concat_operator,
    ACTIONS(14779), 1,
      sym_rel_operator,
    ACTIONS(14781), 1,
      sym_and_operator,
    STATE(2231), 1,
      sym_add_operator,
    STATE(11927), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      sym_assign_operator,
  [579686] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14771), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14773), 1,
      sym_pow_operator,
    ACTIONS(14775), 1,
      sym_mult_operator,
    ACTIONS(14777), 1,
      sym_concat_operator,
    STATE(2231), 1,
      sym_add_operator,
    STATE(11928), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      sym_rel_operator,
      sym_assign_operator,
  [579730] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14825), 1,
      anon_sym_PIPE,
    STATE(11929), 1,
      sym_attribute,
    STATE(11932), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [579766] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8596), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8598), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13610), 1,
      anon_sym_LPAREN,
    ACTIONS(13614), 1,
      anon_sym_functor,
    ACTIONS(13616), 1,
      anon_sym_struct,
    ACTIONS(13620), 1,
      sym__uppercase_identifier,
    STATE(11930), 1,
      sym_attribute,
    STATE(12915), 1,
      sym__module_expression,
    STATE(13140), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13223), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(13238), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [579814] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14771), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14773), 1,
      sym_pow_operator,
    ACTIONS(14775), 1,
      sym_mult_operator,
    ACTIONS(14777), 1,
      sym_concat_operator,
    STATE(2231), 1,
      sym_add_operator,
    STATE(11931), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      sym_rel_operator,
      sym_assign_operator,
  [579858] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14827), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11932), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [579892] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11933), 1,
      sym_attribute,
    STATE(12945), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [579940] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14773), 1,
      sym_pow_operator,
    STATE(2231), 1,
      sym_add_operator,
    STATE(11934), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [579976] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8148), 1,
      sym__module_expression,
    STATE(8633), 1,
      sym_module_path,
    STATE(11935), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [580024] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14773), 1,
      sym_pow_operator,
    STATE(2231), 1,
      sym_add_operator,
    STATE(11936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [580060] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14771), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14773), 1,
      sym_pow_operator,
    ACTIONS(14775), 1,
      sym_mult_operator,
    STATE(2231), 1,
      sym_add_operator,
    STATE(11937), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [580102] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10344), 1,
      anon_sym_PIPE,
    ACTIONS(14771), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14773), 1,
      sym_pow_operator,
    ACTIONS(14775), 1,
      sym_mult_operator,
    ACTIONS(14777), 1,
      sym_concat_operator,
    ACTIONS(14779), 1,
      sym_rel_operator,
    ACTIONS(14781), 1,
      sym_and_operator,
    ACTIONS(14783), 1,
      sym_or_operator,
    STATE(2231), 1,
      sym_add_operator,
    STATE(11938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      sym_assign_operator,
  [580152] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14793), 1,
      anon_sym_let,
    ACTIONS(14795), 1,
      anon_sym_and,
    STATE(11939), 1,
      sym_attribute,
    STATE(12059), 1,
      aux_sym_class_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14791), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [580188] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(11940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 3,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_POUND,
    ACTIONS(8336), 14,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_with,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      sym_hash_operator,
  [580220] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8092), 1,
      sym__module_expression,
    STATE(8633), 1,
      sym_module_path,
    STATE(11941), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [580268] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11942), 1,
      sym_attribute,
    STATE(13090), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [580316] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10340), 1,
      anon_sym_PIPE,
    ACTIONS(14830), 1,
      anon_sym_COMMA,
    ACTIONS(14832), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14834), 1,
      sym_pow_operator,
    ACTIONS(14836), 1,
      sym_mult_operator,
    ACTIONS(14838), 1,
      sym_concat_operator,
    ACTIONS(14840), 1,
      sym_rel_operator,
    ACTIONS(14842), 1,
      sym_and_operator,
    ACTIONS(14844), 1,
      sym_or_operator,
    ACTIONS(14846), 1,
      sym_assign_operator,
    STATE(1954), 1,
      sym_add_operator,
    STATE(11943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10338), 3,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
  [580370] = 18,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(14848), 1,
      anon_sym_COLON_GT,
    ACTIONS(14850), 1,
      anon_sym_RPAREN,
    ACTIONS(14852), 1,
      anon_sym_COLON2,
    STATE(2268), 1,
      sym_add_operator,
    STATE(11944), 1,
      sym_attribute,
    STATE(16677), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [580428] = 18,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(14852), 1,
      anon_sym_COLON2,
    ACTIONS(14854), 1,
      anon_sym_COLON_GT,
    ACTIONS(14856), 1,
      anon_sym_RPAREN,
    STATE(2268), 1,
      sym_add_operator,
    STATE(11945), 1,
      sym_attribute,
    STATE(16595), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [580486] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14767), 1,
      anon_sym_else,
    STATE(7983), 1,
      sym_else_clause,
    STATE(11946), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [580522] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10303), 1,
      anon_sym_PIPE,
    ACTIONS(14830), 1,
      anon_sym_COMMA,
    ACTIONS(14832), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14834), 1,
      sym_pow_operator,
    ACTIONS(14836), 1,
      sym_mult_operator,
    ACTIONS(14838), 1,
      sym_concat_operator,
    ACTIONS(14840), 1,
      sym_rel_operator,
    ACTIONS(14842), 1,
      sym_and_operator,
    ACTIONS(14844), 1,
      sym_or_operator,
    ACTIONS(14846), 1,
      sym_assign_operator,
    STATE(1954), 1,
      sym_add_operator,
    STATE(11947), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10301), 3,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
  [580576] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14834), 1,
      sym_pow_operator,
    ACTIONS(14836), 1,
      sym_mult_operator,
    STATE(1954), 1,
      sym_add_operator,
    STATE(11948), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [580614] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(14830), 1,
      anon_sym_COMMA,
    ACTIONS(14832), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14834), 1,
      sym_pow_operator,
    ACTIONS(14836), 1,
      sym_mult_operator,
    ACTIONS(14838), 1,
      sym_concat_operator,
    ACTIONS(14840), 1,
      sym_rel_operator,
    ACTIONS(14842), 1,
      sym_and_operator,
    ACTIONS(14844), 1,
      sym_or_operator,
    ACTIONS(14846), 1,
      sym_assign_operator,
    STATE(1954), 1,
      sym_add_operator,
    STATE(11949), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 3,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [580668] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11950), 1,
      sym_attribute,
    STATE(12940), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [580716] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(14832), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14834), 1,
      sym_pow_operator,
    ACTIONS(14836), 1,
      sym_mult_operator,
    ACTIONS(14838), 1,
      sym_concat_operator,
    ACTIONS(14840), 1,
      sym_rel_operator,
    ACTIONS(14842), 1,
      sym_and_operator,
    ACTIONS(14844), 1,
      sym_or_operator,
    STATE(1954), 1,
      sym_add_operator,
    STATE(11951), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_assign_operator,
  [580766] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14832), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14834), 1,
      sym_pow_operator,
    ACTIONS(14836), 1,
      sym_mult_operator,
    ACTIONS(14838), 1,
      sym_concat_operator,
    ACTIONS(14840), 1,
      sym_rel_operator,
    ACTIONS(14842), 1,
      sym_and_operator,
    STATE(1954), 1,
      sym_add_operator,
    STATE(11952), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_assign_operator,
  [580814] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14832), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14834), 1,
      sym_pow_operator,
    ACTIONS(14836), 1,
      sym_mult_operator,
    ACTIONS(14838), 1,
      sym_concat_operator,
    STATE(1954), 1,
      sym_add_operator,
    STATE(11953), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [580858] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14832), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14834), 1,
      sym_pow_operator,
    ACTIONS(14836), 1,
      sym_mult_operator,
    ACTIONS(14838), 1,
      sym_concat_operator,
    STATE(1954), 1,
      sym_add_operator,
    STATE(11954), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [580902] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(8713), 1,
      sym__module_expression,
    STATE(11955), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [580950] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14834), 1,
      sym_pow_operator,
    STATE(1954), 1,
      sym_add_operator,
    STATE(11956), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [580986] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11957), 1,
      sym_attribute,
    STATE(12951), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [581034] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(13279), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14858), 1,
      anon_sym_DASH_GT,
    STATE(11958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13277), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [581070] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14834), 1,
      sym_pow_operator,
    STATE(1954), 1,
      sym_add_operator,
    STATE(11959), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [581106] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14832), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14834), 1,
      sym_pow_operator,
    ACTIONS(14836), 1,
      sym_mult_operator,
    STATE(1954), 1,
      sym_add_operator,
    STATE(11960), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [581148] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9116), 1,
      anon_sym_PIPE,
    ACTIONS(14860), 1,
      anon_sym_COMMA,
    ACTIONS(14862), 1,
      anon_sym_SEMI,
    ACTIONS(14864), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14866), 1,
      sym_pow_operator,
    ACTIONS(14868), 1,
      sym_mult_operator,
    ACTIONS(14870), 1,
      sym_concat_operator,
    ACTIONS(14872), 1,
      sym_rel_operator,
    ACTIONS(14874), 1,
      sym_and_operator,
    ACTIONS(14876), 1,
      sym_or_operator,
    ACTIONS(14878), 1,
      sym_assign_operator,
    STATE(2090), 1,
      sym_add_operator,
    STATE(11961), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9114), 2,
      anon_sym_then,
      anon_sym_else,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [581204] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10344), 1,
      anon_sym_PIPE,
    ACTIONS(14832), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14834), 1,
      sym_pow_operator,
    ACTIONS(14836), 1,
      sym_mult_operator,
    ACTIONS(14838), 1,
      sym_concat_operator,
    ACTIONS(14840), 1,
      sym_rel_operator,
    ACTIONS(14842), 1,
      sym_and_operator,
    ACTIONS(14844), 1,
      sym_or_operator,
    STATE(1954), 1,
      sym_add_operator,
    STATE(11962), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_assign_operator,
  [581254] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14880), 1,
      anon_sym_else,
    STATE(8259), 1,
      sym_else_clause,
    STATE(11963), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [581290] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11964), 1,
      sym_attribute,
    STATE(12996), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [581338] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10332), 1,
      anon_sym_PIPE,
    ACTIONS(14860), 1,
      anon_sym_COMMA,
    ACTIONS(14864), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14866), 1,
      sym_pow_operator,
    ACTIONS(14868), 1,
      sym_mult_operator,
    ACTIONS(14870), 1,
      sym_concat_operator,
    ACTIONS(14872), 1,
      sym_rel_operator,
    ACTIONS(14874), 1,
      sym_and_operator,
    ACTIONS(14876), 1,
      sym_or_operator,
    ACTIONS(14878), 1,
      sym_assign_operator,
    STATE(2090), 1,
      sym_add_operator,
    STATE(11965), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10330), 3,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
  [581392] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12719), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12721), 1,
      anon_sym_EQ,
    ACTIONS(14805), 1,
      anon_sym_of,
    ACTIONS(14807), 1,
      anon_sym_COLON2,
    STATE(11966), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12717), 13,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [581430] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11967), 1,
      sym_attribute,
    STATE(13035), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [581478] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12701), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12703), 1,
      anon_sym_EQ,
    ACTIONS(14817), 1,
      anon_sym_of,
    ACTIONS(14819), 1,
      anon_sym_COLON2,
    STATE(11968), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12699), 13,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [581516] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9116), 1,
      anon_sym_PIPE,
    ACTIONS(14769), 1,
      anon_sym_COMMA,
    ACTIONS(14771), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14773), 1,
      sym_pow_operator,
    ACTIONS(14775), 1,
      sym_mult_operator,
    ACTIONS(14777), 1,
      sym_concat_operator,
    ACTIONS(14779), 1,
      sym_rel_operator,
    ACTIONS(14781), 1,
      sym_and_operator,
    ACTIONS(14783), 1,
      sym_or_operator,
    ACTIONS(14785), 1,
      sym_assign_operator,
    ACTIONS(14882), 1,
      anon_sym_SEMI,
    STATE(2231), 1,
      sym_add_operator,
    STATE(11969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9114), 2,
      anon_sym_else,
      anon_sym_do,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [581572] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(2130), 1,
      sym_add_operator,
    STATE(11970), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [581606] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(11971), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 3,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_POUND,
    ACTIONS(8318), 14,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_with,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      sym_hash_operator,
  [581638] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9116), 1,
      anon_sym_PIPE,
    ACTIONS(14884), 1,
      anon_sym_COMMA,
    ACTIONS(14886), 1,
      anon_sym_SEMI,
    ACTIONS(14888), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14890), 1,
      sym_pow_operator,
    ACTIONS(14892), 1,
      sym_mult_operator,
    ACTIONS(14894), 1,
      sym_concat_operator,
    ACTIONS(14896), 1,
      sym_rel_operator,
    ACTIONS(14898), 1,
      sym_and_operator,
    ACTIONS(14900), 1,
      sym_or_operator,
    ACTIONS(14902), 1,
      sym_assign_operator,
    STATE(1834), 1,
      sym_add_operator,
    STATE(11972), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9114), 2,
      anon_sym_else,
      anon_sym_done,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [581694] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(11973), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 3,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_POUND,
    ACTIONS(8322), 14,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_with,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      sym_hash_operator,
  [581726] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(11974), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 3,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_POUND,
    ACTIONS(8340), 14,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_with,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      sym_hash_operator,
  [581758] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(11975), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 3,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_POUND,
    ACTIONS(8310), 14,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_with,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      sym_hash_operator,
  [581790] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14801), 1,
      anon_sym_and,
    ACTIONS(14906), 1,
      anon_sym_let,
    STATE(11976), 1,
      sym_attribute,
    STATE(12071), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14904), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [581826] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10332), 1,
      anon_sym_PIPE,
    ACTIONS(14884), 1,
      anon_sym_COMMA,
    ACTIONS(14888), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14890), 1,
      sym_pow_operator,
    ACTIONS(14892), 1,
      sym_mult_operator,
    ACTIONS(14894), 1,
      sym_concat_operator,
    ACTIONS(14896), 1,
      sym_rel_operator,
    ACTIONS(14898), 1,
      sym_and_operator,
    ACTIONS(14900), 1,
      sym_or_operator,
    ACTIONS(14902), 1,
      sym_assign_operator,
    STATE(1834), 1,
      sym_add_operator,
    STATE(11977), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10330), 3,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_done,
  [581880] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(14908), 1,
      sym__lowercase_identifier,
    ACTIONS(14910), 1,
      anon_sym_LPAREN,
    ACTIONS(14912), 1,
      anon_sym_nonrec,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(14918), 1,
      anon_sym__,
    STATE(11976), 1,
      sym_type_binding,
    STATE(11978), 1,
      sym_attribute,
    STATE(12689), 1,
      sym__attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(14539), 1,
      sym__type_params,
    STATE(16510), 1,
      sym__type_param,
    STATE(16511), 1,
      sym_extended_module_path,
    STATE(20272), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [581940] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(8893), 1,
      sym__module_expression,
    STATE(11979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [581988] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11980), 1,
      sym_attribute,
    STATE(12987), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [582036] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10393), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14920), 1,
      anon_sym_STAR,
    STATE(11981), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10391), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [582070] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14922), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11982), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [582104] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13628), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14925), 1,
      anon_sym_PIPE,
    STATE(11983), 1,
      sym_attribute,
    STATE(12068), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13626), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [582140] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14929), 1,
      anon_sym_let,
    ACTIONS(14931), 1,
      anon_sym_and,
    STATE(11984), 1,
      sym_attribute,
    STATE(12076), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14927), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [582176] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14933), 1,
      anon_sym_PIPE,
    STATE(11982), 1,
      aux_sym__match_cases_repeat1,
    STATE(11985), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [582212] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14933), 1,
      anon_sym_PIPE,
    STATE(11982), 1,
      aux_sym__match_cases_repeat1,
    STATE(11986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [582248] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14935), 1,
      anon_sym_PIPE,
    STATE(11987), 1,
      sym_attribute,
    STATE(11993), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [582284] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14933), 1,
      anon_sym_PIPE,
    STATE(11985), 1,
      aux_sym__match_cases_repeat1,
    STATE(11988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [582320] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12075), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14925), 1,
      anon_sym_PIPE,
    STATE(11989), 1,
      sym_attribute,
    STATE(12069), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12073), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [582356] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14937), 1,
      anon_sym_else,
    STATE(8259), 1,
      sym_else_clause,
    STATE(11990), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [582392] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14935), 1,
      anon_sym_PIPE,
    STATE(11991), 1,
      sym_attribute,
    STATE(11994), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [582428] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14933), 1,
      anon_sym_PIPE,
    STATE(11986), 1,
      aux_sym__match_cases_repeat1,
    STATE(11992), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [582464] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14935), 1,
      anon_sym_PIPE,
    STATE(11993), 1,
      sym_attribute,
    STATE(11996), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [582500] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14935), 1,
      anon_sym_PIPE,
    STATE(11994), 1,
      sym_attribute,
    STATE(11996), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [582536] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14880), 1,
      anon_sym_else,
    STATE(8278), 1,
      sym_else_clause,
    STATE(11995), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [582572] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14939), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11996), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [582606] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(11997), 1,
      sym_attribute,
    STATE(13059), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [582654] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14942), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11998), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [582688] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12701), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14815), 1,
      anon_sym_EQ,
    ACTIONS(14945), 1,
      anon_sym_of,
    ACTIONS(14947), 1,
      anon_sym_COLON2,
    STATE(11999), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12699), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [582726] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12719), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14803), 1,
      anon_sym_EQ,
    ACTIONS(14949), 1,
      anon_sym_of,
    ACTIONS(14951), 1,
      anon_sym_COLON2,
    STATE(12000), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12717), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [582764] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9116), 1,
      anon_sym_PIPE,
    ACTIONS(14953), 1,
      anon_sym_COMMA,
    ACTIONS(14955), 1,
      anon_sym_SEMI,
    ACTIONS(14957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14959), 1,
      sym_pow_operator,
    ACTIONS(14961), 1,
      sym_mult_operator,
    ACTIONS(14963), 1,
      sym_concat_operator,
    ACTIONS(14965), 1,
      sym_rel_operator,
    ACTIONS(14967), 1,
      sym_and_operator,
    ACTIONS(14969), 1,
      sym_or_operator,
    ACTIONS(14971), 1,
      sym_assign_operator,
    STATE(2154), 1,
      sym_add_operator,
    STATE(12001), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9114), 2,
      anon_sym_with,
      anon_sym_else,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [582820] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12002), 1,
      sym_attribute,
    STATE(12959), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [582868] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(14715), 1,
      anon_sym_constraint,
    ACTIONS(14717), 1,
      anon_sym_val,
    ACTIONS(14721), 1,
      anon_sym_inherit,
    ACTIONS(14723), 1,
      anon_sym_method,
    ACTIONS(14973), 1,
      anon_sym_end,
    STATE(12003), 1,
      sym_attribute,
    STATE(12085), 1,
      aux_sym_class_body_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13437), 2,
      sym__class_field_specification,
      sym_floating_attribute,
    STATE(13441), 6,
      sym_inheritance_specification,
      sym_instance_variable_specification,
      sym_method_specification,
      sym_type_parameter_constraint,
      sym_item_extension,
      sym_quoted_item_extension,
  [582918] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14975), 1,
      anon_sym_PIPE,
    STATE(11998), 1,
      aux_sym__match_cases_repeat1,
    STATE(12004), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [582954] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14977), 1,
      anon_sym_else,
    STATE(7983), 1,
      sym_else_clause,
    STATE(12005), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [582990] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12006), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 3,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_POUND,
    ACTIONS(8302), 14,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_with,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      sym_hash_operator,
  [583022] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12007), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 3,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_POUND,
    ACTIONS(8292), 14,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_with,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      sym_hash_operator,
  [583054] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12008), 1,
      sym_attribute,
    STATE(12932), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [583102] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12009), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 3,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_POUND,
    ACTIONS(8288), 14,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_with,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      sym_hash_operator,
  [583134] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14795), 1,
      anon_sym_and,
    ACTIONS(14981), 1,
      anon_sym_let,
    STATE(11913), 1,
      aux_sym_class_definition_repeat1,
    STATE(12010), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14979), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [583170] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10332), 1,
      anon_sym_PIPE,
    ACTIONS(14769), 1,
      anon_sym_COMMA,
    ACTIONS(14771), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14773), 1,
      sym_pow_operator,
    ACTIONS(14775), 1,
      sym_mult_operator,
    ACTIONS(14777), 1,
      sym_concat_operator,
    ACTIONS(14779), 1,
      sym_rel_operator,
    ACTIONS(14781), 1,
      sym_and_operator,
    ACTIONS(14783), 1,
      sym_or_operator,
    ACTIONS(14785), 1,
      sym_assign_operator,
    STATE(2231), 1,
      sym_add_operator,
    STATE(12011), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10330), 3,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
  [583224] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10332), 1,
      anon_sym_PIPE,
    ACTIONS(14830), 1,
      anon_sym_COMMA,
    ACTIONS(14832), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14834), 1,
      sym_pow_operator,
    ACTIONS(14836), 1,
      sym_mult_operator,
    ACTIONS(14838), 1,
      sym_concat_operator,
    ACTIONS(14840), 1,
      sym_rel_operator,
    ACTIONS(14842), 1,
      sym_and_operator,
    ACTIONS(14844), 1,
      sym_or_operator,
    ACTIONS(14846), 1,
      sym_assign_operator,
    STATE(1954), 1,
      sym_add_operator,
    STATE(12012), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10330), 3,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
  [583278] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12013), 1,
      sym_attribute,
    STATE(13049), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [583326] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9116), 1,
      anon_sym_PIPE,
    ACTIONS(14983), 1,
      anon_sym_COMMA,
    ACTIONS(14985), 1,
      anon_sym_SEMI,
    ACTIONS(14987), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14989), 1,
      sym_pow_operator,
    ACTIONS(14991), 1,
      sym_mult_operator,
    ACTIONS(14993), 1,
      sym_concat_operator,
    ACTIONS(14995), 1,
      sym_rel_operator,
    ACTIONS(14997), 1,
      sym_and_operator,
    ACTIONS(14999), 1,
      sym_or_operator,
    ACTIONS(15001), 1,
      sym_assign_operator,
    STATE(2035), 1,
      sym_add_operator,
    STATE(12014), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9114), 2,
      anon_sym_end,
      anon_sym_else,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [583382] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14977), 1,
      anon_sym_else,
    STATE(7952), 1,
      sym_else_clause,
    STATE(12015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [583418] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(14910), 1,
      anon_sym_LPAREN,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(14918), 1,
      anon_sym__,
    ACTIONS(15003), 1,
      sym__lowercase_identifier,
    ACTIONS(15005), 1,
      anon_sym_nonrec,
    STATE(12016), 1,
      sym_attribute,
    STATE(12591), 1,
      sym_type_binding,
    STATE(12718), 1,
      sym__attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(14437), 1,
      sym__type_params,
    STATE(16510), 1,
      sym__type_param,
    STATE(16511), 1,
      sym_extended_module_path,
    STATE(20500), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [583478] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8596), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8598), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13610), 1,
      anon_sym_LPAREN,
    ACTIONS(13614), 1,
      anon_sym_functor,
    ACTIONS(13616), 1,
      anon_sym_struct,
    ACTIONS(13620), 1,
      sym__uppercase_identifier,
    STATE(12017), 1,
      sym_attribute,
    STATE(12847), 1,
      sym__module_expression,
    STATE(13140), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13223), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(13238), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [583526] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15007), 1,
      anon_sym_else,
    STATE(8259), 1,
      sym_else_clause,
    STATE(12018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [583562] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12019), 1,
      sym_attribute,
    STATE(13114), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [583610] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8596), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8598), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13610), 1,
      anon_sym_LPAREN,
    ACTIONS(13614), 1,
      anon_sym_functor,
    ACTIONS(13616), 1,
      anon_sym_struct,
    ACTIONS(13620), 1,
      sym__uppercase_identifier,
    STATE(12020), 1,
      sym_attribute,
    STATE(13055), 1,
      sym__module_expression,
    STATE(13140), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13223), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(13238), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [583658] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12021), 1,
      sym_attribute,
    STATE(13116), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [583706] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13327), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13329), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13610), 1,
      anon_sym_LPAREN,
    ACTIONS(13616), 1,
      anon_sym_struct,
    ACTIONS(13620), 1,
      sym__uppercase_identifier,
    ACTIONS(15009), 1,
      anon_sym_functor,
    STATE(12022), 1,
      sym_attribute,
    STATE(12281), 1,
      sym__module_expression,
    STATE(13140), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13223), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(13238), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [583754] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(2035), 1,
      sym_add_operator,
    STATE(12023), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [583788] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13327), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13329), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13610), 1,
      anon_sym_LPAREN,
    ACTIONS(13616), 1,
      anon_sym_struct,
    ACTIONS(13620), 1,
      sym__uppercase_identifier,
    ACTIONS(15009), 1,
      anon_sym_functor,
    STATE(12024), 1,
      sym_attribute,
    STATE(12503), 1,
      sym__module_expression,
    STATE(13140), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13223), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(13238), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [583836] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14975), 1,
      anon_sym_PIPE,
    STATE(11998), 1,
      aux_sym__match_cases_repeat1,
    STATE(12025), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [583872] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14975), 1,
      anon_sym_PIPE,
    STATE(12004), 1,
      aux_sym__match_cases_repeat1,
    STATE(12026), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [583908] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12027), 1,
      sym_attribute,
    STATE(13132), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [583956] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15013), 1,
      anon_sym_let,
    ACTIONS(15015), 1,
      anon_sym_and,
    STATE(12028), 1,
      sym_attribute,
    STATE(12203), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15011), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [583992] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15017), 1,
      anon_sym_else,
    STATE(8278), 1,
      sym_else_clause,
    STATE(12029), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [584028] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15015), 1,
      anon_sym_and,
    ACTIONS(15021), 1,
      anon_sym_let,
    STATE(12030), 1,
      sym_attribute,
    STATE(12173), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15019), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [584064] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10340), 1,
      anon_sym_PIPE,
    ACTIONS(14884), 1,
      anon_sym_COMMA,
    ACTIONS(14888), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14890), 1,
      sym_pow_operator,
    ACTIONS(14892), 1,
      sym_mult_operator,
    ACTIONS(14894), 1,
      sym_concat_operator,
    ACTIONS(14896), 1,
      sym_rel_operator,
    ACTIONS(14898), 1,
      sym_and_operator,
    ACTIONS(14900), 1,
      sym_or_operator,
    ACTIONS(14902), 1,
      sym_assign_operator,
    STATE(1834), 1,
      sym_add_operator,
    STATE(12031), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10338), 3,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_done,
  [584118] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15023), 1,
      anon_sym_else,
    STATE(10470), 1,
      sym_else_clause,
    STATE(12032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [584154] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10303), 1,
      anon_sym_PIPE,
    ACTIONS(14884), 1,
      anon_sym_COMMA,
    ACTIONS(14888), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14890), 1,
      sym_pow_operator,
    ACTIONS(14892), 1,
      sym_mult_operator,
    ACTIONS(14894), 1,
      sym_concat_operator,
    ACTIONS(14896), 1,
      sym_rel_operator,
    ACTIONS(14898), 1,
      sym_and_operator,
    ACTIONS(14900), 1,
      sym_or_operator,
    ACTIONS(14902), 1,
      sym_assign_operator,
    STATE(1834), 1,
      sym_add_operator,
    STATE(12033), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10301), 3,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_done,
  [584208] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(14715), 1,
      anon_sym_constraint,
    ACTIONS(14717), 1,
      anon_sym_val,
    ACTIONS(14721), 1,
      anon_sym_inherit,
    ACTIONS(14723), 1,
      anon_sym_method,
    ACTIONS(15025), 1,
      anon_sym_end,
    STATE(12003), 1,
      aux_sym_class_body_type_repeat1,
    STATE(12034), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13437), 2,
      sym__class_field_specification,
      sym_floating_attribute,
    STATE(13441), 6,
      sym_inheritance_specification,
      sym_instance_variable_specification,
      sym_method_specification,
      sym_type_parameter_constraint,
      sym_item_extension,
      sym_quoted_item_extension,
  [584258] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12511), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14858), 1,
      anon_sym_DASH_GT,
    STATE(12035), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12509), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [584292] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15027), 1,
      anon_sym_else,
    STATE(8259), 1,
      sym_else_clause,
    STATE(12036), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [584328] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14975), 1,
      anon_sym_PIPE,
    STATE(12025), 1,
      aux_sym__match_cases_repeat1,
    STATE(12037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [584364] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12038), 1,
      sym_attribute,
    STATE(13099), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [584412] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9116), 1,
      anon_sym_PIPE,
    ACTIONS(14830), 1,
      anon_sym_COMMA,
    ACTIONS(14832), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14834), 1,
      sym_pow_operator,
    ACTIONS(14836), 1,
      sym_mult_operator,
    ACTIONS(14838), 1,
      sym_concat_operator,
    ACTIONS(14840), 1,
      sym_rel_operator,
    ACTIONS(14842), 1,
      sym_and_operator,
    ACTIONS(14844), 1,
      sym_or_operator,
    ACTIONS(14846), 1,
      sym_assign_operator,
    ACTIONS(15029), 1,
      anon_sym_SEMI,
    STATE(1954), 1,
      sym_add_operator,
    STATE(12039), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9114), 2,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [584468] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14890), 1,
      sym_pow_operator,
    ACTIONS(14892), 1,
      sym_mult_operator,
    STATE(1834), 1,
      sym_add_operator,
    STATE(12040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [584506] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(14884), 1,
      anon_sym_COMMA,
    ACTIONS(14888), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14890), 1,
      sym_pow_operator,
    ACTIONS(14892), 1,
      sym_mult_operator,
    ACTIONS(14894), 1,
      sym_concat_operator,
    ACTIONS(14896), 1,
      sym_rel_operator,
    ACTIONS(14898), 1,
      sym_and_operator,
    ACTIONS(14900), 1,
      sym_or_operator,
    ACTIONS(14902), 1,
      sym_assign_operator,
    STATE(1834), 1,
      sym_add_operator,
    STATE(12041), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 3,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_done,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [584560] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(14888), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14890), 1,
      sym_pow_operator,
    ACTIONS(14892), 1,
      sym_mult_operator,
    ACTIONS(14894), 1,
      sym_concat_operator,
    ACTIONS(14896), 1,
      sym_rel_operator,
    ACTIONS(14898), 1,
      sym_and_operator,
    ACTIONS(14900), 1,
      sym_or_operator,
    STATE(1834), 1,
      sym_add_operator,
    STATE(12042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_done,
      sym_assign_operator,
  [584610] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14888), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14890), 1,
      sym_pow_operator,
    ACTIONS(14892), 1,
      sym_mult_operator,
    ACTIONS(14894), 1,
      sym_concat_operator,
    ACTIONS(14896), 1,
      sym_rel_operator,
    ACTIONS(14898), 1,
      sym_and_operator,
    STATE(1834), 1,
      sym_add_operator,
    STATE(12043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_done,
      sym_assign_operator,
  [584658] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14888), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14890), 1,
      sym_pow_operator,
    ACTIONS(14892), 1,
      sym_mult_operator,
    ACTIONS(14894), 1,
      sym_concat_operator,
    STATE(1834), 1,
      sym_add_operator,
    STATE(12044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_done,
      sym_rel_operator,
      sym_assign_operator,
  [584702] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12045), 1,
      sym_attribute,
    STATE(13104), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [584750] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14888), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14890), 1,
      sym_pow_operator,
    ACTIONS(14892), 1,
      sym_mult_operator,
    ACTIONS(14894), 1,
      sym_concat_operator,
    STATE(1834), 1,
      sym_add_operator,
    STATE(12046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_done,
      sym_rel_operator,
      sym_assign_operator,
  [584794] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12047), 1,
      sym_attribute,
    STATE(12994), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [584842] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14931), 1,
      anon_sym_and,
    ACTIONS(15013), 1,
      anon_sym_let,
    STATE(12048), 1,
      sym_attribute,
    STATE(12077), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15011), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [584878] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14931), 1,
      anon_sym_and,
    ACTIONS(15021), 1,
      anon_sym_let,
    STATE(12049), 1,
      sym_attribute,
    STATE(12051), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15019), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [584914] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14890), 1,
      sym_pow_operator,
    STATE(1834), 1,
      sym_add_operator,
    STATE(12050), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [584950] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14931), 1,
      anon_sym_and,
    ACTIONS(15013), 1,
      anon_sym_let,
    STATE(12051), 1,
      sym_attribute,
    STATE(12084), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15011), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [584986] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15027), 1,
      anon_sym_else,
    STATE(8278), 1,
      sym_else_clause,
    STATE(12052), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [585022] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14890), 1,
      sym_pow_operator,
    STATE(1834), 1,
      sym_add_operator,
    STATE(12053), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [585058] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12054), 1,
      sym_attribute,
    STATE(12980), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [585106] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14888), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14890), 1,
      sym_pow_operator,
    ACTIONS(14892), 1,
      sym_mult_operator,
    STATE(1834), 1,
      sym_add_operator,
    STATE(12055), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_done,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [585148] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10344), 1,
      anon_sym_PIPE,
    ACTIONS(14888), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14890), 1,
      sym_pow_operator,
    ACTIONS(14892), 1,
      sym_mult_operator,
    ACTIONS(14894), 1,
      sym_concat_operator,
    ACTIONS(14896), 1,
      sym_rel_operator,
    ACTIONS(14898), 1,
      sym_and_operator,
    ACTIONS(14900), 1,
      sym_or_operator,
    STATE(1834), 1,
      sym_add_operator,
    STATE(12056), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_done,
      sym_assign_operator,
  [585198] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12057), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11009), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11007), 9,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
  [585230] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13931), 1,
      anon_sym_let,
    ACTIONS(15031), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12058), 2,
      sym_attribute,
      aux_sym_class_definition_repeat1,
    ACTIONS(13929), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [585264] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14795), 1,
      anon_sym_and,
    ACTIONS(15036), 1,
      anon_sym_let,
    STATE(12058), 1,
      aux_sym_class_definition_repeat1,
    STATE(12059), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15034), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [585300] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15040), 1,
      anon_sym_let,
    ACTIONS(15042), 1,
      anon_sym_and,
    STATE(12060), 1,
      sym_attribute,
    STATE(12073), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15038), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [585336] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12061), 1,
      sym_attribute,
    STATE(12962), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [585384] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(15044), 1,
      sym__lowercase_identifier,
    ACTIONS(15046), 1,
      anon_sym_POUND,
    STATE(12062), 1,
      sym_attribute,
    STATE(12658), 1,
      sym_type_constructor_path,
    STATE(17280), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11128), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11130), 7,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [585426] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12063), 1,
      sym_attribute,
    STATE(13097), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [585474] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12064), 1,
      sym_attribute,
    STATE(13115), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [585522] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12065), 1,
      sym_attribute,
    STATE(13109), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [585570] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13267), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15048), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12066), 2,
      sym_attribute,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(13265), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [585604] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15053), 1,
      anon_sym_let,
    ACTIONS(15055), 1,
      anon_sym_DOT,
    STATE(12067), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15051), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [585638] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13680), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14925), 1,
      anon_sym_PIPE,
    STATE(12066), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(12068), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13678), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [585674] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13628), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14925), 1,
      anon_sym_PIPE,
    STATE(12066), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(12069), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13626), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [585710] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14937), 1,
      anon_sym_else,
    STATE(8278), 1,
      sym_else_clause,
    STATE(12070), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [585746] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14799), 1,
      anon_sym_let,
    ACTIONS(14801), 1,
      anon_sym_and,
    STATE(12071), 1,
      sym_attribute,
    STATE(12082), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14797), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [585782] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15042), 1,
      anon_sym_and,
    ACTIONS(15059), 1,
      anon_sym_let,
    STATE(12060), 1,
      aux_sym_type_definition_repeat1,
    STATE(12072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15057), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [585818] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14180), 1,
      anon_sym_let,
    ACTIONS(15061), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12073), 2,
      sym_attribute,
      aux_sym_type_definition_repeat1,
    ACTIONS(14178), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [585852] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15042), 1,
      anon_sym_and,
    ACTIONS(15059), 1,
      anon_sym_let,
    STATE(12073), 1,
      aux_sym_type_definition_repeat1,
    STATE(12074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15057), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [585888] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12691), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12693), 1,
      anon_sym_EQ,
    ACTIONS(14811), 1,
      anon_sym_of,
    ACTIONS(14813), 1,
      anon_sym_COLON2,
    STATE(12075), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12689), 13,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [585926] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14931), 1,
      anon_sym_and,
    ACTIONS(15066), 1,
      anon_sym_let,
    STATE(12076), 1,
      sym_attribute,
    STATE(12084), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15064), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [585962] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14929), 1,
      anon_sym_let,
    ACTIONS(14931), 1,
      anon_sym_and,
    STATE(12077), 1,
      sym_attribute,
    STATE(12084), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14927), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [585998] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14799), 1,
      anon_sym_let,
    ACTIONS(15042), 1,
      anon_sym_and,
    STATE(12073), 1,
      aux_sym_type_definition_repeat1,
    STATE(12078), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14797), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [586034] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12079), 1,
      sym_attribute,
    STATE(13042), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [586082] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(8720), 1,
      sym__module_expression,
    STATE(12080), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [586130] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14801), 1,
      anon_sym_and,
    ACTIONS(15059), 1,
      anon_sym_let,
    STATE(12081), 1,
      sym_attribute,
    STATE(12082), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15057), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [586166] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14180), 1,
      anon_sym_let,
    ACTIONS(15068), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12082), 2,
      sym_attribute,
      aux_sym_type_definition_repeat1,
    ACTIONS(14178), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [586200] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(14910), 1,
      anon_sym_LPAREN,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(14918), 1,
      anon_sym__,
    ACTIONS(15071), 1,
      sym__lowercase_identifier,
    ACTIONS(15073), 1,
      anon_sym_nonrec,
    STATE(12083), 1,
      sym_attribute,
    STATE(12744), 1,
      sym_type_binding,
    STATE(12788), 1,
      sym__attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(14692), 1,
      sym__type_params,
    STATE(16510), 1,
      sym__type_param,
    STATE(16511), 1,
      sym_extended_module_path,
    STATE(20289), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [586260] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14172), 1,
      anon_sym_let,
    ACTIONS(15075), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12084), 2,
      sym_attribute,
      aux_sym_module_definition_repeat1,
    ACTIONS(14170), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [586294] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15078), 1,
      anon_sym_constraint,
    ACTIONS(15081), 1,
      anon_sym_val,
    ACTIONS(15084), 1,
      anon_sym_end,
    ACTIONS(15086), 1,
      anon_sym_inherit,
    ACTIONS(15089), 1,
      anon_sym_method,
    ACTIONS(15092), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(15095), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(15098), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12085), 2,
      sym_attribute,
      aux_sym_class_body_type_repeat1,
    STATE(13437), 2,
      sym__class_field_specification,
      sym_floating_attribute,
    STATE(13441), 6,
      sym_inheritance_specification,
      sym_instance_variable_specification,
      sym_method_specification,
      sym_type_parameter_constraint,
      sym_item_extension,
      sym_quoted_item_extension,
  [586342] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15101), 1,
      anon_sym_PIPE,
    STATE(12086), 1,
      sym_attribute,
    STATE(12088), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [586378] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15101), 1,
      anon_sym_PIPE,
    STATE(12087), 1,
      sym_attribute,
    STATE(12091), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [586414] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15101), 1,
      anon_sym_PIPE,
    STATE(12088), 1,
      sym_attribute,
    STATE(12094), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [586450] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14801), 1,
      anon_sym_and,
    ACTIONS(15059), 1,
      anon_sym_let,
    STATE(12089), 1,
      sym_attribute,
    STATE(12093), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15057), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [586486] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12090), 1,
      sym_attribute,
    STATE(13031), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [586534] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15101), 1,
      anon_sym_PIPE,
    STATE(12091), 1,
      sym_attribute,
    STATE(12094), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [586570] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(8919), 1,
      sym__module_expression,
    STATE(12092), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [586618] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14801), 1,
      anon_sym_and,
    ACTIONS(15040), 1,
      anon_sym_let,
    STATE(12082), 1,
      aux_sym_type_definition_repeat1,
    STATE(12093), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15038), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [586654] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15103), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12094), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [586688] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12095), 1,
      sym_attribute,
    STATE(13081), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [586736] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12096), 1,
      sym_attribute,
    STATE(13013), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [586784] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(2231), 1,
      sym_add_operator,
    STATE(12097), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [586818] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14787), 1,
      anon_sym_else,
    STATE(8259), 1,
      sym_else_clause,
    STATE(12098), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [586854] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12099), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11845), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11562), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11560), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [586888] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15106), 1,
      anon_sym_PIPE,
    STATE(12100), 1,
      sym_attribute,
    STATE(12102), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [586924] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15106), 1,
      anon_sym_PIPE,
    STATE(12101), 1,
      sym_attribute,
    STATE(12103), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [586960] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15106), 1,
      anon_sym_PIPE,
    STATE(12102), 1,
      sym_attribute,
    STATE(12111), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [586996] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15106), 1,
      anon_sym_PIPE,
    STATE(12103), 1,
      sym_attribute,
    STATE(12111), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [587032] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10344), 1,
      anon_sym_PIPE,
    ACTIONS(14864), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14866), 1,
      sym_pow_operator,
    ACTIONS(14868), 1,
      sym_mult_operator,
    ACTIONS(14870), 1,
      sym_concat_operator,
    ACTIONS(14872), 1,
      sym_rel_operator,
    ACTIONS(14874), 1,
      sym_and_operator,
    ACTIONS(14876), 1,
      sym_or_operator,
    STATE(2090), 1,
      sym_add_operator,
    STATE(12104), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
      sym_assign_operator,
  [587082] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14864), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14866), 1,
      sym_pow_operator,
    ACTIONS(14868), 1,
      sym_mult_operator,
    STATE(2090), 1,
      sym_add_operator,
    STATE(12105), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [587124] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14866), 1,
      sym_pow_operator,
    STATE(2090), 1,
      sym_add_operator,
    STATE(12106), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [587160] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14866), 1,
      sym_pow_operator,
    STATE(2090), 1,
      sym_add_operator,
    STATE(12107), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [587196] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14864), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14866), 1,
      sym_pow_operator,
    ACTIONS(14868), 1,
      sym_mult_operator,
    ACTIONS(14870), 1,
      sym_concat_operator,
    STATE(2090), 1,
      sym_add_operator,
    STATE(12108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [587240] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14864), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14866), 1,
      sym_pow_operator,
    ACTIONS(14868), 1,
      sym_mult_operator,
    ACTIONS(14870), 1,
      sym_concat_operator,
    STATE(2090), 1,
      sym_add_operator,
    STATE(12109), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [587284] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14864), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14866), 1,
      sym_pow_operator,
    ACTIONS(14868), 1,
      sym_mult_operator,
    ACTIONS(14870), 1,
      sym_concat_operator,
    ACTIONS(14872), 1,
      sym_rel_operator,
    ACTIONS(14874), 1,
      sym_and_operator,
    STATE(2090), 1,
      sym_add_operator,
    STATE(12110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
      sym_assign_operator,
  [587332] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15108), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12111), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [587366] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15036), 1,
      anon_sym_let,
    ACTIONS(15111), 1,
      anon_sym_and,
    STATE(12112), 1,
      sym_attribute,
    STATE(12206), 1,
      aux_sym_class_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15034), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [587402] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(14864), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14866), 1,
      sym_pow_operator,
    ACTIONS(14868), 1,
      sym_mult_operator,
    ACTIONS(14870), 1,
      sym_concat_operator,
    ACTIONS(14872), 1,
      sym_rel_operator,
    ACTIONS(14874), 1,
      sym_and_operator,
    ACTIONS(14876), 1,
      sym_or_operator,
    STATE(2090), 1,
      sym_add_operator,
    STATE(12113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
      sym_assign_operator,
  [587452] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(14860), 1,
      anon_sym_COMMA,
    ACTIONS(14864), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14866), 1,
      sym_pow_operator,
    ACTIONS(14868), 1,
      sym_mult_operator,
    ACTIONS(14870), 1,
      sym_concat_operator,
    ACTIONS(14872), 1,
      sym_rel_operator,
    ACTIONS(14874), 1,
      sym_and_operator,
    ACTIONS(14876), 1,
      sym_or_operator,
    ACTIONS(14878), 1,
      sym_assign_operator,
    STATE(2090), 1,
      sym_add_operator,
    STATE(12114), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 3,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [587506] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15113), 1,
      anon_sym_else,
    STATE(8259), 1,
      sym_else_clause,
    STATE(12115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [587542] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14866), 1,
      sym_pow_operator,
    ACTIONS(14868), 1,
      sym_mult_operator,
    STATE(2090), 1,
      sym_add_operator,
    STATE(12116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [587580] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12117), 1,
      sym_attribute,
    STATE(13040), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [587628] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10303), 1,
      anon_sym_PIPE,
    ACTIONS(14860), 1,
      anon_sym_COMMA,
    ACTIONS(14864), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14866), 1,
      sym_pow_operator,
    ACTIONS(14868), 1,
      sym_mult_operator,
    ACTIONS(14870), 1,
      sym_concat_operator,
    ACTIONS(14872), 1,
      sym_rel_operator,
    ACTIONS(14874), 1,
      sym_and_operator,
    ACTIONS(14876), 1,
      sym_or_operator,
    ACTIONS(14878), 1,
      sym_assign_operator,
    STATE(2090), 1,
      sym_add_operator,
    STATE(12118), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10301), 3,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
  [587682] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15113), 1,
      anon_sym_else,
    STATE(8278), 1,
      sym_else_clause,
    STATE(12119), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [587718] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10340), 1,
      anon_sym_PIPE,
    ACTIONS(14860), 1,
      anon_sym_COMMA,
    ACTIONS(14864), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14866), 1,
      sym_pow_operator,
    ACTIONS(14868), 1,
      sym_mult_operator,
    ACTIONS(14870), 1,
      sym_concat_operator,
    ACTIONS(14872), 1,
      sym_rel_operator,
    ACTIONS(14874), 1,
      sym_and_operator,
    ACTIONS(14876), 1,
      sym_or_operator,
    ACTIONS(14878), 1,
      sym_assign_operator,
    STATE(2090), 1,
      sym_add_operator,
    STATE(12120), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10338), 3,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
  [587772] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(2090), 1,
      sym_add_operator,
    STATE(12121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [587806] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12906), 1,
      anon_sym_STAR,
    ACTIONS(13445), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(12122), 1,
      sym_attribute,
    STATE(12125), 1,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13443), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [587842] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10340), 1,
      anon_sym_PIPE,
    ACTIONS(14747), 1,
      anon_sym_COMMA,
    ACTIONS(14751), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14753), 1,
      sym_pow_operator,
    ACTIONS(14755), 1,
      sym_mult_operator,
    ACTIONS(14757), 1,
      sym_concat_operator,
    ACTIONS(14759), 1,
      sym_rel_operator,
    ACTIONS(14761), 1,
      sym_and_operator,
    ACTIONS(14763), 1,
      sym_or_operator,
    ACTIONS(14765), 1,
      sym_assign_operator,
    STATE(2130), 1,
      sym_add_operator,
    STATE(12123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10338), 3,
      anon_sym_SEMI,
      anon_sym_to,
      anon_sym_downto,
  [587896] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14793), 1,
      anon_sym_let,
    ACTIONS(15111), 1,
      anon_sym_and,
    STATE(12124), 1,
      sym_attribute,
    STATE(12206), 1,
      aux_sym_class_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14791), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [587932] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12087), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15115), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12125), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(12085), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [587966] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14793), 1,
      anon_sym_let,
    ACTIONS(15111), 1,
      anon_sym_and,
    STATE(12112), 1,
      aux_sym_class_definition_repeat1,
    STATE(12126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14791), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [588002] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14981), 1,
      anon_sym_let,
    ACTIONS(15111), 1,
      anon_sym_and,
    STATE(12124), 1,
      aux_sym_class_definition_repeat1,
    STATE(12127), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14979), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [588038] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8596), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8598), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13610), 1,
      anon_sym_LPAREN,
    ACTIONS(13614), 1,
      anon_sym_functor,
    ACTIONS(13616), 1,
      anon_sym_struct,
    ACTIONS(13620), 1,
      sym__uppercase_identifier,
    STATE(12128), 1,
      sym_attribute,
    STATE(12829), 1,
      sym__module_expression,
    STATE(13140), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13223), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(13238), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [588086] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10344), 1,
      anon_sym_PIPE,
    ACTIONS(14957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14959), 1,
      sym_pow_operator,
    ACTIONS(14961), 1,
      sym_mult_operator,
    ACTIONS(14963), 1,
      sym_concat_operator,
    ACTIONS(14965), 1,
      sym_rel_operator,
    ACTIONS(14967), 1,
      sym_and_operator,
    ACTIONS(14969), 1,
      sym_or_operator,
    STATE(2154), 1,
      sym_add_operator,
    STATE(12129), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
      sym_assign_operator,
  [588136] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14959), 1,
      sym_pow_operator,
    ACTIONS(14961), 1,
      sym_mult_operator,
    STATE(2154), 1,
      sym_add_operator,
    STATE(12130), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [588178] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(14858), 1,
      anon_sym_DASH_GT,
    ACTIONS(15120), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(12131), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15118), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [588214] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8364), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      sym__uppercase_identifier,
  [588246] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(14858), 1,
      anon_sym_DASH_GT,
    ACTIONS(15124), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(12133), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15122), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [588282] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14959), 1,
      sym_pow_operator,
    STATE(2154), 1,
      sym_add_operator,
    STATE(12134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [588318] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14959), 1,
      sym_pow_operator,
    STATE(2154), 1,
      sym_add_operator,
    STATE(12135), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [588354] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14959), 1,
      sym_pow_operator,
    ACTIONS(14961), 1,
      sym_mult_operator,
    ACTIONS(14963), 1,
      sym_concat_operator,
    STATE(2154), 1,
      sym_add_operator,
    STATE(12136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [588398] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12137), 1,
      sym_attribute,
    STATE(13068), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [588446] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12138), 1,
      sym_attribute,
    STATE(13018), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [588494] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14959), 1,
      sym_pow_operator,
    ACTIONS(14961), 1,
      sym_mult_operator,
    ACTIONS(14963), 1,
      sym_concat_operator,
    STATE(2154), 1,
      sym_add_operator,
    STATE(12139), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [588538] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14959), 1,
      sym_pow_operator,
    ACTIONS(14961), 1,
      sym_mult_operator,
    ACTIONS(14963), 1,
      sym_concat_operator,
    ACTIONS(14965), 1,
      sym_rel_operator,
    ACTIONS(14967), 1,
      sym_and_operator,
    STATE(2154), 1,
      sym_add_operator,
    STATE(12140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
      sym_assign_operator,
  [588586] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(14957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14959), 1,
      sym_pow_operator,
    ACTIONS(14961), 1,
      sym_mult_operator,
    ACTIONS(14963), 1,
      sym_concat_operator,
    ACTIONS(14965), 1,
      sym_rel_operator,
    ACTIONS(14967), 1,
      sym_and_operator,
    ACTIONS(14969), 1,
      sym_or_operator,
    STATE(2154), 1,
      sym_add_operator,
    STATE(12141), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
      sym_assign_operator,
  [588636] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15023), 1,
      anon_sym_else,
    STATE(10654), 1,
      sym_else_clause,
    STATE(12142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [588672] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(1834), 1,
      sym_add_operator,
    STATE(12143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [588706] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12144), 1,
      sym_attribute,
    STATE(12936), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [588754] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(14953), 1,
      anon_sym_COMMA,
    ACTIONS(14957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14959), 1,
      sym_pow_operator,
    ACTIONS(14961), 1,
      sym_mult_operator,
    ACTIONS(14963), 1,
      sym_concat_operator,
    ACTIONS(14965), 1,
      sym_rel_operator,
    ACTIONS(14967), 1,
      sym_and_operator,
    ACTIONS(14969), 1,
      sym_or_operator,
    ACTIONS(14971), 1,
      sym_assign_operator,
    STATE(2154), 1,
      sym_add_operator,
    STATE(12145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 3,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [588808] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14959), 1,
      sym_pow_operator,
    ACTIONS(14961), 1,
      sym_mult_operator,
    STATE(2154), 1,
      sym_add_operator,
    STATE(12146), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [588846] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10303), 1,
      anon_sym_PIPE,
    ACTIONS(14953), 1,
      anon_sym_COMMA,
    ACTIONS(14957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14959), 1,
      sym_pow_operator,
    ACTIONS(14961), 1,
      sym_mult_operator,
    ACTIONS(14963), 1,
      sym_concat_operator,
    ACTIONS(14965), 1,
      sym_rel_operator,
    ACTIONS(14967), 1,
      sym_and_operator,
    ACTIONS(14969), 1,
      sym_or_operator,
    ACTIONS(14971), 1,
      sym_assign_operator,
    STATE(2154), 1,
      sym_add_operator,
    STATE(12147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10301), 3,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
  [588900] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15017), 1,
      anon_sym_else,
    STATE(8259), 1,
      sym_else_clause,
    STATE(12148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [588936] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(15044), 1,
      sym__lowercase_identifier,
    ACTIONS(15126), 1,
      anon_sym_POUND,
    STATE(12149), 1,
      sym_attribute,
    STATE(12631), 1,
      sym_type_constructor_path,
    STATE(17280), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10261), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(10263), 7,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [588978] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15128), 1,
      anon_sym_else,
    STATE(8278), 1,
      sym_else_clause,
    STATE(12150), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [589014] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15130), 1,
      anon_sym_PIPE,
    STATE(12151), 1,
      sym_attribute,
    STATE(12154), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [589050] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15130), 1,
      anon_sym_PIPE,
    STATE(12152), 1,
      sym_attribute,
    STATE(12159), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [589086] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10340), 1,
      anon_sym_PIPE,
    ACTIONS(14953), 1,
      anon_sym_COMMA,
    ACTIONS(14957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14959), 1,
      sym_pow_operator,
    ACTIONS(14961), 1,
      sym_mult_operator,
    ACTIONS(14963), 1,
      sym_concat_operator,
    ACTIONS(14965), 1,
      sym_rel_operator,
    ACTIONS(14967), 1,
      sym_and_operator,
    ACTIONS(14969), 1,
      sym_or_operator,
    ACTIONS(14971), 1,
      sym_assign_operator,
    STATE(2154), 1,
      sym_add_operator,
    STATE(12153), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10338), 3,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
  [589140] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15130), 1,
      anon_sym_PIPE,
    STATE(12154), 1,
      sym_attribute,
    STATE(12161), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [589176] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8360), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      sym__uppercase_identifier,
  [589208] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12156), 1,
      sym_attribute,
    STATE(13117), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [589256] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10303), 1,
      anon_sym_PIPE,
    ACTIONS(14747), 1,
      anon_sym_COMMA,
    ACTIONS(14751), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14753), 1,
      sym_pow_operator,
    ACTIONS(14755), 1,
      sym_mult_operator,
    ACTIONS(14757), 1,
      sym_concat_operator,
    ACTIONS(14759), 1,
      sym_rel_operator,
    ACTIONS(14761), 1,
      sym_and_operator,
    ACTIONS(14763), 1,
      sym_or_operator,
    ACTIONS(14765), 1,
      sym_assign_operator,
    STATE(2130), 1,
      sym_add_operator,
    STATE(12157), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10301), 3,
      anon_sym_SEMI,
      anon_sym_to,
      anon_sym_downto,
  [589310] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12158), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8356), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      sym__uppercase_identifier,
  [589342] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15130), 1,
      anon_sym_PIPE,
    STATE(12159), 1,
      sym_attribute,
    STATE(12161), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [589378] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14753), 1,
      sym_pow_operator,
    ACTIONS(14755), 1,
      sym_mult_operator,
    STATE(2130), 1,
      sym_add_operator,
    STATE(12160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [589416] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15132), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12161), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [589450] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(8971), 1,
      sym__module_expression,
    STATE(12162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [589498] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(14747), 1,
      anon_sym_COMMA,
    ACTIONS(14751), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14753), 1,
      sym_pow_operator,
    ACTIONS(14755), 1,
      sym_mult_operator,
    ACTIONS(14757), 1,
      sym_concat_operator,
    ACTIONS(14759), 1,
      sym_rel_operator,
    ACTIONS(14761), 1,
      sym_and_operator,
    ACTIONS(14763), 1,
      sym_or_operator,
    ACTIONS(14765), 1,
      sym_assign_operator,
    STATE(2130), 1,
      sym_add_operator,
    STATE(12163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 3,
      anon_sym_SEMI,
      anon_sym_to,
      anon_sym_downto,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [589552] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(14751), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14753), 1,
      sym_pow_operator,
    ACTIONS(14755), 1,
      sym_mult_operator,
    ACTIONS(14757), 1,
      sym_concat_operator,
    ACTIONS(14759), 1,
      sym_rel_operator,
    ACTIONS(14761), 1,
      sym_and_operator,
    ACTIONS(14763), 1,
      sym_or_operator,
    STATE(2130), 1,
      sym_add_operator,
    STATE(12164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_to,
      anon_sym_downto,
      sym_assign_operator,
  [589602] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12165), 1,
      sym_attribute,
    STATE(13034), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [589650] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14751), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14753), 1,
      sym_pow_operator,
    ACTIONS(14755), 1,
      sym_mult_operator,
    ACTIONS(14757), 1,
      sym_concat_operator,
    ACTIONS(14759), 1,
      sym_rel_operator,
    ACTIONS(14761), 1,
      sym_and_operator,
    STATE(2130), 1,
      sym_add_operator,
    STATE(12166), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_to,
      anon_sym_downto,
      sym_assign_operator,
  [589698] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14751), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14753), 1,
      sym_pow_operator,
    ACTIONS(14755), 1,
      sym_mult_operator,
    ACTIONS(14757), 1,
      sym_concat_operator,
    STATE(2130), 1,
      sym_add_operator,
    STATE(12167), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_to,
      anon_sym_downto,
      sym_rel_operator,
      sym_assign_operator,
  [589742] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14751), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14753), 1,
      sym_pow_operator,
    ACTIONS(14755), 1,
      sym_mult_operator,
    ACTIONS(14757), 1,
      sym_concat_operator,
    STATE(2130), 1,
      sym_add_operator,
    STATE(12168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_to,
      anon_sym_downto,
      sym_rel_operator,
      sym_assign_operator,
  [589786] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14753), 1,
      sym_pow_operator,
    STATE(2130), 1,
      sym_add_operator,
    STATE(12169), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [589822] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10340), 1,
      anon_sym_PIPE,
    ACTIONS(14983), 1,
      anon_sym_COMMA,
    ACTIONS(14987), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14989), 1,
      sym_pow_operator,
    ACTIONS(14991), 1,
      sym_mult_operator,
    ACTIONS(14993), 1,
      sym_concat_operator,
    ACTIONS(14995), 1,
      sym_rel_operator,
    ACTIONS(14997), 1,
      sym_and_operator,
    ACTIONS(14999), 1,
      sym_or_operator,
    ACTIONS(15001), 1,
      sym_assign_operator,
    STATE(2035), 1,
      sym_add_operator,
    STATE(12170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10338), 3,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
  [589876] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15007), 1,
      anon_sym_else,
    STATE(8278), 1,
      sym_else_clause,
    STATE(12171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [589912] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14753), 1,
      sym_pow_operator,
    STATE(2130), 1,
      sym_add_operator,
    STATE(12172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [589948] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15013), 1,
      anon_sym_let,
    ACTIONS(15015), 1,
      anon_sym_and,
    STATE(12173), 1,
      sym_attribute,
    STATE(12199), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15011), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [589984] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9158), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(9160), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      sym__uppercase_identifier,
  [590016] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10303), 1,
      anon_sym_PIPE,
    ACTIONS(14983), 1,
      anon_sym_COMMA,
    ACTIONS(14987), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14989), 1,
      sym_pow_operator,
    ACTIONS(14991), 1,
      sym_mult_operator,
    ACTIONS(14993), 1,
      sym_concat_operator,
    ACTIONS(14995), 1,
      sym_rel_operator,
    ACTIONS(14997), 1,
      sym_and_operator,
    ACTIONS(14999), 1,
      sym_or_operator,
    ACTIONS(15001), 1,
      sym_assign_operator,
    STATE(2035), 1,
      sym_add_operator,
    STATE(12175), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10301), 3,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
  [590070] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14989), 1,
      sym_pow_operator,
    ACTIONS(14991), 1,
      sym_mult_operator,
    STATE(2035), 1,
      sym_add_operator,
    STATE(12176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [590108] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12177), 1,
      sym_attribute,
    STATE(12948), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [590156] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8570), 1,
      sym__module_expression,
    STATE(8633), 1,
      sym_module_path,
    STATE(12178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [590204] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(14983), 1,
      anon_sym_COMMA,
    ACTIONS(14987), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14989), 1,
      sym_pow_operator,
    ACTIONS(14991), 1,
      sym_mult_operator,
    ACTIONS(14993), 1,
      sym_concat_operator,
    ACTIONS(14995), 1,
      sym_rel_operator,
    ACTIONS(14997), 1,
      sym_and_operator,
    ACTIONS(14999), 1,
      sym_or_operator,
    ACTIONS(15001), 1,
      sym_assign_operator,
    STATE(2035), 1,
      sym_add_operator,
    STATE(12179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 3,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [590258] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12180), 1,
      sym_attribute,
    STATE(12966), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [590306] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(14715), 1,
      anon_sym_constraint,
    ACTIONS(14717), 1,
      anon_sym_val,
    ACTIONS(14721), 1,
      anon_sym_inherit,
    ACTIONS(14723), 1,
      anon_sym_method,
    ACTIONS(15135), 1,
      anon_sym_end,
    STATE(12085), 1,
      aux_sym_class_body_type_repeat1,
    STATE(12181), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13437), 2,
      sym__class_field_specification,
      sym_floating_attribute,
    STATE(13441), 6,
      sym_inheritance_specification,
      sym_instance_variable_specification,
      sym_method_specification,
      sym_type_parameter_constraint,
      sym_item_extension,
      sym_quoted_item_extension,
  [590356] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14751), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14753), 1,
      sym_pow_operator,
    ACTIONS(14755), 1,
      sym_mult_operator,
    STATE(2130), 1,
      sym_add_operator,
    STATE(12182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_to,
      anon_sym_downto,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [590398] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10344), 1,
      anon_sym_PIPE,
    ACTIONS(14751), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14753), 1,
      sym_pow_operator,
    ACTIONS(14755), 1,
      sym_mult_operator,
    ACTIONS(14757), 1,
      sym_concat_operator,
    ACTIONS(14759), 1,
      sym_rel_operator,
    ACTIONS(14761), 1,
      sym_and_operator,
    ACTIONS(14763), 1,
      sym_or_operator,
    STATE(2130), 1,
      sym_add_operator,
    STATE(12183), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_to,
      anon_sym_downto,
      sym_assign_operator,
  [590448] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(14987), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14989), 1,
      sym_pow_operator,
    ACTIONS(14991), 1,
      sym_mult_operator,
    ACTIONS(14993), 1,
      sym_concat_operator,
    ACTIONS(14995), 1,
      sym_rel_operator,
    ACTIONS(14997), 1,
      sym_and_operator,
    ACTIONS(14999), 1,
      sym_or_operator,
    STATE(2035), 1,
      sym_add_operator,
    STATE(12184), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
      sym_assign_operator,
  [590498] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12185), 1,
      sym_attribute,
    STATE(12992), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [590546] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15015), 1,
      anon_sym_and,
    ACTIONS(15066), 1,
      anon_sym_let,
    STATE(12186), 1,
      sym_attribute,
    STATE(12199), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15064), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [590582] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14987), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14989), 1,
      sym_pow_operator,
    ACTIONS(14991), 1,
      sym_mult_operator,
    ACTIONS(14993), 1,
      sym_concat_operator,
    ACTIONS(14995), 1,
      sym_rel_operator,
    ACTIONS(14997), 1,
      sym_and_operator,
    STATE(2035), 1,
      sym_add_operator,
    STATE(12187), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
      sym_assign_operator,
  [590630] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10332), 1,
      anon_sym_PIPE,
    ACTIONS(14953), 1,
      anon_sym_COMMA,
    ACTIONS(14957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14959), 1,
      sym_pow_operator,
    ACTIONS(14961), 1,
      sym_mult_operator,
    ACTIONS(14963), 1,
      sym_concat_operator,
    ACTIONS(14965), 1,
      sym_rel_operator,
    ACTIONS(14967), 1,
      sym_and_operator,
    ACTIONS(14969), 1,
      sym_or_operator,
    ACTIONS(14971), 1,
      sym_assign_operator,
    STATE(2154), 1,
      sym_add_operator,
    STATE(12188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10330), 3,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
  [590684] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14929), 1,
      anon_sym_let,
    ACTIONS(15015), 1,
      anon_sym_and,
    STATE(12186), 1,
      aux_sym_module_definition_repeat1,
    STATE(12189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14927), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [590720] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14987), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14989), 1,
      sym_pow_operator,
    ACTIONS(14991), 1,
      sym_mult_operator,
    ACTIONS(14993), 1,
      sym_concat_operator,
    STATE(2035), 1,
      sym_add_operator,
    STATE(12190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [590764] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14987), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14989), 1,
      sym_pow_operator,
    ACTIONS(14991), 1,
      sym_mult_operator,
    ACTIONS(14993), 1,
      sym_concat_operator,
    STATE(2035), 1,
      sym_add_operator,
    STATE(12191), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [590808] = 19,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(14910), 1,
      anon_sym_LPAREN,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(14918), 1,
      anon_sym__,
    ACTIONS(15137), 1,
      sym__lowercase_identifier,
    ACTIONS(15139), 1,
      anon_sym_nonrec,
    STATE(12192), 1,
      sym_attribute,
    STATE(12202), 1,
      sym_type_binding,
    STATE(12735), 1,
      sym__attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(14599), 1,
      sym__type_params,
    STATE(16510), 1,
      sym__type_param,
    STATE(16511), 1,
      sym_extended_module_path,
    STATE(20242), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [590868] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14989), 1,
      sym_pow_operator,
    STATE(2035), 1,
      sym_add_operator,
    STATE(12193), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [590904] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12194), 1,
      sym_attribute,
    STATE(12957), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [590952] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14989), 1,
      sym_pow_operator,
    STATE(2035), 1,
      sym_add_operator,
    STATE(12195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [590988] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14987), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14989), 1,
      sym_pow_operator,
    ACTIONS(14991), 1,
      sym_mult_operator,
    STATE(2035), 1,
      sym_add_operator,
    STATE(12196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [591030] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10344), 1,
      anon_sym_PIPE,
    ACTIONS(14987), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14989), 1,
      sym_pow_operator,
    ACTIONS(14991), 1,
      sym_mult_operator,
    ACTIONS(14993), 1,
      sym_concat_operator,
    ACTIONS(14995), 1,
      sym_rel_operator,
    ACTIONS(14997), 1,
      sym_and_operator,
    ACTIONS(14999), 1,
      sym_or_operator,
    STATE(2035), 1,
      sym_add_operator,
    STATE(12197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
      sym_assign_operator,
  [591080] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11264), 1,
      anon_sym_COLON2,
    STATE(12198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9158), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(9160), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [591114] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14172), 1,
      anon_sym_let,
    ACTIONS(15141), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12199), 2,
      sym_attribute,
      aux_sym_module_definition_repeat1,
    ACTIONS(14170), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [591148] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8350), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8352), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      sym__uppercase_identifier,
  [591180] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14799), 1,
      anon_sym_let,
    ACTIONS(15042), 1,
      anon_sym_and,
    STATE(12074), 1,
      aux_sym_type_definition_repeat1,
    STATE(12201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14797), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [591216] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14906), 1,
      anon_sym_let,
    ACTIONS(15042), 1,
      anon_sym_and,
    STATE(12078), 1,
      aux_sym_type_definition_repeat1,
    STATE(12202), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14904), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [591252] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14929), 1,
      anon_sym_let,
    ACTIONS(15015), 1,
      anon_sym_and,
    STATE(12199), 1,
      aux_sym_module_definition_repeat1,
    STATE(12203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14927), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [591288] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12204), 1,
      sym_attribute,
    STATE(12972), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [591336] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(2154), 1,
      sym_add_operator,
    STATE(12205), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [591370] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13931), 1,
      anon_sym_let,
    ACTIONS(15144), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12206), 2,
      sym_attribute,
      aux_sym_class_definition_repeat1,
    ACTIONS(13929), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [591404] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13773), 1,
      anon_sym_LPAREN,
    ACTIONS(13777), 1,
      anon_sym_functor,
    ACTIONS(13779), 1,
      anon_sym_struct,
    STATE(8633), 1,
      sym_module_path,
    STATE(12207), 1,
      sym_attribute,
    STATE(12965), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8915), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [591452] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15128), 1,
      anon_sym_else,
    STATE(8259), 1,
      sym_else_clause,
    STATE(12208), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [591488] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(15044), 1,
      sym__lowercase_identifier,
    ACTIONS(15126), 1,
      anon_sym_POUND,
    STATE(12209), 1,
      sym_attribute,
    STATE(12631), 1,
      sym_type_constructor_path,
    STATE(17280), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11124), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11126), 7,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [591530] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10332), 1,
      anon_sym_PIPE,
    ACTIONS(14983), 1,
      anon_sym_COMMA,
    ACTIONS(14987), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14989), 1,
      sym_pow_operator,
    ACTIONS(14991), 1,
      sym_mult_operator,
    ACTIONS(14993), 1,
      sym_concat_operator,
    ACTIONS(14995), 1,
      sym_rel_operator,
    ACTIONS(14997), 1,
      sym_and_operator,
    ACTIONS(14999), 1,
      sym_or_operator,
    ACTIONS(15001), 1,
      sym_assign_operator,
    STATE(2035), 1,
      sym_add_operator,
    STATE(12210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10330), 3,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
  [591584] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14789), 1,
      anon_sym_else,
    STATE(10470), 1,
      sym_else_clause,
    STATE(12211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [591620] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15147), 1,
      anon_sym_RBRACK,
    ACTIONS(15149), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12212), 1,
      sym_attribute,
    STATE(15851), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [591675] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15151), 1,
      sym_pow_operator,
    STATE(2365), 1,
      sym_add_operator,
    STATE(12213), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [591710] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10340), 1,
      anon_sym_PIPE,
    ACTIONS(15153), 1,
      anon_sym_COMMA,
    ACTIONS(15155), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15157), 1,
      sym_pow_operator,
    ACTIONS(15159), 1,
      sym_mult_operator,
    ACTIONS(15161), 1,
      sym_concat_operator,
    ACTIONS(15163), 1,
      sym_rel_operator,
    ACTIONS(15165), 1,
      sym_and_operator,
    ACTIONS(15167), 1,
      sym_or_operator,
    ACTIONS(15169), 1,
      sym_assign_operator,
    STATE(2168), 1,
      sym_add_operator,
    STATE(12214), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10338), 2,
      anon_sym_SEMI,
      anon_sym_done,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [591763] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15171), 1,
      anon_sym_DQUOTE,
    STATE(12215), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19478), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [591804] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15179), 1,
      anon_sym_RBRACK,
    ACTIONS(15181), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12216), 1,
      sym_attribute,
    STATE(15266), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [591859] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15185), 1,
      anon_sym_SEMI,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15189), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12217), 1,
      sym_attribute,
    STATE(16268), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [591914] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15205), 1,
      anon_sym_DQUOTE,
    STATE(12218), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19436), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [591955] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10303), 1,
      anon_sym_PIPE,
    ACTIONS(15153), 1,
      anon_sym_COMMA,
    ACTIONS(15155), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15157), 1,
      sym_pow_operator,
    ACTIONS(15159), 1,
      sym_mult_operator,
    ACTIONS(15161), 1,
      sym_concat_operator,
    ACTIONS(15163), 1,
      sym_rel_operator,
    ACTIONS(15165), 1,
      sym_and_operator,
    ACTIONS(15167), 1,
      sym_or_operator,
    ACTIONS(15169), 1,
      sym_assign_operator,
    STATE(2168), 1,
      sym_add_operator,
    STATE(12219), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10301), 2,
      anon_sym_SEMI,
      anon_sym_done,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [592008] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15207), 1,
      anon_sym_DQUOTE,
    STATE(12220), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19621), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [592049] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15209), 1,
      anon_sym_DQUOTE,
    STATE(12221), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19526), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [592090] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15211), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12222), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [592123] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12223), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11414), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11416), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [592154] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15214), 1,
      anon_sym_PIPE,
    STATE(12222), 1,
      aux_sym__match_cases_repeat1,
    STATE(12224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [592189] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15157), 1,
      sym_pow_operator,
    ACTIONS(15159), 1,
      sym_mult_operator,
    STATE(2168), 1,
      sym_add_operator,
    STATE(12225), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [592226] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12226), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11704), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11706), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [592257] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15214), 1,
      anon_sym_PIPE,
    STATE(12222), 1,
      aux_sym__match_cases_repeat1,
    STATE(12227), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [592292] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(15153), 1,
      anon_sym_COMMA,
    ACTIONS(15155), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15157), 1,
      sym_pow_operator,
    ACTIONS(15159), 1,
      sym_mult_operator,
    ACTIONS(15161), 1,
      sym_concat_operator,
    ACTIONS(15163), 1,
      sym_rel_operator,
    ACTIONS(15165), 1,
      sym_and_operator,
    ACTIONS(15167), 1,
      sym_or_operator,
    ACTIONS(15169), 1,
      sym_assign_operator,
    STATE(2168), 1,
      sym_add_operator,
    STATE(12228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 2,
      anon_sym_SEMI,
      anon_sym_done,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [592345] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15214), 1,
      anon_sym_PIPE,
    STATE(12224), 1,
      aux_sym__match_cases_repeat1,
    STATE(12229), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [592380] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11600), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11602), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [592411] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(15155), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15157), 1,
      sym_pow_operator,
    ACTIONS(15159), 1,
      sym_mult_operator,
    ACTIONS(15161), 1,
      sym_concat_operator,
    ACTIONS(15163), 1,
      sym_rel_operator,
    ACTIONS(15165), 1,
      sym_and_operator,
    ACTIONS(15167), 1,
      sym_or_operator,
    STATE(2168), 1,
      sym_add_operator,
    STATE(12231), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_done,
      sym_assign_operator,
  [592460] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12232), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11474), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11476), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [592491] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15216), 1,
      anon_sym_SEMI,
    ACTIONS(15218), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12233), 1,
      sym_attribute,
    STATE(16091), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [592546] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15214), 1,
      anon_sym_PIPE,
    STATE(12227), 1,
      aux_sym__match_cases_repeat1,
    STATE(12234), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [592581] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15220), 1,
      anon_sym_RBRACK,
    ACTIONS(15222), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12235), 1,
      sym_attribute,
    STATE(16082), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [592636] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15155), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15157), 1,
      sym_pow_operator,
    ACTIONS(15159), 1,
      sym_mult_operator,
    ACTIONS(15161), 1,
      sym_concat_operator,
    ACTIONS(15163), 1,
      sym_rel_operator,
    ACTIONS(15165), 1,
      sym_and_operator,
    STATE(2168), 1,
      sym_add_operator,
    STATE(12236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_done,
      sym_assign_operator,
  [592683] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15224), 1,
      anon_sym_DQUOTE,
    STATE(12237), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19581), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [592724] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15155), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15157), 1,
      sym_pow_operator,
    ACTIONS(15159), 1,
      sym_mult_operator,
    ACTIONS(15161), 1,
      sym_concat_operator,
    STATE(2168), 1,
      sym_add_operator,
    STATE(12238), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_done,
      sym_rel_operator,
      sym_assign_operator,
  [592767] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15155), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15157), 1,
      sym_pow_operator,
    ACTIONS(15159), 1,
      sym_mult_operator,
    ACTIONS(15161), 1,
      sym_concat_operator,
    STATE(2168), 1,
      sym_add_operator,
    STATE(12239), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_done,
      sym_rel_operator,
      sym_assign_operator,
  [592810] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15226), 1,
      anon_sym_DQUOTE,
    STATE(12240), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(17707), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [592851] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15228), 1,
      anon_sym_COLON_GT,
    ACTIONS(15230), 1,
      anon_sym_EQ,
    ACTIONS(15232), 1,
      anon_sym_COLON2,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12241), 1,
      sym_attribute,
    STATE(12836), 1,
      sym__typed,
    STATE(13072), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15234), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [592894] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15157), 1,
      sym_pow_operator,
    STATE(2168), 1,
      sym_add_operator,
    STATE(12242), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [592929] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15236), 1,
      anon_sym_DQUOTE,
    STATE(12243), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(17605), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [592970] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15238), 1,
      anon_sym_DQUOTE,
    STATE(12244), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19685), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [593011] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15240), 1,
      anon_sym_DQUOTE,
    STATE(12245), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19741), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [593052] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15242), 1,
      anon_sym_RBRACK,
    ACTIONS(15244), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12246), 1,
      sym_attribute,
    STATE(16433), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [593107] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15246), 1,
      anon_sym_SEMI,
    ACTIONS(15248), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12247), 1,
      sym_attribute,
    STATE(16425), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [593162] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15157), 1,
      sym_pow_operator,
    STATE(2168), 1,
      sym_add_operator,
    STATE(12248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [593197] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12249), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11560), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11562), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [593228] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15250), 1,
      anon_sym_SEMI,
    ACTIONS(15252), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12250), 1,
      sym_attribute,
    STATE(16307), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [593283] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15254), 1,
      anon_sym_DQUOTE,
    STATE(12251), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19813), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [593324] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(1865), 1,
      sym_add_operator,
    STATE(12252), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [593357] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15256), 1,
      anon_sym_else,
    STATE(7952), 1,
      sym_else_clause,
    STATE(12253), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [593392] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15155), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15157), 1,
      sym_pow_operator,
    ACTIONS(15159), 1,
      sym_mult_operator,
    STATE(2168), 1,
      sym_add_operator,
    STATE(12254), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_done,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [593433] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15258), 1,
      anon_sym_DQUOTE,
    STATE(12255), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19393), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [593474] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15260), 1,
      anon_sym_SEMI,
    ACTIONS(15262), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12256), 1,
      sym_attribute,
    STATE(15913), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [593529] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10344), 1,
      anon_sym_PIPE,
    ACTIONS(15155), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15157), 1,
      sym_pow_operator,
    ACTIONS(15159), 1,
      sym_mult_operator,
    ACTIONS(15161), 1,
      sym_concat_operator,
    ACTIONS(15163), 1,
      sym_rel_operator,
    ACTIONS(15165), 1,
      sym_and_operator,
    ACTIONS(15167), 1,
      sym_or_operator,
    STATE(2168), 1,
      sym_add_operator,
    STATE(12257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_done,
      sym_assign_operator,
  [593578] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15264), 1,
      anon_sym_DQUOTE,
    STATE(12258), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(17755), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [593619] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(13279), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15266), 1,
      anon_sym_DASH_GT,
    STATE(12259), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13277), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [593654] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15268), 1,
      anon_sym_RBRACK,
    ACTIONS(15270), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12260), 1,
      sym_attribute,
    STATE(15854), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [593709] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15272), 1,
      anon_sym_RBRACK,
    ACTIONS(15274), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12261), 1,
      sym_attribute,
    STATE(16441), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [593764] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15276), 1,
      anon_sym_RBRACK,
    ACTIONS(15278), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12262), 1,
      sym_attribute,
    STATE(16231), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [593819] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15280), 1,
      anon_sym_DQUOTE,
    STATE(12263), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(17768), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [593860] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15282), 1,
      anon_sym_SEMI,
    ACTIONS(15284), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12264), 1,
      sym_attribute,
    STATE(15638), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [593915] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15286), 1,
      anon_sym_DQUOTE,
    STATE(12265), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19863), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [593956] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15288), 1,
      anon_sym_DQUOTE,
    STATE(12266), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19906), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [593997] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15290), 1,
      anon_sym_SEMI,
    ACTIONS(15292), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12267), 1,
      sym_attribute,
    STATE(15866), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [594052] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15294), 1,
      anon_sym_DQUOTE,
    STATE(12268), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19951), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [594093] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15296), 1,
      anon_sym_SEMI,
    ACTIONS(15298), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12269), 1,
      sym_attribute,
    STATE(16213), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [594148] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15300), 1,
      anon_sym_COMMA,
    ACTIONS(15302), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15304), 1,
      sym_pow_operator,
    ACTIONS(15306), 1,
      sym_mult_operator,
    ACTIONS(15308), 1,
      sym_concat_operator,
    ACTIONS(15310), 1,
      sym_rel_operator,
    ACTIONS(15312), 1,
      sym_and_operator,
    ACTIONS(15314), 1,
      sym_or_operator,
    ACTIONS(15316), 1,
      sym_assign_operator,
    STATE(2162), 1,
      sym_add_operator,
    STATE(12270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10330), 3,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
  [594199] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15318), 1,
      anon_sym_RBRACK,
    ACTIONS(15320), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12271), 1,
      sym_attribute,
    STATE(15904), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [594254] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15322), 1,
      anon_sym_SEMI,
    ACTIONS(15324), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12272), 1,
      sym_attribute,
    STATE(15716), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [594309] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15326), 1,
      anon_sym_RBRACK,
    ACTIONS(15328), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12273), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [594364] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15330), 1,
      anon_sym_PIPE,
    STATE(12274), 1,
      sym_attribute,
    STATE(12514), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [594399] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15330), 1,
      anon_sym_PIPE,
    STATE(12275), 1,
      sym_attribute,
    STATE(12520), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [594434] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9114), 1,
      anon_sym_done,
    ACTIONS(9116), 1,
      anon_sym_PIPE,
    ACTIONS(15153), 1,
      anon_sym_COMMA,
    ACTIONS(15155), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15157), 1,
      sym_pow_operator,
    ACTIONS(15159), 1,
      sym_mult_operator,
    ACTIONS(15161), 1,
      sym_concat_operator,
    ACTIONS(15163), 1,
      sym_rel_operator,
    ACTIONS(15165), 1,
      sym_and_operator,
    ACTIONS(15167), 1,
      sym_or_operator,
    ACTIONS(15169), 1,
      sym_assign_operator,
    ACTIONS(15332), 1,
      anon_sym_SEMI,
    STATE(2168), 1,
      sym_add_operator,
    STATE(12276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [594489] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(2391), 1,
      sym_add_operator,
    STATE(12277), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [594522] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15334), 1,
      anon_sym_SEMI,
    ACTIONS(15336), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12278), 1,
      sym_attribute,
    STATE(16471), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [594577] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15330), 1,
      anon_sym_PIPE,
    STATE(12275), 1,
      aux_sym__match_cases_repeat1,
    STATE(12279), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [594612] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15338), 1,
      anon_sym_RBRACK,
    ACTIONS(15340), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12280), 1,
      sym_attribute,
    STATE(16484), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [594667] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13327), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13329), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(15342), 1,
      anon_sym_LPAREN,
    STATE(12281), 1,
      sym_attribute,
    STATE(13213), 1,
      sym__simple_module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13238), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(10334), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [594706] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12511), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15266), 1,
      anon_sym_DASH_GT,
    STATE(12282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12509), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [594739] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11918), 1,
      anon_sym_COLON2,
    STATE(12283), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9158), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [594772] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15344), 1,
      anon_sym_else,
    STATE(7983), 1,
      sym_else_clause,
    STATE(12284), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [594807] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15346), 1,
      anon_sym_and,
    STATE(12285), 1,
      sym_attribute,
    STATE(12574), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15064), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [594840] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15348), 1,
      anon_sym_DQUOTE,
    STATE(12286), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(18885), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [594881] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8286), 1,
      anon_sym_let,
    STATE(12287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [594912] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8290), 1,
      anon_sym_let,
    STATE(12288), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [594943] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8300), 1,
      anon_sym_let,
    STATE(12289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [594974] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15350), 1,
      anon_sym_DQUOTE,
    STATE(12290), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19280), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [595015] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8308), 1,
      anon_sym_let,
    STATE(12291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [595046] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15352), 1,
      anon_sym_DQUOTE,
    STATE(12292), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19995), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [595087] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15354), 1,
      anon_sym_else,
    STATE(7952), 1,
      sym_else_clause,
    STATE(12293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [595122] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15356), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15358), 1,
      sym_pow_operator,
    ACTIONS(15360), 1,
      sym_mult_operator,
    STATE(1865), 1,
      sym_add_operator,
    STATE(12294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10397), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10395), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [595163] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15358), 1,
      sym_pow_operator,
    STATE(1865), 1,
      sym_add_operator,
    STATE(12295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [595198] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15358), 1,
      sym_pow_operator,
    STATE(1865), 1,
      sym_add_operator,
    STATE(12296), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [595233] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9114), 1,
      anon_sym_then,
    ACTIONS(9116), 1,
      anon_sym_PIPE,
    ACTIONS(15151), 1,
      sym_pow_operator,
    ACTIONS(15362), 1,
      anon_sym_COMMA,
    ACTIONS(15364), 1,
      anon_sym_SEMI,
    ACTIONS(15366), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15368), 1,
      sym_mult_operator,
    ACTIONS(15370), 1,
      sym_concat_operator,
    ACTIONS(15372), 1,
      sym_rel_operator,
    ACTIONS(15374), 1,
      sym_and_operator,
    ACTIONS(15376), 1,
      sym_or_operator,
    ACTIONS(15378), 1,
      sym_assign_operator,
    STATE(2365), 1,
      sym_add_operator,
    STATE(12297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [595288] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15356), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15358), 1,
      sym_pow_operator,
    ACTIONS(15360), 1,
      sym_mult_operator,
    ACTIONS(15380), 1,
      sym_concat_operator,
    STATE(1865), 1,
      sym_add_operator,
    STATE(12298), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [595331] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15356), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15358), 1,
      sym_pow_operator,
    ACTIONS(15360), 1,
      sym_mult_operator,
    ACTIONS(15380), 1,
      sym_concat_operator,
    STATE(1865), 1,
      sym_add_operator,
    STATE(12299), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [595374] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15382), 1,
      anon_sym_SEMI,
    ACTIONS(15384), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12300), 1,
      sym_attribute,
    STATE(15553), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [595429] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      sym_or_operator,
    ACTIONS(15356), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15358), 1,
      sym_pow_operator,
    ACTIONS(15360), 1,
      sym_mult_operator,
    ACTIONS(15380), 1,
      sym_concat_operator,
    ACTIONS(15386), 1,
      sym_rel_operator,
    ACTIONS(15388), 1,
      sym_and_operator,
    STATE(1865), 1,
      sym_add_operator,
    STATE(12301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
      sym_assign_operator,
  [595476] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15390), 1,
      anon_sym_DQUOTE,
    STATE(12302), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19965), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [595517] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15356), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15358), 1,
      sym_pow_operator,
    ACTIONS(15360), 1,
      sym_mult_operator,
    ACTIONS(15380), 1,
      sym_concat_operator,
    ACTIONS(15386), 1,
      sym_rel_operator,
    ACTIONS(15388), 1,
      sym_and_operator,
    ACTIONS(15392), 1,
      sym_or_operator,
    STATE(1865), 1,
      sym_add_operator,
    STATE(12303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
      sym_assign_operator,
  [595564] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15356), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15358), 1,
      sym_pow_operator,
    ACTIONS(15360), 1,
      sym_mult_operator,
    ACTIONS(15380), 1,
      sym_concat_operator,
    ACTIONS(15386), 1,
      sym_rel_operator,
    ACTIONS(15388), 1,
      sym_and_operator,
    ACTIONS(15392), 1,
      sym_or_operator,
    ACTIONS(15394), 1,
      anon_sym_COMMA,
    ACTIONS(15396), 1,
      sym_assign_operator,
    STATE(1865), 1,
      sym_add_operator,
    STATE(12304), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 3,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [595615] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8262), 1,
      anon_sym_let,
    STATE(12305), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [595646] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15398), 1,
      anon_sym_RBRACK,
    ACTIONS(15400), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12306), 1,
      sym_attribute,
    STATE(15551), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [595701] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15358), 1,
      sym_pow_operator,
    ACTIONS(15360), 1,
      sym_mult_operator,
    STATE(1865), 1,
      sym_add_operator,
    STATE(12307), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 5,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [595738] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15402), 1,
      anon_sym_DQUOTE,
    STATE(12308), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(17917), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [595779] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15356), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15358), 1,
      sym_pow_operator,
    ACTIONS(15360), 1,
      sym_mult_operator,
    ACTIONS(15380), 1,
      sym_concat_operator,
    ACTIONS(15386), 1,
      sym_rel_operator,
    ACTIONS(15388), 1,
      sym_and_operator,
    ACTIONS(15392), 1,
      sym_or_operator,
    ACTIONS(15394), 1,
      anon_sym_COMMA,
    ACTIONS(15396), 1,
      sym_assign_operator,
    STATE(1865), 1,
      sym_add_operator,
    STATE(12309), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10301), 3,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
  [595830] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8316), 1,
      anon_sym_let,
    STATE(12310), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [595861] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15404), 1,
      anon_sym_DQUOTE,
    STATE(12311), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19240), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [595902] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15256), 1,
      anon_sym_else,
    STATE(7983), 1,
      sym_else_clause,
    STATE(12312), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [595937] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15356), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15358), 1,
      sym_pow_operator,
    ACTIONS(15360), 1,
      sym_mult_operator,
    ACTIONS(15380), 1,
      sym_concat_operator,
    ACTIONS(15386), 1,
      sym_rel_operator,
    ACTIONS(15388), 1,
      sym_and_operator,
    ACTIONS(15392), 1,
      sym_or_operator,
    ACTIONS(15394), 1,
      anon_sym_COMMA,
    ACTIONS(15396), 1,
      sym_assign_operator,
    STATE(1865), 1,
      sym_add_operator,
    STATE(12313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10338), 3,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
  [595988] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15406), 1,
      anon_sym_DQUOTE,
    STATE(12314), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(20033), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [596029] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8320), 1,
      anon_sym_let,
    STATE(12315), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [596060] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8266), 1,
      anon_sym_let,
    STATE(12316), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [596091] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15408), 1,
      anon_sym_RBRACK,
    ACTIONS(15410), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12317), 1,
      sym_attribute,
    STATE(16025), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [596146] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15412), 1,
      anon_sym_DQUOTE,
    STATE(12318), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(17833), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [596187] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15414), 1,
      anon_sym_PIPE,
    STATE(12319), 1,
      sym_attribute,
    STATE(12610), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [596222] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15416), 1,
      anon_sym_SEMI,
    ACTIONS(15418), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12320), 1,
      sym_attribute,
    STATE(16005), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [596277] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15420), 1,
      anon_sym_else,
    STATE(7983), 1,
      sym_else_clause,
    STATE(12321), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [596312] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15422), 1,
      anon_sym_DQUOTE,
    STATE(12322), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(20073), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [596353] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15424), 1,
      anon_sym_and,
    STATE(12323), 1,
      sym_attribute,
    STATE(12529), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15038), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [596386] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15426), 1,
      anon_sym_DQUOTE,
    STATE(12324), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19163), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [596427] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15300), 1,
      anon_sym_COMMA,
    ACTIONS(15302), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15304), 1,
      sym_pow_operator,
    ACTIONS(15306), 1,
      sym_mult_operator,
    ACTIONS(15308), 1,
      sym_concat_operator,
    ACTIONS(15310), 1,
      sym_rel_operator,
    ACTIONS(15312), 1,
      sym_and_operator,
    ACTIONS(15314), 1,
      sym_or_operator,
    ACTIONS(15316), 1,
      sym_assign_operator,
    STATE(2162), 1,
      sym_add_operator,
    STATE(12325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10338), 3,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
  [596478] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15428), 1,
      anon_sym_DQUOTE,
    STATE(12326), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19834), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [596519] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15430), 1,
      anon_sym_else,
    STATE(7983), 1,
      sym_else_clause,
    STATE(12327), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [596554] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15300), 1,
      anon_sym_COMMA,
    ACTIONS(15302), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15304), 1,
      sym_pow_operator,
    ACTIONS(15306), 1,
      sym_mult_operator,
    ACTIONS(15308), 1,
      sym_concat_operator,
    ACTIONS(15310), 1,
      sym_rel_operator,
    ACTIONS(15312), 1,
      sym_and_operator,
    ACTIONS(15314), 1,
      sym_or_operator,
    ACTIONS(15316), 1,
      sym_assign_operator,
    STATE(2162), 1,
      sym_add_operator,
    STATE(12328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10301), 3,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
  [596605] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15356), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15358), 1,
      sym_pow_operator,
    ACTIONS(15360), 1,
      sym_mult_operator,
    ACTIONS(15380), 1,
      sym_concat_operator,
    ACTIONS(15386), 1,
      sym_rel_operator,
    ACTIONS(15388), 1,
      sym_and_operator,
    ACTIONS(15392), 1,
      sym_or_operator,
    STATE(1865), 1,
      sym_add_operator,
    STATE(12329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
      sym_assign_operator,
  [596652] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15304), 1,
      sym_pow_operator,
    ACTIONS(15306), 1,
      sym_mult_operator,
    STATE(2162), 1,
      sym_add_operator,
    STATE(12330), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 5,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [596689] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15300), 1,
      anon_sym_COMMA,
    ACTIONS(15302), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15304), 1,
      sym_pow_operator,
    ACTIONS(15306), 1,
      sym_mult_operator,
    ACTIONS(15308), 1,
      sym_concat_operator,
    ACTIONS(15310), 1,
      sym_rel_operator,
    ACTIONS(15312), 1,
      sym_and_operator,
    ACTIONS(15314), 1,
      sym_or_operator,
    ACTIONS(15316), 1,
      sym_assign_operator,
    STATE(2162), 1,
      sym_add_operator,
    STATE(12331), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 3,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [596740] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15432), 1,
      anon_sym_RBRACK,
    ACTIONS(15434), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12332), 1,
      sym_attribute,
    STATE(15147), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [596795] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15436), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12333), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [596828] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15439), 1,
      anon_sym_DQUOTE,
    STATE(12334), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(18784), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [596869] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15441), 1,
      anon_sym_PIPE,
    STATE(12333), 1,
      aux_sym__match_cases_repeat1,
    STATE(12335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [596904] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15441), 1,
      anon_sym_PIPE,
    STATE(12333), 1,
      aux_sym__match_cases_repeat1,
    STATE(12336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [596939] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15441), 1,
      anon_sym_PIPE,
    STATE(12335), 1,
      aux_sym__match_cases_repeat1,
    STATE(12337), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [596974] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15443), 1,
      anon_sym_SEMI,
    ACTIONS(15445), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12338), 1,
      sym_attribute,
    STATE(15192), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [597029] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15447), 1,
      anon_sym_SEMI,
    ACTIONS(15449), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12339), 1,
      sym_attribute,
    STATE(15302), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [597084] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15441), 1,
      anon_sym_PIPE,
    STATE(12336), 1,
      aux_sym__match_cases_repeat1,
    STATE(12340), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [597119] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15451), 1,
      anon_sym_RBRACK,
    ACTIONS(15453), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12341), 1,
      sym_attribute,
    STATE(15277), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [597174] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15302), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15304), 1,
      sym_pow_operator,
    ACTIONS(15306), 1,
      sym_mult_operator,
    ACTIONS(15308), 1,
      sym_concat_operator,
    ACTIONS(15310), 1,
      sym_rel_operator,
    ACTIONS(15312), 1,
      sym_and_operator,
    ACTIONS(15314), 1,
      sym_or_operator,
    STATE(2162), 1,
      sym_add_operator,
    STATE(12342), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      sym_assign_operator,
  [597221] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15455), 1,
      anon_sym_DQUOTE,
    STATE(12343), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(17895), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [597262] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      sym_or_operator,
    ACTIONS(15302), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15304), 1,
      sym_pow_operator,
    ACTIONS(15306), 1,
      sym_mult_operator,
    ACTIONS(15308), 1,
      sym_concat_operator,
    ACTIONS(15310), 1,
      sym_rel_operator,
    ACTIONS(15312), 1,
      sym_and_operator,
    STATE(2162), 1,
      sym_add_operator,
    STATE(12344), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      sym_assign_operator,
  [597309] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15457), 1,
      anon_sym_DQUOTE,
    STATE(12345), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19386), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [597350] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9114), 1,
      anon_sym_do,
    ACTIONS(9116), 1,
      anon_sym_PIPE,
    ACTIONS(15459), 1,
      anon_sym_COMMA,
    ACTIONS(15461), 1,
      anon_sym_SEMI,
    ACTIONS(15463), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15465), 1,
      sym_pow_operator,
    ACTIONS(15467), 1,
      sym_mult_operator,
    ACTIONS(15469), 1,
      sym_concat_operator,
    ACTIONS(15471), 1,
      sym_rel_operator,
    ACTIONS(15473), 1,
      sym_and_operator,
    ACTIONS(15475), 1,
      sym_or_operator,
    ACTIONS(15477), 1,
      sym_assign_operator,
    STATE(2391), 1,
      sym_add_operator,
    STATE(12346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [597405] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15430), 1,
      anon_sym_else,
    STATE(7952), 1,
      sym_else_clause,
    STATE(12347), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [597440] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(2162), 1,
      sym_add_operator,
    STATE(12348), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [597473] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15302), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15304), 1,
      sym_pow_operator,
    ACTIONS(15306), 1,
      sym_mult_operator,
    ACTIONS(15308), 1,
      sym_concat_operator,
    STATE(2162), 1,
      sym_add_operator,
    STATE(12349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      sym_rel_operator,
      sym_assign_operator,
  [597516] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8274), 1,
      anon_sym_let,
    STATE(12350), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [597547] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15302), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15304), 1,
      sym_pow_operator,
    ACTIONS(15306), 1,
      sym_mult_operator,
    ACTIONS(15308), 1,
      sym_concat_operator,
    STATE(2162), 1,
      sym_add_operator,
    STATE(12351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      sym_rel_operator,
      sym_assign_operator,
  [597590] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15479), 1,
      anon_sym_RBRACK,
    ACTIONS(15481), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12352), 1,
      sym_attribute,
    STATE(15239), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [597645] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15346), 1,
      anon_sym_and,
    STATE(12353), 1,
      sym_attribute,
    STATE(12574), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15011), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [597678] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8278), 1,
      anon_sym_let,
    STATE(12354), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [597709] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8270), 1,
      anon_sym_let,
    STATE(12355), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [597740] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8334), 1,
      anon_sym_let,
    STATE(12356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [597771] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15304), 1,
      sym_pow_operator,
    STATE(2162), 1,
      sym_add_operator,
    STATE(12357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [597806] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15485), 1,
      sym_pow_operator,
    ACTIONS(15487), 1,
      sym_mult_operator,
    ACTIONS(15489), 1,
      sym_concat_operator,
    STATE(1921), 1,
      sym_add_operator,
    STATE(12358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [597849] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15304), 1,
      sym_pow_operator,
    STATE(2162), 1,
      sym_add_operator,
    STATE(12359), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [597884] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15491), 1,
      anon_sym_SEMI,
    ACTIONS(15493), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12360), 1,
      sym_attribute,
    STATE(15929), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [597939] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8338), 1,
      anon_sym_let,
    STATE(12361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [597970] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15497), 1,
      anon_sym_let,
    STATE(12362), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15495), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [598001] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15499), 1,
      anon_sym_SEMI,
    ACTIONS(15501), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12363), 1,
      sym_attribute,
    STATE(15381), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [598056] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15302), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15304), 1,
      sym_pow_operator,
    ACTIONS(15306), 1,
      sym_mult_operator,
    STATE(2162), 1,
      sym_add_operator,
    STATE(12364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10397), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10395), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [598097] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15503), 1,
      anon_sym_SEMI,
    ACTIONS(15505), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12365), 1,
      sym_attribute,
    STATE(15120), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [598152] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15346), 1,
      anon_sym_and,
    STATE(12366), 1,
      sym_attribute,
    STATE(12569), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15011), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [598185] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15507), 1,
      anon_sym_RBRACK,
    ACTIONS(15509), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12367), 1,
      sym_attribute,
    STATE(15129), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [598240] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15511), 1,
      anon_sym_DQUOTE,
    STATE(12368), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(17958), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [598281] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15513), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12369), 2,
      sym_attribute,
      aux_sym__structure_repeat1,
    ACTIONS(9081), 14,
      ts_builtin_sym_end,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [598312] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15516), 1,
      anon_sym_SEMI,
    ACTIONS(15518), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12370), 1,
      sym_attribute,
    STATE(15625), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [598367] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15520), 1,
      anon_sym_RBRACK,
    ACTIONS(15522), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12371), 1,
      sym_attribute,
    STATE(16314), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [598422] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15302), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15304), 1,
      sym_pow_operator,
    ACTIONS(15306), 1,
      sym_mult_operator,
    ACTIONS(15308), 1,
      sym_concat_operator,
    ACTIONS(15310), 1,
      sym_rel_operator,
    ACTIONS(15312), 1,
      sym_and_operator,
    ACTIONS(15314), 1,
      sym_or_operator,
    STATE(2162), 1,
      sym_add_operator,
    STATE(12372), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      sym_assign_operator,
  [598469] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15524), 1,
      anon_sym_RBRACK,
    ACTIONS(15526), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12373), 1,
      sym_attribute,
    STATE(15618), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [598524] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15053), 1,
      anon_sym_let,
    STATE(12374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15051), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [598555] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15485), 1,
      sym_pow_operator,
    ACTIONS(15487), 1,
      sym_mult_operator,
    ACTIONS(15489), 1,
      sym_concat_operator,
    ACTIONS(15528), 1,
      sym_rel_operator,
    ACTIONS(15530), 1,
      sym_and_operator,
    ACTIONS(15532), 1,
      sym_or_operator,
    STATE(1921), 1,
      sym_add_operator,
    STATE(12375), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
      sym_assign_operator,
  [598602] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11642), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11644), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [598633] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15534), 1,
      anon_sym_RBRACK,
    ACTIONS(15536), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12377), 1,
      sym_attribute,
    STATE(15442), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [598688] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12378), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11632), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11634), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [598719] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10340), 1,
      anon_sym_PIPE,
    ACTIONS(15538), 1,
      anon_sym_COMMA,
    ACTIONS(15540), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15542), 1,
      sym_pow_operator,
    ACTIONS(15544), 1,
      sym_mult_operator,
    ACTIONS(15546), 1,
      sym_concat_operator,
    ACTIONS(15548), 1,
      sym_rel_operator,
    ACTIONS(15550), 1,
      sym_and_operator,
    ACTIONS(15552), 1,
      sym_or_operator,
    ACTIONS(15554), 1,
      sym_assign_operator,
    STATE(2328), 1,
      sym_add_operator,
    STATE(12379), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10338), 2,
      anon_sym_SEMI,
      anon_sym_end,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [598772] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10303), 1,
      anon_sym_PIPE,
    ACTIONS(15538), 1,
      anon_sym_COMMA,
    ACTIONS(15540), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15542), 1,
      sym_pow_operator,
    ACTIONS(15544), 1,
      sym_mult_operator,
    ACTIONS(15546), 1,
      sym_concat_operator,
    ACTIONS(15548), 1,
      sym_rel_operator,
    ACTIONS(15550), 1,
      sym_and_operator,
    ACTIONS(15552), 1,
      sym_or_operator,
    ACTIONS(15554), 1,
      sym_assign_operator,
    STATE(2328), 1,
      sym_add_operator,
    STATE(12380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10301), 2,
      anon_sym_SEMI,
      anon_sym_end,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [598825] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15542), 1,
      sym_pow_operator,
    ACTIONS(15544), 1,
      sym_mult_operator,
    STATE(2328), 1,
      sym_add_operator,
    STATE(12381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [598862] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15485), 1,
      sym_pow_operator,
    ACTIONS(15487), 1,
      sym_mult_operator,
    STATE(1921), 1,
      sym_add_operator,
    STATE(12382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10397), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10395), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [598903] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11550), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11552), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [598934] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15556), 1,
      anon_sym_RBRACK,
    ACTIONS(15558), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12384), 1,
      sym_attribute,
    STATE(15490), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [598989] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15485), 1,
      sym_pow_operator,
    STATE(1921), 1,
      sym_add_operator,
    STATE(12385), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [599024] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15560), 1,
      anon_sym_DQUOTE,
    STATE(12386), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(18049), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [599065] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(2168), 1,
      sym_add_operator,
    STATE(12387), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [599098] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12388), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11426), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11428), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [599129] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15562), 1,
      anon_sym_SEMI,
    ACTIONS(15564), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12389), 1,
      sym_attribute,
    STATE(15300), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [599184] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15485), 1,
      sym_pow_operator,
    STATE(1921), 1,
      sym_add_operator,
    STATE(12390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [599219] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15566), 1,
      anon_sym_RBRACK,
    ACTIONS(15568), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12391), 1,
      sym_attribute,
    STATE(15314), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [599274] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12392), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11763), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11765), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [599305] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15485), 1,
      sym_pow_operator,
    ACTIONS(15487), 1,
      sym_mult_operator,
    ACTIONS(15489), 1,
      sym_concat_operator,
    STATE(1921), 1,
      sym_add_operator,
    STATE(12393), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [599348] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15424), 1,
      anon_sym_and,
    STATE(12394), 1,
      sym_attribute,
    STATE(12529), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14797), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [599381] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15570), 1,
      anon_sym_DQUOTE,
    STATE(12395), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(18024), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [599422] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      sym_or_operator,
    ACTIONS(15483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15485), 1,
      sym_pow_operator,
    ACTIONS(15487), 1,
      sym_mult_operator,
    ACTIONS(15489), 1,
      sym_concat_operator,
    ACTIONS(15528), 1,
      sym_rel_operator,
    ACTIONS(15530), 1,
      sym_and_operator,
    STATE(1921), 1,
      sym_add_operator,
    STATE(12396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
      sym_assign_operator,
  [599469] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15232), 1,
      anon_sym_COLON2,
    ACTIONS(15572), 1,
      anon_sym_COLON_GT,
    ACTIONS(15574), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12397), 1,
      sym_attribute,
    STATE(12845), 1,
      sym__typed,
    STATE(13084), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15576), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [599512] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15485), 1,
      sym_pow_operator,
    ACTIONS(15487), 1,
      sym_mult_operator,
    ACTIONS(15489), 1,
      sym_concat_operator,
    ACTIONS(15528), 1,
      sym_rel_operator,
    ACTIONS(15530), 1,
      sym_and_operator,
    ACTIONS(15532), 1,
      sym_or_operator,
    STATE(1921), 1,
      sym_add_operator,
    STATE(12398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
      sym_assign_operator,
  [599559] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(15538), 1,
      anon_sym_COMMA,
    ACTIONS(15540), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15542), 1,
      sym_pow_operator,
    ACTIONS(15544), 1,
      sym_mult_operator,
    ACTIONS(15546), 1,
      sym_concat_operator,
    ACTIONS(15548), 1,
      sym_rel_operator,
    ACTIONS(15550), 1,
      sym_and_operator,
    ACTIONS(15552), 1,
      sym_or_operator,
    ACTIONS(15554), 1,
      sym_assign_operator,
    STATE(2328), 1,
      sym_add_operator,
    STATE(12399), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 2,
      anon_sym_SEMI,
      anon_sym_end,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [599612] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15485), 1,
      sym_pow_operator,
    ACTIONS(15487), 1,
      sym_mult_operator,
    ACTIONS(15489), 1,
      sym_concat_operator,
    ACTIONS(15528), 1,
      sym_rel_operator,
    ACTIONS(15530), 1,
      sym_and_operator,
    ACTIONS(15532), 1,
      sym_or_operator,
    ACTIONS(15578), 1,
      anon_sym_COMMA,
    ACTIONS(15580), 1,
      sym_assign_operator,
    STATE(1921), 1,
      sym_add_operator,
    STATE(12400), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 3,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [599663] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15485), 1,
      sym_pow_operator,
    ACTIONS(15487), 1,
      sym_mult_operator,
    STATE(1921), 1,
      sym_add_operator,
    STATE(12401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 5,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [599700] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15485), 1,
      sym_pow_operator,
    ACTIONS(15487), 1,
      sym_mult_operator,
    ACTIONS(15489), 1,
      sym_concat_operator,
    ACTIONS(15528), 1,
      sym_rel_operator,
    ACTIONS(15530), 1,
      sym_and_operator,
    ACTIONS(15532), 1,
      sym_or_operator,
    ACTIONS(15578), 1,
      anon_sym_COMMA,
    ACTIONS(15580), 1,
      sym_assign_operator,
    STATE(1921), 1,
      sym_add_operator,
    STATE(12402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10301), 3,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
  [599751] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(15540), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15542), 1,
      sym_pow_operator,
    ACTIONS(15544), 1,
      sym_mult_operator,
    ACTIONS(15546), 1,
      sym_concat_operator,
    ACTIONS(15548), 1,
      sym_rel_operator,
    ACTIONS(15550), 1,
      sym_and_operator,
    ACTIONS(15552), 1,
      sym_or_operator,
    STATE(2328), 1,
      sym_add_operator,
    STATE(12403), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      sym_assign_operator,
  [599800] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15582), 1,
      anon_sym_DQUOTE,
    STATE(12404), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19161), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [599841] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15540), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15542), 1,
      sym_pow_operator,
    ACTIONS(15544), 1,
      sym_mult_operator,
    ACTIONS(15546), 1,
      sym_concat_operator,
    ACTIONS(15548), 1,
      sym_rel_operator,
    ACTIONS(15550), 1,
      sym_and_operator,
    STATE(2328), 1,
      sym_add_operator,
    STATE(12405), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      sym_assign_operator,
  [599888] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15584), 1,
      anon_sym_else,
    STATE(7983), 1,
      sym_else_clause,
    STATE(12406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [599923] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15540), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15542), 1,
      sym_pow_operator,
    ACTIONS(15544), 1,
      sym_mult_operator,
    ACTIONS(15546), 1,
      sym_concat_operator,
    STATE(2328), 1,
      sym_add_operator,
    STATE(12407), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      sym_rel_operator,
      sym_assign_operator,
  [599966] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15540), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15542), 1,
      sym_pow_operator,
    ACTIONS(15544), 1,
      sym_mult_operator,
    ACTIONS(15546), 1,
      sym_concat_operator,
    STATE(2328), 1,
      sym_add_operator,
    STATE(12408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      sym_rel_operator,
      sym_assign_operator,
  [600009] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15542), 1,
      sym_pow_operator,
    STATE(2328), 1,
      sym_add_operator,
    STATE(12409), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [600044] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15485), 1,
      sym_pow_operator,
    ACTIONS(15487), 1,
      sym_mult_operator,
    ACTIONS(15489), 1,
      sym_concat_operator,
    ACTIONS(15528), 1,
      sym_rel_operator,
    ACTIONS(15530), 1,
      sym_and_operator,
    ACTIONS(15532), 1,
      sym_or_operator,
    ACTIONS(15578), 1,
      anon_sym_COMMA,
    ACTIONS(15580), 1,
      sym_assign_operator,
    STATE(1921), 1,
      sym_add_operator,
    STATE(12410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10338), 3,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
  [600095] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15424), 1,
      anon_sym_and,
    STATE(12411), 1,
      sym_attribute,
    STATE(12496), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14797), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [600128] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15586), 1,
      anon_sym_SEMI,
    ACTIONS(15588), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12412), 1,
      sym_attribute,
    STATE(15506), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [600183] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15542), 1,
      sym_pow_operator,
    STATE(2328), 1,
      sym_add_operator,
    STATE(12413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [600218] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15540), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15542), 1,
      sym_pow_operator,
    ACTIONS(15544), 1,
      sym_mult_operator,
    STATE(2328), 1,
      sym_add_operator,
    STATE(12414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [600259] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15590), 1,
      anon_sym_RBRACK,
    ACTIONS(15592), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12415), 1,
      sym_attribute,
    STATE(15519), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [600314] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10344), 1,
      anon_sym_PIPE,
    ACTIONS(15151), 1,
      sym_pow_operator,
    ACTIONS(15366), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15368), 1,
      sym_mult_operator,
    ACTIONS(15370), 1,
      sym_concat_operator,
    ACTIONS(15372), 1,
      sym_rel_operator,
    ACTIONS(15374), 1,
      sym_and_operator,
    ACTIONS(15376), 1,
      sym_or_operator,
    STATE(2365), 1,
      sym_add_operator,
    STATE(12416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      sym_assign_operator,
  [600363] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15594), 1,
      anon_sym_DQUOTE,
    STATE(12417), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(17646), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [600404] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15356), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15358), 1,
      sym_pow_operator,
    ACTIONS(15360), 1,
      sym_mult_operator,
    ACTIONS(15380), 1,
      sym_concat_operator,
    ACTIONS(15386), 1,
      sym_rel_operator,
    ACTIONS(15388), 1,
      sym_and_operator,
    ACTIONS(15392), 1,
      sym_or_operator,
    ACTIONS(15394), 1,
      anon_sym_COMMA,
    ACTIONS(15396), 1,
      sym_assign_operator,
    ACTIONS(15596), 1,
      anon_sym_SEMI,
    STATE(1865), 1,
      sym_add_operator,
    STATE(12418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9114), 2,
      anon_sym_with,
      anon_sym_else,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [600457] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10340), 1,
      anon_sym_PIPE,
    ACTIONS(15598), 1,
      anon_sym_COMMA,
    ACTIONS(15600), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15602), 1,
      sym_pow_operator,
    ACTIONS(15604), 1,
      sym_mult_operator,
    ACTIONS(15606), 1,
      sym_concat_operator,
    ACTIONS(15608), 1,
      sym_rel_operator,
    ACTIONS(15610), 1,
      sym_and_operator,
    ACTIONS(15612), 1,
      sym_or_operator,
    ACTIONS(15614), 1,
      sym_assign_operator,
    STATE(2409), 1,
      sym_add_operator,
    STATE(12419), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10338), 2,
      anon_sym_SEMI,
      anon_sym_with,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [600510] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15616), 1,
      anon_sym_SEMI,
    ACTIONS(15618), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12420), 1,
      sym_attribute,
    STATE(15083), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [600565] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15620), 1,
      anon_sym_SEMI,
    ACTIONS(15622), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12421), 1,
      sym_attribute,
    STATE(15836), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [600620] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10303), 1,
      anon_sym_PIPE,
    ACTIONS(15598), 1,
      anon_sym_COMMA,
    ACTIONS(15600), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15602), 1,
      sym_pow_operator,
    ACTIONS(15604), 1,
      sym_mult_operator,
    ACTIONS(15606), 1,
      sym_concat_operator,
    ACTIONS(15608), 1,
      sym_rel_operator,
    ACTIONS(15610), 1,
      sym_and_operator,
    ACTIONS(15612), 1,
      sym_or_operator,
    ACTIONS(15614), 1,
      sym_assign_operator,
    STATE(2409), 1,
      sym_add_operator,
    STATE(12422), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10301), 2,
      anon_sym_SEMI,
      anon_sym_with,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [600673] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15602), 1,
      sym_pow_operator,
    ACTIONS(15604), 1,
      sym_mult_operator,
    STATE(2409), 1,
      sym_add_operator,
    STATE(12423), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [600710] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(15598), 1,
      anon_sym_COMMA,
    ACTIONS(15600), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15602), 1,
      sym_pow_operator,
    ACTIONS(15604), 1,
      sym_mult_operator,
    ACTIONS(15606), 1,
      sym_concat_operator,
    ACTIONS(15608), 1,
      sym_rel_operator,
    ACTIONS(15610), 1,
      sym_and_operator,
    ACTIONS(15612), 1,
      sym_or_operator,
    ACTIONS(15614), 1,
      sym_assign_operator,
    STATE(2409), 1,
      sym_add_operator,
    STATE(12424), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 2,
      anon_sym_SEMI,
      anon_sym_with,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [600763] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(15600), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15602), 1,
      sym_pow_operator,
    ACTIONS(15604), 1,
      sym_mult_operator,
    ACTIONS(15606), 1,
      sym_concat_operator,
    ACTIONS(15608), 1,
      sym_rel_operator,
    ACTIONS(15610), 1,
      sym_and_operator,
    ACTIONS(15612), 1,
      sym_or_operator,
    STATE(2409), 1,
      sym_add_operator,
    STATE(12425), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      sym_assign_operator,
  [600812] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15600), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15602), 1,
      sym_pow_operator,
    ACTIONS(15604), 1,
      sym_mult_operator,
    ACTIONS(15606), 1,
      sym_concat_operator,
    ACTIONS(15608), 1,
      sym_rel_operator,
    ACTIONS(15610), 1,
      sym_and_operator,
    STATE(2409), 1,
      sym_add_operator,
    STATE(12426), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      sym_assign_operator,
  [600859] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15626), 1,
      anon_sym_let,
    STATE(12427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15624), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [600890] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15600), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15602), 1,
      sym_pow_operator,
    ACTIONS(15604), 1,
      sym_mult_operator,
    ACTIONS(15606), 1,
      sym_concat_operator,
    STATE(2409), 1,
      sym_add_operator,
    STATE(12428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      sym_rel_operator,
      sym_assign_operator,
  [600933] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15626), 1,
      anon_sym_let,
    ACTIONS(15628), 1,
      anon_sym_in,
    STATE(12429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15624), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [600966] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15630), 1,
      anon_sym_PIPE,
    STATE(12430), 1,
      sym_attribute,
    STATE(12434), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [601001] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15632), 1,
      anon_sym_PIPE,
    STATE(12431), 1,
      sym_attribute,
    STATE(12451), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10379), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [601036] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15634), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12432), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [601069] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15630), 1,
      anon_sym_PIPE,
    STATE(12433), 1,
      sym_attribute,
    STATE(12437), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [601104] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15630), 1,
      anon_sym_PIPE,
    STATE(12434), 1,
      sym_attribute,
    STATE(12440), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [601139] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15414), 1,
      anon_sym_PIPE,
    STATE(12432), 1,
      aux_sym__match_cases_repeat1,
    STATE(12435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [601174] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15420), 1,
      anon_sym_else,
    STATE(7952), 1,
      sym_else_clause,
    STATE(12436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [601209] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15630), 1,
      anon_sym_PIPE,
    STATE(12437), 1,
      sym_attribute,
    STATE(12440), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [601244] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15637), 1,
      anon_sym_SEMI,
    ACTIONS(15639), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12438), 1,
      sym_attribute,
    STATE(15706), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [601299] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15356), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15358), 1,
      sym_pow_operator,
    ACTIONS(15360), 1,
      sym_mult_operator,
    ACTIONS(15380), 1,
      sym_concat_operator,
    ACTIONS(15386), 1,
      sym_rel_operator,
    ACTIONS(15388), 1,
      sym_and_operator,
    ACTIONS(15392), 1,
      sym_or_operator,
    ACTIONS(15394), 1,
      anon_sym_COMMA,
    ACTIONS(15396), 1,
      sym_assign_operator,
    STATE(1865), 1,
      sym_add_operator,
    STATE(12439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10330), 3,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
  [601350] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15641), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12440), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [601383] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15632), 1,
      anon_sym_PIPE,
    STATE(12441), 1,
      sym_attribute,
    STATE(12455), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [601418] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15644), 1,
      anon_sym_RBRACK,
    ACTIONS(15646), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12442), 1,
      sym_attribute,
    STATE(15726), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [601473] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15648), 1,
      anon_sym_DQUOTE,
    STATE(12443), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(18730), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [601514] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15600), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15602), 1,
      sym_pow_operator,
    ACTIONS(15604), 1,
      sym_mult_operator,
    ACTIONS(15606), 1,
      sym_concat_operator,
    STATE(2409), 1,
      sym_add_operator,
    STATE(12444), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      sym_rel_operator,
      sym_assign_operator,
  [601557] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15602), 1,
      sym_pow_operator,
    STATE(2409), 1,
      sym_add_operator,
    STATE(12445), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [601592] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15650), 1,
      anon_sym_DQUOTE,
    STATE(12446), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(18173), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [601633] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15602), 1,
      sym_pow_operator,
    STATE(2409), 1,
      sym_add_operator,
    STATE(12447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [601668] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15600), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15602), 1,
      sym_pow_operator,
    ACTIONS(15604), 1,
      sym_mult_operator,
    STATE(2409), 1,
      sym_add_operator,
    STATE(12448), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [601709] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15652), 1,
      anon_sym_DQUOTE,
    STATE(12449), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(20429), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [601750] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10344), 1,
      anon_sym_PIPE,
    ACTIONS(15600), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15602), 1,
      sym_pow_operator,
    ACTIONS(15604), 1,
      sym_mult_operator,
    ACTIONS(15606), 1,
      sym_concat_operator,
    ACTIONS(15608), 1,
      sym_rel_operator,
    ACTIONS(15610), 1,
      sym_and_operator,
    ACTIONS(15612), 1,
      sym_or_operator,
    STATE(2409), 1,
      sym_add_operator,
    STATE(12450), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      sym_assign_operator,
  [601799] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15632), 1,
      anon_sym_PIPE,
    STATE(12451), 1,
      sym_attribute,
    STATE(12458), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [601834] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10340), 1,
      anon_sym_PIPE,
    ACTIONS(15459), 1,
      anon_sym_COMMA,
    ACTIONS(15463), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15465), 1,
      sym_pow_operator,
    ACTIONS(15467), 1,
      sym_mult_operator,
    ACTIONS(15469), 1,
      sym_concat_operator,
    ACTIONS(15471), 1,
      sym_rel_operator,
    ACTIONS(15473), 1,
      sym_and_operator,
    ACTIONS(15475), 1,
      sym_or_operator,
    ACTIONS(15477), 1,
      sym_assign_operator,
    STATE(2391), 1,
      sym_add_operator,
    STATE(12452), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10338), 2,
      anon_sym_SEMI,
      anon_sym_do,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [601887] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10303), 1,
      anon_sym_PIPE,
    ACTIONS(15459), 1,
      anon_sym_COMMA,
    ACTIONS(15463), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15465), 1,
      sym_pow_operator,
    ACTIONS(15467), 1,
      sym_mult_operator,
    ACTIONS(15469), 1,
      sym_concat_operator,
    ACTIONS(15471), 1,
      sym_rel_operator,
    ACTIONS(15473), 1,
      sym_and_operator,
    ACTIONS(15475), 1,
      sym_or_operator,
    ACTIONS(15477), 1,
      sym_assign_operator,
    STATE(2391), 1,
      sym_add_operator,
    STATE(12453), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10301), 2,
      anon_sym_SEMI,
      anon_sym_do,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [601940] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15654), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15656), 1,
      sym_pow_operator,
    ACTIONS(15658), 1,
      sym_mult_operator,
    ACTIONS(15660), 1,
      sym_concat_operator,
    ACTIONS(15662), 1,
      sym_rel_operator,
    ACTIONS(15664), 1,
      sym_and_operator,
    ACTIONS(15666), 1,
      sym_or_operator,
    STATE(2017), 1,
      sym_add_operator,
    STATE(12454), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
      sym_assign_operator,
  [601987] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15632), 1,
      anon_sym_PIPE,
    STATE(12455), 1,
      sym_attribute,
    STATE(12458), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [602022] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15654), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15656), 1,
      sym_pow_operator,
    ACTIONS(15658), 1,
      sym_mult_operator,
    STATE(2017), 1,
      sym_add_operator,
    STATE(12456), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10397), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10395), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [602063] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12457), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      sym_rel_operator,
      sym_assign_operator,
  [602106] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15668), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12458), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [602139] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15656), 1,
      sym_pow_operator,
    STATE(2017), 1,
      sym_add_operator,
    STATE(12459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [602174] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12460), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [602207] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15465), 1,
      sym_pow_operator,
    ACTIONS(15467), 1,
      sym_mult_operator,
    STATE(2391), 1,
      sym_add_operator,
    STATE(12461), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [602244] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15656), 1,
      sym_pow_operator,
    STATE(2017), 1,
      sym_add_operator,
    STATE(12462), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [602279] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15654), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15656), 1,
      sym_pow_operator,
    ACTIONS(15658), 1,
      sym_mult_operator,
    ACTIONS(15660), 1,
      sym_concat_operator,
    STATE(2017), 1,
      sym_add_operator,
    STATE(12463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [602322] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(15459), 1,
      anon_sym_COMMA,
    ACTIONS(15463), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15465), 1,
      sym_pow_operator,
    ACTIONS(15467), 1,
      sym_mult_operator,
    ACTIONS(15469), 1,
      sym_concat_operator,
    ACTIONS(15471), 1,
      sym_rel_operator,
    ACTIONS(15473), 1,
      sym_and_operator,
    ACTIONS(15475), 1,
      sym_or_operator,
    ACTIONS(15477), 1,
      sym_assign_operator,
    STATE(2391), 1,
      sym_add_operator,
    STATE(12464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 2,
      anon_sym_SEMI,
      anon_sym_do,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [602375] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15671), 1,
      anon_sym_DQUOTE,
    STATE(12465), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19573), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [602416] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15485), 1,
      sym_pow_operator,
    ACTIONS(15487), 1,
      sym_mult_operator,
    ACTIONS(15489), 1,
      sym_concat_operator,
    ACTIONS(15528), 1,
      sym_rel_operator,
    ACTIONS(15530), 1,
      sym_and_operator,
    ACTIONS(15532), 1,
      sym_or_operator,
    ACTIONS(15578), 1,
      anon_sym_COMMA,
    ACTIONS(15580), 1,
      sym_assign_operator,
    ACTIONS(15673), 1,
      anon_sym_SEMI,
    STATE(1921), 1,
      sym_add_operator,
    STATE(12466), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9114), 2,
      anon_sym_then,
      anon_sym_else,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [602469] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15654), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15656), 1,
      sym_pow_operator,
    ACTIONS(15658), 1,
      sym_mult_operator,
    ACTIONS(15660), 1,
      sym_concat_operator,
    STATE(2017), 1,
      sym_add_operator,
    STATE(12467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [602512] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(15463), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15465), 1,
      sym_pow_operator,
    ACTIONS(15467), 1,
      sym_mult_operator,
    ACTIONS(15469), 1,
      sym_concat_operator,
    ACTIONS(15471), 1,
      sym_rel_operator,
    ACTIONS(15473), 1,
      sym_and_operator,
    ACTIONS(15475), 1,
      sym_or_operator,
    STATE(2391), 1,
      sym_add_operator,
    STATE(12468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_do,
      sym_assign_operator,
  [602561] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15463), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15465), 1,
      sym_pow_operator,
    ACTIONS(15467), 1,
      sym_mult_operator,
    ACTIONS(15469), 1,
      sym_concat_operator,
    ACTIONS(15471), 1,
      sym_rel_operator,
    ACTIONS(15473), 1,
      sym_and_operator,
    STATE(2391), 1,
      sym_add_operator,
    STATE(12469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_do,
      sym_assign_operator,
  [602608] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9114), 1,
      anon_sym_with,
    ACTIONS(9116), 1,
      anon_sym_PIPE,
    ACTIONS(15598), 1,
      anon_sym_COMMA,
    ACTIONS(15600), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15602), 1,
      sym_pow_operator,
    ACTIONS(15604), 1,
      sym_mult_operator,
    ACTIONS(15606), 1,
      sym_concat_operator,
    ACTIONS(15608), 1,
      sym_rel_operator,
    ACTIONS(15610), 1,
      sym_and_operator,
    ACTIONS(15612), 1,
      sym_or_operator,
    ACTIONS(15614), 1,
      sym_assign_operator,
    ACTIONS(15675), 1,
      anon_sym_SEMI,
    STATE(2409), 1,
      sym_add_operator,
    STATE(12470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [602663] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      sym_or_operator,
    ACTIONS(15654), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15656), 1,
      sym_pow_operator,
    ACTIONS(15658), 1,
      sym_mult_operator,
    ACTIONS(15660), 1,
      sym_concat_operator,
    ACTIONS(15662), 1,
      sym_rel_operator,
    ACTIONS(15664), 1,
      sym_and_operator,
    STATE(2017), 1,
      sym_add_operator,
    STATE(12471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
      sym_assign_operator,
  [602710] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10344), 1,
      anon_sym_PIPE,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      sym_assign_operator,
  [602759] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15654), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15656), 1,
      sym_pow_operator,
    ACTIONS(15658), 1,
      sym_mult_operator,
    ACTIONS(15660), 1,
      sym_concat_operator,
    ACTIONS(15662), 1,
      sym_rel_operator,
    ACTIONS(15664), 1,
      sym_and_operator,
    ACTIONS(15666), 1,
      sym_or_operator,
    STATE(2017), 1,
      sym_add_operator,
    STATE(12473), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
      sym_assign_operator,
  [602806] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15654), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15656), 1,
      sym_pow_operator,
    ACTIONS(15658), 1,
      sym_mult_operator,
    ACTIONS(15660), 1,
      sym_concat_operator,
    ACTIONS(15662), 1,
      sym_rel_operator,
    ACTIONS(15664), 1,
      sym_and_operator,
    ACTIONS(15666), 1,
      sym_or_operator,
    ACTIONS(15677), 1,
      anon_sym_COMMA,
    ACTIONS(15679), 1,
      sym_assign_operator,
    STATE(2017), 1,
      sym_add_operator,
    STATE(12474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 3,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [602857] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(2409), 1,
      sym_add_operator,
    STATE(12475), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [602890] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12476), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11795), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11797), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [602921] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11470), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11472), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [602952] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11508), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11510), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [602983] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15463), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15465), 1,
      sym_pow_operator,
    ACTIONS(15467), 1,
      sym_mult_operator,
    ACTIONS(15469), 1,
      sym_concat_operator,
    STATE(2391), 1,
      sym_add_operator,
    STATE(12479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_do,
      sym_rel_operator,
      sym_assign_operator,
  [603026] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12480), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11692), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11694), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [603057] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15654), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15656), 1,
      sym_pow_operator,
    ACTIONS(15658), 1,
      sym_mult_operator,
    ACTIONS(15660), 1,
      sym_concat_operator,
    ACTIONS(15662), 1,
      sym_rel_operator,
    ACTIONS(15664), 1,
      sym_and_operator,
    ACTIONS(15666), 1,
      sym_or_operator,
    ACTIONS(15677), 1,
      anon_sym_COMMA,
    ACTIONS(15679), 1,
      sym_assign_operator,
    STATE(2017), 1,
      sym_add_operator,
    STATE(12481), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10301), 3,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
  [603108] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12482), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [603149] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15191), 1,
      sym_pow_operator,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [603184] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15681), 1,
      anon_sym_else,
    STATE(7983), 1,
      sym_else_clause,
    STATE(12484), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [603219] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15463), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15465), 1,
      sym_pow_operator,
    ACTIONS(15467), 1,
      sym_mult_operator,
    ACTIONS(15469), 1,
      sym_concat_operator,
    STATE(2391), 1,
      sym_add_operator,
    STATE(12485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_do,
      sym_rel_operator,
      sym_assign_operator,
  [603262] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15654), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15656), 1,
      sym_pow_operator,
    ACTIONS(15658), 1,
      sym_mult_operator,
    ACTIONS(15660), 1,
      sym_concat_operator,
    ACTIONS(15662), 1,
      sym_rel_operator,
    ACTIONS(15664), 1,
      sym_and_operator,
    ACTIONS(15666), 1,
      sym_or_operator,
    ACTIONS(15677), 1,
      anon_sym_COMMA,
    ACTIONS(15679), 1,
      sym_assign_operator,
    STATE(2017), 1,
      sym_add_operator,
    STATE(12486), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10338), 3,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
  [603313] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11438), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11440), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [603344] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15683), 1,
      anon_sym_DQUOTE,
    STATE(12488), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19472), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [603385] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11442), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11444), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [603416] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15685), 1,
      anon_sym_SEMI,
    ACTIONS(15687), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12490), 1,
      sym_attribute,
    STATE(15886), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [603471] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15191), 1,
      sym_pow_operator,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12491), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [603506] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12492), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      sym_rel_operator,
      sym_assign_operator,
  [603549] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15354), 1,
      anon_sym_else,
    STATE(7983), 1,
      sym_else_clause,
    STATE(12493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [603584] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15689), 1,
      anon_sym_DQUOTE,
    STATE(12494), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(18695), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [603625] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15691), 1,
      anon_sym_RBRACK,
    ACTIONS(15693), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12495), 1,
      sym_attribute,
    STATE(15900), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [603680] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15424), 1,
      anon_sym_and,
    STATE(12496), 1,
      sym_attribute,
    STATE(12529), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15057), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [603713] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15695), 1,
      anon_sym_SEMI,
    ACTIONS(15697), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12497), 1,
      sym_attribute,
    STATE(15532), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [603768] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15699), 1,
      anon_sym_DQUOTE,
    STATE(12498), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(18260), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [603809] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15701), 1,
      anon_sym_DQUOTE,
    STATE(12499), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19701), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [603850] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15465), 1,
      sym_pow_operator,
    STATE(2391), 1,
      sym_add_operator,
    STATE(12500), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [603885] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15465), 1,
      sym_pow_operator,
    STATE(2391), 1,
      sym_add_operator,
    STATE(12501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [603920] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      sym_assign_operator,
  [603967] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13327), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13329), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(15342), 1,
      anon_sym_LPAREN,
    STATE(12503), 1,
      sym_attribute,
    STATE(13213), 1,
      sym__simple_module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13238), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(10239), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [604006] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15463), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15465), 1,
      sym_pow_operator,
    ACTIONS(15467), 1,
      sym_mult_operator,
    STATE(2391), 1,
      sym_add_operator,
    STATE(12504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [604047] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12505), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      sym_assign_operator,
  [604096] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 2,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [604149] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12507), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [604186] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15656), 1,
      sym_pow_operator,
    ACTIONS(15658), 1,
      sym_mult_operator,
    STATE(2017), 1,
      sym_add_operator,
    STATE(12508), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 5,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [604223] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15703), 1,
      anon_sym_RBRACK,
    ACTIONS(15705), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12509), 1,
      sym_attribute,
    STATE(16217), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [604278] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15707), 1,
      anon_sym_RBRACK,
    ACTIONS(15709), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12510), 1,
      sym_attribute,
    STATE(16092), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [604333] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10303), 1,
      anon_sym_PIPE,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12511), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10301), 2,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [604386] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15711), 1,
      anon_sym_RBRACK,
    ACTIONS(15713), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12512), 1,
      sym_attribute,
    STATE(15525), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [604441] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15715), 1,
      anon_sym_SEMI,
    ACTIONS(15717), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12513), 1,
      sym_attribute,
    STATE(16165), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [604496] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15330), 1,
      anon_sym_PIPE,
    STATE(12514), 1,
      sym_attribute,
    STATE(12520), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10321), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10319), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [604531] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13374), 1,
      anon_sym_STAR,
    ACTIONS(13445), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(12515), 1,
      sym_attribute,
    STATE(12518), 1,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13443), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [604566] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10344), 1,
      anon_sym_PIPE,
    ACTIONS(15463), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15465), 1,
      sym_pow_operator,
    ACTIONS(15467), 1,
      sym_mult_operator,
    ACTIONS(15469), 1,
      sym_concat_operator,
    ACTIONS(15471), 1,
      sym_rel_operator,
    ACTIONS(15473), 1,
      sym_and_operator,
    ACTIONS(15475), 1,
      sym_or_operator,
    STATE(2391), 1,
      sym_add_operator,
    STATE(12516), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_do,
      sym_assign_operator,
  [604615] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12517), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10325), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [604646] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12087), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15719), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12518), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(12085), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [604679] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15722), 1,
      anon_sym_SEMI,
    ACTIONS(15724), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12519), 1,
      sym_attribute,
    STATE(16291), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [604734] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15726), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12520), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10325), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [604767] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15729), 1,
      anon_sym_SEMI,
    ACTIONS(15731), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12521), 1,
      sym_attribute,
    STATE(16166), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [604822] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15733), 1,
      anon_sym_DQUOTE,
    STATE(12522), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19090), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [604863] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(15151), 1,
      sym_pow_operator,
    ACTIONS(15366), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15368), 1,
      sym_mult_operator,
    ACTIONS(15370), 1,
      sym_concat_operator,
    ACTIONS(15372), 1,
      sym_rel_operator,
    ACTIONS(15374), 1,
      sym_and_operator,
    ACTIONS(15376), 1,
      sym_or_operator,
    STATE(2365), 1,
      sym_add_operator,
    STATE(12523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      sym_assign_operator,
  [604912] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15735), 1,
      anon_sym_SEMI,
    ACTIONS(15737), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12524), 1,
      sym_attribute,
    STATE(16027), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [604967] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12525), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10370), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10368), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [604998] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15739), 1,
      anon_sym_RBRACK,
    ACTIONS(15741), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12526), 1,
      sym_attribute,
    STATE(16038), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [605053] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15743), 1,
      anon_sym_DQUOTE,
    STATE(12527), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(20102), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [605094] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10340), 1,
      anon_sym_PIPE,
    ACTIONS(15151), 1,
      sym_pow_operator,
    ACTIONS(15362), 1,
      anon_sym_COMMA,
    ACTIONS(15366), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15368), 1,
      sym_mult_operator,
    ACTIONS(15370), 1,
      sym_concat_operator,
    ACTIONS(15372), 1,
      sym_rel_operator,
    ACTIONS(15374), 1,
      sym_and_operator,
    ACTIONS(15376), 1,
      sym_or_operator,
    ACTIONS(15378), 1,
      sym_assign_operator,
    STATE(2365), 1,
      sym_add_operator,
    STATE(12528), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10338), 2,
      anon_sym_SEMI,
      anon_sym_then,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [605147] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15745), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12529), 2,
      sym_attribute,
      aux_sym_type_definition_repeat1,
    ACTIONS(14178), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [605178] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15748), 1,
      anon_sym_DQUOTE,
    STATE(12530), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(18350), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [605219] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12531), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10377), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10375), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [605250] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15750), 1,
      anon_sym_let,
    STATE(12532), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10573), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [605281] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15752), 1,
      anon_sym_DQUOTE,
    STATE(12533), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(18183), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [605322] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11446), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11448), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [605353] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15424), 1,
      anon_sym_and,
    STATE(12323), 1,
      aux_sym_type_definition_repeat1,
    STATE(12535), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15057), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [605386] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10340), 1,
      anon_sym_PIPE,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12536), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10338), 2,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [605439] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15754), 1,
      anon_sym_else,
    STATE(7983), 1,
      sym_else_clause,
    STATE(12537), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10291), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10289), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [605474] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11676), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11678), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [605505] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10303), 1,
      anon_sym_PIPE,
    ACTIONS(15151), 1,
      sym_pow_operator,
    ACTIONS(15362), 1,
      anon_sym_COMMA,
    ACTIONS(15366), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15368), 1,
      sym_mult_operator,
    ACTIONS(15370), 1,
      sym_concat_operator,
    ACTIONS(15372), 1,
      sym_rel_operator,
    ACTIONS(15374), 1,
      sym_and_operator,
    ACTIONS(15376), 1,
      sym_or_operator,
    ACTIONS(15378), 1,
      sym_assign_operator,
    STATE(2365), 1,
      sym_add_operator,
    STATE(12539), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10301), 2,
      anon_sym_SEMI,
      anon_sym_then,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [605558] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15151), 1,
      sym_pow_operator,
    ACTIONS(15368), 1,
      sym_mult_operator,
    STATE(2365), 1,
      sym_add_operator,
    STATE(12540), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [605595] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15756), 1,
      anon_sym_RBRACK,
    ACTIONS(15758), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12541), 1,
      sym_attribute,
    STATE(16310), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [605650] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15760), 1,
      anon_sym_RBRACK,
    ACTIONS(15762), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12542), 1,
      sym_attribute,
    STATE(15670), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [605705] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(2328), 1,
      sym_add_operator,
    STATE(12543), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [605738] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12544), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11478), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11480), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [605769] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      anon_sym_PIPE,
    ACTIONS(15151), 1,
      sym_pow_operator,
    ACTIONS(15362), 1,
      anon_sym_COMMA,
    ACTIONS(15366), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15368), 1,
      sym_mult_operator,
    ACTIONS(15370), 1,
      sym_concat_operator,
    ACTIONS(15372), 1,
      sym_rel_operator,
    ACTIONS(15374), 1,
      sym_and_operator,
    ACTIONS(15376), 1,
      sym_or_operator,
    ACTIONS(15378), 1,
      sym_assign_operator,
    STATE(2365), 1,
      sym_add_operator,
    STATE(12545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 2,
      anon_sym_SEMI,
      anon_sym_then,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [605822] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15764), 1,
      anon_sym_SEMI,
    ACTIONS(15766), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12546), 1,
      sym_attribute,
    STATE(15646), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [605877] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15151), 1,
      sym_pow_operator,
    ACTIONS(15366), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15368), 1,
      sym_mult_operator,
    ACTIONS(15370), 1,
      sym_concat_operator,
    ACTIONS(15372), 1,
      sym_rel_operator,
    ACTIONS(15374), 1,
      sym_and_operator,
    STATE(2365), 1,
      sym_add_operator,
    STATE(12547), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      sym_assign_operator,
  [605924] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15151), 1,
      sym_pow_operator,
    ACTIONS(15366), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15368), 1,
      sym_mult_operator,
    ACTIONS(15370), 1,
      sym_concat_operator,
    STATE(2365), 1,
      sym_add_operator,
    STATE(12548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      sym_rel_operator,
      sym_assign_operator,
  [605967] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15151), 1,
      sym_pow_operator,
    ACTIONS(15366), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15368), 1,
      sym_mult_operator,
    ACTIONS(15370), 1,
      sym_concat_operator,
    STATE(2365), 1,
      sym_add_operator,
    STATE(12549), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      sym_rel_operator,
      sym_assign_operator,
  [606010] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15151), 1,
      sym_pow_operator,
    STATE(2365), 1,
      sym_add_operator,
    STATE(12550), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10271), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [606045] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15768), 1,
      anon_sym_DQUOTE,
    STATE(12551), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19311), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [606086] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15770), 1,
      anon_sym_SEMI,
    ACTIONS(15772), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12552), 1,
      sym_attribute,
    STATE(15438), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [606141] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15774), 1,
      anon_sym_SEMI,
    ACTIONS(15776), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12553), 1,
      sym_attribute,
    STATE(16149), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [606196] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15346), 1,
      anon_sym_and,
    STATE(12353), 1,
      aux_sym_module_definition_repeat1,
    STATE(12554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15019), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [606229] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15778), 1,
      anon_sym_DQUOTE,
    STATE(12555), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(18096), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [606270] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15151), 1,
      sym_pow_operator,
    ACTIONS(15366), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15368), 1,
      sym_mult_operator,
    STATE(2365), 1,
      sym_add_operator,
    STATE(12556), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10397), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10395), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [606311] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10344), 1,
      anon_sym_PIPE,
    ACTIONS(15540), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15542), 1,
      sym_pow_operator,
    ACTIONS(15544), 1,
      sym_mult_operator,
    ACTIONS(15546), 1,
      sym_concat_operator,
    ACTIONS(15548), 1,
      sym_rel_operator,
    ACTIONS(15550), 1,
      sym_and_operator,
    ACTIONS(15552), 1,
      sym_or_operator,
    STATE(2328), 1,
      sym_add_operator,
    STATE(12557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      sym_assign_operator,
  [606360] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15780), 1,
      anon_sym_RBRACK,
    ACTIONS(15782), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12558), 1,
      sym_attribute,
    STATE(15431), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [606415] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15784), 1,
      anon_sym_RBRACK,
    ACTIONS(15786), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12559), 1,
      sym_attribute,
    STATE(16155), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [606470] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15788), 1,
      anon_sym_RBRACK,
    ACTIONS(15790), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12560), 1,
      sym_attribute,
    STATE(15305), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [606525] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15792), 1,
      anon_sym_DQUOTE,
    STATE(12561), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19019), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [606566] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15794), 1,
      anon_sym_SEMI,
    ACTIONS(15796), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12562), 1,
      sym_attribute,
    STATE(15752), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [606621] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15798), 1,
      anon_sym_DQUOTE,
    STATE(12563), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(18439), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [606662] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15654), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15656), 1,
      sym_pow_operator,
    ACTIONS(15658), 1,
      sym_mult_operator,
    ACTIONS(15660), 1,
      sym_concat_operator,
    ACTIONS(15662), 1,
      sym_rel_operator,
    ACTIONS(15664), 1,
      sym_and_operator,
    ACTIONS(15666), 1,
      sym_or_operator,
    ACTIONS(15677), 1,
      anon_sym_COMMA,
    ACTIONS(15679), 1,
      sym_assign_operator,
    STATE(2017), 1,
      sym_add_operator,
    STATE(12564), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10330), 3,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
  [606713] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15800), 1,
      anon_sym_SEMI,
    ACTIONS(15802), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12565), 1,
      sym_attribute,
    STATE(15283), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [606768] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(2365), 1,
      sym_add_operator,
    STATE(12566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [606801] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15654), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15656), 1,
      sym_pow_operator,
    ACTIONS(15658), 1,
      sym_mult_operator,
    ACTIONS(15660), 1,
      sym_concat_operator,
    ACTIONS(15662), 1,
      sym_rel_operator,
    ACTIONS(15664), 1,
      sym_and_operator,
    ACTIONS(15666), 1,
      sym_or_operator,
    ACTIONS(15677), 1,
      anon_sym_COMMA,
    ACTIONS(15679), 1,
      sym_assign_operator,
    ACTIONS(15804), 1,
      anon_sym_SEMI,
    STATE(2017), 1,
      sym_add_operator,
    STATE(12567), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9114), 2,
      anon_sym_end,
      anon_sym_else,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [606854] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14747), 1,
      anon_sym_COMMA,
    ACTIONS(14751), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14753), 1,
      sym_pow_operator,
    ACTIONS(14755), 1,
      sym_mult_operator,
    ACTIONS(14757), 1,
      sym_concat_operator,
    ACTIONS(14759), 1,
      sym_rel_operator,
    ACTIONS(14761), 1,
      sym_and_operator,
    ACTIONS(14763), 1,
      sym_or_operator,
    ACTIONS(14765), 1,
      sym_assign_operator,
    ACTIONS(15806), 1,
      anon_sym_SEMI,
    STATE(2130), 1,
      sym_add_operator,
    STATE(12568), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9114), 2,
      anon_sym_to,
      anon_sym_downto,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [606907] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15346), 1,
      anon_sym_and,
    STATE(12569), 1,
      sym_attribute,
    STATE(12574), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14927), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [606940] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15626), 1,
      anon_sym_let,
    ACTIONS(15808), 1,
      anon_sym_in,
    STATE(12570), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15624), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [606973] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15810), 1,
      anon_sym_SEMI,
    ACTIONS(15812), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12571), 1,
      sym_attribute,
    STATE(15689), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [607028] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12572), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11494), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11496), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [607059] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15814), 1,
      anon_sym_RBRACK,
    ACTIONS(15816), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12573), 1,
      sym_attribute,
    STATE(15708), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [607114] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15818), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12574), 2,
      sym_attribute,
      aux_sym_module_definition_repeat1,
    ACTIONS(14170), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [607145] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15232), 1,
      anon_sym_COLON2,
    ACTIONS(15821), 1,
      anon_sym_COLON_GT,
    ACTIONS(15823), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12575), 1,
      sym_attribute,
    STATE(12840), 1,
      sym__typed,
    STATE(13100), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15825), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [607188] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15344), 1,
      anon_sym_else,
    STATE(7952), 1,
      sym_else_clause,
    STATE(12576), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [607223] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(15120), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15266), 1,
      anon_sym_DASH_GT,
    STATE(12577), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15118), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [607258] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(15124), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15266), 1,
      anon_sym_DASH_GT,
    STATE(12578), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15122), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [607293] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15346), 1,
      anon_sym_and,
    STATE(12285), 1,
      aux_sym_module_definition_repeat1,
    STATE(12579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14927), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [607326] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15827), 1,
      anon_sym_DQUOTE,
    STATE(12580), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(18312), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [607367] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15485), 1,
      sym_pow_operator,
    ACTIONS(15487), 1,
      sym_mult_operator,
    ACTIONS(15489), 1,
      sym_concat_operator,
    ACTIONS(15528), 1,
      sym_rel_operator,
    ACTIONS(15530), 1,
      sym_and_operator,
    ACTIONS(15532), 1,
      sym_or_operator,
    ACTIONS(15578), 1,
      anon_sym_COMMA,
    ACTIONS(15580), 1,
      sym_assign_operator,
    STATE(1921), 1,
      sym_add_operator,
    STATE(12581), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10330), 3,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
  [607418] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15754), 1,
      anon_sym_else,
    STATE(7952), 1,
      sym_else_clause,
    STATE(12582), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [607453] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15829), 1,
      anon_sym_SEMI,
    ACTIONS(15831), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12583), 1,
      sym_attribute,
    STATE(16297), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [607508] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15833), 1,
      anon_sym_SEMI,
    ACTIONS(15835), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12584), 1,
      sym_attribute,
    STATE(16342), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [607563] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15837), 1,
      anon_sym_RBRACK,
    ACTIONS(15839), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12585), 1,
      sym_attribute,
    STATE(15415), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [607618] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15841), 1,
      anon_sym_RBRACK,
    ACTIONS(15843), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12586), 1,
      sym_attribute,
    STATE(16312), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [607673] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15845), 1,
      anon_sym_DQUOTE,
    STATE(12587), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(18523), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [607714] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15847), 1,
      anon_sym_SEMI,
    ACTIONS(15849), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12588), 1,
      sym_attribute,
    STATE(15344), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [607769] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15851), 1,
      anon_sym_RBRACK,
    ACTIONS(15853), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12589), 1,
      sym_attribute,
    STATE(16354), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [607824] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12590), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [607855] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15424), 1,
      anon_sym_and,
    STATE(12394), 1,
      aux_sym_type_definition_repeat1,
    STATE(12591), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14904), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [607888] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15855), 1,
      anon_sym_SEMI,
    ACTIONS(15857), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12592), 1,
      sym_attribute,
    STATE(15400), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [607943] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12593), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11638), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11640), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [607974] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15859), 1,
      anon_sym_RBRACK,
    ACTIONS(15861), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12594), 1,
      sym_attribute,
    STATE(15337), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [608029] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12595), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11534), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11536), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [608060] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12596), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11434), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11436), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [608091] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12597), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11538), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11540), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [608122] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15863), 1,
      anon_sym_DQUOTE,
    STATE(12598), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(18851), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [608163] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15865), 1,
      anon_sym_DQUOTE,
    STATE(12599), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(19000), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [608204] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12600), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11576), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11578), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [608235] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8052), 1,
      anon_sym_let,
    STATE(12601), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [608266] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15867), 1,
      anon_sym_SEMI,
    ACTIONS(15869), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12602), 1,
      sym_attribute,
    STATE(15249), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [608321] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15871), 1,
      anon_sym_DQUOTE,
    STATE(12603), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(18446), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [608362] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15584), 1,
      anon_sym_else,
    STATE(7952), 1,
      sym_else_clause,
    STATE(12604), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [608397] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8056), 1,
      anon_sym_let,
    STATE(12605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [608428] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15873), 1,
      anon_sym_SEMI,
    ACTIONS(15875), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12606), 1,
      sym_attribute,
    STATE(15153), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [608483] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(2017), 1,
      sym_add_operator,
    STATE(12607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [608516] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15877), 1,
      anon_sym_SEMI,
    ACTIONS(15879), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12608), 1,
      sym_attribute,
    STATE(16439), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [608571] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15881), 1,
      anon_sym_RBRACK,
    ACTIONS(15883), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12609), 1,
      sym_attribute,
    STATE(15177), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [608626] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15414), 1,
      anon_sym_PIPE,
    STATE(12432), 1,
      aux_sym__match_cases_repeat1,
    STATE(12610), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [608661] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(1921), 1,
      sym_add_operator,
    STATE(12611), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [608694] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15414), 1,
      anon_sym_PIPE,
    STATE(12435), 1,
      aux_sym__match_cases_repeat1,
    STATE(12612), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10311), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10309), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [608729] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15885), 1,
      anon_sym_RBRACK,
    ACTIONS(15887), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12613), 1,
      sym_attribute,
    STATE(16453), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [608784] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15889), 1,
      anon_sym_SEMI,
    ACTIONS(15891), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12614), 1,
      sym_attribute,
    STATE(15162), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [608839] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15893), 1,
      anon_sym_DQUOTE,
    STATE(12615), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(18558), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [608880] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15895), 1,
      anon_sym_DQUOTE,
    STATE(12616), 1,
      sym_attribute,
    STATE(12627), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    STATE(18610), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [608921] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15897), 1,
      anon_sym_RBRACK,
    ACTIONS(15899), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12617), 1,
      sym_attribute,
    STATE(15652), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [608976] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15901), 1,
      anon_sym_RBRACK,
    ACTIONS(15903), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12618), 1,
      sym_attribute,
    STATE(15242), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [609031] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9114), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(9116), 1,
      anon_sym_PIPE,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    ACTIONS(15905), 1,
      anon_sym_SEMI,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12619), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [609086] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15300), 1,
      anon_sym_COMMA,
    ACTIONS(15302), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15304), 1,
      sym_pow_operator,
    ACTIONS(15306), 1,
      sym_mult_operator,
    ACTIONS(15308), 1,
      sym_concat_operator,
    ACTIONS(15310), 1,
      sym_rel_operator,
    ACTIONS(15312), 1,
      sym_and_operator,
    ACTIONS(15314), 1,
      sym_or_operator,
    ACTIONS(15316), 1,
      sym_assign_operator,
    ACTIONS(15907), 1,
      anon_sym_SEMI,
    STATE(2162), 1,
      sym_add_operator,
    STATE(12620), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9114), 2,
      anon_sym_else,
      anon_sym_do,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [609139] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15681), 1,
      anon_sym_else,
    STATE(7952), 1,
      sym_else_clause,
    STATE(12621), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10297), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10295), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [609174] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9114), 1,
      anon_sym_end,
    ACTIONS(9116), 1,
      anon_sym_PIPE,
    ACTIONS(15538), 1,
      anon_sym_COMMA,
    ACTIONS(15540), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15542), 1,
      sym_pow_operator,
    ACTIONS(15544), 1,
      sym_mult_operator,
    ACTIONS(15546), 1,
      sym_concat_operator,
    ACTIONS(15548), 1,
      sym_rel_operator,
    ACTIONS(15550), 1,
      sym_and_operator,
    ACTIONS(15552), 1,
      sym_or_operator,
    ACTIONS(15554), 1,
      sym_assign_operator,
    ACTIONS(15909), 1,
      anon_sym_SEMI,
    STATE(2328), 1,
      sym_add_operator,
    STATE(12622), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [609229] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(15911), 1,
      anon_sym_RBRACK,
    ACTIONS(15913), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12623), 1,
      sym_attribute,
    STATE(15146), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [609284] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1547), 1,
      anon_sym_LBRACK,
    ACTIONS(1557), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1569), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(15915), 1,
      sym__lowercase_identifier,
    ACTIONS(15917), 1,
      anon_sym_LPAREN,
    ACTIONS(15919), 1,
      anon_sym_LBRACE,
    ACTIONS(15921), 1,
      sym__uppercase_identifier,
    STATE(6536), 1,
      sym__value_name,
    STATE(6655), 1,
      sym_parenthesized_operator,
    STATE(6658), 1,
      sym__constructor_name,
    STATE(12624), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(6400), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [609332] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2471), 1,
      anon_sym_LBRACK,
    ACTIONS(2481), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2493), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(15923), 1,
      sym__lowercase_identifier,
    ACTIONS(15925), 1,
      anon_sym_LPAREN,
    ACTIONS(15927), 1,
      anon_sym_LBRACE,
    ACTIONS(15929), 1,
      sym__uppercase_identifier,
    STATE(6398), 1,
      sym_parenthesized_operator,
    STATE(6492), 1,
      sym__constructor_name,
    STATE(6530), 1,
      sym__value_name,
    STATE(12625), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(6387), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [609380] = 14,
    ACTIONS(47), 1,
      anon_sym_LBRACK,
    ACTIONS(71), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(91), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15931), 1,
      sym__lowercase_identifier,
    ACTIONS(15933), 1,
      anon_sym_LPAREN,
    ACTIONS(15935), 1,
      anon_sym_LBRACE,
    ACTIONS(15937), 1,
      sym__uppercase_identifier,
    STATE(4302), 1,
      sym_parenthesized_operator,
    STATE(4360), 1,
      sym__value_name,
    STATE(4420), 1,
      sym__constructor_name,
    STATE(12626), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(4349), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [609428] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15939), 1,
      anon_sym_DQUOTE,
    STATE(12627), 1,
      sym_attribute,
    STATE(12654), 1,
      aux_sym_string_content_repeat1,
    STATE(12923), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15175), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15177), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15173), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [609466] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9098), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [609494] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12629), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11416), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11414), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [609524] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12630), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11536), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11534), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [609554] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12631), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11640), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11638), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [609584] = 14,
    ACTIONS(585), 1,
      anon_sym_LBRACK,
    ACTIONS(595), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(607), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15941), 1,
      sym__lowercase_identifier,
    ACTIONS(15943), 1,
      anon_sym_LPAREN,
    ACTIONS(15945), 1,
      anon_sym_LBRACE,
    ACTIONS(15947), 1,
      sym__uppercase_identifier,
    STATE(3329), 1,
      sym__value_name,
    STATE(3492), 1,
      sym__constructor_name,
    STATE(3728), 1,
      sym_parenthesized_operator,
    STATE(12632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(3389), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [609632] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12633), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8350), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [609662] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12634), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9258), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9256), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [609692] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15949), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15951), 1,
      sym_pow_operator,
    ACTIONS(15953), 1,
      sym_mult_operator,
    ACTIONS(15955), 1,
      sym_concat_operator,
    STATE(1831), 1,
      sym_add_operator,
    STATE(12635), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      sym_rel_operator,
      sym_assign_operator,
  [609734] = 14,
    ACTIONS(863), 1,
      anon_sym_LBRACK,
    ACTIONS(873), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(885), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15957), 1,
      sym__lowercase_identifier,
    ACTIONS(15959), 1,
      anon_sym_LPAREN,
    ACTIONS(15961), 1,
      anon_sym_LBRACE,
    ACTIONS(15963), 1,
      sym__uppercase_identifier,
    STATE(4045), 1,
      sym__value_name,
    STATE(4160), 1,
      sym_parenthesized_operator,
    STATE(4175), 1,
      sym__constructor_name,
    STATE(12636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(4136), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [609782] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12637), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8354), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [609812] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8358), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [609842] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8362), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [609872] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15965), 1,
      anon_sym_and,
    STATE(12640), 1,
      sym_attribute,
    STATE(12715), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15064), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [609904] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12641), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8000), 2,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15967), 13,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [609934] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5591), 1,
      anon_sym_LBRACK,
    ACTIONS(5599), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5603), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(15969), 1,
      sym__lowercase_identifier,
    ACTIONS(15971), 1,
      anon_sym_LPAREN,
    ACTIONS(15973), 1,
      anon_sym_LBRACE,
    ACTIONS(15975), 1,
      sym__uppercase_identifier,
    STATE(6001), 1,
      sym__value_name,
    STATE(6031), 1,
      sym__constructor_name,
    STATE(6068), 1,
      sym_parenthesized_operator,
    STATE(12642), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5882), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [609982] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11706), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11704), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [610012] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11600), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [610042] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15949), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15951), 1,
      sym_pow_operator,
    ACTIONS(15953), 1,
      sym_mult_operator,
    ACTIONS(15955), 1,
      sym_concat_operator,
    ACTIONS(15977), 1,
      sym_rel_operator,
    ACTIONS(15979), 1,
      sym_and_operator,
    ACTIONS(15981), 1,
      sym_or_operator,
    STATE(1831), 1,
      sym_add_operator,
    STATE(12645), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      sym_assign_operator,
  [610088] = 14,
    ACTIONS(481), 1,
      anon_sym_LBRACK,
    ACTIONS(491), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(503), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15983), 1,
      sym__lowercase_identifier,
    ACTIONS(15985), 1,
      anon_sym_LPAREN,
    ACTIONS(15987), 1,
      anon_sym_LBRACE,
    ACTIONS(15989), 1,
      sym__uppercase_identifier,
    STATE(3349), 1,
      sym_parenthesized_operator,
    STATE(3424), 1,
      sym__constructor_name,
    STATE(3636), 1,
      sym__value_name,
    STATE(12646), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(3690), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [610136] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12647), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11476), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11474), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [610166] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15965), 1,
      anon_sym_and,
    STATE(12640), 1,
      aux_sym_module_definition_repeat1,
    STATE(12648), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14927), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [610198] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15991), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [610226] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12650), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15993), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [610254] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12651), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11644), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11642), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [610284] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15949), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15951), 1,
      sym_pow_operator,
    ACTIONS(15953), 1,
      sym_mult_operator,
    STATE(1831), 1,
      sym_add_operator,
    STATE(12652), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10397), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10395), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [610324] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9158), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [610354] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15995), 1,
      anon_sym_DQUOTE,
    STATE(12923), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16000), 2,
      sym__null,
      aux_sym_string_content_token2,
    STATE(12654), 2,
      sym_attribute,
      aux_sym_string_content_repeat1,
    ACTIONS(16003), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15997), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [610390] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15951), 1,
      sym_pow_operator,
    STATE(1831), 1,
      sym_add_operator,
    STATE(12655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [610424] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2523), 1,
      anon_sym_LBRACK,
    ACTIONS(2533), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2545), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16006), 1,
      sym__lowercase_identifier,
    ACTIONS(16008), 1,
      anon_sym_LPAREN,
    ACTIONS(16010), 1,
      anon_sym_LBRACE,
    ACTIONS(16012), 1,
      sym__uppercase_identifier,
    STATE(6379), 1,
      sym__constructor_name,
    STATE(6393), 1,
      sym__value_name,
    STATE(6647), 1,
      sym_parenthesized_operator,
    STATE(12656), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(6300), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [610472] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9892), 1,
      anon_sym_let,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(16014), 1,
      sym__lowercase_identifier,
    ACTIONS(16016), 1,
      anon_sym_LBRACK,
    STATE(10444), 1,
      sym__simple_class_type,
    STATE(12657), 1,
      sym_attribute,
    STATE(16788), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9607), 6,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_extension,
      sym_quoted_extension,
      sym_class_type_path,
  [610518] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11634), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11632), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [610548] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9114), 1,
      anon_sym_then,
    ACTIONS(16018), 1,
      anon_sym_COMMA,
    ACTIONS(16020), 1,
      anon_sym_SEMI,
    ACTIONS(16022), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16024), 1,
      sym_pow_operator,
    ACTIONS(16026), 1,
      sym_mult_operator,
    ACTIONS(16028), 1,
      sym_concat_operator,
    ACTIONS(16030), 1,
      sym_rel_operator,
    ACTIONS(16032), 1,
      sym_and_operator,
    ACTIONS(16034), 1,
      sym_or_operator,
    ACTIONS(16036), 1,
      sym_assign_operator,
    STATE(1873), 1,
      sym_add_operator,
    STATE(12659), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [610600] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16038), 1,
      anon_sym_and,
    STATE(12660), 1,
      sym_attribute,
    STATE(12662), 1,
      aux_sym_class_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15034), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [610632] = 14,
    ACTIONS(759), 1,
      anon_sym_LBRACK,
    ACTIONS(769), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(781), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16040), 1,
      sym__lowercase_identifier,
    ACTIONS(16042), 1,
      anon_sym_LPAREN,
    ACTIONS(16044), 1,
      anon_sym_LBRACE,
    ACTIONS(16046), 1,
      sym__uppercase_identifier,
    STATE(3767), 1,
      sym__constructor_name,
    STATE(3791), 1,
      sym_parenthesized_operator,
    STATE(3897), 1,
      sym__value_name,
    STATE(12661), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(3801), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [610680] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16048), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12662), 2,
      sym_attribute,
      aux_sym_class_definition_repeat1,
    ACTIONS(13929), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [610710] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15951), 1,
      sym_pow_operator,
    STATE(1831), 1,
      sym_add_operator,
    STATE(12663), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [610744] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(16051), 1,
      anon_sym_EQ,
    ACTIONS(16053), 1,
      anon_sym_DASH_GT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12664), 1,
      sym_attribute,
    STATE(13082), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16055), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [610784] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12665), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11552), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11550), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [610814] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12666), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11428), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11426), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [610844] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1177), 1,
      anon_sym_LBRACK,
    ACTIONS(1187), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1199), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16057), 1,
      sym__lowercase_identifier,
    ACTIONS(16059), 1,
      anon_sym_LPAREN,
    ACTIONS(16061), 1,
      anon_sym_LBRACE,
    ACTIONS(16063), 1,
      sym__uppercase_identifier,
    STATE(5346), 1,
      sym__constructor_name,
    STATE(5384), 1,
      sym__value_name,
    STATE(5392), 1,
      sym_parenthesized_operator,
    STATE(12667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5337), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [610892] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(1831), 1,
      sym_add_operator,
    STATE(12668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [610924] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9114), 1,
      anon_sym_with,
    ACTIONS(16065), 1,
      anon_sym_COMMA,
    ACTIONS(16067), 1,
      anon_sym_SEMI,
    ACTIONS(16069), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16071), 1,
      sym_pow_operator,
    ACTIONS(16073), 1,
      sym_mult_operator,
    ACTIONS(16075), 1,
      sym_concat_operator,
    ACTIONS(16077), 1,
      sym_rel_operator,
    ACTIONS(16079), 1,
      sym_and_operator,
    ACTIONS(16081), 1,
      sym_or_operator,
    ACTIONS(16083), 1,
      sym_assign_operator,
    STATE(2406), 1,
      sym_add_operator,
    STATE(12669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [610976] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(2406), 1,
      sym_add_operator,
    STATE(12670), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [611008] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9892), 1,
      anon_sym_let,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(16014), 1,
      sym__lowercase_identifier,
    ACTIONS(16016), 1,
      anon_sym_LBRACK,
    STATE(12671), 1,
      sym_attribute,
    STATE(13143), 1,
      sym__simple_class_type,
    STATE(16788), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9607), 6,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_extension,
      sym_quoted_extension,
      sym_class_type_path,
  [611054] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9114), 1,
      anon_sym_do,
    ACTIONS(16085), 1,
      anon_sym_COMMA,
    ACTIONS(16087), 1,
      anon_sym_SEMI,
    ACTIONS(16089), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16091), 1,
      sym_pow_operator,
    ACTIONS(16093), 1,
      sym_mult_operator,
    ACTIONS(16095), 1,
      sym_concat_operator,
    ACTIONS(16097), 1,
      sym_rel_operator,
    ACTIONS(16099), 1,
      sym_and_operator,
    ACTIONS(16101), 1,
      sym_or_operator,
    ACTIONS(16103), 1,
      sym_assign_operator,
    STATE(1852), 1,
      sym_add_operator,
    STATE(12672), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [611106] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15949), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15951), 1,
      sym_pow_operator,
    ACTIONS(15953), 1,
      sym_mult_operator,
    ACTIONS(15955), 1,
      sym_concat_operator,
    STATE(1831), 1,
      sym_add_operator,
    STATE(12673), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      sym_rel_operator,
      sym_assign_operator,
  [611148] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9114), 1,
      anon_sym_done,
    ACTIONS(15153), 1,
      anon_sym_COMMA,
    ACTIONS(15155), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15157), 1,
      sym_pow_operator,
    ACTIONS(15159), 1,
      sym_mult_operator,
    ACTIONS(15161), 1,
      sym_concat_operator,
    ACTIONS(15163), 1,
      sym_rel_operator,
    ACTIONS(15165), 1,
      sym_and_operator,
    ACTIONS(15167), 1,
      sym_or_operator,
    ACTIONS(15169), 1,
      sym_assign_operator,
    ACTIONS(16105), 1,
      anon_sym_SEMI,
    STATE(2168), 1,
      sym_add_operator,
    STATE(12674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [611200] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(1852), 1,
      sym_add_operator,
    STATE(12675), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [611232] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2593), 1,
      anon_sym_LBRACK,
    ACTIONS(2603), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2615), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16107), 1,
      sym__lowercase_identifier,
    ACTIONS(16109), 1,
      anon_sym_LPAREN,
    ACTIONS(16111), 1,
      anon_sym_LBRACE,
    ACTIONS(16113), 1,
      sym__uppercase_identifier,
    STATE(6945), 1,
      sym_parenthesized_operator,
    STATE(7039), 1,
      sym__constructor_name,
    STATE(7069), 1,
      sym__value_name,
    STATE(12676), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(7083), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [611280] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6279), 1,
      anon_sym_LBRACK,
    ACTIONS(6287), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6291), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16115), 1,
      sym__lowercase_identifier,
    ACTIONS(16117), 1,
      anon_sym_LPAREN,
    ACTIONS(16119), 1,
      anon_sym_LBRACE,
    ACTIONS(16121), 1,
      sym__uppercase_identifier,
    STATE(6853), 1,
      sym__value_name,
    STATE(7054), 1,
      sym__constructor_name,
    STATE(7163), 1,
      sym_parenthesized_operator,
    STATE(12677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(6760), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [611328] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13366), 1,
      sym_rel_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16123), 2,
      anon_sym_SEMI,
      anon_sym_GT_RBRACE,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [611378] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16018), 1,
      anon_sym_COMMA,
    ACTIONS(16022), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16024), 1,
      sym_pow_operator,
    ACTIONS(16026), 1,
      sym_mult_operator,
    ACTIONS(16028), 1,
      sym_concat_operator,
    ACTIONS(16030), 1,
      sym_rel_operator,
    ACTIONS(16032), 1,
      sym_and_operator,
    ACTIONS(16034), 1,
      sym_or_operator,
    ACTIONS(16036), 1,
      sym_assign_operator,
    STATE(1873), 1,
      sym_add_operator,
    STATE(12679), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 2,
      anon_sym_SEMI,
      anon_sym_then,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [611428] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11797), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11795), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [611458] = 14,
    ACTIONS(1067), 1,
      anon_sym_LBRACK,
    ACTIONS(1077), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1089), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16125), 1,
      sym__lowercase_identifier,
    ACTIONS(16127), 1,
      anon_sym_LPAREN,
    ACTIONS(16129), 1,
      anon_sym_LBRACE,
    ACTIONS(16131), 1,
      sym__uppercase_identifier,
    STATE(5159), 1,
      sym__constructor_name,
    STATE(5203), 1,
      sym_parenthesized_operator,
    STATE(5228), 1,
      sym__value_name,
    STATE(12681), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5180), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [611506] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9114), 1,
      anon_sym_with,
    ACTIONS(16065), 1,
      anon_sym_COMMA,
    ACTIONS(16069), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16071), 1,
      sym_pow_operator,
    ACTIONS(16073), 1,
      sym_mult_operator,
    ACTIONS(16075), 1,
      sym_concat_operator,
    ACTIONS(16077), 1,
      sym_rel_operator,
    ACTIONS(16079), 1,
      sym_and_operator,
    ACTIONS(16081), 1,
      sym_or_operator,
    ACTIONS(16083), 1,
      sym_assign_operator,
    ACTIONS(16133), 1,
      anon_sym_SEMI,
    STATE(2406), 1,
      sym_add_operator,
    STATE(12682), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [611558] = 14,
    ACTIONS(639), 1,
      anon_sym_LBRACK,
    ACTIONS(649), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(661), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16135), 1,
      sym__lowercase_identifier,
    ACTIONS(16137), 1,
      anon_sym_LPAREN,
    ACTIONS(16139), 1,
      anon_sym_LBRACE,
    ACTIONS(16141), 1,
      sym__uppercase_identifier,
    STATE(3377), 1,
      sym__value_name,
    STATE(3405), 1,
      sym_parenthesized_operator,
    STATE(3542), 1,
      sym__constructor_name,
    STATE(12683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(3594), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [611606] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12684), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11562), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11560), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [611636] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16085), 1,
      anon_sym_COMMA,
    ACTIONS(16089), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16091), 1,
      sym_pow_operator,
    ACTIONS(16093), 1,
      sym_mult_operator,
    ACTIONS(16095), 1,
      sym_concat_operator,
    ACTIONS(16097), 1,
      sym_rel_operator,
    ACTIONS(16099), 1,
      sym_and_operator,
    ACTIONS(16101), 1,
      sym_or_operator,
    ACTIONS(16103), 1,
      sym_assign_operator,
    STATE(1852), 1,
      sym_add_operator,
    STATE(12685), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10338), 2,
      anon_sym_SEMI,
      anon_sym_do,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [611686] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12686), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11472), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11470), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [611716] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12687), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11510), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11508), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [611746] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      sym_or_operator,
    ACTIONS(15949), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15951), 1,
      sym_pow_operator,
    ACTIONS(15953), 1,
      sym_mult_operator,
    ACTIONS(15955), 1,
      sym_concat_operator,
    ACTIONS(15977), 1,
      sym_rel_operator,
    ACTIONS(15979), 1,
      sym_and_operator,
    STATE(1831), 1,
      sym_add_operator,
    STATE(12688), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      sym_assign_operator,
  [611792] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14908), 1,
      sym__lowercase_identifier,
    ACTIONS(14910), 1,
      anon_sym_LPAREN,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(14918), 1,
      anon_sym__,
    ACTIONS(16143), 1,
      anon_sym_nonrec,
    STATE(11918), 1,
      sym_type_binding,
    STATE(12689), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(14539), 1,
      sym__type_params,
    STATE(16510), 1,
      sym__type_param,
    STATE(16511), 1,
      sym_extended_module_path,
    STATE(20272), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [611846] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_COMMA,
    ACTIONS(15187), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15191), 1,
      sym_pow_operator,
    ACTIONS(15193), 1,
      sym_mult_operator,
    ACTIONS(15195), 1,
      sym_concat_operator,
    ACTIONS(15197), 1,
      sym_rel_operator,
    ACTIONS(15199), 1,
      sym_and_operator,
    ACTIONS(15201), 1,
      sym_or_operator,
    ACTIONS(15203), 1,
      sym_assign_operator,
    STATE(2031), 1,
      sym_add_operator,
    STATE(12690), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16145), 2,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [611896] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12691), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11694), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11692), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [611926] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9892), 1,
      anon_sym_let,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(16014), 1,
      sym__lowercase_identifier,
    ACTIONS(16016), 1,
      anon_sym_LBRACK,
    STATE(10391), 1,
      sym__simple_class_type,
    STATE(12692), 1,
      sym_attribute,
    STATE(16788), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9607), 6,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_extension,
      sym_quoted_extension,
      sym_class_type_path,
  [611972] = 14,
    ACTIONS(417), 1,
      anon_sym_LBRACK,
    ACTIONS(435), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(447), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16147), 1,
      sym__lowercase_identifier,
    ACTIONS(16149), 1,
      anon_sym_LPAREN,
    ACTIONS(16151), 1,
      anon_sym_LBRACE,
    ACTIONS(16153), 1,
      sym__uppercase_identifier,
    STATE(4279), 1,
      sym_parenthesized_operator,
    STATE(4347), 1,
      sym__constructor_name,
    STATE(4350), 1,
      sym__value_name,
    STATE(12693), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(4376), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [612020] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15949), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15951), 1,
      sym_pow_operator,
    ACTIONS(15953), 1,
      sym_mult_operator,
    ACTIONS(15955), 1,
      sym_concat_operator,
    ACTIONS(15977), 1,
      sym_rel_operator,
    ACTIONS(15979), 1,
      sym_and_operator,
    ACTIONS(15981), 1,
      sym_or_operator,
    STATE(1831), 1,
      sym_add_operator,
    STATE(12694), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      sym_assign_operator,
  [612066] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12695), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11578), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11576), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [612096] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12696), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16155), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [612146] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12697), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11765), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11763), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [612176] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5695), 1,
      anon_sym_LBRACK,
    ACTIONS(5703), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5707), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16157), 1,
      sym__lowercase_identifier,
    ACTIONS(16159), 1,
      anon_sym_LPAREN,
    ACTIONS(16161), 1,
      anon_sym_LBRACE,
    ACTIONS(16163), 1,
      sym__uppercase_identifier,
    STATE(5909), 1,
      sym__value_name,
    STATE(5926), 1,
      sym__constructor_name,
    STATE(6060), 1,
      sym_parenthesized_operator,
    STATE(12698), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5989), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [612224] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1283), 1,
      anon_sym_LBRACK,
    ACTIONS(1293), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1313), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16165), 1,
      sym__lowercase_identifier,
    ACTIONS(16167), 1,
      anon_sym_LPAREN,
    ACTIONS(16169), 1,
      anon_sym_LBRACE,
    ACTIONS(16171), 1,
      sym__uppercase_identifier,
    STATE(5605), 1,
      sym__constructor_name,
    STATE(5655), 1,
      sym__value_name,
    STATE(5713), 1,
      sym_parenthesized_operator,
    STATE(12699), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5661), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [612272] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9114), 1,
      anon_sym_end,
    ACTIONS(15949), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15951), 1,
      sym_pow_operator,
    ACTIONS(15953), 1,
      sym_mult_operator,
    ACTIONS(15955), 1,
      sym_concat_operator,
    ACTIONS(15977), 1,
      sym_rel_operator,
    ACTIONS(15979), 1,
      sym_and_operator,
    ACTIONS(15981), 1,
      sym_or_operator,
    ACTIONS(16173), 1,
      anon_sym_COMMA,
    ACTIONS(16175), 1,
      anon_sym_SEMI,
    ACTIONS(16177), 1,
      sym_assign_operator,
    STATE(1831), 1,
      sym_add_operator,
    STATE(12700), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [612324] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2305), 1,
      anon_sym_LBRACK,
    ACTIONS(2315), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2327), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16179), 1,
      sym__lowercase_identifier,
    ACTIONS(16181), 1,
      anon_sym_LPAREN,
    ACTIONS(16183), 1,
      anon_sym_LBRACE,
    ACTIONS(16185), 1,
      sym__uppercase_identifier,
    STATE(6250), 1,
      sym__value_name,
    STATE(6437), 1,
      sym_parenthesized_operator,
    STATE(6541), 1,
      sym__constructor_name,
    STATE(12701), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(6475), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [612372] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11440), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11438), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [612402] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15949), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15951), 1,
      sym_pow_operator,
    ACTIONS(15953), 1,
      sym_mult_operator,
    ACTIONS(15955), 1,
      sym_concat_operator,
    ACTIONS(15977), 1,
      sym_rel_operator,
    ACTIONS(15979), 1,
      sym_and_operator,
    ACTIONS(15981), 1,
      sym_or_operator,
    ACTIONS(16173), 1,
      anon_sym_COMMA,
    ACTIONS(16177), 1,
      sym_assign_operator,
    STATE(1831), 1,
      sym_add_operator,
    STATE(12703), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 2,
      anon_sym_SEMI,
      anon_sym_end,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [612452] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7771), 1,
      anon_sym_LBRACK,
    ACTIONS(7779), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7783), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16187), 1,
      sym__lowercase_identifier,
    ACTIONS(16189), 1,
      anon_sym_LPAREN,
    ACTIONS(16191), 1,
      anon_sym_LBRACE,
    ACTIONS(16193), 1,
      sym__uppercase_identifier,
    STATE(8161), 1,
      sym__constructor_name,
    STATE(9072), 1,
      sym_parenthesized_operator,
    STATE(9178), 1,
      sym__value_name,
    STATE(12704), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9207), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [612500] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9892), 1,
      anon_sym_let,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(16014), 1,
      sym__lowercase_identifier,
    ACTIONS(16016), 1,
      anon_sym_LBRACK,
    STATE(10485), 1,
      sym__simple_class_type,
    STATE(12705), 1,
      sym_attribute,
    STATE(16788), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9607), 6,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_extension,
      sym_quoted_extension,
      sym_class_type_path,
  [612546] = 14,
    ACTIONS(305), 1,
      anon_sym_LBRACK,
    ACTIONS(315), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(327), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16195), 1,
      sym__lowercase_identifier,
    ACTIONS(16197), 1,
      anon_sym_LPAREN,
    ACTIONS(16199), 1,
      anon_sym_LBRACE,
    ACTIONS(16201), 1,
      sym__uppercase_identifier,
    STATE(2968), 1,
      sym__value_name,
    STATE(3089), 1,
      sym_parenthesized_operator,
    STATE(3196), 1,
      sym__constructor_name,
    STATE(12706), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(3021), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [612594] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12707), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11444), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11442), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [612624] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(16053), 1,
      anon_sym_DASH_GT,
    ACTIONS(16203), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12708), 1,
      sym_attribute,
    STATE(13027), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16205), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [612664] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2645), 1,
      anon_sym_LBRACK,
    ACTIONS(2655), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2667), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16207), 1,
      sym__lowercase_identifier,
    ACTIONS(16209), 1,
      anon_sym_LPAREN,
    ACTIONS(16211), 1,
      anon_sym_LBRACE,
    ACTIONS(16213), 1,
      sym__uppercase_identifier,
    STATE(6728), 1,
      sym__constructor_name,
    STATE(7098), 1,
      sym__value_name,
    STATE(7160), 1,
      sym_parenthesized_operator,
    STATE(12709), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(6993), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [612712] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10393), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(16215), 1,
      anon_sym_STAR,
    STATE(12710), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10391), 13,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [612744] = 14,
    ACTIONS(919), 1,
      anon_sym_LBRACK,
    ACTIONS(929), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(949), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16217), 1,
      sym__lowercase_identifier,
    ACTIONS(16219), 1,
      anon_sym_LPAREN,
    ACTIONS(16221), 1,
      anon_sym_LBRACE,
    ACTIONS(16223), 1,
      sym__uppercase_identifier,
    STATE(4777), 1,
      sym__constructor_name,
    STATE(4810), 1,
      sym__value_name,
    STATE(4812), 1,
      sym_parenthesized_operator,
    STATE(12711), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(4897), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [612792] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9114), 1,
      anon_sym_end,
    ACTIONS(15949), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15951), 1,
      sym_pow_operator,
    ACTIONS(15953), 1,
      sym_mult_operator,
    ACTIONS(15955), 1,
      sym_concat_operator,
    ACTIONS(15977), 1,
      sym_rel_operator,
    ACTIONS(15979), 1,
      sym_and_operator,
    ACTIONS(15981), 1,
      sym_or_operator,
    ACTIONS(16173), 1,
      anon_sym_COMMA,
    ACTIONS(16177), 1,
      sym_assign_operator,
    ACTIONS(16225), 1,
      anon_sym_SEMI,
    STATE(1831), 1,
      sym_add_operator,
    STATE(12712), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [612844] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6945), 1,
      anon_sym_LBRACK,
    ACTIONS(6953), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6957), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16227), 1,
      sym__lowercase_identifier,
    ACTIONS(16229), 1,
      anon_sym_LPAREN,
    ACTIONS(16231), 1,
      anon_sym_LBRACE,
    ACTIONS(16233), 1,
      sym__uppercase_identifier,
    STATE(7880), 1,
      sym__value_name,
    STATE(7908), 1,
      sym_parenthesized_operator,
    STATE(7979), 1,
      sym__constructor_name,
    STATE(12713), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(7954), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [612892] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12714), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11448), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11446), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [612922] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16235), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12715), 2,
      sym_attribute,
      aux_sym_module_definition_repeat1,
    ACTIONS(14170), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [612952] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16238), 1,
      anon_sym_and,
    STATE(12716), 1,
      sym_attribute,
    STATE(12756), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15038), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [612984] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12717), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11678), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11676), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [613014] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14910), 1,
      anon_sym_LPAREN,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(14918), 1,
      anon_sym__,
    ACTIONS(15003), 1,
      sym__lowercase_identifier,
    ACTIONS(16240), 1,
      anon_sym_nonrec,
    STATE(12411), 1,
      sym_type_binding,
    STATE(12718), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(14437), 1,
      sym__type_params,
    STATE(16510), 1,
      sym__type_param,
    STATE(16511), 1,
      sym_extended_module_path,
    STATE(20500), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [613068] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1401), 1,
      anon_sym_LBRACK,
    ACTIONS(1411), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1423), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16242), 1,
      sym__lowercase_identifier,
    ACTIONS(16244), 1,
      anon_sym_LPAREN,
    ACTIONS(16246), 1,
      anon_sym_LBRACE,
    ACTIONS(16248), 1,
      sym__uppercase_identifier,
    STATE(5857), 1,
      sym_parenthesized_operator,
    STATE(6032), 1,
      sym__value_name,
    STATE(6047), 1,
      sym__constructor_name,
    STATE(12719), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5953), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [613116] = 14,
    ACTIONS(533), 1,
      anon_sym_LBRACK,
    ACTIONS(543), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(555), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16250), 1,
      sym__lowercase_identifier,
    ACTIONS(16252), 1,
      anon_sym_LPAREN,
    ACTIONS(16254), 1,
      anon_sym_LBRACE,
    ACTIONS(16256), 1,
      sym__uppercase_identifier,
    STATE(3337), 1,
      sym_parenthesized_operator,
    STATE(3459), 1,
      sym__constructor_name,
    STATE(3564), 1,
      sym__value_name,
    STATE(12720), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(3637), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [613164] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1121), 1,
      anon_sym_LBRACK,
    ACTIONS(1131), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1147), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16258), 1,
      sym__lowercase_identifier,
    ACTIONS(16260), 1,
      anon_sym_LPAREN,
    ACTIONS(16262), 1,
      anon_sym_LBRACE,
    ACTIONS(16264), 1,
      sym__uppercase_identifier,
    STATE(5044), 1,
      sym_parenthesized_operator,
    STATE(5077), 1,
      sym__constructor_name,
    STATE(5117), 1,
      sym__value_name,
    STATE(12721), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5074), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [613212] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2359), 1,
      anon_sym_LBRACK,
    ACTIONS(2369), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2381), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16266), 1,
      sym__lowercase_identifier,
    ACTIONS(16268), 1,
      anon_sym_LPAREN,
    ACTIONS(16270), 1,
      anon_sym_LBRACE,
    ACTIONS(16272), 1,
      sym__uppercase_identifier,
    STATE(6209), 1,
      sym__value_name,
    STATE(6499), 1,
      sym__constructor_name,
    STATE(6529), 1,
      sym_parenthesized_operator,
    STATE(12722), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(6251), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [613260] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15965), 1,
      anon_sym_and,
    STATE(12723), 1,
      sym_attribute,
    STATE(12752), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15011), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [613292] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15951), 1,
      sym_pow_operator,
    ACTIONS(15953), 1,
      sym_mult_operator,
    STATE(1831), 1,
      sym_add_operator,
    STATE(12724), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 5,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [613328] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12725), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11480), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11478), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [613358] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16022), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16024), 1,
      sym_pow_operator,
    ACTIONS(16026), 1,
      sym_mult_operator,
    ACTIONS(16028), 1,
      sym_concat_operator,
    ACTIONS(16030), 1,
      sym_rel_operator,
    ACTIONS(16032), 1,
      sym_and_operator,
    ACTIONS(16034), 1,
      sym_or_operator,
    STATE(1873), 1,
      sym_add_operator,
    STATE(12726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      sym_assign_operator,
  [613404] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12727), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11496), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11494), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [613434] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16089), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16091), 1,
      sym_pow_operator,
    ACTIONS(16093), 1,
      sym_mult_operator,
    ACTIONS(16095), 1,
      sym_concat_operator,
    ACTIONS(16097), 1,
      sym_rel_operator,
    ACTIONS(16099), 1,
      sym_and_operator,
    ACTIONS(16101), 1,
      sym_or_operator,
    STATE(1852), 1,
      sym_add_operator,
    STATE(12728), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_do,
      sym_assign_operator,
  [613480] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16274), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12729), 2,
      sym_attribute,
      aux_sym_class_definition_repeat1,
    ACTIONS(13929), 13,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [613510] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12730), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11436), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11434), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [613540] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16277), 1,
      anon_sym_and,
    STATE(12729), 1,
      aux_sym_class_definition_repeat1,
    STATE(12731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15034), 13,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [613572] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16279), 1,
      anon_sym_and,
    STATE(12732), 1,
      sym_attribute,
    STATE(12745), 1,
      aux_sym_class_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14979), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [613604] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(16053), 1,
      anon_sym_DASH_GT,
    ACTIONS(16281), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12733), 1,
      sym_attribute,
    STATE(12927), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16283), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [613644] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(16053), 1,
      anon_sym_DASH_GT,
    ACTIONS(16285), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12734), 1,
      sym_attribute,
    STATE(12938), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16287), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [613684] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14910), 1,
      anon_sym_LPAREN,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(14918), 1,
      anon_sym__,
    ACTIONS(15137), 1,
      sym__lowercase_identifier,
    ACTIONS(16289), 1,
      anon_sym_nonrec,
    STATE(12201), 1,
      sym_type_binding,
    STATE(12735), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(14599), 1,
      sym__type_params,
    STATE(16510), 1,
      sym__type_param,
    STATE(16511), 1,
      sym_extended_module_path,
    STATE(20242), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [613738] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16022), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16024), 1,
      sym_pow_operator,
    ACTIONS(16026), 1,
      sym_mult_operator,
    STATE(1873), 1,
      sym_add_operator,
    STATE(12736), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10397), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10395), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [613778] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(16053), 1,
      anon_sym_DASH_GT,
    ACTIONS(16291), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12737), 1,
      sym_attribute,
    STATE(13036), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16293), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [613818] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16024), 1,
      sym_pow_operator,
    STATE(1873), 1,
      sym_add_operator,
    STATE(12738), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [613852] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16024), 1,
      sym_pow_operator,
    STATE(1873), 1,
      sym_add_operator,
    STATE(12739), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [613886] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15949), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15951), 1,
      sym_pow_operator,
    ACTIONS(15953), 1,
      sym_mult_operator,
    ACTIONS(15955), 1,
      sym_concat_operator,
    ACTIONS(15977), 1,
      sym_rel_operator,
    ACTIONS(15979), 1,
      sym_and_operator,
    ACTIONS(15981), 1,
      sym_or_operator,
    ACTIONS(16173), 1,
      anon_sym_COMMA,
    ACTIONS(16177), 1,
      sym_assign_operator,
    STATE(1831), 1,
      sym_add_operator,
    STATE(12740), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10301), 2,
      anon_sym_SEMI,
      anon_sym_end,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [613936] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(16295), 1,
      sym__lowercase_identifier,
    ACTIONS(16297), 1,
      anon_sym_POUND,
    STATE(12741), 1,
      sym_attribute,
    STATE(12853), 1,
      sym_type_constructor_path,
    STATE(17215), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11124), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11126), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
  [613976] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16022), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16024), 1,
      sym_pow_operator,
    ACTIONS(16026), 1,
      sym_mult_operator,
    ACTIONS(16028), 1,
      sym_concat_operator,
    STATE(1873), 1,
      sym_add_operator,
    STATE(12742), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      sym_rel_operator,
      sym_assign_operator,
  [614018] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8460), 1,
      anon_sym_LBRACK,
    ACTIONS(8468), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8472), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16299), 1,
      sym__lowercase_identifier,
    ACTIONS(16301), 1,
      anon_sym_LPAREN,
    ACTIONS(16303), 1,
      anon_sym_LBRACE,
    ACTIONS(16305), 1,
      sym__uppercase_identifier,
    STATE(7327), 1,
      sym__value_name,
    STATE(7412), 1,
      sym_parenthesized_operator,
    STATE(7457), 1,
      sym__constructor_name,
    STATE(12743), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(7314), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [614066] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16238), 1,
      anon_sym_and,
    STATE(12744), 1,
      sym_attribute,
    STATE(12783), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14904), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [614098] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16279), 1,
      anon_sym_and,
    STATE(12745), 1,
      sym_attribute,
    STATE(12798), 1,
      aux_sym_class_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14791), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [614130] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16065), 1,
      anon_sym_COMMA,
    ACTIONS(16069), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16071), 1,
      sym_pow_operator,
    ACTIONS(16073), 1,
      sym_mult_operator,
    ACTIONS(16075), 1,
      sym_concat_operator,
    ACTIONS(16077), 1,
      sym_rel_operator,
    ACTIONS(16079), 1,
      sym_and_operator,
    ACTIONS(16081), 1,
      sym_or_operator,
    ACTIONS(16083), 1,
      sym_assign_operator,
    STATE(2406), 1,
      sym_add_operator,
    STATE(12746), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10338), 2,
      anon_sym_SEMI,
      anon_sym_with,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [614180] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LBRACK,
    ACTIONS(1239), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16307), 1,
      sym__lowercase_identifier,
    ACTIONS(16309), 1,
      anon_sym_LPAREN,
    ACTIONS(16311), 1,
      anon_sym_LBRACE,
    ACTIONS(16313), 1,
      sym__uppercase_identifier,
    STATE(5168), 1,
      sym__constructor_name,
    STATE(5264), 1,
      sym__value_name,
    STATE(5292), 1,
      sym_parenthesized_operator,
    STATE(12747), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5270), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [614228] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2419), 1,
      anon_sym_LBRACK,
    ACTIONS(2429), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2441), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16315), 1,
      sym__lowercase_identifier,
    ACTIONS(16317), 1,
      anon_sym_LPAREN,
    ACTIONS(16319), 1,
      anon_sym_LBRACE,
    ACTIONS(16321), 1,
      sym__uppercase_identifier,
    STATE(6301), 1,
      sym__value_name,
    STATE(6337), 1,
      sym__constructor_name,
    STATE(6621), 1,
      sym_parenthesized_operator,
    STATE(12748), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(6208), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [614276] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(16053), 1,
      anon_sym_DASH_GT,
    ACTIONS(16323), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12749), 1,
      sym_attribute,
    STATE(13009), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16325), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [614316] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16238), 1,
      anon_sym_and,
    STATE(12716), 1,
      aux_sym_type_definition_repeat1,
    STATE(12750), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15057), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [614348] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9114), 1,
      anon_sym_do,
    ACTIONS(16085), 1,
      anon_sym_COMMA,
    ACTIONS(16089), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16091), 1,
      sym_pow_operator,
    ACTIONS(16093), 1,
      sym_mult_operator,
    ACTIONS(16095), 1,
      sym_concat_operator,
    ACTIONS(16097), 1,
      sym_rel_operator,
    ACTIONS(16099), 1,
      sym_and_operator,
    ACTIONS(16101), 1,
      sym_or_operator,
    ACTIONS(16103), 1,
      sym_assign_operator,
    ACTIONS(16327), 1,
      anon_sym_SEMI,
    STATE(1852), 1,
      sym_add_operator,
    STATE(12751), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [614400] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15965), 1,
      anon_sym_and,
    STATE(12715), 1,
      aux_sym_module_definition_repeat1,
    STATE(12752), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14927), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [614432] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12753), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16145), 2,
      anon_sym_RBRACK,
      anon_sym_SEMI,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [614482] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16089), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16091), 1,
      sym_pow_operator,
    ACTIONS(16093), 1,
      sym_mult_operator,
    STATE(1852), 1,
      sym_add_operator,
    STATE(12754), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10397), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10395), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [614522] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15965), 1,
      anon_sym_and,
    STATE(12755), 1,
      sym_attribute,
    STATE(12822), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15019), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [614554] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16329), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12756), 2,
      sym_attribute,
      aux_sym_type_definition_repeat1,
    ACTIONS(14178), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [614584] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9116), 1,
      anon_sym_DASH_GT,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    ACTIONS(16332), 1,
      anon_sym_SEMI,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [614636] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16334), 1,
      sym__lowercase_identifier,
    ACTIONS(16336), 1,
      anon_sym_LPAREN,
    ACTIONS(16338), 1,
      anon_sym_LBRACE,
    ACTIONS(16340), 1,
      sym__uppercase_identifier,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7238), 1,
      sym__constructor_name,
    STATE(7413), 1,
      sym__value_name,
    STATE(12758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(7414), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [614684] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16279), 1,
      anon_sym_and,
    STATE(12759), 1,
      sym_attribute,
    STATE(12802), 1,
      aux_sym_class_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14791), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [614716] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16091), 1,
      sym_pow_operator,
    STATE(1852), 1,
      sym_add_operator,
    STATE(12760), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [614750] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9892), 1,
      anon_sym_let,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(16014), 1,
      sym__lowercase_identifier,
    ACTIONS(16016), 1,
      anon_sym_LBRACK,
    STATE(10663), 1,
      sym__simple_class_type,
    STATE(12761), 1,
      sym_attribute,
    STATE(16788), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9607), 6,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_extension,
      sym_quoted_extension,
      sym_class_type_path,
  [614796] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(16295), 1,
      sym__lowercase_identifier,
    ACTIONS(16342), 1,
      anon_sym_POUND,
    STATE(12762), 1,
      sym_attribute,
    STATE(12876), 1,
      sym_type_constructor_path,
    STATE(17215), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11128), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11130), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
  [614836] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16336), 1,
      anon_sym_LPAREN,
    ACTIONS(16338), 1,
      anon_sym_LBRACE,
    ACTIONS(16340), 1,
      sym__uppercase_identifier,
    ACTIONS(16344), 1,
      sym__lowercase_identifier,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7238), 1,
      sym__constructor_name,
    STATE(7413), 1,
      sym__value_name,
    STATE(12763), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(7414), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [614884] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16091), 1,
      sym_pow_operator,
    STATE(1852), 1,
      sym_add_operator,
    STATE(12764), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [614918] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(16295), 1,
      sym__lowercase_identifier,
    ACTIONS(16297), 1,
      anon_sym_POUND,
    STATE(12765), 1,
      sym_attribute,
    STATE(12853), 1,
      sym_type_constructor_path,
    STATE(17215), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10261), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10263), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
  [614958] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8024), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8034), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16334), 1,
      sym__lowercase_identifier,
    ACTIONS(16338), 1,
      anon_sym_LBRACE,
    ACTIONS(16340), 1,
      sym__uppercase_identifier,
    ACTIONS(16346), 1,
      anon_sym_LPAREN,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(7238), 1,
      sym__constructor_name,
    STATE(7413), 1,
      sym__value_name,
    STATE(12766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(7414), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [615006] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16238), 1,
      anon_sym_and,
    STATE(12756), 1,
      aux_sym_type_definition_repeat1,
    STATE(12767), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15057), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [615038] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16089), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16091), 1,
      sym_pow_operator,
    ACTIONS(16093), 1,
      sym_mult_operator,
    ACTIONS(16095), 1,
      sym_concat_operator,
    STATE(1852), 1,
      sym_add_operator,
    STATE(12768), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_do,
      sym_rel_operator,
      sym_assign_operator,
  [615080] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6559), 1,
      anon_sym_LBRACK,
    ACTIONS(6567), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6571), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16348), 1,
      sym__lowercase_identifier,
    ACTIONS(16350), 1,
      anon_sym_LPAREN,
    ACTIONS(16352), 1,
      anon_sym_LBRACE,
    ACTIONS(16354), 1,
      sym__uppercase_identifier,
    STATE(6841), 1,
      sym_parenthesized_operator,
    STATE(6874), 1,
      sym__constructor_name,
    STATE(6923), 1,
      sym__value_name,
    STATE(12769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(6671), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [615128] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2697), 1,
      anon_sym_LBRACK,
    ACTIONS(2707), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2719), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16356), 1,
      sym__lowercase_identifier,
    ACTIONS(16358), 1,
      anon_sym_LPAREN,
    ACTIONS(16360), 1,
      anon_sym_LBRACE,
    ACTIONS(16362), 1,
      sym__uppercase_identifier,
    STATE(6924), 1,
      sym__constructor_name,
    STATE(7147), 1,
      sym_parenthesized_operator,
    STATE(7240), 1,
      sym__value_name,
    STATE(12770), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(7241), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [615176] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16089), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16091), 1,
      sym_pow_operator,
    ACTIONS(16093), 1,
      sym_mult_operator,
    ACTIONS(16095), 1,
      sym_concat_operator,
    STATE(1852), 1,
      sym_add_operator,
    STATE(12771), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_do,
      sym_rel_operator,
      sym_assign_operator,
  [615218] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6239), 1,
      anon_sym_LBRACK,
    ACTIONS(6247), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6251), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16364), 1,
      sym__lowercase_identifier,
    ACTIONS(16366), 1,
      anon_sym_LPAREN,
    ACTIONS(16368), 1,
      anon_sym_LBRACE,
    ACTIONS(16370), 1,
      sym__uppercase_identifier,
    STATE(6761), 1,
      sym__value_name,
    STATE(7077), 1,
      sym_parenthesized_operator,
    STATE(7133), 1,
      sym__constructor_name,
    STATE(12772), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(6997), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [615266] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16277), 1,
      anon_sym_and,
    STATE(12731), 1,
      aux_sym_class_definition_repeat1,
    STATE(12773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14791), 13,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [615298] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      sym_or_operator,
    ACTIONS(16089), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16091), 1,
      sym_pow_operator,
    ACTIONS(16093), 1,
      sym_mult_operator,
    ACTIONS(16095), 1,
      sym_concat_operator,
    ACTIONS(16097), 1,
      sym_rel_operator,
    ACTIONS(16099), 1,
      sym_and_operator,
    STATE(1852), 1,
      sym_add_operator,
    STATE(12774), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_do,
      sym_assign_operator,
  [615344] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9892), 1,
      anon_sym_let,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(16014), 1,
      sym__lowercase_identifier,
    ACTIONS(16016), 1,
      anon_sym_LBRACK,
    STATE(9824), 1,
      sym__simple_class_type,
    STATE(12775), 1,
      sym_attribute,
    STATE(16788), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9607), 6,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_extension,
      sym_quoted_extension,
      sym_class_type_path,
  [615390] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11540), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11538), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [615420] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16277), 1,
      anon_sym_and,
    STATE(12777), 1,
      sym_attribute,
    STATE(12778), 1,
      aux_sym_class_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14979), 13,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [615452] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16277), 1,
      anon_sym_and,
    STATE(12729), 1,
      aux_sym_class_definition_repeat1,
    STATE(12778), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14791), 13,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [615484] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(1873), 1,
      sym_add_operator,
    STATE(12779), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [615516] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13356), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13360), 1,
      sym_pow_operator,
    ACTIONS(13362), 1,
      sym_mult_operator,
    ACTIONS(13364), 1,
      sym_concat_operator,
    ACTIONS(13368), 1,
      sym_and_operator,
    ACTIONS(13370), 1,
      sym_or_operator,
    ACTIONS(13372), 1,
      sym_assign_operator,
    ACTIONS(13881), 1,
      sym_rel_operator,
    STATE(2268), 1,
      sym_add_operator,
    STATE(12780), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16372), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [615566] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2815), 1,
      anon_sym_LBRACK,
    ACTIONS(2825), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2837), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16374), 1,
      sym__lowercase_identifier,
    ACTIONS(16376), 1,
      anon_sym_LPAREN,
    ACTIONS(16378), 1,
      anon_sym_LBRACE,
    ACTIONS(16380), 1,
      sym__uppercase_identifier,
    STATE(6914), 1,
      sym__constructor_name,
    STATE(7198), 1,
      sym__value_name,
    STATE(7200), 1,
      sym_parenthesized_operator,
    STATE(12781), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(7197), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [615614] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16089), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16091), 1,
      sym_pow_operator,
    ACTIONS(16093), 1,
      sym_mult_operator,
    ACTIONS(16095), 1,
      sym_concat_operator,
    ACTIONS(16097), 1,
      sym_rel_operator,
    ACTIONS(16099), 1,
      sym_and_operator,
    ACTIONS(16101), 1,
      sym_or_operator,
    STATE(1852), 1,
      sym_add_operator,
    STATE(12782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_do,
      sym_assign_operator,
  [615660] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16238), 1,
      anon_sym_and,
    STATE(12756), 1,
      aux_sym_type_definition_repeat1,
    STATE(12783), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14797), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [615692] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16065), 1,
      anon_sym_COMMA,
    ACTIONS(16069), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16071), 1,
      sym_pow_operator,
    ACTIONS(16073), 1,
      sym_mult_operator,
    ACTIONS(16075), 1,
      sym_concat_operator,
    ACTIONS(16077), 1,
      sym_rel_operator,
    ACTIONS(16079), 1,
      sym_and_operator,
    ACTIONS(16081), 1,
      sym_or_operator,
    ACTIONS(16083), 1,
      sym_assign_operator,
    STATE(2406), 1,
      sym_add_operator,
    STATE(12784), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10301), 2,
      anon_sym_SEMI,
      anon_sym_with,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [615742] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16038), 1,
      anon_sym_and,
    STATE(12785), 1,
      sym_attribute,
    STATE(12810), 1,
      aux_sym_class_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14979), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [615774] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16069), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16071), 1,
      sym_pow_operator,
    ACTIONS(16073), 1,
      sym_mult_operator,
    ACTIONS(16075), 1,
      sym_concat_operator,
    ACTIONS(16077), 1,
      sym_rel_operator,
    ACTIONS(16079), 1,
      sym_and_operator,
    ACTIONS(16081), 1,
      sym_or_operator,
    STATE(2406), 1,
      sym_add_operator,
    STATE(12786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10342), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      sym_assign_operator,
  [615820] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16069), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16071), 1,
      sym_pow_operator,
    ACTIONS(16073), 1,
      sym_mult_operator,
    STATE(2406), 1,
      sym_add_operator,
    STATE(12787), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10397), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10395), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [615860] = 17,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14910), 1,
      anon_sym_LPAREN,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(14918), 1,
      anon_sym__,
    ACTIONS(15071), 1,
      sym__lowercase_identifier,
    ACTIONS(16382), 1,
      anon_sym_nonrec,
    STATE(12788), 1,
      sym_attribute,
    STATE(12819), 1,
      sym_type_binding,
    STATE(14317), 1,
      sym_type_variable,
    STATE(14692), 1,
      sym__type_params,
    STATE(16510), 1,
      sym__type_param,
    STATE(16511), 1,
      sym_extended_module_path,
    STATE(20289), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [615914] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(9978), 1,
      anon_sym_let,
    ACTIONS(16384), 1,
      sym__lowercase_identifier,
    ACTIONS(16386), 1,
      anon_sym_LBRACK,
    STATE(9824), 1,
      sym__simple_class_type,
    STATE(12789), 1,
      sym_attribute,
    STATE(16582), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9607), 6,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_extension,
      sym_quoted_extension,
      sym_class_type_path,
  [615960] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16022), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16024), 1,
      sym_pow_operator,
    ACTIONS(16026), 1,
      sym_mult_operator,
    ACTIONS(16028), 1,
      sym_concat_operator,
    STATE(1873), 1,
      sym_add_operator,
    STATE(12790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      sym_rel_operator,
      sym_assign_operator,
  [616002] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15949), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15951), 1,
      sym_pow_operator,
    ACTIONS(15953), 1,
      sym_mult_operator,
    ACTIONS(15955), 1,
      sym_concat_operator,
    ACTIONS(15977), 1,
      sym_rel_operator,
    ACTIONS(15979), 1,
      sym_and_operator,
    ACTIONS(15981), 1,
      sym_or_operator,
    ACTIONS(16173), 1,
      anon_sym_COMMA,
    ACTIONS(16177), 1,
      sym_assign_operator,
    STATE(1831), 1,
      sym_add_operator,
    STATE(12791), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10338), 2,
      anon_sym_SEMI,
      anon_sym_end,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [616052] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9114), 1,
      anon_sym_then,
    ACTIONS(16018), 1,
      anon_sym_COMMA,
    ACTIONS(16022), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16024), 1,
      sym_pow_operator,
    ACTIONS(16026), 1,
      sym_mult_operator,
    ACTIONS(16028), 1,
      sym_concat_operator,
    ACTIONS(16030), 1,
      sym_rel_operator,
    ACTIONS(16032), 1,
      sym_and_operator,
    ACTIONS(16034), 1,
      sym_or_operator,
    ACTIONS(16036), 1,
      sym_assign_operator,
    ACTIONS(16388), 1,
      anon_sym_SEMI,
    STATE(1873), 1,
      sym_add_operator,
    STATE(12792), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [616104] = 14,
    ACTIONS(811), 1,
      anon_sym_LBRACK,
    ACTIONS(821), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(833), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16390), 1,
      sym__lowercase_identifier,
    ACTIONS(16392), 1,
      anon_sym_LPAREN,
    ACTIONS(16394), 1,
      anon_sym_LBRACE,
    ACTIONS(16396), 1,
      sym__uppercase_identifier,
    STATE(3972), 1,
      sym_parenthesized_operator,
    STATE(4038), 1,
      sym__value_name,
    STATE(4177), 1,
      sym__constructor_name,
    STATE(12793), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(4067), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [616152] = 14,
    ACTIONS(695), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(717), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16398), 1,
      sym__lowercase_identifier,
    ACTIONS(16400), 1,
      anon_sym_LPAREN,
    ACTIONS(16402), 1,
      anon_sym_LBRACE,
    ACTIONS(16404), 1,
      sym__uppercase_identifier,
    STATE(3822), 1,
      sym_parenthesized_operator,
    STATE(3847), 1,
      sym__value_name,
    STATE(3849), 1,
      sym__constructor_name,
    STATE(12794), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(3870), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [616200] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      sym_or_operator,
    ACTIONS(16022), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16024), 1,
      sym_pow_operator,
    ACTIONS(16026), 1,
      sym_mult_operator,
    ACTIONS(16028), 1,
      sym_concat_operator,
    ACTIONS(16030), 1,
      sym_rel_operator,
    ACTIONS(16032), 1,
      sym_and_operator,
    STATE(1873), 1,
      sym_add_operator,
    STATE(12795), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      sym_assign_operator,
  [616246] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16071), 1,
      sym_pow_operator,
    STATE(2406), 1,
      sym_add_operator,
    STATE(12796), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [616280] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16071), 1,
      sym_pow_operator,
    STATE(2406), 1,
      sym_add_operator,
    STATE(12797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [616314] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16406), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12798), 2,
      sym_attribute,
      aux_sym_class_definition_repeat1,
    ACTIONS(13929), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [616344] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16069), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16071), 1,
      sym_pow_operator,
    ACTIONS(16073), 1,
      sym_mult_operator,
    ACTIONS(16075), 1,
      sym_concat_operator,
    STATE(2406), 1,
      sym_add_operator,
    STATE(12799), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      sym_rel_operator,
      sym_assign_operator,
  [616386] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16022), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16024), 1,
      sym_pow_operator,
    ACTIONS(16026), 1,
      sym_mult_operator,
    ACTIONS(16028), 1,
      sym_concat_operator,
    ACTIONS(16030), 1,
      sym_rel_operator,
    ACTIONS(16032), 1,
      sym_and_operator,
    ACTIONS(16034), 1,
      sym_or_operator,
    STATE(1873), 1,
      sym_add_operator,
    STATE(12800), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      sym_assign_operator,
  [616432] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8518), 1,
      anon_sym_LBRACK,
    ACTIONS(8526), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8530), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16409), 1,
      sym__lowercase_identifier,
    ACTIONS(16411), 1,
      anon_sym_LPAREN,
    ACTIONS(16413), 1,
      anon_sym_LBRACE,
    ACTIONS(16415), 1,
      sym__uppercase_identifier,
    STATE(7470), 1,
      sym__constructor_name,
    STATE(7580), 1,
      sym_parenthesized_operator,
    STATE(7649), 1,
      sym__value_name,
    STATE(12801), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(7702), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [616480] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16279), 1,
      anon_sym_and,
    STATE(12798), 1,
      aux_sym_class_definition_repeat1,
    STATE(12802), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15034), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [616512] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16024), 1,
      sym_pow_operator,
    ACTIONS(16026), 1,
      sym_mult_operator,
    STATE(1873), 1,
      sym_add_operator,
    STATE(12803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 5,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [616548] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8560), 1,
      anon_sym_LBRACK,
    ACTIONS(8568), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8572), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16417), 1,
      sym__lowercase_identifier,
    ACTIONS(16419), 1,
      anon_sym_LPAREN,
    ACTIONS(16421), 1,
      anon_sym_LBRACE,
    ACTIONS(16423), 1,
      sym__uppercase_identifier,
    STATE(9622), 1,
      sym__value_name,
    STATE(9756), 1,
      sym__constructor_name,
    STATE(9784), 1,
      sym_parenthesized_operator,
    STATE(12804), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9657), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [616596] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16018), 1,
      anon_sym_COMMA,
    ACTIONS(16022), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16024), 1,
      sym_pow_operator,
    ACTIONS(16026), 1,
      sym_mult_operator,
    ACTIONS(16028), 1,
      sym_concat_operator,
    ACTIONS(16030), 1,
      sym_rel_operator,
    ACTIONS(16032), 1,
      sym_and_operator,
    ACTIONS(16034), 1,
      sym_or_operator,
    ACTIONS(16036), 1,
      sym_assign_operator,
    STATE(1873), 1,
      sym_add_operator,
    STATE(12805), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10301), 2,
      anon_sym_SEMI,
      anon_sym_then,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [616646] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16069), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16071), 1,
      sym_pow_operator,
    ACTIONS(16073), 1,
      sym_mult_operator,
    ACTIONS(16075), 1,
      sym_concat_operator,
    STATE(2406), 1,
      sym_add_operator,
    STATE(12806), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      sym_rel_operator,
      sym_assign_operator,
  [616688] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16018), 1,
      anon_sym_COMMA,
    ACTIONS(16022), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16024), 1,
      sym_pow_operator,
    ACTIONS(16026), 1,
      sym_mult_operator,
    ACTIONS(16028), 1,
      sym_concat_operator,
    ACTIONS(16030), 1,
      sym_rel_operator,
    ACTIONS(16032), 1,
      sym_and_operator,
    ACTIONS(16034), 1,
      sym_or_operator,
    ACTIONS(16036), 1,
      sym_assign_operator,
    STATE(1873), 1,
      sym_add_operator,
    STATE(12807), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10338), 2,
      anon_sym_SEMI,
      anon_sym_then,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [616738] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16038), 1,
      anon_sym_and,
    STATE(12660), 1,
      aux_sym_class_definition_repeat1,
    STATE(12808), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14791), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [616770] = 14,
    ACTIONS(1001), 1,
      anon_sym_LBRACK,
    ACTIONS(1011), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1023), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16425), 1,
      sym__lowercase_identifier,
    ACTIONS(16427), 1,
      anon_sym_LPAREN,
    ACTIONS(16429), 1,
      anon_sym_LBRACE,
    ACTIONS(16431), 1,
      sym__uppercase_identifier,
    STATE(4935), 1,
      sym_parenthesized_operator,
    STATE(4962), 1,
      sym__value_name,
    STATE(4980), 1,
      sym__constructor_name,
    STATE(12809), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(4938), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [616818] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16038), 1,
      anon_sym_and,
    STATE(12662), 1,
      aux_sym_class_definition_repeat1,
    STATE(12810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14791), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [616850] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(9892), 1,
      anon_sym_let,
    ACTIONS(9898), 1,
      anon_sym_object,
    ACTIONS(16014), 1,
      sym__lowercase_identifier,
    ACTIONS(16016), 1,
      anon_sym_LBRACK,
    STATE(10419), 1,
      sym__simple_class_type,
    STATE(12811), 1,
      sym_attribute,
    STATE(16788), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9607), 6,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_extension,
      sym_quoted_extension,
      sym_class_type_path,
  [616896] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10271), 1,
      sym_or_operator,
    ACTIONS(16069), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16071), 1,
      sym_pow_operator,
    ACTIONS(16073), 1,
      sym_mult_operator,
    ACTIONS(16075), 1,
      sym_concat_operator,
    ACTIONS(16077), 1,
      sym_rel_operator,
    ACTIONS(16079), 1,
      sym_and_operator,
    STATE(2406), 1,
      sym_add_operator,
    STATE(12812), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      sym_assign_operator,
  [616942] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16085), 1,
      anon_sym_COMMA,
    ACTIONS(16089), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16091), 1,
      sym_pow_operator,
    ACTIONS(16093), 1,
      sym_mult_operator,
    ACTIONS(16095), 1,
      sym_concat_operator,
    ACTIONS(16097), 1,
      sym_rel_operator,
    ACTIONS(16099), 1,
      sym_and_operator,
    ACTIONS(16101), 1,
      sym_or_operator,
    ACTIONS(16103), 1,
      sym_assign_operator,
    STATE(1852), 1,
      sym_add_operator,
    STATE(12813), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 2,
      anon_sym_SEMI,
      anon_sym_do,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [616992] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2749), 1,
      anon_sym_LBRACK,
    ACTIONS(2759), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2771), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16433), 1,
      sym__lowercase_identifier,
    ACTIONS(16435), 1,
      anon_sym_LPAREN,
    ACTIONS(16437), 1,
      anon_sym_LBRACE,
    ACTIONS(16439), 1,
      sym__uppercase_identifier,
    STATE(6763), 1,
      sym__constructor_name,
    STATE(6951), 1,
      sym__value_name,
    STATE(7065), 1,
      sym_parenthesized_operator,
    STATE(12814), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(6959), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [617040] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12815), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11134), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [617068] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16091), 1,
      sym_pow_operator,
    ACTIONS(16093), 1,
      sym_mult_operator,
    STATE(1852), 1,
      sym_add_operator,
    STATE(12816), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 5,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [617104] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16069), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16071), 1,
      sym_pow_operator,
    ACTIONS(16073), 1,
      sym_mult_operator,
    ACTIONS(16075), 1,
      sym_concat_operator,
    ACTIONS(16077), 1,
      sym_rel_operator,
    ACTIONS(16079), 1,
      sym_and_operator,
    ACTIONS(16081), 1,
      sym_or_operator,
    STATE(2406), 1,
      sym_add_operator,
    STATE(12817), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10269), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      sym_assign_operator,
  [617150] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16065), 1,
      anon_sym_COMMA,
    ACTIONS(16069), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16071), 1,
      sym_pow_operator,
    ACTIONS(16073), 1,
      sym_mult_operator,
    ACTIONS(16075), 1,
      sym_concat_operator,
    ACTIONS(16077), 1,
      sym_rel_operator,
    ACTIONS(16079), 1,
      sym_and_operator,
    ACTIONS(16081), 1,
      sym_or_operator,
    ACTIONS(16083), 1,
      sym_assign_operator,
    STATE(2406), 1,
      sym_add_operator,
    STATE(12818), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10269), 2,
      anon_sym_SEMI,
      anon_sym_with,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [617200] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16238), 1,
      anon_sym_and,
    STATE(12767), 1,
      aux_sym_type_definition_repeat1,
    STATE(12819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14797), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [617232] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(1343), 1,
      anon_sym_LBRACK,
    ACTIONS(1353), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1365), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16441), 1,
      sym__lowercase_identifier,
    ACTIONS(16443), 1,
      anon_sym_LPAREN,
    ACTIONS(16445), 1,
      anon_sym_LBRACE,
    ACTIONS(16447), 1,
      sym__uppercase_identifier,
    STATE(5765), 1,
      sym__value_name,
    STATE(5786), 1,
      sym_parenthesized_operator,
    STATE(5806), 1,
      sym__constructor_name,
    STATE(12820), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5800), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [617280] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16071), 1,
      sym_pow_operator,
    ACTIONS(16073), 1,
      sym_mult_operator,
    STATE(2406), 1,
      sym_add_operator,
    STATE(12821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 5,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10269), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [617316] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15965), 1,
      anon_sym_and,
    STATE(12715), 1,
      aux_sym_module_definition_repeat1,
    STATE(12822), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15011), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [617348] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16085), 1,
      anon_sym_COMMA,
    ACTIONS(16089), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16091), 1,
      sym_pow_operator,
    ACTIONS(16093), 1,
      sym_mult_operator,
    ACTIONS(16095), 1,
      sym_concat_operator,
    ACTIONS(16097), 1,
      sym_rel_operator,
    ACTIONS(16099), 1,
      sym_and_operator,
    ACTIONS(16101), 1,
      sym_or_operator,
    ACTIONS(16103), 1,
      sym_assign_operator,
    STATE(1852), 1,
      sym_add_operator,
    STATE(12823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10301), 2,
      anon_sym_SEMI,
      anon_sym_do,
    ACTIONS(10275), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [617398] = 14,
    ACTIONS(361), 1,
      anon_sym_LBRACK,
    ACTIONS(371), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(383), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16449), 1,
      sym__lowercase_identifier,
    ACTIONS(16451), 1,
      anon_sym_LPAREN,
    ACTIONS(16453), 1,
      anon_sym_LBRACE,
    ACTIONS(16455), 1,
      sym__uppercase_identifier,
    STATE(2983), 1,
      sym_parenthesized_operator,
    STATE(3095), 1,
      sym__value_name,
    STATE(3133), 1,
      sym__constructor_name,
    STATE(12824), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(3157), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [617446] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14908), 1,
      sym__lowercase_identifier,
    ACTIONS(14910), 1,
      anon_sym_LPAREN,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(14918), 1,
      anon_sym__,
    STATE(11918), 1,
      sym_type_binding,
    STATE(12825), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(14539), 1,
      sym__type_params,
    STATE(16510), 1,
      sym__type_param,
    STATE(16511), 1,
      sym_extended_module_path,
    STATE(20272), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [617497] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8282), 1,
      anon_sym_COLON2,
    STATE(12826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 13,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_of,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_GT,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [617526] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14910), 1,
      anon_sym_LPAREN,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(14918), 1,
      anon_sym__,
    ACTIONS(15003), 1,
      sym__lowercase_identifier,
    STATE(12535), 1,
      sym_type_binding,
    STATE(12827), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(14437), 1,
      sym__type_params,
    STATE(16510), 1,
      sym__type_param,
    STATE(16511), 1,
      sym_extended_module_path,
    STATE(20500), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [617577] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12511), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(16053), 1,
      anon_sym_DASH_GT,
    STATE(12828), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12509), 12,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [617608] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8596), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8598), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(15342), 1,
      anon_sym_LPAREN,
    ACTIONS(16457), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(12829), 1,
      sym_attribute,
    STATE(13213), 1,
      sym__simple_module_expression,
    STATE(14225), 1,
      aux_sym_expression_item_repeat1,
    STATE(15602), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10934), 2,
      anon_sym_and,
      anon_sym_in,
    STATE(13238), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [617651] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(16053), 1,
      anon_sym_DASH_GT,
    ACTIONS(16461), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(12830), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16459), 11,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [617684] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14908), 1,
      sym__lowercase_identifier,
    ACTIONS(14910), 1,
      anon_sym_LPAREN,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(14918), 1,
      anon_sym__,
    STATE(12089), 1,
      sym_type_binding,
    STATE(12831), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(14539), 1,
      sym__type_params,
    STATE(16510), 1,
      sym__type_param,
    STATE(16511), 1,
      sym_extended_module_path,
    STATE(20272), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [617735] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14908), 1,
      sym__lowercase_identifier,
    ACTIONS(14910), 1,
      anon_sym_LPAREN,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(14918), 1,
      anon_sym__,
    STATE(11456), 1,
      sym_type_binding,
    STATE(12832), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(14539), 1,
      sym__type_params,
    STATE(16510), 1,
      sym__type_param,
    STATE(16511), 1,
      sym_extended_module_path,
    STATE(20272), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [617786] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14910), 1,
      anon_sym_LPAREN,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(14918), 1,
      anon_sym__,
    ACTIONS(15137), 1,
      sym__lowercase_identifier,
    STATE(12201), 1,
      sym_type_binding,
    STATE(12833), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(14599), 1,
      sym__type_params,
    STATE(16510), 1,
      sym__type_param,
    STATE(16511), 1,
      sym_extended_module_path,
    STATE(20242), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [617837] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14910), 1,
      anon_sym_LPAREN,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(14918), 1,
      anon_sym__,
    ACTIONS(15071), 1,
      sym__lowercase_identifier,
    STATE(11456), 1,
      sym_type_binding,
    STATE(12834), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(14692), 1,
      sym__type_params,
    STATE(16510), 1,
      sym__type_param,
    STATE(16511), 1,
      sym_extended_module_path,
    STATE(20289), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [617888] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14910), 1,
      anon_sym_LPAREN,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(14918), 1,
      anon_sym__,
    ACTIONS(15071), 1,
      sym__lowercase_identifier,
    STATE(12750), 1,
      sym_type_binding,
    STATE(12835), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(14692), 1,
      sym__type_params,
    STATE(16510), 1,
      sym__type_param,
    STATE(16511), 1,
      sym_extended_module_path,
    STATE(20289), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [617939] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(16463), 1,
      anon_sym_COLON_GT,
    ACTIONS(16465), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12836), 1,
      sym_attribute,
    STATE(13101), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16467), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [617976] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(16053), 1,
      anon_sym_DASH_GT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12837), 1,
      sym_attribute,
    STATE(13133), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16469), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [618013] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14910), 1,
      anon_sym_LPAREN,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(14918), 1,
      anon_sym__,
    ACTIONS(15003), 1,
      sym__lowercase_identifier,
    STATE(11456), 1,
      sym_type_binding,
    STATE(12838), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(14437), 1,
      sym__type_params,
    STATE(16510), 1,
      sym__type_param,
    STATE(16511), 1,
      sym_extended_module_path,
    STATE(20500), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [618064] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11264), 1,
      anon_sym_COLON2,
    STATE(12839), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9158), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(9160), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [618095] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(16471), 1,
      anon_sym_COLON_GT,
    ACTIONS(16473), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12840), 1,
      sym_attribute,
    STATE(12926), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16475), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [618132] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14910), 1,
      anon_sym_LPAREN,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(14918), 1,
      anon_sym__,
    ACTIONS(15003), 1,
      sym__lowercase_identifier,
    STATE(12411), 1,
      sym_type_binding,
    STATE(12841), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(14437), 1,
      sym__type_params,
    STATE(16510), 1,
      sym__type_param,
    STATE(16511), 1,
      sym_extended_module_path,
    STATE(20500), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [618183] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14910), 1,
      anon_sym_LPAREN,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(14918), 1,
      anon_sym__,
    ACTIONS(15137), 1,
      sym__lowercase_identifier,
    STATE(12072), 1,
      sym_type_binding,
    STATE(12842), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(14599), 1,
      sym__type_params,
    STATE(16510), 1,
      sym__type_param,
    STATE(16511), 1,
      sym_extended_module_path,
    STATE(20242), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [618234] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14910), 1,
      anon_sym_LPAREN,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(14918), 1,
      anon_sym__,
    ACTIONS(15137), 1,
      sym__lowercase_identifier,
    STATE(11456), 1,
      sym_type_binding,
    STATE(12843), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(14599), 1,
      sym__type_params,
    STATE(16510), 1,
      sym__type_param,
    STATE(16511), 1,
      sym_extended_module_path,
    STATE(20242), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [618285] = 16,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14910), 1,
      anon_sym_LPAREN,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(14918), 1,
      anon_sym__,
    ACTIONS(15071), 1,
      sym__lowercase_identifier,
    STATE(12819), 1,
      sym_type_binding,
    STATE(12844), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(14692), 1,
      sym__type_params,
    STATE(16510), 1,
      sym__type_param,
    STATE(16511), 1,
      sym_extended_module_path,
    STATE(20289), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [618336] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(16477), 1,
      anon_sym_COLON_GT,
    ACTIONS(16479), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12845), 1,
      sym_attribute,
    STATE(13012), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16481), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [618373] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8596), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8598), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(15342), 1,
      anon_sym_LPAREN,
    ACTIONS(16457), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(12846), 1,
      sym_attribute,
    STATE(13213), 1,
      sym__simple_module_expression,
    STATE(14289), 1,
      aux_sym_expression_item_repeat1,
    STATE(15602), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11030), 2,
      anon_sym_and,
      anon_sym_in,
    STATE(13238), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [618416] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8596), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8598), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(15342), 1,
      anon_sym_LPAREN,
    ACTIONS(16457), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(12847), 1,
      sym_attribute,
    STATE(13213), 1,
      sym__simple_module_expression,
    STATE(14221), 1,
      aux_sym_expression_item_repeat1,
    STATE(15602), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11026), 2,
      anon_sym_and,
      anon_sym_in,
    STATE(13238), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [618459] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12848), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8350), 4,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8352), 9,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [618487] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12396), 1,
      sym__lowercase_identifier,
    ACTIONS(14910), 1,
      anon_sym_LPAREN,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(14918), 1,
      anon_sym__,
    STATE(12849), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(14548), 1,
      sym__type_params,
    STATE(16239), 1,
      sym_type_constructor_path,
    STATE(16510), 1,
      sym__type_param,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [618535] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12850), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11534), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11536), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [618563] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7589), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12851), 1,
      sym_attribute,
    STATE(12991), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7611), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [618597] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(16483), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12852), 1,
      sym_attribute,
    STATE(12998), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16485), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [618631] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11638), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11640), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [618659] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12854), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11414), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11416), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [618687] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12855), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11704), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11706), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [618715] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12856), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11600), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11602), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [618743] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11474), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11476), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [618771] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11550), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11552), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [618799] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12859), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11426), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11428), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [618827] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12860), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11795), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11797), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [618855] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12861), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11470), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11472), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [618883] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12862), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11508), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11510), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [618911] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(16489), 1,
      anon_sym_as,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12863), 1,
      sym_attribute,
    STATE(13089), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16487), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [618945] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9384), 1,
      anon_sym_PIPE,
    ACTIONS(9542), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12077), 1,
      anon_sym_LPAREN,
    ACTIONS(12079), 1,
      anon_sym_LBRACK,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(16491), 1,
      anon_sym_private,
    ACTIONS(16493), 1,
      anon_sym_LBRACE,
    STATE(10650), 1,
      sym__constructor_name,
    STATE(11177), 1,
      sym_constructor_declaration,
    STATE(12864), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12081), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10539), 2,
      sym_variant_declaration,
      sym_record_declaration,
  [618991] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12865), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11692), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11694), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [619019] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(16495), 1,
      sym__lowercase_identifier,
    ACTIONS(16497), 1,
      anon_sym_POUND,
    STATE(12866), 1,
      sym_attribute,
    STATE(13169), 1,
      sym_type_constructor_path,
    STATE(17311), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11128), 4,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
    ACTIONS(11130), 4,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
  [619057] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12867), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11438), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11440), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [619085] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(15120), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(16053), 1,
      anon_sym_DASH_GT,
    STATE(12868), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15118), 10,
      anon_sym_EQ,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [619117] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7693), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12869), 1,
      sym_attribute,
    STATE(13000), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7697), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [619151] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9256), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(9258), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [619179] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12871), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11442), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11444), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [619207] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8596), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8598), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11116), 1,
      anon_sym_in,
    ACTIONS(15342), 1,
      anon_sym_LPAREN,
    ACTIONS(16457), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(12872), 1,
      sym_attribute,
    STATE(13213), 1,
      sym__simple_module_expression,
    STATE(14411), 1,
      aux_sym_expression_item_repeat1,
    STATE(15602), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13238), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [619249] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12396), 1,
      sym__lowercase_identifier,
    ACTIONS(14910), 1,
      anon_sym_LPAREN,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(14918), 1,
      anon_sym__,
    STATE(12873), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(14801), 1,
      sym__type_params,
    STATE(15651), 1,
      sym_type_constructor_path,
    STATE(16510), 1,
      sym__type_param,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [619297] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9158), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(9160), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [619325] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12875), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 4,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8356), 9,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [619353] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12876), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11632), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11634), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [619381] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(16501), 1,
      anon_sym_as,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12877), 1,
      sym_attribute,
    STATE(13050), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16499), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [619415] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12878), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 4,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8360), 9,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [619443] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(15124), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(16053), 1,
      anon_sym_DASH_GT,
    STATE(12879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15122), 10,
      anon_sym_EQ,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [619475] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12880), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 4,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8364), 9,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [619503] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8596), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8598), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11100), 1,
      anon_sym_in,
    ACTIONS(15342), 1,
      anon_sym_LPAREN,
    ACTIONS(16457), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(12881), 1,
      sym_attribute,
    STATE(13213), 1,
      sym__simple_module_expression,
    STATE(14899), 1,
      aux_sym_expression_item_repeat1,
    STATE(15602), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13238), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [619545] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7153), 1,
      anon_sym_COLON2,
    ACTIONS(16503), 1,
      anon_sym_DOT_DOT,
    STATE(12882), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7149), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [619575] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9102), 1,
      anon_sym_COLON2,
    STATE(12883), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9104), 12,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [619603] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(16505), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12884), 1,
      sym_attribute,
    STATE(13071), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16507), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [619637] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12396), 1,
      sym__lowercase_identifier,
    ACTIONS(14910), 1,
      anon_sym_LPAREN,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(14918), 1,
      anon_sym__,
    STATE(12885), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(14547), 1,
      sym__type_params,
    STATE(15241), 1,
      sym_type_constructor_path,
    STATE(16510), 1,
      sym__type_param,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [619685] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12396), 1,
      sym__lowercase_identifier,
    ACTIONS(14910), 1,
      anon_sym_LPAREN,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(14918), 1,
      anon_sym__,
    STATE(12886), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(14513), 1,
      sym__type_params,
    STATE(16077), 1,
      sym_type_constructor_path,
    STATE(16510), 1,
      sym__type_param,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [619733] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11538), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11540), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [619761] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12888), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11642), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11644), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [619789] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12889), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11446), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11448), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [619817] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12396), 1,
      sym__lowercase_identifier,
    ACTIONS(14910), 1,
      anon_sym_LPAREN,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(14918), 1,
      anon_sym__,
    STATE(12890), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(14805), 1,
      sym__type_params,
    STATE(15895), 1,
      sym_type_constructor_path,
    STATE(16510), 1,
      sym__type_param,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [619865] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12891), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11576), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11578), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [619893] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12892), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9158), 4,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(9160), 9,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [619921] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9416), 1,
      anon_sym_PIPE,
    ACTIONS(9562), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12357), 1,
      anon_sym_LPAREN,
    ACTIONS(12359), 1,
      anon_sym_LBRACK,
    ACTIONS(16493), 1,
      anon_sym_LBRACE,
    ACTIONS(16509), 1,
      anon_sym_private,
    STATE(10928), 1,
      sym__constructor_name,
    STATE(11569), 1,
      sym_constructor_declaration,
    STATE(12893), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12361), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10742), 2,
      sym_variant_declaration,
      sym_record_declaration,
  [619967] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9462), 1,
      anon_sym_PIPE,
    ACTIONS(9572), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12208), 1,
      anon_sym_LPAREN,
    ACTIONS(12210), 1,
      anon_sym_LBRACK,
    ACTIONS(16493), 1,
      anon_sym_LBRACE,
    ACTIONS(16511), 1,
      anon_sym_private,
    STATE(10408), 1,
      sym__constructor_name,
    STATE(11053), 1,
      sym_constructor_declaration,
    STATE(12894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12212), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10559), 2,
      sym_variant_declaration,
      sym_record_declaration,
  [620013] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11676), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11678), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [620041] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(13279), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(16053), 1,
      anon_sym_DASH_GT,
    STATE(12896), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13277), 10,
      anon_sym_EQ,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [620073] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9494), 1,
      anon_sym_PIPE,
    ACTIONS(9558), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12513), 1,
      anon_sym_LPAREN,
    ACTIONS(12515), 1,
      anon_sym_LBRACK,
    ACTIONS(16493), 1,
      anon_sym_LBRACE,
    ACTIONS(16513), 1,
      anon_sym_private,
    STATE(11003), 1,
      sym__constructor_name,
    STATE(11787), 1,
      sym_constructor_declaration,
    STATE(12897), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12517), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(11104), 2,
      sym_variant_declaration,
      sym_record_declaration,
  [620119] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(16495), 1,
      sym__lowercase_identifier,
    ACTIONS(16515), 1,
      anon_sym_POUND,
    STATE(12898), 1,
      sym_attribute,
    STATE(13142), 1,
      sym_type_constructor_path,
    STATE(17311), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10261), 4,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
    ACTIONS(10263), 4,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
  [620157] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9384), 1,
      anon_sym_PIPE,
    ACTIONS(9540), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12077), 1,
      anon_sym_LPAREN,
    ACTIONS(12079), 1,
      anon_sym_LBRACK,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(16493), 1,
      anon_sym_LBRACE,
    ACTIONS(16517), 1,
      anon_sym_private,
    STATE(10650), 1,
      sym__constructor_name,
    STATE(11177), 1,
      sym_constructor_declaration,
    STATE(12899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12081), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10516), 2,
      sym_variant_declaration,
      sym_record_declaration,
  [620203] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12900), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11478), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11480), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [620231] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7683), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12901), 1,
      sym_attribute,
    STATE(13044), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7687), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [620265] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12902), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11494), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11496), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [620293] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11009), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11007), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [620321] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12904), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11434), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11436), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [620349] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11763), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11765), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [620377] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12906), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10261), 13,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      anon_sym_GT,
      anon_sym_LBRACK_AT_AT,
  [620403] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(16519), 1,
      anon_sym_EQ,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12907), 1,
      sym_attribute,
    STATE(12967), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16521), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [620437] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9416), 1,
      anon_sym_PIPE,
    ACTIONS(9526), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12357), 1,
      anon_sym_LPAREN,
    ACTIONS(12359), 1,
      anon_sym_LBRACK,
    ACTIONS(16493), 1,
      anon_sym_LBRACE,
    ACTIONS(16523), 1,
      anon_sym_private,
    STATE(10928), 1,
      sym__constructor_name,
    STATE(11569), 1,
      sym_constructor_declaration,
    STATE(12908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12361), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10863), 2,
      sym_variant_declaration,
      sym_record_declaration,
  [620483] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16527), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(16525), 11,
      anon_sym_DQUOTE,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [620511] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9462), 1,
      anon_sym_PIPE,
    ACTIONS(9568), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12208), 1,
      anon_sym_LPAREN,
    ACTIONS(12210), 1,
      anon_sym_LBRACK,
    ACTIONS(16493), 1,
      anon_sym_LBRACE,
    ACTIONS(16529), 1,
      anon_sym_private,
    STATE(10408), 1,
      sym__constructor_name,
    STATE(11053), 1,
      sym_constructor_declaration,
    STATE(12910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12212), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10612), 2,
      sym_variant_declaration,
      sym_record_declaration,
  [620557] = 14,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9494), 1,
      anon_sym_PIPE,
    ACTIONS(9550), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12513), 1,
      anon_sym_LPAREN,
    ACTIONS(12515), 1,
      anon_sym_LBRACK,
    ACTIONS(16493), 1,
      anon_sym_LBRACE,
    ACTIONS(16531), 1,
      anon_sym_private,
    STATE(11003), 1,
      sym__constructor_name,
    STATE(11787), 1,
      sym_constructor_declaration,
    STATE(12911), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12517), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(11060), 2,
      sym_variant_declaration,
      sym_record_declaration,
  [620603] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8364), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [620631] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12913), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8360), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [620659] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12914), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8356), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [620687] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8596), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8598), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11074), 1,
      anon_sym_in,
    ACTIONS(15342), 1,
      anon_sym_LPAREN,
    ACTIONS(16457), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(12915), 1,
      sym_attribute,
    STATE(13213), 1,
      sym__simple_module_expression,
    STATE(14735), 1,
      aux_sym_expression_item_repeat1,
    STATE(15602), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13238), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [620729] = 15,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12396), 1,
      sym__lowercase_identifier,
    ACTIONS(14910), 1,
      anon_sym_LPAREN,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(14918), 1,
      anon_sym__,
    STATE(12916), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(14587), 1,
      sym__type_params,
    STATE(16232), 1,
      sym_type_constructor_path,
    STATE(16510), 1,
      sym__type_param,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [620777] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12917), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8350), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8352), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [620805] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(16495), 1,
      sym__lowercase_identifier,
    ACTIONS(16515), 1,
      anon_sym_POUND,
    STATE(12918), 1,
      sym_attribute,
    STATE(13142), 1,
      sym_type_constructor_path,
    STATE(17311), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11124), 4,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
    ACTIONS(11126), 4,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
  [620843] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(16533), 1,
      anon_sym_DASH_GT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12919), 1,
      sym_attribute,
    STATE(13133), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16469), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [620879] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9108), 1,
      anon_sym_COLON2,
    STATE(12920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9110), 12,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [620907] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11560), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11845), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11562), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [620937] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12922), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9256), 4,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(9258), 9,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [620965] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16537), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(16535), 11,
      anon_sym_DQUOTE,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [620993] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12924), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11560), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11562), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [621021] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16539), 1,
      anon_sym_RPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12925), 1,
      sym_attribute,
    STATE(18240), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [621060] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16055), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [621091] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12927), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16205), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [621122] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9672), 1,
      anon_sym_COLON2,
    STATE(12928), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9674), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [621149] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7153), 1,
      anon_sym_COLON2,
    STATE(12929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7149), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [621176] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16543), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12930), 1,
      sym_attribute,
    STATE(19177), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [621215] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16545), 1,
      aux_sym_attribute_id_token1,
    STATE(12931), 1,
      sym_attribute,
    STATE(12954), 1,
      aux_sym_attribute_id_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9052), 10,
      anon_sym_LPAREN,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [621244] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16547), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12932), 1,
      sym_attribute,
    STATE(17738), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [621283] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8312), 1,
      anon_sym_COLON2,
    STATE(12933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 11,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_of,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
  [621310] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12934), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16549), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [621341] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9680), 1,
      anon_sym_COLON2,
    STATE(12935), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9682), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [621368] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16551), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12936), 1,
      sym_attribute,
    STATE(19192), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [621407] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9384), 1,
      anon_sym_PIPE,
    ACTIONS(12077), 1,
      anon_sym_LPAREN,
    ACTIONS(12079), 1,
      anon_sym_LBRACK,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(16493), 1,
      anon_sym_LBRACE,
    ACTIONS(16553), 1,
      anon_sym_DOT_DOT,
    STATE(10650), 1,
      sym__constructor_name,
    STATE(11177), 1,
      sym_constructor_declaration,
    STATE(12937), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12081), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10577), 2,
      sym_variant_declaration,
      sym_record_declaration,
  [621450] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16555), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [621481] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12939), 1,
      sym_attribute,
    STATE(13111), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16557), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [621512] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16559), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12940), 1,
      sym_attribute,
    STATE(17824), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [621551] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16561), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12941), 1,
      sym_attribute,
    STATE(17750), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [621590] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16563), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12942), 1,
      sym_attribute,
    STATE(18083), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [621629] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16565), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [621660] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10393), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(16567), 1,
      anon_sym_STAR,
    STATE(12944), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10391), 10,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [621689] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16569), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12945), 1,
      sym_attribute,
    STATE(18107), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [621728] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16571), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12946), 1,
      sym_attribute,
    STATE(19443), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [621767] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9684), 1,
      anon_sym_COLON2,
    STATE(12947), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9686), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [621794] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16573), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12948), 1,
      sym_attribute,
    STATE(18942), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [621833] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12949), 1,
      sym_attribute,
    STATE(12970), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16575), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [621864] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12950), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16577), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [621895] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16579), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12951), 1,
      sym_attribute,
    STATE(19275), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [621934] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16581), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12952), 1,
      sym_attribute,
    STATE(19925), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [621973] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12953), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16583), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [622004] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16545), 1,
      aux_sym_attribute_id_token1,
    STATE(12954), 1,
      sym_attribute,
    STATE(13039), 1,
      aux_sym_attribute_id_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8921), 10,
      anon_sym_LPAREN,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [622033] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9494), 1,
      anon_sym_PIPE,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12513), 1,
      anon_sym_LPAREN,
    ACTIONS(12515), 1,
      anon_sym_LBRACK,
    ACTIONS(16493), 1,
      anon_sym_LBRACE,
    ACTIONS(16585), 1,
      anon_sym_DOT_DOT,
    STATE(11003), 1,
      sym__constructor_name,
    STATE(11787), 1,
      sym_constructor_declaration,
    STATE(12955), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12517), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(11135), 2,
      sym_variant_declaration,
      sym_record_declaration,
  [622076] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12956), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10391), 12,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      anon_sym_GT,
      anon_sym_LBRACK_AT_AT,
  [622101] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16587), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12957), 1,
      sym_attribute,
    STATE(19120), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [622140] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16589), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [622171] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16591), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12959), 1,
      sym_attribute,
    STATE(17677), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [622210] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9754), 1,
      anon_sym_COLON2,
    STATE(12960), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9756), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [622237] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16593), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12961), 1,
      sym_attribute,
    STATE(19109), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [622276] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16595), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12962), 1,
      sym_attribute,
    STATE(18140), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [622315] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16597), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12963), 1,
      sym_attribute,
    STATE(18858), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [622354] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16599), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12964), 1,
      sym_attribute,
    STATE(18075), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [622393] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16601), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12965), 1,
      sym_attribute,
    STATE(18840), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [622432] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16603), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12966), 1,
      sym_attribute,
    STATE(18657), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [622471] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12967), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16605), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [622502] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16457), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(16609), 1,
      anon_sym_LPAREN,
    ACTIONS(16611), 1,
      anon_sym_COLON2,
    STATE(12968), 1,
      sym_attribute,
    STATE(13329), 1,
      aux_sym_module_binding_repeat1,
    STATE(13549), 1,
      sym_module_parameter,
    STATE(13798), 1,
      sym__module_typed,
    STATE(14372), 1,
      aux_sym_expression_item_repeat1,
    STATE(15602), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11861), 2,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(16607), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [622545] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9144), 1,
      anon_sym_COLON2,
    STATE(12969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9146), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [622572] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12970), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16613), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [622603] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16615), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12971), 1,
      sym_attribute,
    STATE(19317), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [622642] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16617), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12972), 1,
      sym_attribute,
    STATE(18746), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [622681] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16619), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12973), 1,
      sym_attribute,
    STATE(19137), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [622720] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16621), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12974), 1,
      sym_attribute,
    STATE(17688), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [622759] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16623), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12975), 1,
      sym_attribute,
    STATE(18469), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [622798] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16625), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12976), 1,
      sym_attribute,
    STATE(17594), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [622837] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9140), 1,
      anon_sym_COLON2,
    STATE(12977), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9142), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [622864] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16629), 1,
      anon_sym_COLON2,
    STATE(12978), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16627), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [622891] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9714), 1,
      anon_sym_COLON2,
    STATE(12979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9716), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [622918] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16631), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12980), 1,
      sym_attribute,
    STATE(18062), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [622957] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12981), 1,
      sym_attribute,
    STATE(13073), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16633), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [622988] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16635), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12982), 1,
      sym_attribute,
    STATE(18413), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [623027] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9174), 1,
      anon_sym_COLON2,
    STATE(12983), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9176), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [623054] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12984), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16637), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [623085] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12943), 1,
      aux_sym_expression_item_repeat1,
    STATE(12985), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16639), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [623116] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16641), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12986), 1,
      sym_attribute,
    STATE(18150), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [623155] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16643), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12987), 1,
      sym_attribute,
    STATE(17628), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [623194] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16645), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [623225] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12989), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16647), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [623256] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16649), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12990), 1,
      sym_attribute,
    STATE(20287), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [623295] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12991), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16507), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [623326] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16651), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12992), 1,
      sym_attribute,
    STATE(19768), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [623365] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16655), 1,
      anon_sym_COLON2,
    STATE(12993), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16653), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [623392] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16657), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12994), 1,
      sym_attribute,
    STATE(19337), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [623431] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16659), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12995), 1,
      sym_attribute,
    STATE(18963), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [623470] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16661), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(12996), 1,
      sym_attribute,
    STATE(17679), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [623509] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12997), 1,
      sym_attribute,
    STATE(13062), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16663), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [623540] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12998), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16665), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [623571] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12999), 1,
      sym_attribute,
    STATE(13054), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16667), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [623602] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13000), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16521), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [623633] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13001), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16669), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [623664] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13002), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16671), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [623695] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13003), 1,
      sym_attribute,
    STATE(13015), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16673), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [623726] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13004), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16675), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [623757] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13005), 1,
      sym_attribute,
    STATE(13026), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16677), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [623788] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13006), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16679), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [623819] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16681), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13007), 1,
      sym_attribute,
    STATE(18212), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [623858] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9462), 1,
      anon_sym_PIPE,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12208), 1,
      anon_sym_LPAREN,
    ACTIONS(12210), 1,
      anon_sym_LBRACK,
    ACTIONS(16493), 1,
      anon_sym_LBRACE,
    ACTIONS(16683), 1,
      anon_sym_DOT_DOT,
    STATE(10408), 1,
      sym__constructor_name,
    STATE(11053), 1,
      sym_constructor_declaration,
    STATE(13008), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12212), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10561), 2,
      sym_variant_declaration,
      sym_record_declaration,
  [623901] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13009), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16685), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [623932] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13010), 1,
      sym_attribute,
    STATE(13014), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16687), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [623963] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12984), 1,
      aux_sym_expression_item_repeat1,
    STATE(13011), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16689), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [623994] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13012), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16283), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [624025] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16691), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13013), 1,
      sym_attribute,
    STATE(18400), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [624064] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13014), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16693), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [624095] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16695), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [624126] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9706), 1,
      anon_sym_COLON2,
    STATE(13016), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9708), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [624153] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7687), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [624184] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16697), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13018), 1,
      sym_attribute,
    STATE(19638), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [624223] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16699), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [624254] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9642), 1,
      anon_sym_COLON2,
    STATE(13020), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9644), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [624281] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13021), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7697), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [624312] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16701), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13022), 1,
      sym_attribute,
    STATE(20092), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [624351] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13006), 1,
      aux_sym_expression_item_repeat1,
    STATE(13023), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16703), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [624382] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16705), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [624413] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13025), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7611), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [624444] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13026), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16707), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [624475] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13027), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16709), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [624506] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9634), 1,
      anon_sym_COLON2,
    STATE(13028), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9636), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [624533] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12934), 1,
      aux_sym_expression_item_repeat1,
    STATE(13029), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16711), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [624564] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13024), 1,
      aux_sym_expression_item_repeat1,
    STATE(13030), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16713), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [624595] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16715), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13031), 1,
      sym_attribute,
    STATE(19900), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [624634] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16717), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13032), 1,
      sym_attribute,
    STATE(17878), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [624673] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16721), 1,
      anon_sym_COLON2,
    STATE(13033), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16719), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [624700] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16723), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13034), 1,
      sym_attribute,
    STATE(19056), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [624739] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16725), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13035), 1,
      sym_attribute,
    STATE(19524), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [624778] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13036), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16287), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [624809] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9462), 1,
      anon_sym_PIPE,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12208), 1,
      anon_sym_LPAREN,
    ACTIONS(12210), 1,
      anon_sym_LBRACK,
    ACTIONS(16493), 1,
      anon_sym_LBRACE,
    ACTIONS(16727), 1,
      anon_sym_DOT_DOT,
    STATE(10408), 1,
      sym__constructor_name,
    STATE(11053), 1,
      sym_constructor_declaration,
    STATE(13037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12212), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10528), 2,
      sym_variant_declaration,
      sym_record_declaration,
  [624852] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13038), 1,
      sym_attribute,
    STATE(13047), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16729), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [624883] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16731), 1,
      aux_sym_attribute_id_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13039), 2,
      sym_attribute,
      aux_sym_attribute_id_repeat1,
    ACTIONS(8961), 10,
      anon_sym_LPAREN,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [624910] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16734), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13040), 1,
      sym_attribute,
    STATE(18485), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [624949] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16736), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13041), 1,
      sym_attribute,
    STATE(19041), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [624988] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16738), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13042), 1,
      sym_attribute,
    STATE(18311), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [625027] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11264), 1,
      anon_sym_COLON2,
    STATE(13043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9158), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(9160), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [625056] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16485), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [625087] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13019), 1,
      aux_sym_expression_item_repeat1,
    STATE(13045), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16740), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [625118] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13001), 1,
      aux_sym_expression_item_repeat1,
    STATE(13046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16742), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [625149] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13047), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16744), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [625180] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9216), 1,
      anon_sym_COLON2,
    STATE(13048), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9218), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [625207] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16746), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13049), 1,
      sym_attribute,
    STATE(17802), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [625246] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13050), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16729), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [625277] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16748), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13051), 1,
      sym_attribute,
    STATE(18243), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [625316] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9676), 1,
      anon_sym_COLON2,
    STATE(13052), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9678), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [625343] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16750), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13053), 1,
      sym_attribute,
    STATE(20416), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [625382] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13054), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16752), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [625413] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8596), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8598), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(15342), 1,
      anon_sym_LPAREN,
    STATE(13055), 1,
      sym_attribute,
    STATE(13213), 1,
      sym__simple_module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10239), 3,
      anon_sym_and,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    STATE(13238), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [625448] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13002), 1,
      aux_sym_expression_item_repeat1,
    STATE(13056), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16744), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [625479] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9384), 1,
      anon_sym_PIPE,
    ACTIONS(12077), 1,
      anon_sym_LPAREN,
    ACTIONS(12079), 1,
      anon_sym_LBRACK,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(16493), 1,
      anon_sym_LBRACE,
    ACTIONS(16754), 1,
      anon_sym_DOT_DOT,
    STATE(10650), 1,
      sym__constructor_name,
    STATE(11177), 1,
      sym_constructor_declaration,
    STATE(13057), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12081), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10527), 2,
      sym_variant_declaration,
      sym_record_declaration,
  [625522] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16756), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13058), 1,
      sym_attribute,
    STATE(17797), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [625561] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16758), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13059), 1,
      sym_attribute,
    STATE(18505), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [625600] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12989), 1,
      aux_sym_expression_item_repeat1,
    STATE(13060), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16760), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [625631] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13004), 1,
      aux_sym_expression_item_repeat1,
    STATE(13061), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16762), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [625662] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13062), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16764), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [625693] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16766), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13063), 1,
      sym_attribute,
    STATE(18675), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [625732] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12988), 1,
      aux_sym_expression_item_repeat1,
    STATE(13064), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16768), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [625763] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16770), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13065), 1,
      sym_attribute,
    STATE(17816), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [625802] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9668), 1,
      anon_sym_COLON2,
    STATE(13066), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9670), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [625829] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16772), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13067), 1,
      sym_attribute,
    STATE(19663), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [625868] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16774), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13068), 1,
      sym_attribute,
    STATE(19057), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [625907] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16776), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13069), 1,
      sym_attribute,
    STATE(18588), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [625946] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13070), 1,
      sym_attribute,
    STATE(13078), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16778), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [625977] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13071), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16780), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [626008] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16467), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [626039] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13073), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16782), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [626070] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10387), 12,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      anon_sym_GT,
      anon_sym_LBRACK_AT_AT,
  [626095] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16784), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13075), 1,
      sym_attribute,
    STATE(17635), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [626134] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9416), 1,
      anon_sym_PIPE,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12357), 1,
      anon_sym_LPAREN,
    ACTIONS(12359), 1,
      anon_sym_LBRACK,
    ACTIONS(16493), 1,
      anon_sym_LBRACE,
    ACTIONS(16786), 1,
      anon_sym_DOT_DOT,
    STATE(10928), 1,
      sym__constructor_name,
    STATE(11569), 1,
      sym_constructor_declaration,
    STATE(13076), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12361), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10849), 2,
      sym_variant_declaration,
      sym_record_declaration,
  [626177] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9710), 1,
      anon_sym_COLON2,
    STATE(13077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9712), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [626204] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13078), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16788), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [626235] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9664), 1,
      anon_sym_COLON2,
    STATE(13079), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9666), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [626262] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9688), 1,
      anon_sym_COLON2,
    STATE(13080), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9690), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [626289] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16790), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13081), 1,
      sym_attribute,
    STATE(18925), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [626328] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13082), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16325), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [626359] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9692), 1,
      anon_sym_COLON2,
    STATE(13083), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9694), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [626386] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16481), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [626417] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16792), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13085), 1,
      sym_attribute,
    STATE(19428), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [626456] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9696), 1,
      anon_sym_COLON2,
    STATE(13086), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9698), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [626483] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12953), 1,
      aux_sym_expression_item_repeat1,
    STATE(13087), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16794), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [626514] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16796), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13088), 1,
      sym_attribute,
    STATE(18913), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [626553] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13089), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16499), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [626584] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16798), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13090), 1,
      sym_attribute,
    STATE(17980), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [626623] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16800), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13091), 1,
      sym_attribute,
    STATE(20240), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [626662] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12958), 1,
      aux_sym_expression_item_repeat1,
    STATE(13092), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16802), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [626693] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9416), 1,
      anon_sym_PIPE,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12357), 1,
      anon_sym_LPAREN,
    ACTIONS(12359), 1,
      anon_sym_LBRACK,
    ACTIONS(16493), 1,
      anon_sym_LBRACE,
    ACTIONS(16804), 1,
      anon_sym_DOT_DOT,
    STATE(10928), 1,
      sym__constructor_name,
    STATE(11569), 1,
      sym_constructor_declaration,
    STATE(13093), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12361), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10716), 2,
      sym_variant_declaration,
      sym_record_declaration,
  [626736] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16806), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13094), 1,
      sym_attribute,
    STATE(18006), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [626775] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16808), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13095), 1,
      sym_attribute,
    STATE(20057), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [626814] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9206), 1,
      anon_sym_COLON2,
    STATE(13096), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9208), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [626841] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16810), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13097), 1,
      sym_attribute,
    STATE(18776), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [626880] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16812), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13098), 1,
      sym_attribute,
    STATE(19363), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [626919] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16814), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13099), 1,
      sym_attribute,
    STATE(17997), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [626958] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13100), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16475), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [626989] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13101), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16293), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [627020] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(12950), 1,
      aux_sym_expression_item_repeat1,
    STATE(13102), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16816), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [627051] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16818), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13103), 1,
      sym_attribute,
    STATE(18758), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [627090] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16820), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13104), 1,
      sym_attribute,
    STATE(19209), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [627129] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16824), 1,
      anon_sym_COLON2,
    STATE(13105), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16822), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [627156] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16826), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13106), 1,
      sym_attribute,
    STATE(18759), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [627195] = 13,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9494), 1,
      anon_sym_PIPE,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12513), 1,
      anon_sym_LPAREN,
    ACTIONS(12515), 1,
      anon_sym_LBRACK,
    ACTIONS(16493), 1,
      anon_sym_LBRACE,
    ACTIONS(16828), 1,
      anon_sym_DOT_DOT,
    STATE(11003), 1,
      sym__constructor_name,
    STATE(11787), 1,
      sym_constructor_declaration,
    STATE(13107), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12517), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(11102), 2,
      sym_variant_declaration,
      sym_record_declaration,
  [627238] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9228), 1,
      anon_sym_COLON2,
    STATE(13108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9230), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [627265] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16830), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13109), 1,
      sym_attribute,
    STATE(18221), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [627304] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16834), 1,
      anon_sym_COLON2,
    STATE(13110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16832), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [627331] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13111), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16836), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [627362] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9736), 1,
      anon_sym_COLON2,
    STATE(13112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9738), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [627389] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16840), 1,
      anon_sym_COLON2,
    STATE(13113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16838), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [627416] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16842), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13114), 1,
      sym_attribute,
    STATE(17869), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [627455] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16844), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13115), 1,
      sym_attribute,
    STATE(20030), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [627494] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16846), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13116), 1,
      sym_attribute,
    STATE(18639), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [627533] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16848), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13117), 1,
      sym_attribute,
    STATE(18573), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [627572] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16850), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13118), 1,
      sym_attribute,
    STATE(18499), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [627611] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16852), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13119), 1,
      sym_attribute,
    STATE(19545), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [627650] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16854), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13120), 1,
      sym_attribute,
    STATE(18606), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [627689] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16856), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13121), 1,
      sym_attribute,
    STATE(19793), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [627728] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16858), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13122), 1,
      sym_attribute,
    STATE(17942), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [627767] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16860), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13123), 1,
      sym_attribute,
    STATE(17943), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [627806] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16864), 1,
      anon_sym_COLON2,
    STATE(13124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16862), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [627833] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16868), 1,
      anon_sym_COLON2,
    STATE(13125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16866), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [627860] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9626), 1,
      anon_sym_COLON2,
    STATE(13126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9628), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [627887] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16870), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13127), 1,
      sym_attribute,
    STATE(19349), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [627926] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16872), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13128), 1,
      sym_attribute,
    STATE(19292), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [627965] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16874), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13129), 1,
      sym_attribute,
    STATE(18325), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [628004] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16876), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13130), 1,
      sym_attribute,
    STATE(18343), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [628043] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16457), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(16609), 1,
      anon_sym_LPAREN,
    ACTIONS(16611), 1,
      anon_sym_COLON2,
    STATE(12968), 1,
      aux_sym_module_binding_repeat1,
    STATE(13131), 1,
      sym_attribute,
    STATE(13516), 1,
      sym__module_typed,
    STATE(13549), 1,
      sym_module_parameter,
    STATE(14378), 1,
      aux_sym_expression_item_repeat1,
    STATE(15602), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11851), 2,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(16878), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [628086] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16880), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13132), 1,
      sym_attribute,
    STATE(17930), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [628125] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13133), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16882), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [628156] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16884), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13134), 1,
      sym_attribute,
    STATE(18375), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [628195] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16888), 1,
      anon_sym_COLON2,
    STATE(13135), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16886), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [628222] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9622), 1,
      anon_sym_COLON2,
    STATE(13136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9624), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [628249] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4979), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10243), 1,
      anon_sym_LPAREN,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(16890), 1,
      anon_sym_RPAREN,
    STATE(8886), 1,
      sym__simple_module_expression,
    STATE(13137), 1,
      sym_attribute,
    STATE(19222), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8909), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [628288] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 11,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [628312] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13139), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 11,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [628336] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16892), 1,
      anon_sym_DOT,
    STATE(13140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10983), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [628362] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16894), 1,
      aux_sym_attribute_id_token1,
    STATE(13141), 1,
      sym_attribute,
    STATE(13158), 1,
      aux_sym_attribute_id_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8919), 4,
      anon_sym_module,
      anon_sym_sig,
      anon_sym_functor,
      sym__lowercase_identifier,
    ACTIONS(8921), 5,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__uppercase_identifier,
  [628392] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11638), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11640), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [628418] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13143), 1,
      sym_attribute,
    STATE(13153), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16896), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [628448] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(13279), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(16533), 1,
      anon_sym_DASH_GT,
    STATE(13144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13277), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [628478] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(16461), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(16533), 1,
      anon_sym_DASH_GT,
    STATE(13145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16459), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [628508] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12511), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(16533), 1,
      anon_sym_DASH_GT,
    STATE(13146), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12509), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [628536] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16898), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [628566] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13148), 1,
      sym_attribute,
    STATE(13189), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16898), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [628596] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13149), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16900), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [628626] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13150), 1,
      sym_attribute,
    STATE(13178), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16902), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [628656] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16894), 1,
      aux_sym_attribute_id_token1,
    STATE(13141), 1,
      aux_sym_attribute_id_repeat1,
    STATE(13151), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9050), 4,
      anon_sym_module,
      anon_sym_sig,
      anon_sym_functor,
      sym__lowercase_identifier,
    ACTIONS(9052), 5,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__uppercase_identifier,
  [628686] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13149), 1,
      aux_sym_expression_item_repeat1,
    STATE(13152), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16904), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [628716] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13153), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16906), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [628746] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13147), 1,
      aux_sym_expression_item_repeat1,
    STATE(13154), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16908), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [628776] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16910), 1,
      anon_sym_STAR,
    STATE(13155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10391), 10,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_as,
      anon_sym_GT,
      anon_sym_AMP,
  [628802] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13156), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11560), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11562), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [628828] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13157), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11576), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11578), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [628854] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16912), 1,
      aux_sym_attribute_id_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13158), 2,
      sym_attribute,
      aux_sym_attribute_id_repeat1,
    ACTIONS(8959), 4,
      anon_sym_module,
      anon_sym_sig,
      anon_sym_functor,
      sym__lowercase_identifier,
    ACTIONS(8961), 5,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__uppercase_identifier,
  [628882] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11538), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11540), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [628908] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11534), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11536), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [628934] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(15120), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(16533), 1,
      anon_sym_DASH_GT,
    STATE(13161), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15118), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [628964] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11414), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11416), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [628990] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11704), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11706), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629016] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11600), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11602), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629042] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(15124), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(16533), 1,
      anon_sym_DASH_GT,
    STATE(13165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15122), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [629072] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13166), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8961), 11,
      anon_sym_LPAREN,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_attribute_id_token1,
  [629096] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13167), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11474), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11476), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629122] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11642), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11644), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629148] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13169), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11632), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11634), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629174] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11550), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11552), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629200] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11426), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11428), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629226] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11795), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11797), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629252] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11470), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11472), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629278] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11508), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11510), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629304] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13175), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11692), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11694), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629330] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11438), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11440), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629356] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13177), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11442), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11444), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629382] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16915), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [629412] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11446), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11448), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629438] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11676), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11678), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629464] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13181), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11478), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11480), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629490] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11494), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11496), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629516] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13183), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11009), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11007), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629542] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13184), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11434), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11436), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629568] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9256), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(9258), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629594] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11763), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11765), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629620] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13187), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9158), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(9160), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629646] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8364), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629672] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6921), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9479), 1,
      aux_sym_expression_item_repeat1,
    STATE(9924), 1,
      sym_item_attribute,
    STATE(13189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16917), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [629702] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8360), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629728] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13191), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8356), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629754] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13192), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8350), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8352), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629780] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16925), 1,
      anon_sym_COLON2,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    STATE(13193), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16919), 5,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_when,
  [629813] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11596), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11598), 1,
      anon_sym_in,
    ACTIONS(16931), 1,
      sym__lowercase_identifier,
    ACTIONS(16933), 1,
      anon_sym_POUND,
    STATE(13194), 1,
      sym_attribute,
    STATE(13620), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17229), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [629854] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12811), 1,
      anon_sym_LPAREN,
    ACTIONS(12813), 1,
      anon_sym_LBRACK,
    ACTIONS(16935), 1,
      anon_sym_private,
    ACTIONS(16937), 1,
      anon_sym_PIPE,
    STATE(10410), 1,
      sym_variant_declaration,
    STATE(11639), 1,
      sym__constructor_name,
    STATE(11989), 1,
      sym_constructor_declaration,
    STATE(13195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12815), 2,
      anon_sym_true,
      anon_sym_false,
  [629893] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11078), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [629916] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11070), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [629939] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16939), 1,
      anon_sym_constraint,
    STATE(13198), 1,
      sym_attribute,
    STATE(13227), 1,
      aux_sym_type_binding_repeat1,
    STATE(13489), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12315), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [629968] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12414), 1,
      anon_sym_LPAREN,
    ACTIONS(12416), 1,
      anon_sym_LBRACK,
    ACTIONS(16941), 1,
      anon_sym_private,
    ACTIONS(16943), 1,
      anon_sym_PIPE,
    STATE(10506), 1,
      sym_variant_declaration,
    STATE(11081), 1,
      sym__constructor_name,
    STATE(11841), 1,
      sym_constructor_declaration,
    STATE(13199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12418), 2,
      anon_sym_true,
      anon_sym_false,
  [630007] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11500), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11502), 1,
      anon_sym_in,
    ACTIONS(16931), 1,
      sym__lowercase_identifier,
    ACTIONS(16933), 1,
      anon_sym_POUND,
    STATE(13200), 1,
      sym_attribute,
    STATE(13620), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17229), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [630048] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11588), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11590), 1,
      anon_sym_in,
    ACTIONS(16931), 1,
      sym__lowercase_identifier,
    ACTIONS(16933), 1,
      anon_sym_POUND,
    STATE(13201), 1,
      sym_attribute,
    STATE(13620), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17229), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [630089] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16939), 1,
      anon_sym_constraint,
    STATE(13202), 1,
      sym_attribute,
    STATE(13227), 1,
      aux_sym_type_binding_repeat1,
    STATE(13489), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12329), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [630118] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [630141] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13204), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [630164] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12337), 1,
      anon_sym_LPAREN,
    ACTIONS(12339), 1,
      anon_sym_LBRACK,
    ACTIONS(16945), 1,
      anon_sym_private,
    ACTIONS(16947), 1,
      anon_sym_PIPE,
    STATE(10410), 1,
      sym_variant_declaration,
    STATE(10775), 1,
      sym__constructor_name,
    STATE(11633), 1,
      sym_constructor_declaration,
    STATE(13205), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12341), 2,
      anon_sym_true,
      anon_sym_false,
  [630203] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13206), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [630226] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [630249] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12414), 1,
      anon_sym_LPAREN,
    ACTIONS(12416), 1,
      anon_sym_LBRACK,
    ACTIONS(16943), 1,
      anon_sym_PIPE,
    ACTIONS(16949), 1,
      anon_sym_private,
    STATE(10410), 1,
      sym_variant_declaration,
    STATE(11081), 1,
      sym__constructor_name,
    STATE(11841), 1,
      sym_constructor_declaration,
    STATE(13208), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12418), 2,
      anon_sym_true,
      anon_sym_false,
  [630288] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    STATE(13209), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12509), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_GT,
      anon_sym_AMP,
  [630313] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11104), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [630336] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11088), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [630359] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12351), 1,
      anon_sym_LPAREN,
    ACTIONS(12353), 1,
      anon_sym_LBRACK,
    ACTIONS(16953), 1,
      anon_sym_private,
    ACTIONS(16955), 1,
      anon_sym_PIPE,
    STATE(10410), 1,
      sym_variant_declaration,
    STATE(10915), 1,
      sym__constructor_name,
    STATE(11600), 1,
      sym_constructor_declaration,
    STATE(13212), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12355), 2,
      anon_sym_true,
      anon_sym_false,
  [630398] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13213), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11066), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [630421] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16939), 1,
      anon_sym_constraint,
    STATE(13202), 1,
      aux_sym_type_binding_repeat1,
    STATE(13214), 1,
      sym_attribute,
    STATE(13489), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12315), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [630450] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13215), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11112), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [630473] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12811), 1,
      anon_sym_LPAREN,
    ACTIONS(12813), 1,
      anon_sym_LBRACK,
    ACTIONS(16937), 1,
      anon_sym_PIPE,
    ACTIONS(16957), 1,
      anon_sym_private,
    STATE(10506), 1,
      sym_variant_declaration,
    STATE(11639), 1,
      sym__constructor_name,
    STATE(11989), 1,
      sym_constructor_declaration,
    STATE(13216), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12815), 2,
      anon_sym_true,
      anon_sym_false,
  [630512] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16961), 1,
      anon_sym_COLON2,
    STATE(13217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16959), 5,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_when,
  [630545] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16965), 1,
      anon_sym_COLON2,
    STATE(13218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16963), 8,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_as,
      anon_sym_when,
  [630572] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5079), 1,
      anon_sym_COLON2,
    ACTIONS(16503), 1,
      anon_sym_DOT_DOT,
    STATE(13219), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5077), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [630599] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11720), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11722), 1,
      anon_sym_in,
    ACTIONS(16931), 1,
      sym__lowercase_identifier,
    ACTIONS(16933), 1,
      anon_sym_POUND,
    STATE(13220), 1,
      sym_attribute,
    STATE(13620), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17229), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [630640] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(13221), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 9,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
  [630665] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16939), 1,
      anon_sym_constraint,
    STATE(13198), 1,
      aux_sym_type_binding_repeat1,
    STATE(13222), 1,
      sym_attribute,
    STATE(13489), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12236), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [630694] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13223), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10983), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [630717] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16967), 1,
      anon_sym_STAR,
    STATE(13224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10391), 9,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [630742] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16971), 1,
      anon_sym_COLON2,
    STATE(13225), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16969), 8,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_as,
      anon_sym_when,
  [630769] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13226), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11048), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [630792] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16973), 1,
      anon_sym_constraint,
    STATE(13489), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13227), 2,
      sym_attribute,
      aux_sym_type_binding_repeat1,
    ACTIONS(12282), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [630819] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8959), 4,
      anon_sym_module,
      anon_sym_sig,
      anon_sym_functor,
      sym__lowercase_identifier,
    ACTIONS(8961), 6,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__uppercase_identifier,
      aux_sym_attribute_id_token1,
  [630844] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12351), 1,
      anon_sym_LPAREN,
    ACTIONS(12353), 1,
      anon_sym_LBRACK,
    ACTIONS(16955), 1,
      anon_sym_PIPE,
    ACTIONS(16976), 1,
      anon_sym_private,
    STATE(10506), 1,
      sym_variant_declaration,
    STATE(10915), 1,
      sym__constructor_name,
    STATE(11600), 1,
      sym_constructor_declaration,
    STATE(13229), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12355), 2,
      anon_sym_true,
      anon_sym_false,
  [630883] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16980), 1,
      anon_sym_COLON2,
    STATE(13230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16978), 7,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_as,
      anon_sym_when,
  [630912] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13231), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11108), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [630935] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12337), 1,
      anon_sym_LPAREN,
    ACTIONS(12339), 1,
      anon_sym_LBRACK,
    ACTIONS(16947), 1,
      anon_sym_PIPE,
    ACTIONS(16982), 1,
      anon_sym_private,
    STATE(10506), 1,
      sym_variant_declaration,
    STATE(10775), 1,
      sym__constructor_name,
    STATE(11633), 1,
      sym_constructor_declaration,
    STATE(13232), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12341), 2,
      anon_sym_true,
      anon_sym_false,
  [630974] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13233), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11096), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [630997] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11454), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11456), 1,
      anon_sym_in,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(16931), 1,
      sym__lowercase_identifier,
    ACTIONS(16933), 1,
      anon_sym_POUND,
    STATE(13234), 1,
      sym_attribute,
    STATE(13620), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17229), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [631038] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(11462), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11464), 1,
      anon_sym_in,
    ACTIONS(16931), 1,
      sym__lowercase_identifier,
    ACTIONS(16933), 1,
      anon_sym_POUND,
    STATE(13235), 1,
      sym_attribute,
    STATE(13620), 1,
      sym_type_constructor_path,
    STATE(15466), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17229), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [631079] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10427), 10,
      anon_sym_LPAREN,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [631102] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(13237), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 9,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
  [631127] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13238), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11092), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [631150] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13239), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11084), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [631173] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16984), 1,
      anon_sym_DASH_GT,
    ACTIONS(16986), 1,
      anon_sym_as,
    STATE(13240), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12436), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [631199] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13241), 1,
      sym_attribute,
    STATE(19905), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [631229] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(16994), 1,
      sym__lowercase_identifier,
    ACTIONS(16996), 1,
      anon_sym_LPAREN,
    ACTIONS(16998), 1,
      anon_sym_LBRACK,
    ACTIONS(17000), 1,
      anon_sym_LBRACE,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    STATE(6589), 1,
      sym_field_path,
    STATE(13242), 1,
      sym_attribute,
    STATE(16042), 1,
      sym_indexing_operator_path,
    STATE(18927), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [631267] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13243), 1,
      sym_attribute,
    STATE(19159), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [631297] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13244), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11384), 9,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [631319] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17004), 1,
      sym__lowercase_identifier,
    ACTIONS(17006), 1,
      anon_sym_LPAREN,
    ACTIONS(17008), 1,
      anon_sym_LBRACK,
    ACTIONS(17010), 1,
      anon_sym_LBRACE,
    STATE(5995), 1,
      sym_field_path,
    STATE(13245), 1,
      sym_attribute,
    STATE(15421), 1,
      sym_indexing_operator_path,
    STATE(18262), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [631357] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17012), 1,
      sym__lowercase_identifier,
    ACTIONS(17014), 1,
      anon_sym_LPAREN,
    ACTIONS(17016), 1,
      anon_sym_LBRACK,
    ACTIONS(17018), 1,
      anon_sym_LBRACE,
    STATE(6365), 1,
      sym_field_path,
    STATE(13246), 1,
      sym_attribute,
    STATE(15186), 1,
      sym_indexing_operator_path,
    STATE(18205), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [631395] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13247), 1,
      sym_attribute,
    STATE(17770), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [631425] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5205), 1,
      anon_sym_LBRACK,
    ACTIONS(5213), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17020), 1,
      anon_sym_LPAREN,
    ACTIONS(17022), 1,
      anon_sym_LBRACE,
    ACTIONS(17024), 1,
      sym__uppercase_identifier,
    STATE(5431), 1,
      sym__constructor_name,
    STATE(13248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5634), 3,
      sym_record_binding_pattern,
      sym_list_binding_pattern,
      sym_array_binding_pattern,
  [631459] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12351), 1,
      anon_sym_LPAREN,
    ACTIONS(12353), 1,
      anon_sym_LBRACK,
    ACTIONS(16955), 1,
      anon_sym_PIPE,
    STATE(10702), 1,
      sym_variant_declaration,
    STATE(10915), 1,
      sym__constructor_name,
    STATE(11600), 1,
      sym_constructor_declaration,
    STATE(13249), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12355), 2,
      anon_sym_true,
      anon_sym_false,
  [631495] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6907), 1,
      anon_sym_LBRACK,
    ACTIONS(6917), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17026), 1,
      anon_sym_LPAREN,
    ACTIONS(17028), 1,
      anon_sym_LBRACE,
    ACTIONS(17030), 1,
      sym__uppercase_identifier,
    STATE(7603), 1,
      sym__constructor_name,
    STATE(13250), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(7506), 3,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
  [631529] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13251), 1,
      sym_attribute,
    STATE(19387), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [631559] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9270), 1,
      anon_sym_COLON2,
    STATE(13252), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9272), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [631583] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13253), 1,
      sym_attribute,
    STATE(18557), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [631613] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13254), 1,
      sym_attribute,
    STATE(18048), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [631643] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17032), 1,
      sym__lowercase_identifier,
    ACTIONS(17034), 1,
      anon_sym_LPAREN,
    ACTIONS(17036), 1,
      anon_sym_LBRACK,
    ACTIONS(17038), 1,
      anon_sym_LBRACE,
    STATE(5019), 1,
      sym_field_path,
    STATE(13255), 1,
      sym_attribute,
    STATE(16397), 1,
      sym_indexing_operator_path,
    STATE(20259), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [631681] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13256), 1,
      sym_attribute,
    STATE(17835), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [631711] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17040), 1,
      sym__lowercase_identifier,
    ACTIONS(17042), 1,
      anon_sym_LPAREN,
    ACTIONS(17044), 1,
      anon_sym_LBRACK,
    ACTIONS(17046), 1,
      anon_sym_LBRACE,
    STATE(5082), 1,
      sym_field_path,
    STATE(13257), 1,
      sym_attribute,
    STATE(15398), 1,
      sym_indexing_operator_path,
    STATE(18923), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [631749] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13258), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 9,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
  [631771] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17048), 1,
      sym__lowercase_identifier,
    ACTIONS(17050), 1,
      anon_sym_LPAREN,
    ACTIONS(17052), 1,
      anon_sym_LBRACK,
    ACTIONS(17054), 1,
      anon_sym_LBRACE,
    STATE(6659), 1,
      sym_field_path,
    STATE(13259), 1,
      sym_attribute,
    STATE(15137), 1,
      sym_indexing_operator_path,
    STATE(19191), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [631809] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9278), 1,
      anon_sym_COLON2,
    STATE(13260), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9280), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [631833] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(17056), 1,
      anon_sym_LPAREN,
    ACTIONS(17058), 1,
      anon_sym_LBRACK,
    STATE(10898), 1,
      sym_constructor_declaration,
    STATE(11674), 1,
      sym__constructor_name,
    STATE(13261), 1,
      sym_attribute,
    STATE(13645), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17060), 2,
      anon_sym_true,
      anon_sym_false,
  [631869] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11458), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11896), 1,
      anon_sym_in,
    ACTIONS(16931), 1,
      sym__lowercase_identifier,
    ACTIONS(16933), 1,
      anon_sym_POUND,
    ACTIONS(17062), 1,
      anon_sym_STAR,
    STATE(13262), 1,
      sym_attribute,
    STATE(13620), 1,
      sym_type_constructor_path,
    STATE(14656), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17229), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [631907] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9248), 1,
      anon_sym_COLON2,
    STATE(13263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9250), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [631931] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13264), 1,
      sym_attribute,
    STATE(18727), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [631961] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9260), 1,
      anon_sym_COLON2,
    STATE(13265), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9262), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [631985] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13266), 1,
      sym_attribute,
    STATE(19265), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [632015] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17064), 1,
      anon_sym_LPAREN,
    ACTIONS(17066), 1,
      anon_sym_LBRACE,
    ACTIONS(17068), 1,
      sym__uppercase_identifier,
    STATE(13258), 1,
      sym__constructor_name,
    STATE(13267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13079), 3,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
  [632049] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17074), 1,
      sym__right_quoted_string_delimiter,
    STATE(13268), 1,
      sym_attribute,
    STATE(13471), 1,
      aux_sym_quoted_string_content_repeat1,
    STATE(20396), 1,
      sym_quoted_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17072), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(17070), 4,
      aux_sym_string_content_token1,
      aux_sym_quoted_string_content_token1,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [632079] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13269), 1,
      sym_attribute,
    STATE(19164), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [632109] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13270), 1,
      sym_attribute,
    STATE(19572), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [632139] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17076), 1,
      anon_sym_LPAREN,
    ACTIONS(17078), 1,
      anon_sym_LBRACE,
    ACTIONS(17080), 1,
      sym__uppercase_identifier,
    STATE(9457), 1,
      sym__constructor_name,
    STATE(13271), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13942), 3,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
  [632173] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17066), 1,
      anon_sym_LBRACE,
    ACTIONS(17082), 1,
      anon_sym_LPAREN,
    ACTIONS(17084), 1,
      sym__uppercase_identifier,
    STATE(8936), 1,
      sym__constructor_name,
    STATE(13272), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13079), 3,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
  [632207] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13273), 1,
      sym_attribute,
    STATE(17916), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [632237] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13274), 1,
      sym_attribute,
    STATE(18351), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [632267] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17086), 1,
      sym__lowercase_identifier,
    ACTIONS(17088), 1,
      anon_sym_LPAREN,
    ACTIONS(17090), 1,
      anon_sym_LBRACK,
    ACTIONS(17092), 1,
      anon_sym_LBRACE,
    STATE(3451), 1,
      sym_field_path,
    STATE(13275), 1,
      sym_attribute,
    STATE(16315), 1,
      sym_indexing_operator_path,
    STATE(18542), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [632305] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17094), 1,
      sym__lowercase_identifier,
    ACTIONS(17096), 1,
      anon_sym_LPAREN,
    ACTIONS(17098), 1,
      anon_sym_LBRACK,
    ACTIONS(17100), 1,
      anon_sym_LBRACE,
    STATE(6692), 1,
      sym_field_path,
    STATE(13276), 1,
      sym_attribute,
    STATE(16189), 1,
      sym_indexing_operator_path,
    STATE(18582), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [632343] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17102), 1,
      sym__lowercase_identifier,
    ACTIONS(17104), 1,
      anon_sym_LPAREN,
    ACTIONS(17106), 1,
      anon_sym_LBRACK,
    ACTIONS(17108), 1,
      anon_sym_LBRACE,
    STATE(3805), 1,
      sym_field_path,
    STATE(13277), 1,
      sym_attribute,
    STATE(15655), 1,
      sym_indexing_operator_path,
    STATE(17973), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [632381] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13278), 1,
      sym_attribute,
    STATE(18973), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [632411] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9252), 1,
      anon_sym_COLON2,
    STATE(13279), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9254), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [632435] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17110), 1,
      sym__lowercase_identifier,
    ACTIONS(17112), 1,
      anon_sym_LPAREN,
    ACTIONS(17114), 1,
      anon_sym_LBRACK,
    ACTIONS(17116), 1,
      anon_sym_LBRACE,
    STATE(9225), 1,
      sym_field_path,
    STATE(13280), 1,
      sym_attribute,
    STATE(15571), 1,
      sym_indexing_operator_path,
    STATE(18027), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [632473] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17118), 1,
      sym__lowercase_identifier,
    ACTIONS(17120), 1,
      anon_sym_LPAREN,
    ACTIONS(17122), 1,
      anon_sym_LBRACK,
    ACTIONS(17124), 1,
      anon_sym_LBRACE,
    STATE(5877), 1,
      sym_field_path,
    STATE(13281), 1,
      sym_attribute,
    STATE(15236), 1,
      sym_indexing_operator_path,
    STATE(18222), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [632511] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9190), 1,
      anon_sym_COLON2,
    STATE(13282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9192), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [632535] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7167), 1,
      anon_sym_LBRACK,
    ACTIONS(7177), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17126), 1,
      anon_sym_LPAREN,
    ACTIONS(17128), 1,
      anon_sym_LBRACE,
    ACTIONS(17130), 1,
      sym__uppercase_identifier,
    STATE(7742), 1,
      sym__constructor_name,
    STATE(13283), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(7813), 3,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
  [632569] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17132), 1,
      sym__lowercase_identifier,
    ACTIONS(17134), 1,
      anon_sym_LPAREN,
    ACTIONS(17136), 1,
      anon_sym_LBRACK,
    ACTIONS(17138), 1,
      anon_sym_LBRACE,
    STATE(2940), 1,
      sym_field_path,
    STATE(13284), 1,
      sym_attribute,
    STATE(15105), 1,
      sym_indexing_operator_path,
    STATE(18736), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [632607] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13285), 1,
      sym_attribute,
    STATE(18850), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [632637] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9210), 1,
      anon_sym_COLON2,
    STATE(13286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9212), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [632661] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8448), 1,
      anon_sym_LBRACK,
    ACTIONS(8452), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(16193), 1,
      sym__uppercase_identifier,
    ACTIONS(17140), 1,
      anon_sym_LPAREN,
    ACTIONS(17142), 1,
      anon_sym_LBRACE,
    STATE(8161), 1,
      sym__constructor_name,
    STATE(13287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14049), 3,
      sym_record_binding_pattern,
      sym_list_binding_pattern,
      sym_array_binding_pattern,
  [632695] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17144), 1,
      sym__lowercase_identifier,
    ACTIONS(17146), 1,
      anon_sym_LPAREN,
    ACTIONS(17148), 1,
      anon_sym_LBRACK,
    ACTIONS(17150), 1,
      anon_sym_LBRACE,
    STATE(6041), 1,
      sym_field_path,
    STATE(13288), 1,
      sym_attribute,
    STATE(15734), 1,
      sym_indexing_operator_path,
    STATE(17865), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [632733] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17152), 1,
      sym__lowercase_identifier,
    ACTIONS(17154), 1,
      anon_sym_LPAREN,
    ACTIONS(17156), 1,
      anon_sym_LBRACK,
    ACTIONS(17158), 1,
      anon_sym_LBRACE,
    STATE(6755), 1,
      sym_field_path,
    STATE(13289), 1,
      sym_attribute,
    STATE(15406), 1,
      sym_indexing_operator_path,
    STATE(18660), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [632771] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5249), 1,
      anon_sym_LBRACK,
    ACTIONS(5257), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17160), 1,
      anon_sym_LPAREN,
    ACTIONS(17162), 1,
      anon_sym_LBRACE,
    ACTIONS(17164), 1,
      sym__uppercase_identifier,
    STATE(5480), 1,
      sym__constructor_name,
    STATE(13290), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5695), 3,
      sym_record_binding_pattern,
      sym_list_binding_pattern,
      sym_array_binding_pattern,
  [632805] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17166), 1,
      sym__lowercase_identifier,
    ACTIONS(17168), 1,
      anon_sym_LPAREN,
    ACTIONS(17170), 1,
      anon_sym_LBRACK,
    ACTIONS(17172), 1,
      anon_sym_LBRACE,
    STATE(9669), 1,
      sym_field_path,
    STATE(13291), 1,
      sym_attribute,
    STATE(15837), 1,
      sym_indexing_operator_path,
    STATE(18342), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [632843] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13292), 1,
      sym_attribute,
    STATE(19677), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [632873] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9128), 1,
      anon_sym_COLON2,
    STATE(13293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9130), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [632897] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9154), 1,
      anon_sym_COLON2,
    STATE(13294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9156), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [632921] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13295), 1,
      sym_attribute,
    STATE(19001), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [632951] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13296), 1,
      sym_attribute,
    STATE(18097), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [632981] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9224), 1,
      anon_sym_COLON2,
    STATE(13297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9226), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [633005] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7207), 1,
      anon_sym_LBRACK,
    ACTIONS(7217), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17174), 1,
      anon_sym_LPAREN,
    ACTIONS(17176), 1,
      anon_sym_LBRACE,
    ACTIONS(17178), 1,
      sym__uppercase_identifier,
    STATE(8069), 1,
      sym__constructor_name,
    STATE(13298), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8073), 3,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
  [633039] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13299), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11009), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11007), 7,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
  [633063] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13300), 1,
      sym_attribute,
    STATE(17896), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [633093] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12414), 1,
      anon_sym_LPAREN,
    ACTIONS(12416), 1,
      anon_sym_LBRACK,
    ACTIONS(16943), 1,
      anon_sym_PIPE,
    STATE(10702), 1,
      sym_variant_declaration,
    STATE(11081), 1,
      sym__constructor_name,
    STATE(11841), 1,
      sym_constructor_declaration,
    STATE(13301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12418), 2,
      anon_sym_true,
      anon_sym_false,
  [633129] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9166), 1,
      anon_sym_COLON2,
    STATE(13302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9168), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [633153] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(17180), 1,
      anon_sym_LPAREN,
    ACTIONS(17182), 1,
      anon_sym_LBRACK,
    STATE(10898), 1,
      sym_constructor_declaration,
    STATE(11968), 1,
      sym__constructor_name,
    STATE(13303), 1,
      sym_attribute,
    STATE(13551), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17184), 2,
      anon_sym_true,
      anon_sym_false,
  [633189] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13304), 1,
      sym_attribute,
    STATE(19609), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [633219] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17186), 1,
      sym__lowercase_identifier,
    ACTIONS(17188), 1,
      anon_sym_LPAREN,
    ACTIONS(17190), 1,
      anon_sym_LBRACK,
    ACTIONS(17192), 1,
      anon_sym_LBRACE,
    STATE(7986), 1,
      sym_field_path,
    STATE(13305), 1,
      sym_attribute,
    STATE(16143), 1,
      sym_indexing_operator_path,
    STATE(17703), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [633257] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16984), 1,
      anon_sym_DASH_GT,
    ACTIONS(16986), 1,
      anon_sym_as,
    STATE(13306), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12467), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [633283] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6991), 1,
      anon_sym_LBRACK,
    ACTIONS(7001), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17194), 1,
      anon_sym_LPAREN,
    ACTIONS(17196), 1,
      anon_sym_LBRACE,
    ACTIONS(17198), 1,
      sym__uppercase_identifier,
    STATE(7656), 1,
      sym__constructor_name,
    STATE(13307), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(7724), 3,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
  [633317] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9220), 1,
      anon_sym_COLON2,
    STATE(13308), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9222), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [633341] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13309), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11262), 2,
      anon_sym_LPAREN,
      anon_sym_DOT,
    ACTIONS(11258), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [633365] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9132), 1,
      anon_sym_COLON2,
    STATE(13310), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9134), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [633389] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13311), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11336), 9,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [633411] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9150), 1,
      anon_sym_COLON2,
    STATE(13312), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9152), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [633435] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17200), 1,
      sym__lowercase_identifier,
    ACTIONS(17202), 1,
      anon_sym_LPAREN,
    ACTIONS(17204), 1,
      anon_sym_LBRACK,
    ACTIONS(17206), 1,
      anon_sym_LBRACE,
    STATE(4892), 1,
      sym_field_path,
    STATE(13313), 1,
      sym_attribute,
    STATE(16460), 1,
      sym_indexing_operator_path,
    STATE(17804), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [633473] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9162), 1,
      anon_sym_COLON2,
    STATE(13314), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9164), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [633497] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9170), 1,
      anon_sym_COLON2,
    STATE(13315), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9172), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [633521] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9186), 1,
      anon_sym_COLON2,
    STATE(13316), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9188), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [633545] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13317), 1,
      sym_attribute,
    STATE(19809), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [633575] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13318), 1,
      sym_attribute,
    STATE(19862), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [633605] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13319), 1,
      sym_attribute,
    STATE(19241), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [633635] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13320), 1,
      sym_attribute,
    STATE(18261), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [633665] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17208), 1,
      sym__lowercase_identifier,
    ACTIONS(17210), 1,
      anon_sym_LPAREN,
    ACTIONS(17212), 1,
      anon_sym_LBRACK,
    ACTIONS(17214), 1,
      anon_sym_LBRACE,
    STATE(5998), 1,
      sym_field_path,
    STATE(13321), 1,
      sym_attribute,
    STATE(15139), 1,
      sym_indexing_operator_path,
    STATE(18774), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [633703] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13322), 1,
      sym_attribute,
    STATE(19312), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [633733] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13323), 1,
      sym_attribute,
    STATE(19966), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [633763] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13324), 1,
      sym_attribute,
    STATE(19473), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [633793] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16984), 1,
      anon_sym_DASH_GT,
    ACTIONS(16986), 1,
      anon_sym_as,
    STATE(13325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12426), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [633819] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13326), 1,
      sym_attribute,
    STATE(19512), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [633849] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13327), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11262), 9,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [633871] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13328), 1,
      sym_attribute,
    STATE(18525), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [633901] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11734), 1,
      anon_sym_COLON2,
    ACTIONS(17216), 1,
      anon_sym_LPAREN,
    STATE(13549), 1,
      sym_module_parameter,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13329), 2,
      sym_attribute,
      aux_sym_module_binding_repeat1,
    ACTIONS(11732), 5,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [633929] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9182), 1,
      anon_sym_COLON2,
    STATE(13330), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [633953] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17219), 1,
      sym__lowercase_identifier,
    ACTIONS(17221), 1,
      anon_sym_LPAREN,
    ACTIONS(17223), 1,
      anon_sym_LBRACK,
    ACTIONS(17225), 1,
      anon_sym_LBRACE,
    STATE(5996), 1,
      sym_field_path,
    STATE(13331), 1,
      sym_attribute,
    STATE(16489), 1,
      sym_indexing_operator_path,
    STATE(18502), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [633991] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9178), 1,
      anon_sym_COLON2,
    STATE(13332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9180), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [634015] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13333), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11560), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11845), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11562), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [634041] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13334), 1,
      sym_attribute,
    STATE(19950), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [634071] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6839), 1,
      anon_sym_LBRACK,
    ACTIONS(6849), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17227), 1,
      anon_sym_LPAREN,
    ACTIONS(17229), 1,
      anon_sym_LBRACE,
    ACTIONS(17231), 1,
      sym__uppercase_identifier,
    STATE(8449), 1,
      sym__constructor_name,
    STATE(13335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13293), 3,
      sym_record_binding_pattern,
      sym_list_binding_pattern,
      sym_array_binding_pattern,
  [634105] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13336), 1,
      sym_attribute,
    STATE(18612), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [634135] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13337), 1,
      sym_attribute,
    STATE(17708), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [634165] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5083), 1,
      anon_sym_LBRACK,
    ACTIONS(5091), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17233), 1,
      anon_sym_LPAREN,
    ACTIONS(17235), 1,
      anon_sym_LBRACE,
    ACTIONS(17237), 1,
      sym__uppercase_identifier,
    STATE(5381), 1,
      sym__constructor_name,
    STATE(13338), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5424), 3,
      sym_record_binding_pattern,
      sym_list_binding_pattern,
      sym_array_binding_pattern,
  [634199] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13339), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 9,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
  [634221] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13340), 1,
      sym_attribute,
    STATE(19865), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [634251] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13341), 1,
      sym_attribute,
    STATE(18789), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [634281] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17239), 1,
      sym__lowercase_identifier,
    ACTIONS(17241), 1,
      anon_sym_LPAREN,
    ACTIONS(17243), 1,
      anon_sym_LBRACK,
    ACTIONS(17245), 1,
      anon_sym_LBRACE,
    STATE(5148), 1,
      sym_field_path,
    STATE(13342), 1,
      sym_attribute,
    STATE(15155), 1,
      sym_indexing_operator_path,
    STATE(18182), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [634319] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13343), 1,
      sym_attribute,
    STATE(19835), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [634349] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17247), 1,
      sym__lowercase_identifier,
    ACTIONS(17249), 1,
      anon_sym_LPAREN,
    ACTIONS(17251), 1,
      anon_sym_LBRACK,
    ACTIONS(17253), 1,
      anon_sym_LBRACE,
    STATE(3201), 1,
      sym_field_path,
    STATE(13344), 1,
      sym_attribute,
    STATE(16339), 1,
      sym_indexing_operator_path,
    STATE(17653), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [634387] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4953), 1,
      anon_sym_LBRACK,
    ACTIONS(4969), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17066), 1,
      anon_sym_LBRACE,
    ACTIONS(17255), 1,
      anon_sym_LPAREN,
    ACTIONS(17257), 1,
      sym__uppercase_identifier,
    STATE(8455), 1,
      sym__constructor_name,
    STATE(13345), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13079), 3,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
  [634421] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17259), 1,
      sym__lowercase_identifier,
    ACTIONS(17261), 1,
      anon_sym_LPAREN,
    ACTIONS(17263), 1,
      anon_sym_LBRACK,
    ACTIONS(17265), 1,
      anon_sym_LBRACE,
    STATE(5837), 1,
      sym_field_path,
    STATE(13346), 1,
      sym_attribute,
    STATE(15246), 1,
      sym_indexing_operator_path,
    STATE(18812), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [634459] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17267), 1,
      sym__lowercase_identifier,
    ACTIONS(17269), 1,
      anon_sym_LPAREN,
    ACTIONS(17271), 1,
      anon_sym_LBRACK,
    ACTIONS(17273), 1,
      anon_sym_LBRACE,
    STATE(6097), 1,
      sym_field_path,
    STATE(13347), 1,
      sym_attribute,
    STATE(16075), 1,
      sym_indexing_operator_path,
    STATE(18422), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [634497] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17275), 1,
      sym__lowercase_identifier,
    ACTIONS(17277), 1,
      anon_sym_LPAREN,
    ACTIONS(17279), 1,
      anon_sym_LBRACK,
    ACTIONS(17281), 1,
      anon_sym_LBRACE,
    STATE(4949), 1,
      sym_field_path,
    STATE(13348), 1,
      sym_attribute,
    STATE(15203), 1,
      sym_indexing_operator_path,
    STATE(18135), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [634535] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9136), 1,
      anon_sym_COLON2,
    STATE(13349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9138), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [634559] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13350), 1,
      sym_attribute,
    STATE(20032), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [634589] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11130), 1,
      anon_sym_in,
    ACTIONS(16931), 1,
      sym__lowercase_identifier,
    ACTIONS(17283), 1,
      anon_sym_POUND,
    STATE(13351), 1,
      sym_attribute,
    STATE(13701), 1,
      sym_type_constructor_path,
    STATE(17229), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11128), 3,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT,
  [634623] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13352), 1,
      sym_attribute,
    STATE(18696), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [634653] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17285), 1,
      sym__lowercase_identifier,
    ACTIONS(17287), 1,
      anon_sym_LPAREN,
    ACTIONS(17289), 1,
      anon_sym_LBRACK,
    ACTIONS(17291), 1,
      anon_sym_LBRACE,
    STATE(7318), 1,
      sym_field_path,
    STATE(13353), 1,
      sym_attribute,
    STATE(16463), 1,
      sym_indexing_operator_path,
    STATE(18012), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [634691] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9198), 1,
      anon_sym_COLON2,
    STATE(13354), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9200), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [634715] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5079), 1,
      anon_sym_COLON2,
    STATE(13355), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5077), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [634739] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7595), 1,
      anon_sym_LBRACK,
    ACTIONS(7607), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17293), 1,
      anon_sym_LPAREN,
    ACTIONS(17295), 1,
      anon_sym_LBRACE,
    ACTIONS(17297), 1,
      sym__uppercase_identifier,
    STATE(8693), 1,
      sym__constructor_name,
    STATE(13356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8819), 3,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
  [634773] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9202), 1,
      anon_sym_COLON2,
    STATE(13357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9204), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [634797] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9244), 1,
      anon_sym_COLON2,
    STATE(13358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9246), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [634821] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17299), 1,
      sym__lowercase_identifier,
    ACTIONS(17301), 1,
      anon_sym_LPAREN,
    ACTIONS(17303), 1,
      anon_sym_LBRACK,
    ACTIONS(17305), 1,
      anon_sym_LBRACE,
    STATE(3823), 1,
      sym_field_path,
    STATE(13359), 1,
      sym_attribute,
    STATE(16020), 1,
      sym_indexing_operator_path,
    STATE(17757), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [634859] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17307), 1,
      sym__lowercase_identifier,
    ACTIONS(17309), 1,
      anon_sym_LPAREN,
    ACTIONS(17311), 1,
      anon_sym_LBRACK,
    ACTIONS(17313), 1,
      anon_sym_LBRACE,
    STATE(4125), 1,
      sym_field_path,
    STATE(13360), 1,
      sym_attribute,
    STATE(16083), 1,
      sym_indexing_operator_path,
    STATE(20465), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [634897] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9240), 1,
      anon_sym_COLON2,
    STATE(13361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9242), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [634921] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13362), 1,
      sym_attribute,
    STATE(17960), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [634951] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13363), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10425), 4,
      anon_sym_module,
      anon_sym_sig,
      anon_sym_functor,
      sym__lowercase_identifier,
    ACTIONS(10427), 5,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__uppercase_identifier,
  [634975] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17315), 1,
      sym__lowercase_identifier,
    ACTIONS(17317), 1,
      anon_sym_LPAREN,
    ACTIONS(17319), 1,
      anon_sym_LBRACK,
    ACTIONS(17321), 1,
      anon_sym_LBRACE,
    STATE(6109), 1,
      sym_field_path,
    STATE(13364), 1,
      sym_attribute,
    STATE(15715), 1,
      sym_indexing_operator_path,
    STATE(18302), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [635013] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13365), 1,
      sym_attribute,
    STATE(18440), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [635043] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13366), 1,
      sym_attribute,
    STATE(19476), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [635073] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7517), 1,
      anon_sym_LBRACK,
    ACTIONS(7525), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17323), 1,
      anon_sym_LPAREN,
    ACTIONS(17325), 1,
      anon_sym_LBRACE,
    ACTIONS(17327), 1,
      sym__uppercase_identifier,
    STATE(8639), 1,
      sym__constructor_name,
    STATE(13367), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8938), 3,
      sym_record_binding_pattern,
      sym_list_binding_pattern,
      sym_array_binding_pattern,
  [635107] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16984), 1,
      anon_sym_DASH_GT,
    STATE(13368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12509), 8,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [635131] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13369), 1,
      sym_attribute,
    STATE(17689), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [635161] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(17329), 1,
      anon_sym_LPAREN,
    ACTIONS(17331), 1,
      anon_sym_LBRACK,
    STATE(10898), 1,
      sym_constructor_declaration,
    STATE(11999), 1,
      sym__constructor_name,
    STATE(13370), 1,
      sym_attribute,
    STATE(13593), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17333), 2,
      anon_sym_true,
      anon_sym_false,
  [635197] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13371), 1,
      sym_attribute,
    STATE(18175), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [635227] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(17335), 1,
      anon_sym_LPAREN,
    ACTIONS(17337), 1,
      anon_sym_LBRACK,
    STATE(10898), 1,
      sym_constructor_declaration,
    STATE(11417), 1,
      sym__constructor_name,
    STATE(13372), 1,
      sym_attribute,
    STATE(13690), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17339), 2,
      anon_sym_true,
      anon_sym_false,
  [635263] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13373), 1,
      sym_attribute,
    STATE(18309), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [635293] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17341), 1,
      sym__lowercase_identifier,
    ACTIONS(17343), 1,
      anon_sym_LPAREN,
    ACTIONS(17345), 1,
      anon_sym_LBRACK,
    ACTIONS(17347), 1,
      anon_sym_LBRACE,
    STATE(3060), 1,
      sym_field_path,
    STATE(13374), 1,
      sym_attribute,
    STATE(15492), 1,
      sym_indexing_operator_path,
    STATE(18987), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [635331] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17349), 1,
      sym__lowercase_identifier,
    ACTIONS(17351), 1,
      anon_sym_LPAREN,
    ACTIONS(17353), 1,
      anon_sym_LBRACK,
    ACTIONS(17355), 1,
      anon_sym_LBRACE,
    STATE(2924), 1,
      sym_field_path,
    STATE(13375), 1,
      sym_attribute,
    STATE(15303), 1,
      sym_indexing_operator_path,
    STATE(18849), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [635369] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13376), 1,
      sym_attribute,
    STATE(18180), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [635399] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5497), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17231), 1,
      sym__uppercase_identifier,
    ACTIONS(17357), 1,
      anon_sym_LPAREN,
    ACTIONS(17359), 1,
      anon_sym_LBRACE,
    STATE(8449), 1,
      sym__constructor_name,
    STATE(13377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10248), 3,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
  [635433] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13378), 1,
      sym_attribute,
    STATE(19430), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [635463] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(17361), 1,
      anon_sym_LPAREN,
    ACTIONS(17363), 1,
      anon_sym_LBRACK,
    STATE(10898), 1,
      sym_constructor_declaration,
    STATE(11922), 1,
      sym__constructor_name,
    STATE(13379), 1,
      sym_attribute,
    STATE(13695), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17365), 2,
      anon_sym_true,
      anon_sym_false,
  [635499] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12414), 1,
      anon_sym_LPAREN,
    ACTIONS(12416), 1,
      anon_sym_LBRACK,
    ACTIONS(16943), 1,
      anon_sym_PIPE,
    STATE(10423), 1,
      sym_variant_declaration,
    STATE(11081), 1,
      sym__constructor_name,
    STATE(11841), 1,
      sym_constructor_declaration,
    STATE(13380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12418), 2,
      anon_sym_true,
      anon_sym_false,
  [635535] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17367), 1,
      sym__lowercase_identifier,
    ACTIONS(17369), 1,
      anon_sym_LPAREN,
    ACTIONS(17371), 1,
      anon_sym_LBRACK,
    ACTIONS(17373), 1,
      anon_sym_LBRACE,
    STATE(6477), 1,
      sym_field_path,
    STATE(13381), 1,
      sym_attribute,
    STATE(15806), 1,
      sym_indexing_operator_path,
    STATE(18622), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [635573] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17375), 1,
      sym__lowercase_identifier,
    ACTIONS(17377), 1,
      anon_sym_LPAREN,
    ACTIONS(17379), 1,
      anon_sym_LBRACK,
    ACTIONS(17381), 1,
      anon_sym_LBRACE,
    STATE(7417), 1,
      sym_field_path,
    STATE(13382), 1,
      sym_attribute,
    STATE(15908), 1,
      sym_indexing_operator_path,
    STATE(18411), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [635611] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12811), 1,
      anon_sym_LPAREN,
    ACTIONS(12813), 1,
      anon_sym_LBRACK,
    ACTIONS(16937), 1,
      anon_sym_PIPE,
    STATE(10702), 1,
      sym_variant_declaration,
    STATE(11639), 1,
      sym__constructor_name,
    STATE(11989), 1,
      sym_constructor_declaration,
    STATE(13383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12815), 2,
      anon_sym_true,
      anon_sym_false,
  [635647] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17383), 1,
      sym__lowercase_identifier,
    ACTIONS(17385), 1,
      anon_sym_LPAREN,
    ACTIONS(17387), 1,
      anon_sym_LBRACK,
    ACTIONS(17389), 1,
      anon_sym_LBRACE,
    STATE(6190), 1,
      sym_field_path,
    STATE(13384), 1,
      sym_attribute,
    STATE(15976), 1,
      sym_indexing_operator_path,
    STATE(17811), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [635685] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13385), 1,
      sym_attribute,
    STATE(19574), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [635715] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17391), 1,
      sym__lowercase_identifier,
    ACTIONS(17393), 1,
      anon_sym_LPAREN,
    ACTIONS(17395), 1,
      anon_sym_LBRACK,
    ACTIONS(17397), 1,
      anon_sym_LBRACE,
    STATE(6667), 1,
      sym_field_path,
    STATE(13386), 1,
      sym_attribute,
    STATE(16333), 1,
      sym_indexing_operator_path,
    STATE(17604), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [635753] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13387), 1,
      sym_attribute,
    STATE(19016), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [635783] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13388), 1,
      sym_attribute,
    STATE(17647), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [635813] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13389), 1,
      sym_attribute,
    STATE(19702), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [635843] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13390), 1,
      sym_attribute,
    STATE(20103), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [635873] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12337), 1,
      anon_sym_LPAREN,
    ACTIONS(12339), 1,
      anon_sym_LBRACK,
    ACTIONS(16947), 1,
      anon_sym_PIPE,
    STATE(10702), 1,
      sym_variant_declaration,
    STATE(10775), 1,
      sym__constructor_name,
    STATE(11633), 1,
      sym_constructor_declaration,
    STATE(13391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12341), 2,
      anon_sym_true,
      anon_sym_false,
  [635909] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13392), 1,
      sym_attribute,
    STATE(20430), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [635939] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13393), 1,
      sym_attribute,
    STATE(19619), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [635969] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5161), 1,
      anon_sym_LBRACK,
    ACTIONS(5169), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17399), 1,
      anon_sym_LPAREN,
    ACTIONS(17401), 1,
      anon_sym_LBRACE,
    ACTIONS(17403), 1,
      sym__uppercase_identifier,
    STATE(5414), 1,
      sym__constructor_name,
    STATE(13394), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5531), 3,
      sym_record_binding_pattern,
      sym_list_binding_pattern,
      sym_array_binding_pattern,
  [636003] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17405), 1,
      sym__lowercase_identifier,
    ACTIONS(17407), 1,
      anon_sym_LPAREN,
    ACTIONS(17409), 1,
      anon_sym_LBRACK,
    ACTIONS(17411), 1,
      anon_sym_LBRACE,
    STATE(7706), 1,
      sym_field_path,
    STATE(13395), 1,
      sym_attribute,
    STATE(16099), 1,
      sym_indexing_operator_path,
    STATE(18621), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [636041] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13396), 1,
      sym_attribute,
    STATE(19391), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [636071] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17413), 1,
      sym__lowercase_identifier,
    ACTIONS(17415), 1,
      anon_sym_LPAREN,
    ACTIONS(17417), 1,
      anon_sym_LBRACK,
    ACTIONS(17419), 1,
      anon_sym_LBRACE,
    STATE(5609), 1,
      sym_field_path,
    STATE(13397), 1,
      sym_attribute,
    STATE(15453), 1,
      sym_indexing_operator_path,
    STATE(18081), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [636109] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11007), 9,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [636131] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13399), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11384), 2,
      anon_sym_LPAREN,
      anon_sym_DOT,
    ACTIONS(11388), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [636155] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13400), 1,
      sym_attribute,
    STATE(18025), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [636185] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(17421), 1,
      anon_sym_LPAREN,
    ACTIONS(17423), 1,
      anon_sym_LBRACK,
    ACTIONS(17427), 1,
      sym__uppercase_identifier,
    STATE(13401), 1,
      sym_attribute,
    STATE(13558), 1,
      sym__attribute,
    STATE(14305), 1,
      sym__constructor_name,
    STATE(14480), 1,
      sym_constructor_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17425), 2,
      anon_sym_true,
      anon_sym_false,
  [636221] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17429), 1,
      anon_sym_LPAREN,
    ACTIONS(17431), 1,
      anon_sym_DOT,
    STATE(13402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11270), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [636247] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13403), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17433), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [636269] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17435), 1,
      sym__lowercase_identifier,
    ACTIONS(17437), 1,
      anon_sym_LPAREN,
    ACTIONS(17439), 1,
      anon_sym_LBRACK,
    ACTIONS(17441), 1,
      anon_sym_LBRACE,
    STATE(2989), 1,
      sym_field_path,
    STATE(13404), 1,
      sym_attribute,
    STATE(15668), 1,
      sym_indexing_operator_path,
    STATE(17919), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [636307] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13405), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17443), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [636329] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17445), 1,
      sym__lowercase_identifier,
    ACTIONS(17447), 1,
      anon_sym_LPAREN,
    ACTIONS(17449), 1,
      anon_sym_LBRACK,
    ACTIONS(17451), 1,
      anon_sym_LBRACE,
    STATE(6135), 1,
      sym_field_path,
    STATE(13406), 1,
      sym_attribute,
    STATE(15984), 1,
      sym_indexing_operator_path,
    STATE(18382), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [636367] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12337), 1,
      anon_sym_LPAREN,
    ACTIONS(12339), 1,
      anon_sym_LBRACK,
    ACTIONS(16947), 1,
      anon_sym_PIPE,
    STATE(10423), 1,
      sym_variant_declaration,
    STATE(10775), 1,
      sym__constructor_name,
    STATE(11633), 1,
      sym_constructor_declaration,
    STATE(13407), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12341), 2,
      anon_sym_true,
      anon_sym_false,
  [636403] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12351), 1,
      anon_sym_LPAREN,
    ACTIONS(12353), 1,
      anon_sym_LBRACK,
    ACTIONS(16955), 1,
      anon_sym_PIPE,
    STATE(10423), 1,
      sym_variant_declaration,
    STATE(10915), 1,
      sym__constructor_name,
    STATE(11600), 1,
      sym_constructor_declaration,
    STATE(13408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12355), 2,
      anon_sym_true,
      anon_sym_false,
  [636439] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9236), 1,
      anon_sym_COLON2,
    STATE(13409), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9238), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [636463] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7551), 1,
      anon_sym_LBRACK,
    ACTIONS(7561), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17078), 1,
      anon_sym_LBRACE,
    ACTIONS(17453), 1,
      anon_sym_LPAREN,
    ACTIONS(17455), 1,
      sym__uppercase_identifier,
    STATE(13410), 1,
      sym_attribute,
    STATE(13883), 1,
      sym__constructor_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13942), 3,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
  [636497] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12811), 1,
      anon_sym_LPAREN,
    ACTIONS(12813), 1,
      anon_sym_LBRACK,
    ACTIONS(16937), 1,
      anon_sym_PIPE,
    STATE(10423), 1,
      sym_variant_declaration,
    STATE(11639), 1,
      sym__constructor_name,
    STATE(11989), 1,
      sym_constructor_declaration,
    STATE(13411), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12815), 2,
      anon_sym_true,
      anon_sym_false,
  [636533] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13412), 1,
      sym_attribute,
    STATE(18890), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [636563] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13413), 1,
      sym_attribute,
    STATE(18443), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [636593] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17457), 1,
      sym__lowercase_identifier,
    ACTIONS(17459), 1,
      anon_sym_LPAREN,
    ACTIONS(17461), 1,
      anon_sym_LBRACK,
    ACTIONS(17463), 1,
      anon_sym_LBRACE,
    STATE(2993), 1,
      sym_field_path,
    STATE(13414), 1,
      sym_attribute,
    STATE(15427), 1,
      sym_indexing_operator_path,
    STATE(18959), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [636631] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17465), 1,
      sym__lowercase_identifier,
    ACTIONS(17467), 1,
      anon_sym_LPAREN,
    ACTIONS(17469), 1,
      anon_sym_LBRACK,
    ACTIONS(17471), 1,
      anon_sym_LBRACE,
    STATE(4752), 1,
      sym_field_path,
    STATE(13415), 1,
      sym_attribute,
    STATE(15267), 1,
      sym_indexing_operator_path,
    STATE(18698), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [636669] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17473), 1,
      sym__lowercase_identifier,
    ACTIONS(17475), 1,
      anon_sym_LPAREN,
    ACTIONS(17477), 1,
      anon_sym_LBRACK,
    ACTIONS(17479), 1,
      anon_sym_LBRACE,
    STATE(3718), 1,
      sym_field_path,
    STATE(13416), 1,
      sym_attribute,
    STATE(16398), 1,
      sym_indexing_operator_path,
    STATE(18462), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [636707] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17481), 1,
      sym__lowercase_identifier,
    ACTIONS(17483), 1,
      anon_sym_LPAREN,
    ACTIONS(17485), 1,
      anon_sym_LBRACK,
    ACTIONS(17487), 1,
      anon_sym_LBRACE,
    STATE(5562), 1,
      sym_field_path,
    STATE(13417), 1,
      sym_attribute,
    STATE(15222), 1,
      sym_indexing_operator_path,
    STATE(18886), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [636745] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9274), 1,
      anon_sym_COLON2,
    STATE(13418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9276), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [636769] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16990), 1,
      aux_sym_character_content_token2,
    STATE(13419), 1,
      sym_attribute,
    STATE(17606), 1,
      sym_character_content,
    STATE(20432), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16988), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(16992), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [636799] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17377), 1,
      anon_sym_LPAREN,
    ACTIONS(17379), 1,
      anon_sym_LBRACK,
    ACTIONS(17381), 1,
      anon_sym_LBRACE,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(7417), 1,
      sym_field_path,
    STATE(13420), 1,
      sym_attribute,
    STATE(15908), 1,
      sym_indexing_operator_path,
    STATE(19675), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [636837] = 12,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17002), 1,
      sym_indexing_operator,
    ACTIONS(17491), 1,
      sym__lowercase_identifier,
    ACTIONS(17493), 1,
      anon_sym_LPAREN,
    ACTIONS(17495), 1,
      anon_sym_LBRACK,
    ACTIONS(17497), 1,
      anon_sym_LBRACE,
    STATE(4169), 1,
      sym_field_path,
    STATE(13421), 1,
      sym_attribute,
    STATE(15768), 1,
      sym_indexing_operator_path,
    STATE(20320), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [636875] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    ACTIONS(17499), 1,
      anon_sym_SEMI,
    ACTIONS(17501), 1,
      anon_sym_GT,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(13422), 1,
      sym_attribute,
    STATE(16200), 1,
      aux_sym_object_type_repeat1,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [636910] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17503), 1,
      anon_sym_EQ,
    ACTIONS(17505), 1,
      anon_sym_RPAREN,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    STATE(13423), 1,
      sym_attribute,
    STATE(16655), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [636945] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17509), 1,
      anon_sym_EQ,
    ACTIONS(17511), 1,
      anon_sym_RPAREN,
    STATE(13424), 1,
      sym_attribute,
    STATE(16780), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [636980] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11302), 1,
      anon_sym_LBRACK,
    ACTIONS(11304), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11306), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(17513), 1,
      sym__lowercase_identifier,
    ACTIONS(17515), 1,
      anon_sym_LPAREN,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    STATE(13425), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10296), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [637013] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17519), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(13426), 1,
      sym_attribute,
    STATE(13446), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12236), 5,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_with,
  [637040] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    ACTIONS(17521), 1,
      anon_sym_SEMI,
    ACTIONS(17523), 1,
      anon_sym_GT,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(13427), 1,
      sym_attribute,
    STATE(15674), 1,
      aux_sym_object_type_repeat1,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [637075] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17525), 1,
      anon_sym_EQ,
    ACTIONS(17527), 1,
      anon_sym_RPAREN,
    STATE(13428), 1,
      sym_attribute,
    STATE(16698), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [637110] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17529), 1,
      anon_sym_and,
    STATE(13429), 1,
      sym_attribute,
    STATE(13487), 1,
      aux_sym_module_type_constraint_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12540), 6,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [637135] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17531), 1,
      anon_sym_EQ,
    ACTIONS(17533), 1,
      anon_sym_RPAREN,
    STATE(13430), 1,
      sym_attribute,
    STATE(16644), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [637170] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11282), 1,
      anon_sym_LBRACK,
    ACTIONS(11284), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11286), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17535), 1,
      sym__lowercase_identifier,
    ACTIONS(17537), 1,
      anon_sym_LPAREN,
    STATE(13431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10975), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [637203] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    ACTIONS(17539), 1,
      anon_sym_SEMI,
    ACTIONS(17541), 1,
      anon_sym_GT,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(13432), 1,
      sym_attribute,
    STATE(16010), 1,
      aux_sym_object_type_repeat1,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [637238] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    ACTIONS(17543), 1,
      anon_sym_SEMI,
    ACTIONS(17545), 1,
      anon_sym_GT,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(13433), 1,
      sym_attribute,
    STATE(16131), 1,
      aux_sym_object_type_repeat1,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [637273] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17519), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(13434), 1,
      sym_attribute,
    STATE(13457), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12315), 5,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_with,
  [637300] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11324), 1,
      anon_sym_LBRACK,
    ACTIONS(11326), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11328), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17547), 1,
      sym__lowercase_identifier,
    ACTIONS(17549), 1,
      anon_sym_LPAREN,
    STATE(13435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13694), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [637333] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10734), 1,
      anon_sym_LBRACK,
    ACTIONS(10736), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10738), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17551), 1,
      sym__lowercase_identifier,
    ACTIONS(17553), 1,
      anon_sym_LPAREN,
    STATE(13436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9380), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [637366] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13437), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17555), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [637387] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    ACTIONS(17557), 1,
      anon_sym_SEMI,
    ACTIONS(17559), 1,
      anon_sym_GT,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(13438), 1,
      sym_attribute,
    STATE(15461), 1,
      aux_sym_object_type_repeat1,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [637422] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17529), 1,
      anon_sym_and,
    STATE(13429), 1,
      aux_sym_module_type_constraint_repeat1,
    STATE(13439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12647), 6,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [637447] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9500), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9502), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10932), 1,
      anon_sym_LBRACK,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17561), 1,
      sym__lowercase_identifier,
    ACTIONS(17563), 1,
      anon_sym_LPAREN,
    STATE(13440), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9990), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [637480] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13441), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17565), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [637501] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    ACTIONS(17567), 1,
      anon_sym_SEMI,
    ACTIONS(17569), 1,
      anon_sym_GT,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(13442), 1,
      sym_attribute,
    STATE(15357), 1,
      aux_sym_object_type_repeat1,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [637536] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11372), 1,
      anon_sym_LBRACK,
    ACTIONS(11374), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11376), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17571), 1,
      sym__lowercase_identifier,
    ACTIONS(17573), 1,
      anon_sym_LPAREN,
    STATE(13443), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10675), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [637569] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    ACTIONS(17575), 1,
      anon_sym_SEMI,
    ACTIONS(17577), 1,
      anon_sym_GT,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(13444), 1,
      sym_attribute,
    STATE(16251), 1,
      aux_sym_object_type_repeat1,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [637604] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10684), 1,
      anon_sym_LBRACK,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17579), 1,
      sym__lowercase_identifier,
    ACTIONS(17581), 1,
      anon_sym_LPAREN,
    STATE(13445), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9429), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [637637] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17519), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(13446), 1,
      sym_attribute,
    STATE(13484), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12315), 5,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_with,
  [637664] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17583), 1,
      anon_sym_EQ,
    ACTIONS(17585), 1,
      anon_sym_RPAREN,
    STATE(13447), 1,
      sym_attribute,
    STATE(16821), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [637699] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    ACTIONS(17587), 1,
      anon_sym_SEMI,
    ACTIONS(17589), 1,
      anon_sym_GT,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(13448), 1,
      sym_attribute,
    STATE(16303), 1,
      aux_sym_object_type_repeat1,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [637734] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17591), 1,
      sym__lowercase_identifier,
    ACTIONS(17593), 1,
      anon_sym_LPAREN,
    STATE(13449), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12232), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [637767] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17595), 1,
      anon_sym_EQ,
    ACTIONS(17597), 1,
      anon_sym_RPAREN,
    STATE(13450), 1,
      sym_attribute,
    STATE(16744), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [637802] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7996), 1,
      anon_sym_POUND,
    STATE(13451), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 3,
      anon_sym_DOT,
      anon_sym_with,
      sym_hash_operator,
    ACTIONS(7917), 4,
      anon_sym_EQ,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [637827] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    ACTIONS(17599), 1,
      anon_sym_SEMI,
    ACTIONS(17601), 1,
      anon_sym_GT,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(13452), 1,
      sym_attribute,
    STATE(16174), 1,
      aux_sym_object_type_repeat1,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [637862] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10910), 1,
      anon_sym_LBRACK,
    ACTIONS(10912), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10914), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17603), 1,
      sym__lowercase_identifier,
    ACTIONS(17605), 1,
      anon_sym_LPAREN,
    STATE(13453), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9059), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [637895] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9908), 1,
      anon_sym_LBRACK,
    ACTIONS(9910), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9912), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17607), 1,
      sym__lowercase_identifier,
    ACTIONS(17609), 1,
      anon_sym_LPAREN,
    STATE(13454), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11136), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [637928] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17593), 1,
      anon_sym_LPAREN,
    ACTIONS(17611), 1,
      sym__lowercase_identifier,
    STATE(13455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12232), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [637961] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    ACTIONS(17613), 1,
      anon_sym_SEMI,
    ACTIONS(17615), 1,
      anon_sym_GT,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(13456), 1,
      sym_attribute,
    STATE(16414), 1,
      aux_sym_object_type_repeat1,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [637996] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17519), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    STATE(13457), 1,
      sym_attribute,
    STATE(13484), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12329), 5,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_with,
  [638023] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17623), 1,
      sym__right_quoted_string_delimiter,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17620), 2,
      sym__null,
      aux_sym_string_content_token2,
    STATE(13458), 2,
      sym_attribute,
      aux_sym_quoted_string_content_repeat1,
    ACTIONS(17617), 4,
      aux_sym_string_content_token1,
      aux_sym_quoted_string_content_token1,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [638048] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17593), 1,
      anon_sym_LPAREN,
    ACTIONS(17625), 1,
      sym__lowercase_identifier,
    STATE(13459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12232), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [638081] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    ACTIONS(17627), 1,
      anon_sym_SEMI,
    ACTIONS(17629), 1,
      anon_sym_GT,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(13460), 1,
      sym_attribute,
    STATE(15614), 1,
      aux_sym_object_type_repeat1,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [638116] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    ACTIONS(17631), 1,
      anon_sym_SEMI,
    ACTIONS(17633), 1,
      anon_sym_GT,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(13461), 1,
      sym_attribute,
    STATE(15822), 1,
      aux_sym_object_type_repeat1,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [638151] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    ACTIONS(17635), 1,
      anon_sym_SEMI,
    ACTIONS(17637), 1,
      anon_sym_GT,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(13462), 1,
      sym_attribute,
    STATE(15849), 1,
      aux_sym_object_type_repeat1,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [638186] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10778), 1,
      anon_sym_LBRACK,
    ACTIONS(10780), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10782), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17639), 1,
      sym__lowercase_identifier,
    ACTIONS(17641), 1,
      anon_sym_LPAREN,
    STATE(13463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13167), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [638219] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17643), 1,
      anon_sym_STAR,
    STATE(13464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10391), 7,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
  [638242] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    ACTIONS(17645), 1,
      anon_sym_SEMI,
    ACTIONS(17647), 1,
      anon_sym_GT,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(13465), 1,
      sym_attribute,
    STATE(16261), 1,
      aux_sym_object_type_repeat1,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [638277] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17593), 1,
      anon_sym_LPAREN,
    ACTIONS(17649), 1,
      sym__lowercase_identifier,
    STATE(13466), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12232), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [638310] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9424), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10696), 1,
      anon_sym_LBRACK,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17651), 1,
      sym__lowercase_identifier,
    ACTIONS(17653), 1,
      anon_sym_LPAREN,
    STATE(13467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9838), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [638343] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    ACTIONS(17655), 1,
      anon_sym_SEMI,
    ACTIONS(17657), 1,
      anon_sym_GT,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(13468), 1,
      sym_attribute,
    STATE(15156), 1,
      aux_sym_object_type_repeat1,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [638378] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11356), 1,
      anon_sym_LBRACK,
    ACTIONS(11358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17659), 1,
      sym__lowercase_identifier,
    ACTIONS(17661), 1,
      anon_sym_LPAREN,
    STATE(13469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10259), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [638411] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9468), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9470), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10724), 1,
      anon_sym_LBRACK,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17663), 1,
      sym__lowercase_identifier,
    ACTIONS(17665), 1,
      anon_sym_LPAREN,
    STATE(13470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9447), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [638444] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17667), 1,
      sym__right_quoted_string_delimiter,
    STATE(13458), 1,
      aux_sym_quoted_string_content_repeat1,
    STATE(13471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17072), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(17070), 4,
      aux_sym_string_content_token1,
      aux_sym_quoted_string_content_token1,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [638471] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17593), 1,
      anon_sym_LPAREN,
    ACTIONS(17669), 1,
      sym__lowercase_identifier,
    STATE(13472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12232), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [638504] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10136), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10140), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17671), 1,
      sym__lowercase_identifier,
    ACTIONS(17673), 1,
      anon_sym_LPAREN,
    STATE(13473), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10831), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [638537] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7873), 1,
      anon_sym_LBRACK,
    ACTIONS(7887), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7889), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17593), 1,
      anon_sym_LPAREN,
    ACTIONS(17675), 1,
      sym__lowercase_identifier,
    STATE(13474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12232), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [638570] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    ACTIONS(17677), 1,
      anon_sym_SEMI,
    ACTIONS(17679), 1,
      anon_sym_GT,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(13475), 1,
      sym_attribute,
    STATE(15830), 1,
      aux_sym_object_type_repeat1,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [638605] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9994), 1,
      anon_sym_LBRACK,
    ACTIONS(9996), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9998), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17681), 1,
      sym__lowercase_identifier,
    ACTIONS(17683), 1,
      anon_sym_LPAREN,
    STATE(13476), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11790), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [638638] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7996), 1,
      anon_sym_POUND,
    STATE(13477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 3,
      anon_sym_DOT,
      anon_sym_with,
      sym_hash_operator,
    ACTIONS(7909), 4,
      anon_sym_EQ,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [638663] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10026), 1,
      anon_sym_LBRACK,
    ACTIONS(10028), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10030), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17685), 1,
      sym__lowercase_identifier,
    ACTIONS(17687), 1,
      anon_sym_LPAREN,
    STATE(13478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12647), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [638696] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    ACTIONS(17689), 1,
      anon_sym_SEMI,
    ACTIONS(17691), 1,
      anon_sym_GT,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(13479), 1,
      sym_attribute,
    STATE(15522), 1,
      aux_sym_object_type_repeat1,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [638731] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    ACTIONS(17693), 1,
      anon_sym_SEMI,
    ACTIONS(17695), 1,
      anon_sym_GT,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(13480), 1,
      sym_attribute,
    STATE(15852), 1,
      aux_sym_object_type_repeat1,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [638766] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7915), 1,
      anon_sym_POUND,
    STATE(13481), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 7,
      anon_sym_EQ,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_with,
      sym_hash_operator,
  [638789] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7907), 1,
      anon_sym_POUND,
    STATE(13482), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7909), 7,
      anon_sym_EQ,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_with,
      sym_hash_operator,
  [638812] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    ACTIONS(17697), 1,
      anon_sym_SEMI,
    ACTIONS(17699), 1,
      anon_sym_GT,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(13483), 1,
      sym_attribute,
    STATE(16089), 1,
      aux_sym_object_type_repeat1,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [638847] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17701), 1,
      anon_sym_constraint,
    STATE(9155), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13484), 2,
      sym_attribute,
      aux_sym_type_binding_repeat1,
    ACTIONS(12282), 5,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_with,
  [638872] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    ACTIONS(17704), 1,
      anon_sym_SEMI,
    ACTIONS(17706), 1,
      anon_sym_GT,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(13485), 1,
      sym_attribute,
    STATE(16112), 1,
      aux_sym_object_type_repeat1,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [638907] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    ACTIONS(17708), 1,
      anon_sym_SEMI,
    ACTIONS(17710), 1,
      anon_sym_GT,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(13486), 1,
      sym_attribute,
    STATE(15998), 1,
      aux_sym_object_type_repeat1,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [638942] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17712), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13487), 2,
      sym_attribute,
      aux_sym_module_type_constraint_repeat1,
    ACTIONS(11936), 6,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [638965] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10888), 1,
      anon_sym_LBRACK,
    ACTIONS(10890), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10892), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17715), 1,
      sym__lowercase_identifier,
    ACTIONS(17717), 1,
      anon_sym_LPAREN,
    STATE(13488), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9557), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [638998] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11616), 8,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [639019] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10809), 1,
      anon_sym_LBRACK,
    ACTIONS(10811), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10813), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17719), 1,
      sym__lowercase_identifier,
    ACTIONS(17721), 1,
      anon_sym_LPAREN,
    STATE(13490), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12857), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [639052] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12087), 1,
      anon_sym_in,
    ACTIONS(16931), 1,
      sym__lowercase_identifier,
    ACTIONS(16933), 1,
      anon_sym_POUND,
    STATE(13491), 1,
      sym_attribute,
    STATE(13620), 1,
      sym_type_constructor_path,
    STATE(17229), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12085), 2,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT,
  [639085] = 11,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    ACTIONS(17723), 1,
      anon_sym_SEMI,
    ACTIONS(17725), 1,
      anon_sym_GT,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(13492), 1,
      sym_attribute,
    STATE(16415), 1,
      aux_sym_object_type_repeat1,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [639120] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11230), 1,
      anon_sym_LBRACK,
    ACTIONS(11232), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11234), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17727), 1,
      sym__lowercase_identifier,
    ACTIONS(17729), 1,
      anon_sym_LPAREN,
    STATE(13493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10839), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [639153] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10704), 1,
      anon_sym_LBRACK,
    ACTIONS(10706), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10708), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17731), 1,
      sym__lowercase_identifier,
    ACTIONS(17733), 1,
      anon_sym_LPAREN,
    STATE(13494), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9235), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [639186] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11214), 1,
      anon_sym_LBRACK,
    ACTIONS(11216), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11218), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17735), 1,
      sym__lowercase_identifier,
    ACTIONS(17737), 1,
      anon_sym_LPAREN,
    STATE(13495), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10924), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [639219] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17739), 1,
      anon_sym_COMMA,
    ACTIONS(17741), 1,
      anon_sym_PIPE,
    ACTIONS(17743), 1,
      anon_sym_RBRACK,
    ACTIONS(17745), 1,
      anon_sym_SEMI,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(17749), 1,
      anon_sym_COLON_COLON,
    STATE(13496), 1,
      sym_attribute,
    STATE(15763), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [639251] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(17751), 1,
      anon_sym_DASH_GT,
    STATE(13497), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12467), 5,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_constraint,
      anon_sym_with,
  [639275] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17753), 1,
      anon_sym_RPAREN,
    STATE(13498), 1,
      sym_attribute,
    STATE(18144), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [639307] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(17755), 1,
      anon_sym_rec,
    ACTIONS(17757), 1,
      anon_sym_type,
    STATE(12554), 1,
      sym_module_binding,
    STATE(13499), 1,
      sym_attribute,
    STATE(14468), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17759), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [639337] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13500), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11965), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [639357] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17761), 1,
      anon_sym_DASH_GT,
    ACTIONS(17763), 1,
      anon_sym_with,
    STATE(13501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13340), 5,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [639381] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(17767), 1,
      anon_sym__,
    ACTIONS(17769), 1,
      anon_sym_RBRACE,
    STATE(13502), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(16623), 1,
      sym_field_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [639413] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17771), 1,
      anon_sym_RPAREN,
    STATE(13503), 1,
      sym_attribute,
    STATE(18891), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [639445] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17773), 1,
      anon_sym_RPAREN,
    STATE(13504), 1,
      sym_attribute,
    STATE(19150), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [639477] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17775), 1,
      anon_sym_COMMA,
    ACTIONS(17777), 1,
      anon_sym_PIPE,
    ACTIONS(17779), 1,
      anon_sym_SEMI,
    ACTIONS(17781), 1,
      anon_sym_as,
    ACTIONS(17783), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17785), 1,
      anon_sym_PIPE_RBRACK,
    STATE(13505), 1,
      sym_attribute,
    STATE(15972), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [639509] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11676), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11678), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [639531] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17787), 1,
      anon_sym_RPAREN,
    STATE(13507), 1,
      sym_attribute,
    STATE(17616), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [639563] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8294), 1,
      anon_sym_PIPE,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(13508), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [639587] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12091), 1,
      anon_sym_COLON2,
    STATE(13509), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12089), 6,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [639609] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(17789), 1,
      anon_sym__,
    ACTIONS(17791), 1,
      anon_sym_RBRACE,
    STATE(13510), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(16623), 1,
      sym_field_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [639641] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(17793), 1,
      anon_sym__,
    ACTIONS(17795), 1,
      anon_sym_RBRACE,
    STATE(13511), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(16626), 1,
      sym_field_binding_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [639673] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(17797), 1,
      sym__lowercase_identifier,
    ACTIONS(17799), 1,
      anon_sym_type,
    ACTIONS(17801), 1,
      anon_sym_LBRACK,
    ACTIONS(17803), 1,
      anon_sym_virtual,
    STATE(12777), 1,
      sym_class_binding,
    STATE(13512), 1,
      sym_attribute,
    STATE(14495), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [639705] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(17805), 1,
      anon_sym__,
    ACTIONS(17807), 1,
      anon_sym_RBRACE,
    STATE(13513), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(16623), 1,
      sym_field_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [639737] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17809), 1,
      anon_sym_DASH_GT,
    ACTIONS(17811), 1,
      anon_sym_when,
    STATE(13514), 1,
      sym_attribute,
    STATE(17597), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [639769] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17813), 1,
      anon_sym_RPAREN,
    STATE(13515), 1,
      sym_attribute,
    STATE(18632), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [639801] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16457), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(13516), 1,
      sym_attribute,
    STATE(14372), 1,
      aux_sym_expression_item_repeat1,
    STATE(15602), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11861), 2,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(16607), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [639829] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8294), 1,
      anon_sym_PIPE,
    ACTIONS(8324), 1,
      anon_sym_DOT,
    STATE(13517), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [639853] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(17815), 1,
      anon_sym__,
    ACTIONS(17817), 1,
      anon_sym_RBRACE,
    STATE(13518), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(16626), 1,
      sym_field_binding_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [639885] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(17819), 1,
      anon_sym__,
    STATE(13519), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(16103), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [639915] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17821), 1,
      anon_sym_RPAREN,
    STATE(13520), 1,
      sym_attribute,
    STATE(18626), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [639947] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17823), 1,
      anon_sym_RPAREN,
    STATE(13521), 1,
      sym_attribute,
    STATE(17610), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [639979] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13522), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11258), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [639999] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17751), 1,
      anon_sym_DASH_GT,
    STATE(13523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12509), 6,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
  [640021] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(17825), 1,
      anon_sym__,
    ACTIONS(17827), 1,
      anon_sym_RBRACE,
    STATE(13524), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(16626), 1,
      sym_field_binding_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [640053] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17829), 1,
      anon_sym_RPAREN,
    ACTIONS(17831), 1,
      anon_sym_COMMA,
    ACTIONS(17833), 1,
      anon_sym_PIPE,
    ACTIONS(17835), 1,
      anon_sym_as,
    ACTIONS(17837), 1,
      anon_sym_COLON_COLON,
    STATE(13525), 1,
      sym_attribute,
    STATE(19445), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [640085] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(17839), 1,
      anon_sym_DASH_GT,
    STATE(13526), 1,
      sym_attribute,
    STATE(18597), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [640117] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17775), 1,
      anon_sym_COMMA,
    ACTIONS(17777), 1,
      anon_sym_PIPE,
    ACTIONS(17781), 1,
      anon_sym_as,
    ACTIONS(17783), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17841), 1,
      anon_sym_SEMI,
    ACTIONS(17843), 1,
      anon_sym_PIPE_RBRACK,
    STATE(13527), 1,
      sym_attribute,
    STATE(16413), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [640149] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17845), 1,
      anon_sym_COMMA,
    ACTIONS(17847), 1,
      anon_sym_PIPE,
    ACTIONS(17849), 1,
      anon_sym_SEMI,
    ACTIONS(17851), 1,
      anon_sym_as,
    ACTIONS(17853), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17855), 1,
      anon_sym_PIPE_RBRACK,
    STATE(13528), 1,
      sym_attribute,
    STATE(15758), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [640181] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17739), 1,
      anon_sym_COMMA,
    ACTIONS(17741), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(17749), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17857), 1,
      anon_sym_RBRACK,
    ACTIONS(17859), 1,
      anon_sym_SEMI,
    STATE(13529), 1,
      sym_attribute,
    STATE(16334), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [640213] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(17861), 1,
      anon_sym_DASH_GT,
    STATE(13530), 1,
      sym_attribute,
    STATE(19145), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [640245] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(17863), 1,
      anon_sym__,
    ACTIONS(17865), 1,
      anon_sym_RBRACE,
    STATE(13531), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(16623), 1,
      sym_field_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [640277] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(17867), 1,
      anon_sym_DASH_GT,
    STATE(13532), 1,
      sym_attribute,
    STATE(18867), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [640309] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17831), 1,
      anon_sym_COMMA,
    ACTIONS(17833), 1,
      anon_sym_PIPE,
    ACTIONS(17835), 1,
      anon_sym_as,
    ACTIONS(17837), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17869), 1,
      anon_sym_RPAREN,
    STATE(13533), 1,
      sym_attribute,
    STATE(19927), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [640341] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17845), 1,
      anon_sym_COMMA,
    ACTIONS(17847), 1,
      anon_sym_PIPE,
    ACTIONS(17851), 1,
      anon_sym_as,
    ACTIONS(17853), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17871), 1,
      anon_sym_SEMI,
    ACTIONS(17873), 1,
      anon_sym_PIPE_RBRACK,
    STATE(13534), 1,
      sym_attribute,
    STATE(16350), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [640373] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(17875), 1,
      anon_sym_COMMA,
    ACTIONS(17877), 1,
      anon_sym_PIPE,
    ACTIONS(17879), 1,
      anon_sym_RBRACK,
    ACTIONS(17881), 1,
      anon_sym_SEMI,
    ACTIONS(17883), 1,
      anon_sym_COLON_COLON,
    STATE(13535), 1,
      sym_attribute,
    STATE(16362), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [640405] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17505), 1,
      anon_sym_RPAREN,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    STATE(13536), 1,
      sym_attribute,
    STATE(19928), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [640437] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(17819), 1,
      anon_sym__,
    STATE(13537), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(16123), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [640467] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17885), 1,
      anon_sym_RPAREN,
    STATE(13538), 1,
      sym_attribute,
    STATE(18896), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [640499] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(17887), 1,
      anon_sym__,
    ACTIONS(17889), 1,
      anon_sym_RBRACE,
    STATE(13539), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(16623), 1,
      sym_field_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [640531] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13540), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11878), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [640551] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17511), 1,
      anon_sym_RPAREN,
    STATE(13541), 1,
      sym_attribute,
    STATE(19446), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [640583] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(17819), 1,
      anon_sym__,
    STATE(13542), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(15926), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [640613] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(17891), 1,
      anon_sym__,
    ACTIONS(17893), 1,
      anon_sym_RBRACE,
    STATE(13543), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(16626), 1,
      sym_field_binding_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [640645] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17895), 1,
      anon_sym_RPAREN,
    STATE(13544), 1,
      sym_attribute,
    STATE(17659), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [640677] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(17897), 1,
      anon_sym_DASH_GT,
    STATE(13545), 1,
      sym_attribute,
    STATE(17638), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [640709] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(17899), 1,
      anon_sym_DASH_GT,
    STATE(13546), 1,
      sym_attribute,
    STATE(18085), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [640741] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17901), 1,
      anon_sym_RPAREN,
    STATE(13547), 1,
      sym_attribute,
    STATE(18151), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [640773] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17903), 1,
      anon_sym_RPAREN,
    STATE(13548), 1,
      sym_attribute,
    STATE(19169), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [640805] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12176), 1,
      anon_sym_COLON2,
    STATE(13549), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12174), 6,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [640827] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17905), 1,
      anon_sym_RPAREN,
    STATE(13550), 1,
      sym_attribute,
    STATE(18593), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [640859] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(17180), 1,
      anon_sym_LPAREN,
    ACTIONS(17182), 1,
      anon_sym_LBRACK,
    STATE(10820), 1,
      sym_constructor_declaration,
    STATE(11968), 1,
      sym__constructor_name,
    STATE(13551), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17184), 2,
      anon_sym_true,
      anon_sym_false,
  [640889] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17907), 1,
      anon_sym_RPAREN,
    STATE(13552), 1,
      sym_attribute,
    STATE(18587), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [640921] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(17819), 1,
      anon_sym__,
    STATE(13553), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(16182), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [640951] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(17909), 1,
      anon_sym__,
    ACTIONS(17911), 1,
      anon_sym_RBRACE,
    STATE(13554), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(16626), 1,
      sym_field_binding_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [640983] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17913), 1,
      anon_sym_RPAREN,
    STATE(13555), 1,
      sym_attribute,
    STATE(18098), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [641015] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17915), 1,
      anon_sym_RPAREN,
    STATE(13556), 1,
      sym_attribute,
    STATE(17666), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [641047] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(17917), 1,
      anon_sym__,
    ACTIONS(17919), 1,
      anon_sym_RBRACE,
    STATE(13557), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(16623), 1,
      sym_field_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [641079] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17421), 1,
      anon_sym_LPAREN,
    ACTIONS(17423), 1,
      anon_sym_LBRACK,
    ACTIONS(17427), 1,
      sym__uppercase_identifier,
    STATE(13558), 1,
      sym_attribute,
    STATE(14305), 1,
      sym__constructor_name,
    STATE(14610), 1,
      sym_constructor_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17425), 2,
      anon_sym_true,
      anon_sym_false,
  [641109] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17921), 1,
      anon_sym_RPAREN,
    STATE(13559), 1,
      sym_attribute,
    STATE(18665), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [641141] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17923), 1,
      anon_sym_RPAREN,
    STATE(13560), 1,
      sym_attribute,
    STATE(18779), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [641173] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(17925), 1,
      anon_sym_DASH_GT,
    STATE(13561), 1,
      sym_attribute,
    STATE(20376), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [641205] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12180), 1,
      anon_sym_COLON2,
    STATE(13562), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12178), 6,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [641227] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(17927), 1,
      anon_sym_DASH_GT,
    STATE(13563), 1,
      sym_attribute,
    STATE(17789), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [641259] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13564), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11560), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11562), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [641281] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(17819), 1,
      anon_sym__,
    STATE(13565), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(16026), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [641311] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12077), 1,
      anon_sym_LPAREN,
    ACTIONS(12079), 1,
      anon_sym_LBRACK,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    STATE(10650), 1,
      sym__constructor_name,
    STATE(10677), 1,
      sym_constructor_declaration,
    STATE(13566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12081), 2,
      anon_sym_true,
      anon_sym_false,
  [641341] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(17929), 1,
      anon_sym_DASH_GT,
    STATE(13567), 1,
      sym_attribute,
    STATE(19299), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [641373] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(17931), 1,
      anon_sym_rec,
    ACTIONS(17933), 1,
      anon_sym_type,
    STATE(12755), 1,
      sym_module_binding,
    STATE(13568), 1,
      sym_attribute,
    STATE(14716), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17935), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [641403] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17937), 1,
      anon_sym_RPAREN,
    STATE(13569), 1,
      sym_attribute,
    STATE(17762), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [641435] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(17939), 1,
      anon_sym_DASH_GT,
    STATE(13570), 1,
      sym_attribute,
    STATE(19939), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [641467] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17749), 1,
      anon_sym_COLON_COLON,
    STATE(13571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9268), 6,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
  [641489] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11588), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11590), 1,
      anon_sym_in,
    ACTIONS(16931), 1,
      sym__lowercase_identifier,
    ACTIONS(16933), 1,
      anon_sym_POUND,
    STATE(13572), 1,
      sym_attribute,
    STATE(13620), 1,
      sym_type_constructor_path,
    STATE(17229), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [641521] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17941), 1,
      anon_sym_RPAREN,
    STATE(13573), 1,
      sym_attribute,
    STATE(17785), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [641553] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17739), 1,
      anon_sym_COMMA,
    ACTIONS(17749), 1,
      anon_sym_COLON_COLON,
    STATE(13574), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9196), 5,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
  [641577] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11500), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11502), 1,
      anon_sym_in,
    ACTIONS(16931), 1,
      sym__lowercase_identifier,
    ACTIONS(16933), 1,
      anon_sym_POUND,
    STATE(13575), 1,
      sym_attribute,
    STATE(13620), 1,
      sym_type_constructor_path,
    STATE(17229), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [641609] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17943), 1,
      anon_sym_RPAREN,
    STATE(13576), 1,
      sym_attribute,
    STATE(18928), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [641641] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13577), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11576), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11578), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [641663] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(17751), 1,
      anon_sym_DASH_GT,
    STATE(13578), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12426), 5,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_constraint,
      anon_sym_with,
  [641687] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(17799), 1,
      anon_sym_type,
    ACTIONS(17945), 1,
      sym__lowercase_identifier,
    ACTIONS(17947), 1,
      anon_sym_LBRACK,
    ACTIONS(17949), 1,
      anon_sym_virtual,
    STATE(12010), 1,
      sym_class_binding,
    STATE(13579), 1,
      sym_attribute,
    STATE(14439), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [641719] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13580), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11538), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11540), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [641741] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(13581), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(16056), 1,
      sym_field_binding_pattern,
    STATE(18618), 1,
      sym__quoted_string,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [641773] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12432), 1,
      anon_sym_as,
    ACTIONS(17751), 1,
      anon_sym_DASH_GT,
    STATE(13582), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12436), 5,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_constraint,
      anon_sym_with,
  [641797] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(13583), 1,
      sym_attribute,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12085), 2,
      anon_sym_DASH_GT,
      anon_sym_STAR,
  [641827] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(17799), 1,
      anon_sym_type,
    ACTIONS(17951), 1,
      sym__lowercase_identifier,
    ACTIONS(17953), 1,
      anon_sym_LBRACK,
    ACTIONS(17955), 1,
      anon_sym_virtual,
    STATE(12127), 1,
      sym_class_binding,
    STATE(13584), 1,
      sym_attribute,
    STATE(14958), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [641859] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17749), 1,
      anon_sym_COLON_COLON,
    STATE(13585), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9284), 6,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
  [641881] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(17957), 1,
      anon_sym__,
    ACTIONS(17959), 1,
      anon_sym_RBRACE,
    STATE(13586), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(16623), 1,
      sym_field_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [641913] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17961), 1,
      anon_sym_RPAREN,
    STATE(13587), 1,
      sym_attribute,
    STATE(17713), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [641945] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17963), 1,
      anon_sym_RPAREN,
    STATE(13588), 1,
      sym_attribute,
    STATE(18091), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [641977] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17965), 1,
      anon_sym_RPAREN,
    STATE(13589), 1,
      sym_attribute,
    STATE(18553), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [642009] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11720), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11722), 1,
      anon_sym_in,
    ACTIONS(16931), 1,
      sym__lowercase_identifier,
    ACTIONS(16933), 1,
      anon_sym_POUND,
    STATE(13590), 1,
      sym_attribute,
    STATE(13620), 1,
      sym_type_constructor_path,
    STATE(17229), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [642041] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17967), 1,
      anon_sym_RPAREN,
    STATE(13591), 1,
      sym_attribute,
    STATE(18547), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [642073] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17969), 1,
      anon_sym_RPAREN,
    STATE(13592), 1,
      sym_attribute,
    STATE(18671), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [642105] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(17329), 1,
      anon_sym_LPAREN,
    ACTIONS(17331), 1,
      anon_sym_LBRACK,
    STATE(10820), 1,
      sym_constructor_declaration,
    STATE(11999), 1,
      sym__constructor_name,
    STATE(13593), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17333), 2,
      anon_sym_true,
      anon_sym_false,
  [642135] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13594), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11936), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [642155] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(17971), 1,
      anon_sym_DASH_GT,
    STATE(13595), 1,
      sym_attribute,
    STATE(17693), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [642187] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(13596), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(16045), 1,
      sym_field_pattern,
    STATE(18445), 1,
      sym__quoted_string,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [642219] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(17973), 1,
      anon_sym_DASH_GT,
    STATE(13597), 1,
      sym_attribute,
    STATE(18508), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [642251] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13598), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11388), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [642271] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12351), 1,
      anon_sym_LPAREN,
    ACTIONS(12353), 1,
      anon_sym_LBRACK,
    STATE(10677), 1,
      sym_constructor_declaration,
    STATE(10915), 1,
      sym__constructor_name,
    STATE(13599), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12355), 2,
      anon_sym_true,
      anon_sym_false,
  [642301] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(17975), 1,
      anon_sym_DASH_GT,
    STATE(13600), 1,
      sym_attribute,
    STATE(17931), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [642333] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11436), 1,
      anon_sym_RPAREN,
    ACTIONS(17977), 1,
      anon_sym_COLON2,
    STATE(13601), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [642357] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12278), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12280), 1,
      anon_sym_in,
    ACTIONS(16931), 1,
      sym__lowercase_identifier,
    ACTIONS(16933), 1,
      anon_sym_POUND,
    STATE(13602), 1,
      sym_attribute,
    STATE(13620), 1,
      sym_type_constructor_path,
    STATE(17229), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [642389] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17979), 1,
      anon_sym_RPAREN,
    STATE(13603), 1,
      sym_attribute,
    STATE(18187), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [642421] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9108), 1,
      anon_sym_PIPE,
    STATE(13604), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9110), 6,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [642443] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11534), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11536), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [642465] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(17981), 1,
      anon_sym_DASH_GT,
    STATE(13606), 1,
      sym_attribute,
    STATE(18159), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [642497] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7153), 1,
      anon_sym_PIPE,
    ACTIONS(17983), 1,
      anon_sym_DOT_DOT,
    STATE(13607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7149), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [642521] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17985), 1,
      anon_sym_RPAREN,
    STATE(13608), 1,
      sym_attribute,
    STATE(17720), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [642553] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12303), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12305), 1,
      anon_sym_in,
    ACTIONS(16931), 1,
      sym__lowercase_identifier,
    ACTIONS(16933), 1,
      anon_sym_POUND,
    STATE(13609), 1,
      sym_attribute,
    STATE(13620), 1,
      sym_type_constructor_path,
    STATE(17229), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [642585] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12242), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12244), 1,
      anon_sym_in,
    ACTIONS(16931), 1,
      sym__lowercase_identifier,
    ACTIONS(16933), 1,
      anon_sym_POUND,
    STATE(13610), 1,
      sym_attribute,
    STATE(13620), 1,
      sym_type_constructor_path,
    STATE(17229), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [642617] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(17987), 1,
      anon_sym__,
    ACTIONS(17989), 1,
      anon_sym_RBRACE,
    STATE(13611), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(16623), 1,
      sym_field_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [642649] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(17991), 1,
      anon_sym__,
    ACTIONS(17993), 1,
      anon_sym_RBRACE,
    STATE(13612), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(16623), 1,
      sym_field_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [642681] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(17995), 1,
      anon_sym__,
    ACTIONS(17997), 1,
      anon_sym_RBRACE,
    STATE(13613), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(16626), 1,
      sym_field_binding_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [642713] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(17999), 1,
      anon_sym_rec,
    ACTIONS(18001), 1,
      anon_sym_type,
    STATE(12030), 1,
      sym_module_binding,
    STATE(13614), 1,
      sym_attribute,
    STATE(14842), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18003), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [642743] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18005), 1,
      anon_sym_RPAREN,
    STATE(13615), 1,
      sym_attribute,
    STATE(18513), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [642775] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(18007), 1,
      anon_sym__,
    ACTIONS(18009), 1,
      anon_sym_RBRACE,
    STATE(13616), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(16623), 1,
      sym_field_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [642807] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(13617), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(15191), 1,
      sym_field_pattern,
    STATE(18181), 1,
      sym__quoted_string,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [642839] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18011), 1,
      anon_sym_RPAREN,
    STATE(13618), 1,
      sym_attribute,
    STATE(18859), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [642871] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(13619), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(15111), 1,
      sym_field_binding_pattern,
    STATE(18271), 1,
      sym__quoted_string,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [642903] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13620), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11638), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11640), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [642925] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17845), 1,
      anon_sym_COMMA,
    ACTIONS(17847), 1,
      anon_sym_PIPE,
    ACTIONS(17851), 1,
      anon_sym_as,
    ACTIONS(17853), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18013), 1,
      anon_sym_SEMI,
    ACTIONS(18015), 1,
      anon_sym_PIPE_RBRACK,
    STATE(13621), 1,
      sym_attribute,
    STATE(16387), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [642957] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18017), 1,
      anon_sym_RPAREN,
    STATE(13622), 1,
      sym_attribute,
    STATE(18193), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [642989] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12357), 1,
      anon_sym_LPAREN,
    ACTIONS(12359), 1,
      anon_sym_LBRACK,
    STATE(10677), 1,
      sym_constructor_declaration,
    STATE(10928), 1,
      sym__constructor_name,
    STATE(13623), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12361), 2,
      anon_sym_true,
      anon_sym_false,
  [643019] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(17875), 1,
      anon_sym_COMMA,
    ACTIONS(17877), 1,
      anon_sym_PIPE,
    ACTIONS(17883), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18019), 1,
      anon_sym_RBRACK,
    ACTIONS(18021), 1,
      anon_sym_SEMI,
    STATE(13624), 1,
      sym_attribute,
    STATE(16383), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [643051] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17585), 1,
      anon_sym_RPAREN,
    STATE(13625), 1,
      sym_attribute,
    STATE(19364), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [643083] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(18023), 1,
      anon_sym__,
    ACTIONS(18025), 1,
      anon_sym_RBRACE,
    STATE(13626), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(16626), 1,
      sym_field_binding_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [643115] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(18027), 1,
      anon_sym__,
    ACTIONS(18029), 1,
      anon_sym_RBRACE,
    STATE(13627), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(16626), 1,
      sym_field_binding_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [643147] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18031), 1,
      anon_sym_RPAREN,
    STATE(13628), 1,
      sym_attribute,
    STATE(18507), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [643179] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(18033), 1,
      anon_sym__,
    ACTIONS(18035), 1,
      anon_sym_RBRACE,
    STATE(13629), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(16626), 1,
      sym_field_binding_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [643211] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18037), 1,
      anon_sym_rec,
    ACTIONS(18039), 1,
      anon_sym_type,
    STATE(12049), 1,
      sym_module_binding,
    STATE(13630), 1,
      sym_attribute,
    STATE(14960), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18041), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [643241] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18043), 1,
      anon_sym_RPAREN,
    STATE(13631), 1,
      sym_attribute,
    STATE(20496), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [643273] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18045), 1,
      anon_sym_RPAREN,
    STATE(13632), 1,
      sym_attribute,
    STATE(17977), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [643305] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18051), 1,
      anon_sym_AMP,
    STATE(13633), 1,
      sym_attribute,
    STATE(14265), 1,
      aux_sym_tag_specification_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18047), 3,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_GT,
  [643333] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(18053), 1,
      anon_sym_DASH_GT,
    STATE(13634), 1,
      sym_attribute,
    STATE(19456), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [643365] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18055), 1,
      anon_sym_RPAREN,
    STATE(13635), 1,
      sym_attribute,
    STATE(18933), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [643397] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18057), 1,
      anon_sym_RPAREN,
    STATE(13636), 1,
      sym_attribute,
    STATE(20199), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [643429] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17875), 1,
      anon_sym_COMMA,
    ACTIONS(17883), 1,
      anon_sym_COLON_COLON,
    STATE(13637), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16978), 5,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
  [643453] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17883), 1,
      anon_sym_COLON_COLON,
    STATE(13638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16969), 6,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
  [643475] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17883), 1,
      anon_sym_COLON_COLON,
    STATE(13639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16963), 6,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
  [643497] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18059), 1,
      anon_sym_RPAREN,
    STATE(13640), 1,
      sym_attribute,
    STATE(17767), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [643529] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(18061), 1,
      anon_sym_DASH_GT,
    STATE(13641), 1,
      sym_attribute,
    STATE(20031), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [643561] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18063), 1,
      anon_sym_RPAREN,
    STATE(13642), 1,
      sym_attribute,
    STATE(18993), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [643593] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18065), 1,
      anon_sym_RPAREN,
    STATE(13643), 1,
      sym_attribute,
    STATE(17996), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [643625] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(17875), 1,
      anon_sym_COMMA,
    ACTIONS(17877), 1,
      anon_sym_PIPE,
    ACTIONS(17883), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18067), 1,
      anon_sym_RBRACK,
    ACTIONS(18069), 1,
      anon_sym_SEMI,
    STATE(13644), 1,
      sym_attribute,
    STATE(15753), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [643657] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(17056), 1,
      anon_sym_LPAREN,
    ACTIONS(17058), 1,
      anon_sym_LBRACK,
    STATE(10820), 1,
      sym_constructor_declaration,
    STATE(11674), 1,
      sym__constructor_name,
    STATE(13645), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17060), 2,
      anon_sym_true,
      anon_sym_false,
  [643687] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(18071), 1,
      anon_sym__,
    ACTIONS(18073), 1,
      anon_sym_RBRACE,
    STATE(13646), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(16626), 1,
      sym_field_binding_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [643719] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18075), 1,
      anon_sym_RPAREN,
    STATE(13647), 1,
      sym_attribute,
    STATE(18900), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [643751] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18077), 1,
      anon_sym_RPAREN,
    STATE(13648), 1,
      sym_attribute,
    STATE(18854), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [643783] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18079), 1,
      anon_sym_RPAREN,
    STATE(13649), 1,
      sym_attribute,
    STATE(18964), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [643815] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(18081), 1,
      anon_sym_DASH_GT,
    STATE(13650), 1,
      sym_attribute,
    STATE(19369), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [643847] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18083), 1,
      anon_sym_RPAREN,
    STATE(13651), 1,
      sym_attribute,
    STATE(18747), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [643879] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18085), 1,
      anon_sym_RPAREN,
    STATE(13652), 1,
      sym_attribute,
    STATE(17774), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [643911] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18087), 1,
      anon_sym_RPAREN,
    STATE(13653), 1,
      sym_attribute,
    STATE(18473), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [643943] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(17819), 1,
      anon_sym__,
    STATE(13654), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(16141), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [643973] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18089), 1,
      anon_sym_RPAREN,
    STATE(13655), 1,
      sym_attribute,
    STATE(20470), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [644005] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(18091), 1,
      anon_sym_DASH_GT,
    STATE(13656), 1,
      sym_attribute,
    STATE(17756), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [644037] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16910), 1,
      anon_sym_STAR,
    STATE(13657), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10391), 6,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_GT,
  [644059] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18093), 1,
      anon_sym_RPAREN,
    STATE(13658), 1,
      sym_attribute,
    STATE(18969), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [644091] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(18095), 1,
      anon_sym__,
    ACTIONS(18097), 1,
      anon_sym_RBRACE,
    STATE(13659), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(16623), 1,
      sym_field_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [644123] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18099), 1,
      anon_sym_RPAREN,
    STATE(13660), 1,
      sym_attribute,
    STATE(18467), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [644155] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17761), 1,
      anon_sym_DASH_GT,
    ACTIONS(17763), 1,
      anon_sym_with,
    STATE(13661), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13402), 5,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [644179] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(13662), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(16379), 1,
      sym_field_pattern,
    STATE(19477), 1,
      sym__quoted_string,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [644211] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18101), 1,
      anon_sym_RPAREN,
    STATE(13663), 1,
      sym_attribute,
    STATE(18044), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [644243] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(13664), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(16416), 1,
      sym_field_binding_pattern,
    STATE(19706), 1,
      sym__quoted_string,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [644275] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(18103), 1,
      anon_sym_DASH_GT,
    STATE(13665), 1,
      sym_attribute,
    STATE(18419), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [644307] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18105), 1,
      anon_sym_RPAREN,
    STATE(13666), 1,
      sym_attribute,
    STATE(18433), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [644339] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18107), 1,
      anon_sym_RPAREN,
    STATE(13667), 1,
      sym_attribute,
    STATE(18875), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [644371] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12513), 1,
      anon_sym_LPAREN,
    ACTIONS(12515), 1,
      anon_sym_LBRACK,
    STATE(10677), 1,
      sym_constructor_declaration,
    STATE(11003), 1,
      sym__constructor_name,
    STATE(13668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12517), 2,
      anon_sym_true,
      anon_sym_false,
  [644401] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18109), 1,
      anon_sym_RPAREN,
    STATE(13669), 1,
      sym_attribute,
    STATE(18991), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [644433] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13670), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11914), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [644453] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18111), 1,
      anon_sym_RPAREN,
    STATE(13671), 1,
      sym_attribute,
    STATE(18172), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [644485] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(13672), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(15318), 1,
      sym_field_binding_pattern,
    STATE(18793), 1,
      sym__quoted_string,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [644517] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18113), 1,
      anon_sym_RPAREN,
    STATE(13673), 1,
      sym_attribute,
    STATE(18427), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [644549] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11414), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11416), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [644571] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(18115), 1,
      anon_sym__,
    ACTIONS(18117), 1,
      anon_sym_RBRACE,
    STATE(13675), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(16623), 1,
      sym_field_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [644603] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13676), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11704), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11706), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [644625] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(17875), 1,
      anon_sym_COMMA,
    ACTIONS(17877), 1,
      anon_sym_PIPE,
    ACTIONS(17883), 1,
      anon_sym_COLON_COLON,
    STATE(13677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16959), 3,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [644653] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18119), 1,
      anon_sym_RPAREN,
    STATE(13678), 1,
      sym_attribute,
    STATE(20062), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [644685] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13679), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11600), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11602), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [644707] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(17819), 1,
      anon_sym__,
    STATE(13680), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(15092), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [644737] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(17875), 1,
      anon_sym_COMMA,
    ACTIONS(17877), 1,
      anon_sym_PIPE,
    ACTIONS(17883), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18121), 1,
      anon_sym_RBRACK,
    ACTIONS(18123), 1,
      anon_sym_SEMI,
    STATE(13681), 1,
      sym_attribute,
    STATE(15214), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [644769] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(18125), 1,
      anon_sym_DASH_GT,
    STATE(13682), 1,
      sym_attribute,
    STATE(18014), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [644801] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17845), 1,
      anon_sym_COMMA,
    ACTIONS(17847), 1,
      anon_sym_PIPE,
    ACTIONS(17851), 1,
      anon_sym_as,
    ACTIONS(17853), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18127), 1,
      anon_sym_SEMI,
    ACTIONS(18129), 1,
      anon_sym_PIPE_RBRACK,
    STATE(13683), 1,
      sym_attribute,
    STATE(15095), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [644833] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(13684), 1,
      sym_attribute,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18131), 2,
      anon_sym_SEMI,
      anon_sym_GT,
  [644863] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18133), 1,
      anon_sym_RPAREN,
    STATE(13685), 1,
      sym_attribute,
    STATE(18227), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [644895] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18135), 1,
      anon_sym_RPAREN,
    STATE(13686), 1,
      sym_attribute,
    STATE(18741), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [644927] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17831), 1,
      anon_sym_COMMA,
    ACTIONS(17833), 1,
      anon_sym_PIPE,
    ACTIONS(17835), 1,
      anon_sym_as,
    ACTIONS(17837), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18137), 1,
      anon_sym_RPAREN,
    STATE(13687), 1,
      sym_attribute,
    STATE(20060), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [644959] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18139), 1,
      anon_sym_RPAREN,
    STATE(13688), 1,
      sym_attribute,
    STATE(18037), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [644991] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18141), 1,
      anon_sym_RPAREN,
    STATE(13689), 1,
      sym_attribute,
    STATE(17821), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [645023] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(17335), 1,
      anon_sym_LPAREN,
    ACTIONS(17337), 1,
      anon_sym_LBRACK,
    STATE(10820), 1,
      sym_constructor_declaration,
    STATE(11417), 1,
      sym__constructor_name,
    STATE(13690), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17339), 2,
      anon_sym_true,
      anon_sym_false,
  [645053] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17739), 1,
      anon_sym_COMMA,
    ACTIONS(17741), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(17749), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18143), 1,
      anon_sym_RBRACK,
    ACTIONS(18145), 1,
      anon_sym_SEMI,
    STATE(13691), 1,
      sym_attribute,
    STATE(15385), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [645085] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17761), 1,
      anon_sym_DASH_GT,
    ACTIONS(17763), 1,
      anon_sym_with,
    STATE(13692), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13453), 5,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [645109] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17739), 1,
      anon_sym_COMMA,
    ACTIONS(17741), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(17749), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18147), 1,
      anon_sym_RBRACK,
    ACTIONS(18149), 1,
      anon_sym_SEMI,
    STATE(13693), 1,
      sym_attribute,
    STATE(15208), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [645141] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13694), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11474), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11476), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [645163] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(17361), 1,
      anon_sym_LPAREN,
    ACTIONS(17363), 1,
      anon_sym_LBRACK,
    STATE(10820), 1,
      sym_constructor_declaration,
    STATE(11922), 1,
      sym__constructor_name,
    STATE(13695), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17365), 2,
      anon_sym_true,
      anon_sym_false,
  [645193] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17775), 1,
      anon_sym_COMMA,
    ACTIONS(17777), 1,
      anon_sym_PIPE,
    ACTIONS(17781), 1,
      anon_sym_as,
    ACTIONS(17783), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18151), 1,
      anon_sym_SEMI,
    ACTIONS(18153), 1,
      anon_sym_PIPE_RBRACK,
    STATE(13696), 1,
      sym_attribute,
    STATE(15201), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [645225] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18155), 1,
      anon_sym_RPAREN,
    STATE(13697), 1,
      sym_attribute,
    STATE(19008), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [645257] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(18157), 1,
      anon_sym_DASH_GT,
    STATE(13698), 1,
      sym_attribute,
    STATE(18951), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [645289] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18159), 1,
      anon_sym_RPAREN,
    STATE(13699), 1,
      sym_attribute,
    STATE(18185), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [645321] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13700), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11642), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11644), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [645343] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13701), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11632), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11634), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [645365] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18161), 1,
      anon_sym_RPAREN,
    STATE(13702), 1,
      sym_attribute,
    STATE(19010), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [645397] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13703), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11550), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11552), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [645419] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18163), 1,
      anon_sym_RPAREN,
    STATE(13704), 1,
      sym_attribute,
    STATE(18393), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [645451] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12414), 1,
      anon_sym_LPAREN,
    ACTIONS(12416), 1,
      anon_sym_LBRACK,
    STATE(10677), 1,
      sym_constructor_declaration,
    STATE(11081), 1,
      sym__constructor_name,
    STATE(13705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12418), 2,
      anon_sym_true,
      anon_sym_false,
  [645481] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18165), 1,
      anon_sym_RPAREN,
    STATE(13706), 1,
      sym_attribute,
    STATE(17828), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [645513] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(13707), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(15326), 1,
      sym_field_pattern,
    STATE(19706), 1,
      sym__quoted_string,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [645545] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18167), 1,
      anon_sym_RPAREN,
    STATE(13708), 1,
      sym_attribute,
    STATE(18387), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [645577] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18051), 1,
      anon_sym_AMP,
    STATE(13709), 1,
      sym_attribute,
    STATE(14338), 1,
      aux_sym_tag_specification_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18169), 3,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_GT,
  [645605] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(17875), 1,
      anon_sym_COMMA,
    ACTIONS(17877), 1,
      anon_sym_PIPE,
    ACTIONS(17883), 1,
      anon_sym_COLON_COLON,
    STATE(13710), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16919), 3,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [645633] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13711), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11426), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11428), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [645655] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18171), 1,
      anon_sym_RPAREN,
    STATE(13712), 1,
      sym_attribute,
    STATE(18822), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [645687] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18173), 1,
      anon_sym_RPAREN,
    STATE(13713), 1,
      sym_attribute,
    STATE(20282), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [645719] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(17819), 1,
      anon_sym__,
    STATE(13714), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(16298), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [645749] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(17819), 1,
      anon_sym__,
    STATE(13715), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(15944), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [645779] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(18175), 1,
      anon_sym_DASH_GT,
    STATE(13716), 1,
      sym_attribute,
    STATE(17820), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [645811] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13717), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11795), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11797), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [645833] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13718), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11470), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11472), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [645855] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18177), 1,
      anon_sym_RPAREN,
    STATE(13719), 1,
      sym_attribute,
    STATE(18703), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [645887] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    STATE(13720), 1,
      sym_attribute,
    STATE(20412), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11262), 2,
      anon_sym_LPAREN,
      anon_sym_DOT,
    ACTIONS(11258), 3,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_with,
  [645913] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17775), 1,
      anon_sym_COMMA,
    ACTIONS(17777), 1,
      anon_sym_PIPE,
    ACTIONS(17781), 1,
      anon_sym_as,
    ACTIONS(17783), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18179), 1,
      anon_sym_SEMI,
    ACTIONS(18181), 1,
      anon_sym_PIPE_RBRACK,
    STATE(13721), 1,
      sym_attribute,
    STATE(16226), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [645945] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18183), 1,
      anon_sym_RPAREN,
    STATE(13722), 1,
      sym_attribute,
    STATE(18233), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [645977] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18185), 1,
      anon_sym_RPAREN,
    STATE(13723), 1,
      sym_attribute,
    STATE(20159), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [646009] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8338), 1,
      anon_sym_PIPE,
    STATE(13724), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 6,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [646031] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13725), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11508), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11510), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [646053] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11438), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11440), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [646075] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8320), 1,
      anon_sym_PIPE,
    STATE(13727), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 6,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [646097] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17739), 1,
      anon_sym_COMMA,
    ACTIONS(17741), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(17749), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18187), 1,
      anon_sym_RBRACK,
    ACTIONS(18189), 1,
      anon_sym_SEMI,
    STATE(13728), 1,
      sym_attribute,
    STATE(16210), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [646129] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13729), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11442), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11444), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [646151] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8334), 1,
      anon_sym_PIPE,
    STATE(13730), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 6,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [646173] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17831), 1,
      anon_sym_COMMA,
    ACTIONS(17833), 1,
      anon_sym_PIPE,
    ACTIONS(17835), 1,
      anon_sym_as,
    ACTIONS(17837), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18191), 1,
      anon_sym_RPAREN,
    STATE(13731), 1,
      sym_attribute,
    STATE(19670), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [646205] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(13732), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(15567), 1,
      sym_field_pattern,
    STATE(18033), 1,
      sym__quoted_string,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [646237] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(13733), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(15593), 1,
      sym_field_binding_pattern,
    STATE(18106), 1,
      sym__quoted_string,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [646269] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13734), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11892), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [646289] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8308), 1,
      anon_sym_PIPE,
    STATE(13735), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 6,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [646311] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17845), 1,
      anon_sym_COMMA,
    ACTIONS(17847), 1,
      anon_sym_PIPE,
    ACTIONS(17851), 1,
      anon_sym_as,
    ACTIONS(17853), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18193), 1,
      anon_sym_SEMI,
    ACTIONS(18195), 1,
      anon_sym_PIPE_RBRACK,
    STATE(13736), 1,
      sym_attribute,
    STATE(16202), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [646343] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8300), 1,
      anon_sym_PIPE,
    STATE(13737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 6,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [646365] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(17799), 1,
      anon_sym_type,
    ACTIONS(18197), 1,
      sym__lowercase_identifier,
    ACTIONS(18199), 1,
      anon_sym_LBRACK,
    ACTIONS(18201), 1,
      anon_sym_virtual,
    STATE(12785), 1,
      sym_class_binding,
    STATE(13738), 1,
      sym_attribute,
    STATE(14624), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [646397] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(18203), 1,
      anon_sym__,
    ACTIONS(18205), 1,
      anon_sym_RBRACE,
    STATE(13739), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(16623), 1,
      sym_field_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [646429] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13740), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11446), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11448), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [646451] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18207), 1,
      anon_sym_RPAREN,
    STATE(13741), 1,
      sym_attribute,
    STATE(18785), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [646483] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18209), 1,
      anon_sym_RBRACK,
    ACTIONS(18211), 1,
      anon_sym_when,
    STATE(13742), 1,
      sym_attribute,
    STATE(20391), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [646515] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(18213), 1,
      anon_sym_DASH_GT,
    STATE(13743), 1,
      sym_attribute,
    STATE(18333), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [646547] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17533), 1,
      anon_sym_RPAREN,
    STATE(13744), 1,
      sym_attribute,
    STATE(20300), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [646579] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(18215), 1,
      anon_sym__,
    ACTIONS(18217), 1,
      anon_sym_RBRACE,
    STATE(13745), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(16626), 1,
      sym_field_binding_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [646611] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(17875), 1,
      anon_sym_COMMA,
    ACTIONS(17877), 1,
      anon_sym_PIPE,
    ACTIONS(17883), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18219), 1,
      anon_sym_RBRACK,
    ACTIONS(18221), 1,
      anon_sym_SEMI,
    STATE(13746), 1,
      sym_attribute,
    STATE(16406), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [646643] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(18223), 1,
      anon_sym_DASH_GT,
    STATE(13747), 1,
      sym_attribute,
    STATE(18679), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [646675] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(17875), 1,
      anon_sym_COMMA,
    ACTIONS(17877), 1,
      anon_sym_PIPE,
    ACTIONS(17883), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18225), 1,
      anon_sym_RBRACK,
    ACTIONS(18227), 1,
      anon_sym_SEMI,
    STATE(13748), 1,
      sym_attribute,
    STATE(16196), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [646707] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8290), 1,
      anon_sym_PIPE,
    STATE(13749), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 6,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [646729] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18229), 1,
      anon_sym_RPAREN,
    STATE(13750), 1,
      sym_attribute,
    STATE(17990), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [646761] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17527), 1,
      anon_sym_RPAREN,
    STATE(13751), 1,
      sym_attribute,
    STATE(19671), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [646793] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13752), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11478), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11480), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [646815] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18231), 1,
      anon_sym_RPAREN,
    STATE(13753), 1,
      sym_attribute,
    STATE(18353), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [646847] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8286), 1,
      anon_sym_PIPE,
    STATE(13754), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 6,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [646869] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13755), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11494), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11496), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [646891] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18233), 1,
      anon_sym_RPAREN,
    STATE(13756), 1,
      sym_attribute,
    STATE(17875), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [646923] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12811), 1,
      anon_sym_LPAREN,
    ACTIONS(12813), 1,
      anon_sym_LBRACK,
    STATE(10677), 1,
      sym_constructor_declaration,
    STATE(11639), 1,
      sym__constructor_name,
    STATE(13757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12815), 2,
      anon_sym_true,
      anon_sym_false,
  [646953] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18235), 1,
      anon_sym_RPAREN,
    STATE(13758), 1,
      sym_attribute,
    STATE(18347), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [646985] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17775), 1,
      anon_sym_COMMA,
    ACTIONS(17777), 1,
      anon_sym_PIPE,
    ACTIONS(17781), 1,
      anon_sym_as,
    ACTIONS(17783), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18237), 1,
      anon_sym_SEMI,
    ACTIONS(18239), 1,
      anon_sym_PIPE_RBRACK,
    STATE(13759), 1,
      sym_attribute,
    STATE(16327), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [647017] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18241), 1,
      anon_sym_RPAREN,
    STATE(13760), 1,
      sym_attribute,
    STATE(19578), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [647049] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(17819), 1,
      anon_sym__,
    STATE(13761), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(15273), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [647079] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18243), 1,
      anon_sym_COLON2,
    STATE(13762), 1,
      sym_attribute,
    STATE(16602), 1,
      sym__polymorphic_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 5,
      anon_sym_SEMI,
      anon_sym_GT,
      anon_sym_POUND,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [647103] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(17819), 1,
      anon_sym__,
    STATE(13763), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(15348), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [647133] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8316), 1,
      anon_sym_PIPE,
    STATE(13764), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 6,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [647155] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17739), 1,
      anon_sym_COMMA,
    ACTIONS(17741), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(17749), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18245), 1,
      anon_sym_RBRACK,
    ACTIONS(18247), 1,
      anon_sym_SEMI,
    STATE(13765), 1,
      sym_attribute,
    STATE(16353), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [647187] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18249), 1,
      anon_sym_RPAREN,
    STATE(13766), 1,
      sym_attribute,
    STATE(20218), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [647219] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18251), 1,
      anon_sym_RPAREN,
    STATE(13767), 1,
      sym_attribute,
    STATE(18589), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [647251] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18253), 1,
      anon_sym_RPAREN,
    STATE(13768), 1,
      sym_attribute,
    STATE(18267), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [647283] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18255), 1,
      anon_sym_RPAREN,
    STATE(13769), 1,
      sym_attribute,
    STATE(17882), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [647315] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18257), 1,
      anon_sym_RPAREN,
    STATE(13770), 1,
      sym_attribute,
    STATE(18709), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [647347] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(17819), 1,
      anon_sym__,
    STATE(13771), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(15250), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [647377] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(18259), 1,
      anon_sym__,
    ACTIONS(18261), 1,
      anon_sym_RBRACE,
    STATE(13772), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(16626), 1,
      sym_field_binding_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [647409] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18263), 1,
      anon_sym_RPAREN,
    STATE(13773), 1,
      sym_attribute,
    STATE(18372), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [647441] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(17799), 1,
      anon_sym_type,
    ACTIONS(18265), 1,
      sym__lowercase_identifier,
    ACTIONS(18267), 1,
      anon_sym_LBRACK,
    ACTIONS(18269), 1,
      anon_sym_virtual,
    STATE(12732), 1,
      sym_class_binding,
    STATE(13774), 1,
      sym_attribute,
    STATE(14773), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [647473] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18271), 1,
      anon_sym_RPAREN,
    STATE(13775), 1,
      sym_attribute,
    STATE(17983), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [647505] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17831), 1,
      anon_sym_COMMA,
    ACTIONS(17833), 1,
      anon_sym_PIPE,
    ACTIONS(17835), 1,
      anon_sym_as,
    ACTIONS(17837), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18273), 1,
      anon_sym_RPAREN,
    STATE(13776), 1,
      sym_attribute,
    STATE(19547), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [647537] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(18275), 1,
      anon_sym__,
    ACTIONS(18277), 1,
      anon_sym_RBRACE,
    STATE(13777), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(16623), 1,
      sym_field_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [647569] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17845), 1,
      anon_sym_COMMA,
    ACTIONS(17847), 1,
      anon_sym_PIPE,
    ACTIONS(17851), 1,
      anon_sym_as,
    ACTIONS(17853), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18279), 1,
      anon_sym_SEMI,
    ACTIONS(18281), 1,
      anon_sym_PIPE_RBRACK,
    STATE(13778), 1,
      sym_attribute,
    STATE(16454), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [647601] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(18283), 1,
      anon_sym_DASH_GT,
    STATE(13779), 1,
      sym_attribute,
    STATE(19676), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [647633] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5079), 1,
      anon_sym_PIPE,
    ACTIONS(17983), 1,
      anon_sym_DOT_DOT,
    STATE(13780), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5077), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [647657] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(13781), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(15160), 1,
      sym_field_pattern,
    STATE(19971), 1,
      sym__quoted_string,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [647689] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18285), 1,
      anon_sym_RPAREN,
    STATE(13782), 1,
      sym_attribute,
    STATE(18384), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [647721] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(17819), 1,
      anon_sym__,
    STATE(13783), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(15917), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [647751] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(17875), 1,
      anon_sym_COMMA,
    ACTIONS(17877), 1,
      anon_sym_PIPE,
    ACTIONS(17883), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18287), 1,
      anon_sym_RBRACK,
    ACTIONS(18289), 1,
      anon_sym_SEMI,
    STATE(13784), 1,
      sym_attribute,
    STATE(16378), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [647783] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17845), 1,
      anon_sym_COMMA,
    ACTIONS(17847), 1,
      anon_sym_PIPE,
    ACTIONS(17851), 1,
      anon_sym_as,
    ACTIONS(17853), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18291), 1,
      anon_sym_SEMI,
    ACTIONS(18293), 1,
      anon_sym_PIPE_RBRACK,
    STATE(13785), 1,
      sym_attribute,
    STATE(16486), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [647815] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12337), 1,
      anon_sym_LPAREN,
    ACTIONS(12339), 1,
      anon_sym_LBRACK,
    STATE(10677), 1,
      sym_constructor_declaration,
    STATE(10775), 1,
      sym__constructor_name,
    STATE(13786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12341), 2,
      anon_sym_true,
      anon_sym_false,
  [647845] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(18295), 1,
      anon_sym_DASH_GT,
    STATE(13787), 1,
      sym_attribute,
    STATE(17886), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [647877] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(18297), 1,
      anon_sym_DASH_GT,
    STATE(13788), 1,
      sym_attribute,
    STATE(18767), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [647909] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18299), 1,
      anon_sym_RPAREN,
    STATE(13789), 1,
      sym_attribute,
    STATE(18583), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [647941] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18301), 1,
      anon_sym_RPAREN,
    STATE(13790), 1,
      sym_attribute,
    STATE(18817), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [647973] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(18303), 1,
      anon_sym_DASH_GT,
    STATE(13791), 1,
      sym_attribute,
    STATE(17947), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [648005] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(13792), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(15115), 1,
      sym_field_binding_pattern,
    STATE(19844), 1,
      sym__quoted_string,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [648037] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17597), 1,
      anon_sym_RPAREN,
    STATE(13793), 1,
      sym_attribute,
    STATE(19548), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [648069] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(14916), 1,
      anon_sym_BANG,
    ACTIONS(17819), 1,
      anon_sym__,
    STATE(13794), 1,
      sym_attribute,
    STATE(14317), 1,
      sym_type_variable,
    STATE(16187), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [648099] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13795), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11763), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11765), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [648121] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13796), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11434), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11436), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [648143] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9102), 1,
      anon_sym_PIPE,
    STATE(13797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9104), 6,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [648165] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16457), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(13798), 1,
      sym_attribute,
    STATE(14287), 1,
      aux_sym_expression_item_repeat1,
    STATE(15602), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12289), 2,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(18305), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [648193] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13799), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 7,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [648213] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17775), 1,
      anon_sym_COMMA,
    ACTIONS(17777), 1,
      anon_sym_PIPE,
    ACTIONS(17781), 1,
      anon_sym_as,
    ACTIONS(17783), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18307), 1,
      anon_sym_SEMI,
    ACTIONS(18309), 1,
      anon_sym_PIPE_RBRACK,
    STATE(13800), 1,
      sym_attribute,
    STATE(15448), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [648245] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(18311), 1,
      anon_sym_DASH_GT,
    STATE(13801), 1,
      sym_attribute,
    STATE(19227), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [648277] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(18313), 1,
      anon_sym_DASH_GT,
    STATE(13802), 1,
      sym_attribute,
    STATE(19807), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [648309] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(18315), 1,
      anon_sym_DASH_GT,
    STATE(13803), 1,
      sym_attribute,
    STATE(19555), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [648341] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18317), 1,
      anon_sym_RPAREN,
    STATE(13804), 1,
      sym_attribute,
    STATE(18313), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [648373] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(18319), 1,
      anon_sym__,
    ACTIONS(18321), 1,
      anon_sym_RBRACE,
    STATE(13805), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(16626), 1,
      sym_field_binding_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [648405] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18323), 1,
      anon_sym_RPAREN,
    STATE(13806), 1,
      sym_attribute,
    STATE(19799), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [648437] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17775), 1,
      anon_sym_COMMA,
    ACTIONS(17777), 1,
      anon_sym_PIPE,
    ACTIONS(17781), 1,
      anon_sym_as,
    ACTIONS(17783), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18325), 1,
      anon_sym_SEMI,
    ACTIONS(18327), 1,
      anon_sym_PIPE_RBRACK,
    STATE(13807), 1,
      sym_attribute,
    STATE(16421), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [648469] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(13808), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(15131), 1,
      sym_field_binding_pattern,
    STATE(18706), 1,
      sym__quoted_string,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [648501] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13809), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 7,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [648521] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18329), 1,
      anon_sym_RPAREN,
    STATE(13810), 1,
      sym_attribute,
    STATE(19616), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [648553] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(13811), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(15107), 1,
      sym_field_pattern,
    STATE(18706), 1,
      sym__quoted_string,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [648585] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(18331), 1,
      anon_sym__,
    ACTIONS(18333), 1,
      anon_sym_RBRACE,
    STATE(13812), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(16623), 1,
      sym_field_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [648617] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17761), 1,
      anon_sym_DASH_GT,
    ACTIONS(17763), 1,
      anon_sym_with,
    STATE(13813), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13348), 5,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [648641] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17811), 1,
      anon_sym_when,
    ACTIONS(18335), 1,
      anon_sym_DASH_GT,
    STATE(13814), 1,
      sym_attribute,
    STATE(18245), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [648673] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(18337), 1,
      anon_sym__,
    ACTIONS(18339), 1,
      anon_sym_RBRACE,
    STATE(13815), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(16623), 1,
      sym_field_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [648705] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17831), 1,
      anon_sym_COMMA,
    ACTIONS(17833), 1,
      anon_sym_PIPE,
    ACTIONS(17835), 1,
      anon_sym_as,
    ACTIONS(17837), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18341), 1,
      anon_sym_RPAREN,
    STATE(13816), 1,
      sym_attribute,
    STATE(20294), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [648737] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18343), 1,
      anon_sym_RPAREN,
    STATE(13817), 1,
      sym_attribute,
    STATE(18307), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [648769] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(17831), 1,
      anon_sym_COMMA,
    ACTIONS(17833), 1,
      anon_sym_PIPE,
    ACTIONS(17835), 1,
      anon_sym_as,
    ACTIONS(17837), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18345), 1,
      anon_sym_RPAREN,
    STATE(13818), 1,
      sym_attribute,
    STATE(19798), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [648801] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18347), 1,
      anon_sym_RPAREN,
    STATE(13819), 1,
      sym_attribute,
    STATE(18273), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [648833] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17765), 1,
      sym__lowercase_identifier,
    ACTIONS(18349), 1,
      anon_sym__,
    ACTIONS(18351), 1,
      anon_sym_RBRACE,
    STATE(13820), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(16626), 1,
      sym_field_binding_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [648865] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(13821), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(16290), 1,
      sym_field_pattern,
    STATE(17778), 1,
      sym__quoted_string,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [648897] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17845), 1,
      anon_sym_COMMA,
    ACTIONS(17847), 1,
      anon_sym_PIPE,
    ACTIONS(17851), 1,
      anon_sym_as,
    ACTIONS(17853), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18353), 1,
      anon_sym_SEMI,
    ACTIONS(18355), 1,
      anon_sym_PIPE_RBRACK,
    STATE(13822), 1,
      sym_attribute,
    STATE(15362), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [648929] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18357), 1,
      anon_sym_RPAREN,
    STATE(13823), 1,
      sym_attribute,
    STATE(17936), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [648961] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(17875), 1,
      anon_sym_COMMA,
    ACTIONS(17877), 1,
      anon_sym_PIPE,
    ACTIONS(17883), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18359), 1,
      anon_sym_RBRACK,
    ACTIONS(18361), 1,
      anon_sym_SEMI,
    STATE(13824), 1,
      sym_attribute,
    STATE(15331), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [648993] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13825), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11932), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [649013] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18365), 3,
      sym__right_quoted_string_delimiter,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(18363), 4,
      aux_sym_string_content_token1,
      aux_sym_quoted_string_content_token1,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [649035] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(18367), 1,
      anon_sym_RPAREN,
    STATE(13827), 1,
      sym_attribute,
    STATE(17929), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [649067] = 10,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17739), 1,
      anon_sym_COMMA,
    ACTIONS(17741), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(17749), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18369), 1,
      anon_sym_RBRACK,
    ACTIONS(18371), 1,
      anon_sym_SEMI,
    STATE(13828), 1,
      sym_attribute,
    STATE(16436), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [649099] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12083), 1,
      sym__uppercase_identifier,
    ACTIONS(12208), 1,
      anon_sym_LPAREN,
    ACTIONS(12210), 1,
      anon_sym_LBRACK,
    STATE(10408), 1,
      sym__constructor_name,
    STATE(10677), 1,
      sym_constructor_declaration,
    STATE(13829), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12212), 2,
      anon_sym_true,
      anon_sym_false,
  [649129] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13830), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11692), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11694), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [649151] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18373), 1,
      anon_sym_RBRACE,
    STATE(13831), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [649180] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9710), 1,
      anon_sym_PIPE,
    STATE(13832), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9712), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [649201] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(17875), 1,
      anon_sym_COMMA,
    ACTIONS(17877), 1,
      anon_sym_PIPE,
    ACTIONS(17883), 1,
      anon_sym_COLON_COLON,
    STATE(13833), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18375), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [649228] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18377), 1,
      sym__lowercase_identifier,
    STATE(6026), 1,
      sym_class_path,
    STATE(13834), 1,
      sym_attribute,
    STATE(14672), 1,
      sym__attribute,
    STATE(18570), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [649257] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18379), 1,
      anon_sym_RBRACE,
    STATE(13835), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [649286] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9132), 1,
      anon_sym_PIPE,
    STATE(13836), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9134), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [649307] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11765), 1,
      anon_sym_RPAREN,
    STATE(13837), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9258), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [649328] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18381), 1,
      anon_sym_RBRACE,
    STATE(13838), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [649357] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18383), 1,
      anon_sym_RBRACE,
    STATE(13839), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [649386] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7759), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12567), 1,
      anon_sym_and,
    STATE(13840), 1,
      sym_attribute,
    STATE(14069), 1,
      aux_sym_expression_item_repeat1,
    STATE(14644), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12565), 2,
      anon_sym_in,
      sym_let_and_operator,
  [649413] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7759), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12665), 1,
      anon_sym_and,
    STATE(13841), 1,
      sym_attribute,
    STATE(13868), 1,
      aux_sym_expression_item_repeat1,
    STATE(14644), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12663), 2,
      anon_sym_in,
      sym_let_and_operator,
  [649440] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18385), 1,
      anon_sym_RBRACE,
    STATE(13842), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [649469] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9260), 1,
      anon_sym_PIPE,
    STATE(13843), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9262), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [649490] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18387), 1,
      anon_sym_RBRACE,
    STATE(13844), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [649519] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18389), 1,
      sym__lowercase_identifier,
    STATE(6633), 1,
      sym_class_path,
    STATE(13845), 1,
      sym_attribute,
    STATE(14905), 1,
      sym__attribute,
    STATE(18800), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [649548] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8282), 1,
      anon_sym_PIPE,
    STATE(13846), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [649569] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_PIPE,
    STATE(13847), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [649590] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18391), 1,
      anon_sym_RBRACE,
    STATE(13848), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [649619] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18393), 1,
      anon_sym_RBRACE,
    STATE(13849), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [649648] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18395), 1,
      sym__lowercase_identifier,
    STATE(6167), 1,
      sym_class_path,
    STATE(13850), 1,
      sym_attribute,
    STATE(14913), 1,
      sym__attribute,
    STATE(18011), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [649677] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8060), 1,
      anon_sym_PIPE,
    STATE(13851), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [649698] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18397), 1,
      sym__lowercase_identifier,
    STATE(7109), 1,
      sym_class_path,
    STATE(13852), 1,
      sym_attribute,
    STATE(14796), 1,
      sym__attribute,
    STATE(18461), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [649727] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7996), 1,
      anon_sym_PIPE,
    STATE(13853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7998), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [649748] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9166), 1,
      anon_sym_PIPE,
    STATE(13854), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9168), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [649769] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18399), 1,
      sym__lowercase_identifier,
    STATE(7157), 1,
      sym_class_path,
    STATE(13855), 1,
      sym_attribute,
    STATE(14859), 1,
      sym__attribute,
    STATE(18683), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [649798] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18401), 1,
      anon_sym_RBRACE,
    STATE(13856), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [649827] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9224), 1,
      anon_sym_PIPE,
    STATE(13857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9226), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [649848] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7759), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12769), 1,
      anon_sym_and,
    STATE(13841), 1,
      aux_sym_expression_item_repeat1,
    STATE(13858), 1,
      sym_attribute,
    STATE(14644), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12767), 2,
      anon_sym_in,
      sym_let_and_operator,
  [649875] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18403), 1,
      anon_sym_RBRACE,
    STATE(13859), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [649904] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18405), 1,
      anon_sym_RBRACE,
    STATE(13860), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [649933] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7759), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12773), 1,
      anon_sym_and,
    STATE(13861), 1,
      sym_attribute,
    STATE(13868), 1,
      aux_sym_expression_item_repeat1,
    STATE(14644), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12771), 2,
      anon_sym_in,
      sym_let_and_operator,
  [649960] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18407), 1,
      anon_sym_RBRACE,
    STATE(13862), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [649989] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(16334), 1,
      sym__lowercase_identifier,
    ACTIONS(18409), 1,
      anon_sym_LPAREN,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(13863), 1,
      sym_attribute,
    STATE(14497), 1,
      sym__attribute,
    STATE(16524), 1,
      sym__value_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [650018] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18411), 1,
      sym__lowercase_identifier,
    STATE(5782), 1,
      sym_class_path,
    STATE(13864), 1,
      sym_attribute,
    STATE(14552), 1,
      sym__attribute,
    STATE(18169), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [650047] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18413), 1,
      anon_sym_RBRACE,
    STATE(13865), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [650076] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18415), 1,
      sym__lowercase_identifier,
    STATE(5389), 1,
      sym_class_path,
    STATE(13866), 1,
      sym_attribute,
    STATE(14711), 1,
      sym__attribute,
    STATE(18250), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [650105] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18417), 1,
      anon_sym_RBRACE,
    STATE(13867), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [650134] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11942), 1,
      anon_sym_and,
    ACTIONS(18419), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(14644), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11940), 2,
      anon_sym_in,
      sym_let_and_operator,
    STATE(13868), 2,
      sym_attribute,
      aux_sym_expression_item_repeat1,
  [650159] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18422), 1,
      anon_sym_RBRACE,
    STATE(13869), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [650188] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16868), 1,
      anon_sym_PIPE,
    STATE(13870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16866), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [650209] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(17875), 1,
      anon_sym_COMMA,
    ACTIONS(17877), 1,
      anon_sym_PIPE,
    ACTIONS(17883), 1,
      anon_sym_COLON_COLON,
    STATE(13871), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18424), 2,
      anon_sym_RBRACK,
      anon_sym_SEMI,
  [650236] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18426), 1,
      anon_sym_RBRACE,
    STATE(13872), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [650265] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9706), 1,
      anon_sym_PIPE,
    STATE(13873), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9708), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [650286] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18428), 1,
      anon_sym_RBRACE,
    STATE(13874), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [650315] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18430), 1,
      anon_sym_RBRACE,
    STATE(13875), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [650344] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18432), 1,
      sym__lowercase_identifier,
    STATE(6325), 1,
      sym_class_path,
    STATE(13876), 1,
      sym_attribute,
    STATE(14969), 1,
      sym__attribute,
    STATE(18370), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [650373] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18434), 1,
      anon_sym_RBRACE,
    STATE(13877), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [650402] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18436), 1,
      sym__lowercase_identifier,
    STATE(3597), 1,
      sym_class_path,
    STATE(13878), 1,
      sym_attribute,
    STATE(14968), 1,
      sym__attribute,
    STATE(18982), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [650431] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9136), 1,
      anon_sym_PIPE,
    STATE(13879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9138), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [650452] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18438), 1,
      anon_sym_RBRACE,
    STATE(13880), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [650481] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18440), 1,
      anon_sym_RBRACE,
    STATE(13881), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [650510] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18442), 1,
      anon_sym_RBRACE,
    STATE(13882), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [650539] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8326), 1,
      anon_sym_PIPE,
    STATE(13883), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [650560] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18444), 1,
      anon_sym_RBRACE,
    STATE(13884), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [650589] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18446), 1,
      anon_sym_RBRACE,
    STATE(13885), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [650618] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18448), 1,
      anon_sym_RBRACE,
    STATE(13886), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [650647] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9692), 1,
      anon_sym_PIPE,
    STATE(13887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9694), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [650668] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18450), 1,
      anon_sym_RBRACE,
    STATE(13888), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [650697] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18452), 1,
      anon_sym_RBRACE,
    STATE(13889), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [650726] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18454), 1,
      anon_sym_RBRACE,
    STATE(13890), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [650755] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9154), 1,
      anon_sym_PIPE,
    STATE(13891), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9156), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [650776] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18409), 1,
      anon_sym_LPAREN,
    ACTIONS(18456), 1,
      sym__lowercase_identifier,
    STATE(13892), 1,
      sym_attribute,
    STATE(14626), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(20405), 2,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [650803] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18458), 1,
      anon_sym_RBRACE,
    STATE(13893), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [650832] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18460), 1,
      anon_sym_and,
    STATE(13894), 1,
      sym_attribute,
    STATE(14078), 1,
      aux_sym_module_type_constraint_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12647), 4,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_with,
  [650855] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(18464), 1,
      anon_sym_PIPE,
    ACTIONS(18466), 1,
      anon_sym_RBRACK,
    STATE(13895), 1,
      sym_attribute,
    STATE(15085), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [650884] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18468), 1,
      anon_sym_RBRACE,
    STATE(13896), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [650913] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18470), 1,
      anon_sym_RBRACE,
    STATE(13897), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [650942] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18472), 1,
      anon_sym_RBRACE,
    STATE(13898), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [650971] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18474), 1,
      sym__lowercase_identifier,
    STATE(7100), 1,
      sym_class_path,
    STATE(13899), 1,
      sym_attribute,
    STATE(14660), 1,
      sym__attribute,
    STATE(17957), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [651000] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9206), 1,
      anon_sym_PIPE,
    STATE(13900), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9208), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [651021] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9150), 1,
      anon_sym_PIPE,
    STATE(13901), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9152), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [651042] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18476), 1,
      anon_sym_RBRACE,
    STATE(13902), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [651071] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18478), 1,
      anon_sym_RBRACE,
    STATE(13903), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [651100] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9236), 1,
      anon_sym_PIPE,
    STATE(13904), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9238), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [651121] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18480), 1,
      anon_sym_RBRACE,
    STATE(13905), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [651150] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18482), 1,
      anon_sym_RBRACE,
    STATE(13906), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [651179] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9696), 1,
      anon_sym_PIPE,
    STATE(13907), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9698), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [651200] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9240), 1,
      anon_sym_PIPE,
    STATE(13908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9242), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [651221] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9244), 1,
      anon_sym_PIPE,
    STATE(13909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9246), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [651242] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18484), 1,
      anon_sym_RBRACE,
    STATE(13910), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [651271] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9202), 1,
      anon_sym_PIPE,
    STATE(13911), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9204), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [651292] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18486), 1,
      anon_sym_DASH_GT,
    STATE(13912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12509), 5,
      anon_sym_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_GT,
  [651313] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18488), 1,
      sym__lowercase_identifier,
    STATE(3170), 1,
      sym_class_path,
    STATE(13913), 1,
      sym_attribute,
    STATE(14806), 1,
      sym__attribute,
    STATE(18762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [651342] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18490), 1,
      anon_sym_RBRACE,
    STATE(13914), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [651371] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18492), 1,
      anon_sym_RBRACE,
    STATE(13915), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [651400] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18494), 1,
      anon_sym_RBRACE,
    STATE(13916), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [651429] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18496), 1,
      anon_sym_RBRACE,
    STATE(13917), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [651458] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17739), 1,
      anon_sym_COMMA,
    ACTIONS(17741), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(17749), 1,
      anon_sym_COLON_COLON,
    STATE(13918), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18498), 2,
      anon_sym_RBRACK,
      anon_sym_SEMI,
  [651485] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9684), 1,
      anon_sym_PIPE,
    STATE(13919), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9686), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [651506] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5079), 1,
      anon_sym_PIPE,
    STATE(13920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5077), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [651527] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18500), 1,
      anon_sym_RBRACE,
    STATE(13921), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [651556] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18502), 1,
      anon_sym_rec,
    STATE(13922), 1,
      sym_attribute,
    STATE(14465), 1,
      sym__attribute,
    STATE(16405), 1,
      sym_module_binding,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18504), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [651583] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18506), 1,
      anon_sym_RBRACE,
    STATE(13923), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [651612] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18508), 1,
      anon_sym_RBRACE,
    STATE(13924), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [651641] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9210), 1,
      anon_sym_PIPE,
    STATE(13925), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9212), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [651662] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7153), 1,
      anon_sym_PIPE,
    STATE(13926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7149), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [651683] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9680), 1,
      anon_sym_PIPE,
    STATE(13927), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9682), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [651704] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18510), 1,
      anon_sym_RBRACE,
    STATE(13928), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [651733] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9672), 1,
      anon_sym_PIPE,
    STATE(13929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9674), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [651754] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9668), 1,
      anon_sym_PIPE,
    STATE(13930), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9670), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [651775] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18512), 1,
      anon_sym_RBRACE,
    STATE(13931), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [651804] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18514), 1,
      anon_sym_RBRACE,
    STATE(13932), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [651833] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18516), 1,
      anon_sym_RBRACE,
    STATE(13933), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [651862] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18409), 1,
      anon_sym_LPAREN,
    ACTIONS(18456), 1,
      sym__lowercase_identifier,
    STATE(13934), 1,
      sym_attribute,
    STATE(14868), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(20384), 2,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [651889] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18518), 1,
      sym__lowercase_identifier,
    STATE(3447), 1,
      sym_class_path,
    STATE(13935), 1,
      sym_attribute,
    STATE(14647), 1,
      sym__attribute,
    STATE(17849), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [651918] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18520), 1,
      anon_sym_RBRACE,
    STATE(13936), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [651947] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18522), 1,
      anon_sym_RBRACE,
    STATE(13937), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [651976] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18524), 1,
      anon_sym_RBRACE,
    STATE(13938), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652005] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18526), 1,
      sym__lowercase_identifier,
    STATE(4059), 1,
      sym_class_path,
    STATE(13939), 1,
      sym_attribute,
    STATE(15070), 1,
      sym__attribute,
    STATE(17903), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652034] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9598), 1,
      anon_sym_PIPE,
    STATE(13940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9600), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [652055] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17739), 1,
      anon_sym_COMMA,
    ACTIONS(17741), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(17749), 1,
      anon_sym_COLON_COLON,
    STATE(13941), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18528), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [652082] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9664), 1,
      anon_sym_PIPE,
    STATE(13942), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9666), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [652103] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9270), 1,
      anon_sym_PIPE,
    STATE(13943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9272), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [652124] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18530), 1,
      anon_sym_RBRACE,
    STATE(13944), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652153] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18532), 1,
      sym__lowercase_identifier,
    STATE(7122), 1,
      sym_class_path,
    STATE(13945), 1,
      sym_attribute,
    STATE(14825), 1,
      sym__attribute,
    STATE(18053), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652182] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18534), 1,
      anon_sym_RBRACE,
    STATE(13946), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652211] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18536), 1,
      sym__lowercase_identifier,
    STATE(7170), 1,
      sym_class_path,
    STATE(13947), 1,
      sym_attribute,
    STATE(14613), 1,
      sym__attribute,
    STATE(18264), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652240] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18538), 1,
      sym__lowercase_identifier,
    STATE(6515), 1,
      sym_class_path,
    STATE(13948), 1,
      sym_attribute,
    STATE(14872), 1,
      sym__attribute,
    STATE(18330), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652269] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18540), 1,
      anon_sym_RBRACE,
    STATE(13949), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652298] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18542), 1,
      anon_sym_RBRACE,
    STATE(13950), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652327] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18544), 1,
      anon_sym_RBRACE,
    STATE(13951), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652356] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18546), 1,
      anon_sym_RBRACE,
    STATE(13952), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652385] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18548), 1,
      anon_sym_RBRACE,
    STATE(13953), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652414] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9274), 1,
      anon_sym_PIPE,
    STATE(13954), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9276), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [652435] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16965), 1,
      anon_sym_PIPE,
    ACTIONS(17853), 1,
      anon_sym_COLON_COLON,
    STATE(13955), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16963), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_PIPE_RBRACK,
  [652458] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18550), 1,
      anon_sym_RBRACE,
    STATE(13956), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652487] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9278), 1,
      anon_sym_PIPE,
    STATE(13957), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9280), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [652508] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18552), 1,
      anon_sym_RBRACE,
    STATE(13958), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652537] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18554), 1,
      anon_sym_RBRACE,
    STATE(13959), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652566] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18556), 1,
      sym__lowercase_identifier,
    STATE(7340), 1,
      sym_class_path,
    STATE(13960), 1,
      sym_attribute,
    STATE(14666), 1,
      sym__attribute,
    STATE(17591), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652595] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18558), 1,
      anon_sym_RBRACE,
    STATE(13961), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652624] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18560), 1,
      anon_sym_RBRACE,
    STATE(13962), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652653] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18562), 1,
      anon_sym_RBRACE,
    STATE(13963), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652682] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18564), 1,
      anon_sym_RBRACE,
    STATE(13964), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652711] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18566), 1,
      anon_sym_RBRACE,
    STATE(13965), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652740] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18568), 1,
      sym__lowercase_identifier,
    STATE(6847), 1,
      sym_class_path,
    STATE(13966), 1,
      sym_attribute,
    STATE(14662), 1,
      sym__attribute,
    STATE(20390), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652769] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18570), 1,
      sym__lowercase_identifier,
    STATE(7443), 1,
      sym_class_path,
    STATE(13967), 1,
      sym_attribute,
    STATE(14887), 1,
      sym__attribute,
    STATE(19260), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652798] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18572), 1,
      sym__lowercase_identifier,
    STATE(5983), 1,
      sym_class_path,
    STATE(13968), 1,
      sym_attribute,
    STATE(15004), 1,
      sym__attribute,
    STATE(18837), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652827] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9248), 1,
      anon_sym_PIPE,
    STATE(13969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9250), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [652848] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18574), 1,
      anon_sym_RBRACE,
    STATE(13970), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652877] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18576), 1,
      sym__lowercase_identifier,
    STATE(4991), 1,
      sym_class_path,
    STATE(13971), 1,
      sym_attribute,
    STATE(14422), 1,
      sym__attribute,
    STATE(17687), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652906] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18578), 1,
      anon_sym_RBRACE,
    STATE(13972), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [652935] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7759), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12847), 1,
      anon_sym_and,
    STATE(13868), 1,
      aux_sym_expression_item_repeat1,
    STATE(13973), 1,
      sym_attribute,
    STATE(14644), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12845), 2,
      anon_sym_in,
      sym_let_and_operator,
  [652962] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9754), 1,
      anon_sym_PIPE,
    STATE(13974), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9756), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [652983] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9642), 1,
      anon_sym_PIPE,
    STATE(13975), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9644), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [653004] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18580), 1,
      sym__lowercase_identifier,
    STATE(3679), 1,
      sym_class_path,
    STATE(13976), 1,
      sym_attribute,
    STATE(14921), 1,
      sym__attribute,
    STATE(19002), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [653033] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18582), 1,
      sym__lowercase_identifier,
    STATE(9722), 1,
      sym_class_path,
    STATE(13977), 1,
      sym_attribute,
    STATE(15039), 1,
      sym__attribute,
    STATE(18410), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [653062] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18584), 1,
      sym__lowercase_identifier,
    STATE(3819), 1,
      sym_class_path,
    STATE(13978), 1,
      sym_attribute,
    STATE(14520), 1,
      sym__attribute,
    STATE(18609), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [653091] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18586), 1,
      anon_sym_RBRACE,
    STATE(13979), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [653120] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18588), 1,
      anon_sym_RBRACE,
    STATE(13980), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [653149] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18590), 1,
      anon_sym_RBRACE,
    STATE(13981), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [653178] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16864), 1,
      anon_sym_PIPE,
    STATE(13982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16862), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [653199] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9228), 1,
      anon_sym_PIPE,
    STATE(13983), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9230), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [653220] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(18464), 1,
      anon_sym_PIPE,
    ACTIONS(18592), 1,
      anon_sym_RBRACK,
    STATE(13984), 1,
      sym_attribute,
    STATE(15102), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [653249] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18594), 1,
      anon_sym_RBRACE,
    STATE(13985), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [653278] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17739), 1,
      anon_sym_COMMA,
    ACTIONS(17741), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(17749), 1,
      anon_sym_COLON_COLON,
    STATE(13986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18596), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [653305] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9162), 1,
      anon_sym_PIPE,
    STATE(13987), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9164), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [653326] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18598), 1,
      anon_sym_RBRACE,
    STATE(13988), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [653355] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18600), 1,
      sym__lowercase_identifier,
    STATE(3920), 1,
      sym_class_path,
    STATE(13989), 1,
      sym_attribute,
    STATE(14829), 1,
      sym__attribute,
    STATE(18530), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [653384] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18602), 1,
      anon_sym_RBRACE,
    STATE(13990), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [653413] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18604), 1,
      anon_sym_RBRACE,
    STATE(13991), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [653442] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18606), 1,
      anon_sym_RBRACE,
    STATE(13992), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [653471] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9634), 1,
      anon_sym_PIPE,
    STATE(13993), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9636), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [653492] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7759), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12950), 1,
      anon_sym_and,
    STATE(13861), 1,
      aux_sym_expression_item_repeat1,
    STATE(13994), 1,
      sym_attribute,
    STATE(14644), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12948), 2,
      anon_sym_in,
      sym_let_and_operator,
  [653519] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16980), 1,
      anon_sym_PIPE,
    ACTIONS(17845), 1,
      anon_sym_COMMA,
    ACTIONS(17853), 1,
      anon_sym_COLON_COLON,
    STATE(13995), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16978), 3,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_PIPE_RBRACK,
  [653544] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18608), 1,
      anon_sym_RBRACE,
    STATE(13996), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [653573] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(16334), 1,
      sym__lowercase_identifier,
    ACTIONS(18409), 1,
      anon_sym_LPAREN,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(13997), 1,
      sym_attribute,
    STATE(14434), 1,
      sym__attribute,
    STATE(16508), 1,
      sym__value_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [653602] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16971), 1,
      anon_sym_PIPE,
    ACTIONS(17853), 1,
      anon_sym_COLON_COLON,
    STATE(13998), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16969), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_PIPE_RBRACK,
  [653625] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18610), 1,
      anon_sym_RBRACE,
    STATE(13999), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [653654] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18612), 1,
      anon_sym_RBRACE,
    STATE(14000), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [653683] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16824), 1,
      anon_sym_PIPE,
    STATE(14001), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16822), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [653704] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17845), 1,
      anon_sym_COMMA,
    ACTIONS(17847), 1,
      anon_sym_PIPE,
    ACTIONS(17851), 1,
      anon_sym_as,
    ACTIONS(17853), 1,
      anon_sym_COLON_COLON,
    STATE(14002), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16959), 2,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [653731] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18614), 1,
      sym__lowercase_identifier,
    STATE(4774), 1,
      sym_class_path,
    STATE(14003), 1,
      sym_attribute,
    STATE(14706), 1,
      sym__attribute,
    STATE(18724), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [653760] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18616), 1,
      anon_sym_RBRACE,
    STATE(14004), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [653789] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18618), 1,
      sym__lowercase_identifier,
    STATE(9246), 1,
      sym_class_path,
    STATE(14005), 1,
      sym_attribute,
    STATE(14487), 1,
      sym__attribute,
    STATE(17854), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [653818] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18620), 1,
      anon_sym_RBRACE,
    STATE(14006), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [653847] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(17875), 1,
      anon_sym_COMMA,
    ACTIONS(17877), 1,
      anon_sym_PIPE,
    ACTIONS(17883), 1,
      anon_sym_COLON_COLON,
    STATE(14007), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18622), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [653874] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18624), 1,
      anon_sym_RBRACE,
    STATE(14008), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [653903] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18626), 1,
      anon_sym_RBRACE,
    STATE(14009), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [653932] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9282), 1,
      anon_sym_PIPE,
    ACTIONS(17783), 1,
      anon_sym_COLON_COLON,
    STATE(14010), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9284), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_PIPE_RBRACK,
  [653955] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9170), 1,
      anon_sym_PIPE,
    STATE(14011), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9172), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [653976] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8278), 1,
      anon_sym_PIPE,
    STATE(14012), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [653997] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18628), 1,
      anon_sym_RBRACE,
    STATE(14013), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [654026] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18630), 1,
      anon_sym_RBRACE,
    STATE(14014), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [654055] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18632), 1,
      anon_sym_RBRACE,
    STATE(14015), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [654084] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18634), 1,
      anon_sym_RBRACE,
    STATE(14016), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [654113] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18636), 1,
      anon_sym_RBRACE,
    STATE(14017), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [654142] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18638), 1,
      anon_sym_RBRACE,
    STATE(14018), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [654171] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9186), 1,
      anon_sym_PIPE,
    STATE(14019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9188), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [654192] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9194), 1,
      anon_sym_PIPE,
    ACTIONS(17775), 1,
      anon_sym_COMMA,
    ACTIONS(17783), 1,
      anon_sym_COLON_COLON,
    STATE(14020), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9196), 3,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_PIPE_RBRACK,
  [654217] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18640), 1,
      anon_sym_RBRACE,
    STATE(14021), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [654246] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18642), 1,
      anon_sym_RBRACE,
    STATE(14022), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [654275] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18644), 1,
      anon_sym_RBRACE,
    STATE(14023), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [654304] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9174), 1,
      anon_sym_PIPE,
    STATE(14024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9176), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [654325] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9144), 1,
      anon_sym_PIPE,
    STATE(14025), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9146), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [654346] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8274), 1,
      anon_sym_PIPE,
    STATE(14026), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8276), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [654367] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9252), 1,
      anon_sym_PIPE,
    STATE(14027), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9254), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [654388] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18646), 1,
      sym__lowercase_identifier,
    STATE(3049), 1,
      sym_class_path,
    STATE(14028), 1,
      sym_attribute,
    STATE(15078), 1,
      sym__attribute,
    STATE(18874), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [654417] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18648), 1,
      anon_sym_RBRACE,
    STATE(14029), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [654446] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9266), 1,
      anon_sym_PIPE,
    ACTIONS(17783), 1,
      anon_sym_COLON_COLON,
    STATE(14030), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9268), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_PIPE_RBRACK,
  [654469] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8270), 1,
      anon_sym_PIPE,
    STATE(14031), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8272), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [654490] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8266), 1,
      anon_sym_PIPE,
    STATE(14032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [654511] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18650), 1,
      anon_sym_RBRACE,
    STATE(14033), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [654540] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9626), 1,
      anon_sym_PIPE,
    STATE(14034), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9628), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [654561] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    STATE(14035), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18652), 4,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_GT,
      anon_sym_AMP,
  [654584] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18654), 1,
      anon_sym_RBRACE,
    STATE(14036), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [654613] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18656), 1,
      anon_sym_RBRACE,
    STATE(14037), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [654642] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18658), 1,
      anon_sym_RBRACE,
    STATE(14038), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [654671] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18660), 1,
      anon_sym_RBRACE,
    STATE(14039), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [654700] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9714), 1,
      anon_sym_PIPE,
    STATE(14040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9716), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [654721] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18662), 1,
      anon_sym_RBRACE,
    STATE(14041), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [654750] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18664), 1,
      anon_sym_RBRACE,
    STATE(14042), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [654779] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18666), 1,
      anon_sym_RBRACE,
    STATE(14043), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [654808] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18668), 1,
      anon_sym_RBRACE,
    STATE(14044), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [654837] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9216), 1,
      anon_sym_PIPE,
    STATE(14045), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9218), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [654858] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9622), 1,
      anon_sym_PIPE,
    STATE(14046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9624), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [654879] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18409), 1,
      anon_sym_LPAREN,
    ACTIONS(18456), 1,
      sym__lowercase_identifier,
    STATE(14047), 1,
      sym_attribute,
    STATE(14774), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(20395), 2,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [654906] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18670), 1,
      sym__lowercase_identifier,
    STATE(5147), 1,
      sym_class_path,
    STATE(14048), 1,
      sym_attribute,
    STATE(14834), 1,
      sym__attribute,
    STATE(19791), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [654935] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9128), 1,
      anon_sym_PIPE,
    STATE(14049), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9130), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [654956] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18672), 1,
      anon_sym_RBRACE,
    STATE(14050), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [654985] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7759), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13078), 1,
      anon_sym_and,
    STATE(14051), 1,
      sym_attribute,
    STATE(14145), 1,
      aux_sym_expression_item_repeat1,
    STATE(14644), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13076), 2,
      anon_sym_in,
      sym_let_and_operator,
  [655012] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18674), 1,
      anon_sym_RBRACE,
    STATE(14052), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655041] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18676), 1,
      anon_sym_RBRACE,
    STATE(14053), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655070] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18678), 1,
      anon_sym_RBRACE,
    STATE(14054), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655099] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9198), 1,
      anon_sym_PIPE,
    STATE(14055), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9200), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [655120] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18680), 1,
      anon_sym_RBRACE,
    STATE(14056), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655149] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18682), 1,
      anon_sym_RBRACE,
    STATE(14057), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655178] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18684), 1,
      anon_sym_RBRACE,
    STATE(14058), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655207] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18686), 1,
      anon_sym_RBRACE,
    STATE(14059), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655236] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18688), 1,
      anon_sym_RBRACE,
    STATE(14060), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655265] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18690), 1,
      anon_sym_RBRACE,
    STATE(14061), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655294] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18692), 1,
      sym__lowercase_identifier,
    STATE(3694), 1,
      sym_class_path,
    STATE(14062), 1,
      sym_attribute,
    STATE(14760), 1,
      sym__attribute,
    STATE(18065), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655323] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18694), 1,
      anon_sym_RBRACE,
    STATE(14063), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655352] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9140), 1,
      anon_sym_PIPE,
    STATE(14064), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9142), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [655373] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9676), 1,
      anon_sym_PIPE,
    STATE(14065), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9678), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [655394] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18696), 1,
      anon_sym_RBRACE,
    STATE(14066), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655423] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18698), 1,
      anon_sym_RBRACE,
    STATE(14067), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655452] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18700), 1,
      anon_sym_RBRACE,
    STATE(14068), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655481] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7759), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12605), 1,
      anon_sym_and,
    STATE(13868), 1,
      aux_sym_expression_item_repeat1,
    STATE(14069), 1,
      sym_attribute,
    STATE(14644), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12603), 2,
      anon_sym_in,
      sym_let_and_operator,
  [655508] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18702), 1,
      anon_sym_RBRACE,
    STATE(14070), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655537] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18704), 1,
      anon_sym_RBRACE,
    STATE(14071), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655566] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18706), 1,
      anon_sym_RBRACE,
    STATE(14072), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655595] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18708), 1,
      anon_sym_RBRACE,
    STATE(14073), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655624] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18710), 1,
      sym__lowercase_identifier,
    STATE(8025), 1,
      sym_class_path,
    STATE(14074), 1,
      sym_attribute,
    STATE(14807), 1,
      sym__attribute,
    STATE(19003), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655653] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18712), 1,
      anon_sym_RBRACE,
    STATE(14075), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655682] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8312), 1,
      anon_sym_PIPE,
    STATE(14076), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [655703] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18714), 1,
      anon_sym_RBRACE,
    STATE(14077), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655732] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18460), 1,
      anon_sym_and,
    STATE(14078), 1,
      sym_attribute,
    STATE(14157), 1,
      aux_sym_module_type_constraint_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12540), 4,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_with,
  [655755] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18716), 1,
      anon_sym_RBRACE,
    STATE(14079), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655784] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18718), 1,
      anon_sym_RBRACE,
    STATE(14080), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655813] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18720), 1,
      anon_sym_RBRACE,
    STATE(14081), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655842] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18722), 1,
      sym__lowercase_identifier,
    STATE(4391), 1,
      sym_class_path,
    STATE(14082), 1,
      sym_attribute,
    STATE(14577), 1,
      sym__attribute,
    STATE(20423), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655871] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18724), 1,
      sym__lowercase_identifier,
    STATE(6177), 1,
      sym_class_path,
    STATE(14083), 1,
      sym_attribute,
    STATE(15055), 1,
      sym__attribute,
    STATE(18450), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655900] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18726), 1,
      sym__lowercase_identifier,
    STATE(6720), 1,
      sym_class_path,
    STATE(14084), 1,
      sym_attribute,
    STATE(14932), 1,
      sym__attribute,
    STATE(17795), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655929] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9282), 1,
      anon_sym_COLON2,
    ACTIONS(17837), 1,
      anon_sym_COLON_COLON,
    STATE(14085), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9284), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_as,
  [655952] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18728), 1,
      anon_sym_RBRACE,
    STATE(14086), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [655981] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9220), 1,
      anon_sym_PIPE,
    STATE(14087), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9222), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [656002] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18730), 1,
      sym__lowercase_identifier,
    STATE(5293), 1,
      sym_class_path,
    STATE(14088), 1,
      sym_attribute,
    STATE(15003), 1,
      sym__attribute,
    STATE(18947), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [656031] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18732), 1,
      anon_sym_RBRACE,
    STATE(14089), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [656060] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18734), 1,
      sym__lowercase_identifier,
    STATE(6729), 1,
      sym_class_path,
    STATE(14090), 1,
      sym_attribute,
    STATE(14603), 1,
      sym__attribute,
    STATE(18686), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [656089] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18736), 1,
      anon_sym_RBRACE,
    STATE(14091), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [656118] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9194), 1,
      anon_sym_COLON2,
    ACTIONS(17831), 1,
      anon_sym_COMMA,
    ACTIONS(17837), 1,
      anon_sym_COLON_COLON,
    STATE(14092), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9196), 3,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_as,
  [656143] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16629), 1,
      anon_sym_PIPE,
    STATE(14093), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16627), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [656164] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9736), 1,
      anon_sym_PIPE,
    STATE(14094), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9738), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [656185] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18738), 1,
      anon_sym_RBRACE,
    STATE(14095), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [656214] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9178), 1,
      anon_sym_PIPE,
    STATE(14096), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9180), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [656235] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18740), 1,
      sym__lowercase_identifier,
    STATE(4118), 1,
      sym_class_path,
    STATE(14097), 1,
      sym_attribute,
    STATE(14475), 1,
      sym__attribute,
    STATE(18119), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [656264] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18742), 1,
      anon_sym_RBRACE,
    STATE(14098), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [656293] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18744), 1,
      anon_sym_RBRACE,
    STATE(14099), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [656322] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18746), 1,
      anon_sym_RBRACE,
    STATE(14100), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [656351] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18748), 1,
      anon_sym_RBRACE,
    STATE(14101), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [656380] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9190), 1,
      anon_sym_PIPE,
    STATE(14102), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9192), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [656401] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16834), 1,
      anon_sym_PIPE,
    STATE(14103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16832), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [656422] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9266), 1,
      anon_sym_COLON2,
    ACTIONS(17837), 1,
      anon_sym_COLON_COLON,
    STATE(14104), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9268), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_as,
  [656445] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18750), 1,
      anon_sym_RBRACE,
    STATE(14105), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [656474] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18752), 1,
      anon_sym_RBRACE,
    STATE(14106), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [656503] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18754), 1,
      anon_sym_RBRACE,
    STATE(14107), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [656532] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16721), 1,
      anon_sym_PIPE,
    STATE(14108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16719), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [656553] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18756), 1,
      anon_sym_RBRACE,
    STATE(14109), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [656582] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16888), 1,
      anon_sym_PIPE,
    STATE(14110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16886), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [656603] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18409), 1,
      anon_sym_LPAREN,
    ACTIONS(18456), 1,
      sym__lowercase_identifier,
    STATE(14111), 1,
      sym_attribute,
    STATE(14828), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(20438), 2,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [656630] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18758), 1,
      anon_sym_RBRACE,
    STATE(14112), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [656659] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18760), 1,
      sym__lowercase_identifier,
    STATE(5891), 1,
      sym_class_path,
    STATE(14113), 1,
      sym_attribute,
    STATE(14779), 1,
      sym__attribute,
    STATE(18290), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [656688] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18762), 1,
      anon_sym_RBRACE,
    STATE(14114), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [656717] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18764), 1,
      sym__lowercase_identifier,
    STATE(4351), 1,
      sym_class_path,
    STATE(14115), 1,
      sym_attribute,
    STATE(14851), 1,
      sym__attribute,
    STATE(20435), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [656746] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17845), 1,
      anon_sym_COMMA,
    ACTIONS(17847), 1,
      anon_sym_PIPE,
    ACTIONS(17851), 1,
      anon_sym_as,
    ACTIONS(17853), 1,
      anon_sym_COLON_COLON,
    STATE(14116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18424), 2,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [656773] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12069), 1,
      anon_sym_RPAREN,
    STATE(14117), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11562), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [656794] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18766), 1,
      anon_sym_RBRACE,
    STATE(14118), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [656823] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18768), 1,
      anon_sym_RBRACE,
    STATE(14119), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [656852] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18770), 1,
      anon_sym_RBRACE,
    STATE(14120), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [656881] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18772), 1,
      anon_sym_RBRACE,
    STATE(14121), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [656910] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18774), 1,
      anon_sym_RBRACE,
    STATE(14122), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [656939] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18776), 1,
      anon_sym_RBRACE,
    STATE(14123), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [656968] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18778), 1,
      sym__lowercase_identifier,
    ACTIONS(18780), 1,
      anon_sym_BANG,
    STATE(12575), 1,
      sym__instance_variable_name,
    STATE(14124), 1,
      sym_attribute,
    STATE(14278), 1,
      aux_sym_instance_variable_specification_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18782), 2,
      anon_sym_mutable,
      anon_sym_virtual,
  [656995] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18784), 1,
      anon_sym_RBRACE,
    STATE(14125), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657024] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18786), 1,
      anon_sym_RBRACE,
    STATE(14126), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657053] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18788), 1,
      anon_sym_RBRACE,
    STATE(14127), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657082] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(16334), 1,
      sym__lowercase_identifier,
    ACTIONS(18409), 1,
      anon_sym_LPAREN,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(14128), 1,
      sym_attribute,
    STATE(14772), 1,
      sym__attribute,
    STATE(16579), 1,
      sym__value_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657111] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18790), 1,
      sym__lowercase_identifier,
    STATE(5021), 1,
      sym_class_path,
    STATE(14129), 1,
      sym_attribute,
    STATE(14615), 1,
      sym__attribute,
    STATE(18210), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657140] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18792), 1,
      anon_sym_RBRACE,
    STATE(14130), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657169] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8262), 1,
      anon_sym_PIPE,
    STATE(14131), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [657190] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18794), 1,
      anon_sym_RBRACE,
    STATE(14132), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657219] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18796), 1,
      sym__lowercase_identifier,
    STATE(6269), 1,
      sym_class_path,
    STATE(14133), 1,
      sym_attribute,
    STATE(14942), 1,
      sym__attribute,
    STATE(18490), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657248] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18798), 1,
      anon_sym_RBRACE,
    STATE(14134), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657277] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18800), 1,
      anon_sym_RBRACE,
    STATE(14135), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657306] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18802), 1,
      anon_sym_RBRACE,
    STATE(14136), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657335] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16840), 1,
      anon_sym_PIPE,
    STATE(14137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16838), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [657356] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18804), 1,
      anon_sym_RBRACE,
    STATE(14138), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657385] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18806), 1,
      sym__lowercase_identifier,
    STATE(7720), 1,
      sym_class_path,
    STATE(14139), 1,
      sym_attribute,
    STATE(14499), 1,
      sym__attribute,
    STATE(18648), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657414] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18808), 1,
      anon_sym_RBRACE,
    STATE(14140), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657443] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16655), 1,
      anon_sym_PIPE,
    STATE(14141), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16653), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [657464] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7759), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13168), 1,
      anon_sym_and,
    STATE(13973), 1,
      aux_sym_expression_item_repeat1,
    STATE(14142), 1,
      sym_attribute,
    STATE(14644), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13166), 2,
      anon_sym_in,
      sym_let_and_operator,
  [657491] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    ACTIONS(14574), 1,
      anon_sym_POUND,
    ACTIONS(18810), 1,
      anon_sym_DASH_GT,
    STATE(12593), 1,
      sym_type_constructor_path,
    STATE(14143), 1,
      sym_attribute,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657520] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18812), 1,
      anon_sym_RBRACE,
    STATE(14144), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657549] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7759), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13176), 1,
      anon_sym_and,
    STATE(13868), 1,
      aux_sym_expression_item_repeat1,
    STATE(14145), 1,
      sym_attribute,
    STATE(14644), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13174), 2,
      anon_sym_in,
      sym_let_and_operator,
  [657576] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18814), 1,
      anon_sym_RBRACE,
    STATE(14146), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657605] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17845), 1,
      anon_sym_COMMA,
    ACTIONS(17847), 1,
      anon_sym_PIPE,
    ACTIONS(17851), 1,
      anon_sym_as,
    ACTIONS(17853), 1,
      anon_sym_COLON_COLON,
    STATE(14147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16919), 2,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [657632] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18816), 1,
      anon_sym_RBRACE,
    STATE(14148), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657661] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9688), 1,
      anon_sym_PIPE,
    STATE(14149), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9690), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [657682] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17775), 1,
      anon_sym_COMMA,
    ACTIONS(17777), 1,
      anon_sym_PIPE,
    ACTIONS(17781), 1,
      anon_sym_as,
    ACTIONS(17783), 1,
      anon_sym_COLON_COLON,
    STATE(14150), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18498), 2,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [657709] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18818), 1,
      anon_sym_RBRACE,
    STATE(14151), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657738] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18820), 1,
      sym__lowercase_identifier,
    ACTIONS(18822), 1,
      anon_sym_LBRACK,
    ACTIONS(18824), 1,
      anon_sym_virtual,
    STATE(11023), 1,
      sym_class_type_binding,
    STATE(14152), 1,
      sym_attribute,
    STATE(14646), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657767] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    ACTIONS(18826), 1,
      sym__lowercase_identifier,
    STATE(5724), 1,
      sym_class_path,
    STATE(14153), 1,
      sym_attribute,
    STATE(15035), 1,
      sym__attribute,
    STATE(18911), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657796] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18828), 1,
      anon_sym_RBRACE,
    STATE(14154), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657825] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18830), 1,
      anon_sym_RBRACE,
    STATE(14155), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657854] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18832), 1,
      anon_sym_RBRACE,
    STATE(14156), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657883] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18834), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14157), 2,
      sym_attribute,
      aux_sym_module_type_constraint_repeat1,
    ACTIONS(11936), 4,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_with,
  [657904] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18837), 1,
      anon_sym_RBRACE,
    STATE(14158), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657933] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18839), 1,
      anon_sym_RBRACE,
    STATE(14159), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657962] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18841), 1,
      anon_sym_RBRACE,
    STATE(14160), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657991] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18843), 1,
      anon_sym_RBRACE,
    STATE(14161), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658020] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7759), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13142), 1,
      anon_sym_and,
    STATE(13868), 1,
      aux_sym_expression_item_repeat1,
    STATE(14162), 1,
      sym_attribute,
    STATE(14644), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13140), 2,
      anon_sym_in,
      sym_let_and_operator,
  [658047] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18845), 1,
      anon_sym_RBRACE,
    STATE(14163), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658076] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18847), 1,
      anon_sym_RBRACE,
    STATE(14164), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658105] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9182), 1,
      anon_sym_PIPE,
    STATE(14165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [658126] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18849), 1,
      anon_sym_RBRACE,
    STATE(14166), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658155] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18851), 1,
      anon_sym_RBRACE,
    STATE(14167), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658184] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18853), 1,
      anon_sym_RBRACE,
    STATE(14168), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658213] = 9,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    ACTIONS(18855), 1,
      anon_sym_RBRACE,
    STATE(14169), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658242] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    STATE(14170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13340), 3,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
  [658264] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17831), 1,
      anon_sym_COMMA,
    ACTIONS(17833), 1,
      anon_sym_PIPE,
    ACTIONS(17835), 1,
      anon_sym_as,
    ACTIONS(17837), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18861), 1,
      anon_sym_RPAREN,
    STATE(14171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658290] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11252), 1,
      sym__lowercase_identifier,
    ACTIONS(18863), 1,
      anon_sym_POUND,
    STATE(9345), 1,
      sym_type_constructor_path,
    STATE(14172), 1,
      sym_attribute,
    STATE(17537), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658316] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14173), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(15567), 1,
      sym_field_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658342] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(18867), 1,
      anon_sym_SEMI,
    ACTIONS(18869), 1,
      anon_sym_GT_RBRACE,
    STATE(14174), 1,
      sym_attribute,
    STATE(15419), 1,
      sym_instance_variable_expression,
    STATE(15653), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658368] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(18871), 1,
      anon_sym_SEMI,
    ACTIONS(18873), 1,
      anon_sym_GT_RBRACE,
    STATE(14175), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(15729), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658394] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14176), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16176), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658420] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11340), 1,
      sym__lowercase_identifier,
    ACTIONS(18875), 1,
      anon_sym_POUND,
    STATE(9488), 1,
      sym_type_constructor_path,
    STATE(14177), 1,
      sym_attribute,
    STATE(17458), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658446] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12370), 1,
      sym__lowercase_identifier,
    ACTIONS(18877), 1,
      anon_sym_POUND,
    STATE(12687), 1,
      sym_type_constructor_path,
    STATE(14178), 1,
      sym_attribute,
    STATE(17280), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658472] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9300), 1,
      sym__uppercase_identifier,
    ACTIONS(18879), 1,
      anon_sym_LPAREN,
    STATE(8923), 1,
      sym__constructor_name,
    STATE(10353), 1,
      sym_constructor_path,
    STATE(14179), 1,
      sym_attribute,
    STATE(20419), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658498] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18881), 1,
      anon_sym_type,
    ACTIONS(18883), 1,
      anon_sym_module,
    STATE(14180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13439), 3,
      sym_constrain_type,
      sym_constrain_module,
      sym_constrain_module_type,
  [658520] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14181), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16605), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658546] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14182), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16257), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658572] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17831), 1,
      anon_sym_COMMA,
    ACTIONS(17833), 1,
      anon_sym_PIPE,
    ACTIONS(17835), 1,
      anon_sym_as,
    ACTIONS(17837), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18885), 1,
      anon_sym_RPAREN,
    STATE(14183), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658598] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14184), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(16167), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658624] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18887), 1,
      anon_sym_type,
    ACTIONS(18889), 1,
      anon_sym_module,
    STATE(14185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9477), 3,
      sym_constrain_type,
      sym_constrain_module,
      sym_constrain_module_type,
  [658646] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(18891), 1,
      anon_sym_SEMI,
    ACTIONS(18893), 1,
      anon_sym_GT_RBRACE,
    STATE(14186), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(15876), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658672] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18895), 1,
      anon_sym_RPAREN,
    STATE(14187), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658698] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18778), 1,
      sym__lowercase_identifier,
    STATE(12397), 1,
      sym__instance_variable_name,
    STATE(14188), 1,
      sym_attribute,
    STATE(14669), 1,
      aux_sym_instance_variable_specification_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18782), 2,
      anon_sym_mutable,
      anon_sym_virtual,
  [658722] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14189), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(16056), 1,
      sym_field_binding_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658748] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(18897), 1,
      anon_sym_SEMI,
    ACTIONS(18899), 1,
      anon_sym_GT_RBRACE,
    STATE(14190), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16070), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658774] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(18901), 1,
      anon_sym_RPAREN,
    STATE(14191), 1,
      sym_attribute,
    STATE(15297), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658800] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18903), 1,
      anon_sym_RPAREN,
    STATE(14192), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658826] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14193), 1,
      sym_attribute,
    STATE(14194), 1,
      sym_field_path,
    STATE(15828), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658852] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18905), 1,
      anon_sym_EQ,
    ACTIONS(18907), 1,
      anon_sym_COLON2,
    STATE(14194), 1,
      sym_attribute,
    STATE(15494), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18909), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [658876] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(18911), 1,
      anon_sym_RPAREN,
    STATE(14195), 1,
      sym_attribute,
    STATE(15594), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658902] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12321), 1,
      sym__lowercase_identifier,
    ACTIONS(18913), 1,
      anon_sym_POUND,
    STATE(9353), 1,
      sym_type_constructor_path,
    STATE(14196), 1,
      sym_attribute,
    STATE(17359), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658928] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11352), 1,
      sym__lowercase_identifier,
    ACTIONS(18915), 1,
      anon_sym_POUND,
    STATE(10157), 1,
      sym_type_constructor_path,
    STATE(14197), 1,
      sym_attribute,
    STATE(17325), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658954] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(18917), 1,
      anon_sym_RBRACK,
    STATE(14198), 1,
      sym_attribute,
    STATE(16267), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658980] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(18919), 1,
      anon_sym_SEMI,
    ACTIONS(18921), 1,
      anon_sym_GT_RBRACE,
    STATE(14199), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(15659), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659006] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11320), 1,
      sym__lowercase_identifier,
    ACTIONS(18923), 1,
      anon_sym_POUND,
    STATE(13725), 1,
      sym_type_constructor_path,
    STATE(14200), 1,
      sym_attribute,
    STATE(17229), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659032] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14201), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(15593), 1,
      sym_field_binding_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659058] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14202), 1,
      sym_attribute,
    STATE(15730), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659084] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(14203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18925), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [659102] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(14204), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18927), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [659120] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(18929), 1,
      anon_sym_RBRACK,
    STATE(14205), 1,
      sym_attribute,
    STATE(15333), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659146] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11316), 1,
      sym__lowercase_identifier,
    ACTIONS(18931), 1,
      anon_sym_POUND,
    STATE(10780), 1,
      sym_type_constructor_path,
    STATE(14206), 1,
      sym_attribute,
    STATE(17037), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659172] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18933), 1,
      sym__lowercase_identifier,
    ACTIONS(18935), 1,
      anon_sym_LPAREN,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    STATE(10358), 1,
      sym_parenthesized_operator,
    STATE(12601), 1,
      sym__value_name,
    STATE(14207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659198] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14208), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(15107), 1,
      sym_field_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659224] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(18939), 1,
      anon_sym_SEMI,
    ACTIONS(18941), 1,
      anon_sym_GT_RBRACE,
    STATE(14209), 1,
      sym_attribute,
    STATE(15324), 1,
      sym_instance_variable_expression,
    STATE(15653), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659250] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(18943), 1,
      anon_sym_RPAREN,
    STATE(14210), 1,
      sym_attribute,
    STATE(15159), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659276] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14211), 1,
      sym_attribute,
    STATE(15152), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659302] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14212), 1,
      sym_attribute,
    STATE(15243), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659328] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18945), 1,
      anon_sym_type,
    ACTIONS(18947), 1,
      anon_sym_module,
    STATE(14213), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10394), 3,
      sym_constrain_type,
      sym_constrain_module,
      sym_constrain_module_type,
  [659350] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14214), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(15131), 1,
      sym_field_binding_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659376] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(18879), 1,
      anon_sym_LPAREN,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(10473), 1,
      sym_constructor_path,
    STATE(14215), 1,
      sym_attribute,
    STATE(20440), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659402] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(18879), 1,
      anon_sym_LPAREN,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(10496), 1,
      sym_constructor_path,
    STATE(14216), 1,
      sym_attribute,
    STATE(20440), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659428] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14217), 1,
      sym_attribute,
    STATE(15452), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659454] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14218), 1,
      sym_attribute,
    STATE(15263), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659480] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14219), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(16045), 1,
      sym_field_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659506] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18945), 1,
      anon_sym_type,
    ACTIONS(18947), 1,
      anon_sym_module,
    STATE(14220), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9477), 3,
      sym_constrain_type,
      sym_constrain_module,
      sym_constrain_module_type,
  [659528] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16457), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(14221), 1,
      sym_attribute,
    STATE(14262), 1,
      aux_sym_expression_item_repeat1,
    STATE(15602), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13269), 2,
      anon_sym_and,
      anon_sym_in,
  [659552] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(18949), 1,
      anon_sym_SEMI,
    ACTIONS(18951), 1,
      anon_sym_GT_RBRACE,
    STATE(14222), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16160), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659578] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14223), 1,
      sym_attribute,
    STATE(15990), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659604] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18887), 1,
      anon_sym_type,
    ACTIONS(18889), 1,
      anon_sym_module,
    STATE(14224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11149), 3,
      sym_constrain_type,
      sym_constrain_module,
      sym_constrain_module_type,
  [659626] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16457), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(14225), 1,
      sym_attribute,
    STATE(14262), 1,
      aux_sym_expression_item_repeat1,
    STATE(15602), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13084), 2,
      anon_sym_and,
      anon_sym_in,
  [659650] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(18953), 1,
      anon_sym_RPAREN,
    STATE(14226), 1,
      sym_attribute,
    STATE(15346), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659676] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14227), 1,
      sym_attribute,
    STATE(15669), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659702] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14228), 1,
      sym_attribute,
    STATE(15622), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659728] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18955), 1,
      sym__lowercase_identifier,
    ACTIONS(18959), 1,
      anon_sym_BANG,
    STATE(14229), 1,
      sym_attribute,
    STATE(14873), 1,
      aux_sym_method_specification_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18957), 2,
      anon_sym_private,
      anon_sym_virtual,
  [659752] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18961), 1,
      anon_sym_RPAREN,
    STATE(14230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659778] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(18963), 1,
      anon_sym_RPAREN,
    STATE(14231), 1,
      sym_attribute,
    STATE(15937), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659804] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(18965), 1,
      anon_sym_SEMI,
    ACTIONS(18967), 1,
      anon_sym_GT_RBRACE,
    STATE(14232), 1,
      sym_attribute,
    STATE(15380), 1,
      sym_instance_variable_expression,
    STATE(15653), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659830] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(18969), 1,
      anon_sym_RBRACK,
    STATE(14233), 1,
      sym_attribute,
    STATE(16052), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659856] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14234), 1,
      sym_attribute,
    STATE(16404), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659882] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(18971), 1,
      anon_sym_SEMI,
    ACTIONS(18973), 1,
      anon_sym_GT_RBRACE,
    STATE(14235), 1,
      sym_attribute,
    STATE(15513), 1,
      sym_instance_variable_expression,
    STATE(15653), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659908] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(18975), 1,
      anon_sym_SEMI,
    ACTIONS(18977), 1,
      anon_sym_GT_RBRACE,
    STATE(14236), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16037), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659934] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(18979), 1,
      anon_sym_SEMI,
    ACTIONS(18981), 1,
      anon_sym_GT_RBRACE,
    STATE(14237), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(15692), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659960] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11298), 1,
      sym__lowercase_identifier,
    ACTIONS(18983), 1,
      anon_sym_POUND,
    STATE(10328), 1,
      sym_type_constructor_path,
    STATE(14238), 1,
      sym_attribute,
    STATE(17343), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659986] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(18985), 1,
      anon_sym_SEMI,
    ACTIONS(18987), 1,
      anon_sym_GT_RBRACE,
    STATE(14239), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(15817), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660012] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(18879), 1,
      anon_sym_LPAREN,
    STATE(7106), 1,
      sym__constructor_name,
    STATE(10353), 1,
      sym_constructor_path,
    STATE(14240), 1,
      sym_attribute,
    STATE(20440), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660038] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(18989), 1,
      anon_sym_SEMI,
    ACTIONS(18991), 1,
      anon_sym_GT_RBRACE,
    STATE(14241), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16274), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660064] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(18993), 1,
      anon_sym_SEMI,
    ACTIONS(18995), 1,
      anon_sym_GT_RBRACE,
    STATE(14242), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16318), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660090] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(18997), 1,
      anon_sym_RPAREN,
    STATE(14243), 1,
      sym_attribute,
    STATE(16192), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660116] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9300), 1,
      sym__uppercase_identifier,
    ACTIONS(18879), 1,
      anon_sym_LPAREN,
    STATE(8923), 1,
      sym__constructor_name,
    STATE(10496), 1,
      sym_constructor_path,
    STATE(14244), 1,
      sym_attribute,
    STATE(20419), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660142] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(18999), 1,
      anon_sym_RPAREN,
    STATE(14245), 1,
      sym_attribute,
    STATE(15603), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660168] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19001), 1,
      anon_sym_SEMI,
    ACTIONS(19003), 1,
      anon_sym_GT_RBRACE,
    STATE(14246), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16429), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660194] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19005), 1,
      anon_sym_type,
    ACTIONS(19007), 1,
      anon_sym_module,
    STATE(14247), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9477), 3,
      sym_constrain_type,
      sym_constrain_module,
      sym_constrain_module_type,
  [660216] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14248), 1,
      sym_attribute,
    STATE(16424), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660242] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9300), 1,
      sym__uppercase_identifier,
    ACTIONS(18879), 1,
      anon_sym_LPAREN,
    STATE(8923), 1,
      sym__constructor_name,
    STATE(10473), 1,
      sym_constructor_path,
    STATE(14249), 1,
      sym_attribute,
    STATE(20419), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660268] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14250), 1,
      sym_attribute,
    STATE(15096), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660294] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14251), 1,
      sym_attribute,
    STATE(15850), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660320] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17831), 1,
      anon_sym_COMMA,
    ACTIONS(17833), 1,
      anon_sym_PIPE,
    ACTIONS(17835), 1,
      anon_sym_as,
    ACTIONS(17837), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19009), 1,
      anon_sym_RPAREN,
    STATE(14252), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660346] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14253), 1,
      sym_attribute,
    STATE(15351), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660372] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(19011), 1,
      anon_sym_RPAREN,
    STATE(14254), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660398] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9338), 1,
      sym__uppercase_identifier,
    ACTIONS(19013), 1,
      anon_sym_LPAREN,
    STATE(13339), 1,
      sym__constructor_name,
    STATE(14255), 1,
      sym_attribute,
    STATE(16647), 1,
      sym_constructor_path,
    STATE(20249), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660424] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14256), 1,
      sym_attribute,
    STATE(16408), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660450] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19015), 1,
      anon_sym_AMP,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14257), 2,
      sym_attribute,
      aux_sym_tag_specification_repeat1,
    ACTIONS(18652), 3,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_GT,
  [660470] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11318), 1,
      sym__lowercase_identifier,
    ACTIONS(19018), 1,
      anon_sym_POUND,
    STATE(11031), 1,
      sym_type_constructor_path,
    STATE(14258), 1,
      sym_attribute,
    STATE(17395), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660496] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12333), 1,
      sym__lowercase_identifier,
    ACTIONS(19020), 1,
      anon_sym_POUND,
    STATE(9528), 1,
      sym_type_constructor_path,
    STATE(14259), 1,
      sym_attribute,
    STATE(17263), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660522] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14260), 1,
      sym_attribute,
    STATE(15167), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660548] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19005), 1,
      anon_sym_type,
    ACTIONS(19007), 1,
      anon_sym_module,
    STATE(14261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13894), 3,
      sym_constrain_type,
      sym_constrain_module,
      sym_constrain_module_type,
  [660570] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(19022), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(15602), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11940), 2,
      anon_sym_and,
      anon_sym_in,
    STATE(14262), 2,
      sym_attribute,
      aux_sym_expression_item_repeat1,
  [660592] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14263), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(16623), 1,
      sym_field_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660618] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(19025), 1,
      anon_sym_RPAREN,
    STATE(14264), 1,
      sym_attribute,
    STATE(16053), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660644] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18051), 1,
      anon_sym_AMP,
    STATE(14257), 1,
      aux_sym_tag_specification_repeat1,
    STATE(14265), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19027), 3,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_GT,
  [660666] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(19029), 1,
      anon_sym_RPAREN,
    STATE(14266), 1,
      sym_attribute,
    STATE(16252), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660692] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14267), 1,
      sym_attribute,
    STATE(16198), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660718] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19031), 1,
      anon_sym_SEMI,
    ACTIONS(19033), 1,
      anon_sym_GT_RBRACE,
    STATE(14268), 1,
      sym_attribute,
    STATE(15325), 1,
      sym_instance_variable_expression,
    STATE(15653), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660744] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11368), 1,
      sym__lowercase_identifier,
    ACTIONS(19035), 1,
      anon_sym_POUND,
    STATE(10685), 1,
      sym_type_constructor_path,
    STATE(14269), 1,
      sym_attribute,
    STATE(17478), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660770] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12272), 1,
      sym__lowercase_identifier,
    ACTIONS(19037), 1,
      anon_sym_POUND,
    STATE(9289), 1,
      sym_type_constructor_path,
    STATE(14270), 1,
      sym_attribute,
    STATE(17230), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660796] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14271), 1,
      sym_attribute,
    STATE(16105), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660822] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12347), 1,
      sym__lowercase_identifier,
    ACTIONS(19039), 1,
      anon_sym_POUND,
    STATE(11804), 1,
      sym_type_constructor_path,
    STATE(14272), 1,
      sym_attribute,
    STATE(17375), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660848] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19041), 1,
      anon_sym_type,
    ACTIONS(19043), 1,
      anon_sym_module,
    STATE(14273), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9477), 3,
      sym_constrain_type,
      sym_constrain_module,
      sym_constrain_module_type,
  [660870] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14274), 1,
      sym_attribute,
    STATE(15460), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660896] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(19045), 1,
      anon_sym_RPAREN,
    STATE(14275), 1,
      sym_attribute,
    STATE(15518), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660922] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 5,
      anon_sym_EQ,
      anon_sym_of,
      anon_sym_COLON2,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [660940] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19047), 1,
      anon_sym_SEMI,
    ACTIONS(19049), 1,
      anon_sym_GT_RBRACE,
    STATE(14277), 1,
      sym_attribute,
    STATE(15195), 1,
      sym_instance_variable_expression,
    STATE(15653), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660966] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18778), 1,
      sym__lowercase_identifier,
    STATE(12241), 1,
      sym__instance_variable_name,
    STATE(14278), 1,
      sym_attribute,
    STATE(14669), 1,
      aux_sym_instance_variable_specification_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18782), 2,
      anon_sym_mutable,
      anon_sym_virtual,
  [660990] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14279), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(15111), 1,
      sym_field_binding_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661016] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14280), 1,
      sym_attribute,
    STATE(16152), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661042] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18778), 1,
      sym__lowercase_identifier,
    STATE(12241), 1,
      sym__instance_variable_name,
    STATE(14188), 1,
      aux_sym_instance_variable_specification_repeat1,
    STATE(14281), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18782), 2,
      anon_sym_mutable,
      anon_sym_virtual,
  [661066] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19051), 1,
      anon_sym_SEMI,
    ACTIONS(19053), 1,
      anon_sym_GT_RBRACE,
    STATE(14282), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16044), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661092] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19055), 1,
      anon_sym_SEMI,
    ACTIONS(19057), 1,
      anon_sym_GT_RBRACE,
    STATE(14283), 1,
      sym_attribute,
    STATE(15436), 1,
      sym_instance_variable_expression,
    STATE(15653), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661118] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14284), 1,
      sym_attribute,
    STATE(15122), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661144] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14285), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(16416), 1,
      sym_field_binding_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661170] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(19059), 1,
      anon_sym_EQ,
    ACTIONS(19061), 1,
      anon_sym_of,
    ACTIONS(19063), 1,
      anon_sym_COLON2,
    STATE(14286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12717), 2,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [661194] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16457), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(14262), 1,
      aux_sym_expression_item_repeat1,
    STATE(14287), 1,
      sym_attribute,
    STATE(15602), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12872), 2,
      anon_sym_and,
      anon_sym_in,
  [661218] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(19065), 1,
      anon_sym_RPAREN,
    STATE(14288), 1,
      sym_attribute,
    STATE(16332), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661244] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16457), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(14262), 1,
      aux_sym_expression_item_repeat1,
    STATE(14289), 1,
      sym_attribute,
    STATE(15602), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12876), 2,
      anon_sym_and,
      anon_sym_in,
  [661268] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12266), 1,
      sym__lowercase_identifier,
    ACTIONS(19067), 1,
      anon_sym_POUND,
    STATE(13174), 1,
      sym_type_constructor_path,
    STATE(14290), 1,
      sym_attribute,
    STATE(17311), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661294] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18881), 1,
      anon_sym_type,
    ACTIONS(18883), 1,
      anon_sym_module,
    STATE(14291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13594), 3,
      sym_constrain_type,
      sym_constrain_module,
      sym_constrain_module_type,
  [661316] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    STATE(14292), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16459), 3,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
  [661338] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    ACTIONS(19069), 1,
      anon_sym_POUND,
    STATE(12478), 1,
      sym_type_constructor_path,
    STATE(14293), 1,
      sym_attribute,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661364] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19071), 1,
      anon_sym_SEMI,
    ACTIONS(19073), 1,
      anon_sym_GT_RBRACE,
    STATE(14294), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16265), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661390] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    STATE(14295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19075), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [661412] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19077), 1,
      anon_sym_SEMI,
    ACTIONS(19079), 1,
      anon_sym_GT_RBRACE,
    STATE(14296), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16348), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661438] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14297), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(16626), 1,
      sym_field_binding_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661464] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14298), 1,
      sym_attribute,
    STATE(16041), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661490] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11210), 1,
      sym__lowercase_identifier,
    ACTIONS(19081), 1,
      anon_sym_POUND,
    STATE(10946), 1,
      sym_type_constructor_path,
    STATE(14299), 1,
      sym_attribute,
    STATE(17296), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661516] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19041), 1,
      anon_sym_type,
    ACTIONS(19043), 1,
      anon_sym_module,
    STATE(14300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10801), 3,
      sym_constrain_type,
      sym_constrain_module,
      sym_constrain_module_type,
  [661538] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    STATE(14301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13453), 3,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
  [661560] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9338), 1,
      sym__uppercase_identifier,
    ACTIONS(19013), 1,
      anon_sym_LPAREN,
    STATE(13339), 1,
      sym__constructor_name,
    STATE(14302), 1,
      sym_attribute,
    STATE(16650), 1,
      sym_constructor_path,
    STATE(20249), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661586] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19083), 1,
      anon_sym_SEMI,
    ACTIONS(19085), 1,
      anon_sym_GT_RBRACE,
    STATE(14303), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(15698), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661612] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19087), 1,
      anon_sym_SEMI,
    ACTIONS(19089), 1,
      anon_sym_GT_RBRACE,
    STATE(14304), 1,
      sym_attribute,
    STATE(15503), 1,
      sym_instance_variable_expression,
    STATE(15653), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661638] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(19091), 1,
      anon_sym_EQ,
    ACTIONS(19093), 1,
      anon_sym_of,
    ACTIONS(19095), 1,
      anon_sym_COLON2,
    STATE(14305), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12699), 2,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [661662] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(19097), 1,
      anon_sym_RPAREN,
    STATE(14306), 1,
      sym_attribute,
    STATE(15631), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661688] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14307), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(16290), 1,
      sym_field_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661714] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14308), 1,
      sym_attribute,
    STATE(15813), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661740] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14309), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(15326), 1,
      sym_field_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661766] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19099), 1,
      anon_sym_SEMI,
    ACTIONS(19101), 1,
      anon_sym_GT_RBRACE,
    STATE(14310), 1,
      sym_attribute,
    STATE(15229), 1,
      sym_instance_variable_expression,
    STATE(15653), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661792] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19103), 1,
      anon_sym_SEMI,
    ACTIONS(19105), 1,
      anon_sym_GT_RBRACE,
    STATE(14311), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16240), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661818] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(19107), 1,
      anon_sym_RBRACK,
    STATE(14312), 1,
      sym_attribute,
    STATE(15204), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661844] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19109), 1,
      anon_sym_SEMI,
    ACTIONS(19111), 1,
      anon_sym_GT_RBRACE,
    STATE(14313), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16336), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661870] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18486), 1,
      anon_sym_DASH_GT,
    ACTIONS(19113), 1,
      anon_sym_as,
    STATE(14314), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15122), 3,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
  [661892] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14315), 1,
      sym_attribute,
    STATE(16258), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661918] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14316), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(15318), 1,
      sym_field_binding_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661944] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(14317), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19115), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [661962] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14318), 1,
      sym_attribute,
    STATE(15863), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661988] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(19117), 1,
      anon_sym_RPAREN,
    STATE(14319), 1,
      sym_attribute,
    STATE(15121), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662014] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14320), 1,
      sym_attribute,
    STATE(15935), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662040] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14321), 1,
      sym_attribute,
    STATE(14387), 1,
      sym_field_path,
    STATE(15115), 1,
      sym_field_binding_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662066] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14322), 1,
      sym_attribute,
    STATE(16311), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662092] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14323), 1,
      sym_attribute,
    STATE(14349), 1,
      sym_field_path,
    STATE(16379), 1,
      sym_field_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662118] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(14324), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19119), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [662136] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(14325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19121), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [662154] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14326), 1,
      sym_attribute,
    STATE(15999), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662180] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(19123), 1,
      anon_sym_RPAREN,
    STATE(14327), 1,
      sym_attribute,
    STATE(15172), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662206] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19125), 1,
      anon_sym_SEMI,
    ACTIONS(19127), 1,
      anon_sym_GT_RBRACE,
    STATE(14328), 1,
      sym_attribute,
    STATE(15142), 1,
      sym_instance_variable_expression,
    STATE(15653), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662232] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18486), 1,
      anon_sym_DASH_GT,
    ACTIONS(19113), 1,
      anon_sym_as,
    STATE(14329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13277), 3,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
  [662254] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14330), 1,
      sym_attribute,
    STATE(15379), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662280] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19129), 1,
      anon_sym_SEMI,
    ACTIONS(19131), 1,
      anon_sym_GT_RBRACE,
    STATE(14331), 1,
      sym_attribute,
    STATE(15565), 1,
      sym_instance_variable_expression,
    STATE(15653), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662306] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19133), 1,
      anon_sym_SEMI,
    ACTIONS(19135), 1,
      anon_sym_GT_RBRACE,
    STATE(14332), 1,
      sym_attribute,
    STATE(15626), 1,
      sym_instance_variable_expression,
    STATE(15653), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662332] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19137), 1,
      anon_sym_SEMI,
    ACTIONS(19139), 1,
      anon_sym_GT_RBRACE,
    STATE(14333), 1,
      sym_attribute,
    STATE(15181), 1,
      sym_instance_variable_expression,
    STATE(15653), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662358] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18486), 1,
      anon_sym_DASH_GT,
    ACTIONS(19113), 1,
      anon_sym_as,
    STATE(14334), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16459), 3,
      anon_sym_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [662380] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(14335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19141), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [662398] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19145), 1,
      anon_sym__,
    STATE(14204), 1,
      sym_type_variable,
    STATE(14336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19143), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [662422] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19147), 1,
      anon_sym_type,
    ACTIONS(19149), 1,
      anon_sym_module,
    STATE(14337), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10498), 3,
      sym_constrain_type,
      sym_constrain_module,
      sym_constrain_module_type,
  [662444] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18051), 1,
      anon_sym_AMP,
    STATE(14257), 1,
      aux_sym_tag_specification_repeat1,
    STATE(14338), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18047), 3,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_GT,
  [662466] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(18466), 1,
      anon_sym_RBRACK,
    STATE(14339), 1,
      sym_attribute,
    STATE(15085), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662492] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14340), 1,
      sym_attribute,
    STATE(15995), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662518] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(19151), 1,
      anon_sym_RBRACK,
    STATE(14341), 1,
      sym_attribute,
    STATE(15873), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662544] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(19153), 1,
      anon_sym_RPAREN,
    STATE(14342), 1,
      sym_attribute,
    STATE(15366), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662570] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    STATE(14343), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18464), 3,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_GT,
  [662592] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(19155), 1,
      anon_sym_RPAREN,
    STATE(14344), 1,
      sym_attribute,
    STATE(15845), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662618] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(19157), 1,
      anon_sym_RBRACK,
    STATE(14345), 1,
      sym_attribute,
    STATE(15605), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662644] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(19159), 1,
      anon_sym_RPAREN,
    STATE(14346), 1,
      sym_attribute,
    STATE(16255), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662670] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19147), 1,
      anon_sym_type,
    ACTIONS(19149), 1,
      anon_sym_module,
    STATE(14347), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9477), 3,
      sym_constrain_type,
      sym_constrain_module,
      sym_constrain_module_type,
  [662692] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19161), 1,
      anon_sym_SEMI,
    ACTIONS(19163), 1,
      anon_sym_GT_RBRACE,
    STATE(14348), 1,
      sym_attribute,
    STATE(15198), 1,
      sym_instance_variable_expression,
    STATE(15653), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662718] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18907), 1,
      anon_sym_COLON2,
    ACTIONS(19165), 1,
      anon_sym_EQ,
    STATE(14349), 1,
      sym_attribute,
    STATE(16485), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19167), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [662742] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(19169), 1,
      anon_sym_RPAREN,
    STATE(14350), 1,
      sym_attribute,
    STATE(16065), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662768] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14349), 1,
      sym_field_path,
    STATE(14351), 1,
      sym_attribute,
    STATE(15191), 1,
      sym_field_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662794] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19171), 1,
      anon_sym_SEMI,
    ACTIONS(19173), 1,
      anon_sym_GT_RBRACE,
    STATE(14352), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(15938), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662820] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14353), 1,
      sym_attribute,
    STATE(15639), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662846] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19175), 1,
      anon_sym_RPAREN,
    STATE(14354), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662872] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19177), 1,
      anon_sym_RPAREN,
    STATE(14355), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662898] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(19179), 1,
      anon_sym_RPAREN,
    STATE(14356), 1,
      sym_attribute,
    STATE(15180), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662924] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9338), 1,
      sym__uppercase_identifier,
    ACTIONS(19013), 1,
      anon_sym_LPAREN,
    STATE(13339), 1,
      sym__constructor_name,
    STATE(14357), 1,
      sym_attribute,
    STATE(16651), 1,
      sym_constructor_path,
    STATE(20249), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662950] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11246), 1,
      sym__lowercase_identifier,
    ACTIONS(19181), 1,
      anon_sym_POUND,
    STATE(9976), 1,
      sym_type_constructor_path,
    STATE(14358), 1,
      sym_attribute,
    STATE(17413), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662976] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18778), 1,
      sym__lowercase_identifier,
    STATE(14359), 1,
      sym_attribute,
    STATE(14391), 1,
      aux_sym_instance_variable_specification_repeat1,
    STATE(16616), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18782), 2,
      anon_sym_mutable,
      anon_sym_virtual,
  [663000] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(19183), 1,
      anon_sym_EQ,
    ACTIONS(19185), 1,
      anon_sym_of,
    ACTIONS(19187), 1,
      anon_sym_COLON2,
    STATE(14360), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12689), 2,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [663024] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12372), 1,
      sym__lowercase_identifier,
    ACTIONS(19189), 1,
      anon_sym_POUND,
    STATE(12862), 1,
      sym_type_constructor_path,
    STATE(14361), 1,
      sym_attribute,
    STATE(17215), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663050] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14362), 1,
      sym_attribute,
    STATE(15358), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663076] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(19191), 1,
      anon_sym_RPAREN,
    STATE(14363), 1,
      sym_attribute,
    STATE(15677), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663102] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17831), 1,
      anon_sym_COMMA,
    ACTIONS(17833), 1,
      anon_sym_PIPE,
    ACTIONS(17835), 1,
      anon_sym_as,
    ACTIONS(17837), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19193), 1,
      anon_sym_RPAREN,
    STATE(14364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663128] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14365), 1,
      sym_attribute,
    STATE(15604), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663154] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14366), 1,
      sym_attribute,
    STATE(15834), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663180] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14367), 1,
      sym_attribute,
    STATE(16417), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663206] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(19195), 1,
      anon_sym_POUND,
    STATE(9082), 1,
      sym_type_constructor_path,
    STATE(14368), 1,
      sym_attribute,
    STATE(17243), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663232] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11226), 1,
      sym__lowercase_identifier,
    ACTIONS(19197), 1,
      anon_sym_POUND,
    STATE(10795), 1,
      sym_type_constructor_path,
    STATE(14369), 1,
      sym_attribute,
    STATE(17441), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663258] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14370), 1,
      sym_attribute,
    STATE(15353), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663284] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19199), 1,
      anon_sym_SEMI,
    ACTIONS(19201), 1,
      anon_sym_GT_RBRACE,
    STATE(14371), 1,
      sym_attribute,
    STATE(15089), 1,
      sym_instance_variable_expression,
    STATE(15653), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663310] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16457), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(14262), 1,
      aux_sym_expression_item_repeat1,
    STATE(14372), 1,
      sym_attribute,
    STATE(15602), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12289), 2,
      anon_sym_and,
      anon_sym_in,
  [663334] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(19203), 1,
      anon_sym_RPAREN,
    STATE(14373), 1,
      sym_attribute,
    STATE(16468), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663360] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    STATE(14374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13402), 3,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
  [663382] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14375), 1,
      sym_attribute,
    STATE(16130), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663408] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19205), 1,
      anon_sym_SEMI,
    ACTIONS(19207), 1,
      anon_sym_GT_RBRACE,
    STATE(14376), 1,
      sym_attribute,
    STATE(15606), 1,
      sym_instance_variable_expression,
    STATE(15653), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663434] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19209), 1,
      anon_sym_SEMI,
    ACTIONS(19211), 1,
      anon_sym_GT_RBRACE,
    STATE(14377), 1,
      sym_attribute,
    STATE(15225), 1,
      sym_instance_variable_expression,
    STATE(15653), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663460] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16457), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(14262), 1,
      aux_sym_expression_item_repeat1,
    STATE(14378), 1,
      sym_attribute,
    STATE(15602), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11861), 2,
      anon_sym_and,
      anon_sym_in,
  [663484] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14379), 1,
      sym_attribute,
    STATE(15617), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663510] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19213), 1,
      anon_sym_SEMI,
    ACTIONS(19215), 1,
      anon_sym_GT_RBRACE,
    STATE(14380), 1,
      sym_attribute,
    STATE(15530), 1,
      sym_instance_variable_expression,
    STATE(15653), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663536] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17831), 1,
      anon_sym_COMMA,
    ACTIONS(17833), 1,
      anon_sym_PIPE,
    ACTIONS(17835), 1,
      anon_sym_as,
    ACTIONS(17837), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19217), 1,
      anon_sym_RPAREN,
    STATE(14381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663562] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19219), 1,
      anon_sym_RPAREN,
    STATE(14382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663588] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11208), 1,
      sym__lowercase_identifier,
    ACTIONS(19221), 1,
      anon_sym_POUND,
    STATE(9540), 1,
      sym_type_constructor_path,
    STATE(14383), 1,
      sym_attribute,
    STATE(16902), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663614] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17831), 1,
      anon_sym_COMMA,
    ACTIONS(17833), 1,
      anon_sym_PIPE,
    ACTIONS(17835), 1,
      anon_sym_as,
    ACTIONS(17837), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19223), 1,
      anon_sym_RPAREN,
    STATE(14384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663640] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14349), 1,
      sym_field_path,
    STATE(14385), 1,
      sym_attribute,
    STATE(15160), 1,
      sym_field_pattern,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663666] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19225), 1,
      anon_sym_SEMI,
    ACTIONS(19227), 1,
      anon_sym_GT_RBRACE,
    STATE(14386), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(15906), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663692] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18907), 1,
      anon_sym_COLON2,
    ACTIONS(19229), 1,
      anon_sym_EQ,
    STATE(14387), 1,
      sym_attribute,
    STATE(16432), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19231), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [663716] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19233), 1,
      anon_sym_SEMI,
    ACTIONS(19235), 1,
      anon_sym_GT_RBRACE,
    STATE(14388), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16014), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663742] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19237), 1,
      anon_sym_RPAREN,
    STATE(14389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663768] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19239), 1,
      anon_sym_SEMI,
    ACTIONS(19241), 1,
      anon_sym_GT_RBRACE,
    STATE(14390), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16465), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663794] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18778), 1,
      sym__lowercase_identifier,
    STATE(14391), 1,
      sym_attribute,
    STATE(14669), 1,
      aux_sym_instance_variable_specification_repeat1,
    STATE(16637), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18782), 2,
      anon_sym_mutable,
      anon_sym_virtual,
  [663818] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14392), 1,
      sym_attribute,
    STATE(15546), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663844] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17831), 1,
      anon_sym_COMMA,
    ACTIONS(17833), 1,
      anon_sym_PIPE,
    ACTIONS(17835), 1,
      anon_sym_as,
    ACTIONS(17837), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19243), 1,
      anon_sym_RPAREN,
    STATE(14393), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663870] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16921), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19245), 1,
      anon_sym_RPAREN,
    STATE(14394), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663896] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11278), 1,
      sym__lowercase_identifier,
    ACTIONS(19247), 1,
      anon_sym_POUND,
    STATE(10893), 1,
      sym_type_constructor_path,
    STATE(14395), 1,
      sym_attribute,
    STATE(17519), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663922] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19249), 1,
      anon_sym_SEMI,
    ACTIONS(19251), 1,
      anon_sym_GT_RBRACE,
    STATE(14396), 1,
      sym_attribute,
    STATE(15416), 1,
      sym_instance_variable_expression,
    STATE(15653), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663948] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19253), 1,
      anon_sym_SEMI,
    ACTIONS(19255), 1,
      anon_sym_GT_RBRACE,
    STATE(14397), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16058), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663974] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19257), 1,
      anon_sym_SEMI,
    ACTIONS(19259), 1,
      anon_sym_GT_RBRACE,
    STATE(14398), 1,
      sym_attribute,
    STATE(15133), 1,
      sym_instance_variable_expression,
    STATE(15653), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664000] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(18592), 1,
      anon_sym_RBRACK,
    STATE(14399), 1,
      sym_attribute,
    STATE(15102), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664026] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(17489), 1,
      sym__lowercase_identifier,
    STATE(14194), 1,
      sym_field_path,
    STATE(14400), 1,
      sym_attribute,
    STATE(15514), 1,
      sym_field_expression,
    STATE(20399), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664052] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18486), 1,
      anon_sym_DASH_GT,
    ACTIONS(19113), 1,
      anon_sym_as,
    STATE(14401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15118), 3,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
  [664074] = 8,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19261), 1,
      anon_sym_SEMI,
    ACTIONS(19263), 1,
      anon_sym_GT_RBRACE,
    STATE(14402), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16464), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664100] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19265), 1,
      anon_sym_GT_RBRACE,
    STATE(14403), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664123] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19267), 1,
      anon_sym_GT_RBRACE,
    STATE(14404), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664146] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19269), 1,
      sym__lowercase_identifier,
    STATE(12644), 1,
      sym_class_type_path,
    STATE(14405), 1,
      sym_attribute,
    STATE(17452), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664169] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19271), 1,
      anon_sym_RBRACK,
    STATE(14406), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664192] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19269), 1,
      sym__lowercase_identifier,
    STATE(12686), 1,
      sym_class_type_path,
    STATE(14407), 1,
      sym_attribute,
    STATE(17452), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664215] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19269), 1,
      sym__lowercase_identifier,
    STATE(12714), 1,
      sym_class_type_path,
    STATE(14408), 1,
      sym_attribute,
    STATE(17452), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664238] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9988), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19275), 1,
      anon_sym_GT,
    STATE(14409), 1,
      sym_attribute,
    STATE(14585), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664261] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19277), 1,
      anon_sym_RBRACK,
    STATE(14410), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664284] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11074), 1,
      anon_sym_in,
    ACTIONS(16457), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(14262), 1,
      aux_sym_expression_item_repeat1,
    STATE(14411), 1,
      sym_attribute,
    STATE(15602), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664307] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19279), 1,
      anon_sym_RBRACK,
    STATE(14412), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664330] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(19281), 1,
      anon_sym_COLON_GT,
    ACTIONS(19283), 1,
      anon_sym_RPAREN,
    STATE(14413), 1,
      sym_attribute,
    STATE(17205), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664353] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19285), 1,
      anon_sym_RBRACK,
    STATE(14414), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664376] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19287), 1,
      anon_sym_RBRACK,
    STATE(14415), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664399] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19289), 1,
      anon_sym_RBRACK,
    STATE(14416), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664422] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19293), 1,
      anon_sym_with,
    ACTIONS(19295), 1,
      sym_hash_operator,
    STATE(14417), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664445] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19297), 1,
      sym__lowercase_identifier,
    STATE(13160), 1,
      sym_class_type_path,
    STATE(14418), 1,
      sym_attribute,
    STATE(17487), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664468] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(19299), 1,
      anon_sym_COLON_GT,
    ACTIONS(19301), 1,
      anon_sym_RPAREN,
    STATE(14419), 1,
      sym_attribute,
    STATE(17574), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664491] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(19303), 1,
      anon_sym_with,
    STATE(14420), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664514] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19287), 1,
      anon_sym_RBRACK,
    ACTIONS(19305), 1,
      anon_sym_GT,
    STATE(14421), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664537] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18576), 1,
      sym__lowercase_identifier,
    STATE(4955), 1,
      sym_class_path,
    STATE(14422), 1,
      sym_attribute,
    STATE(17687), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664560] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17945), 1,
      sym__lowercase_identifier,
    ACTIONS(17947), 1,
      anon_sym_LBRACK,
    ACTIONS(17949), 1,
      anon_sym_virtual,
    STATE(11259), 1,
      sym_class_binding,
    STATE(14423), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664583] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19307), 1,
      anon_sym_DOT,
    STATE(14424), 1,
      sym_attribute,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664606] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13398), 1,
      anon_sym_in,
    ACTIONS(16457), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(14262), 1,
      aux_sym_expression_item_repeat1,
    STATE(14425), 1,
      sym_attribute,
    STATE(15602), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664629] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(19309), 1,
      anon_sym_with,
    STATE(14426), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664652] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19311), 1,
      anon_sym_DOT,
    STATE(14427), 1,
      sym_attribute,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664675] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19313), 1,
      anon_sym_GT_RBRACE,
    STATE(14428), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664698] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(19315), 1,
      sym__lowercase_identifier,
    STATE(7294), 1,
      sym_class_path,
    STATE(14429), 1,
      sym_attribute,
    STATE(17741), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664721] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19317), 1,
      sym__lowercase_identifier,
    STATE(13679), 1,
      sym_class_type_path,
    STATE(14430), 1,
      sym_attribute,
    STATE(17572), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664744] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19317), 1,
      sym__lowercase_identifier,
    STATE(13718), 1,
      sym_class_type_path,
    STATE(14431), 1,
      sym_attribute,
    STATE(17572), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664767] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18409), 1,
      anon_sym_LPAREN,
    ACTIONS(18933), 1,
      sym__lowercase_identifier,
    STATE(10358), 1,
      sym_parenthesized_operator,
    STATE(13279), 1,
      sym__value_name,
    STATE(14432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664790] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19317), 1,
      sym__lowercase_identifier,
    STATE(13740), 1,
      sym_class_type_path,
    STATE(14433), 1,
      sym_attribute,
    STATE(17572), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664813] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16334), 1,
      sym__lowercase_identifier,
    ACTIONS(18409), 1,
      anon_sym_LPAREN,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(14434), 1,
      sym_attribute,
    STATE(16535), 1,
      sym__value_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664836] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19143), 1,
      anon_sym_BANG,
    ACTIONS(19145), 1,
      anon_sym__,
    STATE(14204), 1,
      sym_type_variable,
    STATE(14435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664859] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9934), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19319), 1,
      anon_sym_GT,
    STATE(14436), 1,
      sym_attribute,
    STATE(14454), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664882] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19321), 1,
      sym__lowercase_identifier,
    STATE(14437), 1,
      sym_attribute,
    STATE(16511), 1,
      sym_extended_module_path,
    STATE(20472), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664905] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(19323), 1,
      aux_sym_attribute_id_token1,
    STATE(14438), 1,
      sym_attribute,
    STATE(14500), 1,
      aux_sym_attribute_id_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8921), 2,
      sym__left_quoted_string_delimiter,
      aux_sym_quoted_extension_token1,
  [664926] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17945), 1,
      sym__lowercase_identifier,
    ACTIONS(17947), 1,
      anon_sym_LBRACK,
    ACTIONS(17949), 1,
      anon_sym_virtual,
    STATE(11939), 1,
      sym_class_binding,
    STATE(14439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664949] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19325), 1,
      anon_sym_GT_RBRACE,
    STATE(14440), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664972] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19327), 1,
      anon_sym_EQ,
    ACTIONS(19329), 1,
      anon_sym_RPAREN,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(14441), 1,
      sym_attribute,
    STATE(16844), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664995] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19333), 1,
      anon_sym_GT_RBRACE,
    STATE(14442), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665018] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19335), 1,
      sym__lowercase_identifier,
    STATE(10759), 1,
      sym_class_type_path,
    STATE(14443), 1,
      sym_attribute,
    STATE(16607), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665041] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19337), 1,
      anon_sym_GT_RBRACE,
    STATE(14444), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665064] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(19339), 1,
      anon_sym_with,
    STATE(14445), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665087] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19341), 1,
      anon_sym_RBRACK,
    STATE(14446), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665110] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19343), 1,
      anon_sym_RBRACK,
    STATE(14447), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665133] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19345), 1,
      sym__lowercase_identifier,
    STATE(14448), 1,
      sym_attribute,
    STATE(15082), 1,
      aux_sym_method_specification_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18957), 2,
      anon_sym_private,
      anon_sym_virtual,
  [665154] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(19347), 1,
      sym__lowercase_identifier,
    STATE(14449), 1,
      sym_attribute,
    STATE(16515), 1,
      sym_module_type_path,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665177] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(19347), 1,
      sym__lowercase_identifier,
    STATE(14450), 1,
      sym_attribute,
    STATE(16517), 1,
      sym_module_type_path,
    STATE(16522), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665200] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(19347), 1,
      sym__lowercase_identifier,
    STATE(14451), 1,
      sym_attribute,
    STATE(16522), 1,
      sym_extended_module_path,
    STATE(16526), 1,
      sym_module_type_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665223] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19349), 1,
      anon_sym_RBRACK,
    ACTIONS(19351), 1,
      anon_sym_GT,
    STATE(14452), 1,
      sym_attribute,
    STATE(14469), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665246] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(19347), 1,
      sym__lowercase_identifier,
    STATE(14453), 1,
      sym_attribute,
    STATE(16522), 1,
      sym_extended_module_path,
    STATE(16531), 1,
      sym_module_type_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665269] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19349), 1,
      anon_sym_RBRACK,
    ACTIONS(19351), 1,
      anon_sym_GT,
    STATE(14454), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665292] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10096), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19353), 1,
      anon_sym_GT,
    STATE(14455), 1,
      sym_attribute,
    STATE(14831), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665315] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19343), 1,
      anon_sym_RBRACK,
    ACTIONS(19355), 1,
      anon_sym_GT,
    STATE(14456), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665338] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19357), 1,
      anon_sym_GT_RBRACE,
    STATE(14457), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665361] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19335), 1,
      sym__lowercase_identifier,
    STATE(10838), 1,
      sym_class_type_path,
    STATE(14458), 1,
      sym_attribute,
    STATE(16607), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665384] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19359), 1,
      anon_sym_RBRACK,
    ACTIONS(19361), 1,
      anon_sym_GT,
    STATE(14459), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665407] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19359), 1,
      anon_sym_RBRACK,
    ACTIONS(19361), 1,
      anon_sym_GT,
    STATE(14421), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(14460), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665430] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19363), 1,
      anon_sym_DOT,
    STATE(14461), 1,
      sym_attribute,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665453] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19341), 1,
      anon_sym_RBRACK,
    ACTIONS(19365), 1,
      anon_sym_GT,
    STATE(14462), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665476] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    STATE(14463), 1,
      sym_attribute,
    STATE(17585), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19367), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [665497] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19369), 1,
      anon_sym_GT_RBRACE,
    STATE(14464), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665520] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19371), 1,
      anon_sym_rec,
    STATE(14465), 1,
      sym_attribute,
    STATE(16478), 1,
      sym_module_binding,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18504), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [665541] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19373), 1,
      anon_sym_GT_RBRACE,
    STATE(14466), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665564] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    STATE(14467), 1,
      sym_attribute,
    STATE(16539), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19375), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [665585] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19377), 1,
      anon_sym_rec,
    STATE(12366), 1,
      sym_module_binding,
    STATE(14468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17759), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [665606] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19379), 1,
      anon_sym_RBRACK,
    ACTIONS(19381), 1,
      anon_sym_GT,
    STATE(14469), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665629] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(19383), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12085), 2,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    STATE(14470), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
  [665648] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19386), 1,
      sym__lowercase_identifier,
    STATE(7637), 1,
      sym_type_constructor_path,
    STATE(14471), 1,
      sym_attribute,
    STATE(17387), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665671] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    ACTIONS(19388), 1,
      anon_sym_EQ,
    ACTIONS(19390), 1,
      anon_sym_RPAREN,
    STATE(14472), 1,
      sym_attribute,
    STATE(16725), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665694] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19379), 1,
      anon_sym_RBRACK,
    STATE(14473), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665717] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19392), 1,
      anon_sym_GT_RBRACE,
    STATE(14474), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665740] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18740), 1,
      sym__lowercase_identifier,
    STATE(4081), 1,
      sym_class_path,
    STATE(14475), 1,
      sym_attribute,
    STATE(18119), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665763] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19394), 1,
      anon_sym_RBRACK,
    STATE(14476), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665786] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19396), 1,
      anon_sym_DOT,
    STATE(14477), 1,
      sym_attribute,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665809] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(13523), 1,
      anon_sym_DASH_GT,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(14478), 1,
      sym_attribute,
    STATE(14631), 1,
      aux_sym_module_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665832] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    ACTIONS(19398), 1,
      anon_sym_EQ,
    ACTIONS(19400), 1,
      anon_sym_RPAREN,
    STATE(14479), 1,
      sym_attribute,
    STATE(16620), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665855] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13410), 1,
      anon_sym_in,
    ACTIONS(16457), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(14425), 1,
      aux_sym_expression_item_repeat1,
    STATE(14480), 1,
      sym_attribute,
    STATE(15602), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665878] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19402), 1,
      anon_sym_RBRACK,
    STATE(14481), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665901] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    STATE(14482), 1,
      sym_attribute,
    STATE(16521), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19404), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [665922] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19406), 1,
      anon_sym_RBRACK,
    STATE(14483), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665945] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(13523), 1,
      anon_sym_DASH_GT,
    STATE(9272), 1,
      aux_sym_module_binding_repeat1,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(14484), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665968] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(19323), 1,
      aux_sym_attribute_id_token1,
    STATE(14438), 1,
      aux_sym_attribute_id_repeat1,
    STATE(14485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9052), 2,
      sym__left_quoted_string_delimiter,
      aux_sym_quoted_extension_token1,
  [665989] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(19408), 1,
      anon_sym_COLON_GT,
    ACTIONS(19410), 1,
      anon_sym_RPAREN,
    STATE(14486), 1,
      sym_attribute,
    STATE(16917), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666012] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18618), 1,
      sym__lowercase_identifier,
    STATE(9227), 1,
      sym_class_path,
    STATE(14487), 1,
      sym_attribute,
    STATE(17854), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666035] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    STATE(14488), 1,
      sym_attribute,
    STATE(17581), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19412), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [666056] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19414), 1,
      anon_sym_GT_RBRACE,
    STATE(14489), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666079] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19416), 1,
      sym__lowercase_identifier,
    STATE(9558), 1,
      sym_class_type_path,
    STATE(14490), 1,
      sym_attribute,
    STATE(17426), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666102] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(19418), 1,
      anon_sym_with,
    STATE(14491), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666125] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19420), 1,
      sym__lowercase_identifier,
    STATE(10026), 1,
      sym_class_type_path,
    STATE(14492), 1,
      sym_attribute,
    STATE(17422), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666148] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19416), 1,
      sym__lowercase_identifier,
    STATE(9529), 1,
      sym_class_type_path,
    STATE(14493), 1,
      sym_attribute,
    STATE(17426), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666171] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(19422), 1,
      anon_sym_DASH_GT,
    STATE(9272), 1,
      aux_sym_module_binding_repeat1,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(14494), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666194] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17797), 1,
      sym__lowercase_identifier,
    ACTIONS(17801), 1,
      anon_sym_LBRACK,
    ACTIONS(17803), 1,
      anon_sym_virtual,
    STATE(12773), 1,
      sym_class_binding,
    STATE(14495), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666217] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19416), 1,
      sym__lowercase_identifier,
    STATE(9562), 1,
      sym_class_type_path,
    STATE(14496), 1,
      sym_attribute,
    STATE(17426), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666240] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16334), 1,
      sym__lowercase_identifier,
    ACTIONS(18409), 1,
      anon_sym_LPAREN,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(14497), 1,
      sym_attribute,
    STATE(16549), 1,
      sym__value_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666263] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19424), 1,
      anon_sym_DOT,
    STATE(14498), 1,
      sym_attribute,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666286] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18806), 1,
      sym__lowercase_identifier,
    STATE(7708), 1,
      sym_class_path,
    STATE(14499), 1,
      sym_attribute,
    STATE(18648), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666309] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(19426), 1,
      aux_sym_attribute_id_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8961), 2,
      sym__left_quoted_string_delimiter,
      aux_sym_quoted_extension_token1,
    STATE(14500), 2,
      sym_attribute,
      aux_sym_attribute_id_repeat1,
  [666328] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(19429), 1,
      anon_sym_COLON_GT,
    ACTIONS(19431), 1,
      anon_sym_RPAREN,
    STATE(14501), 1,
      sym_attribute,
    STATE(17232), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666351] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(19433), 1,
      anon_sym_COLON_GT,
    ACTIONS(19435), 1,
      anon_sym_RPAREN,
    STATE(14502), 1,
      sym_attribute,
    STATE(17564), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666374] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(19315), 1,
      sym__lowercase_identifier,
    STATE(7296), 1,
      sym_class_path,
    STATE(14503), 1,
      sym_attribute,
    STATE(17741), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666397] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19437), 1,
      anon_sym_DOT,
    STATE(14504), 1,
      sym_attribute,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666420] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19439), 1,
      sym__lowercase_identifier,
    STATE(10879), 1,
      sym_class_type_path,
    STATE(14505), 1,
      sym_attribute,
    STATE(17472), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666443] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19441), 1,
      anon_sym_DOT,
    STATE(14506), 1,
      sym_attribute,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666466] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19443), 1,
      anon_sym_GT_RBRACE,
    STATE(14507), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666489] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9974), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19445), 1,
      anon_sym_GT,
    STATE(14459), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(14508), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666512] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19447), 1,
      anon_sym_DOT,
    STATE(14509), 1,
      sym_attribute,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666535] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19449), 1,
      sym__lowercase_identifier,
    STATE(9417), 1,
      sym_class_type_path,
    STATE(14510), 1,
      sym_attribute,
    STATE(17550), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666558] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19451), 1,
      anon_sym_DOT,
    STATE(14511), 1,
      sym_attribute,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666581] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14110), 1,
      anon_sym_in,
    ACTIONS(19453), 1,
      anon_sym_and,
    ACTIONS(19455), 1,
      sym_let_and_operator,
    STATE(14512), 1,
      sym_attribute,
    STATE(14933), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666604] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11316), 1,
      sym__lowercase_identifier,
    STATE(14513), 1,
      sym_attribute,
    STATE(16055), 1,
      sym_type_constructor_path,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666627] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(19457), 1,
      anon_sym_with,
    STATE(14514), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666650] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19459), 1,
      anon_sym_GT_RBRACE,
    STATE(14515), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666673] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9926), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19461), 1,
      anon_sym_GT,
    STATE(14516), 1,
      sym_attribute,
    STATE(14531), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666696] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9984), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19463), 1,
      anon_sym_GT,
    STATE(14517), 1,
      sym_attribute,
    STATE(14558), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666719] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19465), 1,
      anon_sym_RBRACK,
    ACTIONS(19467), 1,
      anon_sym_GT,
    STATE(14518), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666742] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19465), 1,
      anon_sym_RBRACK,
    ACTIONS(19467), 1,
      anon_sym_GT,
    STATE(14456), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(14519), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666765] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18584), 1,
      sym__lowercase_identifier,
    STATE(3764), 1,
      sym_class_path,
    STATE(14520), 1,
      sym_attribute,
    STATE(18609), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666788] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19469), 1,
      sym__lowercase_identifier,
    ACTIONS(19471), 1,
      anon_sym_LPAREN,
    STATE(5637), 1,
      sym__value_name,
    STATE(5725), 1,
      sym_parenthesized_operator,
    STATE(14521), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666811] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19473), 1,
      anon_sym_GT_RBRACE,
    STATE(14522), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666834] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(19475), 1,
      anon_sym_COLON_GT,
    ACTIONS(19477), 1,
      anon_sym_RPAREN,
    STATE(14523), 1,
      sym_attribute,
    STATE(17110), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666857] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(19479), 1,
      anon_sym_COLON_GT,
    ACTIONS(19481), 1,
      anon_sym_RPAREN,
    STATE(14524), 1,
      sym_attribute,
    STATE(17522), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666880] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19483), 1,
      anon_sym_DOT,
    STATE(14525), 1,
      sym_attribute,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666903] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19485), 1,
      anon_sym_DOT,
    STATE(14526), 1,
      sym_attribute,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666926] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19487), 1,
      anon_sym_GT_RBRACE,
    STATE(14527), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666949] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    STATE(14528), 1,
      sym_attribute,
    STATE(16534), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19489), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [666970] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16866), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    STATE(14529), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666993] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19491), 1,
      anon_sym_RBRACK,
    ACTIONS(19493), 1,
      anon_sym_GT,
    STATE(14530), 1,
      sym_attribute,
    STATE(14541), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667016] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19491), 1,
      anon_sym_RBRACK,
    ACTIONS(19493), 1,
      anon_sym_GT,
    STATE(14531), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667039] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(19495), 1,
      anon_sym_DASH_GT,
    STATE(9272), 1,
      aux_sym_module_binding_repeat1,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(14532), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667062] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16822), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    STATE(14533), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667085] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19497), 1,
      anon_sym_GT_RBRACE,
    STATE(14534), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667108] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(13352), 1,
      anon_sym_DASH_GT,
    STATE(9272), 1,
      aux_sym_module_binding_repeat1,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(14535), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667131] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(13352), 1,
      anon_sym_DASH_GT,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(14532), 1,
      aux_sym_module_binding_repeat1,
    STATE(14536), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667154] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    STATE(14537), 1,
      sym_attribute,
    STATE(16527), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19499), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [667175] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19501), 1,
      sym__lowercase_identifier,
    STATE(8010), 1,
      sym_type_constructor_path,
    STATE(14538), 1,
      sym_attribute,
    STATE(17555), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667198] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19503), 1,
      sym__lowercase_identifier,
    STATE(14539), 1,
      sym_attribute,
    STATE(16511), 1,
      sym_extended_module_path,
    STATE(20274), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667221] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19505), 1,
      anon_sym_GT_RBRACE,
    STATE(14540), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667244] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19507), 1,
      anon_sym_RBRACK,
    ACTIONS(19509), 1,
      anon_sym_GT,
    STATE(14541), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667267] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19507), 1,
      anon_sym_RBRACK,
    STATE(14542), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667290] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19511), 1,
      anon_sym_RBRACK,
    ACTIONS(19513), 1,
      anon_sym_GT,
    STATE(14543), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667313] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(19347), 1,
      sym__lowercase_identifier,
    STATE(14544), 1,
      sym_attribute,
    STATE(16522), 1,
      sym_extended_module_path,
    STATE(16614), 1,
      sym_module_type_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667336] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19511), 1,
      anon_sym_RBRACK,
    ACTIONS(19513), 1,
      anon_sym_GT,
    STATE(14462), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(14545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667359] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12406), 1,
      sym__uppercase_identifier,
    ACTIONS(19347), 1,
      sym__lowercase_identifier,
    STATE(14546), 1,
      sym_attribute,
    STATE(16522), 1,
      sym_extended_module_path,
    STATE(16684), 1,
      sym_module_type_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667382] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11316), 1,
      sym__lowercase_identifier,
    STATE(14547), 1,
      sym_attribute,
    STATE(15112), 1,
      sym_type_constructor_path,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667405] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11316), 1,
      sym__lowercase_identifier,
    STATE(14548), 1,
      sym_attribute,
    STATE(15234), 1,
      sym_type_constructor_path,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667428] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19515), 1,
      anon_sym_DOT,
    STATE(14549), 1,
      sym_attribute,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667451] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19517), 1,
      anon_sym_RBRACK,
    STATE(14550), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667474] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19519), 1,
      anon_sym_RBRACK,
    STATE(14551), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667497] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18411), 1,
      sym__lowercase_identifier,
    STATE(5795), 1,
      sym_class_path,
    STATE(14552), 1,
      sym_attribute,
    STATE(18169), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667520] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19521), 1,
      sym__lowercase_identifier,
    STATE(9241), 1,
      sym_class_type_path,
    STATE(14553), 1,
      sym_attribute,
    STATE(17407), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667543] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(19523), 1,
      anon_sym_with,
    STATE(14554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667566] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19521), 1,
      sym__lowercase_identifier,
    STATE(9057), 1,
      sym_class_type_path,
    STATE(14555), 1,
      sym_attribute,
    STATE(17407), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667589] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19521), 1,
      sym__lowercase_identifier,
    STATE(9050), 1,
      sym_class_type_path,
    STATE(14556), 1,
      sym_attribute,
    STATE(17407), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667612] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19525), 1,
      anon_sym_RBRACK,
    ACTIONS(19527), 1,
      anon_sym_GT,
    STATE(14557), 1,
      sym_attribute,
    STATE(14593), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667635] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19525), 1,
      anon_sym_RBRACK,
    ACTIONS(19527), 1,
      anon_sym_GT,
    STATE(14558), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667658] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19529), 1,
      sym__lowercase_identifier,
    STATE(10869), 1,
      sym_class_type_path,
    STATE(14559), 1,
      sym_attribute,
    STATE(17344), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667681] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    STATE(14560), 1,
      sym_attribute,
    STATE(16542), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19531), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [667702] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19335), 1,
      sym__lowercase_identifier,
    STATE(10923), 1,
      sym_class_type_path,
    STATE(14561), 1,
      sym_attribute,
    STATE(16607), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667725] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19533), 1,
      anon_sym_GT_RBRACE,
    STATE(14562), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667748] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    ACTIONS(19535), 1,
      anon_sym_EQ,
    ACTIONS(19537), 1,
      anon_sym_RPAREN,
    STATE(14563), 1,
      sym_attribute,
    STATE(16803), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667771] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19539), 1,
      anon_sym_DOT,
    STATE(14564), 1,
      sym_attribute,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667794] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19541), 1,
      anon_sym_RBRACK,
    ACTIONS(19543), 1,
      anon_sym_GT,
    STATE(14565), 1,
      sym_attribute,
    STATE(14679), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667817] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(19545), 1,
      anon_sym_COLON_GT,
    ACTIONS(19547), 1,
      anon_sym_RPAREN,
    STATE(14566), 1,
      sym_attribute,
    STATE(16713), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667840] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(19549), 1,
      anon_sym_with,
    STATE(14567), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667863] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19551), 1,
      anon_sym_GT_RBRACE,
    STATE(14568), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667886] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19553), 1,
      anon_sym_GT_RBRACE,
    STATE(14569), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667909] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(19555), 1,
      anon_sym_COLON_GT,
    ACTIONS(19557), 1,
      anon_sym_RPAREN,
    STATE(14570), 1,
      sym_attribute,
    STATE(17267), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667932] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19541), 1,
      anon_sym_RBRACK,
    ACTIONS(19543), 1,
      anon_sym_GT,
    STATE(14571), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667955] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19559), 1,
      anon_sym_DOT,
    STATE(14572), 1,
      sym_attribute,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667978] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19561), 1,
      anon_sym_GT_RBRACE,
    STATE(14573), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668001] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19563), 1,
      anon_sym_GT_RBRACE,
    STATE(14574), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668024] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19269), 1,
      sym__lowercase_identifier,
    STATE(12630), 1,
      sym_class_type_path,
    STATE(14575), 1,
      sym_attribute,
    STATE(17452), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668047] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11316), 1,
      sym__lowercase_identifier,
    STATE(13096), 1,
      sym_type_constructor_path,
    STATE(14576), 1,
      sym_attribute,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668070] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18722), 1,
      sym__lowercase_identifier,
    STATE(4409), 1,
      sym_class_path,
    STATE(14577), 1,
      sym_attribute,
    STATE(20423), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668093] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13955), 1,
      anon_sym_in,
    ACTIONS(19453), 1,
      anon_sym_and,
    ACTIONS(19455), 1,
      sym_let_and_operator,
    STATE(14578), 1,
      sym_attribute,
    STATE(14643), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668116] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19565), 1,
      anon_sym_GT_RBRACE,
    STATE(14579), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668139] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(19567), 1,
      anon_sym_COLON_GT,
    ACTIONS(19569), 1,
      anon_sym_RPAREN,
    STATE(14580), 1,
      sym_attribute,
    STATE(16894), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668162] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9886), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19571), 1,
      anon_sym_GT,
    STATE(14518), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(14581), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668185] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19573), 1,
      anon_sym_RBRACK,
    ACTIONS(19575), 1,
      anon_sym_GT,
    STATE(14582), 1,
      sym_attribute,
    STATE(14717), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668208] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9888), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19577), 1,
      anon_sym_GT,
    STATE(14583), 1,
      sym_attribute,
    STATE(14589), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668231] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19579), 1,
      anon_sym_GT_RBRACE,
    STATE(14584), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668254] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19573), 1,
      anon_sym_RBRACK,
    ACTIONS(19575), 1,
      anon_sym_GT,
    STATE(14585), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668277] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(19581), 1,
      anon_sym_with,
    STATE(14586), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668300] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11316), 1,
      sym__lowercase_identifier,
    STATE(14587), 1,
      sym_attribute,
    STATE(16263), 1,
      sym_type_constructor_path,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668323] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19583), 1,
      anon_sym_RBRACK,
    ACTIONS(19585), 1,
      anon_sym_GT,
    STATE(14588), 1,
      sym_attribute,
    STATE(14601), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668346] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19583), 1,
      anon_sym_RBRACK,
    ACTIONS(19585), 1,
      anon_sym_GT,
    STATE(14589), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668369] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19587), 1,
      sym__lowercase_identifier,
    STATE(10162), 1,
      sym_class_type_path,
    STATE(14590), 1,
      sym_attribute,
    STATE(17508), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668392] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19589), 1,
      anon_sym_GT_RBRACE,
    STATE(14591), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668415] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19591), 1,
      anon_sym_RBRACK,
    ACTIONS(19593), 1,
      anon_sym_GT,
    STATE(14592), 1,
      sym_attribute,
    STATE(14999), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668438] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19595), 1,
      anon_sym_RBRACK,
    ACTIONS(19597), 1,
      anon_sym_GT,
    STATE(14593), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668461] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19591), 1,
      anon_sym_RBRACK,
    ACTIONS(19593), 1,
      anon_sym_GT,
    STATE(14594), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668484] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19599), 1,
      anon_sym_DOT,
    STATE(14595), 1,
      sym_attribute,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668507] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    STATE(14596), 1,
      sym_attribute,
    STATE(17512), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19601), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [668528] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19595), 1,
      anon_sym_RBRACK,
    STATE(14597), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668551] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19603), 1,
      anon_sym_GT_RBRACE,
    STATE(14598), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668574] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19605), 1,
      sym__lowercase_identifier,
    STATE(14599), 1,
      sym_attribute,
    STATE(16511), 1,
      sym_extended_module_path,
    STATE(20246), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668597] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19607), 1,
      anon_sym_GT_RBRACE,
    STATE(14600), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668620] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19609), 1,
      anon_sym_RBRACK,
    ACTIONS(19611), 1,
      anon_sym_GT,
    STATE(14601), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668643] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19609), 1,
      anon_sym_RBRACK,
    STATE(14602), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668666] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18734), 1,
      sym__lowercase_identifier,
    STATE(6750), 1,
      sym_class_path,
    STATE(14603), 1,
      sym_attribute,
    STATE(18686), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668689] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19613), 1,
      anon_sym_DOT,
    STATE(14604), 1,
      sym_attribute,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668712] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(19615), 1,
      anon_sym_with,
    STATE(14605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668735] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19617), 1,
      anon_sym_RBRACK,
    STATE(14606), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668758] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(19619), 1,
      anon_sym_with,
    STATE(14607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668781] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    STATE(14608), 1,
      sym_attribute,
    STATE(16627), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19621), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [668802] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19623), 1,
      anon_sym_RBRACK,
    STATE(14609), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668825] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13398), 1,
      anon_sym_in,
    ACTIONS(16457), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(14610), 1,
      sym_attribute,
    STATE(14710), 1,
      aux_sym_expression_item_repeat1,
    STATE(15602), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668848] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19625), 1,
      anon_sym_RBRACK,
    STATE(14611), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668871] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(19627), 1,
      anon_sym_DASH_GT,
    STATE(9272), 1,
      aux_sym_module_binding_repeat1,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(14612), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668894] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18536), 1,
      sym__lowercase_identifier,
    STATE(7254), 1,
      sym_class_path,
    STATE(14613), 1,
      sym_attribute,
    STATE(18264), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668917] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19629), 1,
      anon_sym_RBRACK,
    STATE(14614), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668940] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18790), 1,
      sym__lowercase_identifier,
    STATE(5131), 1,
      sym_class_path,
    STATE(14615), 1,
      sym_attribute,
    STATE(18210), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668963] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19631), 1,
      sym__lowercase_identifier,
    STATE(8928), 1,
      sym_type_constructor_path,
    STATE(14616), 1,
      sym_attribute,
    STATE(17309), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668986] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19633), 1,
      anon_sym_RBRACK,
    STATE(14617), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669009] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19635), 1,
      anon_sym_GT_RBRACE,
    STATE(14618), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669032] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19637), 1,
      sym__lowercase_identifier,
    STATE(9144), 1,
      sym_class_type_path,
    STATE(14619), 1,
      sym_attribute,
    STATE(17382), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669055] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18726), 1,
      sym__lowercase_identifier,
    STATE(7737), 1,
      sym_class_path,
    STATE(14620), 1,
      sym_attribute,
    STATE(17795), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669078] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19637), 1,
      sym__lowercase_identifier,
    STATE(9320), 1,
      sym_class_type_path,
    STATE(14621), 1,
      sym_attribute,
    STATE(17382), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669101] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19637), 1,
      sym__lowercase_identifier,
    STATE(9222), 1,
      sym_class_type_path,
    STATE(14622), 1,
      sym_attribute,
    STATE(17382), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669124] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19639), 1,
      sym__lowercase_identifier,
    ACTIONS(19641), 1,
      anon_sym_LPAREN,
    STATE(13851), 1,
      sym_parenthesized_operator,
    STATE(14027), 1,
      sym__value_name,
    STATE(14623), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669147] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18197), 1,
      sym__lowercase_identifier,
    ACTIONS(18199), 1,
      anon_sym_LBRACK,
    ACTIONS(18201), 1,
      anon_sym_virtual,
    STATE(12808), 1,
      sym_class_binding,
    STATE(14624), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669170] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19643), 1,
      anon_sym_DOT,
    STATE(14625), 1,
      sym_attribute,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669193] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18409), 1,
      anon_sym_LPAREN,
    ACTIONS(18456), 1,
      sym__lowercase_identifier,
    STATE(14626), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(20408), 2,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [669214] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(19645), 1,
      anon_sym_COLON_GT,
    ACTIONS(19647), 1,
      anon_sym_RPAREN,
    STATE(14627), 1,
      sym_attribute,
    STATE(17303), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669237] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(19649), 1,
      anon_sym_COLON_GT,
    ACTIONS(19651), 1,
      anon_sym_RPAREN,
    STATE(14628), 1,
      sym_attribute,
    STATE(17466), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669260] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(19653), 1,
      anon_sym_DASH_GT,
    STATE(9272), 1,
      aux_sym_module_binding_repeat1,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(14629), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669283] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19416), 1,
      sym__lowercase_identifier,
    STATE(9628), 1,
      sym_class_type_path,
    STATE(14630), 1,
      sym_attribute,
    STATE(17426), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669306] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(19655), 1,
      anon_sym_DASH_GT,
    STATE(9272), 1,
      aux_sym_module_binding_repeat1,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(14631), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669329] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19529), 1,
      sym__lowercase_identifier,
    STATE(10797), 1,
      sym_class_type_path,
    STATE(14632), 1,
      sym_attribute,
    STATE(17344), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669352] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14001), 1,
      anon_sym_in,
    ACTIONS(19657), 1,
      anon_sym_and,
    ACTIONS(19660), 1,
      sym_let_and_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14633), 2,
      sym_attribute,
      aux_sym_value_definition_repeat1,
  [669373] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(19663), 1,
      anon_sym_with,
    STATE(14634), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669396] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19529), 1,
      sym__lowercase_identifier,
    STATE(10784), 1,
      sym_class_type_path,
    STATE(14635), 1,
      sym_attribute,
    STATE(17344), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669419] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(19665), 1,
      anon_sym_with,
    STATE(14636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669442] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19667), 1,
      anon_sym_DOT,
    STATE(14637), 1,
      sym_attribute,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669465] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19669), 1,
      anon_sym_DOT,
    STATE(14638), 1,
      sym_attribute,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669488] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10253), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19671), 1,
      anon_sym_GT,
    STATE(14639), 1,
      sym_attribute,
    STATE(14658), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669511] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19673), 1,
      anon_sym_DOT,
    STATE(14640), 1,
      sym_attribute,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669534] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18618), 1,
      sym__lowercase_identifier,
    STATE(9978), 1,
      sym_class_path,
    STATE(14641), 1,
      sym_attribute,
    STATE(17854), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669557] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19587), 1,
      sym__lowercase_identifier,
    STATE(10145), 1,
      sym_class_type_path,
    STATE(14642), 1,
      sym_attribute,
    STATE(17508), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669580] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13909), 1,
      anon_sym_in,
    ACTIONS(19453), 1,
      anon_sym_and,
    ACTIONS(19455), 1,
      sym_let_and_operator,
    STATE(14633), 1,
      aux_sym_value_definition_repeat1,
    STATE(14643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669603] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12270), 1,
      anon_sym_and,
    STATE(14644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12268), 3,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [669622] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9970), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19675), 1,
      anon_sym_GT,
    STATE(14543), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(14645), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669645] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18820), 1,
      sym__lowercase_identifier,
    ACTIONS(18822), 1,
      anon_sym_LBRACK,
    ACTIONS(18824), 1,
      anon_sym_virtual,
    STATE(11155), 1,
      sym_class_type_binding,
    STATE(14646), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669668] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18518), 1,
      sym__lowercase_identifier,
    STATE(3403), 1,
      sym_class_path,
    STATE(14647), 1,
      sym_attribute,
    STATE(17849), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669691] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19587), 1,
      sym__lowercase_identifier,
    STATE(10189), 1,
      sym_class_type_path,
    STATE(14648), 1,
      sym_attribute,
    STATE(17508), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669714] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(19677), 1,
      anon_sym_COLON_GT,
    ACTIONS(19679), 1,
      anon_sym_RPAREN,
    STATE(14649), 1,
      sym_attribute,
    STATE(17548), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669737] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19681), 1,
      sym__lowercase_identifier,
    STATE(11789), 1,
      sym_class_type_path,
    STATE(14650), 1,
      sym_attribute,
    STATE(17578), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669760] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19683), 1,
      anon_sym_RBRACK,
    ACTIONS(19685), 1,
      anon_sym_GT,
    STATE(14651), 1,
      sym_attribute,
    STATE(14951), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669783] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19681), 1,
      sym__lowercase_identifier,
    STATE(11803), 1,
      sym_class_type_path,
    STATE(14652), 1,
      sym_attribute,
    STATE(17578), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669806] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19687), 1,
      anon_sym_GT_RBRACE,
    STATE(14653), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669829] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18197), 1,
      sym__lowercase_identifier,
    ACTIONS(18199), 1,
      anon_sym_LBRACK,
    ACTIONS(18201), 1,
      anon_sym_virtual,
    STATE(11259), 1,
      sym_class_binding,
    STATE(14654), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669852] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19689), 1,
      sym__lowercase_identifier,
    STATE(9823), 1,
      sym_class_type_path,
    STATE(14655), 1,
      sym_attribute,
    STATE(16582), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669875] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17062), 1,
      anon_sym_STAR,
    STATE(14470), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(14656), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13443), 2,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [669896] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19691), 1,
      anon_sym_RBRACK,
    ACTIONS(19693), 1,
      anon_sym_GT,
    STATE(14657), 1,
      sym_attribute,
    STATE(14693), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669919] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19691), 1,
      anon_sym_RBRACK,
    ACTIONS(19693), 1,
      anon_sym_GT,
    STATE(14658), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669942] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19695), 1,
      sym__lowercase_identifier,
    STATE(11017), 1,
      sym_class_type_path,
    STATE(14659), 1,
      sym_attribute,
    STATE(17499), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669965] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18474), 1,
      sym__lowercase_identifier,
    STATE(7055), 1,
      sym_class_path,
    STATE(14660), 1,
      sym_attribute,
    STATE(17957), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669988] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19695), 1,
      sym__lowercase_identifier,
    STATE(11042), 1,
      sym_class_type_path,
    STATE(14661), 1,
      sym_attribute,
    STATE(17499), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670011] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18568), 1,
      sym__lowercase_identifier,
    STATE(6806), 1,
      sym_class_path,
    STATE(14662), 1,
      sym_attribute,
    STATE(20390), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670034] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19695), 1,
      sym__lowercase_identifier,
    STATE(11134), 1,
      sym_class_type_path,
    STATE(14663), 1,
      sym_attribute,
    STATE(17499), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670057] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12260), 1,
      anon_sym_and,
    STATE(14664), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12258), 3,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [670076] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19697), 1,
      anon_sym_GT_RBRACE,
    STATE(14665), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670099] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18556), 1,
      sym__lowercase_identifier,
    STATE(7323), 1,
      sym_class_path,
    STATE(14666), 1,
      sym_attribute,
    STATE(17591), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670122] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19587), 1,
      sym__lowercase_identifier,
    STATE(10247), 1,
      sym_class_type_path,
    STATE(14667), 1,
      sym_attribute,
    STATE(17508), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670145] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19699), 1,
      anon_sym_RBRACK,
    STATE(14668), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670168] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19701), 1,
      sym__lowercase_identifier,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19703), 2,
      anon_sym_mutable,
      anon_sym_virtual,
    STATE(14669), 2,
      sym_attribute,
      aux_sym_instance_variable_specification_repeat1,
  [670187] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19681), 1,
      sym__lowercase_identifier,
    STATE(11802), 1,
      sym_class_type_path,
    STATE(14670), 1,
      sym_attribute,
    STATE(17578), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670210] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19706), 1,
      sym__lowercase_identifier,
    STATE(10902), 1,
      sym_class_type_path,
    STATE(14671), 1,
      sym_attribute,
    STATE(17079), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670233] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18377), 1,
      sym__lowercase_identifier,
    STATE(6005), 1,
      sym_class_path,
    STATE(14672), 1,
      sym_attribute,
    STATE(18570), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670256] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19708), 1,
      anon_sym_GT_RBRACE,
    STATE(14673), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670279] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18409), 1,
      anon_sym_LPAREN,
    ACTIONS(18456), 1,
      sym__lowercase_identifier,
    STATE(14674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13038), 2,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [670300] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(19710), 1,
      anon_sym_COLON_GT,
    ACTIONS(19712), 1,
      anon_sym_RPAREN,
    STATE(14675), 1,
      sym_attribute,
    STATE(16793), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670323] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19714), 1,
      sym__lowercase_identifier,
    STATE(14676), 1,
      sym_attribute,
    STATE(14707), 1,
      aux_sym_method_specification_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18957), 2,
      anon_sym_private,
      anon_sym_virtual,
  [670344] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(19716), 1,
      anon_sym_with,
    STATE(14677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670367] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(13344), 1,
      anon_sym_DASH_GT,
    STATE(9272), 1,
      aux_sym_module_binding_repeat1,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(14678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670390] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19718), 1,
      anon_sym_RBRACK,
    ACTIONS(19720), 1,
      anon_sym_GT,
    STATE(14679), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670413] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19718), 1,
      anon_sym_RBRACK,
    STATE(14680), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670436] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13955), 1,
      anon_sym_in,
    ACTIONS(19453), 1,
      anon_sym_and,
    ACTIONS(19455), 1,
      sym_let_and_operator,
    STATE(14633), 1,
      aux_sym_value_definition_repeat1,
    STATE(14681), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670459] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19722), 1,
      anon_sym_GT_RBRACE,
    STATE(14682), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670482] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(19724), 1,
      anon_sym_COLON_GT,
    ACTIONS(19726), 1,
      anon_sym_RPAREN,
    STATE(14683), 1,
      sym_attribute,
    STATE(17169), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670505] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19728), 1,
      anon_sym_RBRACK,
    STATE(14684), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670528] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16627), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    STATE(14685), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670551] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19730), 1,
      sym__lowercase_identifier,
    STATE(5594), 1,
      sym_type_constructor_path,
    STATE(14686), 1,
      sym_attribute,
    STATE(17465), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670574] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(19732), 1,
      anon_sym_COLON_GT,
    ACTIONS(19734), 1,
      anon_sym_RPAREN,
    STATE(14687), 1,
      sym_attribute,
    STATE(16937), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670597] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19736), 1,
      anon_sym_RBRACK,
    STATE(14688), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670620] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19695), 1,
      sym__lowercase_identifier,
    STATE(11038), 1,
      sym_class_type_path,
    STATE(14689), 1,
      sym_attribute,
    STATE(17499), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670643] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19736), 1,
      anon_sym_RBRACK,
    ACTIONS(19738), 1,
      anon_sym_GT,
    STATE(14690), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670666] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19740), 1,
      anon_sym_GT_RBRACE,
    STATE(14691), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670689] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19742), 1,
      sym__lowercase_identifier,
    STATE(14692), 1,
      sym_attribute,
    STATE(16511), 1,
      sym_extended_module_path,
    STATE(20291), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670712] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19744), 1,
      anon_sym_RBRACK,
    ACTIONS(19746), 1,
      anon_sym_GT,
    STATE(14693), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670735] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19744), 1,
      anon_sym_RBRACK,
    STATE(14694), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670758] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(13344), 1,
      anon_sym_DASH_GT,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(14629), 1,
      aux_sym_module_binding_repeat1,
    STATE(14695), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670781] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19748), 1,
      anon_sym_RBRACK,
    STATE(14696), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670804] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19750), 1,
      sym__lowercase_identifier,
    STATE(7770), 1,
      sym_type_constructor_path,
    STATE(14697), 1,
      sym_attribute,
    STATE(16583), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670827] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17797), 1,
      sym__lowercase_identifier,
    ACTIONS(17801), 1,
      anon_sym_LBRACK,
    ACTIONS(17803), 1,
      anon_sym_virtual,
    STATE(11259), 1,
      sym_class_binding,
    STATE(14698), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670850] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19752), 1,
      sym__lowercase_identifier,
    STATE(5558), 1,
      sym_type_constructor_path,
    STATE(14699), 1,
      sym_attribute,
    STATE(17143), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670873] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19754), 1,
      anon_sym_GT_RBRACE,
    STATE(14700), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670896] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19756), 1,
      anon_sym_RBRACK,
    STATE(14701), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670919] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19758), 1,
      anon_sym_RBRACK,
    STATE(14702), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670942] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19335), 1,
      sym__lowercase_identifier,
    STATE(10850), 1,
      sym_class_type_path,
    STATE(14703), 1,
      sym_attribute,
    STATE(16607), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670965] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19760), 1,
      anon_sym_GT_RBRACE,
    STATE(14704), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670988] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(19762), 1,
      anon_sym_with,
    STATE(14705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671011] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18614), 1,
      sym__lowercase_identifier,
    STATE(4825), 1,
      sym_class_path,
    STATE(14706), 1,
      sym_attribute,
    STATE(18724), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671034] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19764), 1,
      sym__lowercase_identifier,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19766), 2,
      anon_sym_private,
      anon_sym_virtual,
    STATE(14707), 2,
      sym_attribute,
      aux_sym_method_specification_repeat1,
  [671053] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19769), 1,
      anon_sym_RBRACK,
    STATE(14708), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671076] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(19771), 1,
      anon_sym_with,
    STATE(14709), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671099] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13457), 1,
      anon_sym_in,
    ACTIONS(16457), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(14262), 1,
      aux_sym_expression_item_repeat1,
    STATE(14710), 1,
      sym_attribute,
    STATE(15602), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671122] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18415), 1,
      sym__lowercase_identifier,
    STATE(5370), 1,
      sym_class_path,
    STATE(14711), 1,
      sym_attribute,
    STATE(18250), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671145] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19773), 1,
      sym__lowercase_identifier,
    STATE(12856), 1,
      sym_class_type_path,
    STATE(14712), 1,
      sym_attribute,
    STATE(17369), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671168] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19777), 1,
      anon_sym_COMMA,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19775), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
    STATE(14713), 2,
      sym_attribute,
      aux_sym__type_params_repeat1,
  [671187] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19773), 1,
      sym__lowercase_identifier,
    STATE(12861), 1,
      sym_class_type_path,
    STATE(14714), 1,
      sym_attribute,
    STATE(17369), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671210] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19780), 1,
      anon_sym_GT_RBRACE,
    STATE(14715), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671233] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19782), 1,
      anon_sym_rec,
    STATE(12723), 1,
      sym_module_binding,
    STATE(14716), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17935), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [671254] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19784), 1,
      anon_sym_RBRACK,
    ACTIONS(19786), 1,
      anon_sym_GT,
    STATE(14717), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671277] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19773), 1,
      sym__lowercase_identifier,
    STATE(12889), 1,
      sym_class_type_path,
    STATE(14718), 1,
      sym_attribute,
    STATE(17369), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671300] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19784), 1,
      anon_sym_RBRACK,
    STATE(14719), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671323] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19788), 1,
      sym__lowercase_identifier,
    STATE(9416), 1,
      sym_class_type_path,
    STATE(14720), 1,
      sym_attribute,
    STATE(16948), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671346] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19790), 1,
      anon_sym_DOT,
    STATE(14721), 1,
      sym_attribute,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671369] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19792), 1,
      anon_sym_DOT,
    STATE(14722), 1,
      sym_attribute,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671392] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19794), 1,
      anon_sym_DOT,
    ACTIONS(19796), 1,
      aux_sym_type_variable_token1,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14723), 2,
      sym_attribute,
      aux_sym_constructor_declaration_repeat1,
  [671413] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19799), 1,
      anon_sym_RBRACK,
    STATE(14724), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671436] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(19801), 1,
      anon_sym_COLON_GT,
    ACTIONS(19803), 1,
      anon_sym_RPAREN,
    STATE(14725), 1,
      sym_attribute,
    STATE(17336), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671459] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19788), 1,
      sym__lowercase_identifier,
    STATE(9344), 1,
      sym_class_type_path,
    STATE(14726), 1,
      sym_attribute,
    STATE(16948), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671482] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19799), 1,
      anon_sym_RBRACK,
    ACTIONS(19805), 1,
      anon_sym_GT,
    STATE(14727), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671505] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    STATE(14728), 1,
      sym_attribute,
    STATE(16808), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19807), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [671526] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18265), 1,
      sym__lowercase_identifier,
    ACTIONS(18267), 1,
      anon_sym_LBRACK,
    ACTIONS(18269), 1,
      anon_sym_virtual,
    STATE(11259), 1,
      sym_class_binding,
    STATE(14729), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671549] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19521), 1,
      sym__lowercase_identifier,
    STATE(9099), 1,
      sym_class_type_path,
    STATE(14730), 1,
      sym_attribute,
    STATE(17407), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671572] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(19809), 1,
      anon_sym_COLON_GT,
    ACTIONS(19811), 1,
      anon_sym_RPAREN,
    STATE(14731), 1,
      sym_attribute,
    STATE(17409), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671595] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19813), 1,
      anon_sym_RBRACK,
    STATE(14732), 1,
      sym_attribute,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671618] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9986), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19815), 1,
      anon_sym_GT,
    STATE(14733), 1,
      sym_attribute,
    STATE(14746), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671641] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10227), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19817), 1,
      anon_sym_GT,
    STATE(14734), 1,
      sym_attribute,
    STATE(14762), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671664] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11100), 1,
      anon_sym_in,
    ACTIONS(16457), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(14262), 1,
      aux_sym_expression_item_repeat1,
    STATE(14735), 1,
      sym_attribute,
    STATE(15602), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671687] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19819), 1,
      anon_sym_GT_RBRACE,
    STATE(14736), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671710] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19821), 1,
      sym__lowercase_identifier,
    STATE(14737), 1,
      sym_attribute,
    STATE(14961), 1,
      aux_sym__abstract_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19823), 2,
      anon_sym_RPAREN,
      anon_sym_DOT,
  [671731] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19825), 1,
      anon_sym_GT_RBRACE,
    STATE(14738), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671754] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19689), 1,
      sym__lowercase_identifier,
    STATE(12534), 1,
      sym_class_type_path,
    STATE(14739), 1,
      sym_attribute,
    STATE(16582), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671777] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19827), 1,
      sym__lowercase_identifier,
    STATE(9541), 1,
      sym_class_type_path,
    STATE(14740), 1,
      sym_attribute,
    STATE(16550), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671800] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19829), 1,
      anon_sym_RBRACK,
    ACTIONS(19831), 1,
      aux_sym_tag_token1,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14741), 2,
      sym_attribute,
      aux_sym_polymorphic_variant_type_repeat2,
  [671821] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16886), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    STATE(14742), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671844] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16653), 1,
      anon_sym_COMMA,
    ACTIONS(16923), 1,
      anon_sym_PIPE,
    ACTIONS(16927), 1,
      anon_sym_as,
    ACTIONS(16929), 1,
      anon_sym_COLON_COLON,
    STATE(14743), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671867] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    STATE(14744), 1,
      sym_attribute,
    STATE(17435), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19834), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [671888] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19836), 1,
      anon_sym_RBRACK,
    ACTIONS(19838), 1,
      anon_sym_GT,
    STATE(14745), 1,
      sym_attribute,
    STATE(14764), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671911] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19836), 1,
      anon_sym_RBRACK,
    ACTIONS(19838), 1,
      anon_sym_GT,
    STATE(14746), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671934] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19439), 1,
      sym__lowercase_identifier,
    STATE(10956), 1,
      sym_class_type_path,
    STATE(14747), 1,
      sym_attribute,
    STATE(17472), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671957] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19840), 1,
      anon_sym_GT_RBRACE,
    STATE(14748), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671980] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18726), 1,
      sym__lowercase_identifier,
    STATE(7741), 1,
      sym_class_path,
    STATE(14749), 1,
      sym_attribute,
    STATE(17795), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672003] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19439), 1,
      sym__lowercase_identifier,
    STATE(10944), 1,
      sym_class_type_path,
    STATE(14750), 1,
      sym_attribute,
    STATE(17472), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672026] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(19842), 1,
      anon_sym_with,
    STATE(14751), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672049] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18618), 1,
      sym__lowercase_identifier,
    STATE(10031), 1,
      sym_class_path,
    STATE(14752), 1,
      sym_attribute,
    STATE(17854), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672072] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19844), 1,
      anon_sym_GT_RBRACE,
    STATE(14753), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672095] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19846), 1,
      anon_sym_GT_RBRACE,
    STATE(14754), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672118] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19848), 1,
      anon_sym_RBRACK,
    ACTIONS(19850), 1,
      anon_sym_GT,
    STATE(14755), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672141] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19852), 1,
      anon_sym_RBRACK,
    ACTIONS(19854), 1,
      anon_sym_GT,
    STATE(14756), 1,
      sym_attribute,
    STATE(14780), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672164] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19439), 1,
      sym__lowercase_identifier,
    STATE(10918), 1,
      sym_class_type_path,
    STATE(14757), 1,
      sym_attribute,
    STATE(17472), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672187] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(19856), 1,
      anon_sym_with,
    STATE(14758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672210] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(19858), 1,
      anon_sym_COLON_GT,
    ACTIONS(19860), 1,
      anon_sym_RPAREN,
    STATE(14759), 1,
      sym_attribute,
    STATE(16577), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672233] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18692), 1,
      sym__lowercase_identifier,
    STATE(3655), 1,
      sym_class_path,
    STATE(14760), 1,
      sym_attribute,
    STATE(18065), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672256] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19862), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14761), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672279] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19852), 1,
      anon_sym_RBRACK,
    ACTIONS(19854), 1,
      anon_sym_GT,
    STATE(14762), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672302] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19848), 1,
      anon_sym_RBRACK,
    ACTIONS(19850), 1,
      anon_sym_GT,
    STATE(14690), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(14763), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672325] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19864), 1,
      anon_sym_RBRACK,
    ACTIONS(19866), 1,
      anon_sym_GT,
    STATE(14764), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672348] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19868), 1,
      anon_sym_GT_RBRACE,
    STATE(14765), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672371] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19864), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14766), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672394] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19870), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14767), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672417] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19872), 1,
      anon_sym_GT_RBRACE,
    STATE(14768), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672440] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19874), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14769), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672463] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19876), 1,
      anon_sym_RBRACK,
    ACTIONS(19878), 1,
      anon_sym_GT,
    STATE(14770), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672486] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19876), 1,
      anon_sym_RBRACK,
    ACTIONS(19878), 1,
      anon_sym_GT,
    STATE(14727), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(14771), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672509] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16334), 1,
      sym__lowercase_identifier,
    ACTIONS(18409), 1,
      anon_sym_LPAREN,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(14772), 1,
      sym_attribute,
    STATE(16570), 1,
      sym__value_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672532] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18265), 1,
      sym__lowercase_identifier,
    ACTIONS(18267), 1,
      anon_sym_LBRACK,
    ACTIONS(18269), 1,
      anon_sym_virtual,
    STATE(12759), 1,
      sym_class_binding,
    STATE(14773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672555] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18409), 1,
      anon_sym_LPAREN,
    ACTIONS(18456), 1,
      sym__lowercase_identifier,
    STATE(14774), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(20398), 2,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [672576] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19880), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14775), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672599] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19882), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14776), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672622] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(19884), 1,
      anon_sym_with,
    STATE(14777), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672645] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19886), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14778), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672668] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18760), 1,
      sym__lowercase_identifier,
    STATE(5872), 1,
      sym_class_path,
    STATE(14779), 1,
      sym_attribute,
    STATE(18290), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672691] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19888), 1,
      anon_sym_RBRACK,
    ACTIONS(19890), 1,
      anon_sym_GT,
    STATE(14780), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672714] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19888), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14781), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672737] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19892), 1,
      anon_sym_GT_RBRACE,
    STATE(14782), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672760] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19689), 1,
      sym__lowercase_identifier,
    STATE(12595), 1,
      sym_class_type_path,
    STATE(14783), 1,
      sym_attribute,
    STATE(16582), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672783] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19894), 1,
      sym__lowercase_identifier,
    STATE(9494), 1,
      sym_class_type_path,
    STATE(14784), 1,
      sym_attribute,
    STATE(17266), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672806] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(19896), 1,
      anon_sym_with,
    STATE(14785), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672829] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(19898), 1,
      anon_sym_DASH_GT,
    STATE(9272), 1,
      aux_sym_module_binding_repeat1,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(14786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672852] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(19900), 1,
      anon_sym_with,
    STATE(14787), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672875] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19902), 1,
      anon_sym_DOT,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(14788), 1,
      sym_attribute,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672898] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19904), 1,
      sym__lowercase_identifier,
    STATE(9735), 1,
      sym_class_type_path,
    STATE(14789), 1,
      sym_attribute,
    STATE(16788), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672921] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19894), 1,
      sym__lowercase_identifier,
    STATE(9487), 1,
      sym_class_type_path,
    STATE(14790), 1,
      sym_attribute,
    STATE(17266), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672944] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19906), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14791), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672967] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19908), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14792), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672990] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19894), 1,
      sym__lowercase_identifier,
    STATE(9445), 1,
      sym_class_type_path,
    STATE(14793), 1,
      sym_attribute,
    STATE(17266), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673013] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19910), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14794), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673036] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19912), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14795), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673059] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18397), 1,
      sym__lowercase_identifier,
    STATE(7006), 1,
      sym_class_path,
    STATE(14796), 1,
      sym_attribute,
    STATE(18461), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673082] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(19914), 1,
      anon_sym_with,
    STATE(14797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673105] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19916), 1,
      anon_sym_GT_RBRACE,
    STATE(14798), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673128] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(19918), 1,
      anon_sym_COLON_GT,
    ACTIONS(19920), 1,
      anon_sym_RPAREN,
    STATE(14799), 1,
      sym_attribute,
    STATE(17372), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673151] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(19922), 1,
      anon_sym_COLON_GT,
    ACTIONS(19924), 1,
      anon_sym_RPAREN,
    STATE(14800), 1,
      sym_attribute,
    STATE(17525), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673174] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11316), 1,
      sym__lowercase_identifier,
    STATE(14801), 1,
      sym_attribute,
    STATE(15608), 1,
      sym_type_constructor_path,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673197] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19926), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14802), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673220] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19928), 1,
      anon_sym_GT_RBRACE,
    STATE(14803), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673243] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19926), 1,
      anon_sym_RBRACK,
    ACTIONS(19930), 1,
      anon_sym_GT,
    STATE(14804), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673266] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11316), 1,
      sym__lowercase_identifier,
    STATE(14805), 1,
      sym_attribute,
    STATE(15875), 1,
      sym_type_constructor_path,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673289] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18488), 1,
      sym__lowercase_identifier,
    STATE(3161), 1,
      sym_class_path,
    STATE(14806), 1,
      sym_attribute,
    STATE(18762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673312] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18710), 1,
      sym__lowercase_identifier,
    STATE(7990), 1,
      sym_class_path,
    STATE(14807), 1,
      sym_attribute,
    STATE(19003), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673335] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19637), 1,
      sym__lowercase_identifier,
    STATE(9210), 1,
      sym_class_type_path,
    STATE(14808), 1,
      sym_attribute,
    STATE(17382), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673358] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19706), 1,
      sym__lowercase_identifier,
    STATE(10914), 1,
      sym_class_type_path,
    STATE(14809), 1,
      sym_attribute,
    STATE(17079), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673381] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18568), 1,
      sym__lowercase_identifier,
    STATE(7715), 1,
      sym_class_path,
    STATE(14810), 1,
      sym_attribute,
    STATE(20390), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673404] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19932), 1,
      anon_sym_DOT,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(14811), 1,
      sym_attribute,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673427] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19706), 1,
      sym__lowercase_identifier,
    STATE(10905), 1,
      sym_class_type_path,
    STATE(14812), 1,
      sym_attribute,
    STATE(17079), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673450] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19934), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14813), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673473] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19936), 1,
      anon_sym_GT_RBRACE,
    STATE(14814), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673496] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19938), 1,
      anon_sym_DOT,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(14815), 1,
      sym_attribute,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673519] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19449), 1,
      sym__lowercase_identifier,
    STATE(9348), 1,
      sym_class_type_path,
    STATE(14816), 1,
      sym_attribute,
    STATE(17550), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673542] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9972), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19940), 1,
      anon_sym_GT,
    STATE(14817), 1,
      sym_attribute,
    STATE(14850), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673565] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19942), 1,
      anon_sym_GT_RBRACE,
    STATE(14818), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673588] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19944), 1,
      anon_sym_GT_RBRACE,
    STATE(14819), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673611] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19449), 1,
      sym__lowercase_identifier,
    STATE(9352), 1,
      sym_class_type_path,
    STATE(14820), 1,
      sym_attribute,
    STATE(17550), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673634] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19449), 1,
      sym__lowercase_identifier,
    STATE(9369), 1,
      sym_class_type_path,
    STATE(14821), 1,
      sym_attribute,
    STATE(17550), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673657] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19946), 1,
      anon_sym_GT_RBRACE,
    STATE(14822), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673680] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10178), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19948), 1,
      anon_sym_GT,
    STATE(14770), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(14823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673703] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19950), 1,
      anon_sym_GT_RBRACE,
    STATE(14824), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673726] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18532), 1,
      sym__lowercase_identifier,
    STATE(7093), 1,
      sym_class_path,
    STATE(14825), 1,
      sym_attribute,
    STATE(18053), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673749] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(19952), 1,
      anon_sym_with,
    STATE(14826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673772] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(13921), 1,
      anon_sym_DASH_GT,
    STATE(9272), 1,
      aux_sym_module_binding_repeat1,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(14827), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673795] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18409), 1,
      anon_sym_LPAREN,
    ACTIONS(18456), 1,
      sym__lowercase_identifier,
    STATE(14828), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(20319), 2,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [673816] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18600), 1,
      sym__lowercase_identifier,
    STATE(3783), 1,
      sym_class_path,
    STATE(14829), 1,
      sym_attribute,
    STATE(18530), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673839] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(19954), 1,
      anon_sym_COLON_GT,
    ACTIONS(19956), 1,
      anon_sym_RPAREN,
    STATE(14830), 1,
      sym_attribute,
    STATE(17361), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673862] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19683), 1,
      anon_sym_RBRACK,
    ACTIONS(19685), 1,
      anon_sym_GT,
    STATE(14831), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673885] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(13921), 1,
      anon_sym_DASH_GT,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(14786), 1,
      aux_sym_module_binding_repeat1,
    STATE(14832), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673908] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19958), 1,
      anon_sym_GT_RBRACE,
    STATE(14833), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673931] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18670), 1,
      sym__lowercase_identifier,
    STATE(5298), 1,
      sym_class_path,
    STATE(14834), 1,
      sym_attribute,
    STATE(19791), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673954] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19420), 1,
      sym__lowercase_identifier,
    STATE(10041), 1,
      sym_class_type_path,
    STATE(14835), 1,
      sym_attribute,
    STATE(17422), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673977] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19960), 1,
      anon_sym_DOT,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(14836), 1,
      sym_attribute,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674000] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19962), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14837), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674023] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19964), 1,
      anon_sym_DOT,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(14838), 1,
      sym_attribute,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674046] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19966), 1,
      anon_sym_GT_RBRACE,
    STATE(14839), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674069] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(19968), 1,
      anon_sym_COLON_GT,
    ACTIONS(19970), 1,
      anon_sym_RPAREN,
    STATE(14840), 1,
      sym_attribute,
    STATE(16900), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674092] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19420), 1,
      sym__lowercase_identifier,
    STATE(10098), 1,
      sym_class_type_path,
    STATE(14841), 1,
      sym_attribute,
    STATE(17422), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674115] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19972), 1,
      anon_sym_rec,
    STATE(12028), 1,
      sym_module_binding,
    STATE(14842), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18003), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [674136] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19420), 1,
      sym__lowercase_identifier,
    STATE(9968), 1,
      sym_class_type_path,
    STATE(14843), 1,
      sym_attribute,
    STATE(17422), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674159] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19974), 1,
      sym__lowercase_identifier,
    ACTIONS(19976), 1,
      anon_sym_RBRACE,
    ACTIONS(19978), 1,
      anon_sym_mutable,
    STATE(14844), 1,
      sym_attribute,
    STATE(16635), 1,
      sym_field_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674182] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    STATE(14845), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15122), 2,
      anon_sym_COLON_GT,
      anon_sym_EQ,
  [674203] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    STATE(14846), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15118), 2,
      anon_sym_COLON_GT,
      anon_sym_EQ,
  [674224] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(19980), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14847), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674247] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    STATE(14848), 1,
      sym_attribute,
    STATE(16966), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19982), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [674268] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19984), 1,
      anon_sym_RBRACK,
    ACTIONS(19986), 1,
      anon_sym_GT,
    STATE(14849), 1,
      sym_attribute,
    STATE(14860), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674291] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19984), 1,
      anon_sym_RBRACK,
    ACTIONS(19986), 1,
      anon_sym_GT,
    STATE(14850), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674314] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18764), 1,
      sym__lowercase_identifier,
    STATE(4281), 1,
      sym_class_path,
    STATE(14851), 1,
      sym_attribute,
    STATE(20435), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674337] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17951), 1,
      sym__lowercase_identifier,
    ACTIONS(17953), 1,
      anon_sym_LBRACK,
    ACTIONS(17955), 1,
      anon_sym_virtual,
    STATE(11259), 1,
      sym_class_binding,
    STATE(14852), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674360] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10196), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19988), 1,
      anon_sym_GT,
    STATE(14755), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(14853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674383] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(19990), 1,
      anon_sym_with,
    STATE(14854), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674406] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(19992), 1,
      sym__lowercase_identifier,
    STATE(7358), 1,
      sym_class_path,
    STATE(14855), 1,
      sym_attribute,
    STATE(17641), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674429] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19994), 1,
      anon_sym_GT_RBRACE,
    STATE(14856), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674452] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19996), 1,
      anon_sym_GT_RBRACE,
    STATE(14857), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674475] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(19998), 1,
      anon_sym_GT_RBRACE,
    STATE(14858), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674498] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18399), 1,
      sym__lowercase_identifier,
    STATE(7177), 1,
      sym_class_path,
    STATE(14859), 1,
      sym_attribute,
    STATE(18683), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674521] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20000), 1,
      anon_sym_RBRACK,
    ACTIONS(20002), 1,
      anon_sym_GT,
    STATE(14860), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674544] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20000), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14861), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674567] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20004), 1,
      anon_sym_GT_RBRACE,
    STATE(14862), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674590] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19706), 1,
      sym__lowercase_identifier,
    STATE(10969), 1,
      sym_class_type_path,
    STATE(14863), 1,
      sym_attribute,
    STATE(17079), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674613] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20006), 1,
      anon_sym_GT_RBRACE,
    STATE(14864), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674636] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20008), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14865), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674659] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20010), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14866), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674682] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(20012), 1,
      sym__lowercase_identifier,
    STATE(7526), 1,
      sym_type_constructor_path,
    STATE(14867), 1,
      sym_attribute,
    STATE(17539), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674705] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18409), 1,
      anon_sym_LPAREN,
    ACTIONS(18456), 1,
      sym__lowercase_identifier,
    STATE(14868), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(20387), 2,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [674726] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20010), 1,
      anon_sym_RBRACK,
    ACTIONS(20014), 1,
      anon_sym_GT,
    STATE(14869), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674749] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20016), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14870), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674772] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20018), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14871), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674795] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18538), 1,
      sym__lowercase_identifier,
    STATE(6482), 1,
      sym_class_path,
    STATE(14872), 1,
      sym_attribute,
    STATE(18330), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674818] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20020), 1,
      sym__lowercase_identifier,
    STATE(14707), 1,
      aux_sym_method_specification_repeat1,
    STATE(14873), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18957), 2,
      anon_sym_private,
      anon_sym_virtual,
  [674839] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20022), 1,
      sym__lowercase_identifier,
    ACTIONS(20024), 1,
      anon_sym_LPAREN,
    STATE(5674), 1,
      sym_parenthesized_operator,
    STATE(5699), 1,
      sym__value_name,
    STATE(14874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674862] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(20026), 1,
      sym__lowercase_identifier,
    STATE(10642), 1,
      sym_class_type_path,
    STATE(14875), 1,
      sym_attribute,
    STATE(17183), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674885] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(20026), 1,
      sym__lowercase_identifier,
    STATE(10674), 1,
      sym_class_type_path,
    STATE(14876), 1,
      sym_attribute,
    STATE(17183), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674908] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(20028), 1,
      anon_sym_COLON_GT,
    ACTIONS(20030), 1,
      anon_sym_RPAREN,
    STATE(14877), 1,
      sym_attribute,
    STATE(16975), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674931] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20020), 1,
      sym__lowercase_identifier,
    STATE(14676), 1,
      aux_sym_method_specification_repeat1,
    STATE(14878), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18957), 2,
      anon_sym_private,
      anon_sym_virtual,
  [674952] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(20032), 1,
      anon_sym_COLON_GT,
    ACTIONS(20034), 1,
      anon_sym_RPAREN,
    STATE(14879), 1,
      sym_attribute,
    STATE(16983), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674975] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(20036), 1,
      anon_sym_with,
    STATE(14880), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674998] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20038), 1,
      anon_sym_GT_RBRACE,
    STATE(14881), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675021] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19317), 1,
      sym__lowercase_identifier,
    STATE(13605), 1,
      sym_class_type_path,
    STATE(14882), 1,
      sym_attribute,
    STATE(17572), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675044] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20040), 1,
      anon_sym_GT_RBRACE,
    STATE(14883), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675067] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(20026), 1,
      sym__lowercase_identifier,
    STATE(10686), 1,
      sym_class_type_path,
    STATE(14884), 1,
      sym_attribute,
    STATE(17183), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675090] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20042), 1,
      anon_sym_RBRACK,
    ACTIONS(20044), 1,
      anon_sym_GT,
    STATE(14885), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675113] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19689), 1,
      sym__lowercase_identifier,
    STATE(9735), 1,
      sym_class_type_path,
    STATE(14886), 1,
      sym_attribute,
    STATE(16582), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675136] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18570), 1,
      sym__lowercase_identifier,
    STATE(7420), 1,
      sym_class_path,
    STATE(14887), 1,
      sym_attribute,
    STATE(19260), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675159] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19974), 1,
      sym__lowercase_identifier,
    ACTIONS(19978), 1,
      anon_sym_mutable,
    ACTIONS(20046), 1,
      anon_sym_RBRACE,
    STATE(14888), 1,
      sym_attribute,
    STATE(16635), 1,
      sym_field_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675182] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(19992), 1,
      sym__lowercase_identifier,
    STATE(7381), 1,
      sym_class_path,
    STATE(14889), 1,
      sym_attribute,
    STATE(17641), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675205] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20042), 1,
      anon_sym_RBRACK,
    ACTIONS(20044), 1,
      anon_sym_GT,
    STATE(14804), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(14890), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675228] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19529), 1,
      sym__lowercase_identifier,
    STATE(10844), 1,
      sym_class_type_path,
    STATE(14891), 1,
      sym_attribute,
    STATE(17344), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675251] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    STATE(14892), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13277), 2,
      anon_sym_COLON_GT,
      anon_sym_EQ,
  [675272] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(20048), 1,
      anon_sym_COLON_GT,
    ACTIONS(20050), 1,
      anon_sym_RPAREN,
    STATE(14893), 1,
      sym_attribute,
    STATE(17398), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675295] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(20026), 1,
      sym__lowercase_identifier,
    STATE(10585), 1,
      sym_class_type_path,
    STATE(14894), 1,
      sym_attribute,
    STATE(17183), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675318] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    STATE(14895), 1,
      sym_attribute,
    STATE(17357), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20052), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [675339] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20054), 1,
      anon_sym_GT_RBRACE,
    STATE(14896), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675362] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19773), 1,
      sym__lowercase_identifier,
    STATE(12850), 1,
      sym_class_type_path,
    STATE(14897), 1,
      sym_attribute,
    STATE(17369), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675385] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20056), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14898), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675408] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13461), 1,
      anon_sym_in,
    ACTIONS(16457), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(14262), 1,
      aux_sym_expression_item_repeat1,
    STATE(14899), 1,
      sym_attribute,
    STATE(15602), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675431] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19681), 1,
      sym__lowercase_identifier,
    STATE(11777), 1,
      sym_class_type_path,
    STATE(14900), 1,
      sym_attribute,
    STATE(17578), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675454] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20058), 1,
      anon_sym_DOT,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(14901), 1,
      sym_attribute,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675477] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20060), 1,
      anon_sym_DOT,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(14902), 1,
      sym_attribute,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675500] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(20062), 1,
      anon_sym_with,
    STATE(14903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675523] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(20064), 1,
      anon_sym_COLON_GT,
    ACTIONS(20066), 1,
      anon_sym_RPAREN,
    STATE(14904), 1,
      sym_attribute,
    STATE(17073), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675546] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18389), 1,
      sym__lowercase_identifier,
    STATE(6504), 1,
      sym_class_path,
    STATE(14905), 1,
      sym_attribute,
    STATE(18800), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675569] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20068), 1,
      anon_sym_DOT,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(14906), 1,
      sym_attribute,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675592] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10086), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20070), 1,
      anon_sym_GT,
    STATE(14907), 1,
      sym_attribute,
    STATE(14925), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675615] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    ACTIONS(20072), 1,
      anon_sym_EQ,
    ACTIONS(20074), 1,
      anon_sym_RPAREN,
    STATE(14908), 1,
      sym_attribute,
    STATE(16762), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675638] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20076), 1,
      anon_sym_RBRACK,
    ACTIONS(20078), 1,
      anon_sym_GT,
    STATE(14909), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675661] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(20080), 1,
      anon_sym_COLON_GT,
    ACTIONS(20082), 1,
      anon_sym_RPAREN,
    STATE(14910), 1,
      sym_attribute,
    STATE(17015), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675684] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20076), 1,
      anon_sym_RBRACK,
    ACTIONS(20078), 1,
      anon_sym_GT,
    STATE(14869), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(14911), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675707] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(17761), 1,
      anon_sym_DASH_GT,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(14912), 1,
      sym_attribute,
    STATE(14943), 1,
      aux_sym_module_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675730] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18395), 1,
      sym__lowercase_identifier,
    STATE(6347), 1,
      sym_class_path,
    STATE(14913), 1,
      sym_attribute,
    STATE(18011), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675753] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19297), 1,
      sym__lowercase_identifier,
    STATE(13164), 1,
      sym_class_type_path,
    STATE(14914), 1,
      sym_attribute,
    STATE(17487), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675776] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(17761), 1,
      anon_sym_DASH_GT,
    STATE(9272), 1,
      aux_sym_module_binding_repeat1,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(14915), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675799] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19297), 1,
      sym__lowercase_identifier,
    STATE(13173), 1,
      sym_class_type_path,
    STATE(14916), 1,
      sym_attribute,
    STATE(17487), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675822] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19297), 1,
      sym__lowercase_identifier,
    STATE(13179), 1,
      sym_class_type_path,
    STATE(14917), 1,
      sym_attribute,
    STATE(17487), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675845] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20084), 1,
      anon_sym_GT_RBRACE,
    STATE(14918), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675868] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(20086), 1,
      anon_sym_DASH_GT,
    STATE(9272), 1,
      aux_sym_module_binding_repeat1,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(14919), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675891] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(20088), 1,
      anon_sym_COLON_GT,
    ACTIONS(20090), 1,
      anon_sym_RPAREN,
    STATE(14920), 1,
      sym_attribute,
    STATE(17498), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675914] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18580), 1,
      sym__lowercase_identifier,
    STATE(3648), 1,
      sym_class_path,
    STATE(14921), 1,
      sym_attribute,
    STATE(19002), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675937] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10214), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20092), 1,
      anon_sym_GT,
    STATE(14922), 1,
      sym_attribute,
    STATE(14977), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675960] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20094), 1,
      anon_sym_DOT,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(14923), 1,
      sym_attribute,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675983] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20096), 1,
      anon_sym_RBRACK,
    ACTIONS(20098), 1,
      anon_sym_GT,
    STATE(14924), 1,
      sym_attribute,
    STATE(14937), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676006] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20096), 1,
      anon_sym_RBRACK,
    ACTIONS(20098), 1,
      anon_sym_GT,
    STATE(14925), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676029] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(20100), 1,
      anon_sym_with,
    STATE(14926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676052] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10064), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20102), 1,
      anon_sym_GT,
    STATE(14571), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(14927), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676075] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20104), 1,
      anon_sym_GT_RBRACE,
    STATE(14928), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676098] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(20106), 1,
      anon_sym_COLON_GT,
    ACTIONS(20108), 1,
      anon_sym_RPAREN,
    STATE(14929), 1,
      sym_attribute,
    STATE(17308), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676121] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13901), 1,
      anon_sym_in,
    ACTIONS(19453), 1,
      anon_sym_and,
    ACTIONS(19455), 1,
      sym_let_and_operator,
    STATE(14681), 1,
      aux_sym_value_definition_repeat1,
    STATE(14930), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676144] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20110), 1,
      anon_sym_GT_RBRACE,
    STATE(14931), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676167] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18726), 1,
      sym__lowercase_identifier,
    STATE(6670), 1,
      sym_class_path,
    STATE(14932), 1,
      sym_attribute,
    STATE(17795), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676190] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13901), 1,
      anon_sym_in,
    ACTIONS(19453), 1,
      anon_sym_and,
    ACTIONS(19455), 1,
      sym_let_and_operator,
    STATE(14633), 1,
      aux_sym_value_definition_repeat1,
    STATE(14933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676213] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(20112), 1,
      sym__lowercase_identifier,
    STATE(5597), 1,
      sym_type_constructor_path,
    STATE(14934), 1,
      sym_attribute,
    STATE(17568), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676236] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(20114), 1,
      anon_sym_DASH_GT,
    STATE(9272), 1,
      aux_sym_module_binding_repeat1,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(14935), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676259] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20116), 1,
      anon_sym_GT_RBRACE,
    STATE(14936), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676282] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20118), 1,
      anon_sym_RBRACK,
    ACTIONS(20120), 1,
      anon_sym_GT,
    STATE(14937), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676305] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(20122), 1,
      anon_sym_with,
    STATE(14938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676328] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20118), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14939), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676351] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    STATE(9272), 1,
      aux_sym_module_binding_repeat1,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(14940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676374] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19689), 1,
      sym__lowercase_identifier,
    STATE(12230), 1,
      sym_class_type_path,
    STATE(14941), 1,
      sym_attribute,
    STATE(16582), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676397] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18796), 1,
      sym__lowercase_identifier,
    STATE(6290), 1,
      sym_class_path,
    STATE(14942), 1,
      sym_attribute,
    STATE(18490), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676420] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(20124), 1,
      anon_sym_DASH_GT,
    STATE(9272), 1,
      aux_sym_module_binding_repeat1,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(14943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676443] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20126), 1,
      anon_sym_GT_RBRACE,
    STATE(14944), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676466] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(20128), 1,
      anon_sym_with,
    STATE(14945), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676489] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20130), 1,
      sym__lowercase_identifier,
    ACTIONS(20132), 1,
      anon_sym_LPAREN,
    STATE(8914), 1,
      sym_parenthesized_operator,
    STATE(8931), 1,
      sym__value_name,
    STATE(14946), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676512] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(14919), 1,
      aux_sym_module_binding_repeat1,
    STATE(14947), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676535] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20134), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14948), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676558] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(20136), 1,
      sym__lowercase_identifier,
    STATE(5476), 1,
      sym_type_constructor_path,
    STATE(14949), 1,
      sym_attribute,
    STATE(16540), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676581] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(20138), 1,
      anon_sym_with,
    STATE(14950), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676604] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19962), 1,
      anon_sym_RBRACK,
    ACTIONS(20140), 1,
      anon_sym_GT,
    STATE(14951), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676627] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20142), 1,
      anon_sym_GT_RBRACE,
    STATE(14952), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676650] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(20144), 1,
      anon_sym_COLON_GT,
    ACTIONS(20146), 1,
      anon_sym_RPAREN,
    STATE(14953), 1,
      sym_attribute,
    STATE(17054), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676673] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(20148), 1,
      anon_sym_COLON_GT,
    ACTIONS(20150), 1,
      anon_sym_RPAREN,
    STATE(14954), 1,
      sym_attribute,
    STATE(16671), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676696] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20152), 1,
      anon_sym_DOT,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(14955), 1,
      sym_attribute,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676719] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19827), 1,
      sym__lowercase_identifier,
    STATE(9724), 1,
      sym_class_type_path,
    STATE(14956), 1,
      sym_attribute,
    STATE(16550), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676742] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    STATE(14957), 1,
      sym_attribute,
    STATE(17095), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20154), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [676763] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17951), 1,
      sym__lowercase_identifier,
    ACTIONS(17953), 1,
      anon_sym_LBRACK,
    ACTIONS(17955), 1,
      anon_sym_virtual,
    STATE(12126), 1,
      sym_class_binding,
    STATE(14958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676786] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20156), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14959), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676809] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20158), 1,
      anon_sym_rec,
    STATE(12048), 1,
      sym_module_binding,
    STATE(14960), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18041), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [676830] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20160), 1,
      sym__lowercase_identifier,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20163), 2,
      anon_sym_RPAREN,
      anon_sym_DOT,
    STATE(14961), 2,
      sym_attribute,
      aux_sym__abstract_type_repeat1,
  [676849] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18409), 1,
      anon_sym_LPAREN,
    ACTIONS(18456), 1,
      sym__lowercase_identifier,
    STATE(14962), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13056), 2,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [676870] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20165), 1,
      anon_sym_GT_RBRACE,
    STATE(14963), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676893] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20167), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14964), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676916] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20169), 1,
      anon_sym_DOT,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(14965), 1,
      sym_attribute,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676939] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20171), 1,
      anon_sym_DOT,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(14966), 1,
      sym_attribute,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676962] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10206), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20173), 1,
      anon_sym_GT,
    STATE(14594), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(14967), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676985] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18436), 1,
      sym__lowercase_identifier,
    STATE(3661), 1,
      sym_class_path,
    STATE(14968), 1,
      sym_attribute,
    STATE(18982), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677008] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18432), 1,
      sym__lowercase_identifier,
    STATE(6260), 1,
      sym_class_path,
    STATE(14969), 1,
      sym_attribute,
    STATE(18370), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677031] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20175), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14970), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677054] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(20177), 1,
      anon_sym_with,
    STATE(14971), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677077] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(20179), 1,
      sym__lowercase_identifier,
    STATE(10287), 1,
      sym_type_constructor_path,
    STATE(14972), 1,
      sym_attribute,
    STATE(16724), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677100] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19788), 1,
      sym__lowercase_identifier,
    STATE(9424), 1,
      sym_class_type_path,
    STATE(14973), 1,
      sym_attribute,
    STATE(16948), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677123] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20181), 1,
      anon_sym_GT_RBRACE,
    STATE(14974), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677146] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20183), 1,
      anon_sym_GT_RBRACE,
    STATE(14975), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677169] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20185), 1,
      anon_sym_RBRACK,
    ACTIONS(20187), 1,
      anon_sym_GT,
    STATE(14976), 1,
      sym_attribute,
    STATE(15011), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677192] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20185), 1,
      anon_sym_RBRACK,
    ACTIONS(20187), 1,
      anon_sym_GT,
    STATE(14977), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677215] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20189), 1,
      anon_sym_DOT,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(14978), 1,
      sym_attribute,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677238] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(20191), 1,
      anon_sym_with,
    STATE(14979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677261] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20193), 1,
      anon_sym_GT_RBRACE,
    STATE(14980), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677284] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20195), 1,
      anon_sym_DOT,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(14981), 1,
      sym_attribute,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677307] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20197), 1,
      anon_sym_GT_RBRACE,
    STATE(14982), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677330] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20199), 1,
      anon_sym_DOT,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(14983), 1,
      sym_attribute,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677353] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20201), 1,
      anon_sym_DOT,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(14984), 1,
      sym_attribute,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677376] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(20203), 1,
      anon_sym_COLON_GT,
    ACTIONS(20205), 1,
      anon_sym_RPAREN,
    STATE(14985), 1,
      sym_attribute,
    STATE(17427), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677399] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20207), 1,
      anon_sym_GT_RBRACE,
    STATE(14986), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677422] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20211), 1,
      anon_sym_of,
    STATE(14987), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20209), 3,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_GT,
  [677441] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(20213), 1,
      anon_sym_with,
    STATE(14988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677464] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20215), 1,
      anon_sym_DOT,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(14989), 1,
      sym_attribute,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677487] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(20217), 1,
      anon_sym_with,
    STATE(14990), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677510] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19827), 1,
      sym__lowercase_identifier,
    STATE(9744), 1,
      sym_class_type_path,
    STATE(14991), 1,
      sym_attribute,
    STATE(16550), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677533] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(20219), 1,
      anon_sym_COLON_GT,
    ACTIONS(20221), 1,
      anon_sym_RPAREN,
    STATE(14992), 1,
      sym_attribute,
    STATE(17108), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677556] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20223), 1,
      anon_sym_GT_RBRACE,
    STATE(14993), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677579] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20225), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(14994), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677602] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20227), 1,
      sym__lowercase_identifier,
    ACTIONS(20229), 1,
      anon_sym_LPAREN,
    STATE(5518), 1,
      sym__value_name,
    STATE(5534), 1,
      sym_parenthesized_operator,
    STATE(14995), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677625] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19641), 1,
      anon_sym_LPAREN,
    ACTIONS(20231), 1,
      sym__lowercase_identifier,
    STATE(14996), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13982), 2,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [677646] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10044), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20233), 1,
      anon_sym_GT,
    STATE(14885), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(14997), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677669] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(20235), 1,
      anon_sym_COLON_GT,
    ACTIONS(20237), 1,
      anon_sym_RPAREN,
    STATE(14998), 1,
      sym_attribute,
    STATE(16753), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677692] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20175), 1,
      anon_sym_RBRACK,
    ACTIONS(20239), 1,
      anon_sym_GT,
    STATE(14999), 1,
      sym_attribute,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677715] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10233), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20241), 1,
      anon_sym_GT,
    STATE(15000), 1,
      sym_attribute,
    STATE(15054), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677738] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20243), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20246), 2,
      anon_sym_RBRACK,
      anon_sym_GT,
    STATE(15001), 2,
      sym_attribute,
      aux_sym_polymorphic_variant_type_repeat1,
  [677757] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12345), 1,
      anon_sym_and,
    STATE(15002), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12343), 3,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [677776] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18730), 1,
      sym__lowercase_identifier,
    STATE(5221), 1,
      sym_class_path,
    STATE(15003), 1,
      sym_attribute,
    STATE(18947), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677799] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18572), 1,
      sym__lowercase_identifier,
    STATE(5883), 1,
      sym_class_path,
    STATE(15004), 1,
      sym_attribute,
    STATE(18837), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677822] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19788), 1,
      sym__lowercase_identifier,
    STATE(9469), 1,
      sym_class_type_path,
    STATE(15005), 1,
      sym_attribute,
    STATE(16948), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677845] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(20248), 1,
      anon_sym_with,
    STATE(15006), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677868] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20250), 1,
      anon_sym_GT_RBRACE,
    STATE(15007), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677891] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(20252), 1,
      anon_sym_with,
    STATE(15008), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677914] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18710), 1,
      sym__lowercase_identifier,
    STATE(8417), 1,
      sym_class_path,
    STATE(15009), 1,
      sym_attribute,
    STATE(19003), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677937] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20254), 1,
      anon_sym_GT_RBRACE,
    STATE(15010), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677960] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20256), 1,
      anon_sym_RBRACK,
    ACTIONS(20258), 1,
      anon_sym_GT,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15011), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677983] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20260), 1,
      anon_sym_GT_RBRACE,
    STATE(15012), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678006] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20262), 1,
      anon_sym_GT_RBRACE,
    STATE(15013), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678029] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19974), 1,
      sym__lowercase_identifier,
    ACTIONS(19978), 1,
      anon_sym_mutable,
    ACTIONS(20264), 1,
      anon_sym_RBRACE,
    STATE(15014), 1,
      sym_attribute,
    STATE(16635), 1,
      sym_field_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678052] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18820), 1,
      sym__lowercase_identifier,
    ACTIONS(18822), 1,
      anon_sym_LBRACK,
    ACTIONS(18824), 1,
      anon_sym_virtual,
    STATE(11668), 1,
      sym_class_type_binding,
    STATE(15015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678075] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20256), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15016), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678098] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(20266), 1,
      anon_sym_with,
    STATE(15017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678121] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20268), 1,
      anon_sym_DOT,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15018), 1,
      sym_attribute,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678144] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20270), 1,
      anon_sym_GT_RBRACE,
    STATE(15019), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678167] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20272), 1,
      anon_sym_COMMA,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19075), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
    STATE(15020), 2,
      sym_attribute,
      aux_sym_instantiated_class_type_repeat1,
  [678186] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20275), 1,
      anon_sym_GT_RBRACE,
    STATE(15021), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678209] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19689), 1,
      sym__lowercase_identifier,
    STATE(12477), 1,
      sym_class_type_path,
    STATE(15022), 1,
      sym_attribute,
    STATE(16582), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678232] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    ACTIONS(20277), 1,
      anon_sym_EQ,
    ACTIONS(20279), 1,
      anon_sym_RPAREN,
    STATE(15023), 1,
      sym_attribute,
    STATE(16685), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678255] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(20281), 1,
      anon_sym_COLON_GT,
    ACTIONS(20283), 1,
      anon_sym_RPAREN,
    STATE(15024), 1,
      sym_attribute,
    STATE(16832), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678278] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(20285), 1,
      anon_sym_COLON_GT,
    ACTIONS(20287), 1,
      anon_sym_RPAREN,
    STATE(15025), 1,
      sym_attribute,
    STATE(17149), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678301] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(20289), 1,
      anon_sym_COLON_GT,
    ACTIONS(20291), 1,
      anon_sym_RPAREN,
    STATE(15026), 1,
      sym_attribute,
    STATE(17253), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678324] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    STATE(15027), 1,
      sym_attribute,
    STATE(16597), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20293), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [678345] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11835), 1,
      sym__lowercase_identifier,
    STATE(13096), 1,
      sym_type_constructor_path,
    STATE(15028), 1,
      sym_attribute,
    STATE(16511), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678368] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(20295), 1,
      sym__lowercase_identifier,
    STATE(8702), 1,
      sym_type_constructor_path,
    STATE(15029), 1,
      sym_attribute,
    STATE(17496), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678391] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19827), 1,
      sym__lowercase_identifier,
    STATE(9836), 1,
      sym_class_type_path,
    STATE(15030), 1,
      sym_attribute,
    STATE(16550), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678414] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(20297), 1,
      anon_sym_COLON_GT,
    ACTIONS(20299), 1,
      anon_sym_RPAREN,
    STATE(15031), 1,
      sym_attribute,
    STATE(17477), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678437] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18568), 1,
      sym__lowercase_identifier,
    STATE(7654), 1,
      sym_class_path,
    STATE(15032), 1,
      sym_attribute,
    STATE(20390), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678460] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20301), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15033), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678483] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20303), 1,
      anon_sym_DOT,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15034), 1,
      sym_attribute,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678506] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18826), 1,
      sym__lowercase_identifier,
    STATE(5747), 1,
      sym_class_path,
    STATE(15035), 1,
      sym_attribute,
    STATE(18911), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678529] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    STATE(15036), 1,
      sym_attribute,
    STATE(17198), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20305), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [678550] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(20307), 1,
      anon_sym_with,
    STATE(15037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678573] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20309), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15038), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678596] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18582), 1,
      sym__lowercase_identifier,
    STATE(9680), 1,
      sym_class_path,
    STATE(15039), 1,
      sym_attribute,
    STATE(18410), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678619] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13618), 1,
      anon_sym_PERCENT,
    STATE(15040), 1,
      sym_attribute,
    STATE(17279), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20311), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [678640] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20313), 1,
      anon_sym_DOT,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15041), 1,
      sym_attribute,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678663] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20315), 1,
      anon_sym_RBRACK,
    STATE(14741), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15042), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678686] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20317), 1,
      anon_sym_DOT,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15043), 1,
      sym_attribute,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678709] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18409), 1,
      anon_sym_LPAREN,
    ACTIONS(18456), 1,
      sym__lowercase_identifier,
    STATE(15044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13124), 2,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [678730] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20309), 1,
      anon_sym_RBRACK,
    ACTIONS(20319), 1,
      anon_sym_GT,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15045), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678753] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    STATE(15046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13348), 2,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
  [678774] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(20321), 1,
      anon_sym_with,
    STATE(15047), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678797] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19894), 1,
      sym__lowercase_identifier,
    STATE(9378), 1,
      sym_class_type_path,
    STATE(15048), 1,
      sym_attribute,
    STATE(17266), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678820] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20323), 1,
      anon_sym_GT_RBRACE,
    STATE(15049), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678843] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(20325), 1,
      anon_sym_COLON_GT,
    ACTIONS(20327), 1,
      anon_sym_RPAREN,
    STATE(15050), 1,
      sym_attribute,
    STATE(16864), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678866] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20329), 1,
      anon_sym_GT,
    STATE(14909), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15051), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678889] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20331), 1,
      anon_sym_RBRACK,
    ACTIONS(20333), 1,
      anon_sym_GT,
    STATE(15045), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15052), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678912] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20335), 1,
      anon_sym_DOT,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15053), 1,
      sym_attribute,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678935] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20331), 1,
      anon_sym_RBRACK,
    ACTIONS(20333), 1,
      anon_sym_GT,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15054), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678958] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18724), 1,
      sym__lowercase_identifier,
    STATE(6198), 1,
      sym_class_path,
    STATE(15055), 1,
      sym_attribute,
    STATE(18450), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678981] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20337), 1,
      anon_sym_GT_RBRACE,
    STATE(15056), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679004] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(20339), 1,
      anon_sym_COLON_GT,
    ACTIONS(20341), 1,
      anon_sym_RPAREN,
    STATE(15057), 1,
      sym_attribute,
    STATE(17457), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679027] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(11320), 1,
      sym__lowercase_identifier,
    STATE(13900), 1,
      sym_type_constructor_path,
    STATE(15058), 1,
      sym_attribute,
    STATE(17229), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679050] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20343), 1,
      sym__lowercase_identifier,
    ACTIONS(20345), 1,
      anon_sym_LPAREN,
    STATE(5498), 1,
      sym_parenthesized_operator,
    STATE(5539), 1,
      sym__value_name,
    STATE(15059), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679073] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20347), 1,
      anon_sym_GT_RBRACE,
    STATE(15060), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679096] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(20349), 1,
      anon_sym_with,
    STATE(15061), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679119] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18409), 1,
      anon_sym_LPAREN,
    ACTIONS(20351), 1,
      sym__lowercase_identifier,
    STATE(13279), 1,
      sym__value_name,
    STATE(13809), 1,
      sym_parenthesized_operator,
    STATE(15062), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679142] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20353), 1,
      anon_sym_GT_RBRACE,
    STATE(15063), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679165] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8174), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    STATE(15064), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 2,
      anon_sym_with,
      sym_hash_operator,
  [679186] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(19904), 1,
      sym__lowercase_identifier,
    STATE(9823), 1,
      sym_class_type_path,
    STATE(15065), 1,
      sym_attribute,
    STATE(16788), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679209] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(20355), 1,
      anon_sym_with,
    STATE(15066), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679232] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20357), 1,
      anon_sym_DOT,
    STATE(14723), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15067), 1,
      sym_attribute,
    STATE(16591), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679255] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(20359), 1,
      anon_sym_COLON_GT,
    ACTIONS(20361), 1,
      anon_sym_RPAREN,
    STATE(15068), 1,
      sym_attribute,
    STATE(17206), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679278] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19974), 1,
      sym__lowercase_identifier,
    ACTIONS(19978), 1,
      anon_sym_mutable,
    ACTIONS(20363), 1,
      anon_sym_RBRACE,
    STATE(15069), 1,
      sym_attribute,
    STATE(16635), 1,
      sym_field_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679301] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18526), 1,
      sym__lowercase_identifier,
    STATE(4111), 1,
      sym_class_path,
    STATE(15070), 1,
      sym_attribute,
    STATE(17903), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679324] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(20365), 1,
      anon_sym_with,
    STATE(15071), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679347] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20367), 1,
      anon_sym_GT_RBRACE,
    STATE(15072), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679370] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9746), 1,
      anon_sym_POUND,
    ACTIONS(19291), 1,
      anon_sym_DOT,
    ACTIONS(19295), 1,
      sym_hash_operator,
    ACTIONS(20369), 1,
      anon_sym_with,
    STATE(15073), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679393] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17507), 1,
      anon_sym_COLON2,
    ACTIONS(20371), 1,
      anon_sym_COLON_GT,
    ACTIONS(20373), 1,
      anon_sym_RPAREN,
    STATE(15074), 1,
      sym_attribute,
    STATE(17138), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679416] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(20375), 1,
      sym__lowercase_identifier,
    STATE(10241), 1,
      sym_class_type_path,
    STATE(15075), 1,
      sym_attribute,
    STATE(17531), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679439] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18710), 1,
      sym__lowercase_identifier,
    STATE(8411), 1,
      sym_class_path,
    STATE(15076), 1,
      sym_attribute,
    STATE(19003), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679462] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    ACTIONS(20377), 1,
      anon_sym_GT_RBRACE,
    STATE(15077), 1,
      sym_attribute,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679485] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(18646), 1,
      sym__lowercase_identifier,
    STATE(3035), 1,
      sym_class_path,
    STATE(15078), 1,
      sym_attribute,
    STATE(18874), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679508] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(20375), 1,
      sym__lowercase_identifier,
    STATE(10329), 1,
      sym_class_type_path,
    STATE(15079), 1,
      sym_attribute,
    STATE(17531), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679531] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(20375), 1,
      sym__lowercase_identifier,
    STATE(10321), 1,
      sym_class_type_path,
    STATE(15080), 1,
      sym_attribute,
    STATE(17531), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679554] = 7,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    ACTIONS(20375), 1,
      sym__lowercase_identifier,
    STATE(10125), 1,
      sym_class_type_path,
    STATE(15081), 1,
      sym_attribute,
    STATE(17531), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679577] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20379), 1,
      sym__lowercase_identifier,
    STATE(14707), 1,
      aux_sym_method_specification_repeat1,
    STATE(15082), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18957), 2,
      anon_sym_private,
      anon_sym_virtual,
  [679598] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3311), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(20381), 1,
      anon_sym_SEMI,
    STATE(15083), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679618] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(20383), 1,
      anon_sym_RPAREN,
    STATE(15084), 1,
      sym_attribute,
    STATE(18827), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679638] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(20385), 1,
      anon_sym_RBRACK,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(15085), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679658] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20387), 1,
      sym__lowercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    STATE(15086), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679678] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20391), 1,
      anon_sym_RPAREN,
    STATE(15087), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679698] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20393), 1,
      anon_sym_RPAREN,
    STATE(15088), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679718] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20395), 1,
      anon_sym_SEMI,
    ACTIONS(20397), 1,
      anon_sym_GT_RBRACE,
    STATE(15089), 1,
      sym_attribute,
    STATE(16016), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679738] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18401), 1,
      anon_sym_RBRACE,
    ACTIONS(20399), 1,
      anon_sym_SEMI,
    STATE(15090), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679758] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14609), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15091), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679778] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    ACTIONS(20403), 1,
      anon_sym_RBRACK,
    STATE(15092), 1,
      sym_attribute,
    STATE(15275), 1,
      aux_sym__type_params_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679798] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14611), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15093), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679818] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(74), 1,
      sym_attribute_id,
    STATE(15094), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [679836] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8376), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(20407), 1,
      anon_sym_SEMI,
    STATE(15095), 1,
      sym_attribute,
    STATE(16269), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679856] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18393), 1,
      anon_sym_RBRACE,
    ACTIONS(20409), 1,
      anon_sym_SEMI,
    STATE(15096), 1,
      sym_attribute,
    STATE(15106), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679876] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(20411), 1,
      aux_sym_quoted_extension_token1,
    STATE(15097), 1,
      sym_attribute,
    STATE(19818), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679896] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20413), 1,
      anon_sym_LPAREN,
    ACTIONS(20415), 1,
      anon_sym_LBRACK,
    ACTIONS(20417), 1,
      anon_sym_LBRACE,
    STATE(15098), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679916] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20309), 1,
      anon_sym_RBRACK,
    STATE(15099), 1,
      sym_attribute,
    STATE(15312), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679936] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(20419), 1,
      aux_sym_quoted_extension_token1,
    STATE(15100), 1,
      sym_attribute,
    STATE(19376), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679956] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20421), 1,
      anon_sym_RPAREN,
    STATE(15101), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679976] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(20423), 1,
      anon_sym_RBRACK,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(15102), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679996] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(20425), 1,
      anon_sym_RPAREN,
    STATE(15103), 1,
      sym_attribute,
    STATE(20017), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680016] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    STATE(15104), 1,
      sym_attribute,
    STATE(15499), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680036] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20427), 1,
      anon_sym_LPAREN,
    ACTIONS(20429), 1,
      anon_sym_LBRACK,
    ACTIONS(20431), 1,
      anon_sym_LBRACE,
    STATE(15105), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680056] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18403), 1,
      anon_sym_RBRACE,
    ACTIONS(20433), 1,
      anon_sym_SEMI,
    STATE(15106), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680076] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20435), 1,
      anon_sym_SEMI,
    ACTIONS(20437), 1,
      anon_sym_RBRACE,
    STATE(15107), 1,
      sym_attribute,
    STATE(15228), 1,
      aux_sym_record_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680096] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(82), 1,
      sym_attribute_id,
    STATE(15108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [680114] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15109), 1,
      sym_attribute,
    STATE(15922), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [680132] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(20441), 1,
      aux_sym_quoted_extension_token1,
    STATE(15110), 1,
      sym_attribute,
    STATE(18884), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680152] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20443), 1,
      anon_sym_SEMI,
    ACTIONS(20445), 1,
      anon_sym_RBRACE,
    STATE(15111), 1,
      sym_attribute,
    STATE(16347), 1,
      aux_sym_record_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680172] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13214), 1,
      sym__type_equation,
    STATE(15112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20447), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [680190] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(20449), 1,
      anon_sym_RPAREN,
    STATE(15113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680210] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20451), 1,
      anon_sym_LPAREN,
    ACTIONS(20453), 1,
      anon_sym_LBRACK,
    ACTIONS(20455), 1,
      anon_sym_LBRACE,
    STATE(15114), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680230] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20457), 1,
      anon_sym_SEMI,
    ACTIONS(20459), 1,
      anon_sym_RBRACE,
    STATE(15115), 1,
      sym_attribute,
    STATE(16435), 1,
      aux_sym_record_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680250] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20367), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(20461), 1,
      anon_sym_SEMI,
    STATE(15116), 1,
      sym_attribute,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680270] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20463), 1,
      anon_sym_EQ,
    STATE(15117), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680290] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20363), 1,
      anon_sym_RBRACE,
    ACTIONS(20465), 1,
      anon_sym_SEMI,
    STATE(15118), 1,
      sym_attribute,
    STATE(15590), 1,
      aux_sym_record_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680310] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14602), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15119), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680330] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3465), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(20467), 1,
      anon_sym_SEMI,
    STATE(15120), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680350] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(20469), 1,
      anon_sym_RPAREN,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(15121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680370] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18407), 1,
      anon_sym_RBRACE,
    ACTIONS(20471), 1,
      anon_sym_SEMI,
    STATE(15090), 1,
      aux_sym_record_expression_repeat1,
    STATE(15122), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680390] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20473), 1,
      anon_sym_LPAREN,
    ACTIONS(20475), 1,
      anon_sym_LBRACK,
    ACTIONS(20477), 1,
      anon_sym_LBRACE,
    STATE(15123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680410] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20479), 1,
      anon_sym_SEMI,
    ACTIONS(20482), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(15124), 2,
      sym_attribute,
      aux_sym_record_pattern_repeat1,
  [680428] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20484), 1,
      anon_sym_SEMI,
    ACTIONS(20486), 1,
      anon_sym_RBRACE,
    STATE(15125), 1,
      sym_attribute,
    STATE(15148), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680448] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20488), 1,
      anon_sym_SEMI,
    ACTIONS(20490), 1,
      anon_sym_RBRACE,
    STATE(15126), 1,
      sym_attribute,
    STATE(15347), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680468] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18379), 1,
      anon_sym_RBRACE,
    ACTIONS(20492), 1,
      anon_sym_SEMI,
    STATE(15127), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680488] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20494), 1,
      anon_sym_RPAREN,
    STATE(15128), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680508] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3463), 1,
      anon_sym_RBRACK,
    ACTIONS(20496), 1,
      anon_sym_SEMI,
    STATE(15129), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680528] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(20498), 1,
      aux_sym_quoted_extension_token1,
    STATE(15130), 1,
      sym_attribute,
    STATE(18340), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680548] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20500), 1,
      anon_sym_SEMI,
    ACTIONS(20502), 1,
      anon_sym_RBRACE,
    STATE(15131), 1,
      sym_attribute,
    STATE(15432), 1,
      aux_sym_record_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680568] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(20504), 1,
      sym__lowercase_identifier,
    STATE(15132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680588] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20506), 1,
      anon_sym_SEMI,
    ACTIONS(20508), 1,
      anon_sym_GT_RBRACE,
    STATE(15133), 1,
      sym_attribute,
    STATE(15158), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680608] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20510), 1,
      anon_sym_LPAREN,
    ACTIONS(20512), 1,
      anon_sym_LBRACK,
    ACTIONS(20514), 1,
      anon_sym_LBRACE,
    STATE(15134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680628] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14668), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15135), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680648] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14684), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15136), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680668] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20516), 1,
      anon_sym_LPAREN,
    ACTIONS(20518), 1,
      anon_sym_LBRACK,
    ACTIONS(20520), 1,
      anon_sym_LBRACE,
    STATE(15137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680688] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20522), 1,
      anon_sym_RPAREN,
    STATE(15138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680708] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20524), 1,
      anon_sym_LPAREN,
    ACTIONS(20526), 1,
      anon_sym_LBRACK,
    ACTIONS(20528), 1,
      anon_sym_LBRACE,
    STATE(15139), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680728] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15140), 1,
      sym_attribute,
    STATE(15504), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [680746] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15141), 1,
      sym_attribute,
    STATE(15619), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [680764] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20530), 1,
      anon_sym_SEMI,
    ACTIONS(20532), 1,
      anon_sym_GT_RBRACE,
    STATE(15116), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(15142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680784] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(20534), 1,
      anon_sym_RPAREN,
    STATE(15143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680804] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20347), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(20536), 1,
      anon_sym_SEMI,
    STATE(15144), 1,
      sym_attribute,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680824] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20538), 1,
      anon_sym_SEMI,
    ACTIONS(20540), 1,
      anon_sym_RBRACE,
    STATE(15145), 1,
      sym_attribute,
    STATE(15502), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680844] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3861), 1,
      anon_sym_RBRACK,
    ACTIONS(20542), 1,
      anon_sym_SEMI,
    STATE(15146), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680864] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3691), 1,
      anon_sym_RBRACK,
    ACTIONS(20544), 1,
      anon_sym_SEMI,
    STATE(15147), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680884] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18478), 1,
      anon_sym_RBRACE,
    ACTIONS(20546), 1,
      anon_sym_SEMI,
    STATE(15148), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680904] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20548), 1,
      anon_sym_LPAREN,
    ACTIONS(20550), 1,
      anon_sym_LBRACK,
    ACTIONS(20552), 1,
      anon_sym_LBRACE,
    STATE(15149), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680924] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20554), 1,
      anon_sym_SEMI,
    ACTIONS(20556), 1,
      anon_sym_RBRACE,
    STATE(15127), 1,
      aux_sym_record_expression_repeat1,
    STATE(15150), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680944] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14688), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15151), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680964] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18482), 1,
      anon_sym_RBRACE,
    ACTIONS(20558), 1,
      anon_sym_SEMI,
    STATE(15152), 1,
      sym_attribute,
    STATE(15205), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680984] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3867), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(20560), 1,
      anon_sym_SEMI,
    STATE(15153), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681004] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(84), 1,
      sym_attribute_id,
    STATE(15154), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [681022] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20562), 1,
      anon_sym_LPAREN,
    ACTIONS(20564), 1,
      anon_sym_LBRACK,
    ACTIONS(20566), 1,
      anon_sym_LBRACE,
    STATE(15155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681042] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11785), 1,
      anon_sym_GT,
    ACTIONS(20568), 1,
      anon_sym_SEMI,
    STATE(15156), 1,
      sym_attribute,
    STATE(15334), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681062] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20309), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15157), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681082] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20337), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(20570), 1,
      anon_sym_SEMI,
    STATE(15158), 1,
      sym_attribute,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681102] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(20572), 1,
      anon_sym_RPAREN,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(15159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681122] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20574), 1,
      anon_sym_SEMI,
    ACTIONS(20576), 1,
      anon_sym_RBRACE,
    STATE(15160), 1,
      sym_attribute,
    STATE(16483), 1,
      aux_sym_record_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681142] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(20), 1,
      sym_attribute_id,
    STATE(15161), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [681160] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3831), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(20578), 1,
      anon_sym_SEMI,
    STATE(15162), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681180] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18424), 1,
      anon_sym_RBRACK,
    ACTIONS(20580), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(15163), 2,
      sym_attribute,
      aux_sym_list_pattern_repeat1,
  [681198] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(11141), 1,
      sym_attribute_id,
    STATE(15164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20583), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [681216] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20585), 1,
      anon_sym_RPAREN,
    STATE(15165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681236] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20331), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15166), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681256] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18512), 1,
      anon_sym_RBRACE,
    ACTIONS(20587), 1,
      anon_sym_SEMI,
    STATE(15167), 1,
      sym_attribute,
    STATE(15184), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681276] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18498), 1,
      anon_sym_RBRACK,
    ACTIONS(20589), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(15168), 2,
      sym_attribute,
      aux_sym_list_binding_pattern_repeat1,
  [681294] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18426), 1,
      anon_sym_RBRACE,
    ACTIONS(20592), 1,
      anon_sym_SEMI,
    STATE(15169), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681314] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20331), 1,
      anon_sym_RBRACK,
    STATE(15157), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681334] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15171), 1,
      sym_attribute,
    STATE(15783), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [681352] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(20594), 1,
      anon_sym_RPAREN,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(15172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681372] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(20596), 1,
      anon_sym_RPAREN,
    STATE(15173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681392] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15174), 1,
      sym_attribute,
    STATE(15727), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [681410] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20598), 1,
      anon_sym_SEMI,
    ACTIONS(20601), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(15175), 2,
      sym_attribute,
      aux_sym_record_binding_pattern_repeat1,
  [681428] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20603), 1,
      anon_sym_RPAREN,
    STATE(15176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681448] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3829), 1,
      anon_sym_RBRACK,
    ACTIONS(20605), 1,
      anon_sym_SEMI,
    STATE(15177), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681468] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(20607), 1,
      sym__lowercase_identifier,
    STATE(15178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681488] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17689), 1,
      anon_sym_SEMI,
    ACTIONS(17691), 1,
      anon_sym_GT,
    STATE(15179), 1,
      sym_attribute,
    STATE(15522), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681508] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(20609), 1,
      anon_sym_RPAREN,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(15180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681528] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20611), 1,
      anon_sym_SEMI,
    ACTIONS(20613), 1,
      anon_sym_GT_RBRACE,
    STATE(15181), 1,
      sym_attribute,
    STATE(15424), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681548] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20615), 1,
      anon_sym_RPAREN,
    STATE(15182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681568] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18540), 1,
      anon_sym_RBRACE,
    ACTIONS(20617), 1,
      anon_sym_SEMI,
    STATE(15183), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681588] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18550), 1,
      anon_sym_RBRACE,
    ACTIONS(20619), 1,
      anon_sym_SEMI,
    STATE(15184), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681608] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20621), 1,
      anon_sym_EQ,
    STATE(15185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681628] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20623), 1,
      anon_sym_LPAREN,
    ACTIONS(20625), 1,
      anon_sym_LBRACK,
    ACTIONS(20627), 1,
      anon_sym_LBRACE,
    STATE(15186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681648] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15187), 1,
      sym_attribute,
    STATE(15575), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [681666] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(20629), 1,
      aux_sym_quoted_extension_token1,
    STATE(15188), 1,
      sym_attribute,
    STATE(19697), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681686] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(20631), 1,
      anon_sym_RPAREN,
    STATE(15189), 1,
      sym_attribute,
    STATE(20219), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681706] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20633), 1,
      anon_sym_EQ,
    STATE(15190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681726] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20635), 1,
      anon_sym_SEMI,
    ACTIONS(20637), 1,
      anon_sym_RBRACE,
    STATE(15191), 1,
      sym_attribute,
    STATE(16470), 1,
      aux_sym_record_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681746] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3681), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(20639), 1,
      anon_sym_SEMI,
    STATE(15192), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681766] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(25), 1,
      sym_attribute_id,
    STATE(15193), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [681784] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20641), 1,
      anon_sym_EQ,
    STATE(15194), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681804] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20643), 1,
      anon_sym_SEMI,
    ACTIONS(20645), 1,
      anon_sym_GT_RBRACE,
    STATE(15195), 1,
      sym_attribute,
    STATE(15281), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681824] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14694), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15196), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681844] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20647), 1,
      anon_sym_EQ,
    STATE(15197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681864] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20649), 1,
      anon_sym_SEMI,
    ACTIONS(20651), 1,
      anon_sym_GT_RBRACE,
    STATE(15144), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(15198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681884] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20653), 1,
      anon_sym_RPAREN,
    STATE(15199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681904] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20301), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681924] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8688), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(20655), 1,
      anon_sym_SEMI,
    STATE(15201), 1,
      sym_attribute,
    STATE(16271), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681944] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18217), 1,
      anon_sym_RBRACE,
    ACTIONS(20657), 1,
      anon_sym_SEMI,
    STATE(15175), 1,
      aux_sym_record_binding_pattern_repeat1,
    STATE(15202), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681964] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20659), 1,
      anon_sym_LPAREN,
    ACTIONS(20661), 1,
      anon_sym_LBRACK,
    ACTIONS(20663), 1,
      anon_sym_LBRACE,
    STATE(15203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681984] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(20665), 1,
      anon_sym_RBRACK,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(15204), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682004] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18440), 1,
      anon_sym_RBRACE,
    ACTIONS(20667), 1,
      anon_sym_SEMI,
    STATE(15205), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682024] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(20669), 1,
      aux_sym_quoted_extension_token1,
    STATE(15206), 1,
      sym_attribute,
    STATE(19751), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682044] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15207), 1,
      sym_attribute,
    STATE(15780), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [682062] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8762), 1,
      anon_sym_RBRACK,
    ACTIONS(20671), 1,
      anon_sym_SEMI,
    STATE(15168), 1,
      aux_sym_list_binding_pattern_repeat1,
    STATE(15208), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682082] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20673), 1,
      anon_sym_RPAREN,
    STATE(15209), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682102] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(26), 1,
      sym_attribute_id,
    STATE(15210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [682120] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15211), 1,
      sym_attribute,
    STATE(15777), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [682138] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20675), 1,
      anon_sym_SEMI,
    ACTIONS(20677), 1,
      anon_sym_RBRACE,
    STATE(15169), 1,
      aux_sym_record_expression_repeat1,
    STATE(15212), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682158] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14701), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15213), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682178] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8374), 1,
      anon_sym_RBRACK,
    ACTIONS(20679), 1,
      anon_sym_SEMI,
    STATE(15163), 1,
      aux_sym_list_pattern_repeat1,
    STATE(15214), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682198] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18205), 1,
      anon_sym_RBRACE,
    ACTIONS(20681), 1,
      anon_sym_SEMI,
    STATE(15124), 1,
      aux_sym_record_pattern_repeat1,
    STATE(15215), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682218] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14708), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15216), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682238] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18588), 1,
      anon_sym_RBRACE,
    ACTIONS(20683), 1,
      anon_sym_SEMI,
    STATE(15217), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682258] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20685), 1,
      anon_sym_RPAREN,
    STATE(15218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682278] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20687), 1,
      anon_sym_SEMI,
    ACTIONS(20689), 1,
      anon_sym_RBRACE,
    STATE(15219), 1,
      sym_attribute,
    STATE(15294), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682298] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20691), 1,
      anon_sym_LPAREN,
    ACTIONS(20693), 1,
      anon_sym_LBRACK,
    ACTIONS(20695), 1,
      anon_sym_LBRACE,
    STATE(15220), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682318] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20697), 1,
      anon_sym_SEMI,
    ACTIONS(20699), 1,
      anon_sym_RBRACE,
    STATE(15221), 1,
      sym_attribute,
    STATE(15244), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682338] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20701), 1,
      anon_sym_LPAREN,
    ACTIONS(20703), 1,
      anon_sym_LBRACK,
    ACTIONS(20705), 1,
      anon_sym_LBRACE,
    STATE(15222), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682358] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(20707), 1,
      anon_sym_RPAREN,
    STATE(15223), 1,
      sym_attribute,
    STATE(20035), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682378] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(32), 1,
      sym_attribute_id,
    STATE(15224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [682396] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20709), 1,
      anon_sym_SEMI,
    ACTIONS(20711), 1,
      anon_sym_GT_RBRACE,
    STATE(15225), 1,
      sym_attribute,
    STATE(15316), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682416] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(30), 1,
      sym_attribute_id,
    STATE(15226), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [682434] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20713), 1,
      anon_sym_RPAREN,
    ACTIONS(20715), 1,
      anon_sym_COLON2,
    STATE(15227), 1,
      sym_attribute,
    STATE(20040), 1,
      sym__class_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682454] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18117), 1,
      anon_sym_RBRACE,
    ACTIONS(20717), 1,
      anon_sym_SEMI,
    STATE(15124), 1,
      aux_sym_record_pattern_repeat1,
    STATE(15228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682474] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20719), 1,
      anon_sym_SEMI,
    ACTIONS(20721), 1,
      anon_sym_GT_RBRACE,
    STATE(15229), 1,
      sym_attribute,
    STATE(15254), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682494] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(20723), 1,
      anon_sym_RPAREN,
    STATE(15230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682514] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(20725), 1,
      sym__lowercase_identifier,
    STATE(15231), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682534] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(20727), 1,
      aux_sym_quoted_extension_token1,
    STATE(15232), 1,
      sym_attribute,
    STATE(19463), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682554] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(20729), 1,
      aux_sym_quoted_extension_token1,
    STATE(15233), 1,
      sym_attribute,
    STATE(19773), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682574] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10336), 1,
      sym__type_equation,
    STATE(15234), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20731), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [682592] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(20733), 1,
      aux_sym_quoted_extension_token1,
    STATE(15235), 1,
      sym_attribute,
    STATE(18430), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682612] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20735), 1,
      anon_sym_LPAREN,
    ACTIONS(20737), 1,
      anon_sym_LBRACK,
    ACTIONS(20739), 1,
      anon_sym_LBRACE,
    STATE(15236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682632] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20741), 1,
      anon_sym_LPAREN,
    ACTIONS(20743), 1,
      anon_sym_LBRACK,
    ACTIONS(20745), 1,
      anon_sym_LBRACE,
    STATE(15237), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682652] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(20747), 1,
      aux_sym_quoted_extension_token1,
    STATE(15238), 1,
      sym_attribute,
    STATE(18254), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682672] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3787), 1,
      anon_sym_RBRACK,
    ACTIONS(20749), 1,
      anon_sym_SEMI,
    STATE(15239), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682692] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10987), 1,
      anon_sym_DOT,
    STATE(15240), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20751), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [682710] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13222), 1,
      sym__type_equation,
    STATE(15241), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20447), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [682728] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3869), 1,
      anon_sym_RBRACK,
    ACTIONS(20753), 1,
      anon_sym_SEMI,
    STATE(15242), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682748] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18373), 1,
      anon_sym_RBRACE,
    ACTIONS(20755), 1,
      anon_sym_SEMI,
    STATE(15217), 1,
      aux_sym_record_expression_repeat1,
    STATE(15243), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682768] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18610), 1,
      anon_sym_RBRACE,
    ACTIONS(20757), 1,
      anon_sym_SEMI,
    STATE(15244), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682788] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18616), 1,
      anon_sym_RBRACE,
    ACTIONS(20759), 1,
      anon_sym_SEMI,
    STATE(15245), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682808] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20761), 1,
      anon_sym_LPAREN,
    ACTIONS(20763), 1,
      anon_sym_LBRACK,
    ACTIONS(20765), 1,
      anon_sym_LBRACE,
    STATE(15246), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682828] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15247), 1,
      sym_attribute,
    STATE(15472), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [682846] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16340), 1,
      sym__uppercase_identifier,
    ACTIONS(18879), 1,
      anon_sym_LPAREN,
    STATE(7238), 1,
      sym__constructor_name,
    STATE(15248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682866] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3939), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(20767), 1,
      anon_sym_SEMI,
    STATE(15249), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682886] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    ACTIONS(20769), 1,
      anon_sym_RBRACK,
    STATE(15250), 1,
      sym_attribute,
    STATE(16328), 1,
      aux_sym__type_params_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682906] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    ACTIONS(20769), 1,
      anon_sym_RBRACK,
    STATE(14713), 1,
      aux_sym__type_params_repeat1,
    STATE(15251), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682926] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(38), 1,
      sym_attribute_id,
    STATE(15252), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [682944] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20771), 1,
      anon_sym_LPAREN,
    ACTIONS(20773), 1,
      anon_sym_LBRACK,
    ACTIONS(20775), 1,
      anon_sym_LBRACE,
    STATE(15253), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682964] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20270), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(20777), 1,
      anon_sym_SEMI,
    STATE(15254), 1,
      sym_attribute,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682984] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20779), 1,
      anon_sym_RPAREN,
    STATE(15255), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683004] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20781), 1,
      anon_sym_SEMI,
    ACTIONS(20783), 1,
      anon_sym_RBRACE,
    STATE(15183), 1,
      aux_sym_record_expression_repeat1,
    STATE(15256), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683024] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15110), 1,
      sym_attribute_id,
    STATE(15257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [683042] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20785), 1,
      anon_sym_RPAREN,
    STATE(15258), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683062] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(20787), 1,
      aux_sym_quoted_extension_token1,
    STATE(15259), 1,
      sym_attribute,
    STATE(20042), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683082] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20789), 1,
      anon_sym_RPAREN,
    STATE(15260), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683102] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20791), 1,
      anon_sym_RPAREN,
    STATE(15261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683122] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20793), 1,
      anon_sym_SEMI,
    ACTIONS(20795), 1,
      anon_sym_RBRACE,
    STATE(15118), 1,
      aux_sym_record_declaration_repeat1,
    STATE(15262), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683142] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18620), 1,
      anon_sym_RBRACE,
    ACTIONS(20797), 1,
      anon_sym_SEMI,
    STATE(15263), 1,
      sym_attribute,
    STATE(15280), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683162] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20799), 1,
      anon_sym_LPAREN,
    ACTIONS(20801), 1,
      anon_sym_LBRACK,
    ACTIONS(20803), 1,
      anon_sym_LBRACE,
    STATE(15264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683182] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15265), 1,
      sym_attribute,
    STATE(16127), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [683200] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3821), 1,
      anon_sym_RBRACK,
    ACTIONS(20805), 1,
      anon_sym_SEMI,
    STATE(15266), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683220] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20807), 1,
      anon_sym_LPAREN,
    ACTIONS(20809), 1,
      anon_sym_LBRACK,
    ACTIONS(20811), 1,
      anon_sym_LBRACE,
    STATE(15267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683240] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20254), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(20813), 1,
      anon_sym_SEMI,
    STATE(15268), 1,
      sym_attribute,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683260] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20175), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15269), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683280] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(69), 1,
      sym_attribute_id,
    STATE(15270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [683298] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(20815), 1,
      anon_sym_RPAREN,
    STATE(15271), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683318] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20256), 1,
      anon_sym_RBRACK,
    STATE(15200), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15272), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683338] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    ACTIONS(20817), 1,
      anon_sym_RBRACK,
    STATE(15273), 1,
      sym_attribute,
    STATE(16294), 1,
      aux_sym__type_params_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683358] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(20819), 1,
      sym__lowercase_identifier,
    STATE(15274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683378] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    ACTIONS(20821), 1,
      anon_sym_RBRACK,
    STATE(14713), 1,
      aux_sym__type_params_repeat1,
    STATE(15275), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683398] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20256), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683418] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3479), 1,
      anon_sym_RBRACK,
    ACTIONS(20823), 1,
      anon_sym_SEMI,
    STATE(15277), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683438] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20825), 1,
      anon_sym_RPAREN,
    STATE(15278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683458] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20175), 1,
      anon_sym_RBRACK,
    STATE(15279), 1,
      sym_attribute,
    STATE(15882), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683478] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18628), 1,
      anon_sym_RBRACE,
    ACTIONS(20827), 1,
      anon_sym_SEMI,
    STATE(15280), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683498] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20262), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(20829), 1,
      anon_sym_SEMI,
    STATE(15281), 1,
      sym_attribute,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683518] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(20831), 1,
      anon_sym_RPAREN,
    STATE(15282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683538] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3501), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(20833), 1,
      anon_sym_SEMI,
    STATE(15283), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683558] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20835), 1,
      anon_sym_RPAREN,
    STATE(15284), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683578] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20250), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(20837), 1,
      anon_sym_SEMI,
    STATE(15285), 1,
      sym_attribute,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683598] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18634), 1,
      anon_sym_RBRACE,
    ACTIONS(20839), 1,
      anon_sym_SEMI,
    STATE(15286), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683618] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20841), 1,
      anon_sym_LPAREN,
    ACTIONS(20843), 1,
      anon_sym_LBRACK,
    ACTIONS(20845), 1,
      anon_sym_LBRACE,
    STATE(15287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683638] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10044), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    STATE(15288), 1,
      sym_attribute,
    STATE(15556), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683658] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(20847), 1,
      anon_sym_RPAREN,
    STATE(15289), 1,
      sym_attribute,
    STATE(19076), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683678] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(20849), 1,
      aux_sym_quoted_extension_token1,
    STATE(15290), 1,
      sym_attribute,
    STATE(19913), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683698] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20851), 1,
      anon_sym_LPAREN,
    ACTIONS(20853), 1,
      anon_sym_LBRACK,
    ACTIONS(20855), 1,
      anon_sym_LBRACE,
    STATE(15291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683718] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(36), 1,
      sym_attribute_id,
    STATE(15292), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [683736] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17655), 1,
      anon_sym_SEMI,
    ACTIONS(17657), 1,
      anon_sym_GT,
    STATE(15156), 1,
      aux_sym_object_type_repeat1,
    STATE(15293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683756] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18492), 1,
      anon_sym_RBRACE,
    ACTIONS(20857), 1,
      anon_sym_SEMI,
    STATE(15294), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683776] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(20859), 1,
      anon_sym_type,
    STATE(15295), 1,
      sym_attribute,
    STATE(16245), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683796] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15296), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20246), 3,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_GT,
  [683812] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(20861), 1,
      anon_sym_RPAREN,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(15297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683832] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14551), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15298), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683852] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14732), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15299), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683872] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3427), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(20863), 1,
      anon_sym_SEMI,
    STATE(15300), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683892] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10233), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    STATE(15166), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683912] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3481), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(20865), 1,
      anon_sym_SEMI,
    STATE(15302), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683932] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20867), 1,
      anon_sym_LPAREN,
    ACTIONS(20869), 1,
      anon_sym_LBRACK,
    ACTIONS(20871), 1,
      anon_sym_LBRACE,
    STATE(15303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683952] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(24), 1,
      sym_attribute_id,
    STATE(15304), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [683970] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3499), 1,
      anon_sym_RBRACK,
    ACTIONS(20873), 1,
      anon_sym_SEMI,
    STATE(15305), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683990] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15306), 1,
      sym_attribute,
    STATE(15678), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [684008] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15307), 1,
      sym_attribute,
    STATE(15771), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [684026] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14415), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15308), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684046] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18656), 1,
      anon_sym_RBRACE,
    ACTIONS(20875), 1,
      anon_sym_SEMI,
    STATE(15309), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684066] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(20877), 1,
      aux_sym_quoted_extension_token1,
    STATE(15310), 1,
      sym_attribute,
    STATE(19964), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684086] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(40), 1,
      sym_attribute_id,
    STATE(15311), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [684104] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20225), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15312), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684124] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(20879), 1,
      sym__lowercase_identifier,
    STATE(15313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684144] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3425), 1,
      anon_sym_RBRACK,
    ACTIONS(20881), 1,
      anon_sym_SEMI,
    STATE(15314), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684164] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14550), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15315), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684184] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20223), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(20883), 1,
      anon_sym_SEMI,
    STATE(15316), 1,
      sym_attribute,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684204] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20885), 1,
      anon_sym_SEMI,
    ACTIONS(20887), 1,
      anon_sym_RBRACE,
    STATE(15317), 1,
      sym_attribute,
    STATE(15339), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684224] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20889), 1,
      anon_sym_SEMI,
    ACTIONS(20891), 1,
      anon_sym_RBRACE,
    STATE(15202), 1,
      aux_sym_record_binding_pattern_repeat1,
    STATE(15318), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684244] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18510), 1,
      anon_sym_RBRACE,
    ACTIONS(20893), 1,
      anon_sym_SEMI,
    STATE(15319), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684264] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(20895), 1,
      aux_sym_quoted_extension_token1,
    STATE(15320), 1,
      sym_attribute,
    STATE(19997), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684284] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20715), 1,
      anon_sym_COLON2,
    ACTIONS(20897), 1,
      anon_sym_RPAREN,
    STATE(15321), 1,
      sym_attribute,
    STATE(19775), 1,
      sym__class_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684304] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(45), 1,
      sym_attribute_id,
    STATE(15322), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [684322] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15323), 1,
      sym_attribute,
    STATE(15765), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [684340] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20899), 1,
      anon_sym_SEMI,
    ACTIONS(20901), 1,
      anon_sym_GT_RBRACE,
    STATE(15285), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(15324), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684360] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20903), 1,
      anon_sym_SEMI,
    ACTIONS(20905), 1,
      anon_sym_GT_RBRACE,
    STATE(15325), 1,
      sym_attribute,
    STATE(15349), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684380] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20907), 1,
      anon_sym_SEMI,
    ACTIONS(20909), 1,
      anon_sym_RBRACE,
    STATE(15215), 1,
      aux_sym_record_pattern_repeat1,
    STATE(15326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684400] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14794), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15327), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684420] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15328), 1,
      sym_attribute,
    STATE(15657), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [684438] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(20911), 1,
      anon_sym_RPAREN,
    STATE(15329), 1,
      sym_attribute,
    STATE(19772), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684458] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14769), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15330), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684478] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8344), 1,
      anon_sym_RBRACK,
    ACTIONS(20913), 1,
      anon_sym_SEMI,
    STATE(15163), 1,
      aux_sym_list_pattern_repeat1,
    STATE(15331), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684498] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17627), 1,
      anon_sym_SEMI,
    ACTIONS(17629), 1,
      anon_sym_GT,
    STATE(15332), 1,
      sym_attribute,
    STATE(15614), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684518] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(20915), 1,
      anon_sym_RBRACK,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(15333), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684538] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18131), 1,
      anon_sym_GT,
    ACTIONS(20917), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(15334), 2,
      sym_attribute,
      aux_sym_object_type_repeat1,
  [684556] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    ACTIONS(20920), 1,
      anon_sym_RBRACK,
    STATE(14713), 1,
      aux_sym__type_params_repeat1,
    STATE(15335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684576] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20922), 1,
      anon_sym_RPAREN,
    STATE(15336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684596] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3839), 1,
      anon_sym_RBRACK,
    ACTIONS(20924), 1,
      anon_sym_SEMI,
    STATE(15337), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684616] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20926), 1,
      anon_sym_SEMI,
    ACTIONS(20928), 1,
      anon_sym_RBRACE,
    STATE(15309), 1,
      aux_sym_record_expression_repeat1,
    STATE(15338), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684636] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18698), 1,
      anon_sym_RBRACE,
    ACTIONS(20930), 1,
      anon_sym_SEMI,
    STATE(15339), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684656] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20932), 1,
      anon_sym_SEMI,
    ACTIONS(20934), 1,
      anon_sym_RBRACE,
    STATE(15340), 1,
      sym_attribute,
    STATE(15683), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684676] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20936), 1,
      anon_sym_LPAREN,
    ACTIONS(20938), 1,
      anon_sym_LBRACK,
    ACTIONS(20940), 1,
      anon_sym_LBRACE,
    STATE(15341), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684696] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14476), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15342), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684716] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14414), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15343), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684736] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3827), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(20942), 1,
      anon_sym_SEMI,
    STATE(15344), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684756] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(20944), 1,
      sym__lowercase_identifier,
    STATE(15345), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684776] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(20946), 1,
      anon_sym_RPAREN,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(15346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684796] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18696), 1,
      anon_sym_RBRACE,
    ACTIONS(20948), 1,
      anon_sym_SEMI,
    STATE(15347), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684816] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    ACTIONS(20821), 1,
      anon_sym_RBRACK,
    STATE(15348), 1,
      sym_attribute,
    STATE(15457), 1,
      aux_sym__type_params_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684836] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20197), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(20950), 1,
      anon_sym_SEMI,
    STATE(15349), 1,
      sym_attribute,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684856] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20952), 1,
      anon_sym_RPAREN,
    STATE(15350), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684876] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18702), 1,
      anon_sym_RBRACE,
    ACTIONS(20954), 1,
      anon_sym_SEMI,
    STATE(15245), 1,
      aux_sym_record_expression_repeat1,
    STATE(15351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684896] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20956), 1,
      anon_sym_RPAREN,
    STATE(15352), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684916] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18524), 1,
      anon_sym_RBRACE,
    ACTIONS(20958), 1,
      anon_sym_SEMI,
    STATE(15353), 1,
      sym_attribute,
    STATE(15410), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684936] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14680), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15354), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684956] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15355), 1,
      sym_attribute,
    STATE(15413), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [684974] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20960), 1,
      anon_sym_RPAREN,
    STATE(15356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684994] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11606), 1,
      anon_sym_GT,
    ACTIONS(20962), 1,
      anon_sym_SEMI,
    STATE(15334), 1,
      aux_sym_object_type_repeat1,
    STATE(15357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685014] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18720), 1,
      anon_sym_RBRACE,
    ACTIONS(20964), 1,
      anon_sym_SEMI,
    STATE(15358), 1,
      sym_attribute,
    STATE(15375), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685034] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14766), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15359), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685054] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(8), 1,
      sym_attribute_id,
    STATE(15360), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [685072] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15361), 1,
      sym_attribute,
    STATE(16473), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [685090] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8342), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(20966), 1,
      anon_sym_SEMI,
    STATE(15362), 1,
      sym_attribute,
    STATE(16269), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685110] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10206), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    STATE(15363), 1,
      sym_attribute,
    STATE(16133), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685130] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(11276), 1,
      anon_sym_DOT,
    ACTIONS(20968), 1,
      anon_sym_RPAREN,
    STATE(15364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685150] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(20970), 1,
      aux_sym_quoted_extension_token1,
    STATE(15365), 1,
      sym_attribute,
    STATE(19686), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685170] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(20972), 1,
      anon_sym_RPAREN,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(15366), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685190] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20185), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15367), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685210] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20185), 1,
      anon_sym_RBRACK,
    STATE(15276), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685230] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(20974), 1,
      sym__lowercase_identifier,
    STATE(15369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685250] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18712), 1,
      anon_sym_RBRACE,
    ACTIONS(20976), 1,
      anon_sym_SEMI,
    STATE(15370), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685270] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14775), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15371), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685290] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(20978), 1,
      anon_sym_RPAREN,
    STATE(15372), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685310] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20980), 1,
      anon_sym_RPAREN,
    STATE(15373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685330] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15374), 1,
      sym_attribute,
    STATE(15609), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [685348] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18772), 1,
      anon_sym_RBRACE,
    ACTIONS(20982), 1,
      anon_sym_SEMI,
    STATE(15375), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685368] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14542), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15376), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685388] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20984), 1,
      anon_sym_RPAREN,
    STATE(15377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685408] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14778), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15378), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685428] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18530), 1,
      anon_sym_RBRACE,
    ACTIONS(20986), 1,
      anon_sym_SEMI,
    STATE(15319), 1,
      aux_sym_record_expression_repeat1,
    STATE(15379), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685448] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20988), 1,
      anon_sym_SEMI,
    ACTIONS(20990), 1,
      anon_sym_GT_RBRACE,
    STATE(15268), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(15380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685468] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3791), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(20992), 1,
      anon_sym_SEMI,
    STATE(15381), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685488] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(20994), 1,
      anon_sym_RPAREN,
    STATE(15382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685508] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15383), 1,
      sym_attribute,
    STATE(15804), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [685526] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(46), 1,
      sym_attribute_id,
    STATE(15384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [685544] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8702), 1,
      anon_sym_RBRACK,
    ACTIONS(20996), 1,
      anon_sym_SEMI,
    STATE(15168), 1,
      aux_sym_list_binding_pattern_repeat1,
    STATE(15385), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685564] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(20998), 1,
      anon_sym_RPAREN,
    STATE(15386), 1,
      sym_attribute,
    STATE(19106), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685584] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12), 1,
      sym_attribute_id,
    STATE(15387), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [685602] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(21000), 1,
      sym__lowercase_identifier,
    STATE(15388), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685622] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21002), 1,
      aux_sym_quoted_extension_token1,
    STATE(15389), 1,
      sym_attribute,
    STATE(20076), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685642] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21004), 1,
      anon_sym_EQ,
    STATE(15390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685662] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21006), 1,
      anon_sym_LPAREN,
    ACTIONS(21008), 1,
      anon_sym_LBRACK,
    ACTIONS(21010), 1,
      anon_sym_LBRACE,
    STATE(15391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685682] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21012), 1,
      sym__lowercase_identifier,
    ACTIONS(21014), 1,
      anon_sym_LPAREN,
    STATE(7565), 1,
      sym__simple_value_pattern,
    STATE(15392), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685702] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(3), 1,
      sym_attribute_id,
    STATE(15393), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [685720] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20165), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21016), 1,
      anon_sym_SEMI,
    STATE(15394), 1,
      sym_attribute,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685740] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21018), 1,
      anon_sym_LPAREN,
    ACTIONS(21020), 1,
      anon_sym_LBRACK,
    ACTIONS(21022), 1,
      anon_sym_LBRACE,
    STATE(15395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685760] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(47), 1,
      sym_attribute_id,
    STATE(15396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [685778] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17697), 1,
      anon_sym_SEMI,
    ACTIONS(17699), 1,
      anon_sym_GT,
    STATE(15397), 1,
      sym_attribute,
    STATE(16089), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685798] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21024), 1,
      anon_sym_LPAREN,
    ACTIONS(21026), 1,
      anon_sym_LBRACK,
    ACTIONS(21028), 1,
      anon_sym_LBRACE,
    STATE(15398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685818] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21030), 1,
      anon_sym_SEMI,
    ACTIONS(21032), 1,
      anon_sym_RBRACE,
    STATE(15286), 1,
      aux_sym_record_expression_repeat1,
    STATE(15399), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685838] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3805), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21034), 1,
      anon_sym_SEMI,
    STATE(15400), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685858] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15401), 1,
      sym_attribute,
    STATE(16260), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [685876] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21036), 1,
      aux_sym_quoted_extension_token1,
    STATE(15402), 1,
      sym_attribute,
    STATE(19595), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685896] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21038), 1,
      aux_sym_quoted_extension_token1,
    STATE(15403), 1,
      sym_attribute,
    STATE(20085), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685916] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21040), 1,
      anon_sym_EQ,
    STATE(15404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685936] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15405), 1,
      sym_attribute,
    STATE(16487), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [685954] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21042), 1,
      anon_sym_LPAREN,
    ACTIONS(21044), 1,
      anon_sym_LBRACK,
    ACTIONS(21046), 1,
      anon_sym_LBRACE,
    STATE(15406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685974] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20142), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21048), 1,
      anon_sym_SEMI,
    STATE(15407), 1,
      sym_attribute,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685994] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21050), 1,
      anon_sym_RPAREN,
    STATE(15408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686014] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18546), 1,
      anon_sym_RBRACE,
    ACTIONS(21052), 1,
      anon_sym_SEMI,
    STATE(15409), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686034] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18548), 1,
      anon_sym_RBRACE,
    ACTIONS(21054), 1,
      anon_sym_SEMI,
    STATE(15410), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686054] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21056), 1,
      anon_sym_SEMI,
    ACTIONS(21058), 1,
      anon_sym_RBRACE,
    STATE(15411), 1,
      sym_attribute,
    STATE(15433), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686074] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20156), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686094] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21060), 1,
      aux_sym_quoted_extension_token1,
    STATE(15413), 1,
      sym_attribute,
    STATE(18165), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686114] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(48), 1,
      sym_attribute_id,
    STATE(15414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [686132] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3803), 1,
      anon_sym_RBRACK,
    ACTIONS(21062), 1,
      anon_sym_SEMI,
    STATE(15415), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686152] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21064), 1,
      anon_sym_SEMI,
    ACTIONS(21066), 1,
      anon_sym_GT_RBRACE,
    STATE(15416), 1,
      sym_attribute,
    STATE(15713), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686172] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21068), 1,
      anon_sym_LPAREN,
    ACTIONS(21070), 1,
      anon_sym_LBRACK,
    ACTIONS(21072), 1,
      anon_sym_LBRACE,
    STATE(15417), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686192] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21074), 1,
      sym__lowercase_identifier,
    ACTIONS(21076), 1,
      anon_sym_LPAREN,
    STATE(10155), 1,
      sym__simple_value_pattern,
    STATE(15418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686212] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21078), 1,
      anon_sym_SEMI,
    ACTIONS(21080), 1,
      anon_sym_GT_RBRACE,
    STATE(15419), 1,
      sym_attribute,
    STATE(15443), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686232] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21082), 1,
      anon_sym_LPAREN,
    ACTIONS(21084), 1,
      anon_sym_LBRACK,
    ACTIONS(21086), 1,
      anon_sym_LBRACE,
    STATE(15420), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686252] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21088), 1,
      anon_sym_LPAREN,
    ACTIONS(21090), 1,
      anon_sym_LBRACK,
    ACTIONS(21092), 1,
      anon_sym_LBRACE,
    STATE(15421), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686272] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21094), 1,
      aux_sym_quoted_extension_token1,
    STATE(15422), 1,
      sym_attribute,
    STATE(20106), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686292] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15423), 1,
      sym_attribute,
    STATE(15887), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [686310] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20126), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21096), 1,
      anon_sym_SEMI,
    STATE(15424), 1,
      sym_attribute,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686330] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18847), 1,
      anon_sym_RBRACE,
    ACTIONS(21098), 1,
      anon_sym_SEMI,
    STATE(15425), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686350] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15100), 1,
      sym_attribute_id,
    STATE(15426), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [686368] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21100), 1,
      anon_sym_LPAREN,
    ACTIONS(21102), 1,
      anon_sym_LBRACK,
    ACTIONS(21104), 1,
      anon_sym_LBRACE,
    STATE(15427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686388] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21106), 1,
      anon_sym_RPAREN,
    STATE(15428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686408] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15429), 1,
      sym_attribute,
    STATE(15733), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [686426] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(42), 1,
      sym_attribute_id,
    STATE(15430), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [686444] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3789), 1,
      anon_sym_RBRACK,
    ACTIONS(21108), 1,
      anon_sym_SEMI,
    STATE(15431), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686464] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18035), 1,
      anon_sym_RBRACE,
    ACTIONS(21110), 1,
      anon_sym_SEMI,
    STATE(15175), 1,
      aux_sym_record_binding_pattern_repeat1,
    STATE(15432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686484] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18853), 1,
      anon_sym_RBRACE,
    ACTIONS(21112), 1,
      anon_sym_SEMI,
    STATE(15433), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686504] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(21114), 1,
      anon_sym_RPAREN,
    STATE(15434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686524] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(21116), 1,
      anon_sym_RPAREN,
    STATE(15435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686544] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21118), 1,
      anon_sym_SEMI,
    ACTIONS(21120), 1,
      anon_sym_GT_RBRACE,
    STATE(15394), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(15436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686564] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15437), 1,
      sym_attribute,
    STATE(15880), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [686582] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3783), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21122), 1,
      anon_sym_SEMI,
    STATE(15438), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686602] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(49), 1,
      sym_attribute_id,
    STATE(15439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [686620] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20118), 1,
      anon_sym_RBRACK,
    STATE(15412), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15440), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686640] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20118), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15441), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686660] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3527), 1,
      anon_sym_RBRACK,
    ACTIONS(21124), 1,
      anon_sym_SEMI,
    STATE(15442), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686680] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20116), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21126), 1,
      anon_sym_SEMI,
    STATE(15443), 1,
      sym_attribute,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686700] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21128), 1,
      aux_sym_quoted_extension_token1,
    STATE(15444), 1,
      sym_attribute,
    STATE(19567), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686720] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13236), 1,
      sym_attribute_id,
    STATE(15445), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21130), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [686738] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(21132), 1,
      anon_sym_RPAREN,
    STATE(15446), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686758] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21134), 1,
      anon_sym_RPAREN,
    STATE(15447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686778] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8696), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21136), 1,
      anon_sym_SEMI,
    STATE(15448), 1,
      sym_attribute,
    STATE(16271), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686798] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(21138), 1,
      sym__lowercase_identifier,
    STATE(15449), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686818] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21140), 1,
      anon_sym_RPAREN,
    STATE(15450), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686838] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21142), 1,
      anon_sym_LPAREN,
    ACTIONS(21144), 1,
      anon_sym_LBRACK,
    ACTIONS(21146), 1,
      anon_sym_LBRACE,
    STATE(15451), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686858] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18776), 1,
      anon_sym_RBRACE,
    ACTIONS(21148), 1,
      anon_sym_SEMI,
    STATE(15452), 1,
      sym_attribute,
    STATE(15469), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686878] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21150), 1,
      anon_sym_LPAREN,
    ACTIONS(21152), 1,
      anon_sym_LBRACK,
    ACTIONS(21154), 1,
      anon_sym_LBRACE,
    STATE(15453), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686898] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10064), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    STATE(15454), 1,
      sym_attribute,
    STATE(16212), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686918] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21156), 1,
      anon_sym_RPAREN,
    STATE(15455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21158), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [686936] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(11276), 1,
      anon_sym_DOT,
    ACTIONS(21160), 1,
      anon_sym_RPAREN,
    STATE(15456), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686956] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    ACTIONS(21162), 1,
      anon_sym_RBRACK,
    STATE(14713), 1,
      aux_sym__type_params_repeat1,
    STATE(15457), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686976] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21164), 1,
      anon_sym_SEMI,
    ACTIONS(21166), 1,
      anon_sym_RBRACE,
    STATE(15409), 1,
      aux_sym_record_expression_repeat1,
    STATE(15458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686996] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(5), 1,
      sym_attribute_id,
    STATE(15459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [687014] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18758), 1,
      anon_sym_RBRACE,
    ACTIONS(21168), 1,
      anon_sym_SEMI,
    STATE(15425), 1,
      aux_sym_record_expression_repeat1,
    STATE(15460), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687034] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11757), 1,
      anon_sym_GT,
    ACTIONS(21170), 1,
      anon_sym_SEMI,
    STATE(15334), 1,
      aux_sym_object_type_repeat1,
    STATE(15461), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687054] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21172), 1,
      aux_sym_quoted_extension_token1,
    STATE(15462), 1,
      sym_attribute,
    STATE(19532), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687074] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(21174), 1,
      sym__lowercase_identifier,
    STATE(15463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687094] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17), 1,
      sym_attribute_id,
    STATE(15464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [687112] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21176), 1,
      aux_sym_quoted_extension_token1,
    STATE(15465), 1,
      sym_attribute,
    STATE(20120), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687132] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11460), 1,
      anon_sym_STAR,
    ACTIONS(13443), 1,
      anon_sym_DASH_GT,
    STATE(15466), 1,
      sym_attribute,
    STATE(16080), 1,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687152] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21178), 1,
      anon_sym_RPAREN,
    STATE(15467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687172] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21180), 1,
      aux_sym_quoted_extension_token1,
    STATE(15468), 1,
      sym_attribute,
    STATE(18519), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687192] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18750), 1,
      anon_sym_RBRACE,
    ACTIONS(21182), 1,
      anon_sym_SEMI,
    STATE(15469), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687212] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18746), 1,
      anon_sym_RBRACE,
    ACTIONS(21184), 1,
      anon_sym_SEMI,
    STATE(15470), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687232] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20096), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687252] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21186), 1,
      aux_sym_quoted_extension_token1,
    STATE(15472), 1,
      sym_attribute,
    STATE(19305), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687272] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17567), 1,
      anon_sym_SEMI,
    ACTIONS(17569), 1,
      anon_sym_GT,
    STATE(15357), 1,
      aux_sym_object_type_repeat1,
    STATE(15473), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687292] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20096), 1,
      anon_sym_RBRACK,
    STATE(15441), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687312] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(50), 1,
      sym_attribute_id,
    STATE(15475), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [687330] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(21188), 1,
      anon_sym_RPAREN,
    STATE(15476), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687350] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17599), 1,
      anon_sym_SEMI,
    ACTIONS(17601), 1,
      anon_sym_GT,
    STATE(15477), 1,
      sym_attribute,
    STATE(16174), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687370] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10214), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    STATE(15367), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687390] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21190), 1,
      anon_sym_RPAREN,
    STATE(15479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687410] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21192), 1,
      aux_sym_quoted_extension_token1,
    STATE(15480), 1,
      sym_attribute,
    STATE(20241), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687430] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21194), 1,
      anon_sym_LPAREN,
    ACTIONS(21196), 1,
      anon_sym_LBRACK,
    ACTIONS(21198), 1,
      anon_sym_LBRACE,
    STATE(15481), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687450] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15064), 1,
      anon_sym_in,
    ACTIONS(21200), 1,
      anon_sym_and,
    STATE(15482), 1,
      sym_attribute,
    STATE(15893), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687470] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18598), 1,
      anon_sym_RBRACE,
    ACTIONS(21202), 1,
      anon_sym_SEMI,
    STATE(15483), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687490] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21204), 1,
      aux_sym_quoted_extension_token1,
    STATE(15484), 1,
      sym_attribute,
    STATE(20133), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687510] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15485), 1,
      sym_attribute,
    STATE(15510), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [687528] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21206), 1,
      anon_sym_RPAREN,
    STATE(15486), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687548] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(21208), 1,
      anon_sym_RPAREN,
    STATE(15487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687568] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20084), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21210), 1,
      anon_sym_SEMI,
    STATE(15488), 1,
      sym_attribute,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687588] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21212), 1,
      anon_sym_SEMI,
    ACTIONS(21214), 1,
      anon_sym_RBRACE,
    STATE(15489), 1,
      sym_attribute,
    STATE(15552), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687608] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3317), 1,
      anon_sym_RBRACK,
    ACTIONS(21216), 1,
      anon_sym_SEMI,
    STATE(15490), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687628] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20076), 1,
      anon_sym_RBRACK,
    STATE(15491), 1,
      sym_attribute,
    STATE(15601), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687648] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21218), 1,
      anon_sym_LPAREN,
    ACTIONS(21220), 1,
      anon_sym_LBRACK,
    ACTIONS(21222), 1,
      anon_sym_LBRACE,
    STATE(15492), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687668] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21224), 1,
      anon_sym_RPAREN,
    STATE(15493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687688] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21226), 1,
      anon_sym_EQ,
    STATE(15494), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21228), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [687706] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(52), 1,
      sym_attribute_id,
    STATE(15495), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [687724] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15496), 1,
      sym_attribute,
    STATE(16478), 1,
      sym_module_binding,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18504), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [687742] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15497), 1,
      sym_attribute,
    STATE(15697), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [687760] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13363), 1,
      sym_attribute_id,
    STATE(15498), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21230), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [687778] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20076), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15499), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687798] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21232), 1,
      anon_sym_EQ,
    STATE(15500), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687818] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15501), 1,
      sym_attribute,
    STATE(15644), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [687836] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18606), 1,
      anon_sym_RBRACE,
    ACTIONS(21234), 1,
      anon_sym_SEMI,
    STATE(15502), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687856] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21236), 1,
      anon_sym_SEMI,
    ACTIONS(21238), 1,
      anon_sym_GT_RBRACE,
    STATE(15503), 1,
      sym_attribute,
    STATE(15592), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687876] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21240), 1,
      aux_sym_quoted_extension_token1,
    STATE(15504), 1,
      sym_attribute,
    STATE(19487), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687896] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21242), 1,
      anon_sym_SEMI,
    ACTIONS(21244), 1,
      anon_sym_RBRACE,
    STATE(15505), 1,
      sym_attribute,
    STATE(15527), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687916] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3403), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21246), 1,
      anon_sym_SEMI,
    STATE(15506), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687936] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(51), 1,
      sym_attribute_id,
    STATE(15507), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [687954] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21248), 1,
      anon_sym_LPAREN,
    ACTIONS(21250), 1,
      anon_sym_LBRACK,
    ACTIONS(21252), 1,
      anon_sym_LBRACE,
    STATE(15508), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687974] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18660), 1,
      anon_sym_RBRACE,
    ACTIONS(21254), 1,
      anon_sym_SEMI,
    STATE(15509), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687994] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21256), 1,
      aux_sym_quoted_extension_token1,
    STATE(15510), 1,
      sym_attribute,
    STATE(20139), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688014] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(53), 1,
      sym_attribute_id,
    STATE(15511), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [688032] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17557), 1,
      anon_sym_SEMI,
    ACTIONS(17559), 1,
      anon_sym_GT,
    STATE(15461), 1,
      aux_sym_object_type_repeat1,
    STATE(15512), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688052] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21258), 1,
      anon_sym_SEMI,
    ACTIONS(21260), 1,
      anon_sym_GT_RBRACE,
    STATE(15513), 1,
      sym_attribute,
    STATE(15537), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688072] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18845), 1,
      anon_sym_RBRACE,
    ACTIONS(21262), 1,
      anon_sym_SEMI,
    STATE(15514), 1,
      sym_attribute,
    STATE(15636), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688092] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21264), 1,
      anon_sym_EQ,
    STATE(15515), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688112] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19974), 1,
      sym__lowercase_identifier,
    ACTIONS(19978), 1,
      anon_sym_mutable,
    STATE(15516), 1,
      sym_attribute,
    STATE(15969), 1,
      sym_field_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688132] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10086), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    STATE(15471), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15517), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688152] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(21266), 1,
      anon_sym_RPAREN,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(15518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688172] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3401), 1,
      anon_sym_RBRACK,
    ACTIONS(21268), 1,
      anon_sym_SEMI,
    STATE(15519), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688192] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15520), 1,
      sym_attribute,
    STATE(15613), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [688210] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14861), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15521), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688230] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11761), 1,
      anon_sym_GT,
    ACTIONS(21270), 1,
      anon_sym_SEMI,
    STATE(15334), 1,
      aux_sym_object_type_repeat1,
    STATE(15522), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688250] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15480), 1,
      sym_attribute_id,
    STATE(15523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [688268] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15524), 1,
      sym_attribute,
    STATE(15597), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [688286] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3693), 1,
      anon_sym_RBRACK,
    ACTIONS(21272), 1,
      anon_sym_SEMI,
    STATE(15525), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688306] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15526), 1,
      sym_attribute,
    STATE(15584), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [688324] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18534), 1,
      anon_sym_RBRACE,
    ACTIONS(21274), 1,
      anon_sym_SEMI,
    STATE(15527), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688344] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14483), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15528), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688364] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14865), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15529), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688384] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21276), 1,
      anon_sym_SEMI,
    ACTIONS(21278), 1,
      anon_sym_GT_RBRACE,
    STATE(15488), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(15530), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688404] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14871), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15531), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688424] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3685), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21280), 1,
      anon_sym_SEMI,
    STATE(15532), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688444] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21284), 1,
      anon_sym_LBRACK,
    STATE(15533), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21282), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [688462] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21286), 3,
      anon_sym_mutable,
      anon_sym_virtual,
      sym__lowercase_identifier,
  [688478] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21288), 1,
      aux_sym_quoted_extension_token1,
    STATE(15535), 1,
      sym_attribute,
    STATE(20146), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688498] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15536), 1,
      sym_attribute,
    STATE(15793), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [688516] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19265), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21290), 1,
      anon_sym_SEMI,
    STATE(15537), 1,
      sym_attribute,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688536] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14481), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15538), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688556] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    ACTIONS(21292), 1,
      anon_sym_RPAREN,
    STATE(14713), 1,
      aux_sym__type_params_repeat1,
    STATE(15539), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688576] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15540), 1,
      sym_attribute,
    STATE(15572), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [688594] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(55), 1,
      sym_attribute_id,
    STATE(15541), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [688612] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15542), 1,
      sym_attribute,
    STATE(15564), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [688630] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(21294), 1,
      anon_sym_RPAREN,
    STATE(15543), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688650] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21296), 1,
      anon_sym_RPAREN,
    STATE(15544), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688670] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(21298), 1,
      sym__lowercase_identifier,
    STATE(15545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688690] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18496), 1,
      anon_sym_RBRACE,
    ACTIONS(21300), 1,
      anon_sym_SEMI,
    STATE(15546), 1,
      sym_attribute,
    STATE(15563), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688710] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(27), 1,
      sym_attribute_id,
    STATE(15547), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [688728] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21302), 1,
      anon_sym_SEMI,
    ACTIONS(21304), 1,
      anon_sym_RBRACE,
    STATE(15509), 1,
      aux_sym_record_expression_repeat1,
    STATE(15548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688748] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15549), 1,
      sym_attribute,
    STATE(15559), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [688766] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12256), 1,
      anon_sym_DQUOTE,
    STATE(9907), 1,
      aux_sym_external_repeat1,
    STATE(11083), 1,
      sym_string,
    STATE(15550), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688786] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3503), 1,
      anon_sym_RBRACK,
    ACTIONS(21306), 1,
      anon_sym_SEMI,
    STATE(15551), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688806] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18640), 1,
      anon_sym_RBRACE,
    ACTIONS(21308), 1,
      anon_sym_SEMI,
    STATE(15552), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688826] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3505), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21310), 1,
      anon_sym_SEMI,
    STATE(15553), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688846] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21312), 1,
      aux_sym_quoted_extension_token1,
    STATE(15554), 1,
      sym_attribute,
    STATE(20163), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688866] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20042), 1,
      anon_sym_RBRACK,
    STATE(15555), 1,
      sym_attribute,
    STATE(15610), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688886] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20042), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15556), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688906] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(21314), 1,
      sym__lowercase_identifier,
    STATE(15557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688926] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(57), 1,
      sym_attribute_id,
    STATE(15558), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [688944] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21316), 1,
      aux_sym_quoted_extension_token1,
    STATE(15559), 1,
      sym_attribute,
    STATE(20169), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688964] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(56), 1,
      sym_attribute_id,
    STATE(15560), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [688982] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21318), 1,
      anon_sym_RPAREN,
    STATE(15561), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689002] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21320), 1,
      anon_sym_EQ,
    STATE(15562), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689022] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18472), 1,
      anon_sym_RBRACE,
    ACTIONS(21322), 1,
      anon_sym_SEMI,
    STATE(15563), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689042] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21324), 1,
      aux_sym_quoted_extension_token1,
    STATE(15564), 1,
      sym_attribute,
    STATE(20198), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689062] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21326), 1,
      anon_sym_SEMI,
    ACTIONS(21328), 1,
      anon_sym_GT_RBRACE,
    STATE(15407), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(15565), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689082] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(63), 1,
      sym_attribute_id,
    STATE(15566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [689100] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21330), 1,
      anon_sym_SEMI,
    ACTIONS(21332), 1,
      anon_sym_RBRACE,
    STATE(15567), 1,
      sym_attribute,
    STATE(15756), 1,
      aux_sym_record_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689120] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15554), 1,
      sym_attribute_id,
    STATE(15568), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [689138] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21334), 1,
      anon_sym_SEMI,
    ACTIONS(21336), 1,
      anon_sym_RBRACE,
    STATE(15569), 1,
      sym_attribute,
    STATE(15736), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689158] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15238), 1,
      sym_attribute_id,
    STATE(15570), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [689176] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21338), 1,
      anon_sym_LPAREN,
    ACTIONS(21340), 1,
      anon_sym_LBRACK,
    ACTIONS(21342), 1,
      anon_sym_LBRACE,
    STATE(15571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689196] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21344), 1,
      aux_sym_quoted_extension_token1,
    STATE(15572), 1,
      sym_attribute,
    STATE(20213), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689216] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15535), 1,
      sym_attribute_id,
    STATE(15573), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [689234] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21346), 1,
      anon_sym_LPAREN,
    ACTIONS(21348), 1,
      anon_sym_LBRACK,
    ACTIONS(21350), 1,
      anon_sym_LBRACE,
    STATE(15574), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689254] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21352), 1,
      aux_sym_quoted_extension_token1,
    STATE(15575), 1,
      sym_attribute,
    STATE(18090), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689274] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9), 1,
      sym_attribute_id,
    STATE(15576), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [689292] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18648), 1,
      anon_sym_RBRACE,
    ACTIONS(21354), 1,
      anon_sym_SEMI,
    STATE(15577), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689312] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14473), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15578), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689332] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(11451), 1,
      sym_module_binding,
    STATE(15579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18041), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [689350] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(21356), 1,
      anon_sym_RPAREN,
    STATE(15580), 1,
      sym_attribute,
    STATE(19754), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689370] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21358), 1,
      anon_sym_RPAREN,
    STATE(15581), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689390] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(66), 1,
      sym_attribute_id,
    STATE(15582), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [689408] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21360), 1,
      anon_sym_SEMI,
    ACTIONS(21362), 1,
      anon_sym_RBRACE,
    STATE(15470), 1,
      aux_sym_record_expression_repeat1,
    STATE(15583), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689428] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21364), 1,
      aux_sym_quoted_extension_token1,
    STATE(15584), 1,
      sym_attribute,
    STATE(20225), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689448] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(67), 1,
      sym_attribute_id,
    STATE(15585), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [689466] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14406), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15586), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689486] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19976), 1,
      anon_sym_RBRACE,
    ACTIONS(21366), 1,
      anon_sym_SEMI,
    STATE(15587), 1,
      sym_attribute,
    STATE(15590), 1,
      aux_sym_record_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689506] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21368), 1,
      anon_sym_LPAREN,
    ACTIONS(21370), 1,
      anon_sym_LBRACK,
    ACTIONS(21372), 1,
      anon_sym_LBRACE,
    STATE(15588), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689526] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(21374), 1,
      sym__lowercase_identifier,
    STATE(15589), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689546] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21376), 1,
      anon_sym_SEMI,
    ACTIONS(21379), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(15590), 2,
      sym_attribute,
      aux_sym_record_declaration_repeat1,
  [689564] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14412), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15591), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689584] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20040), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21381), 1,
      anon_sym_SEMI,
    STATE(15592), 1,
      sym_attribute,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689604] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21383), 1,
      anon_sym_SEMI,
    ACTIONS(21385), 1,
      anon_sym_RBRACE,
    STATE(15593), 1,
      sym_attribute,
    STATE(15766), 1,
      aux_sym_record_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689624] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(21387), 1,
      anon_sym_RPAREN,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(15594), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689644] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21389), 1,
      anon_sym_RPAREN,
    STATE(15595), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689664] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15596), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21391), 3,
      anon_sym_private,
      anon_sym_virtual,
      sym__lowercase_identifier,
  [689680] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21393), 1,
      aux_sym_quoted_extension_token1,
    STATE(15597), 1,
      sym_attribute,
    STATE(20236), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689700] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21395), 1,
      anon_sym_SEMI,
    ACTIONS(21397), 1,
      anon_sym_RBRACE,
    STATE(15598), 1,
      sym_attribute,
    STATE(15620), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689720] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(11984), 1,
      sym_module_binding,
    STATE(15599), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18041), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [689738] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(21399), 1,
      anon_sym_RPAREN,
    STATE(15600), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689758] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20010), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15601), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689778] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(15602), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12268), 3,
      anon_sym_and,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [689794] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(21401), 1,
      anon_sym_RPAREN,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(15603), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689814] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18658), 1,
      anon_sym_RBRACE,
    ACTIONS(21403), 1,
      anon_sym_SEMI,
    STATE(15577), 1,
      aux_sym_record_expression_repeat1,
    STATE(15604), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689834] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(21405), 1,
      anon_sym_RBRACK,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(15605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689854] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21407), 1,
      anon_sym_SEMI,
    ACTIONS(21409), 1,
      anon_sym_GT_RBRACE,
    STATE(15606), 1,
      sym_attribute,
    STATE(15630), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689874] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(68), 1,
      sym_attribute_id,
    STATE(15607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [689892] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9998), 1,
      sym__type_equation,
    STATE(15608), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21411), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [689910] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21413), 1,
      aux_sym_quoted_extension_token1,
    STATE(15609), 1,
      sym_attribute,
    STATE(20264), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689930] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19926), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15610), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689950] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(71), 1,
      sym_attribute_id,
    STATE(15611), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [689968] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20010), 1,
      anon_sym_RBRACK,
    STATE(15612), 1,
      sym_attribute,
    STATE(15676), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689988] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21415), 1,
      aux_sym_quoted_extension_token1,
    STATE(15613), 1,
      sym_attribute,
    STATE(20248), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690008] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11682), 1,
      anon_sym_GT,
    ACTIONS(21417), 1,
      anon_sym_SEMI,
    STATE(15334), 1,
      aux_sym_object_type_repeat1,
    STATE(15614), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690028] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(21419), 1,
      anon_sym_RPAREN,
    STATE(15615), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690048] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21421), 1,
      anon_sym_RPAREN,
    STATE(15616), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690068] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18668), 1,
      anon_sym_RBRACE,
    ACTIONS(21423), 1,
      anon_sym_SEMI,
    STATE(15617), 1,
      sym_attribute,
    STATE(15675), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690088] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3633), 1,
      anon_sym_RBRACK,
    ACTIONS(21425), 1,
      anon_sym_SEMI,
    STATE(15618), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690108] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21427), 1,
      aux_sym_quoted_extension_token1,
    STATE(15619), 1,
      sym_attribute,
    STATE(18719), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690128] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18385), 1,
      anon_sym_RBRACE,
    ACTIONS(21429), 1,
      anon_sym_SEMI,
    STATE(15620), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690148] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(72), 1,
      sym_attribute_id,
    STATE(15621), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [690166] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18444), 1,
      anon_sym_RBRACE,
    ACTIONS(21431), 1,
      anon_sym_SEMI,
    STATE(15622), 1,
      sym_attribute,
    STATE(15787), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690186] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14447), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15623), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690206] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20016), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15624), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690226] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3627), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21433), 1,
      anon_sym_SEMI,
    STATE(15625), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690246] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21435), 1,
      anon_sym_SEMI,
    ACTIONS(21437), 1,
      anon_sym_GT_RBRACE,
    STATE(15626), 1,
      sym_attribute,
    STATE(15761), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690266] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10), 1,
      sym_attribute_id,
    STATE(15627), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [690284] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20008), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690304] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20006), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21439), 1,
      anon_sym_SEMI,
    STATE(15629), 1,
      sym_attribute,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690324] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20004), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21441), 1,
      anon_sym_SEMI,
    STATE(15630), 1,
      sym_attribute,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690344] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(21443), 1,
      anon_sym_RPAREN,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(15631), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690364] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21445), 1,
      anon_sym_RPAREN,
    STATE(15632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690384] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15484), 1,
      sym_attribute_id,
    STATE(15633), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [690402] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18448), 1,
      anon_sym_RBRACE,
    ACTIONS(21447), 1,
      anon_sym_SEMI,
    STATE(15634), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690422] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21449), 1,
      anon_sym_RPAREN,
    STATE(15635), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690442] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18608), 1,
      anon_sym_RBRACE,
    ACTIONS(21451), 1,
      anon_sym_SEMI,
    STATE(15636), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690462] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21453), 1,
      anon_sym_RPAREN,
    STATE(15637), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690482] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3785), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21455), 1,
      anon_sym_SEMI,
    STATE(15638), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690502] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18450), 1,
      anon_sym_RBRACE,
    ACTIONS(21457), 1,
      anon_sym_SEMI,
    STATE(15639), 1,
      sym_attribute,
    STATE(15656), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690522] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21459), 1,
      aux_sym_quoted_extension_token1,
    STATE(15640), 1,
      sym_attribute,
    STATE(19455), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690542] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20000), 1,
      anon_sym_RBRACK,
    STATE(15628), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15641), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690562] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(20000), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15642), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690582] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(21461), 1,
      anon_sym_RPAREN,
    STATE(15643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690602] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21463), 1,
      aux_sym_quoted_extension_token1,
    STATE(15644), 1,
      sym_attribute,
    STATE(20251), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690622] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(75), 1,
      sym_attribute_id,
    STATE(15645), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [690640] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3781), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21465), 1,
      anon_sym_SEMI,
    STATE(15646), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690660] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21467), 1,
      anon_sym_RPAREN,
    STATE(15647), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690680] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15130), 1,
      sym_attribute_id,
    STATE(15648), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [690698] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(76), 1,
      sym_attribute_id,
    STATE(15649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [690716] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(21469), 1,
      sym__lowercase_identifier,
    STATE(15650), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690736] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9894), 1,
      sym__type_equation,
    STATE(15651), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21411), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [690754] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3461), 1,
      anon_sym_RBRACK,
    ACTIONS(21471), 1,
      anon_sym_SEMI,
    STATE(15652), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690774] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21473), 1,
      anon_sym_EQ,
    STATE(15653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21475), 2,
      anon_sym_SEMI,
      anon_sym_GT_RBRACE,
  [690792] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21477), 1,
      anon_sym_RPAREN,
    STATE(15654), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690812] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21479), 1,
      anon_sym_LPAREN,
    ACTIONS(21481), 1,
      anon_sym_LBRACK,
    ACTIONS(21483), 1,
      anon_sym_LBRACE,
    STATE(15655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690832] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18490), 1,
      anon_sym_RBRACE,
    ACTIONS(21485), 1,
      anon_sym_SEMI,
    STATE(15656), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690852] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21487), 1,
      aux_sym_quoted_extension_token1,
    STATE(15657), 1,
      sym_attribute,
    STATE(20281), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690872] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(21489), 1,
      sym__lowercase_identifier,
    STATE(15658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690892] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21491), 1,
      anon_sym_SEMI,
    ACTIONS(21493), 1,
      anon_sym_GT_RBRACE,
    STATE(15659), 1,
      sym_attribute,
    STATE(15722), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690912] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14939), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15660), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690932] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21495), 1,
      anon_sym_LPAREN,
    ACTIONS(21497), 1,
      anon_sym_LBRACK,
    ACTIONS(21499), 1,
      anon_sym_LBRACE,
    STATE(15661), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690952] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(21501), 1,
      sym__lowercase_identifier,
    STATE(15662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690972] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(14), 1,
      sym_attribute_id,
    STATE(15663), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [690990] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18678), 1,
      anon_sym_RBRACE,
    ACTIONS(21503), 1,
      anon_sym_SEMI,
    STATE(15664), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691010] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10196), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    STATE(15665), 1,
      sym_attribute,
    STATE(15829), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691030] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21505), 1,
      anon_sym_RPAREN,
    STATE(15666), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691050] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15235), 1,
      sym_attribute_id,
    STATE(15667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [691068] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21507), 1,
      anon_sym_LPAREN,
    ACTIONS(21509), 1,
      anon_sym_LBRACK,
    ACTIONS(21511), 1,
      anon_sym_LBRACE,
    STATE(15668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691088] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18574), 1,
      anon_sym_RBRACE,
    ACTIONS(21513), 1,
      anon_sym_SEMI,
    STATE(15634), 1,
      aux_sym_record_expression_repeat1,
    STATE(15669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691108] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3711), 1,
      anon_sym_RBRACK,
    ACTIONS(21515), 1,
      anon_sym_SEMI,
    STATE(15670), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691128] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(77), 1,
      sym_attribute_id,
    STATE(15671), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [691146] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17635), 1,
      anon_sym_SEMI,
    ACTIONS(17637), 1,
      anon_sym_GT,
    STATE(15672), 1,
      sym_attribute,
    STATE(15849), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691166] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(21517), 1,
      anon_sym_RPAREN,
    STATE(15673), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691186] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11801), 1,
      anon_sym_GT,
    ACTIONS(21519), 1,
      anon_sym_SEMI,
    STATE(15334), 1,
      aux_sym_object_type_repeat1,
    STATE(15674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691206] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18686), 1,
      anon_sym_RBRACE,
    ACTIONS(21521), 1,
      anon_sym_SEMI,
    STATE(15675), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691226] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19980), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15676), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691246] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(21523), 1,
      anon_sym_RPAREN,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(15677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691266] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21525), 1,
      aux_sym_quoted_extension_token1,
    STATE(15678), 1,
      sym_attribute,
    STATE(19022), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691286] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19984), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15679), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691306] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19984), 1,
      anon_sym_RBRACK,
    STATE(15642), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691326] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(21527), 1,
      anon_sym_RPAREN,
    STATE(15681), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691346] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18694), 1,
      anon_sym_RBRACE,
    ACTIONS(21529), 1,
      anon_sym_SEMI,
    STATE(15682), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691366] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18586), 1,
      anon_sym_RBRACE,
    ACTIONS(21531), 1,
      anon_sym_SEMI,
    STATE(15683), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691386] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14597), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15684), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691406] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21533), 1,
      anon_sym_RPAREN,
    STATE(15685), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691426] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21535), 1,
      anon_sym_RPAREN,
    STATE(15686), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691446] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14959), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15687), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691466] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15688), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18464), 3,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_GT,
  [691482] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3459), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21537), 1,
      anon_sym_SEMI,
    STATE(15689), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691502] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21539), 1,
      anon_sym_SEMI,
    ACTIONS(21541), 1,
      anon_sym_RBRACE,
    STATE(15690), 1,
      sym_attribute,
    STATE(15711), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691522] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21543), 1,
      anon_sym_EQ,
    STATE(15691), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691542] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21545), 1,
      anon_sym_SEMI,
    ACTIONS(21547), 1,
      anon_sym_GT_RBRACE,
    STATE(15629), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(15692), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691562] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14614), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15693), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691582] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21549), 1,
      anon_sym_RPAREN,
    STATE(15694), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691602] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14964), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15695), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691622] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19958), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21551), 1,
      anon_sym_SEMI,
    STATE(15696), 1,
      sym_attribute,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691642] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21553), 1,
      aux_sym_quoted_extension_token1,
    STATE(15697), 1,
      sym_attribute,
    STATE(19404), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691662] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21555), 1,
      anon_sym_SEMI,
    ACTIONS(21557), 1,
      anon_sym_GT_RBRACE,
    STATE(15698), 1,
      sym_attribute,
    STATE(15721), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691682] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15465), 1,
      sym_attribute_id,
    STATE(15699), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [691700] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14617), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15700), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691720] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21559), 1,
      anon_sym_SEMI,
    ACTIONS(21561), 1,
      anon_sym_RBRACE,
    STATE(15664), 1,
      aux_sym_record_expression_repeat1,
    STATE(15701), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691740] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(65), 1,
      sym_attribute_id,
    STATE(15702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [691758] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19962), 1,
      anon_sym_RBRACK,
    STATE(15624), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15703), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691778] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15422), 1,
      sym_attribute_id,
    STATE(15704), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [691796] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21563), 1,
      anon_sym_LPAREN,
    ACTIONS(21565), 1,
      anon_sym_LBRACK,
    ACTIONS(21567), 1,
      anon_sym_LBRACE,
    STATE(15705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691816] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3375), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21569), 1,
      anon_sym_SEMI,
    STATE(15706), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691836] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18865), 1,
      sym__lowercase_identifier,
    STATE(15653), 1,
      sym__instance_variable_name,
    STATE(15707), 1,
      sym_attribute,
    STATE(16609), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691856] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3313), 1,
      anon_sym_RBRACK,
    ACTIONS(21571), 1,
      anon_sym_SEMI,
    STATE(15708), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691876] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3563), 1,
      anon_sym_RBRACK,
    ACTIONS(21573), 1,
      anon_sym_SEMI,
    STATE(15709), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691896] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21575), 1,
      anon_sym_LPAREN,
    ACTIONS(21577), 1,
      anon_sym_LBRACK,
    ACTIONS(21579), 1,
      anon_sym_LBRACE,
    STATE(15710), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691916] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18688), 1,
      anon_sym_RBRACE,
    ACTIONS(21581), 1,
      anon_sym_SEMI,
    STATE(15711), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691936] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10178), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    STATE(15712), 1,
      sym_attribute,
    STATE(15814), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691956] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19946), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21583), 1,
      anon_sym_SEMI,
    STATE(15713), 1,
      sym_attribute,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691976] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18690), 1,
      anon_sym_RBRACE,
    ACTIONS(21585), 1,
      anon_sym_SEMI,
    STATE(15714), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691996] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21587), 1,
      anon_sym_LPAREN,
    ACTIONS(21589), 1,
      anon_sym_LBRACK,
    ACTIONS(21591), 1,
      anon_sym_LBRACE,
    STATE(15715), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692016] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3561), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21593), 1,
      anon_sym_SEMI,
    STATE(15716), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692036] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17521), 1,
      anon_sym_SEMI,
    ACTIONS(17523), 1,
      anon_sym_GT,
    STATE(15674), 1,
      aux_sym_object_type_repeat1,
    STATE(15717), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692056] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(35), 1,
      sym_attribute_id,
    STATE(15718), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [692074] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19962), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15719), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692094] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17631), 1,
      anon_sym_SEMI,
    ACTIONS(17633), 1,
      anon_sym_GT,
    STATE(15720), 1,
      sym_attribute,
    STATE(15822), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692114] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19942), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21595), 1,
      anon_sym_SEMI,
    STATE(15721), 1,
      sym_attribute,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692134] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19944), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21597), 1,
      anon_sym_SEMI,
    STATE(15722), 1,
      sym_attribute,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692154] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9972), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    STATE(15679), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15723), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692174] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(21599), 1,
      sym__lowercase_identifier,
    STATE(15724), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692194] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15468), 1,
      sym_attribute_id,
    STATE(15725), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [692212] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3373), 1,
      anon_sym_RBRACK,
    ACTIONS(21601), 1,
      anon_sym_SEMI,
    STATE(15726), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692232] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21603), 1,
      aux_sym_quoted_extension_token1,
    STATE(15727), 1,
      sym_attribute,
    STATE(18017), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692252] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21605), 1,
      anon_sym_RPAREN,
    STATE(15728), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692272] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21607), 1,
      anon_sym_SEMI,
    ACTIONS(21609), 1,
      anon_sym_GT_RBRACE,
    STATE(15696), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(15729), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692292] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18766), 1,
      anon_sym_RBRACE,
    ACTIONS(21611), 1,
      anon_sym_SEMI,
    STATE(15730), 1,
      sym_attribute,
    STATE(15747), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692312] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21613), 1,
      anon_sym_RPAREN,
    STATE(15731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692332] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21615), 1,
      aux_sym_quoted_extension_token1,
    STATE(15732), 1,
      sym_attribute,
    STATE(18602), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692352] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21617), 1,
      aux_sym_quoted_extension_token1,
    STATE(15733), 1,
      sym_attribute,
    STATE(19689), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692372] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21619), 1,
      anon_sym_LPAREN,
    ACTIONS(21621), 1,
      anon_sym_LBRACK,
    ACTIONS(21623), 1,
      anon_sym_LBRACE,
    STATE(15734), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692392] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(21625), 1,
      anon_sym_RPAREN,
    STATE(15735), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692412] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18728), 1,
      anon_sym_RBRACE,
    ACTIONS(21627), 1,
      anon_sym_SEMI,
    STATE(15736), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692432] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(21629), 1,
      sym__lowercase_identifier,
    STATE(15737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692452] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14416), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15738), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692472] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21631), 1,
      anon_sym_SEMI,
    ACTIONS(21633), 1,
      anon_sym_RBRACE,
    STATE(15714), 1,
      aux_sym_record_expression_repeat1,
    STATE(15739), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692492] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19926), 1,
      anon_sym_RBRACK,
    STATE(15740), 1,
      sym_attribute,
    STATE(15812), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692512] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(21635), 1,
      sym__lowercase_identifier,
    STATE(15741), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692532] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15742), 1,
      sym_attribute,
    STATE(15920), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [692550] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21637), 1,
      anon_sym_RPAREN,
    STATE(15743), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692570] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(11451), 1,
      sym_module_binding,
    STATE(15744), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18003), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [692588] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21639), 1,
      anon_sym_RPAREN,
    STATE(15745), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692608] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(19), 1,
      sym_attribute_id,
    STATE(15746), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [692626] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18800), 1,
      anon_sym_RBRACE,
    ACTIONS(21641), 1,
      anon_sym_SEMI,
    STATE(15747), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692646] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(33), 1,
      sym_attribute_id,
    STATE(15748), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [692664] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21645), 1,
      anon_sym_LBRACK,
    STATE(15749), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21643), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [692682] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(2), 1,
      sym_attribute_id,
    STATE(15750), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [692700] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(21647), 1,
      anon_sym_RPAREN,
    STATE(15751), 1,
      sym_attribute,
    STATE(19431), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692720] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3315), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21649), 1,
      anon_sym_SEMI,
    STATE(15752), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692740] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8414), 1,
      anon_sym_RBRACK,
    ACTIONS(21651), 1,
      anon_sym_SEMI,
    STATE(15163), 1,
      aux_sym_list_pattern_repeat1,
    STATE(15753), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692760] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21653), 1,
      anon_sym_SEMI,
    ACTIONS(21656), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(15754), 2,
      sym_attribute,
      aux_sym_object_copy_expression_repeat1,
  [692778] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14410), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15755), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692798] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18009), 1,
      anon_sym_RBRACE,
    ACTIONS(21658), 1,
      anon_sym_SEMI,
    STATE(15124), 1,
      aux_sym_record_pattern_repeat1,
    STATE(15756), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692818] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21660), 1,
      anon_sym_SEMI,
    ACTIONS(21662), 1,
      anon_sym_RBRACE,
    STATE(15483), 1,
      aux_sym_record_expression_repeat1,
    STATE(15757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692838] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8412), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21664), 1,
      anon_sym_SEMI,
    STATE(15758), 1,
      sym_attribute,
    STATE(16269), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692858] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15403), 1,
      sym_attribute_id,
    STATE(15759), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [692876] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21666), 1,
      anon_sym_RPAREN,
    STATE(15760), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692896] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19916), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21668), 1,
      anon_sym_SEMI,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(15761), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692916] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(11), 1,
      sym_attribute_id,
    STATE(15762), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [692934] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8710), 1,
      anon_sym_RBRACK,
    ACTIONS(21670), 1,
      anon_sym_SEMI,
    STATE(15168), 1,
      aux_sym_list_binding_pattern_repeat1,
    STATE(15763), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692954] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15389), 1,
      sym_attribute_id,
    STATE(15764), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [692972] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21672), 1,
      aux_sym_quoted_extension_token1,
    STATE(15765), 1,
      sym_attribute,
    STATE(20285), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692992] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18029), 1,
      anon_sym_RBRACE,
    ACTIONS(21674), 1,
      anon_sym_SEMI,
    STATE(15175), 1,
      aux_sym_record_binding_pattern_repeat1,
    STATE(15766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693012] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21676), 1,
      anon_sym_RPAREN,
    STATE(15767), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693032] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21678), 1,
      anon_sym_LPAREN,
    ACTIONS(21680), 1,
      anon_sym_LBRACK,
    ACTIONS(21682), 1,
      anon_sym_LBRACE,
    STATE(15768), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693052] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(78), 1,
      sym_attribute_id,
    STATE(15769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [693070] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15444), 1,
      sym_attribute_id,
    STATE(15770), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [693088] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21684), 1,
      aux_sym_quoted_extension_token1,
    STATE(15771), 1,
      sym_attribute,
    STATE(20296), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693108] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(64), 1,
      sym_attribute_id,
    STATE(15772), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [693126] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12189), 1,
      sym_module_binding,
    STATE(15773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18003), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [693144] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(79), 1,
      sym_attribute_id,
    STATE(15774), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [693162] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18748), 1,
      anon_sym_RBRACE,
    ACTIONS(21686), 1,
      anon_sym_SEMI,
    STATE(15775), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693182] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19906), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693202] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21688), 1,
      aux_sym_quoted_extension_token1,
    STATE(15777), 1,
      sym_attribute,
    STATE(20312), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693222] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(80), 1,
      sym_attribute_id,
    STATE(15778), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [693240] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(18209), 1,
      anon_sym_RBRACK,
    STATE(15779), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693260] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21690), 1,
      aux_sym_quoted_extension_token1,
    STATE(15780), 1,
      sym_attribute,
    STATE(20317), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693280] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(81), 1,
      sym_attribute_id,
    STATE(15781), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [693298] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21692), 1,
      anon_sym_LPAREN,
    ACTIONS(21694), 1,
      anon_sym_LBRACK,
    ACTIONS(21696), 1,
      anon_sym_LBRACE,
    STATE(15782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693318] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21698), 1,
      aux_sym_quoted_extension_token1,
    STATE(15783), 1,
      sym_attribute,
    STATE(20382), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693338] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21700), 1,
      anon_sym_SEMI,
    ACTIONS(21702), 1,
      anon_sym_RBRACE,
    STATE(15784), 1,
      sym_attribute,
    STATE(15855), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693358] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18636), 1,
      anon_sym_RBRACE,
    ACTIONS(21704), 1,
      anon_sym_SEMI,
    STATE(15785), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693378] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21706), 1,
      anon_sym_RPAREN,
    STATE(15786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693398] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18843), 1,
      anon_sym_RBRACE,
    ACTIONS(21708), 1,
      anon_sym_SEMI,
    STATE(15787), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693418] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21710), 1,
      anon_sym_RPAREN,
    STATE(15788), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693438] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(21712), 1,
      sym__lowercase_identifier,
    STATE(15789), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693458] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(21714), 1,
      sym__lowercase_identifier,
    STATE(15790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693478] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15259), 1,
      sym_attribute_id,
    STATE(15791), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [693496] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(21716), 1,
      anon_sym_RPAREN,
    STATE(15792), 1,
      sym_attribute,
    STATE(18943), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693516] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21718), 1,
      aux_sym_quoted_extension_token1,
    STATE(15793), 1,
      sym_attribute,
    STATE(19233), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693536] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(21720), 1,
      sym__lowercase_identifier,
    STATE(15794), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693556] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19888), 1,
      anon_sym_RBRACK,
    STATE(15776), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15795), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693576] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19888), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15796), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693596] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(21722), 1,
      sym__lowercase_identifier,
    STATE(15797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693616] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21724), 1,
      anon_sym_LPAREN,
    ACTIONS(21726), 1,
      anon_sym_LBRACK,
    ACTIONS(21728), 1,
      anon_sym_LBRACE,
    STATE(15798), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693636] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(21730), 1,
      anon_sym_RPAREN,
    STATE(15799), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693656] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21732), 1,
      anon_sym_RPAREN,
    STATE(15800), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693676] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15320), 1,
      sym_attribute_id,
    STATE(15801), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [693694] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(21734), 1,
      anon_sym_RPAREN,
    STATE(15802), 1,
      sym_attribute,
    STATE(19199), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693714] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21736), 1,
      anon_sym_RPAREN,
    STATE(15803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693734] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21738), 1,
      aux_sym_quoted_extension_token1,
    STATE(15804), 1,
      sym_attribute,
    STATE(17951), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693754] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15805), 1,
      sym_attribute,
    STATE(16139), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [693772] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21740), 1,
      anon_sym_LPAREN,
    ACTIONS(21742), 1,
      anon_sym_LBRACK,
    ACTIONS(21744), 1,
      anon_sym_LBRACE,
    STATE(15806), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693792] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(21746), 1,
      sym__lowercase_identifier,
    STATE(15807), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693812] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(21748), 1,
      anon_sym_RPAREN,
    STATE(15808), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693832] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19876), 1,
      anon_sym_RBRACK,
    STATE(15809), 1,
      sym_attribute,
    STATE(15914), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693852] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19880), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693872] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21750), 1,
      anon_sym_LPAREN,
    ACTIONS(21752), 1,
      anon_sym_LBRACK,
    ACTIONS(21754), 1,
      anon_sym_LBRACE,
    STATE(15811), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693892] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19870), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15812), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693912] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18754), 1,
      anon_sym_RBRACE,
    ACTIONS(21756), 1,
      anon_sym_SEMI,
    STATE(15775), 1,
      aux_sym_record_expression_repeat1,
    STATE(15813), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693932] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19876), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15814), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693952] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21758), 1,
      anon_sym_RPAREN,
    STATE(15815), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693972] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19882), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15816), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693992] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21760), 1,
      anon_sym_SEMI,
    ACTIONS(21762), 1,
      anon_sym_GT_RBRACE,
    STATE(15817), 1,
      sym_attribute,
    STATE(15956), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694012] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18672), 1,
      anon_sym_RBRACE,
    ACTIONS(21764), 1,
      anon_sym_SEMI,
    STATE(15818), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694032] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21766), 1,
      anon_sym_RPAREN,
    STATE(15819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694052] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(21768), 1,
      anon_sym_RPAREN,
    STATE(15820), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694072] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21770), 1,
      anon_sym_RPAREN,
    STATE(15821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694092] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11566), 1,
      anon_sym_GT,
    ACTIONS(21772), 1,
      anon_sym_SEMI,
    STATE(15334), 1,
      aux_sym_object_type_repeat1,
    STATE(15822), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694112] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19868), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21774), 1,
      anon_sym_SEMI,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(15823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694132] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19864), 1,
      anon_sym_RBRACK,
    STATE(15810), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15824), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694152] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19848), 1,
      anon_sym_RBRACK,
    STATE(15825), 1,
      sym_attribute,
    STATE(15961), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694172] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19864), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694192] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(21776), 1,
      anon_sym_RPAREN,
    STATE(15827), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694212] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18638), 1,
      anon_sym_RBRACE,
    ACTIONS(21778), 1,
      anon_sym_SEMI,
    STATE(15785), 1,
      aux_sym_record_expression_repeat1,
    STATE(15828), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694232] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19848), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15829), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694252] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11789), 1,
      anon_sym_GT,
    ACTIONS(21780), 1,
      anon_sym_SEMI,
    STATE(15334), 1,
      aux_sym_object_type_repeat1,
    STATE(15830), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694272] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21782), 1,
      anon_sym_LPAREN,
    ACTIONS(21784), 1,
      anon_sym_LBRACK,
    ACTIONS(21786), 1,
      anon_sym_LBRACE,
    STATE(15831), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694292] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21788), 1,
      anon_sym_RPAREN,
    STATE(15832), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694312] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19874), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15833), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694332] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18762), 1,
      anon_sym_RBRACE,
    ACTIONS(21790), 1,
      anon_sym_SEMI,
    STATE(15834), 1,
      sym_attribute,
    STATE(15927), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694352] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(21792), 1,
      sym__lowercase_identifier,
    STATE(15835), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694372] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3683), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21794), 1,
      anon_sym_SEMI,
    STATE(15836), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694392] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21796), 1,
      anon_sym_LPAREN,
    ACTIONS(21798), 1,
      anon_sym_LBRACK,
    ACTIONS(21800), 1,
      anon_sym_LBRACE,
    STATE(15837), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694412] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14446), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15838), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694432] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15839), 1,
      sym_attribute,
    STATE(16013), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [694450] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19852), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15840), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694470] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19852), 1,
      anon_sym_RBRACK,
    STATE(15796), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694490] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(21802), 1,
      anon_sym_RPAREN,
    STATE(15842), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694510] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18768), 1,
      anon_sym_RBRACE,
    ACTIONS(21804), 1,
      anon_sym_SEMI,
    STATE(15843), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694530] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21806), 1,
      anon_sym_RPAREN,
    STATE(15844), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694550] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(21808), 1,
      anon_sym_RPAREN,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(15845), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694570] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15310), 1,
      sym_attribute_id,
    STATE(15846), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [694588] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(21810), 1,
      anon_sym_RPAREN,
    STATE(15847), 1,
      sym_attribute,
    STATE(19210), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694608] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21812), 1,
      anon_sym_LPAREN,
    ACTIONS(21814), 1,
      anon_sym_LBRACK,
    ACTIONS(21816), 1,
      anon_sym_LBRACE,
    STATE(15848), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694628] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11781), 1,
      anon_sym_GT,
    ACTIONS(21818), 1,
      anon_sym_SEMI,
    STATE(15334), 1,
      aux_sym_object_type_repeat1,
    STATE(15849), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694648] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18594), 1,
      anon_sym_RBRACE,
    ACTIONS(21820), 1,
      anon_sym_SEMI,
    STATE(15818), 1,
      aux_sym_record_expression_repeat1,
    STATE(15850), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694668] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3677), 1,
      anon_sym_RBRACK,
    ACTIONS(21822), 1,
      anon_sym_SEMI,
    STATE(15851), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694688] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11741), 1,
      anon_sym_GT,
    ACTIONS(21824), 1,
      anon_sym_SEMI,
    STATE(15334), 1,
      aux_sym_object_type_repeat1,
    STATE(15852), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694708] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19840), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21826), 1,
      anon_sym_SEMI,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(15853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694728] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3531), 1,
      anon_sym_RBRACK,
    ACTIONS(21828), 1,
      anon_sym_SEMI,
    STATE(15854), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694748] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18788), 1,
      anon_sym_RBRACE,
    ACTIONS(21830), 1,
      anon_sym_SEMI,
    STATE(15855), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694768] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12256), 1,
      anon_sym_DQUOTE,
    STATE(10029), 1,
      aux_sym_external_repeat1,
    STATE(11083), 1,
      sym_string,
    STATE(15856), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694788] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(21832), 1,
      sym__lowercase_identifier,
    STATE(15857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694808] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19836), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694828] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21834), 1,
      anon_sym_EQ,
    STATE(15859), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694848] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19836), 1,
      anon_sym_RBRACK,
    STATE(15826), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15860), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694868] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14795), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15861), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694888] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21836), 1,
      anon_sym_EQ,
    STATE(15862), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694908] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18590), 1,
      anon_sym_RBRACE,
    ACTIONS(21838), 1,
      anon_sym_SEMI,
    STATE(15863), 1,
      sym_attribute,
    STATE(15974), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694928] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(21840), 1,
      anon_sym_RPAREN,
    STATE(15864), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694948] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21842), 1,
      sym__lowercase_identifier,
    ACTIONS(21844), 1,
      anon_sym_LPAREN,
    STATE(8613), 1,
      sym__simple_value_pattern,
    STATE(15865), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694968] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3355), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21846), 1,
      anon_sym_SEMI,
    STATE(15866), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694988] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21848), 1,
      anon_sym_RPAREN,
    STATE(15867), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695008] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21850), 1,
      anon_sym_LPAREN,
    ACTIONS(21852), 1,
      anon_sym_LBRACK,
    ACTIONS(21854), 1,
      anon_sym_LBRACE,
    STATE(15868), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695028] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14847), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15869), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695048] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21856), 1,
      anon_sym_EQ,
    STATE(15870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695068] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(29), 1,
      sym_attribute_id,
    STATE(15871), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [695086] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21858), 1,
      anon_sym_EQ,
    STATE(15872), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695106] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(21860), 1,
      anon_sym_RBRACK,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(15873), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695126] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18552), 1,
      anon_sym_RBRACE,
    ACTIONS(21862), 1,
      anon_sym_SEMI,
    STATE(15874), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695146] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10011), 1,
      sym__type_equation,
    STATE(15875), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21864), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [695164] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21866), 1,
      anon_sym_SEMI,
    ACTIONS(21868), 1,
      anon_sym_GT_RBRACE,
    STATE(15823), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(15876), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695184] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15877), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21870), 3,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym__lowercase_identifier,
  [695200] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17677), 1,
      anon_sym_SEMI,
    ACTIONS(17679), 1,
      anon_sym_GT,
    STATE(15830), 1,
      aux_sym_object_type_repeat1,
    STATE(15878), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695220] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19819), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21872), 1,
      anon_sym_SEMI,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(15879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695240] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21874), 1,
      aux_sym_quoted_extension_token1,
    STATE(15880), 1,
      sym_attribute,
    STATE(19297), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695260] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(21876), 1,
      anon_sym_RPAREN,
    STATE(15881), 1,
      sym_attribute,
    STATE(18930), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695280] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19813), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15882), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695300] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14866), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15883), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695320] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18794), 1,
      anon_sym_RBRACE,
    ACTIONS(21878), 1,
      anon_sym_SEMI,
    STATE(15884), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695340] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(21880), 1,
      anon_sym_RPAREN,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(15885), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695360] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3343), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21882), 1,
      anon_sym_SEMI,
    STATE(15886), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695380] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21884), 1,
      aux_sym_quoted_extension_token1,
    STATE(15887), 1,
      sym_attribute,
    STATE(17890), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695400] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21886), 1,
      anon_sym_EQ,
    STATE(15888), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695420] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14927), 1,
      anon_sym_in,
    ACTIONS(21200), 1,
      anon_sym_and,
    STATE(15482), 1,
      aux_sym_module_definition_repeat1,
    STATE(15889), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695440] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18514), 1,
      anon_sym_RBRACE,
    ACTIONS(21888), 1,
      anon_sym_SEMI,
    STATE(15890), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695460] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17693), 1,
      anon_sym_SEMI,
    ACTIONS(17695), 1,
      anon_sym_GT,
    STATE(15852), 1,
      aux_sym_object_type_repeat1,
    STATE(15891), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695480] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10227), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    STATE(15840), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15892), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695500] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14170), 1,
      anon_sym_in,
    ACTIONS(21890), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(15893), 2,
      sym_attribute,
      aux_sym_module_definition_repeat1,
  [695518] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    ACTIONS(21893), 1,
      anon_sym_RBRACK,
    STATE(14713), 1,
      aux_sym__type_params_repeat1,
    STATE(15894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695538] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(9993), 1,
      sym__type_equation,
    STATE(15895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21864), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [695556] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21895), 1,
      anon_sym_RPAREN,
    STATE(15896), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695576] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9986), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    STATE(15858), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15897), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695596] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21897), 1,
      anon_sym_LPAREN,
    ACTIONS(21899), 1,
      anon_sym_LBRACK,
    ACTIONS(21901), 1,
      anon_sym_LBRACE,
    STATE(15898), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695616] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21903), 1,
      anon_sym_SEMI,
    ACTIONS(21905), 1,
      anon_sym_RBRACE,
    STATE(15843), 1,
      aux_sym_record_expression_repeat1,
    STATE(15899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695636] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3341), 1,
      anon_sym_RBRACK,
    ACTIONS(21907), 1,
      anon_sym_SEMI,
    STATE(15900), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695656] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14606), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15901), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695676] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21909), 1,
      anon_sym_LPAREN,
    ACTIONS(21911), 1,
      anon_sym_LBRACK,
    ACTIONS(21913), 1,
      anon_sym_LBRACE,
    STATE(15902), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695696] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15290), 1,
      sym_attribute_id,
    STATE(15903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [695714] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3357), 1,
      anon_sym_RBRACK,
    ACTIONS(21915), 1,
      anon_sym_SEMI,
    STATE(15904), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695734] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(21917), 1,
      sym__lowercase_identifier,
    STATE(15905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695754] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21919), 1,
      anon_sym_SEMI,
    ACTIONS(21921), 1,
      anon_sym_GT_RBRACE,
    STATE(15879), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(15906), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695774] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(8287), 1,
      sym_attribute_id,
    STATE(15907), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21923), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [695792] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21925), 1,
      anon_sym_LPAREN,
    ACTIONS(21927), 1,
      anon_sym_LBRACK,
    ACTIONS(21929), 1,
      anon_sym_LBRACE,
    STATE(15908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695812] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21931), 1,
      anon_sym_SEMI,
    ACTIONS(21933), 1,
      anon_sym_RBRACE,
    STATE(15890), 1,
      aux_sym_record_expression_repeat1,
    STATE(15909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695832] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(21935), 1,
      anon_sym_RPAREN,
    STATE(15910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695852] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21937), 1,
      anon_sym_LPAREN,
    ACTIONS(21939), 1,
      anon_sym_LBRACK,
    ACTIONS(21941), 1,
      anon_sym_LBRACE,
    STATE(15911), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695872] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14927), 1,
      anon_sym_in,
    ACTIONS(21200), 1,
      anon_sym_and,
    STATE(15893), 1,
      aux_sym_module_definition_repeat1,
    STATE(15912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695892] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3533), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21943), 1,
      anon_sym_SEMI,
    STATE(15913), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695912] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19799), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15914), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695932] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19799), 1,
      anon_sym_RBRACK,
    STATE(15915), 1,
      sym_attribute,
    STATE(15940), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695952] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21945), 1,
      anon_sym_RPAREN,
    STATE(15916), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695972] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    ACTIONS(21947), 1,
      anon_sym_RBRACK,
    STATE(15894), 1,
      aux_sym__type_params_repeat1,
    STATE(15917), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695992] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    ACTIONS(21947), 1,
      anon_sym_RBRACK,
    STATE(14713), 1,
      aux_sym__type_params_repeat1,
    STATE(15918), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696012] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(23), 1,
      sym_attribute_id,
    STATE(15919), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [696030] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21949), 1,
      aux_sym_quoted_extension_token1,
    STATE(15920), 1,
      sym_attribute,
    STATE(17825), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696050] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21951), 1,
      anon_sym_EQ,
    STATE(15921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696070] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21953), 1,
      aux_sym_quoted_extension_token1,
    STATE(15922), 1,
      sym_attribute,
    STATE(18586), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696090] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21955), 1,
      anon_sym_LPAREN,
    ACTIONS(21957), 1,
      anon_sym_LBRACK,
    ACTIONS(21959), 1,
      anon_sym_LBRACE,
    STATE(15923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696110] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(21961), 1,
      anon_sym_RPAREN,
    STATE(15924), 1,
      sym_attribute,
    STATE(19420), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696130] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21963), 1,
      anon_sym_RPAREN,
    STATE(15925), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696150] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19775), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [696166] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18802), 1,
      anon_sym_RBRACE,
    ACTIONS(21965), 1,
      anon_sym_SEMI,
    STATE(15927), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696186] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(44), 1,
      sym_attribute_id,
    STATE(15928), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [696204] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3525), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21967), 1,
      anon_sym_SEMI,
    STATE(15929), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696224] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19784), 1,
      anon_sym_RBRACK,
    STATE(15816), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15930), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696244] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15462), 1,
      sym_attribute_id,
    STATE(15931), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [696262] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19784), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15932), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696282] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(62), 1,
      sym_attribute_id,
    STATE(15933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [696300] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21969), 1,
      anon_sym_RPAREN,
    STATE(15934), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696320] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18816), 1,
      anon_sym_RBRACE,
    ACTIONS(21971), 1,
      anon_sym_SEMI,
    STATE(15935), 1,
      sym_attribute,
    STATE(15963), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696340] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(21973), 1,
      anon_sym_RPAREN,
    STATE(15936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696360] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(21975), 1,
      anon_sym_RPAREN,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(15937), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696380] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21977), 1,
      anon_sym_SEMI,
    ACTIONS(21979), 1,
      anon_sym_GT_RBRACE,
    STATE(15853), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(15938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696400] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10818), 1,
      sym_attribute_id,
    STATE(15939), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21981), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [696418] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19758), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696438] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21983), 1,
      anon_sym_RPAREN,
    STATE(15941), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696458] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19756), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15942), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696478] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21985), 1,
      anon_sym_LPAREN,
    ACTIONS(21987), 1,
      anon_sym_LBRACK,
    ACTIONS(21989), 1,
      anon_sym_LBRACE,
    STATE(15943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696498] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    ACTIONS(21991), 1,
      anon_sym_RBRACK,
    STATE(15918), 1,
      aux_sym__type_params_repeat1,
    STATE(15944), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696518] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21993), 1,
      aux_sym_quoted_extension_token1,
    STATE(15945), 1,
      sym_attribute,
    STATE(19823), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696538] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21995), 1,
      sym__lowercase_identifier,
    ACTIONS(21997), 1,
      anon_sym_LPAREN,
    STATE(7854), 1,
      sym__simple_value_pattern,
    STATE(15946), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696558] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(21999), 1,
      anon_sym_RPAREN,
    STATE(15947), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696578] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15402), 1,
      sym_attribute_id,
    STATE(15948), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [696596] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18442), 1,
      anon_sym_RBRACE,
    ACTIONS(22001), 1,
      anon_sym_SEMI,
    STATE(15949), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696616] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(31), 1,
      sym_attribute_id,
    STATE(15950), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [696634] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22003), 1,
      anon_sym_RPAREN,
    STATE(15951), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696654] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14781), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15952), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696674] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15732), 1,
      sym_attribute_id,
    STATE(15953), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [696692] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(22005), 1,
      sym__lowercase_identifier,
    STATE(15954), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696712] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15955), 1,
      sym_attribute,
    STATE(16064), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [696730] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19780), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22007), 1,
      anon_sym_SEMI,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(15956), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696750] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(22009), 1,
      anon_sym_RPAREN,
    STATE(15957), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696770] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22011), 1,
      anon_sym_LPAREN,
    ACTIONS(22013), 1,
      anon_sym_LBRACK,
    ACTIONS(22015), 1,
      anon_sym_LBRACE,
    STATE(15958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696790] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(18), 1,
      sym_attribute_id,
    STATE(15959), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [696808] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18837), 1,
      anon_sym_RBRACE,
    ACTIONS(22017), 1,
      anon_sym_SEMI,
    STATE(15960), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696828] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19736), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15961), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696848] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19744), 1,
      anon_sym_RBRACK,
    STATE(15942), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15962), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696868] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18839), 1,
      anon_sym_RBRACE,
    ACTIONS(22019), 1,
      anon_sym_SEMI,
    STATE(15963), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696888] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19736), 1,
      anon_sym_RBRACK,
    STATE(15964), 1,
      sym_attribute,
    STATE(15983), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696908] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22021), 1,
      anon_sym_SEMI,
    ACTIONS(22023), 1,
      anon_sym_RBRACE,
    STATE(15874), 1,
      aux_sym_record_expression_repeat1,
    STATE(15965), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696928] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18841), 1,
      anon_sym_RBRACE,
    ACTIONS(22025), 1,
      anon_sym_SEMI,
    STATE(15966), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696948] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19744), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15967), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696968] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22027), 1,
      anon_sym_RPAREN,
    STATE(15968), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696988] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22029), 1,
      anon_sym_SEMI,
    ACTIONS(22031), 1,
      anon_sym_RBRACE,
    STATE(15587), 1,
      aux_sym_record_declaration_repeat1,
    STATE(15969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697008] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(22033), 1,
      anon_sym_RPAREN,
    STATE(15970), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697028] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14791), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15971), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697048] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8712), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22035), 1,
      anon_sym_SEMI,
    STATE(15972), 1,
      sym_attribute,
    STATE(16271), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697068] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22037), 1,
      anon_sym_RPAREN,
    STATE(15973), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697088] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18446), 1,
      anon_sym_RBRACE,
    ACTIONS(22039), 1,
      anon_sym_SEMI,
    STATE(15974), 1,
      sym_attribute,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697108] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22041), 1,
      anon_sym_LPAREN,
    ACTIONS(22043), 1,
      anon_sym_LBRACK,
    ACTIONS(22045), 1,
      anon_sym_LBRACE,
    STATE(15975), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697128] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22047), 1,
      anon_sym_LPAREN,
    ACTIONS(22049), 1,
      anon_sym_LBRACK,
    ACTIONS(22051), 1,
      anon_sym_LBRACE,
    STATE(15976), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697148] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14792), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15977), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697168] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(22053), 1,
      sym__lowercase_identifier,
    STATE(15978), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697188] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15233), 1,
      sym_attribute_id,
    STATE(15979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [697206] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22055), 1,
      anon_sym_LPAREN,
    ACTIONS(22057), 1,
      anon_sym_LBRACK,
    ACTIONS(22059), 1,
      anon_sym_LBRACE,
    STATE(15980), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697226] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22061), 1,
      anon_sym_RPAREN,
    STATE(15981), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697246] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(22063), 1,
      sym__lowercase_identifier,
    STATE(15982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697266] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19728), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15983), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697286] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22065), 1,
      anon_sym_LPAREN,
    ACTIONS(22067), 1,
      anon_sym_LBRACK,
    ACTIONS(22069), 1,
      anon_sym_LBRACE,
    STATE(15984), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697306] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22071), 1,
      aux_sym_quoted_extension_token1,
    STATE(15985), 1,
      sym_attribute,
    STATE(18689), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697326] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22073), 1,
      anon_sym_RPAREN,
    STATE(15986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697346] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(4), 1,
      sym_attribute_id,
    STATE(15987), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [697364] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19718), 1,
      anon_sym_RBRACK,
    STATE(15833), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697384] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19718), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15989), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697404] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18851), 1,
      anon_sym_RBRACE,
    ACTIONS(22075), 1,
      anon_sym_SEMI,
    STATE(15966), 1,
      aux_sym_record_expression_repeat1,
    STATE(15990), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697424] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22077), 1,
      anon_sym_RPAREN,
    STATE(15991), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697444] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(22079), 1,
      anon_sym_RPAREN,
    STATE(15992), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697464] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22081), 1,
      anon_sym_SEMI,
    ACTIONS(22083), 1,
      anon_sym_RBRACE,
    STATE(15993), 1,
      sym_attribute,
    STATE(16162), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697484] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17708), 1,
      anon_sym_SEMI,
    ACTIONS(17710), 1,
      anon_sym_GT,
    STATE(15994), 1,
      sym_attribute,
    STATE(15998), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697504] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18480), 1,
      anon_sym_RBRACE,
    ACTIONS(22085), 1,
      anon_sym_SEMI,
    STATE(15949), 1,
      aux_sym_record_expression_repeat1,
    STATE(15995), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697524] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14761), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15996), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697544] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22087), 1,
      anon_sym_SEMI,
    ACTIONS(22090), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(15997), 2,
      sym_attribute,
      aux_sym_record_expression_repeat1,
  [697562] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11610), 1,
      anon_sym_GT,
    ACTIONS(22092), 1,
      anon_sym_SEMI,
    STATE(15334), 1,
      aux_sym_object_type_repeat1,
    STATE(15998), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697582] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18855), 1,
      anon_sym_RBRACE,
    ACTIONS(22094), 1,
      anon_sym_SEMI,
    STATE(15682), 1,
      aux_sym_record_expression_repeat1,
    STATE(15999), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697602] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19697), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22096), 1,
      anon_sym_SEMI,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16000), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697622] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14003), 1,
      anon_sym_and,
    STATE(16001), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14001), 2,
      anon_sym_in,
      sym_let_and_operator,
  [697640] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22098), 1,
      sym__lowercase_identifier,
    ACTIONS(22100), 1,
      anon_sym_LPAREN,
    STATE(7763), 1,
      sym__simple_value_pattern,
    STATE(16002), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697660] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16), 1,
      sym_attribute_id,
    STATE(16003), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [697678] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14970), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16004), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697698] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3655), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22102), 1,
      anon_sym_SEMI,
    STATE(16005), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697718] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14767), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16006), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697738] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19691), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16007), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697758] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(16008), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12343), 3,
      anon_sym_and,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [697774] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19691), 1,
      anon_sym_RBRACK,
    STATE(15967), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16009), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697794] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11730), 1,
      anon_sym_GT,
    ACTIONS(22104), 1,
      anon_sym_SEMI,
    STATE(15334), 1,
      aux_sym_object_type_repeat1,
    STATE(16010), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697814] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(22106), 1,
      anon_sym_RPAREN,
    STATE(16011), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697834] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22108), 1,
      anon_sym_RPAREN,
    STATE(16012), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697854] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22110), 1,
      aux_sym_quoted_extension_token1,
    STATE(16013), 1,
      sym_attribute,
    STATE(17763), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697874] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22112), 1,
      anon_sym_SEMI,
    ACTIONS(22114), 1,
      anon_sym_GT_RBRACE,
    STATE(16014), 1,
      sym_attribute,
    STATE(16184), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697894] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15985), 1,
      sym_attribute_id,
    STATE(16015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [697912] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19754), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22116), 1,
      anon_sym_SEMI,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16016), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697932] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22118), 1,
      anon_sym_SEMI,
    ACTIONS(22120), 1,
      anon_sym_RBRACE,
    STATE(16017), 1,
      sym_attribute,
    STATE(16156), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697952] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19687), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22122), 1,
      anon_sym_SEMI,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697972] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18786), 1,
      anon_sym_RBRACE,
    ACTIONS(22124), 1,
      anon_sym_SEMI,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    STATE(16019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697992] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22126), 1,
      anon_sym_LPAREN,
    ACTIONS(22128), 1,
      anon_sym_LBRACK,
    ACTIONS(22130), 1,
      anon_sym_LBRACE,
    STATE(16020), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698012] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19595), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16021), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698032] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22132), 1,
      anon_sym_LPAREN,
    ACTIONS(22134), 1,
      anon_sym_LBRACK,
    ACTIONS(22136), 1,
      anon_sym_LBRACE,
    STATE(16022), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698052] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19683), 1,
      anon_sym_RBRACK,
    STATE(15719), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16023), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698072] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22138), 1,
      anon_sym_LPAREN,
    ACTIONS(22140), 1,
      anon_sym_LBRACK,
    ACTIONS(22142), 1,
      anon_sym_LBRACE,
    STATE(16024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698092] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3649), 1,
      anon_sym_RBRACK,
    ACTIONS(22144), 1,
      anon_sym_SEMI,
    STATE(16025), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698112] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    ACTIONS(22146), 1,
      anon_sym_RBRACK,
    STATE(15251), 1,
      aux_sym__type_params_repeat1,
    STATE(16026), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698132] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3297), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22148), 1,
      anon_sym_SEMI,
    STATE(16027), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698152] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18452), 1,
      anon_sym_RBRACE,
    ACTIONS(22150), 1,
      anon_sym_SEMI,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    STATE(16028), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698172] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(22152), 1,
      anon_sym_RPAREN,
    STATE(16029), 1,
      sym_attribute,
    STATE(19890), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698192] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19683), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16030), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698212] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22154), 1,
      anon_sym_SEMI,
    ACTIONS(22156), 1,
      anon_sym_RBRACE,
    STATE(16031), 1,
      sym_attribute,
    STATE(16084), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698232] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(39), 1,
      sym_attribute_id,
    STATE(16032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [698250] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14802), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16033), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698270] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(11451), 1,
      sym_module_binding,
    STATE(16034), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17935), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [698288] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20715), 1,
      anon_sym_COLON2,
    ACTIONS(22158), 1,
      anon_sym_RPAREN,
    STATE(16035), 1,
      sym_attribute,
    STATE(19533), 1,
      sym__class_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698308] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10253), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    STATE(16007), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16036), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698328] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22160), 1,
      anon_sym_SEMI,
    ACTIONS(22162), 1,
      anon_sym_GT_RBRACE,
    STATE(16000), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698348] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3295), 1,
      anon_sym_RBRACK,
    ACTIONS(22164), 1,
      anon_sym_SEMI,
    STATE(16038), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698368] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14813), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16039), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698388] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22166), 1,
      anon_sym_EQ,
    STATE(16040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698408] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18774), 1,
      anon_sym_RBRACE,
    ACTIONS(22168), 1,
      anon_sym_SEMI,
    STATE(15370), 1,
      aux_sym_record_expression_repeat1,
    STATE(16041), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698428] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22170), 1,
      anon_sym_LPAREN,
    ACTIONS(22172), 1,
      anon_sym_LBRACK,
    ACTIONS(22174), 1,
      anon_sym_LBRACE,
    STATE(16042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698448] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(22176), 1,
      anon_sym_RPAREN,
    STATE(16043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698468] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22178), 1,
      anon_sym_SEMI,
    ACTIONS(22180), 1,
      anon_sym_GT_RBRACE,
    STATE(16018), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698488] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22182), 1,
      anon_sym_SEMI,
    ACTIONS(22184), 1,
      anon_sym_RBRACE,
    STATE(16045), 1,
      sym_attribute,
    STATE(16197), 1,
      aux_sym_record_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698508] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(22186), 1,
      anon_sym_RPAREN,
    STATE(16046), 1,
      sym_attribute,
    STATE(19514), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698528] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14776), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16047), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698548] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22188), 1,
      anon_sym_EQ,
    STATE(16048), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698568] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(28), 1,
      sym_attribute_id,
    STATE(16049), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [698586] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22190), 1,
      anon_sym_LPAREN,
    ACTIONS(22192), 1,
      anon_sym_LBRACK,
    ACTIONS(22194), 1,
      anon_sym_LBRACE,
    STATE(16050), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698606] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22196), 1,
      anon_sym_SEMI,
    ACTIONS(22198), 1,
      anon_sym_RBRACE,
    STATE(16028), 1,
      aux_sym_record_expression_repeat1,
    STATE(16051), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698626] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(22200), 1,
      anon_sym_RBRACK,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16052), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698646] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(22202), 1,
      anon_sym_RPAREN,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16053), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698666] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12648), 1,
      sym_module_binding,
    STATE(16054), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17935), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [698684] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10571), 1,
      sym__type_equation,
    STATE(16055), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22204), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [698702] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22206), 1,
      anon_sym_SEMI,
    ACTIONS(22208), 1,
      anon_sym_RBRACE,
    STATE(16056), 1,
      sym_attribute,
    STATE(16223), 1,
      aux_sym_record_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698722] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22210), 1,
      anon_sym_SEMI,
    ACTIONS(22212), 1,
      anon_sym_RBRACE,
    STATE(16019), 1,
      aux_sym_record_expression_repeat1,
    STATE(16057), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698742] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22214), 1,
      anon_sym_SEMI,
    ACTIONS(22216), 1,
      anon_sym_GT_RBRACE,
    STATE(16058), 1,
      sym_attribute,
    STATE(16177), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698762] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(22218), 1,
      anon_sym_RPAREN,
    STATE(16059), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698782] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15640), 1,
      sym_attribute_id,
    STATE(16060), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [698800] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15097), 1,
      sym_attribute_id,
    STATE(16061), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [698818] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22220), 1,
      anon_sym_LPAREN,
    ACTIONS(22222), 1,
      anon_sym_LBRACK,
    ACTIONS(22224), 1,
      anon_sym_LBRACE,
    STATE(16062), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698838] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14719), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16063), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698858] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22226), 1,
      aux_sym_quoted_extension_token1,
    STATE(16064), 1,
      sym_attribute,
    STATE(17697), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698878] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(22228), 1,
      anon_sym_RPAREN,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16065), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698898] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22230), 1,
      aux_sym_quoted_extension_token1,
    STATE(16066), 1,
      sym_attribute,
    STATE(19154), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698918] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16067), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13277), 3,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
  [698934] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15945), 1,
      sym_attribute_id,
    STATE(16068), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [698952] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22232), 1,
      anon_sym_EQ,
    STATE(16069), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698972] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22234), 1,
      anon_sym_SEMI,
    ACTIONS(22236), 1,
      anon_sym_GT_RBRACE,
    STATE(16070), 1,
      sym_attribute,
    STATE(16117), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698992] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17084), 1,
      sym__uppercase_identifier,
    ACTIONS(18879), 1,
      anon_sym_LPAREN,
    STATE(8936), 1,
      sym__constructor_name,
    STATE(16071), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699012] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15206), 1,
      sym_attribute_id,
    STATE(16072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [699030] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22238), 1,
      anon_sym_LPAREN,
    ACTIONS(22240), 1,
      anon_sym_LBRACK,
    ACTIONS(22242), 1,
      anon_sym_LBRACE,
    STATE(16073), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699050] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(22244), 1,
      sym__lowercase_identifier,
    STATE(16074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699070] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22246), 1,
      anon_sym_LPAREN,
    ACTIONS(22248), 1,
      anon_sym_LBRACK,
    ACTIONS(22250), 1,
      anon_sym_LBRACE,
    STATE(16075), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699090] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    ACTIONS(22252), 1,
      anon_sym_RBRACK,
    STATE(14713), 1,
      aux_sym__type_params_repeat1,
    STATE(16076), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699110] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10643), 1,
      sym__type_equation,
    STATE(16077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22204), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [699128] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16078), 1,
      sym_attribute,
    STATE(16125), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [699146] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22254), 1,
      anon_sym_RPAREN,
    STATE(16079), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699166] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12085), 1,
      anon_sym_DASH_GT,
    ACTIONS(22256), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(16080), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
  [699184] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22259), 1,
      aux_sym_quoted_extension_token1,
    STATE(16081), 1,
      sym_attribute,
    STATE(20413), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699204] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3549), 1,
      anon_sym_RBRACK,
    ACTIONS(22261), 1,
      anon_sym_SEMI,
    STATE(16082), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699224] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22263), 1,
      anon_sym_LPAREN,
    ACTIONS(22265), 1,
      anon_sym_LBRACK,
    ACTIONS(22267), 1,
      anon_sym_LBRACE,
    STATE(16083), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699244] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18732), 1,
      anon_sym_RBRACE,
    ACTIONS(22269), 1,
      anon_sym_SEMI,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    STATE(16084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699264] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(22271), 1,
      anon_sym_RPAREN,
    STATE(16085), 1,
      sym_attribute,
    STATE(18841), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699284] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10817), 1,
      sym_attribute_id,
    STATE(16086), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22273), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [699302] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19394), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16087), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699322] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19629), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16088), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699342] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11813), 1,
      anon_sym_GT,
    ACTIONS(22275), 1,
      anon_sym_SEMI,
    STATE(15334), 1,
      aux_sym_object_type_repeat1,
    STATE(16089), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699362] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16090), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13102), 3,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
  [699378] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3551), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22277), 1,
      anon_sym_SEMI,
    STATE(16091), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699398] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3949), 1,
      anon_sym_RBRACK,
    ACTIONS(22279), 1,
      anon_sym_SEMI,
    STATE(16092), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699418] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16093), 1,
      sym_attribute,
    STATE(16455), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [699436] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19623), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16094), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699456] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16095), 1,
      sym_attribute,
    STATE(16233), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [699474] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19974), 1,
      sym__lowercase_identifier,
    ACTIONS(19978), 1,
      anon_sym_mutable,
    STATE(16096), 1,
      sym_attribute,
    STATE(16635), 1,
      sym_field_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699494] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18662), 1,
      anon_sym_RBRACE,
    ACTIONS(22281), 1,
      anon_sym_SEMI,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    STATE(16097), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699514] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12579), 1,
      sym_module_binding,
    STATE(16098), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17759), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [699532] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22283), 1,
      anon_sym_LPAREN,
    ACTIONS(22285), 1,
      anon_sym_LBRACK,
    ACTIONS(22287), 1,
      anon_sym_LBRACE,
    STATE(16099), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699552] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22289), 1,
      anon_sym_RPAREN,
    STATE(16100), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699572] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15232), 1,
      sym_attribute_id,
    STATE(16101), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [699590] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18664), 1,
      anon_sym_RBRACE,
    ACTIONS(22291), 1,
      anon_sym_SEMI,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    STATE(16102), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699610] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    ACTIONS(22293), 1,
      anon_sym_RBRACK,
    STATE(16076), 1,
      aux_sym__type_params_repeat1,
    STATE(16103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699630] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    ACTIONS(22293), 1,
      anon_sym_RBRACK,
    STATE(14713), 1,
      aux_sym__type_params_repeat1,
    STATE(16104), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699650] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18714), 1,
      anon_sym_RBRACE,
    ACTIONS(22295), 1,
      anon_sym_SEMI,
    STATE(15884), 1,
      aux_sym_record_expression_repeat1,
    STATE(16105), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699670] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(11451), 1,
      sym_module_binding,
    STATE(16106), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17759), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [699688] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22297), 1,
      anon_sym_RPAREN,
    STATE(16107), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699708] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22299), 1,
      anon_sym_EQ,
    STATE(16108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699728] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(22301), 1,
      sym__lowercase_identifier,
    STATE(16109), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699748] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22303), 1,
      anon_sym_LPAREN,
    ACTIONS(22305), 1,
      anon_sym_LBRACK,
    ACTIONS(22307), 1,
      anon_sym_LBRACE,
    STATE(16110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699768] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19609), 1,
      anon_sym_RBRACK,
    STATE(16094), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16111), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699788] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11821), 1,
      anon_sym_GT,
    ACTIONS(22309), 1,
      anon_sym_SEMI,
    STATE(15334), 1,
      aux_sym_object_type_repeat1,
    STATE(16112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699808] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19609), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699828] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(22311), 1,
      anon_sym_RPAREN,
    STATE(16114), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699848] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19541), 1,
      anon_sym_RBRACK,
    STATE(15989), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699868] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22313), 1,
      anon_sym_RPAREN,
    STATE(16116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699888] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19603), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22315), 1,
      anon_sym_SEMI,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16117), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699908] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19595), 1,
      anon_sym_RBRACK,
    STATE(16088), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16118), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699928] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(14935), 1,
      aux_sym_module_binding_repeat1,
    STATE(16119), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699948] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(87), 1,
      sym_attribute_id,
    STATE(16120), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [699966] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(43), 1,
      sym_attribute_id,
    STATE(16121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [699984] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22317), 1,
      anon_sym_RPAREN,
    STATE(16122), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700004] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    ACTIONS(22319), 1,
      anon_sym_RPAREN,
    STATE(15539), 1,
      aux_sym__type_params_repeat1,
    STATE(16123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700024] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(22321), 1,
      sym__lowercase_identifier,
    STATE(16124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700044] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22323), 1,
      aux_sym_quoted_extension_token1,
    STATE(16125), 1,
      sym_attribute,
    STATE(17643), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700064] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18630), 1,
      anon_sym_RBRACE,
    ACTIONS(22325), 1,
      anon_sym_SEMI,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    STATE(16126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700084] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22327), 1,
      aux_sym_quoted_extension_token1,
    STATE(16127), 1,
      sym_attribute,
    STATE(18401), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700104] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12382), 1,
      anon_sym_RPAREN,
    STATE(16128), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22329), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [700122] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(22331), 1,
      anon_sym_RPAREN,
    STATE(16129), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700142] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18680), 1,
      anon_sym_RBRACE,
    ACTIONS(22333), 1,
      anon_sym_SEMI,
    STATE(16097), 1,
      aux_sym_record_expression_repeat1,
    STATE(16130), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700162] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11520), 1,
      anon_sym_GT,
    ACTIONS(22335), 1,
      anon_sym_SEMI,
    STATE(15334), 1,
      aux_sym_object_type_repeat1,
    STATE(16131), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700182] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(34), 1,
      sym_attribute_id,
    STATE(16132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [700200] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19591), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16133), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700220] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22337), 1,
      anon_sym_RPAREN,
    STATE(16134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700240] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18682), 1,
      anon_sym_RBRACE,
    ACTIONS(22339), 1,
      anon_sym_SEMI,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    STATE(16135), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700260] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19583), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700280] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(22341), 1,
      anon_sym_RPAREN,
    STATE(16137), 1,
      sym_attribute,
    STATE(19267), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700300] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22343), 1,
      anon_sym_RPAREN,
    STATE(16138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700320] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22345), 1,
      aux_sym_quoted_extension_token1,
    STATE(16139), 1,
      sym_attribute,
    STATE(20090), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700340] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19583), 1,
      anon_sym_RBRACK,
    STATE(16113), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700360] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    ACTIONS(22347), 1,
      anon_sym_RBRACK,
    STATE(16141), 1,
      sym_attribute,
    STATE(16186), 1,
      aux_sym__type_params_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700380] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(22349), 1,
      anon_sym_RPAREN,
    STATE(16142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700400] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22351), 1,
      anon_sym_LPAREN,
    ACTIONS(22353), 1,
      anon_sym_LBRACK,
    ACTIONS(22355), 1,
      anon_sym_LBRACE,
    STATE(16143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700420] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22357), 1,
      aux_sym_quoted_extension_token1,
    STATE(16144), 1,
      sym_attribute,
    STATE(17773), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700440] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17575), 1,
      anon_sym_SEMI,
    ACTIONS(17577), 1,
      anon_sym_GT,
    STATE(16145), 1,
      sym_attribute,
    STATE(16251), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700460] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9886), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    STATE(16146), 1,
      sym_attribute,
    STATE(16295), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700480] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19579), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22359), 1,
      anon_sym_SEMI,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700500] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22361), 1,
      anon_sym_RPAREN,
    STATE(16148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700520] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3383), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22363), 1,
      anon_sym_SEMI,
    STATE(16149), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700540] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18708), 1,
      anon_sym_RBRACE,
    ACTIONS(22365), 1,
      anon_sym_SEMI,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    STATE(16150), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700560] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17543), 1,
      anon_sym_SEMI,
    ACTIONS(17545), 1,
      anon_sym_GT,
    STATE(16131), 1,
      aux_sym_object_type_repeat1,
    STATE(16151), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700580] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18674), 1,
      anon_sym_RBRACE,
    ACTIONS(22367), 1,
      anon_sym_SEMI,
    STATE(16126), 1,
      aux_sym_record_expression_repeat1,
    STATE(16152), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700600] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9888), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    STATE(16136), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16153), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700620] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(22369), 1,
      sym__lowercase_identifier,
    STATE(16154), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700640] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3397), 1,
      anon_sym_RBRACK,
    ACTIONS(22371), 1,
      anon_sym_SEMI,
    STATE(16155), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700660] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18704), 1,
      anon_sym_RBRACE,
    ACTIONS(22373), 1,
      anon_sym_SEMI,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    STATE(16156), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700680] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15188), 1,
      sym_attribute_id,
    STATE(16157), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [700698] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17587), 1,
      anon_sym_SEMI,
    ACTIONS(17589), 1,
      anon_sym_GT,
    STATE(16158), 1,
      sym_attribute,
    STATE(16303), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700718] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(58), 1,
      sym_attribute_id,
    STATE(16159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [700736] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22375), 1,
      anon_sym_SEMI,
    ACTIONS(22377), 1,
      anon_sym_GT_RBRACE,
    STATE(16147), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700756] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22379), 1,
      anon_sym_LPAREN,
    ACTIONS(22381), 1,
      anon_sym_LBRACK,
    ACTIONS(22383), 1,
      anon_sym_LBRACE,
    STATE(16161), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700776] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18716), 1,
      anon_sym_RBRACE,
    ACTIONS(22385), 1,
      anon_sym_SEMI,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    STATE(16162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700796] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22387), 1,
      anon_sym_LPAREN,
    ACTIONS(22389), 1,
      anon_sym_LBRACK,
    ACTIONS(22391), 1,
      anon_sym_LBRACE,
    STATE(16163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700816] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19573), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700836] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3599), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22393), 1,
      anon_sym_SEMI,
    STATE(16165), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700856] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3935), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22395), 1,
      anon_sym_SEMI,
    STATE(16166), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700876] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18684), 1,
      anon_sym_RBRACE,
    ACTIONS(22397), 1,
      anon_sym_SEMI,
    STATE(15960), 1,
      aux_sym_record_expression_repeat1,
    STATE(16167), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700896] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22399), 1,
      anon_sym_SEMI,
    ACTIONS(22401), 1,
      anon_sym_RBRACE,
    STATE(16150), 1,
      aux_sym_record_expression_repeat1,
    STATE(16168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700916] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(22403), 1,
      sym__lowercase_identifier,
    STATE(16169), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700936] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22405), 1,
      aux_sym_quoted_extension_token1,
    STATE(16170), 1,
      sym_attribute,
    STATE(17600), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700956] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22407), 1,
      sym__lowercase_identifier,
    ACTIONS(22409), 1,
      anon_sym_LPAREN,
    STATE(7563), 1,
      sym__simple_value_pattern,
    STATE(16171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700976] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22411), 1,
      anon_sym_LPAREN,
    ACTIONS(22413), 1,
      anon_sym_LBRACK,
    ACTIONS(22415), 1,
      anon_sym_LBRACE,
    STATE(16172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700996] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19573), 1,
      anon_sym_RBRACK,
    STATE(15932), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701016] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11424), 1,
      anon_sym_GT,
    ACTIONS(22417), 1,
      anon_sym_SEMI,
    STATE(15334), 1,
      aux_sym_object_type_repeat1,
    STATE(16174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701036] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16145), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22419), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(16175), 2,
      sym_attribute,
      aux_sym_list_expression_repeat1,
  [701054] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18666), 1,
      anon_sym_RBRACE,
    ACTIONS(22422), 1,
      anon_sym_SEMI,
    STATE(16135), 1,
      aux_sym_record_expression_repeat1,
    STATE(16176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701074] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19563), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22424), 1,
      anon_sym_SEMI,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16177), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701094] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19974), 1,
      sym__lowercase_identifier,
    ACTIONS(19978), 1,
      anon_sym_mutable,
    STATE(15262), 1,
      sym_field_declaration,
    STATE(16178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701114] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22426), 1,
      anon_sym_EQ,
    STATE(16179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701134] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22428), 1,
      anon_sym_RPAREN,
    STATE(16180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701154] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(22430), 1,
      anon_sym_RPAREN,
    STATE(16181), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701174] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    ACTIONS(22432), 1,
      anon_sym_RBRACK,
    STATE(16104), 1,
      aux_sym__type_params_repeat1,
    STATE(16182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701194] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22434), 1,
      aux_sym_quoted_extension_token1,
    STATE(16183), 1,
      sym_attribute,
    STATE(19954), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701214] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19551), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22436), 1,
      anon_sym_SEMI,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16184), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701234] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(22438), 1,
      anon_sym_type,
    STATE(15240), 1,
      sym_module_path,
    STATE(16185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701254] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    ACTIONS(22440), 1,
      anon_sym_RBRACK,
    STATE(14713), 1,
      aux_sym__type_params_repeat1,
    STATE(16186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701274] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    ACTIONS(22440), 1,
      anon_sym_RBRACK,
    STATE(16187), 1,
      sym_attribute,
    STATE(16236), 1,
      aux_sym__type_params_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701294] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16188), 1,
      sym_attribute,
    STATE(16370), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [701312] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22442), 1,
      anon_sym_LPAREN,
    ACTIONS(22444), 1,
      anon_sym_LBRACK,
    ACTIONS(22446), 1,
      anon_sym_LBRACE,
    STATE(16189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701332] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(54), 1,
      sym_attribute_id,
    STATE(16190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [701350] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20715), 1,
      anon_sym_COLON2,
    ACTIONS(22448), 1,
      anon_sym_RPAREN,
    STATE(16191), 1,
      sym_attribute,
    STATE(19651), 1,
      sym__class_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701370] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(22450), 1,
      anon_sym_RPAREN,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16192), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701390] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(22452), 1,
      anon_sym_RPAREN,
    STATE(16193), 1,
      sym_attribute,
    STATE(19644), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701410] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19533), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22454), 1,
      anon_sym_SEMI,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16194), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701430] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22456), 1,
      anon_sym_LPAREN,
    ACTIONS(22458), 1,
      anon_sym_LBRACK,
    ACTIONS(22460), 1,
      anon_sym_LBRACE,
    STATE(16195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701450] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8256), 1,
      anon_sym_RBRACK,
    ACTIONS(22462), 1,
      anon_sym_SEMI,
    STATE(15163), 1,
      aux_sym_list_pattern_repeat1,
    STATE(16196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701470] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18097), 1,
      anon_sym_RBRACE,
    ACTIONS(22464), 1,
      anon_sym_SEMI,
    STATE(15124), 1,
      aux_sym_record_pattern_repeat1,
    STATE(16197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701490] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18742), 1,
      anon_sym_RBRACE,
    ACTIONS(22466), 1,
      anon_sym_SEMI,
    STATE(16102), 1,
      aux_sym_record_expression_repeat1,
    STATE(16198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701510] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22468), 1,
      anon_sym_SEMI,
    ACTIONS(22470), 1,
      anon_sym_RBRACE,
    STATE(16199), 1,
      sym_attribute,
    STATE(16335), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701530] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11702), 1,
      anon_sym_GT,
    ACTIONS(22472), 1,
      anon_sym_SEMI,
    STATE(15334), 1,
      aux_sym_object_type_repeat1,
    STATE(16200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701550] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15), 1,
      sym_attribute_id,
    STATE(16201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [701568] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8206), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22474), 1,
      anon_sym_SEMI,
    STATE(16202), 1,
      sym_attribute,
    STATE(16269), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701588] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15016), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16203), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701608] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22476), 1,
      anon_sym_SEMI,
    ACTIONS(22478), 1,
      anon_sym_RBRACE,
    STATE(16204), 1,
      sym_attribute,
    STATE(16505), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701628] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15365), 1,
      sym_attribute_id,
    STATE(16205), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [701646] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16206), 1,
      sym_attribute,
    STATE(16430), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [701664] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19525), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701684] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19525), 1,
      anon_sym_RBRACK,
    STATE(16021), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16208), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701704] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(22480), 1,
      anon_sym_RPAREN,
    STATE(16209), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701724] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8694), 1,
      anon_sym_RBRACK,
    ACTIONS(22482), 1,
      anon_sym_SEMI,
    STATE(15168), 1,
      aux_sym_list_binding_pattern_repeat1,
    STATE(16210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701744] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22484), 1,
      anon_sym_RPAREN,
    STATE(16211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701764] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19541), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16212), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701784] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3639), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22486), 1,
      anon_sym_SEMI,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    STATE(16213), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701804] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(22488), 1,
      anon_sym_RPAREN,
    STATE(16214), 1,
      sym_attribute,
    STATE(19276), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701824] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(22490), 1,
      anon_sym_RPAREN,
    STATE(16215), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701844] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22492), 1,
      anon_sym_RPAREN,
    STATE(16216), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701864] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3601), 1,
      anon_sym_RBRACK,
    ACTIONS(22494), 1,
      anon_sym_SEMI,
    STATE(16217), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701884] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22496), 1,
      anon_sym_EQ,
    STATE(16218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701904] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9970), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    STATE(16219), 1,
      sym_attribute,
    STATE(16234), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701924] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22498), 1,
      anon_sym_RPAREN,
    STATE(16220), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701944] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13), 1,
      sym_attribute_id,
    STATE(16221), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [701962] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(21), 1,
      sym_attribute_id,
    STATE(16222), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [701980] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18073), 1,
      anon_sym_RBRACE,
    ACTIONS(22500), 1,
      anon_sym_SEMI,
    STATE(15175), 1,
      aux_sym_record_binding_pattern_repeat1,
    STATE(16223), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702000] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(22502), 1,
      anon_sym_RPAREN,
    STATE(16224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702020] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19511), 1,
      anon_sym_RBRACK,
    STATE(16225), 1,
      sym_attribute,
    STATE(16372), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702040] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8700), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22504), 1,
      anon_sym_SEMI,
    STATE(16226), 1,
      sym_attribute,
    STATE(16271), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702060] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(37), 1,
      sym_attribute_id,
    STATE(16227), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [702078] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18650), 1,
      anon_sym_RBRACE,
    ACTIONS(22506), 1,
      anon_sym_SEMI,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    STATE(16228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702098] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(22508), 1,
      sym__lowercase_identifier,
    STATE(16229), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702118] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19517), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702138] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3637), 1,
      anon_sym_RBRACK,
    ACTIONS(22510), 1,
      anon_sym_SEMI,
    STATE(16231), 1,
      sym_attribute,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702158] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13426), 1,
      sym__type_equation,
    STATE(16232), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22512), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [702176] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22514), 1,
      aux_sym_quoted_extension_token1,
    STATE(16233), 1,
      sym_attribute,
    STATE(18778), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702196] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19511), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16234), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702216] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    ACTIONS(22516), 1,
      anon_sym__,
    STATE(14324), 1,
      sym_type_variable,
    STATE(16235), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702236] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    ACTIONS(22518), 1,
      anon_sym_RBRACK,
    STATE(14713), 1,
      aux_sym__type_params_repeat1,
    STATE(16236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702256] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(88), 1,
      sym_attribute_id,
    STATE(16237), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [702274] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19591), 1,
      anon_sym_RBRACK,
    STATE(15269), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16238), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702294] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(10242), 1,
      sym__type_equation,
    STATE(16239), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20731), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [702312] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22520), 1,
      anon_sym_SEMI,
    ACTIONS(22522), 1,
      anon_sym_GT_RBRACE,
    STATE(16240), 1,
      sym_attribute,
    STATE(16355), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702332] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18792), 1,
      anon_sym_RBRACE,
    ACTIONS(22524), 1,
      anon_sym_SEMI,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    STATE(16241), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702352] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22526), 1,
      anon_sym_RPAREN,
    STATE(16242), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702372] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22528), 1,
      anon_sym_EQ,
    STATE(16243), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702392] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22530), 1,
      anon_sym_RPAREN,
    STATE(16244), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702412] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10987), 1,
      anon_sym_DOT,
    STATE(16245), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22532), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [702430] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19507), 1,
      anon_sym_RBRACK,
    STATE(16230), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16246), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702450] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19507), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16247), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702470] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(22534), 1,
      anon_sym_RPAREN,
    STATE(16248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702490] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22536), 1,
      anon_sym_RPAREN,
    STATE(16249), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702510] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(22538), 1,
      sym__lowercase_identifier,
    STATE(16250), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702530] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11582), 1,
      anon_sym_GT,
    ACTIONS(22540), 1,
      anon_sym_SEMI,
    STATE(15334), 1,
      aux_sym_object_type_repeat1,
    STATE(16251), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702550] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(22542), 1,
      anon_sym_RPAREN,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16252), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702570] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(22544), 1,
      anon_sym_RPAREN,
    STATE(16253), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702590] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15038), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16254), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702610] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(22546), 1,
      anon_sym_RPAREN,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16255), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702630] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15033), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16256), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702650] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18812), 1,
      anon_sym_RBRACE,
    ACTIONS(22548), 1,
      anon_sym_SEMI,
    STATE(16257), 1,
      sym_attribute,
    STATE(16456), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702670] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18832), 1,
      anon_sym_RBRACE,
    ACTIONS(22550), 1,
      anon_sym_SEMI,
    STATE(16241), 1,
      aux_sym_record_expression_repeat1,
    STATE(16258), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702690] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15042), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16259), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702710] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22552), 1,
      aux_sym_quoted_extension_token1,
    STATE(16260), 1,
      sym_attribute,
    STATE(19168), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702730] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11452), 1,
      anon_sym_GT,
    ACTIONS(22554), 1,
      anon_sym_SEMI,
    STATE(15334), 1,
      aux_sym_object_type_repeat1,
    STATE(16261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702750] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22556), 1,
      anon_sym_RPAREN,
    STATE(16262), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702770] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(13434), 1,
      sym__type_equation,
    STATE(16263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22512), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [702788] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9974), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    STATE(16264), 1,
      sym_attribute,
    STATE(16411), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702808] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22558), 1,
      anon_sym_SEMI,
    ACTIONS(22560), 1,
      anon_sym_GT_RBRACE,
    STATE(16194), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16265), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702828] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19497), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22562), 1,
      anon_sym_SEMI,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16266), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702848] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(22564), 1,
      anon_sym_RBRACK,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702868] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3583), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22566), 1,
      anon_sym_SEMI,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    STATE(16268), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702888] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18424), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22568), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(16269), 2,
      sym_attribute,
      aux_sym_list_pattern_repeat1,
  [702906] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(41), 1,
      sym_attribute_id,
    STATE(16270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [702924] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18498), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22571), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(16271), 2,
      sym_attribute,
      aux_sym_list_binding_pattern_repeat1,
  [702942] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22574), 1,
      anon_sym_EQ,
    STATE(16272), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702962] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22576), 1,
      anon_sym_RPAREN,
    STATE(16273), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702982] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22578), 1,
      anon_sym_SEMI,
    ACTIONS(22580), 1,
      anon_sym_GT_RBRACE,
    STATE(16274), 1,
      sym_attribute,
    STATE(16469), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703002] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14994), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16275), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703022] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19491), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703042] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19491), 1,
      anon_sym_RBRACK,
    STATE(16247), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16277), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703062] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12048), 1,
      sym_module_binding,
    STATE(16278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18041), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [703080] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19487), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22582), 1,
      anon_sym_SEMI,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16279), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703100] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14898), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16280), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703120] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14870), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16281), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703140] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(22584), 1,
      anon_sym_RPAREN,
    STATE(16282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703160] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22586), 1,
      anon_sym_RPAREN,
    STATE(16283), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703180] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(22588), 1,
      anon_sym_RPAREN,
    STATE(16284), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703200] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22590), 1,
      anon_sym_SEMI,
    ACTIONS(22592), 1,
      anon_sym_RBRACE,
    STATE(16228), 1,
      aux_sym_record_expression_repeat1,
    STATE(16285), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703220] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22594), 1,
      anon_sym_EQ,
    STATE(16286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703240] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14948), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16287), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703260] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19473), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22596), 1,
      anon_sym_SEMI,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16288), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703280] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(61), 1,
      sym_attribute_id,
    STATE(16289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [703298] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22598), 1,
      anon_sym_SEMI,
    ACTIONS(22600), 1,
      anon_sym_RBRACE,
    STATE(16290), 1,
      sym_attribute,
    STATE(16385), 1,
      aux_sym_record_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703318] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3391), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22602), 1,
      anon_sym_SEMI,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    STATE(16291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703338] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(22604), 1,
      anon_sym_RPAREN,
    STATE(16292), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703358] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19465), 1,
      anon_sym_RBRACK,
    STATE(16293), 1,
      sym_attribute,
    STATE(16371), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703378] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    ACTIONS(22606), 1,
      anon_sym_RBRACK,
    STATE(14713), 1,
      aux_sym__type_params_repeat1,
    STATE(16294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703398] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19465), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703418] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18612), 1,
      anon_sym_RBRACE,
    ACTIONS(22608), 1,
      anon_sym_SEMI,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    STATE(16296), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703438] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3515), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22610), 1,
      anon_sym_SEMI,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    STATE(16297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703458] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    ACTIONS(22606), 1,
      anon_sym_RBRACK,
    STATE(15335), 1,
      aux_sym__type_params_repeat1,
    STATE(16298), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703478] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16145), 1,
      anon_sym_RBRACK,
    ACTIONS(22612), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(16299), 2,
      sym_attribute,
      aux_sym_list_expression_repeat1,
  [703496] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17499), 1,
      anon_sym_SEMI,
    ACTIONS(17501), 1,
      anon_sym_GT,
    STATE(16200), 1,
      aux_sym_object_type_repeat1,
    STATE(16300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703516] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18808), 1,
      anon_sym_RBRACE,
    ACTIONS(22615), 1,
      anon_sym_SEMI,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    STATE(16301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703536] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17645), 1,
      anon_sym_SEMI,
    ACTIONS(17647), 1,
      anon_sym_GT,
    STATE(16261), 1,
      aux_sym_object_type_repeat1,
    STATE(16302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703556] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11432), 1,
      anon_sym_GT,
    ACTIONS(22617), 1,
      anon_sym_SEMI,
    STATE(15334), 1,
      aux_sym_object_type_repeat1,
    STATE(16303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703576] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16304), 1,
      sym_attribute,
    STATE(16317), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [703594] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12028), 1,
      sym_module_binding,
    STATE(16305), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18003), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [703612] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9984), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    STATE(16207), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16306), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703632] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3577), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22619), 1,
      anon_sym_SEMI,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    STATE(16307), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703652] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9926), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    STATE(16276), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16308), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703672] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22621), 1,
      anon_sym_LPAREN,
    ACTIONS(22623), 1,
      anon_sym_LBRACK,
    ACTIONS(22625), 1,
      anon_sym_LBRACE,
    STATE(16309), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703692] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3393), 1,
      anon_sym_RBRACK,
    ACTIONS(22627), 1,
      anon_sym_SEMI,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    STATE(16310), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703712] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18784), 1,
      anon_sym_RBRACE,
    ACTIONS(22629), 1,
      anon_sym_SEMI,
    STATE(16311), 1,
      sym_attribute,
    STATE(16450), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703732] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3523), 1,
      anon_sym_RBRACK,
    ACTIONS(22631), 1,
      anon_sym_SEMI,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    STATE(16312), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703752] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(70), 1,
      sym_attribute_id,
    STATE(16313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [703770] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3423), 1,
      anon_sym_RBRACK,
    ACTIONS(22633), 1,
      anon_sym_SEMI,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    STATE(16314), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703790] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22635), 1,
      anon_sym_LPAREN,
    ACTIONS(22637), 1,
      anon_sym_LBRACK,
    ACTIONS(22639), 1,
      anon_sym_LBRACE,
    STATE(16315), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703810] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22641), 1,
      anon_sym_RPAREN,
    STATE(16316), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703830] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22643), 1,
      aux_sym_quoted_extension_token1,
    STATE(16317), 1,
      sym_attribute,
    STATE(17922), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703850] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22645), 1,
      anon_sym_SEMI,
    ACTIONS(22647), 1,
      anon_sym_GT_RBRACE,
    STATE(16288), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16318), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703870] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22649), 1,
      anon_sym_LPAREN,
    ACTIONS(22651), 1,
      anon_sym_LBRACK,
    ACTIONS(22653), 1,
      anon_sym_LBRACE,
    STATE(16319), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703890] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(22655), 1,
      sym__lowercase_identifier,
    STATE(16320), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703910] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22657), 1,
      anon_sym_RPAREN,
    STATE(16321), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703930] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(85), 1,
      sym_attribute_id,
    STATE(16322), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [703948] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22659), 1,
      aux_sym_quoted_extension_token1,
    STATE(16323), 1,
      sym_attribute,
    STATE(20428), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703968] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16324), 1,
      sym_attribute,
    STATE(16352), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [703986] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22661), 1,
      anon_sym_SEMI,
    ACTIONS(22663), 1,
      anon_sym_RBRACE,
    STATE(16301), 1,
      aux_sym_record_expression_repeat1,
    STATE(16325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704006] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22665), 1,
      anon_sym_LPAREN,
    ACTIONS(22667), 1,
      anon_sym_LBRACK,
    ACTIONS(22669), 1,
      anon_sym_LBRACE,
    STATE(16326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704026] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8734), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22671), 1,
      anon_sym_SEMI,
    STATE(16271), 1,
      aux_sym_list_binding_pattern_repeat1,
    STATE(16327), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704046] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    ACTIONS(22673), 1,
      anon_sym_RBRACK,
    STATE(14713), 1,
      aux_sym__type_params_repeat1,
    STATE(16328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704066] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17911), 1,
      anon_sym_RBRACE,
    ACTIONS(22675), 1,
      anon_sym_SEMI,
    STATE(15175), 1,
      aux_sym_record_binding_pattern_repeat1,
    STATE(16329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704086] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14837), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16330), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704106] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17723), 1,
      anon_sym_SEMI,
    ACTIONS(17725), 1,
      anon_sym_GT,
    STATE(16331), 1,
      sym_attribute,
    STATE(16415), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704126] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(22677), 1,
      anon_sym_RPAREN,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704146] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22679), 1,
      anon_sym_LPAREN,
    ACTIONS(22681), 1,
      anon_sym_LBRACK,
    ACTIONS(22683), 1,
      anon_sym_LBRACE,
    STATE(16333), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704166] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8722), 1,
      anon_sym_RBRACK,
    ACTIONS(22685), 1,
      anon_sym_SEMI,
    STATE(15168), 1,
      aux_sym_list_binding_pattern_repeat1,
    STATE(16334), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704186] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18738), 1,
      anon_sym_RBRACE,
    ACTIONS(22687), 1,
      anon_sym_SEMI,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    STATE(16335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704206] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22689), 1,
      anon_sym_SEMI,
    ACTIONS(22691), 1,
      anon_sym_GT_RBRACE,
    STATE(16279), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704226] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(22693), 1,
      anon_sym_RPAREN,
    STATE(16337), 1,
      sym_attribute,
    STATE(19623), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704246] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22695), 1,
      anon_sym_LPAREN,
    ACTIONS(22697), 1,
      anon_sym_LBRACK,
    ACTIONS(22699), 1,
      anon_sym_LBRACE,
    STATE(16338), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704266] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22701), 1,
      anon_sym_LPAREN,
    ACTIONS(22703), 1,
      anon_sym_LBRACK,
    ACTIONS(22705), 1,
      anon_sym_LBRACE,
    STATE(16339), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704286] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20715), 1,
      anon_sym_COLON2,
    ACTIONS(22707), 1,
      anon_sym_RPAREN,
    STATE(16340), 1,
      sym_attribute,
    STATE(20254), 1,
      sym__class_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704306] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22709), 1,
      anon_sym_RPAREN,
    STATE(16341), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704326] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3421), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22711), 1,
      anon_sym_SEMI,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    STATE(16342), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704346] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22713), 1,
      anon_sym_SEMI,
    ACTIONS(22715), 1,
      anon_sym_RBRACE,
    STATE(16343), 1,
      sym_attribute,
    STATE(16356), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704366] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(22717), 1,
      anon_sym_RPAREN,
    STATE(16344), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704386] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18542), 1,
      anon_sym_RBRACE,
    ACTIONS(22719), 1,
      anon_sym_SEMI,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    STATE(16345), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704406] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22721), 1,
      anon_sym_SEMI,
    ACTIONS(22723), 1,
      anon_sym_RBRACE,
    STATE(16296), 1,
      aux_sym_record_expression_repeat1,
    STATE(16346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704426] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17893), 1,
      anon_sym_RBRACE,
    ACTIONS(22725), 1,
      anon_sym_SEMI,
    STATE(15175), 1,
      aux_sym_record_binding_pattern_repeat1,
    STATE(16347), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704446] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22727), 1,
      anon_sym_SEMI,
    ACTIONS(22729), 1,
      anon_sym_GT_RBRACE,
    STATE(16348), 1,
      sym_attribute,
    STATE(16412), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704466] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22731), 1,
      anon_sym_SEMI,
    ACTIONS(22733), 1,
      anon_sym_RBRACE,
    STATE(16345), 1,
      aux_sym_record_expression_repeat1,
    STATE(16349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704486] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8420), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22735), 1,
      anon_sym_SEMI,
    STATE(16269), 1,
      aux_sym_list_pattern_repeat1,
    STATE(16350), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704506] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17889), 1,
      anon_sym_RBRACE,
    ACTIONS(22737), 1,
      anon_sym_SEMI,
    STATE(15124), 1,
      aux_sym_record_pattern_repeat1,
    STATE(16351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704526] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22739), 1,
      aux_sym_quoted_extension_token1,
    STATE(16352), 1,
      sym_attribute,
    STATE(18979), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704546] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8772), 1,
      anon_sym_RBRACK,
    ACTIONS(22741), 1,
      anon_sym_SEMI,
    STATE(15168), 1,
      aux_sym_list_binding_pattern_repeat1,
    STATE(16353), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704566] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3579), 1,
      anon_sym_RBRACK,
    ACTIONS(22743), 1,
      anon_sym_SEMI,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    STATE(16354), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704586] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19414), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22745), 1,
      anon_sym_SEMI,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16355), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704606] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18506), 1,
      anon_sym_RBRACE,
    ACTIONS(22747), 1,
      anon_sym_SEMI,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    STATE(16356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704626] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12723), 1,
      sym_module_binding,
    STATE(16357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17935), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [704644] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(22749), 1,
      sym__lowercase_identifier,
    STATE(16358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704664] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8959), 1,
      aux_sym_attribute_id_token1,
    STATE(16359), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8961), 2,
      sym__left_quoted_string_delimiter,
      aux_sym_quoted_extension_token1,
  [704682] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17539), 1,
      anon_sym_SEMI,
    ACTIONS(17541), 1,
      anon_sym_GT,
    STATE(16010), 1,
      aux_sym_object_type_repeat1,
    STATE(16360), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704702] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18494), 1,
      anon_sym_RBRACE,
    ACTIONS(22751), 1,
      anon_sym_SEMI,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    STATE(16361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704722] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8418), 1,
      anon_sym_RBRACK,
    ACTIONS(22753), 1,
      anon_sym_SEMI,
    STATE(15163), 1,
      aux_sym_list_pattern_repeat1,
    STATE(16362), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704742] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(59), 1,
      sym_attribute_id,
    STATE(16363), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [704760] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22755), 1,
      anon_sym_RPAREN,
    STATE(16364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704780] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(16365), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12258), 3,
      anon_sym_and,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [704796] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22757), 1,
      anon_sym_RPAREN,
    STATE(16366), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704816] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19402), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16367), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704836] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22759), 1,
      anon_sym_LPAREN,
    ACTIONS(22761), 1,
      anon_sym_LBRACK,
    ACTIONS(22763), 1,
      anon_sym_LBRACE,
    STATE(16368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704856] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22765), 1,
      anon_sym_EQ,
    STATE(16369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704876] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22767), 1,
      aux_sym_quoted_extension_token1,
    STATE(16370), 1,
      sym_attribute,
    STATE(18067), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704896] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19343), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704916] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19341), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16372), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704936] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(22769), 1,
      sym__lowercase_identifier,
    STATE(16373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704956] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18604), 1,
      anon_sym_RBRACE,
    ACTIONS(22771), 1,
      anon_sym_SEMI,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    STATE(16374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704976] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(14494), 1,
      aux_sym_module_binding_repeat1,
    STATE(16375), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704996] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22773), 1,
      anon_sym_RPAREN,
    STATE(16376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705016] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(22775), 1,
      anon_sym_RPAREN,
    STATE(16377), 1,
      sym_attribute,
    STATE(20252), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705036] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8408), 1,
      anon_sym_RBRACK,
    ACTIONS(22777), 1,
      anon_sym_SEMI,
    STATE(15163), 1,
      aux_sym_list_pattern_repeat1,
    STATE(16378), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705056] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22779), 1,
      anon_sym_SEMI,
    ACTIONS(22781), 1,
      anon_sym_RBRACE,
    STATE(16351), 1,
      aux_sym_record_pattern_repeat1,
    STATE(16379), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705076] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(22783), 1,
      anon_sym_RPAREN,
    STATE(16380), 1,
      sym_attribute,
    STATE(19907), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705096] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22785), 1,
      anon_sym_LPAREN,
    ACTIONS(22787), 1,
      anon_sym_LBRACK,
    ACTIONS(22789), 1,
      anon_sym_LBRACE,
    STATE(16381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705116] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(22791), 1,
      anon_sym_RPAREN,
    STATE(16382), 1,
      sym_attribute,
    STATE(19351), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705136] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8392), 1,
      anon_sym_RBRACK,
    ACTIONS(22793), 1,
      anon_sym_SEMI,
    STATE(15163), 1,
      aux_sym_list_pattern_repeat1,
    STATE(16383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705156] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20715), 1,
      anon_sym_COLON2,
    ACTIONS(22795), 1,
      anon_sym_RPAREN,
    STATE(16384), 1,
      sym_attribute,
    STATE(19909), 1,
      sym__class_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705176] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17919), 1,
      anon_sym_RBRACE,
    ACTIONS(22797), 1,
      anon_sym_SEMI,
    STATE(15124), 1,
      aux_sym_record_pattern_repeat1,
    STATE(16385), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705196] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16183), 1,
      sym_attribute_id,
    STATE(16386), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [705214] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8390), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22799), 1,
      anon_sym_SEMI,
    STATE(16269), 1,
      aux_sym_list_pattern_repeat1,
    STATE(16387), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705234] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(22), 1,
      sym_attribute_id,
    STATE(16388), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [705252] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19379), 1,
      anon_sym_RBRACK,
    STATE(16367), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705272] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19379), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705292] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(22801), 1,
      anon_sym_RPAREN,
    STATE(16391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705312] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22803), 1,
      anon_sym_RPAREN,
    STATE(16392), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705332] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16081), 1,
      sym_attribute_id,
    STATE(16393), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [705350] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(73), 1,
      sym_attribute_id,
    STATE(16394), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [705368] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11857), 1,
      anon_sym_LPAREN,
    STATE(9766), 1,
      sym_module_parameter,
    STATE(14612), 1,
      aux_sym_module_binding_repeat1,
    STATE(16395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705388] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19341), 1,
      anon_sym_RBRACK,
    STATE(16396), 1,
      sym_attribute,
    STATE(16499), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705408] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22805), 1,
      anon_sym_LPAREN,
    ACTIONS(22807), 1,
      anon_sym_LBRACK,
    ACTIONS(22809), 1,
      anon_sym_LBRACE,
    STATE(16397), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705428] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22811), 1,
      anon_sym_LPAREN,
    ACTIONS(22813), 1,
      anon_sym_LBRACK,
    ACTIONS(22815), 1,
      anon_sym_LBRACE,
    STATE(16398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705448] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19343), 1,
      anon_sym_RBRACK,
    STATE(16399), 1,
      sym_attribute,
    STATE(16488), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705468] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(22817), 1,
      sym__lowercase_identifier,
    STATE(16400), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705488] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17068), 1,
      sym__uppercase_identifier,
    ACTIONS(19013), 1,
      anon_sym_LPAREN,
    STATE(13258), 1,
      sym__constructor_name,
    STATE(16401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705508] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(12366), 1,
      sym_module_binding,
    STATE(16402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17759), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [705526] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22819), 1,
      anon_sym_RPAREN,
    STATE(16403), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705546] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18476), 1,
      anon_sym_RBRACE,
    ACTIONS(22821), 1,
      anon_sym_SEMI,
    STATE(16361), 1,
      aux_sym_record_expression_repeat1,
    STATE(16404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705566] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15019), 1,
      anon_sym_in,
    ACTIONS(21200), 1,
      anon_sym_and,
    STATE(16405), 1,
      sym_attribute,
    STATE(16491), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705586] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8216), 1,
      anon_sym_RBRACK,
    ACTIONS(22823), 1,
      anon_sym_SEMI,
    STATE(15163), 1,
      aux_sym_list_pattern_repeat1,
    STATE(16406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705606] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22825), 1,
      anon_sym_RPAREN,
    STATE(16407), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705626] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18566), 1,
      anon_sym_RBRACE,
    ACTIONS(22827), 1,
      anon_sym_SEMI,
    STATE(16374), 1,
      aux_sym_record_expression_repeat1,
    STATE(16408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705646] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(22829), 1,
      anon_sym_RPAREN,
    STATE(16409), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705666] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19359), 1,
      anon_sym_RBRACK,
    STATE(16410), 1,
      sym_attribute,
    STATE(16467), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705686] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19359), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16411), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705706] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19369), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22831), 1,
      anon_sym_SEMI,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705726] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8724), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22833), 1,
      anon_sym_SEMI,
    STATE(16271), 1,
      aux_sym_list_binding_pattern_repeat1,
    STATE(16413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705746] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11745), 1,
      anon_sym_GT,
    ACTIONS(22835), 1,
      anon_sym_SEMI,
    STATE(15334), 1,
      aux_sym_object_type_repeat1,
    STATE(16414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705766] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11594), 1,
      anon_sym_GT,
    ACTIONS(22837), 1,
      anon_sym_SEMI,
    STATE(15334), 1,
      aux_sym_object_type_repeat1,
    STATE(16415), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705786] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22839), 1,
      anon_sym_SEMI,
    ACTIONS(22841), 1,
      anon_sym_RBRACE,
    STATE(16329), 1,
      aux_sym_record_binding_pattern_repeat1,
    STATE(16416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705806] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18554), 1,
      anon_sym_RBRACE,
    ACTIONS(22843), 1,
      anon_sym_SEMI,
    STATE(16417), 1,
      sym_attribute,
    STATE(16477), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705826] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19357), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22845), 1,
      anon_sym_SEMI,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705846] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16170), 1,
      sym_attribute_id,
    STATE(16419), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [705864] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22847), 1,
      anon_sym_RPAREN,
    STATE(16420), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705884] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8750), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22849), 1,
      anon_sym_SEMI,
    STATE(16271), 1,
      aux_sym_list_binding_pattern_repeat1,
    STATE(16421), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705904] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19349), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16422), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705924] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19349), 1,
      anon_sym_RBRACK,
    STATE(16390), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16423), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705944] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18458), 1,
      anon_sym_RBRACE,
    ACTIONS(22851), 1,
      anon_sym_SEMI,
    STATE(16424), 1,
      sym_attribute,
    STATE(16461), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705964] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3617), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22853), 1,
      anon_sym_SEMI,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    STATE(16425), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705984] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(22855), 1,
      anon_sym_RPAREN,
    STATE(16426), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706004] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10096), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    STATE(16030), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706024] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22857), 1,
      anon_sym_RPAREN,
    STATE(16428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706044] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22859), 1,
      anon_sym_SEMI,
    ACTIONS(22861), 1,
      anon_sym_GT_RBRACE,
    STATE(16266), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706064] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22863), 1,
      aux_sym_quoted_extension_token1,
    STATE(16430), 1,
      sym_attribute,
    STATE(18877), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706084] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18454), 1,
      anon_sym_RBRACE,
    ACTIONS(22865), 1,
      anon_sym_SEMI,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    STATE(16431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706104] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22867), 1,
      anon_sym_EQ,
    STATE(16432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22869), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [706122] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3615), 1,
      anon_sym_RBRACK,
    ACTIONS(22871), 1,
      anon_sym_SEMI,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    STATE(16433), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706142] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19325), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22873), 1,
      anon_sym_SEMI,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706162] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17827), 1,
      anon_sym_RBRACE,
    ACTIONS(22875), 1,
      anon_sym_SEMI,
    STATE(15175), 1,
      aux_sym_record_binding_pattern_repeat1,
    STATE(16435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706182] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8698), 1,
      anon_sym_RBRACK,
    ACTIONS(22877), 1,
      anon_sym_SEMI,
    STATE(15168), 1,
      aux_sym_list_binding_pattern_repeat1,
    STATE(16436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706202] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(22879), 1,
      sym__lowercase_identifier,
    STATE(16437), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706222] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(20389), 1,
      sym_indexing_operator,
    ACTIONS(22881), 1,
      sym__lowercase_identifier,
    STATE(16438), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706242] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3635), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22883), 1,
      anon_sym_SEMI,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    STATE(16439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706262] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(22885), 1,
      anon_sym_RPAREN,
    STATE(16440), 1,
      sym_attribute,
    STATE(19341), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706282] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3575), 1,
      anon_sym_RBRACK,
    ACTIONS(22887), 1,
      anon_sym_SEMI,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    STATE(16441), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706302] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22889), 1,
      anon_sym_RPAREN,
    STATE(16442), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706322] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(22891), 1,
      anon_sym_type,
    STATE(16245), 1,
      sym_module_path,
    STATE(16443), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706342] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18516), 1,
      anon_sym_RBRACE,
    ACTIONS(22893), 1,
      anon_sym_SEMI,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    STATE(16444), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706362] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17613), 1,
      anon_sym_SEMI,
    ACTIONS(17615), 1,
      anon_sym_GT,
    STATE(16414), 1,
      aux_sym_object_type_repeat1,
    STATE(16445), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706382] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(7), 1,
      sym_attribute_id,
    STATE(16446), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [706400] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(60), 1,
      sym_attribute_id,
    STATE(16447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [706418] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22895), 1,
      anon_sym_RPAREN,
    STATE(16448), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706438] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9934), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    STATE(16422), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16449), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706458] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18520), 1,
      anon_sym_RBRACE,
    ACTIONS(22897), 1,
      anon_sym_SEMI,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    STATE(16450), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706478] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22899), 1,
      anon_sym_RPAREN,
    STATE(16451), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706498] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(22901), 1,
      anon_sym_type,
    STATE(16245), 1,
      sym_module_path,
    STATE(16452), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706518] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3671), 1,
      anon_sym_RBRACK,
    ACTIONS(22903), 1,
      anon_sym_SEMI,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    STATE(16453), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706538] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8424), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22905), 1,
      anon_sym_SEMI,
    STATE(16269), 1,
      aux_sym_list_pattern_repeat1,
    STATE(16454), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706558] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22907), 1,
      aux_sym_quoted_extension_token1,
    STATE(16455), 1,
      sym_attribute,
    STATE(18189), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706578] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18484), 1,
      anon_sym_RBRACE,
    ACTIONS(22909), 1,
      anon_sym_SEMI,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    STATE(16456), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706598] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22911), 1,
      anon_sym_RPAREN,
    STATE(16457), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706618] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    ACTIONS(18859), 1,
      anon_sym_with,
    ACTIONS(22913), 1,
      anon_sym_RPAREN,
    STATE(16458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706638] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16066), 1,
      sym_attribute_id,
    STATE(16459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [706656] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22915), 1,
      anon_sym_LPAREN,
    ACTIONS(22917), 1,
      anon_sym_LBRACK,
    ACTIONS(22919), 1,
      anon_sym_LBRACE,
    STATE(16460), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706676] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18430), 1,
      anon_sym_RBRACE,
    ACTIONS(22921), 1,
      anon_sym_SEMI,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    STATE(16461), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706696] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    ACTIONS(22923), 1,
      anon_sym_RPAREN,
    STATE(16462), 1,
      sym_attribute,
    STATE(19528), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706716] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22925), 1,
      anon_sym_LPAREN,
    ACTIONS(22927), 1,
      anon_sym_LBRACK,
    ACTIONS(22929), 1,
      anon_sym_LBRACE,
    STATE(16463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706736] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22931), 1,
      anon_sym_SEMI,
    ACTIONS(22933), 1,
      anon_sym_GT_RBRACE,
    STATE(16418), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706756] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22935), 1,
      anon_sym_SEMI,
    ACTIONS(22937), 1,
      anon_sym_GT_RBRACE,
    STATE(16434), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16465), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706776] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(11855), 1,
      sym_attribute_id,
    STATE(16466), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22939), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [706794] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19287), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706814] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(22941), 1,
      anon_sym_RPAREN,
    STATE(15020), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706834] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19313), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22943), 1,
      anon_sym_SEMI,
    STATE(15754), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706854] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17769), 1,
      anon_sym_RBRACE,
    ACTIONS(22945), 1,
      anon_sym_SEMI,
    STATE(15124), 1,
      aux_sym_record_pattern_repeat1,
    STATE(16470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706874] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3845), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22947), 1,
      anon_sym_SEMI,
    STATE(16175), 1,
      aux_sym_list_expression_repeat1,
    STATE(16471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706894] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19287), 1,
      anon_sym_RBRACK,
    STATE(16087), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706914] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22949), 1,
      aux_sym_quoted_extension_token1,
    STATE(16473), 1,
      sym_attribute,
    STATE(19089), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706934] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22951), 1,
      anon_sym_LPAREN,
    ACTIONS(22953), 1,
      anon_sym_LBRACK,
    ACTIONS(22955), 1,
      anon_sym_LBRACE,
    STATE(16474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706954] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22957), 1,
      anon_sym_SEMI,
    ACTIONS(22959), 1,
      anon_sym_RBRACE,
    STATE(16444), 1,
      aux_sym_record_expression_repeat1,
    STATE(16475), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706974] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14724), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16476), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706994] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18438), 1,
      anon_sym_RBRACE,
    ACTIONS(22961), 1,
      anon_sym_SEMI,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    STATE(16477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707014] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15011), 1,
      anon_sym_in,
    ACTIONS(21200), 1,
      anon_sym_and,
    STATE(15912), 1,
      aux_sym_module_definition_repeat1,
    STATE(16478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707034] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(22963), 1,
      anon_sym_RPAREN,
    STATE(16479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707054] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22965), 1,
      anon_sym_LPAREN,
    ACTIONS(22967), 1,
      anon_sym_LBRACK,
    ACTIONS(22969), 1,
      anon_sym_LBRACE,
    STATE(16480), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707074] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22971), 1,
      anon_sym_SEMI,
    ACTIONS(22973), 1,
      anon_sym_RBRACE,
    STATE(16431), 1,
      aux_sym_record_expression_repeat1,
    STATE(16481), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707094] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16144), 1,
      sym_attribute_id,
    STATE(16482), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [707112] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17791), 1,
      anon_sym_RBRACE,
    ACTIONS(22975), 1,
      anon_sym_SEMI,
    STATE(15124), 1,
      aux_sym_record_pattern_repeat1,
    STATE(16483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707132] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3859), 1,
      anon_sym_RBRACK,
    ACTIONS(22977), 1,
      anon_sym_SEMI,
    STATE(16299), 1,
      aux_sym_list_expression_repeat1,
    STATE(16484), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707152] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22979), 1,
      anon_sym_EQ,
    STATE(16485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22981), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [707170] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8152), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22983), 1,
      anon_sym_SEMI,
    STATE(16269), 1,
      aux_sym_list_pattern_repeat1,
    STATE(16486), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707190] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22985), 1,
      aux_sym_quoted_extension_token1,
    STATE(16487), 1,
      sym_attribute,
    STATE(18203), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707210] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19279), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16488), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707230] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22987), 1,
      anon_sym_LPAREN,
    ACTIONS(22989), 1,
      anon_sym_LBRACK,
    ACTIONS(22991), 1,
      anon_sym_LBRACE,
    STATE(16489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707250] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16490), 1,
      sym_attribute,
    STATE(16648), 1,
      sym_module_binding,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18504), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [707268] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15011), 1,
      anon_sym_in,
    ACTIONS(21200), 1,
      anon_sym_and,
    STATE(15893), 1,
      aux_sym_module_definition_repeat1,
    STATE(16491), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707288] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(22993), 1,
      anon_sym_type,
    STATE(16245), 1,
      sym_module_path,
    STATE(16492), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707308] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9954), 1,
      sym__uppercase_identifier,
    ACTIONS(22995), 1,
      anon_sym_type,
    STATE(16245), 1,
      sym_module_path,
    STATE(16493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707328] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16323), 1,
      sym_attribute_id,
    STATE(16494), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20439), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [707346] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(83), 1,
      sym_attribute_id,
    STATE(16495), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [707364] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(86), 1,
      sym_attribute_id,
    STATE(16496), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [707382] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(15889), 1,
      sym_module_binding,
    STATE(16497), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18504), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [707400] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(6), 1,
      sym_attribute_id,
    STATE(16498), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20405), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [707418] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    ACTIONS(19289), 1,
      anon_sym_RBRACK,
    STATE(15001), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16499), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707438] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14702), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16500), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707458] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(14696), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16501), 1,
      sym_attribute,
    STATE(16629), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707478] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9988), 1,
      anon_sym_RBRACK,
    ACTIONS(19273), 1,
      anon_sym_PIPE,
    STATE(16164), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707498] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17704), 1,
      anon_sym_SEMI,
    ACTIONS(17706), 1,
      anon_sym_GT,
    STATE(16112), 1,
      aux_sym_object_type_repeat1,
    STATE(16503), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707518] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22997), 1,
      anon_sym_LPAREN,
    ACTIONS(22999), 1,
      anon_sym_LBRACK,
    ACTIONS(23001), 1,
      anon_sym_LBRACE,
    STATE(16504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707538] = 6,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18387), 1,
      anon_sym_RBRACE,
    ACTIONS(23003), 1,
      anon_sym_SEMI,
    STATE(15997), 1,
      aux_sym_record_expression_repeat1,
    STATE(16505), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707558] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23005), 1,
      anon_sym_SEMI,
    ACTIONS(23007), 1,
      anon_sym_RBRACE,
    STATE(16506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707575] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16507), 1,
      sym_attribute,
    STATE(18863), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707592] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23009), 1,
      anon_sym_COLON2,
    STATE(16508), 1,
      sym_attribute,
    STATE(20473), 1,
      sym__polymorphic_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707609] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16509), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23011), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [707624] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16510), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23013), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [707639] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23015), 1,
      anon_sym_DOT,
    STATE(16511), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707656] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5279), 1,
      anon_sym_COLON_COLON,
    ACTIONS(23017), 1,
      anon_sym_RPAREN,
    STATE(16512), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707673] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23019), 1,
      anon_sym_then,
    STATE(11077), 1,
      sym_then_clause,
    STATE(16513), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707690] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23019), 1,
      anon_sym_then,
    STATE(11047), 1,
      sym_then_clause,
    STATE(16514), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707707] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16515), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23021), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [707722] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23023), 1,
      anon_sym_then,
    STATE(11946), 1,
      sym_then_clause,
    STATE(16516), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707739] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16517), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23025), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [707754] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23023), 1,
      anon_sym_then,
    STATE(11903), 1,
      sym_then_clause,
    STATE(16518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707771] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23023), 1,
      anon_sym_then,
    STATE(12015), 1,
      sym_then_clause,
    STATE(16519), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707788] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23027), 1,
      anon_sym_then,
    STATE(10200), 1,
      sym_then_clause,
    STATE(16520), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707805] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16521), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23029), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [707820] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23031), 1,
      anon_sym_DOT,
    STATE(16522), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707837] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23033), 1,
      sym__lowercase_identifier,
    ACTIONS(23035), 1,
      anon_sym_LBRACK,
    STATE(16523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707854] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23037), 1,
      anon_sym_COLON2,
    STATE(11782), 1,
      sym__polymorphic_typed,
    STATE(16524), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707871] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16525), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23039), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [707886] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16526), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23041), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [707901] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16527), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23043), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [707916] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23023), 1,
      anon_sym_then,
    STATE(12005), 1,
      sym_then_clause,
    STATE(16528), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707933] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16529), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23045), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [707948] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16530), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23047), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [707963] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16531), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23049), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [707978] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23019), 1,
      anon_sym_then,
    STATE(11180), 1,
      sym_then_clause,
    STATE(16532), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707995] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23019), 1,
      anon_sym_then,
    STATE(11044), 1,
      sym_then_clause,
    STATE(16533), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708012] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23051), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [708027] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23009), 1,
      anon_sym_COLON2,
    STATE(16535), 1,
      sym_attribute,
    STATE(20424), 1,
      sym__polymorphic_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708044] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    STATE(15456), 1,
      sym_extended_module_path,
    STATE(16536), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708061] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(16537), 1,
      sym_attribute,
    STATE(20028), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708078] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17669), 1,
      sym__lowercase_identifier,
    STATE(16538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708095] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16539), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23053), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [708110] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23055), 1,
      anon_sym_DOT,
    STATE(16540), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708127] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22528), 1,
      anon_sym_EQ,
    ACTIONS(23057), 1,
      anon_sym_COLON_GT,
    STATE(16541), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708144] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16542), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23059), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [708159] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    STATE(16543), 1,
      sym_attribute,
    STATE(20412), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708176] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23061), 1,
      anon_sym_SEMI,
    ACTIONS(23063), 1,
      anon_sym_RBRACE,
    STATE(16544), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708193] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23063), 1,
      anon_sym_RBRACK,
    ACTIONS(23065), 1,
      anon_sym_SEMI,
    STATE(16545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708210] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23063), 1,
      anon_sym_RPAREN,
    ACTIONS(23067), 1,
      anon_sym_SEMI,
    STATE(16546), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708227] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23069), 1,
      sym__lowercase_identifier,
    ACTIONS(23071), 1,
      sym__uppercase_identifier,
    STATE(16547), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708244] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23073), 1,
      sym__lowercase_identifier,
    ACTIONS(23075), 1,
      anon_sym_LBRACK,
    STATE(16548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708261] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23037), 1,
      anon_sym_COLON2,
    STATE(11880), 1,
      sym__polymorphic_typed,
    STATE(16549), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708278] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23077), 1,
      anon_sym_DOT,
    STATE(16550), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708295] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16551), 1,
      sym_attribute,
    STATE(20394), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708312] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23079), 1,
      anon_sym_DOT,
    STATE(16552), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708329] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8839), 1,
      anon_sym_COLON_GT,
    ACTIONS(8841), 1,
      anon_sym_EQ,
    STATE(16553), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708346] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23081), 1,
      anon_sym_DOT,
    STATE(16554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708363] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23083), 1,
      anon_sym_open,
    STATE(16555), 1,
      sym_attribute,
    STATE(20061), 1,
      sym_open_module,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708380] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18456), 1,
      sym__lowercase_identifier,
    STATE(15023), 1,
      sym__simple_value_pattern,
    STATE(16556), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708397] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23085), 1,
      anon_sym_then,
    STATE(8481), 1,
      sym_then_clause,
    STATE(16557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708414] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16558), 1,
      sym_attribute,
    STATE(20065), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708431] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23087), 1,
      anon_sym_do,
    STATE(8134), 1,
      sym_do_clause,
    STATE(16559), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708448] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16560), 1,
      sym_attribute,
    STATE(18895), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708465] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19821), 1,
      sym__lowercase_identifier,
    STATE(14737), 1,
      aux_sym__abstract_type_repeat1,
    STATE(16561), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708482] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16562), 1,
      sym_attribute,
    STATE(19844), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708499] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16563), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23089), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [708514] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16564), 1,
      sym_attribute,
    STATE(20305), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708531] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23091), 1,
      sym__lowercase_identifier,
    ACTIONS(23093), 1,
      anon_sym_LPAREN,
    STATE(16565), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708548] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18456), 1,
      sym__lowercase_identifier,
    STATE(14479), 1,
      sym__simple_value_pattern,
    STATE(16566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708565] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23095), 1,
      anon_sym_then,
    STATE(8551), 1,
      sym_then_clause,
    STATE(16567), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708582] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10364), 1,
      anon_sym_RPAREN,
    ACTIONS(23097), 1,
      aux_sym_number_token1,
    STATE(16568), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708599] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23083), 1,
      anon_sym_open,
    STATE(16569), 1,
      sym_attribute,
    STATE(20299), 1,
      sym_open_module,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708616] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23099), 1,
      anon_sym_COLON2,
    STATE(11880), 1,
      sym__polymorphic_typed,
    STATE(16570), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708633] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23101), 1,
      anon_sym_then,
    STATE(8255), 1,
      sym_then_clause,
    STATE(16571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708650] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16910), 1,
      anon_sym_STAR,
    ACTIONS(23103), 1,
      anon_sym_DASH_GT,
    STATE(16572), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708667] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16541), 1,
      anon_sym_COLON2,
    STATE(16573), 1,
      sym_attribute,
    STATE(20089), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708684] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23105), 1,
      anon_sym_DOT,
    STATE(16574), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708701] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    STATE(15364), 1,
      sym_extended_module_path,
    STATE(16575), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708718] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8776), 1,
      anon_sym_COLON_GT,
    ACTIONS(8778), 1,
      anon_sym_EQ,
    STATE(16576), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708735] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23107), 1,
      anon_sym_COLON_GT,
    ACTIONS(23109), 1,
      anon_sym_RPAREN,
    STATE(16577), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708752] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10206), 1,
      anon_sym_RBRACK,
    ACTIONS(18464), 1,
      anon_sym_PIPE,
    STATE(16578), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708769] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23099), 1,
      anon_sym_COLON2,
    STATE(11782), 1,
      sym__polymorphic_typed,
    STATE(16579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708786] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16580), 1,
      sym_attribute,
    STATE(19706), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708803] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23111), 1,
      anon_sym_DOT,
    STATE(16581), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708820] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23113), 1,
      anon_sym_DOT,
    STATE(16582), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708837] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23115), 1,
      anon_sym_DOT,
    STATE(16583), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708854] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    STATE(8190), 1,
      sym_type_variable,
    STATE(16584), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708871] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23085), 1,
      anon_sym_then,
    STATE(8520), 1,
      sym_then_clause,
    STATE(16585), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708888] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23087), 1,
      anon_sym_do,
    STATE(8144), 1,
      sym_do_clause,
    STATE(16586), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708905] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(23117), 1,
      sym__lowercase_identifier,
    STATE(16587), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708922] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16588), 1,
      sym_attribute,
    STATE(19934), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708939] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23119), 1,
      anon_sym_RBRACK,
    ACTIONS(23121), 1,
      anon_sym_SEMI,
    STATE(16589), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708956] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23119), 1,
      anon_sym_RBRACE,
    ACTIONS(23123), 1,
      anon_sym_SEMI,
    STATE(16590), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708973] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16591), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11845), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
  [708988] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16592), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23125), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [709003] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18243), 1,
      anon_sym_COLON2,
    STATE(16593), 1,
      sym_attribute,
    STATE(16613), 1,
      sym__polymorphic_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709020] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18456), 1,
      sym__lowercase_identifier,
    STATE(14472), 1,
      sym__simple_value_pattern,
    STATE(16594), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709037] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23127), 1,
      anon_sym_COLON_GT,
    ACTIONS(23129), 1,
      anon_sym_RPAREN,
    STATE(16595), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709054] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23131), 1,
      anon_sym_DOT,
    STATE(16596), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709071] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16597), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23133), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [709086] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23119), 1,
      anon_sym_RPAREN,
    ACTIONS(23135), 1,
      anon_sym_SEMI,
    STATE(16598), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709103] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8835), 1,
      anon_sym_COLON_GT,
    ACTIONS(8837), 1,
      anon_sym_EQ,
    STATE(16599), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709120] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22765), 1,
      anon_sym_EQ,
    ACTIONS(23137), 1,
      anon_sym_COLON_GT,
    STATE(16600), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709137] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16601), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23139), 2,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [709152] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16602), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23141), 2,
      anon_sym_SEMI,
      anon_sym_GT,
  [709167] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(23143), 1,
      sym__lowercase_identifier,
    STATE(16603), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709184] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(23145), 1,
      anon_sym_DASH_GT,
    STATE(16604), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709201] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22090), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [709216] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(21298), 1,
      sym__lowercase_identifier,
    STATE(16606), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709233] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23147), 1,
      anon_sym_DOT,
    STATE(16607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709250] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16608), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23149), 2,
      anon_sym_to,
      anon_sym_downto,
  [709265] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16609), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21656), 2,
      anon_sym_SEMI,
      anon_sym_GT_RBRACE,
  [709280] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(16610), 1,
      sym_attribute,
    STATE(20233), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709297] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23151), 1,
      anon_sym_RPAREN,
    ACTIONS(23153), 1,
      anon_sym_LT_DASH,
    STATE(16611), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709314] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18243), 1,
      anon_sym_COLON2,
    STATE(16612), 1,
      sym_attribute,
    STATE(16634), 1,
      sym__polymorphic_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709331] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16613), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23155), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [709346] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16614), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23157), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [709361] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7899), 1,
      sym__uppercase_identifier,
    STATE(8972), 1,
      sym_extended_module_path,
    STATE(16615), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709378] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23159), 1,
      anon_sym_COLON2,
    STATE(13154), 1,
      sym__typed,
    STATE(16616), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709395] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23161), 1,
      anon_sym_RPAREN,
    ACTIONS(23163), 1,
      anon_sym_SEMI,
    STATE(16617), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709412] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23161), 1,
      anon_sym_RBRACK,
    ACTIONS(23165), 1,
      anon_sym_SEMI,
    STATE(16618), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709429] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23161), 1,
      anon_sym_RBRACE,
    ACTIONS(23167), 1,
      anon_sym_SEMI,
    STATE(16619), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709446] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23169), 1,
      anon_sym_EQ,
    ACTIONS(23171), 1,
      anon_sym_RPAREN,
    STATE(16620), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709463] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16910), 1,
      anon_sym_STAR,
    ACTIONS(23173), 1,
      anon_sym_DASH_GT,
    STATE(16621), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709480] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18339), 1,
      anon_sym_RBRACE,
    ACTIONS(23175), 1,
      anon_sym_SEMI,
    STATE(16622), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709497] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16623), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20482), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [709512] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18261), 1,
      anon_sym_RBRACE,
    ACTIONS(23177), 1,
      anon_sym_SEMI,
    STATE(16624), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709529] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23179), 1,
      sym__lowercase_identifier,
    ACTIONS(23181), 1,
      anon_sym_LBRACK,
    STATE(16625), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709546] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16626), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20601), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [709561] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16627), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23183), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [709576] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18049), 1,
      anon_sym_as,
    ACTIONS(23185), 1,
      anon_sym_DASH_GT,
    STATE(16628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709593] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16629), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23187), 2,
      anon_sym_RBRACK,
      aux_sym_tag_token1,
  [709608] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22232), 1,
      anon_sym_EQ,
    ACTIONS(23189), 1,
      anon_sym_COLON_GT,
    STATE(16630), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709625] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16631), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18131), 2,
      anon_sym_SEMI,
      anon_sym_GT,
  [709640] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23191), 1,
      anon_sym_COLON2,
    STATE(13152), 1,
      sym__polymorphic_typed,
    STATE(16632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709657] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16633), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23193), 2,
      anon_sym_to,
      anon_sym_downto,
  [709672] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16634), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23195), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [709687] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16635), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21379), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [709702] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16910), 1,
      anon_sym_STAR,
    ACTIONS(23197), 1,
      anon_sym_DASH_GT,
    STATE(16636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709719] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23159), 1,
      anon_sym_COLON2,
    STATE(13148), 1,
      sym__typed,
    STATE(16637), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709736] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23191), 1,
      anon_sym_COLON2,
    STATE(13150), 1,
      sym__polymorphic_typed,
    STATE(16638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709753] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(16639), 1,
      sym_attribute,
    STATE(19897), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709770] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23199), 1,
      anon_sym_SEMI,
    ACTIONS(23201), 1,
      anon_sym_RBRACE,
    STATE(16640), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709787] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23203), 1,
      anon_sym_SEMI,
    ACTIONS(23205), 1,
      anon_sym_RBRACE,
    STATE(16641), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709804] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23087), 1,
      anon_sym_do,
    STATE(8140), 1,
      sym_do_clause,
    STATE(16642), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709821] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23207), 1,
      anon_sym_RPAREN,
    ACTIONS(23209), 1,
      anon_sym_LT_DASH,
    STATE(16643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709838] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23211), 1,
      anon_sym_EQ,
    ACTIONS(23213), 1,
      anon_sym_RPAREN,
    STATE(16644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709855] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23087), 1,
      anon_sym_do,
    STATE(8270), 1,
      sym_do_clause,
    STATE(16645), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709872] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(16646), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11458), 2,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [709887] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(16647), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11454), 2,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [709902] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16648), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14170), 2,
      anon_sym_and,
      anon_sym_in,
  [709917] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23215), 1,
      anon_sym_then,
    STATE(10591), 1,
      sym_then_clause,
    STATE(16649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709934] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(16650), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11596), 2,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [709949] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(16651), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11462), 2,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [709964] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23217), 1,
      sym__uppercase_identifier,
    STATE(13402), 1,
      sym_extended_module_path,
    STATE(16652), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709981] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(16653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12497), 2,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [709996] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(16654), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12451), 2,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [710011] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23219), 1,
      anon_sym_EQ,
    ACTIONS(23221), 1,
      anon_sym_RPAREN,
    STATE(16655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710028] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(16656), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12493), 2,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [710043] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5391), 1,
      anon_sym_COLON_COLON,
    ACTIONS(23223), 1,
      anon_sym_RPAREN,
    STATE(16657), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710060] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23225), 1,
      sym__lowercase_identifier,
    ACTIONS(23227), 1,
      anon_sym_LBRACK,
    STATE(16658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710077] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16659), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23229), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [710092] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16660), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23231), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [710107] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16661), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23233), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [710122] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(23235), 1,
      sym__lowercase_identifier,
    STATE(16662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710139] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16663), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23237), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [710154] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23239), 1,
      sym__lowercase_identifier,
    ACTIONS(23241), 1,
      sym__uppercase_identifier,
    STATE(16664), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710171] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23243), 1,
      anon_sym_DOT,
    STATE(16665), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710188] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23215), 1,
      anon_sym_then,
    STATE(10430), 1,
      sym_then_clause,
    STATE(16666), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710205] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23245), 1,
      anon_sym_do,
    STATE(7920), 1,
      sym_do_clause,
    STATE(16667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710222] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23247), 1,
      sym__lowercase_identifier,
    ACTIONS(23249), 1,
      anon_sym_LPAREN,
    STATE(16668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710239] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16910), 1,
      anon_sym_STAR,
    ACTIONS(23251), 1,
      anon_sym_DASH_GT,
    STATE(16669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710256] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8831), 1,
      anon_sym_COLON_GT,
    ACTIONS(8833), 1,
      anon_sym_EQ,
    STATE(16670), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710273] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23253), 1,
      anon_sym_COLON_GT,
    ACTIONS(23255), 1,
      anon_sym_RPAREN,
    STATE(16671), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710290] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10233), 1,
      anon_sym_RBRACK,
    ACTIONS(18464), 1,
      anon_sym_PIPE,
    STATE(16672), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710307] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23257), 1,
      aux_sym_type_variable_token1,
    STATE(8190), 1,
      sym_type_variable,
    STATE(16673), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710324] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23095), 1,
      anon_sym_then,
    STATE(8489), 1,
      sym_then_clause,
    STATE(16674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710341] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23245), 1,
      anon_sym_do,
    STATE(7957), 1,
      sym_do_clause,
    STATE(16675), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710358] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(23259), 1,
      sym__lowercase_identifier,
    STATE(16676), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710375] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23261), 1,
      anon_sym_COLON_GT,
    ACTIONS(23263), 1,
      anon_sym_RPAREN,
    STATE(16677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710392] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20633), 1,
      anon_sym_EQ,
    ACTIONS(23265), 1,
      anon_sym_COLON_GT,
    STATE(16678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710409] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16679), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23267), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [710424] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(23269), 1,
      sym__lowercase_identifier,
    STATE(16680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710441] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23271), 1,
      anon_sym_RPAREN,
    ACTIONS(23273), 1,
      anon_sym_LT_DASH,
    STATE(16681), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710458] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23275), 1,
      anon_sym_RPAREN,
    ACTIONS(23277), 1,
      anon_sym_LT_DASH,
    STATE(16682), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710475] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23279), 1,
      anon_sym_RPAREN,
    ACTIONS(23281), 1,
      anon_sym_LT_DASH,
    STATE(16683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710492] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16684), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23283), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [710507] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23285), 1,
      anon_sym_EQ,
    ACTIONS(23287), 1,
      anon_sym_RPAREN,
    STATE(16685), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710524] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16910), 1,
      anon_sym_STAR,
    ACTIONS(23289), 1,
      anon_sym_DASH_GT,
    STATE(16686), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710541] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18277), 1,
      anon_sym_RBRACE,
    ACTIONS(23291), 1,
      anon_sym_SEMI,
    STATE(16687), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710558] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16910), 1,
      anon_sym_STAR,
    ACTIONS(23293), 1,
      anon_sym_DASH_GT,
    STATE(16688), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710575] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23295), 1,
      anon_sym_SEMI,
    ACTIONS(23297), 1,
      anon_sym_RBRACE,
    STATE(16689), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710592] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23299), 1,
      anon_sym_SEMI,
    ACTIONS(23301), 1,
      anon_sym_RBRACE,
    STATE(16690), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710609] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23245), 1,
      anon_sym_do,
    STATE(8023), 1,
      sym_do_clause,
    STATE(16691), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710626] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16692), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23303), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [710641] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23305), 1,
      anon_sym_RPAREN,
    ACTIONS(23307), 1,
      anon_sym_LT_DASH,
    STATE(16693), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710658] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23309), 1,
      anon_sym_RPAREN,
    ACTIONS(23311), 1,
      anon_sym_LT_DASH,
    STATE(16694), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710675] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23245), 1,
      anon_sym_do,
    STATE(8045), 1,
      sym_do_clause,
    STATE(16695), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710692] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23313), 1,
      anon_sym_RPAREN,
    ACTIONS(23315), 1,
      anon_sym_LT_DASH,
    STATE(16696), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710709] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23317), 1,
      anon_sym_then,
    STATE(12537), 1,
      sym_then_clause,
    STATE(16697), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710726] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23319), 1,
      anon_sym_EQ,
    ACTIONS(23321), 1,
      anon_sym_RPAREN,
    STATE(16698), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710743] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18351), 1,
      anon_sym_RBRACE,
    ACTIONS(23323), 1,
      anon_sym_SEMI,
    STATE(16699), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710760] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16700), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23325), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [710775] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16701), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23327), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [710790] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23329), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [710805] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(23331), 1,
      sym__lowercase_identifier,
    STATE(16703), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710822] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23333), 1,
      anon_sym_DOT,
    STATE(16704), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710839] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23335), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [710854] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23317), 1,
      anon_sym_then,
    STATE(12582), 1,
      sym_then_clause,
    STATE(16706), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710871] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23337), 1,
      anon_sym_RPAREN,
    ACTIONS(23339), 1,
      anon_sym_LT_DASH,
    STATE(16707), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710888] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23341), 1,
      anon_sym_do,
    STATE(10535), 1,
      sym_do_clause,
    STATE(16708), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710905] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23343), 1,
      anon_sym_RPAREN,
    ACTIONS(23345), 1,
      anon_sym_LT_DASH,
    STATE(16709), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710922] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23347), 1,
      sym__lowercase_identifier,
    ACTIONS(23349), 1,
      anon_sym_LPAREN,
    STATE(16710), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710939] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23351), 1,
      sym__lowercase_identifier,
    ACTIONS(23353), 1,
      anon_sym_LBRACK,
    STATE(16711), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710956] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16910), 1,
      anon_sym_STAR,
    ACTIONS(23355), 1,
      anon_sym_DASH_GT,
    STATE(16712), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710973] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23357), 1,
      anon_sym_COLON_GT,
    ACTIONS(23359), 1,
      anon_sym_RPAREN,
    STATE(16713), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710990] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9988), 1,
      anon_sym_RBRACK,
    ACTIONS(18464), 1,
      anon_sym_PIPE,
    STATE(16714), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711007] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7901), 1,
      aux_sym_type_variable_token1,
    STATE(13074), 1,
      sym_type_variable,
    STATE(16715), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711024] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23101), 1,
      anon_sym_then,
    STATE(8120), 1,
      sym_then_clause,
    STATE(16716), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711041] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23341), 1,
      anon_sym_do,
    STATE(10493), 1,
      sym_do_clause,
    STATE(16717), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711058] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16718), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23361), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [711073] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(23363), 1,
      sym__lowercase_identifier,
    STATE(16719), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711090] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23365), 1,
      anon_sym_RPAREN,
    ACTIONS(23367), 1,
      anon_sym_LT_DASH,
    STATE(16720), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711107] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(23369), 1,
      sym__lowercase_identifier,
    STATE(16721), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711124] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23371), 1,
      anon_sym_RPAREN,
    ACTIONS(23373), 1,
      anon_sym_LT_DASH,
    STATE(16722), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711141] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23375), 1,
      anon_sym_RPAREN,
    ACTIONS(23377), 1,
      anon_sym_LT_DASH,
    STATE(16723), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711158] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23379), 1,
      anon_sym_DOT,
    STATE(16724), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711175] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23381), 1,
      anon_sym_EQ,
    ACTIONS(23383), 1,
      anon_sym_RPAREN,
    STATE(16725), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711192] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16910), 1,
      anon_sym_STAR,
    ACTIONS(23385), 1,
      anon_sym_DASH_GT,
    STATE(16726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711209] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17989), 1,
      anon_sym_RBRACE,
    ACTIONS(23387), 1,
      anon_sym_SEMI,
    STATE(16727), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711226] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18025), 1,
      anon_sym_RBRACE,
    ACTIONS(23389), 1,
      anon_sym_SEMI,
    STATE(16728), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711243] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16910), 1,
      anon_sym_STAR,
    ACTIONS(23391), 1,
      anon_sym_DASH_GT,
    STATE(16729), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711260] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23393), 1,
      anon_sym_SEMI,
    ACTIONS(23395), 1,
      anon_sym_RBRACE,
    STATE(16730), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711277] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23397), 1,
      anon_sym_SEMI,
    ACTIONS(23399), 1,
      anon_sym_RBRACE,
    STATE(16731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711294] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16732), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23401), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [711309] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23341), 1,
      anon_sym_do,
    STATE(10354), 1,
      sym_do_clause,
    STATE(16733), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711326] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23403), 1,
      anon_sym_RPAREN,
    ACTIONS(23405), 1,
      anon_sym_LT_DASH,
    STATE(16734), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711343] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23407), 1,
      anon_sym_RPAREN,
    ACTIONS(23409), 1,
      anon_sym_LT_DASH,
    STATE(16735), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711360] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23341), 1,
      anon_sym_do,
    STATE(10360), 1,
      sym_do_clause,
    STATE(16736), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711377] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23411), 1,
      anon_sym_RPAREN,
    ACTIONS(23413), 1,
      anon_sym_LT_DASH,
    STATE(16737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711394] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23415), 1,
      anon_sym_then,
    STATE(12493), 1,
      sym_then_clause,
    STATE(16738), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711411] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16739), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23417), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [711426] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23419), 1,
      sym__lowercase_identifier,
    ACTIONS(23421), 1,
      anon_sym_LBRACK,
    STATE(16740), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711443] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16741), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23423), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [711458] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16742), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23425), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [711473] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(23427), 1,
      sym__lowercase_identifier,
    STATE(16743), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711490] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23429), 1,
      anon_sym_EQ,
    ACTIONS(23431), 1,
      anon_sym_RPAREN,
    STATE(16744), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711507] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23433), 1,
      anon_sym_DOT,
    STATE(16745), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711524] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23415), 1,
      anon_sym_then,
    STATE(12293), 1,
      sym_then_clause,
    STATE(16746), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711541] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23435), 1,
      anon_sym_do,
    STATE(8143), 1,
      sym_do_clause,
    STATE(16747), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711558] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16748), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23437), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [711573] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23439), 1,
      sym__lowercase_identifier,
    ACTIONS(23441), 1,
      anon_sym_LPAREN,
    STATE(16749), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711590] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23443), 1,
      anon_sym_RPAREN,
    ACTIONS(23445), 1,
      anon_sym_LT_DASH,
    STATE(16750), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711607] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16910), 1,
      anon_sym_STAR,
    ACTIONS(23447), 1,
      anon_sym_DASH_GT,
    STATE(16751), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711624] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23449), 1,
      anon_sym_RPAREN,
    ACTIONS(23451), 1,
      anon_sym_LT_DASH,
    STATE(16752), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711641] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23453), 1,
      anon_sym_COLON_GT,
    ACTIONS(23455), 1,
      anon_sym_RPAREN,
    STATE(16753), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711658] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23085), 1,
      anon_sym_then,
    STATE(8525), 1,
      sym_then_clause,
    STATE(16754), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711675] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_RBRACK,
    ACTIONS(18464), 1,
      anon_sym_PIPE,
    STATE(16755), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711692] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23457), 1,
      aux_sym_type_variable_token1,
    STATE(13074), 1,
      sym_type_variable,
    STATE(16756), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711709] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23085), 1,
      anon_sym_then,
    STATE(8522), 1,
      sym_then_clause,
    STATE(16757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711726] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23435), 1,
      anon_sym_do,
    STATE(8263), 1,
      sym_do_clause,
    STATE(16758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711743] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(23459), 1,
      sym__lowercase_identifier,
    STATE(16759), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711760] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(23461), 1,
      sym__lowercase_identifier,
    STATE(16760), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711777] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23463), 1,
      anon_sym_RPAREN,
    ACTIONS(23465), 1,
      anon_sym_LT_DASH,
    STATE(16761), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711794] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23467), 1,
      anon_sym_EQ,
    ACTIONS(23469), 1,
      anon_sym_RPAREN,
    STATE(16762), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711811] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16763), 1,
      sym_attribute,
    STATE(18793), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711828] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16910), 1,
      anon_sym_STAR,
    ACTIONS(23471), 1,
      anon_sym_DASH_GT,
    STATE(16764), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711845] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17807), 1,
      anon_sym_RBRACE,
    ACTIONS(23473), 1,
      anon_sym_SEMI,
    STATE(16765), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711862] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23475), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [711877] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17795), 1,
      anon_sym_RBRACE,
    ACTIONS(23477), 1,
      anon_sym_SEMI,
    STATE(16767), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711894] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23479), 1,
      anon_sym_RPAREN,
    ACTIONS(23481), 1,
      anon_sym_LT_DASH,
    STATE(16768), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711911] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16910), 1,
      anon_sym_STAR,
    ACTIONS(23483), 1,
      anon_sym_DASH_GT,
    STATE(16769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711928] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16770), 1,
      sym_attribute,
    STATE(19801), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711945] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23485), 1,
      anon_sym_RPAREN,
    ACTIONS(23487), 1,
      anon_sym_LT_DASH,
    STATE(16771), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711962] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23489), 1,
      anon_sym_SEMI,
    ACTIONS(23491), 1,
      anon_sym_RBRACE,
    STATE(16772), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711979] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23493), 1,
      anon_sym_SEMI,
    ACTIONS(23495), 1,
      anon_sym_RBRACE,
    STATE(16773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711996] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23435), 1,
      anon_sym_do,
    STATE(8252), 1,
      sym_do_clause,
    STATE(16774), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712013] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23497), 1,
      anon_sym_RPAREN,
    ACTIONS(23499), 1,
      anon_sym_LT_DASH,
    STATE(16775), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712030] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18456), 1,
      sym__lowercase_identifier,
    STATE(14908), 1,
      sym__simple_value_pattern,
    STATE(16776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712047] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23435), 1,
      anon_sym_do,
    STATE(8157), 1,
      sym_do_clause,
    STATE(16777), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712064] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23501), 1,
      anon_sym_DOT,
    STATE(16778), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712081] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23503), 1,
      anon_sym_then,
    STATE(12321), 1,
      sym_then_clause,
    STATE(16779), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712098] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23505), 1,
      anon_sym_EQ,
    ACTIONS(23507), 1,
      anon_sym_RPAREN,
    STATE(16780), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712115] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8843), 1,
      anon_sym_COLON_GT,
    ACTIONS(8845), 1,
      anon_sym_EQ,
    STATE(16781), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712132] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23509), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [712147] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16783), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23511), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [712162] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16784), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23513), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [712177] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17651), 1,
      sym__lowercase_identifier,
    STATE(16785), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712194] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23515), 1,
      anon_sym_RPAREN,
    ACTIONS(23517), 1,
      anon_sym_LT_DASH,
    STATE(16786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712211] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23519), 1,
      anon_sym_DOT,
    STATE(16787), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712228] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23521), 1,
      anon_sym_DOT,
    STATE(16788), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712245] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23523), 1,
      anon_sym_RPAREN,
    ACTIONS(23525), 1,
      anon_sym_LT_DASH,
    STATE(16789), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712262] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23503), 1,
      anon_sym_then,
    STATE(12436), 1,
      sym_then_clause,
    STATE(16790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712279] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23527), 1,
      sym__lowercase_identifier,
    ACTIONS(23529), 1,
      anon_sym_LPAREN,
    STATE(16791), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712296] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16910), 1,
      anon_sym_STAR,
    ACTIONS(23531), 1,
      anon_sym_DASH_GT,
    STATE(16792), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712313] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23533), 1,
      anon_sym_COLON_GT,
    ACTIONS(23535), 1,
      anon_sym_RPAREN,
    STATE(16793), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712330] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9886), 1,
      anon_sym_RBRACK,
    ACTIONS(18464), 1,
      anon_sym_PIPE,
    STATE(16794), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712347] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16795), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23537), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [712362] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(23539), 1,
      sym__lowercase_identifier,
    STATE(16796), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712379] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5279), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9838), 1,
      anon_sym_RPAREN,
    STATE(16797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712396] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23541), 1,
      anon_sym_RPAREN,
    ACTIONS(23543), 1,
      anon_sym_SEMI,
    STATE(16798), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712413] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23541), 1,
      anon_sym_RBRACK,
    ACTIONS(23545), 1,
      anon_sym_SEMI,
    STATE(16799), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712430] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23541), 1,
      anon_sym_RBRACE,
    ACTIONS(23547), 1,
      anon_sym_SEMI,
    STATE(16800), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712447] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(23549), 1,
      sym__lowercase_identifier,
    STATE(16801), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712464] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23551), 1,
      anon_sym_RPAREN,
    ACTIONS(23553), 1,
      anon_sym_LT_DASH,
    STATE(16802), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712481] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23555), 1,
      anon_sym_EQ,
    ACTIONS(23557), 1,
      anon_sym_RPAREN,
    STATE(16803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712498] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16804), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23559), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [712513] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5279), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9814), 1,
      anon_sym_RPAREN,
    STATE(16805), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712530] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16910), 1,
      anon_sym_STAR,
    ACTIONS(23561), 1,
      anon_sym_DASH_GT,
    STATE(16806), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712547] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23563), 1,
      anon_sym_RPAREN,
    ACTIONS(23565), 1,
      anon_sym_LT_DASH,
    STATE(16807), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712564] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16808), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23567), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [712579] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17959), 1,
      anon_sym_RBRACE,
    ACTIONS(23569), 1,
      anon_sym_SEMI,
    STATE(16809), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712596] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23571), 1,
      anon_sym_RPAREN,
    ACTIONS(23573), 1,
      anon_sym_LT_DASH,
    STATE(16810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712613] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21886), 1,
      anon_sym_EQ,
    ACTIONS(23575), 1,
      anon_sym_COLON_GT,
    STATE(16811), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712630] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17817), 1,
      anon_sym_RBRACE,
    ACTIONS(23577), 1,
      anon_sym_SEMI,
    STATE(16812), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712647] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5279), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9854), 1,
      anon_sym_RPAREN,
    STATE(16813), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712664] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16910), 1,
      anon_sym_STAR,
    ACTIONS(23579), 1,
      anon_sym_DASH_GT,
    STATE(16814), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712681] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23581), 1,
      anon_sym_SEMI,
    ACTIONS(23583), 1,
      anon_sym_RBRACE,
    STATE(16815), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712698] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23585), 1,
      anon_sym_then,
    STATE(8258), 1,
      sym_then_clause,
    STATE(16816), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712715] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23587), 1,
      anon_sym_RPAREN,
    ACTIONS(23589), 1,
      anon_sym_LT_DASH,
    STATE(16817), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712732] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5279), 1,
      anon_sym_COLON_COLON,
    ACTIONS(23591), 1,
      anon_sym_RPAREN,
    STATE(16818), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712749] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23593), 1,
      anon_sym_then,
    STATE(12284), 1,
      sym_then_clause,
    STATE(16819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712766] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(16820), 1,
      sym_attribute,
    STATE(19766), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712783] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23595), 1,
      anon_sym_EQ,
    ACTIONS(23597), 1,
      anon_sym_RPAREN,
    STATE(16821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712800] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16822), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23599), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [712815] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23601), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [712830] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23603), 1,
      anon_sym_RPAREN,
    ACTIONS(23605), 1,
      anon_sym_LT_DASH,
    STATE(16824), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712847] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16825), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23607), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [712862] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23609), 1,
      anon_sym_RPAREN,
    ACTIONS(23611), 1,
      anon_sym_LT_DASH,
    STATE(16826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712879] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17671), 1,
      sym__lowercase_identifier,
    STATE(16827), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712896] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5279), 1,
      anon_sym_COLON_COLON,
    ACTIONS(23613), 1,
      anon_sym_RPAREN,
    STATE(16828), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712913] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23615), 1,
      anon_sym_DOT,
    STATE(16829), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712930] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23593), 1,
      anon_sym_then,
    STATE(12576), 1,
      sym_then_clause,
    STATE(16830), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712947] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23617), 1,
      sym__lowercase_identifier,
    ACTIONS(23619), 1,
      anon_sym_LPAREN,
    STATE(16831), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712964] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23621), 1,
      anon_sym_COLON_GT,
    ACTIONS(23623), 1,
      anon_sym_RPAREN,
    STATE(16832), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712981] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10064), 1,
      anon_sym_RBRACK,
    ACTIONS(18464), 1,
      anon_sym_PIPE,
    STATE(16833), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712998] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5279), 1,
      anon_sym_COLON_COLON,
    ACTIONS(23625), 1,
      anon_sym_RPAREN,
    STATE(16834), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713015] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23095), 1,
      anon_sym_then,
    STATE(8557), 1,
      sym_then_clause,
    STATE(16835), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713032] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(23627), 1,
      sym__lowercase_identifier,
    STATE(16836), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713049] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16837), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23629), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [713064] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(23631), 1,
      sym__lowercase_identifier,
    STATE(16838), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713081] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16839), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23633), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [713096] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23635), 1,
      anon_sym_RPAREN,
    ACTIONS(23637), 1,
      anon_sym_LT_DASH,
    STATE(16840), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713113] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23639), 1,
      anon_sym_RPAREN,
    ACTIONS(23641), 1,
      anon_sym_LT_DASH,
    STATE(16841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713130] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5279), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9786), 1,
      anon_sym_RPAREN,
    STATE(16842), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713147] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23643), 1,
      anon_sym_RPAREN,
    ACTIONS(23645), 1,
      anon_sym_LT_DASH,
    STATE(16843), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713164] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23647), 1,
      anon_sym_EQ,
    ACTIONS(23649), 1,
      anon_sym_RPAREN,
    STATE(16844), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713181] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17993), 1,
      anon_sym_RBRACE,
    ACTIONS(23651), 1,
      anon_sym_SEMI,
    STATE(16845), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713198] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17997), 1,
      anon_sym_RBRACE,
    ACTIONS(23653), 1,
      anon_sym_SEMI,
    STATE(16846), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713215] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23655), 1,
      anon_sym_SEMI,
    ACTIONS(23657), 1,
      anon_sym_RBRACE,
    STATE(16847), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713232] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23659), 1,
      anon_sym_SEMI,
    ACTIONS(23661), 1,
      anon_sym_RBRACE,
    STATE(16848), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713249] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23663), 1,
      anon_sym_RPAREN,
    ACTIONS(23665), 1,
      anon_sym_LT_DASH,
    STATE(16849), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713266] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5279), 1,
      anon_sym_COLON_COLON,
    ACTIONS(23667), 1,
      anon_sym_RPAREN,
    STATE(16850), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713283] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23669), 1,
      anon_sym_then,
    STATE(9683), 1,
      sym_then_clause,
    STATE(16851), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713300] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16852), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23671), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [713315] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23673), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [713330] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23675), 1,
      anon_sym_RPAREN,
    ACTIONS(23677), 1,
      anon_sym_LT_DASH,
    STATE(16854), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713347] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16855), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23679), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [713362] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23681), 1,
      anon_sym_RPAREN,
    ACTIONS(23683), 1,
      anon_sym_LT_DASH,
    STATE(16856), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713379] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(23685), 1,
      sym__lowercase_identifier,
    STATE(16857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713396] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23687), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [713411] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23689), 1,
      anon_sym_DOT,
    STATE(16859), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713428] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23669), 1,
      anon_sym_then,
    STATE(9706), 1,
      sym_then_clause,
    STATE(16860), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713445] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5279), 1,
      anon_sym_COLON_COLON,
    ACTIONS(23691), 1,
      anon_sym_RPAREN,
    STATE(16861), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713462] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23693), 1,
      sym__lowercase_identifier,
    ACTIONS(23695), 1,
      anon_sym_LPAREN,
    STATE(16862), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713479] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16863), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23697), 2,
      anon_sym_to,
      anon_sym_downto,
  [713494] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23699), 1,
      anon_sym_COLON_GT,
    ACTIONS(23701), 1,
      anon_sym_RPAREN,
    STATE(16864), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713511] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16865), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23703), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [713526] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10196), 1,
      anon_sym_RBRACK,
    ACTIONS(18464), 1,
      anon_sym_PIPE,
    STATE(16866), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713543] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23705), 1,
      anon_sym_RPAREN,
    ACTIONS(23707), 1,
      anon_sym_LT_DASH,
    STATE(16867), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713560] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23709), 1,
      anon_sym_then,
    STATE(8362), 1,
      sym_then_clause,
    STATE(16868), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713577] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23711), 1,
      anon_sym_RPAREN,
    ACTIONS(23713), 1,
      anon_sym_LT_DASH,
    STATE(16869), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713594] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(23715), 1,
      sym__lowercase_identifier,
    STATE(16870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713611] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(23717), 1,
      sym__lowercase_identifier,
    STATE(16871), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713628] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16872), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23719), 2,
      anon_sym_to,
      anon_sym_downto,
  [713643] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23721), 1,
      anon_sym_RPAREN,
    ACTIONS(23723), 1,
      anon_sym_LT_DASH,
    STATE(16873), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713660] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18333), 1,
      anon_sym_RBRACE,
    ACTIONS(23725), 1,
      anon_sym_SEMI,
    STATE(16874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713677] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18321), 1,
      anon_sym_RBRACE,
    ACTIONS(23727), 1,
      anon_sym_SEMI,
    STATE(16875), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713694] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23729), 1,
      anon_sym_SEMI,
    ACTIONS(23731), 1,
      anon_sym_RBRACE,
    STATE(16876), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713711] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23733), 1,
      anon_sym_SEMI,
    ACTIONS(23735), 1,
      anon_sym_RBRACE,
    STATE(16877), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713728] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23737), 1,
      anon_sym_RPAREN,
    ACTIONS(23739), 1,
      anon_sym_LT_DASH,
    STATE(16878), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713745] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23741), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [713760] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23743), 1,
      anon_sym_then,
    STATE(12211), 1,
      sym_then_clause,
    STATE(16880), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713777] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23745), 1,
      anon_sym_RPAREN,
    ACTIONS(23747), 1,
      anon_sym_LT_DASH,
    STATE(16881), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713794] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16882), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23749), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [713809] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23751), 1,
      anon_sym_RPAREN,
    ACTIONS(23753), 1,
      anon_sym_LT_DASH,
    STATE(16883), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713826] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16884), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23755), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [713841] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(23757), 1,
      sym__lowercase_identifier,
    STATE(16885), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713858] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(23759), 1,
      sym__lowercase_identifier,
    STATE(16886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713875] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17547), 1,
      sym__lowercase_identifier,
    STATE(16887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713892] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5279), 1,
      anon_sym_COLON_COLON,
    ACTIONS(23761), 1,
      anon_sym_RPAREN,
    STATE(16888), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713909] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23763), 1,
      anon_sym_DOT,
    STATE(16889), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713926] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23743), 1,
      anon_sym_then,
    STATE(11909), 1,
      sym_then_clause,
    STATE(16890), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713943] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16891), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23765), 2,
      anon_sym_to,
      anon_sym_downto,
  [713958] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23767), 1,
      sym__lowercase_identifier,
    ACTIONS(23769), 1,
      anon_sym_LPAREN,
    STATE(16892), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713975] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16893), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23771), 2,
      anon_sym_to,
      anon_sym_downto,
  [713990] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23773), 1,
      anon_sym_COLON_GT,
    ACTIONS(23775), 1,
      anon_sym_RPAREN,
    STATE(16894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714007] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9974), 1,
      anon_sym_RBRACK,
    ACTIONS(18464), 1,
      anon_sym_PIPE,
    STATE(16895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714024] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23777), 1,
      anon_sym_then,
    STATE(8342), 1,
      sym_then_clause,
    STATE(16896), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714041] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(23779), 1,
      sym__lowercase_identifier,
    STATE(16897), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714058] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16898), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23781), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [714073] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23783), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [714088] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23785), 1,
      anon_sym_COLON_GT,
    ACTIONS(23787), 1,
      anon_sym_RPAREN,
    STATE(16900), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714105] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23789), 1,
      anon_sym_RPAREN,
    ACTIONS(23791), 1,
      anon_sym_LT_DASH,
    STATE(16901), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714122] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23793), 1,
      anon_sym_DOT,
    STATE(16902), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714139] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(23795), 1,
      sym__lowercase_identifier,
    STATE(16903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714156] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17865), 1,
      anon_sym_RBRACE,
    ACTIONS(23797), 1,
      anon_sym_SEMI,
    STATE(16904), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714173] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23799), 1,
      anon_sym_SEMI,
    ACTIONS(23801), 1,
      anon_sym_RBRACE,
    STATE(16905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714190] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23803), 1,
      anon_sym_RPAREN,
    ACTIONS(23805), 1,
      anon_sym_LT_DASH,
    STATE(16906), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714207] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23807), 1,
      anon_sym_then,
    STATE(11778), 1,
      sym_then_clause,
    STATE(16907), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714224] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23809), 1,
      anon_sym_RPAREN,
    ACTIONS(23811), 1,
      anon_sym_LT_DASH,
    STATE(16908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714241] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23813), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [714256] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23815), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [714271] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23817), 1,
      anon_sym_RPAREN,
    ACTIONS(23819), 1,
      anon_sym_LT_DASH,
    STATE(16911), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714288] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(23821), 1,
      sym__lowercase_identifier,
    STATE(16912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714305] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5279), 1,
      anon_sym_COLON_COLON,
    ACTIONS(23823), 1,
      anon_sym_RPAREN,
    STATE(16913), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714322] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23825), 1,
      anon_sym_DOT,
    STATE(16914), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714339] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23807), 1,
      anon_sym_then,
    STATE(11801), 1,
      sym_then_clause,
    STATE(16915), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714356] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23827), 1,
      sym__lowercase_identifier,
    ACTIONS(23829), 1,
      anon_sym_LPAREN,
    STATE(16916), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714373] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23831), 1,
      anon_sym_COLON_GT,
    ACTIONS(23833), 1,
      anon_sym_RPAREN,
    STATE(16917), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714390] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9984), 1,
      anon_sym_RBRACK,
    ACTIONS(18464), 1,
      anon_sym_PIPE,
    STATE(16918), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714407] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23101), 1,
      anon_sym_then,
    STATE(8280), 1,
      sym_then_clause,
    STATE(16919), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714424] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(23835), 1,
      sym__lowercase_identifier,
    STATE(16920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714441] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(23837), 1,
      sym__lowercase_identifier,
    STATE(16921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714458] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16922), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23839), 2,
      anon_sym_to,
      anon_sym_downto,
  [714473] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(23841), 1,
      sym__lowercase_identifier,
    STATE(16923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714490] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16924), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23843), 2,
      anon_sym_to,
      anon_sym_downto,
  [714505] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23585), 1,
      anon_sym_then,
    STATE(8276), 1,
      sym_then_clause,
    STATE(16925), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714522] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23845), 1,
      anon_sym_RPAREN,
    ACTIONS(23847), 1,
      anon_sym_LT_DASH,
    STATE(16926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714539] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16927), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23849), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [714554] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23851), 1,
      anon_sym_RPAREN,
    ACTIONS(23853), 1,
      anon_sym_LT_DASH,
    STATE(16928), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714571] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23855), 1,
      anon_sym_then,
    STATE(11428), 1,
      sym_then_clause,
    STATE(16929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714588] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16930), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23857), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [714603] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16931), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23859), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [714618] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(23861), 1,
      sym__lowercase_identifier,
    STATE(16932), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714635] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16933), 1,
      sym_attribute,
    STATE(18706), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714652] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23863), 1,
      anon_sym_DOT,
    STATE(16934), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714669] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16935), 1,
      sym_attribute,
    STATE(19672), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714686] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23865), 1,
      sym__lowercase_identifier,
    ACTIONS(23867), 1,
      anon_sym_LPAREN,
    STATE(16936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714703] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23869), 1,
      anon_sym_COLON_GT,
    ACTIONS(23871), 1,
      anon_sym_RPAREN,
    STATE(16937), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714720] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10227), 1,
      anon_sym_RBRACK,
    ACTIONS(18464), 1,
      anon_sym_PIPE,
    STATE(16938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714737] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18456), 1,
      sym__lowercase_identifier,
    STATE(14563), 1,
      sym__simple_value_pattern,
    STATE(16939), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714754] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23585), 1,
      anon_sym_then,
    STATE(8132), 1,
      sym_then_clause,
    STATE(16940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714771] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23873), 1,
      anon_sym_DOT,
    STATE(16941), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714788] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23855), 1,
      anon_sym_then,
    STATE(11236), 1,
      sym_then_clause,
    STATE(16942), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714805] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(23875), 1,
      sym__lowercase_identifier,
    STATE(16943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714822] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23877), 1,
      anon_sym_RPAREN,
    ACTIONS(23879), 1,
      anon_sym_LT_DASH,
    STATE(16944), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714839] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5279), 1,
      anon_sym_COLON_COLON,
    ACTIONS(23881), 1,
      anon_sym_RPAREN,
    STATE(16945), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714856] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16946), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23883), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [714871] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16947), 1,
      sym_attribute,
    STATE(20383), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714888] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23885), 1,
      anon_sym_DOT,
    STATE(16948), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714905] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23887), 1,
      anon_sym_RPAREN,
    ACTIONS(23889), 1,
      anon_sym_LT_DASH,
    STATE(16949), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714922] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16950), 1,
      sym_attribute,
    STATE(20325), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714939] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16951), 1,
      sym_attribute,
    STATE(20315), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714956] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23891), 1,
      anon_sym_RPAREN,
    ACTIONS(23893), 1,
      anon_sym_LT_DASH,
    STATE(16952), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714973] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16953), 1,
      sym_attribute,
    STATE(20301), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714990] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(23895), 1,
      sym__lowercase_identifier,
    STATE(16954), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715007] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16955), 1,
      sym_attribute,
    STATE(20286), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715024] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16956), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23897), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [715039] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16957), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23899), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [715054] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23901), 1,
      anon_sym_RPAREN,
    ACTIONS(23903), 1,
      anon_sym_SEMI,
    STATE(16958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715071] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23901), 1,
      anon_sym_RBRACK,
    ACTIONS(23905), 1,
      anon_sym_SEMI,
    STATE(16959), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715088] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23901), 1,
      anon_sym_RBRACE,
    ACTIONS(23907), 1,
      anon_sym_SEMI,
    STATE(16960), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715105] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23909), 1,
      anon_sym_RPAREN,
    ACTIONS(23911), 1,
      anon_sym_LT_DASH,
    STATE(16961), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715122] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16962), 1,
      sym_attribute,
    STATE(20283), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715139] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16963), 1,
      sym_attribute,
    STATE(20276), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715156] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(23913), 1,
      sym__lowercase_identifier,
    STATE(16964), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715173] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16965), 1,
      sym_attribute,
    STATE(20260), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715190] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16966), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23915), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [715205] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16967), 1,
      sym_attribute,
    STATE(20224), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715222] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16968), 1,
      sym_attribute,
    STATE(20243), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715239] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16969), 1,
      sym_attribute,
    STATE(20238), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715256] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(23917), 1,
      anon_sym_DOT,
    STATE(16970), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715273] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16971), 1,
      sym_attribute,
    STATE(20234), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715290] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(23919), 1,
      sym__lowercase_identifier,
    STATE(16972), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715307] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23215), 1,
      anon_sym_then,
    STATE(10483), 1,
      sym_then_clause,
    STATE(16973), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715324] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16974), 1,
      sym_attribute,
    STATE(20214), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715341] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23921), 1,
      anon_sym_COLON_GT,
    ACTIONS(23923), 1,
      anon_sym_RPAREN,
    STATE(16975), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715358] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(16976), 1,
      sym_attribute,
    STATE(19636), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715375] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16977), 1,
      sym_attribute,
    STATE(20203), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715392] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16978), 1,
      sym_attribute,
    STATE(20188), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715409] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23925), 1,
      sym__lowercase_identifier,
    ACTIONS(23927), 1,
      anon_sym_LPAREN,
    STATE(16979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715426] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16980), 1,
      sym_attribute,
    STATE(20164), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715443] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16981), 1,
      sym_attribute,
    STATE(20147), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715460] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16982), 1,
      sym_attribute,
    STATE(20141), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715477] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23929), 1,
      anon_sym_COLON_GT,
    ACTIONS(23931), 1,
      anon_sym_RPAREN,
    STATE(16983), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715494] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10214), 1,
      anon_sym_RBRACK,
    ACTIONS(18464), 1,
      anon_sym_PIPE,
    STATE(16984), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715511] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16985), 1,
      sym_attribute,
    STATE(20134), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715528] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23215), 1,
      anon_sym_then,
    STATE(10579), 1,
      sym_then_clause,
    STATE(16986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715545] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16987), 1,
      sym_attribute,
    STATE(19994), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715562] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23709), 1,
      anon_sym_then,
    STATE(8376), 1,
      sym_then_clause,
    STATE(16988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715579] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16989), 1,
      sym_attribute,
    STATE(20107), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715596] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(23933), 1,
      sym__lowercase_identifier,
    STATE(16990), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715613] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16991), 1,
      sym_attribute,
    STATE(20086), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715630] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16992), 1,
      sym_attribute,
    STATE(20078), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715647] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(23935), 1,
      sym__lowercase_identifier,
    STATE(16993), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715664] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23937), 1,
      anon_sym_SEMI,
    ACTIONS(23939), 1,
      anon_sym_RBRACE,
    STATE(16994), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715681] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23939), 1,
      anon_sym_RBRACK,
    ACTIONS(23941), 1,
      anon_sym_SEMI,
    STATE(16995), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715698] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(16996), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23943), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [715713] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23939), 1,
      anon_sym_RPAREN,
    ACTIONS(23945), 1,
      anon_sym_SEMI,
    STATE(16997), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715730] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23947), 1,
      anon_sym_RPAREN,
    ACTIONS(23949), 1,
      anon_sym_LT_DASH,
    STATE(16998), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715747] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(16999), 1,
      sym_attribute,
    STATE(20045), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715764] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23951), 1,
      anon_sym_SEMI,
    ACTIONS(23953), 1,
      anon_sym_RBRACE,
    STATE(17000), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715781] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23953), 1,
      anon_sym_RBRACK,
    ACTIONS(23955), 1,
      anon_sym_SEMI,
    STATE(17001), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715798] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23953), 1,
      anon_sym_RPAREN,
    ACTIONS(23957), 1,
      anon_sym_SEMI,
    STATE(17002), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715815] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17003), 1,
      sym_attribute,
    STATE(20001), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715832] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23959), 1,
      anon_sym_RPAREN,
    ACTIONS(23961), 1,
      anon_sym_LT_DASH,
    STATE(17004), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715849] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23963), 1,
      anon_sym_RPAREN,
    ACTIONS(23965), 1,
      anon_sym_LT_DASH,
    STATE(17005), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715866] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23967), 1,
      anon_sym_SEMI,
    ACTIONS(23969), 1,
      anon_sym_RBRACE,
    STATE(17006), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715883] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23969), 1,
      anon_sym_RBRACK,
    ACTIONS(23971), 1,
      anon_sym_SEMI,
    STATE(17007), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715900] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23969), 1,
      anon_sym_RPAREN,
    ACTIONS(23973), 1,
      anon_sym_SEMI,
    STATE(17008), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715917] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17009), 1,
      sym_attribute,
    STATE(19969), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715934] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23975), 1,
      anon_sym_SEMI,
    ACTIONS(23977), 1,
      anon_sym_RBRACE,
    STATE(17010), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715951] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23977), 1,
      anon_sym_RBRACK,
    ACTIONS(23979), 1,
      anon_sym_SEMI,
    STATE(17011), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715968] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23977), 1,
      anon_sym_RPAREN,
    ACTIONS(23981), 1,
      anon_sym_SEMI,
    STATE(17012), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715985] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(23983), 1,
      sym__lowercase_identifier,
    STATE(17013), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716002] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17014), 1,
      sym_attribute,
    STATE(19924), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716019] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23985), 1,
      anon_sym_COLON_GT,
    ACTIONS(23987), 1,
      anon_sym_RPAREN,
    STATE(17015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716036] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23989), 1,
      anon_sym_SEMI,
    ACTIONS(23991), 1,
      anon_sym_RBRACE,
    STATE(17016), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716053] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23991), 1,
      anon_sym_RBRACK,
    ACTIONS(23993), 1,
      anon_sym_SEMI,
    STATE(17017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716070] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23991), 1,
      anon_sym_RPAREN,
    ACTIONS(23995), 1,
      anon_sym_SEMI,
    STATE(17018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716087] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17019), 1,
      sym_attribute,
    STATE(19874), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716104] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23997), 1,
      anon_sym_SEMI,
    ACTIONS(23999), 1,
      anon_sym_RBRACE,
    STATE(17020), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716121] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23999), 1,
      anon_sym_RBRACK,
    ACTIONS(24001), 1,
      anon_sym_SEMI,
    STATE(17021), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716138] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23999), 1,
      anon_sym_RPAREN,
    ACTIONS(24003), 1,
      anon_sym_SEMI,
    STATE(17022), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716155] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(24005), 1,
      sym__lowercase_identifier,
    STATE(17023), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716172] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17024), 1,
      sym_attribute,
    STATE(19819), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716189] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24007), 1,
      anon_sym_SEMI,
    ACTIONS(24009), 1,
      anon_sym_RBRACE,
    STATE(17025), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716206] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24009), 1,
      anon_sym_RBRACK,
    ACTIONS(24011), 1,
      anon_sym_SEMI,
    STATE(17026), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716223] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24009), 1,
      anon_sym_RPAREN,
    ACTIONS(24013), 1,
      anon_sym_SEMI,
    STATE(17027), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716240] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17028), 1,
      sym_attribute,
    STATE(19753), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716257] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24015), 1,
      anon_sym_RPAREN,
    ACTIONS(24017), 1,
      anon_sym_LT_DASH,
    STATE(17029), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716274] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24019), 1,
      anon_sym_SEMI,
    ACTIONS(24021), 1,
      anon_sym_RBRACE,
    STATE(17030), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716291] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17031), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24023), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [716306] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24021), 1,
      anon_sym_RBRACK,
    ACTIONS(24025), 1,
      anon_sym_SEMI,
    STATE(17032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716323] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24027), 1,
      anon_sym_RPAREN,
    ACTIONS(24029), 1,
      anon_sym_LT_DASH,
    STATE(17033), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716340] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24021), 1,
      anon_sym_RPAREN,
    ACTIONS(24031), 1,
      anon_sym_SEMI,
    STATE(17034), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716357] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17035), 1,
      sym_attribute,
    STATE(19707), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716374] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23027), 1,
      anon_sym_then,
    STATE(10294), 1,
      sym_then_clause,
    STATE(17036), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716391] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24033), 1,
      anon_sym_DOT,
    STATE(17037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716408] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24035), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [716423] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24037), 1,
      anon_sym_SEMI,
    ACTIONS(24039), 1,
      anon_sym_RBRACE,
    STATE(17039), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716440] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24041), 1,
      anon_sym_RPAREN,
    ACTIONS(24043), 1,
      anon_sym_LT_DASH,
    STATE(17040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716457] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24039), 1,
      anon_sym_RBRACK,
    ACTIONS(24045), 1,
      anon_sym_SEMI,
    STATE(17041), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716474] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24039), 1,
      anon_sym_RPAREN,
    ACTIONS(24047), 1,
      anon_sym_SEMI,
    STATE(17042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716491] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17043), 1,
      sym_attribute,
    STATE(19640), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716508] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(24049), 1,
      sym__lowercase_identifier,
    STATE(17044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716525] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24051), 1,
      anon_sym_SEMI,
    ACTIONS(24053), 1,
      anon_sym_RBRACE,
    STATE(17045), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716542] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24053), 1,
      anon_sym_RBRACK,
    ACTIONS(24055), 1,
      anon_sym_SEMI,
    STATE(17046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716559] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24053), 1,
      anon_sym_RPAREN,
    ACTIONS(24057), 1,
      anon_sym_SEMI,
    STATE(17047), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716576] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17048), 1,
      sym_attribute,
    STATE(19599), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716593] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24059), 1,
      anon_sym_SEMI,
    ACTIONS(24061), 1,
      anon_sym_RBRACE,
    STATE(17049), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716610] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24061), 1,
      anon_sym_RBRACK,
    ACTIONS(24063), 1,
      anon_sym_SEMI,
    STATE(17050), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716627] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24061), 1,
      anon_sym_RPAREN,
    ACTIONS(24065), 1,
      anon_sym_SEMI,
    STATE(17051), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716644] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17052), 1,
      sym_attribute,
    STATE(19534), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716661] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24067), 1,
      anon_sym_SEMI,
    ACTIONS(24069), 1,
      anon_sym_RBRACE,
    STATE(17053), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716678] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24071), 1,
      anon_sym_COLON_GT,
    ACTIONS(24073), 1,
      anon_sym_RPAREN,
    STATE(17054), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716695] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24069), 1,
      anon_sym_RBRACK,
    ACTIONS(24075), 1,
      anon_sym_SEMI,
    STATE(17055), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716712] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24069), 1,
      anon_sym_RPAREN,
    ACTIONS(24077), 1,
      anon_sym_SEMI,
    STATE(17056), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716729] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17057), 1,
      sym_attribute,
    STATE(19492), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716746] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24079), 1,
      anon_sym_DOT,
    STATE(17058), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716763] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23095), 1,
      anon_sym_then,
    STATE(8485), 1,
      sym_then_clause,
    STATE(17059), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716780] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23027), 1,
      anon_sym_then,
    STATE(10137), 1,
      sym_then_clause,
    STATE(17060), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716797] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24081), 1,
      anon_sym_SEMI,
    ACTIONS(24083), 1,
      anon_sym_RBRACE,
    STATE(17061), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716814] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24083), 1,
      anon_sym_RBRACK,
    ACTIONS(24085), 1,
      anon_sym_SEMI,
    STATE(17062), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716831] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24083), 1,
      anon_sym_RPAREN,
    ACTIONS(24087), 1,
      anon_sym_SEMI,
    STATE(17063), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716848] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17064), 1,
      sym_attribute,
    STATE(19457), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716865] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24089), 1,
      sym__lowercase_identifier,
    ACTIONS(24091), 1,
      anon_sym_LPAREN,
    STATE(17065), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716882] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24093), 1,
      anon_sym_SEMI,
    ACTIONS(24095), 1,
      anon_sym_RBRACE,
    STATE(17066), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716899] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17067), 1,
      sym_attribute,
    STATE(18618), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716916] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24095), 1,
      anon_sym_RBRACK,
    ACTIONS(24097), 1,
      anon_sym_SEMI,
    STATE(17068), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716933] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17069), 1,
      sym_attribute,
    STATE(19549), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716950] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24095), 1,
      anon_sym_RPAREN,
    ACTIONS(24099), 1,
      anon_sym_SEMI,
    STATE(17070), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716967] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17071), 1,
      sym_attribute,
    STATE(19408), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716984] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18456), 1,
      sym__lowercase_identifier,
    STATE(14441), 1,
      sym__simple_value_pattern,
    STATE(17072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717001] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24101), 1,
      anon_sym_COLON_GT,
    ACTIONS(24103), 1,
      anon_sym_RPAREN,
    STATE(17073), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717018] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10178), 1,
      anon_sym_RBRACK,
    ACTIONS(18464), 1,
      anon_sym_PIPE,
    STATE(17074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717035] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23777), 1,
      anon_sym_then,
    STATE(8314), 1,
      sym_then_clause,
    STATE(17075), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717052] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17076), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24105), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [717067] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(24107), 1,
      sym__lowercase_identifier,
    STATE(17077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717084] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17078), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24109), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [717099] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24111), 1,
      anon_sym_DOT,
    STATE(17079), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717116] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24113), 1,
      anon_sym_SEMI,
    ACTIONS(24115), 1,
      anon_sym_RBRACE,
    STATE(17080), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717133] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24117), 1,
      anon_sym_RPAREN,
    ACTIONS(24119), 1,
      anon_sym_LT_DASH,
    STATE(17081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717150] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24115), 1,
      anon_sym_RBRACK,
    ACTIONS(24121), 1,
      anon_sym_SEMI,
    STATE(17082), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717167] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24115), 1,
      anon_sym_RPAREN,
    ACTIONS(24123), 1,
      anon_sym_SEMI,
    STATE(17083), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717184] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(24125), 1,
      sym__lowercase_identifier,
    STATE(17084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717201] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24127), 1,
      anon_sym_RPAREN,
    ACTIONS(24129), 1,
      anon_sym_LT_DASH,
    STATE(17085), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717218] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17086), 1,
      sym_attribute,
    STATE(19310), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717235] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24131), 1,
      anon_sym_RPAREN,
    ACTIONS(24133), 1,
      anon_sym_LT_DASH,
    STATE(17087), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717252] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24135), 1,
      anon_sym_SEMI,
    ACTIONS(24137), 1,
      anon_sym_RBRACE,
    STATE(17088), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717269] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24139), 1,
      anon_sym_RPAREN,
    ACTIONS(24141), 1,
      anon_sym_SEMI,
    STATE(17089), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717286] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24139), 1,
      anon_sym_RBRACK,
    ACTIONS(24143), 1,
      anon_sym_SEMI,
    STATE(17090), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717303] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24139), 1,
      anon_sym_RBRACE,
    ACTIONS(24145), 1,
      anon_sym_SEMI,
    STATE(17091), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717320] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24137), 1,
      anon_sym_RBRACK,
    ACTIONS(24147), 1,
      anon_sym_SEMI,
    STATE(17092), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717337] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24137), 1,
      anon_sym_RPAREN,
    ACTIONS(24149), 1,
      anon_sym_SEMI,
    STATE(17093), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717354] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24151), 1,
      anon_sym_RPAREN,
    ACTIONS(24153), 1,
      anon_sym_LT_DASH,
    STATE(17094), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717371] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17095), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24155), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [717386] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23317), 1,
      anon_sym_then,
    STATE(12406), 1,
      sym_then_clause,
    STATE(17096), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717403] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17097), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24157), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [717418] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17098), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24159), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [717433] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(24161), 1,
      sym__lowercase_identifier,
    STATE(17099), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717450] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17100), 1,
      sym_attribute,
    STATE(19174), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717467] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24163), 1,
      anon_sym_DOT,
    STATE(17101), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717484] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24165), 1,
      anon_sym_SEMI,
    ACTIONS(24167), 1,
      anon_sym_RBRACE,
    STATE(17102), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717501] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24167), 1,
      anon_sym_RBRACK,
    ACTIONS(24169), 1,
      anon_sym_SEMI,
    STATE(17103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717518] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17104), 1,
      sym_attribute,
    STATE(19521), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717535] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24167), 1,
      anon_sym_RPAREN,
    ACTIONS(24171), 1,
      anon_sym_SEMI,
    STATE(17105), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717552] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(24173), 1,
      sym__lowercase_identifier,
    STATE(17106), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717569] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24175), 1,
      sym__lowercase_identifier,
    ACTIONS(24177), 1,
      anon_sym_LPAREN,
    STATE(17107), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717586] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24179), 1,
      anon_sym_COLON_GT,
    ACTIONS(24181), 1,
      anon_sym_RPAREN,
    STATE(17108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717603] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17109), 1,
      sym_attribute,
    STATE(19102), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717620] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24183), 1,
      anon_sym_COLON_GT,
    ACTIONS(24185), 1,
      anon_sym_RPAREN,
    STATE(17110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717637] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10096), 1,
      anon_sym_RBRACK,
    ACTIONS(18464), 1,
      anon_sym_PIPE,
    STATE(17111), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717654] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(24187), 1,
      sym__lowercase_identifier,
    STATE(17112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717671] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(24189), 1,
      sym__lowercase_identifier,
    STATE(17113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717688] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24191), 1,
      anon_sym_SEMI,
    ACTIONS(24193), 1,
      anon_sym_RBRACE,
    STATE(17114), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717705] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24193), 1,
      anon_sym_RBRACK,
    ACTIONS(24195), 1,
      anon_sym_SEMI,
    STATE(17115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717722] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24193), 1,
      anon_sym_RPAREN,
    ACTIONS(24197), 1,
      anon_sym_SEMI,
    STATE(17116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717739] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24199), 1,
      anon_sym_RPAREN,
    ACTIONS(24201), 1,
      anon_sym_LT_DASH,
    STATE(17117), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717756] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23317), 1,
      anon_sym_then,
    STATE(12604), 1,
      sym_then_clause,
    STATE(17118), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717773] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17119), 1,
      sym_attribute,
    STATE(19040), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717790] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24203), 1,
      anon_sym_RPAREN,
    ACTIONS(24205), 1,
      anon_sym_LT_DASH,
    STATE(17120), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717807] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24207), 1,
      anon_sym_then,
    STATE(11995), 1,
      sym_then_clause,
    STATE(17121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717824] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17122), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [717839] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24211), 1,
      anon_sym_SEMI,
    ACTIONS(24213), 1,
      anon_sym_RBRACE,
    STATE(17123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717856] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24213), 1,
      anon_sym_RBRACK,
    ACTIONS(24215), 1,
      anon_sym_SEMI,
    STATE(17124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717873] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24213), 1,
      anon_sym_RPAREN,
    ACTIONS(24217), 1,
      anon_sym_SEMI,
    STATE(17125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717890] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(24219), 1,
      sym__lowercase_identifier,
    STATE(17126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717907] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17127), 1,
      sym_attribute,
    STATE(18889), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717924] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17128), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24221), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [717939] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24223), 1,
      anon_sym_DOT,
    STATE(17129), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717956] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24225), 1,
      anon_sym_RPAREN,
    ACTIONS(24227), 1,
      anon_sym_LT_DASH,
    STATE(17130), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717973] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24207), 1,
      anon_sym_then,
    STATE(11963), 1,
      sym_then_clause,
    STATE(17131), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717990] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24229), 1,
      sym__lowercase_identifier,
    ACTIONS(24231), 1,
      anon_sym_LPAREN,
    STATE(17132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718007] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17133), 1,
      sym_attribute,
    STATE(18777), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718024] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24233), 1,
      anon_sym_SEMI,
    ACTIONS(24235), 1,
      anon_sym_RBRACE,
    STATE(17134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718041] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24235), 1,
      anon_sym_RBRACK,
    ACTIONS(24237), 1,
      anon_sym_SEMI,
    STATE(17135), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718058] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24235), 1,
      anon_sym_RPAREN,
    ACTIONS(24239), 1,
      anon_sym_SEMI,
    STATE(17136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718075] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24241), 1,
      anon_sym_RPAREN,
    ACTIONS(24243), 1,
      anon_sym_LT_DASH,
    STATE(17137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718092] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24245), 1,
      anon_sym_COLON_GT,
    ACTIONS(24247), 1,
      anon_sym_RPAREN,
    STATE(17138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718109] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10044), 1,
      anon_sym_RBRACK,
    ACTIONS(18464), 1,
      anon_sym_PIPE,
    STATE(17139), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718126] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(24249), 1,
      sym__lowercase_identifier,
    STATE(17140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718143] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17141), 1,
      sym_attribute,
    STATE(18754), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718160] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(24251), 1,
      sym__lowercase_identifier,
    STATE(17142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718177] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24253), 1,
      anon_sym_DOT,
    STATE(17143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718194] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24255), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [718209] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24257), 1,
      anon_sym_RPAREN,
    ACTIONS(24259), 1,
      anon_sym_LT_DASH,
    STATE(17145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718226] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17146), 1,
      sym_attribute,
    STATE(18640), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718243] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(24261), 1,
      sym__lowercase_identifier,
    STATE(17147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718260] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24263), 1,
      anon_sym_RPAREN,
    ACTIONS(24265), 1,
      anon_sym_LT_DASH,
    STATE(17148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718277] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24267), 1,
      anon_sym_COLON_GT,
    ACTIONS(24269), 1,
      anon_sym_RPAREN,
    STATE(17149), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718294] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24271), 1,
      anon_sym_SEMI,
    ACTIONS(24273), 1,
      anon_sym_RBRACE,
    STATE(17150), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718311] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24273), 1,
      anon_sym_RBRACK,
    ACTIONS(24275), 1,
      anon_sym_SEMI,
    STATE(17151), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718328] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24273), 1,
      anon_sym_RPAREN,
    ACTIONS(24277), 1,
      anon_sym_SEMI,
    STATE(17152), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718345] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24279), 1,
      anon_sym_RPAREN,
    ACTIONS(24281), 1,
      anon_sym_LT_DASH,
    STATE(17153), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718362] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24283), 1,
      sym__lowercase_identifier,
    ACTIONS(24285), 1,
      anon_sym_LPAREN,
    STATE(17154), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718379] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23415), 1,
      anon_sym_then,
    STATE(12327), 1,
      sym_then_clause,
    STATE(17155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718396] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17156), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24287), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [718411] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17157), 1,
      sym_attribute,
    STATE(18601), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718428] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17158), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24289), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [718443] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17579), 1,
      sym__lowercase_identifier,
    STATE(17159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718460] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24291), 1,
      anon_sym_DOT,
    STATE(17160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718477] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17161), 1,
      sym_attribute,
    STATE(18506), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718494] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23415), 1,
      anon_sym_then,
    STATE(12347), 1,
      sym_then_clause,
    STATE(17162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718511] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24293), 1,
      anon_sym_SEMI,
    ACTIONS(24295), 1,
      anon_sym_RBRACE,
    STATE(17163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718528] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24295), 1,
      anon_sym_RBRACK,
    ACTIONS(24297), 1,
      anon_sym_SEMI,
    STATE(17164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718545] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23709), 1,
      anon_sym_then,
    STATE(8303), 1,
      sym_then_clause,
    STATE(17165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718562] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24295), 1,
      anon_sym_RPAREN,
    ACTIONS(24299), 1,
      anon_sym_SEMI,
    STATE(17166), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718579] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24301), 1,
      sym__lowercase_identifier,
    ACTIONS(24303), 1,
      anon_sym_LPAREN,
    STATE(17167), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718596] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17168), 1,
      sym_attribute,
    STATE(18468), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718613] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24305), 1,
      anon_sym_COLON_GT,
    ACTIONS(24307), 1,
      anon_sym_RPAREN,
    STATE(17169), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718630] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9970), 1,
      anon_sym_RBRACK,
    ACTIONS(18464), 1,
      anon_sym_PIPE,
    STATE(17170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718647] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(24309), 1,
      sym__lowercase_identifier,
    STATE(17171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718664] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17172), 1,
      sym_attribute,
    STATE(18546), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718681] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17173), 1,
      sym_attribute,
    STATE(18271), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718698] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24311), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [718713] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17175), 1,
      sym_attribute,
    STATE(19447), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718730] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24313), 1,
      anon_sym_SEMI,
    ACTIONS(24315), 1,
      anon_sym_RBRACE,
    STATE(17176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718747] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24315), 1,
      anon_sym_RBRACK,
    ACTIONS(24317), 1,
      anon_sym_SEMI,
    STATE(17177), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718764] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24315), 1,
      anon_sym_RPAREN,
    ACTIONS(24319), 1,
      anon_sym_SEMI,
    STATE(17178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718781] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24321), 1,
      anon_sym_RPAREN,
    ACTIONS(24323), 1,
      anon_sym_LT_DASH,
    STATE(17179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718798] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17180), 1,
      sym_attribute,
    STATE(18339), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718815] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24325), 1,
      anon_sym_RPAREN,
    ACTIONS(24327), 1,
      anon_sym_LT_DASH,
    STATE(17181), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718832] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24329), 1,
      anon_sym_then,
    STATE(12029), 1,
      sym_then_clause,
    STATE(17182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718849] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24331), 1,
      anon_sym_DOT,
    STATE(17183), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718866] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17184), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24333), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [718881] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24335), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [718896] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17535), 1,
      sym__lowercase_identifier,
    STATE(17186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718913] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24337), 1,
      anon_sym_RPAREN,
    ACTIONS(24339), 1,
      anon_sym_LT_DASH,
    STATE(17187), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718930] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17188), 1,
      sym_attribute,
    STATE(18251), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718947] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24341), 1,
      anon_sym_SEMI,
    ACTIONS(24343), 1,
      anon_sym_RBRACE,
    STATE(17189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718964] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24343), 1,
      anon_sym_RBRACK,
    ACTIONS(24345), 1,
      anon_sym_SEMI,
    STATE(17190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718981] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24343), 1,
      anon_sym_RPAREN,
    ACTIONS(24347), 1,
      anon_sym_SEMI,
    STATE(17191), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718998] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24349), 1,
      anon_sym_DOT,
    STATE(17192), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719015] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24351), 1,
      anon_sym_RPAREN,
    ACTIONS(24353), 1,
      anon_sym_SEMI,
    STATE(17193), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719032] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24351), 1,
      anon_sym_RBRACK,
    ACTIONS(24355), 1,
      anon_sym_SEMI,
    STATE(17194), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719049] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24351), 1,
      anon_sym_RBRACE,
    ACTIONS(24357), 1,
      anon_sym_SEMI,
    STATE(17195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719066] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24329), 1,
      anon_sym_then,
    STATE(12148), 1,
      sym_then_clause,
    STATE(17196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719083] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17197), 1,
      sym_attribute,
    STATE(18207), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719100] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24359), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [719115] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24361), 1,
      sym__lowercase_identifier,
    ACTIONS(24363), 1,
      anon_sym_LPAREN,
    STATE(17199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719132] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(24365), 1,
      sym__lowercase_identifier,
    STATE(17200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719149] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9934), 1,
      anon_sym_RBRACK,
    ACTIONS(18464), 1,
      anon_sym_PIPE,
    STATE(17201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719166] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(24367), 1,
      sym__lowercase_identifier,
    STATE(17202), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719183] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(24369), 1,
      sym__lowercase_identifier,
    STATE(17203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719200] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17204), 1,
      sym_attribute,
    STATE(18114), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719217] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24371), 1,
      anon_sym_COLON_GT,
    ACTIONS(24373), 1,
      anon_sym_RPAREN,
    STATE(17205), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719234] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24375), 1,
      anon_sym_COLON_GT,
    ACTIONS(24377), 1,
      anon_sym_RPAREN,
    STATE(17206), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719251] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17207), 1,
      sym_attribute,
    STATE(19426), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719268] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24379), 1,
      anon_sym_SEMI,
    ACTIONS(24381), 1,
      anon_sym_RBRACE,
    STATE(17208), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719285] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24381), 1,
      anon_sym_RBRACK,
    ACTIONS(24383), 1,
      anon_sym_SEMI,
    STATE(17209), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719302] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24381), 1,
      anon_sym_RPAREN,
    ACTIONS(24385), 1,
      anon_sym_SEMI,
    STATE(17210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719319] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24387), 1,
      sym__lowercase_identifier,
    ACTIONS(24389), 1,
      anon_sym_LPAREN,
    STATE(17211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719336] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24391), 1,
      anon_sym_RPAREN,
    ACTIONS(24393), 1,
      anon_sym_LT_DASH,
    STATE(17212), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719353] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17213), 1,
      sym_attribute,
    STATE(18082), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719370] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24395), 1,
      anon_sym_RPAREN,
    ACTIONS(24397), 1,
      anon_sym_LT_DASH,
    STATE(17214), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719387] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24399), 1,
      anon_sym_DOT,
    STATE(17215), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719404] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23503), 1,
      anon_sym_then,
    STATE(12312), 1,
      sym_then_clause,
    STATE(17216), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719421] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24401), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [719436] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24403), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [719451] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17219), 1,
      sym_attribute,
    STATE(17981), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719468] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(24405), 1,
      sym__lowercase_identifier,
    STATE(17220), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719485] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24407), 1,
      anon_sym_SEMI,
    ACTIONS(24409), 1,
      anon_sym_RBRACE,
    STATE(17221), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719502] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24409), 1,
      anon_sym_RBRACK,
    ACTIONS(24411), 1,
      anon_sym_SEMI,
    STATE(17222), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719519] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24409), 1,
      anon_sym_RPAREN,
    ACTIONS(24413), 1,
      anon_sym_SEMI,
    STATE(17223), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719536] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24415), 1,
      anon_sym_DOT,
    STATE(17224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719553] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17225), 1,
      sym_attribute,
    STATE(17935), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719570] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(24417), 1,
      sym__lowercase_identifier,
    STATE(17226), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719587] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24419), 1,
      sym__lowercase_identifier,
    ACTIONS(24421), 1,
      anon_sym_LPAREN,
    STATE(17227), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719604] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24423), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [719619] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24425), 1,
      anon_sym_DOT,
    STATE(17229), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719636] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24427), 1,
      anon_sym_DOT,
    STATE(17230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719653] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24429), 1,
      anon_sym_RPAREN,
    ACTIONS(24431), 1,
      anon_sym_LT_DASH,
    STATE(17231), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719670] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24433), 1,
      anon_sym_COLON_GT,
    ACTIONS(24435), 1,
      anon_sym_RPAREN,
    STATE(17232), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719687] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9926), 1,
      anon_sym_RBRACK,
    ACTIONS(18464), 1,
      anon_sym_PIPE,
    STATE(17233), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719704] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17234), 1,
      sym_attribute,
    STATE(17832), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719721] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(24437), 1,
      sym__lowercase_identifier,
    STATE(17235), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719738] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24439), 1,
      anon_sym_SEMI,
    ACTIONS(24441), 1,
      anon_sym_RBRACE,
    STATE(17236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719755] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24441), 1,
      anon_sym_RBRACK,
    ACTIONS(24443), 1,
      anon_sym_SEMI,
    STATE(17237), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719772] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24441), 1,
      anon_sym_RPAREN,
    ACTIONS(24445), 1,
      anon_sym_SEMI,
    STATE(17238), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719789] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24447), 1,
      anon_sym_RPAREN,
    ACTIONS(24449), 1,
      anon_sym_LT_DASH,
    STATE(17239), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719806] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(24451), 1,
      sym__lowercase_identifier,
    STATE(17240), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719823] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17241), 1,
      sym_attribute,
    STATE(17792), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719840] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24453), 1,
      anon_sym_RPAREN,
    ACTIONS(24455), 1,
      anon_sym_LT_DASH,
    STATE(17242), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719857] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24457), 1,
      anon_sym_DOT,
    STATE(17243), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719874] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24459), 1,
      anon_sym_RPAREN,
    ACTIONS(24461), 1,
      anon_sym_LT_DASH,
    STATE(17244), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719891] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17245), 1,
      sym_attribute,
    STATE(17661), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719908] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24463), 1,
      anon_sym_then,
    STATE(12052), 1,
      sym_then_clause,
    STATE(17246), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719925] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17247), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24465), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [719940] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24467), 1,
      anon_sym_SEMI,
    ACTIONS(24469), 1,
      anon_sym_RBRACE,
    STATE(17248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719957] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23777), 1,
      anon_sym_then,
    STATE(8325), 1,
      sym_then_clause,
    STATE(17249), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719974] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(24471), 1,
      sym__lowercase_identifier,
    STATE(17250), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719991] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24469), 1,
      anon_sym_RBRACK,
    ACTIONS(24473), 1,
      anon_sym_SEMI,
    STATE(17251), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720008] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24469), 1,
      anon_sym_RPAREN,
    ACTIONS(24475), 1,
      anon_sym_SEMI,
    STATE(17252), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720025] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24477), 1,
      anon_sym_COLON_GT,
    ACTIONS(24479), 1,
      anon_sym_RPAREN,
    STATE(17253), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720042] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17254), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24481), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [720057] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23503), 1,
      anon_sym_then,
    STATE(12253), 1,
      sym_then_clause,
    STATE(17255), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720074] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17571), 1,
      sym__lowercase_identifier,
    STATE(17256), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720091] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17257), 1,
      sym_attribute,
    STATE(18106), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720108] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17258), 1,
      sym_attribute,
    STATE(17595), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720125] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17259), 1,
      sym_attribute,
    STATE(19365), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720142] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24483), 1,
      anon_sym_DOT,
    STATE(17260), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720159] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24485), 1,
      sym__lowercase_identifier,
    ACTIONS(24487), 1,
      anon_sym_LPAREN,
    STATE(17261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720176] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24463), 1,
      anon_sym_then,
    STATE(12036), 1,
      sym_then_clause,
    STATE(17262), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720193] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24489), 1,
      anon_sym_DOT,
    STATE(17263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720210] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24491), 1,
      sym__lowercase_identifier,
    ACTIONS(24493), 1,
      anon_sym_LPAREN,
    STATE(17264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720227] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17265), 1,
      sym_attribute,
    STATE(17627), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720244] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24495), 1,
      anon_sym_DOT,
    STATE(17266), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720261] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24497), 1,
      anon_sym_COLON_GT,
    ACTIONS(24499), 1,
      anon_sym_RPAREN,
    STATE(17267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720278] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9888), 1,
      anon_sym_RBRACK,
    ACTIONS(18464), 1,
      anon_sym_PIPE,
    STATE(17268), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720295] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24501), 1,
      anon_sym_SEMI,
    ACTIONS(24503), 1,
      anon_sym_RBRACE,
    STATE(17269), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720312] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24503), 1,
      anon_sym_RBRACK,
    ACTIONS(24505), 1,
      anon_sym_SEMI,
    STATE(17270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720329] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24503), 1,
      anon_sym_RPAREN,
    ACTIONS(24507), 1,
      anon_sym_SEMI,
    STATE(17271), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720346] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(24509), 1,
      sym__lowercase_identifier,
    STATE(17272), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720363] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17273), 1,
      sym_attribute,
    STATE(17636), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720380] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(24511), 1,
      sym__lowercase_identifier,
    STATE(17274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720397] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24513), 1,
      anon_sym_RPAREN,
    ACTIONS(24515), 1,
      anon_sym_LT_DASH,
    STATE(17275), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720414] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24517), 1,
      anon_sym_RPAREN,
    ACTIONS(24519), 1,
      anon_sym_SEMI,
    STATE(17276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720431] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24517), 1,
      anon_sym_RBRACK,
    ACTIONS(24521), 1,
      anon_sym_SEMI,
    STATE(17277), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720448] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24517), 1,
      anon_sym_RBRACE,
    ACTIONS(24523), 1,
      anon_sym_SEMI,
    STATE(17278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720465] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17279), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24525), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [720480] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24527), 1,
      anon_sym_DOT,
    STATE(17280), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720497] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17281), 1,
      sym_attribute,
    STATE(17676), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720514] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24529), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [720529] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24531), 1,
      anon_sym_SEMI,
    ACTIONS(24533), 1,
      anon_sym_RBRACE,
    STATE(17283), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720546] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24535), 1,
      anon_sym_RPAREN,
    ACTIONS(24537), 1,
      anon_sym_LT_DASH,
    STATE(17284), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720563] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24533), 1,
      anon_sym_RBRACK,
    ACTIONS(24539), 1,
      anon_sym_SEMI,
    STATE(17285), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720580] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24533), 1,
      anon_sym_RPAREN,
    ACTIONS(24541), 1,
      anon_sym_SEMI,
    STATE(17286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720597] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24543), 1,
      anon_sym_RPAREN,
    ACTIONS(24545), 1,
      anon_sym_LT_DASH,
    STATE(17287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720614] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17288), 1,
      sym_attribute,
    STATE(19347), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720631] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23593), 1,
      anon_sym_then,
    STATE(12484), 1,
      sym_then_clause,
    STATE(17289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720648] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17290), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24547), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [720663] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(24549), 1,
      sym__lowercase_identifier,
    STATE(17291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720680] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17292), 1,
      sym_attribute,
    STATE(17637), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720697] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17663), 1,
      sym__lowercase_identifier,
    STATE(17293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720714] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24551), 1,
      anon_sym_DOT,
    STATE(17294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720731] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23593), 1,
      anon_sym_then,
    STATE(12621), 1,
      sym_then_clause,
    STATE(17295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720748] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24553), 1,
      anon_sym_DOT,
    STATE(17296), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720765] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24555), 1,
      anon_sym_RPAREN,
    ACTIONS(24557), 1,
      anon_sym_LT_DASH,
    STATE(17297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720782] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17298), 1,
      sym_attribute,
    STATE(17737), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720799] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24559), 1,
      sym__lowercase_identifier,
    ACTIONS(24561), 1,
      anon_sym_LPAREN,
    STATE(17299), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720816] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24563), 1,
      anon_sym_SEMI,
    ACTIONS(24565), 1,
      anon_sym_RBRACE,
    STATE(17300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720833] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24565), 1,
      anon_sym_RBRACK,
    ACTIONS(24567), 1,
      anon_sym_SEMI,
    STATE(17301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720850] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24565), 1,
      anon_sym_RPAREN,
    ACTIONS(24569), 1,
      anon_sym_SEMI,
    STATE(17302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720867] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24571), 1,
      anon_sym_COLON_GT,
    ACTIONS(24573), 1,
      anon_sym_RPAREN,
    STATE(17303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720884] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10253), 1,
      anon_sym_RBRACK,
    ACTIONS(18464), 1,
      anon_sym_PIPE,
    STATE(17304), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720901] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17305), 1,
      sym_attribute,
    STATE(17751), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720918] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(24575), 1,
      sym__lowercase_identifier,
    STATE(17306), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720935] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17307), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24577), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [720950] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24579), 1,
      anon_sym_COLON_GT,
    ACTIONS(24581), 1,
      anon_sym_RPAREN,
    STATE(17308), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720967] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24583), 1,
      anon_sym_DOT,
    STATE(17309), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720984] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(24585), 1,
      sym__lowercase_identifier,
    STATE(17310), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721001] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24587), 1,
      anon_sym_DOT,
    STATE(17311), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721018] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24589), 1,
      anon_sym_RPAREN,
    ACTIONS(24591), 1,
      anon_sym_LT_DASH,
    STATE(17312), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721035] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24593), 1,
      sym__lowercase_identifier,
    ACTIONS(24595), 1,
      anon_sym_LPAREN,
    STATE(17313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721052] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17314), 1,
      sym_attribute,
    STATE(17801), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721069] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(24597), 1,
      sym__lowercase_identifier,
    STATE(17315), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721086] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24599), 1,
      anon_sym_SEMI,
    ACTIONS(24601), 1,
      anon_sym_RBRACE,
    STATE(17316), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721103] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24601), 1,
      anon_sym_RBRACK,
    ACTIONS(24603), 1,
      anon_sym_SEMI,
    STATE(17317), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721120] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24601), 1,
      anon_sym_RPAREN,
    ACTIONS(24605), 1,
      anon_sym_SEMI,
    STATE(17318), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721137] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24607), 1,
      anon_sym_RPAREN,
    ACTIONS(24609), 1,
      anon_sym_LT_DASH,
    STATE(17319), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721154] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24611), 1,
      anon_sym_then,
    STATE(12070), 1,
      sym_then_clause,
    STATE(17320), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721171] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17321), 1,
      sym_attribute,
    STATE(17817), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721188] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17322), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24613), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721203] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17323), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24615), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721218] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17727), 1,
      sym__lowercase_identifier,
    STATE(17324), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721235] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24617), 1,
      anon_sym_DOT,
    STATE(17325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721252] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24619), 1,
      anon_sym_DOT,
    STATE(17326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721269] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24611), 1,
      anon_sym_then,
    STATE(11990), 1,
      sym_then_clause,
    STATE(17327), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721286] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23101), 1,
      anon_sym_then,
    STATE(8254), 1,
      sym_then_clause,
    STATE(17328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721303] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24621), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721318] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17330), 1,
      sym_attribute,
    STATE(17864), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721335] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24623), 1,
      anon_sym_SEMI,
    ACTIONS(24625), 1,
      anon_sym_RBRACE,
    STATE(17331), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721352] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24627), 1,
      anon_sym_RPAREN,
    ACTIONS(24629), 1,
      anon_sym_LT_DASH,
    STATE(17332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721369] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24625), 1,
      anon_sym_RBRACK,
    ACTIONS(24631), 1,
      anon_sym_SEMI,
    STATE(17333), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721386] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24625), 1,
      anon_sym_RPAREN,
    ACTIONS(24633), 1,
      anon_sym_SEMI,
    STATE(17334), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721403] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24635), 1,
      sym__lowercase_identifier,
    ACTIONS(24637), 1,
      anon_sym_LPAREN,
    STATE(17335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721420] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24639), 1,
      anon_sym_COLON_GT,
    ACTIONS(24641), 1,
      anon_sym_RPAREN,
    STATE(17336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721437] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17337), 1,
      sym_attribute,
    STATE(19293), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721454] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17338), 1,
      sym_attribute,
    STATE(17879), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721471] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9986), 1,
      anon_sym_RBRACK,
    ACTIONS(18464), 1,
      anon_sym_PIPE,
    STATE(17339), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721488] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(24643), 1,
      sym__lowercase_identifier,
    STATE(17340), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721505] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(24645), 1,
      sym__lowercase_identifier,
    STATE(17341), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721522] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24647), 1,
      anon_sym_RPAREN,
    ACTIONS(24649), 1,
      anon_sym_LT_DASH,
    STATE(17342), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721539] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24651), 1,
      anon_sym_DOT,
    STATE(17343), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721556] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24653), 1,
      anon_sym_DOT,
    STATE(17344), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721573] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17345), 1,
      sym_attribute,
    STATE(17928), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721590] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24655), 1,
      anon_sym_RPAREN,
    ACTIONS(24657), 1,
      anon_sym_LT_DASH,
    STATE(17346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721607] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24659), 1,
      anon_sym_SEMI,
    ACTIONS(24661), 1,
      anon_sym_RBRACE,
    STATE(17347), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721624] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24661), 1,
      anon_sym_RBRACK,
    ACTIONS(24663), 1,
      anon_sym_SEMI,
    STATE(17348), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721641] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24661), 1,
      anon_sym_RPAREN,
    ACTIONS(24665), 1,
      anon_sym_SEMI,
    STATE(17349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721658] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17350), 1,
      sym_attribute,
    STATE(17944), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721675] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24667), 1,
      anon_sym_RPAREN,
    ACTIONS(24669), 1,
      anon_sym_LT_DASH,
    STATE(17351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721692] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23669), 1,
      anon_sym_then,
    STATE(9534), 1,
      sym_then_clause,
    STATE(17352), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721709] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17353), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24671), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721724] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24673), 1,
      anon_sym_RPAREN,
    ACTIONS(24675), 1,
      anon_sym_SEMI,
    STATE(17354), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721741] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24673), 1,
      anon_sym_RBRACK,
    ACTIONS(24677), 1,
      anon_sym_SEMI,
    STATE(17355), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721758] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24673), 1,
      anon_sym_RBRACE,
    ACTIONS(24679), 1,
      anon_sym_SEMI,
    STATE(17356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721775] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24681), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [721790] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17561), 1,
      sym__lowercase_identifier,
    STATE(17358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721807] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24683), 1,
      anon_sym_DOT,
    STATE(17359), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721824] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17360), 1,
      sym_attribute,
    STATE(17995), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721841] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24685), 1,
      anon_sym_COLON_GT,
    ACTIONS(24687), 1,
      anon_sym_RPAREN,
    STATE(17361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721858] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24689), 1,
      anon_sym_DOT,
    STATE(17362), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721875] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24691), 1,
      anon_sym_SEMI,
    ACTIONS(24693), 1,
      anon_sym_RBRACE,
    STATE(17363), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721892] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24693), 1,
      anon_sym_RBRACK,
    ACTIONS(24695), 1,
      anon_sym_SEMI,
    STATE(17364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721909] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24693), 1,
      anon_sym_RPAREN,
    ACTIONS(24697), 1,
      anon_sym_SEMI,
    STATE(17365), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721926] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17366), 1,
      sym_attribute,
    STATE(19273), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721943] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24699), 1,
      sym__lowercase_identifier,
    ACTIONS(24701), 1,
      anon_sym_LPAREN,
    STATE(17367), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721960] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23669), 1,
      anon_sym_then,
    STATE(9789), 1,
      sym_then_clause,
    STATE(17368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721977] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24703), 1,
      anon_sym_DOT,
    STATE(17369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721994] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24705), 1,
      sym__lowercase_identifier,
    ACTIONS(24707), 1,
      anon_sym_LPAREN,
    STATE(17370), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722011] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17371), 1,
      sym_attribute,
    STATE(18007), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722028] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24709), 1,
      anon_sym_COLON_GT,
    ACTIONS(24711), 1,
      anon_sym_RPAREN,
    STATE(17372), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722045] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9972), 1,
      anon_sym_RBRACK,
    ACTIONS(18464), 1,
      anon_sym_PIPE,
    STATE(17373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722062] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(24713), 1,
      sym__lowercase_identifier,
    STATE(17374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722079] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24715), 1,
      anon_sym_DOT,
    STATE(17375), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722096] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24717), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [722111] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17377), 1,
      sym_attribute,
    STATE(18060), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722128] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24719), 1,
      anon_sym_RPAREN,
    ACTIONS(24721), 1,
      anon_sym_LT_DASH,
    STATE(17378), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722145] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24723), 1,
      anon_sym_SEMI,
    ACTIONS(24725), 1,
      anon_sym_RBRACE,
    STATE(17379), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722162] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24725), 1,
      anon_sym_RBRACK,
    ACTIONS(24727), 1,
      anon_sym_SEMI,
    STATE(17380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722179] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24725), 1,
      anon_sym_RPAREN,
    ACTIONS(24729), 1,
      anon_sym_SEMI,
    STATE(17381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722196] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24731), 1,
      anon_sym_DOT,
    STATE(17382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722213] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24733), 1,
      anon_sym_RPAREN,
    ACTIONS(24735), 1,
      anon_sym_LT_DASH,
    STATE(17383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722230] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24737), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [722245] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24739), 1,
      anon_sym_then,
    STATE(9516), 1,
      sym_then_clause,
    STATE(17385), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722262] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24741), 1,
      anon_sym_RPAREN,
    ACTIONS(24743), 1,
      anon_sym_LT_DASH,
    STATE(17386), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722279] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24745), 1,
      anon_sym_DOT,
    STATE(17387), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722296] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17388), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24747), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [722311] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17389), 1,
      sym_attribute,
    STATE(18078), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722328] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24749), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [722343] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17607), 1,
      sym__lowercase_identifier,
    STATE(17391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722360] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24751), 1,
      anon_sym_DOT,
    STATE(17392), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722377] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24739), 1,
      anon_sym_then,
    STATE(9456), 1,
      sym_then_clause,
    STATE(17393), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722394] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24753), 1,
      anon_sym_RPAREN,
    ACTIONS(24755), 1,
      anon_sym_LT_DASH,
    STATE(17394), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722411] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24757), 1,
      anon_sym_DOT,
    STATE(17395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722428] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24759), 1,
      sym__lowercase_identifier,
    ACTIONS(24761), 1,
      anon_sym_LPAREN,
    STATE(17396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722445] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17397), 1,
      sym_attribute,
    STATE(18134), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722462] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24763), 1,
      anon_sym_COLON_GT,
    ACTIONS(24765), 1,
      anon_sym_RPAREN,
    STATE(17398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722479] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10086), 1,
      anon_sym_RBRACK,
    ACTIONS(18464), 1,
      anon_sym_PIPE,
    STATE(17399), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722496] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24767), 1,
      anon_sym_SEMI,
    ACTIONS(24769), 1,
      anon_sym_RBRACE,
    STATE(17400), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722513] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24769), 1,
      anon_sym_RBRACK,
    ACTIONS(24771), 1,
      anon_sym_SEMI,
    STATE(17401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722530] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24769), 1,
      anon_sym_RPAREN,
    ACTIONS(24773), 1,
      anon_sym_SEMI,
    STATE(17402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722547] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(24775), 1,
      sym__lowercase_identifier,
    STATE(17403), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722564] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(24777), 1,
      sym__lowercase_identifier,
    STATE(17404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722581] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(24779), 1,
      sym__lowercase_identifier,
    STATE(17405), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722598] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23585), 1,
      anon_sym_then,
    STATE(8121), 1,
      sym_then_clause,
    STATE(17406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722615] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24781), 1,
      anon_sym_DOT,
    STATE(17407), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722632] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17408), 1,
      sym_attribute,
    STATE(18155), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722649] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24783), 1,
      anon_sym_COLON_GT,
    ACTIONS(24785), 1,
      anon_sym_RPAREN,
    STATE(17409), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722666] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24787), 1,
      anon_sym_RPAREN,
    ACTIONS(24789), 1,
      anon_sym_LT_DASH,
    STATE(17410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722683] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24791), 1,
      anon_sym_RPAREN,
    ACTIONS(24793), 1,
      anon_sym_LT_DASH,
    STATE(17411), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722700] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23743), 1,
      anon_sym_then,
    STATE(12032), 1,
      sym_then_clause,
    STATE(17412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722717] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24795), 1,
      anon_sym_DOT,
    STATE(17413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722734] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24797), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [722749] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17415), 1,
      sym_attribute,
    STATE(19223), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722766] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24799), 1,
      sym__lowercase_identifier,
    ACTIONS(24801), 1,
      anon_sym_LPAREN,
    STATE(17416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722783] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17417), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24803), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [722798] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17681), 1,
      sym__lowercase_identifier,
    STATE(17418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722815] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17419), 1,
      sym_attribute,
    STATE(18219), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722832] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23743), 1,
      anon_sym_then,
    STATE(12142), 1,
      sym_then_clause,
    STATE(17420), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722849] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24805), 1,
      anon_sym_SEMI,
    ACTIONS(24807), 1,
      anon_sym_RBRACE,
    STATE(17421), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722866] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24809), 1,
      anon_sym_DOT,
    STATE(17422), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722883] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24807), 1,
      anon_sym_RBRACK,
    ACTIONS(24811), 1,
      anon_sym_SEMI,
    STATE(17423), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722900] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24807), 1,
      anon_sym_RPAREN,
    ACTIONS(24813), 1,
      anon_sym_SEMI,
    STATE(17424), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722917] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24815), 1,
      sym__lowercase_identifier,
    ACTIONS(24817), 1,
      anon_sym_LPAREN,
    STATE(17425), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722934] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24819), 1,
      anon_sym_DOT,
    STATE(17426), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722951] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24821), 1,
      anon_sym_COLON_GT,
    ACTIONS(24823), 1,
      anon_sym_RPAREN,
    STATE(17427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722968] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17428), 1,
      sym_attribute,
    STATE(18241), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722985] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(24825), 1,
      sym__lowercase_identifier,
    STATE(17429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723002] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17719), 1,
      sym__lowercase_identifier,
    STATE(17430), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723019] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(24827), 1,
      sym__lowercase_identifier,
    STATE(17431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723036] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24829), 1,
      anon_sym_RPAREN,
    ACTIONS(24831), 1,
      anon_sym_SEMI,
    STATE(17432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723053] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24829), 1,
      anon_sym_RBRACK,
    ACTIONS(24833), 1,
      anon_sym_SEMI,
    STATE(17433), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723070] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24829), 1,
      anon_sym_RBRACE,
    ACTIONS(24835), 1,
      anon_sym_SEMI,
    STATE(17434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723087] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24837), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [723102] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24839), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [723117] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(24841), 1,
      sym__lowercase_identifier,
    STATE(17437), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723134] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17438), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24843), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [723149] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24845), 1,
      anon_sym_RPAREN,
    ACTIONS(24847), 1,
      anon_sym_LT_DASH,
    STATE(17439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723166] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24849), 1,
      anon_sym_RPAREN,
    ACTIONS(24851), 1,
      anon_sym_LT_DASH,
    STATE(17440), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723183] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24853), 1,
      anon_sym_DOT,
    STATE(17441), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723200] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24855), 1,
      anon_sym_RPAREN,
    ACTIONS(24857), 1,
      anon_sym_LT_DASH,
    STATE(17442), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723217] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17443), 1,
      sym_attribute,
    STATE(18230), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723234] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17444), 1,
      sym_attribute,
    STATE(19207), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723251] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23807), 1,
      anon_sym_then,
    STATE(11887), 1,
      sym_then_clause,
    STATE(17445), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723268] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17446), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24859), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [723283] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24861), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [723298] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17551), 1,
      sym__lowercase_identifier,
    STATE(17448), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723315] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24863), 1,
      anon_sym_SEMI,
    ACTIONS(24865), 1,
      anon_sym_RBRACE,
    STATE(17449), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723332] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24865), 1,
      anon_sym_RBRACK,
    ACTIONS(24867), 1,
      anon_sym_SEMI,
    STATE(17450), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723349] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24865), 1,
      anon_sym_RPAREN,
    ACTIONS(24869), 1,
      anon_sym_SEMI,
    STATE(17451), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723366] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24871), 1,
      anon_sym_DOT,
    STATE(17452), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723383] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24873), 1,
      anon_sym_RPAREN,
    ACTIONS(24875), 1,
      anon_sym_LT_DASH,
    STATE(17453), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723400] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23807), 1,
      anon_sym_then,
    STATE(11897), 1,
      sym_then_clause,
    STATE(17454), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723417] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17455), 1,
      sym_attribute,
    STATE(18326), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723434] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24877), 1,
      sym__lowercase_identifier,
    ACTIONS(24879), 1,
      anon_sym_LPAREN,
    STATE(17456), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723451] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24881), 1,
      anon_sym_COLON_GT,
    ACTIONS(24883), 1,
      anon_sym_RPAREN,
    STATE(17457), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723468] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24885), 1,
      anon_sym_DOT,
    STATE(17458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723485] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(24887), 1,
      sym__lowercase_identifier,
    STATE(17459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723502] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24889), 1,
      anon_sym_RPAREN,
    ACTIONS(24891), 1,
      anon_sym_LT_DASH,
    STATE(17460), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723519] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17461), 1,
      sym_attribute,
    STATE(18397), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723536] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(24893), 1,
      sym__lowercase_identifier,
    STATE(17462), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723553] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24895), 1,
      anon_sym_RPAREN,
    ACTIONS(24897), 1,
      anon_sym_LT_DASH,
    STATE(17463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723570] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24899), 1,
      anon_sym_SEMI,
    ACTIONS(24901), 1,
      anon_sym_RBRACE,
    STATE(17464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723587] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24903), 1,
      anon_sym_DOT,
    STATE(17465), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723604] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24905), 1,
      anon_sym_COLON_GT,
    ACTIONS(24907), 1,
      anon_sym_RPAREN,
    STATE(17466), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723621] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24901), 1,
      anon_sym_RBRACK,
    ACTIONS(24909), 1,
      anon_sym_SEMI,
    STATE(17467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723638] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24901), 1,
      anon_sym_RPAREN,
    ACTIONS(24911), 1,
      anon_sym_SEMI,
    STATE(17468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723655] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23855), 1,
      anon_sym_then,
    STATE(11488), 1,
      sym_then_clause,
    STATE(17469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723672] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24913), 1,
      sym__lowercase_identifier,
    ACTIONS(24915), 1,
      anon_sym_LPAREN,
    STATE(17470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723689] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24917), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [723704] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24919), 1,
      anon_sym_DOT,
    STATE(17472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723721] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17513), 1,
      sym__lowercase_identifier,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    STATE(17473), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723738] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17474), 1,
      sym_attribute,
    STATE(18414), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723755] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23855), 1,
      anon_sym_then,
    STATE(11631), 1,
      sym_then_clause,
    STATE(17475), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723772] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24921), 1,
      sym__lowercase_identifier,
    ACTIONS(24923), 1,
      anon_sym_LPAREN,
    STATE(17476), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723789] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24925), 1,
      anon_sym_COLON_GT,
    ACTIONS(24927), 1,
      anon_sym_RPAREN,
    STATE(17477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723806] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24929), 1,
      anon_sym_DOT,
    STATE(17478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723823] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(24931), 1,
      sym__lowercase_identifier,
    STATE(17479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723840] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17480), 1,
      sym_attribute,
    STATE(18482), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723857] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24933), 1,
      anon_sym_RPAREN,
    ACTIONS(24935), 1,
      anon_sym_LT_DASH,
    STATE(17481), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723874] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24937), 1,
      anon_sym_SEMI,
    ACTIONS(24939), 1,
      anon_sym_RBRACE,
    STATE(17482), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723891] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17603), 1,
      sym__lowercase_identifier,
    STATE(17483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723908] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23709), 1,
      anon_sym_then,
    STATE(8294), 1,
      sym_then_clause,
    STATE(17484), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723925] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24939), 1,
      anon_sym_RBRACK,
    ACTIONS(24941), 1,
      anon_sym_SEMI,
    STATE(17485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723942] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24939), 1,
      anon_sym_RPAREN,
    ACTIONS(24943), 1,
      anon_sym_SEMI,
    STATE(17486), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723959] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24945), 1,
      anon_sym_DOT,
    STATE(17487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723976] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24947), 1,
      anon_sym_RPAREN,
    ACTIONS(24949), 1,
      anon_sym_LT_DASH,
    STATE(17488), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723993] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23027), 1,
      anon_sym_then,
    STATE(10333), 1,
      sym_then_clause,
    STATE(17489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724010] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17490), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24951), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [724025] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17491), 1,
      sym_attribute,
    STATE(18500), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724042] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17492), 1,
      sym_attribute,
    STATE(19139), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724059] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24953), 1,
      anon_sym_RPAREN,
    ACTIONS(24955), 1,
      anon_sym_LT_DASH,
    STATE(17493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724076] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17659), 1,
      sym__lowercase_identifier,
    STATE(17494), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724093] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24207), 1,
      anon_sym_then,
    STATE(12115), 1,
      sym_then_clause,
    STATE(17495), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724110] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24957), 1,
      anon_sym_DOT,
    STATE(17496), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724127] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24959), 1,
      sym__lowercase_identifier,
    ACTIONS(24961), 1,
      anon_sym_LPAREN,
    STATE(17497), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724144] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24963), 1,
      anon_sym_COLON_GT,
    ACTIONS(24965), 1,
      anon_sym_RPAREN,
    STATE(17498), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724161] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24967), 1,
      anon_sym_DOT,
    STATE(17499), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724178] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17500), 1,
      sym_attribute,
    STATE(18567), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724195] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24969), 1,
      anon_sym_RPAREN,
    ACTIONS(24971), 1,
      anon_sym_LT_DASH,
    STATE(17501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724212] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(24973), 1,
      sym__lowercase_identifier,
    STATE(17502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724229] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24975), 1,
      anon_sym_SEMI,
    ACTIONS(24977), 1,
      anon_sym_RBRACE,
    STATE(17503), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724246] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24977), 1,
      anon_sym_RBRACK,
    ACTIONS(24979), 1,
      anon_sym_SEMI,
    STATE(17504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724263] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24977), 1,
      anon_sym_RPAREN,
    ACTIONS(24981), 1,
      anon_sym_SEMI,
    STATE(17505), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724280] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23769), 1,
      anon_sym_LPAREN,
    ACTIONS(24983), 1,
      sym__lowercase_identifier,
    STATE(17506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724297] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24985), 1,
      anon_sym_RPAREN,
    ACTIONS(24987), 1,
      anon_sym_LT_DASH,
    STATE(17507), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724314] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(24989), 1,
      anon_sym_DOT,
    STATE(17508), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724331] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24991), 1,
      anon_sym_RPAREN,
    ACTIONS(24993), 1,
      anon_sym_SEMI,
    STATE(17509), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724348] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24991), 1,
      anon_sym_RBRACK,
    ACTIONS(24995), 1,
      anon_sym_SEMI,
    STATE(17510), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724365] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24991), 1,
      anon_sym_RBRACE,
    ACTIONS(24997), 1,
      anon_sym_SEMI,
    STATE(17511), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724382] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17512), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24999), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [724397] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17513), 1,
      sym_attribute,
    STATE(18590), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724414] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25001), 1,
      anon_sym_RPAREN,
    ACTIONS(25003), 1,
      anon_sym_LT_DASH,
    STATE(17514), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724431] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24207), 1,
      anon_sym_then,
    STATE(12119), 1,
      sym_then_clause,
    STATE(17515), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724448] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17516), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25005), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [724463] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(25007), 1,
      sym__lowercase_identifier,
    STATE(17517), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724480] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17639), 1,
      sym__lowercase_identifier,
    STATE(17518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724497] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(25009), 1,
      anon_sym_DOT,
    STATE(17519), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724514] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24329), 1,
      anon_sym_then,
    STATE(12098), 1,
      sym_then_clause,
    STATE(17520), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724531] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17521), 1,
      sym_attribute,
    STATE(19096), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724548] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25011), 1,
      anon_sym_COLON_GT,
    ACTIONS(25013), 1,
      anon_sym_RPAREN,
    STATE(17522), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724565] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17523), 1,
      sym_attribute,
    STATE(18653), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724582] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25015), 1,
      sym__lowercase_identifier,
    ACTIONS(25017), 1,
      anon_sym_LPAREN,
    STATE(17524), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724599] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25019), 1,
      anon_sym_COLON_GT,
    ACTIONS(25021), 1,
      anon_sym_RPAREN,
    STATE(17525), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724616] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25023), 1,
      anon_sym_SEMI,
    ACTIONS(25025), 1,
      anon_sym_RBRACE,
    STATE(17526), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724633] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25025), 1,
      anon_sym_RBRACK,
    ACTIONS(25027), 1,
      anon_sym_SEMI,
    STATE(17527), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724650] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25025), 1,
      anon_sym_RPAREN,
    ACTIONS(25029), 1,
      anon_sym_SEMI,
    STATE(17528), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724667] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(25031), 1,
      sym__lowercase_identifier,
    STATE(17529), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724684] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25033), 1,
      sym__lowercase_identifier,
    ACTIONS(25035), 1,
      anon_sym_LPAREN,
    STATE(17530), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724701] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(25037), 1,
      anon_sym_DOT,
    STATE(17531), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724718] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17532), 1,
      sym_attribute,
    STATE(18676), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724735] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25039), 1,
      anon_sym_RPAREN,
    ACTIONS(25041), 1,
      anon_sym_LT_DASH,
    STATE(17533), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724752] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25043), 1,
      anon_sym_RPAREN,
    ACTIONS(25045), 1,
      anon_sym_LT_DASH,
    STATE(17534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724769] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24329), 1,
      anon_sym_then,
    STATE(11906), 1,
      sym_then_clause,
    STATE(17535), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724786] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17536), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25047), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [724801] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(25049), 1,
      anon_sym_DOT,
    STATE(17537), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724818] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17735), 1,
      sym__lowercase_identifier,
    STATE(17538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724835] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(25051), 1,
      anon_sym_DOT,
    STATE(17539), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724852] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17540), 1,
      sym_attribute,
    STATE(18744), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724869] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24463), 1,
      anon_sym_then,
    STATE(12208), 1,
      sym_then_clause,
    STATE(17541), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724886] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17731), 1,
      sym__lowercase_identifier,
    STATE(17542), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724903] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25053), 1,
      anon_sym_SEMI,
    ACTIONS(25055), 1,
      anon_sym_RBRACE,
    STATE(17543), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724920] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25055), 1,
      anon_sym_RBRACK,
    ACTIONS(25057), 1,
      anon_sym_SEMI,
    STATE(17544), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724937] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25059), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [724952] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24739), 1,
      anon_sym_then,
    STATE(9480), 1,
      sym_then_clause,
    STATE(17546), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724969] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25055), 1,
      anon_sym_RPAREN,
    ACTIONS(25061), 1,
      anon_sym_SEMI,
    STATE(17547), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724986] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25063), 1,
      anon_sym_COLON_GT,
    ACTIONS(25065), 1,
      anon_sym_RPAREN,
    STATE(17548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725003] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25067), 1,
      anon_sym_RPAREN,
    ACTIONS(25069), 1,
      anon_sym_LT_DASH,
    STATE(17549), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725020] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(25071), 1,
      anon_sym_DOT,
    STATE(17550), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725037] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(25073), 1,
      sym__lowercase_identifier,
    STATE(17551), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725054] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25075), 1,
      sym__lowercase_identifier,
    ACTIONS(25077), 1,
      anon_sym_LPAREN,
    STATE(17552), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725071] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17553), 1,
      sym_attribute,
    STATE(18763), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725088] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25079), 1,
      anon_sym_RPAREN,
    ACTIONS(25081), 1,
      anon_sym_LT_DASH,
    STATE(17554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725105] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(25083), 1,
      anon_sym_DOT,
    STATE(17555), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725122] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25085), 1,
      anon_sym_RPAREN,
    ACTIONS(25087), 1,
      anon_sym_LT_DASH,
    STATE(17556), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725139] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23777), 1,
      anon_sym_then,
    STATE(8339), 1,
      sym_then_clause,
    STATE(17557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725156] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25089), 1,
      anon_sym_RPAREN,
    ACTIONS(25091), 1,
      anon_sym_LT_DASH,
    STATE(17558), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725173] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24463), 1,
      anon_sym_then,
    STATE(12150), 1,
      sym_then_clause,
    STATE(17559), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725190] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17560), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25093), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [725205] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17561), 1,
      sym_attribute,
    STATE(18834), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725222] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24739), 1,
      anon_sym_then,
    STATE(9522), 1,
      sym_then_clause,
    STATE(17562), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725239] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25095), 1,
      anon_sym_RPAREN,
    ACTIONS(25097), 1,
      anon_sym_LT_DASH,
    STATE(17563), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725256] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25099), 1,
      anon_sym_COLON_GT,
    ACTIONS(25101), 1,
      anon_sym_RPAREN,
    STATE(17564), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725273] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17565), 1,
      sym_attribute,
    STATE(18965), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725290] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25103), 1,
      anon_sym_RPAREN,
    ACTIONS(25105), 1,
      anon_sym_SEMI,
    STATE(17566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725307] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19331), 1,
      anon_sym_COLON2,
    STATE(17567), 1,
      sym_attribute,
    STATE(18940), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725324] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(25107), 1,
      anon_sym_DOT,
    STATE(17568), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725341] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25103), 1,
      anon_sym_RBRACK,
    ACTIONS(25109), 1,
      anon_sym_SEMI,
    STATE(17569), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725358] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(25111), 1,
      sym__lowercase_identifier,
    STATE(17570), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725375] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25103), 1,
      anon_sym_RBRACE,
    ACTIONS(25113), 1,
      anon_sym_SEMI,
    STATE(17571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725392] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(25115), 1,
      anon_sym_DOT,
    STATE(17572), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725409] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    ACTIONS(25117), 1,
      sym__lowercase_identifier,
    STATE(17573), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725426] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25119), 1,
      anon_sym_COLON_GT,
    ACTIONS(25121), 1,
      anon_sym_RPAREN,
    STATE(17574), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725443] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25123), 1,
      sym__lowercase_identifier,
    ACTIONS(25125), 1,
      anon_sym_LPAREN,
    STATE(17575), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725460] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25127), 1,
      anon_sym_RPAREN,
    ACTIONS(25129), 1,
      anon_sym_LT_DASH,
    STATE(17576), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725477] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24611), 1,
      anon_sym_then,
    STATE(12018), 1,
      sym_then_clause,
    STATE(17577), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725494] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11274), 1,
      anon_sym_LPAREN,
    ACTIONS(25131), 1,
      anon_sym_DOT,
    STATE(17578), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725511] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17715), 1,
      sym__lowercase_identifier,
    STATE(17579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725528] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25133), 1,
      sym__lowercase_identifier,
    ACTIONS(25135), 1,
      anon_sym_LPAREN,
    STATE(17580), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725545] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17581), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25137), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [725560] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25139), 1,
      anon_sym_RPAREN,
    ACTIONS(25141), 1,
      anon_sym_SEMI,
    STATE(17582), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725577] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25139), 1,
      anon_sym_RBRACK,
    ACTIONS(25143), 1,
      anon_sym_SEMI,
    STATE(17583), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725594] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25139), 1,
      anon_sym_RBRACE,
    ACTIONS(25145), 1,
      anon_sym_SEMI,
    STATE(17584), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725611] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17585), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25147), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [725626] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    ACTIONS(17685), 1,
      sym__lowercase_identifier,
    STATE(17586), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725643] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    STATE(17587), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25149), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [725658] = 5,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(24611), 1,
      anon_sym_then,
    STATE(12171), 1,
      sym_then_clause,
    STATE(17588), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725675] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25151), 1,
      anon_sym_RBRACK,
    STATE(17589), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725689] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25153), 1,
      anon_sym_LT_DASH,
    STATE(17590), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725703] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25155), 1,
      anon_sym_DOT,
    STATE(17591), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725717] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25157), 1,
      anon_sym_end,
    STATE(17592), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725731] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25159), 1,
      anon_sym_DASH_GT,
    STATE(17593), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725745] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16661), 1,
      anon_sym_RPAREN,
    STATE(17594), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725759] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25161), 1,
      anon_sym_RBRACE,
    STATE(17595), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725773] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25163), 1,
      anon_sym_end,
    STATE(17596), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725787] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25165), 1,
      anon_sym_DASH_GT,
    STATE(17597), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725801] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8875), 1,
      anon_sym_DASH_GT,
    STATE(17598), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725815] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25167), 1,
      anon_sym_with,
    STATE(17599), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725829] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25169), 1,
      anon_sym_RBRACE,
    STATE(17600), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725843] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25171), 1,
      anon_sym_with,
    STATE(17601), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725857] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25173), 1,
      anon_sym_RBRACK,
    STATE(17602), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725871] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25175), 1,
      sym__lowercase_identifier,
    STATE(17603), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725885] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25177), 1,
      anon_sym_DOT,
    STATE(17604), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725899] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25179), 1,
      anon_sym_DQUOTE,
    STATE(17605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725913] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25181), 1,
      anon_sym_SQUOTE2,
    STATE(17606), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725927] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19301), 1,
      anon_sym_end,
    STATE(17607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725941] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22933), 1,
      anon_sym_GT_RBRACE,
    STATE(17608), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725955] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25183), 1,
      anon_sym_RBRACE,
    STATE(17609), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725969] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17787), 1,
      anon_sym_RPAREN,
    STATE(17610), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725983] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25185), 1,
      anon_sym_in,
    STATE(17611), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725997] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25187), 1,
      anon_sym_in,
    STATE(17612), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726011] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25189), 1,
      anon_sym_in,
    STATE(17613), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726025] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25191), 1,
      anon_sym_in,
    STATE(17614), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726039] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25193), 1,
      anon_sym_RPAREN,
    STATE(17615), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726053] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25195), 1,
      anon_sym_RPAREN,
    STATE(17616), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726067] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25197), 1,
      anon_sym_RPAREN,
    STATE(17617), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726081] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25197), 1,
      anon_sym_RBRACK,
    STATE(17618), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726095] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25197), 1,
      anon_sym_RBRACE,
    STATE(17619), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726109] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3209), 1,
      anon_sym_RPAREN,
    STATE(17620), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726123] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25199), 1,
      anon_sym_LT_DASH,
    STATE(17621), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726137] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25201), 1,
      anon_sym_RPAREN,
    STATE(17622), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726151] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25203), 1,
      anon_sym_RPAREN,
    STATE(17623), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726165] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25205), 1,
      anon_sym_RBRACE,
    STATE(17624), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726179] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25207), 1,
      anon_sym_RBRACK,
    STATE(17625), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726193] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25209), 1,
      anon_sym_RPAREN,
    STATE(17626), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726207] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25211), 1,
      anon_sym_RPAREN,
    STATE(17627), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726221] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25213), 1,
      anon_sym_RPAREN,
    STATE(17628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726235] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25215), 1,
      anon_sym_RPAREN,
    STATE(17629), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726249] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25217), 1,
      anon_sym_RBRACE,
    STATE(17630), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726263] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25219), 1,
      anon_sym_DOT,
    STATE(17631), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726277] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25221), 1,
      anon_sym_RBRACK,
    STATE(17632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726291] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25223), 1,
      anon_sym_RPAREN,
    STATE(17633), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726305] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25225), 1,
      anon_sym_DASH_GT,
    STATE(17634), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726319] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16643), 1,
      anon_sym_RPAREN,
    STATE(17635), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726333] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25227), 1,
      anon_sym_RBRACE,
    STATE(17636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726347] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25229), 1,
      anon_sym_RBRACE,
    STATE(17637), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726361] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25231), 1,
      anon_sym_DASH_GT,
    STATE(17638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726375] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25233), 1,
      anon_sym_with,
    STATE(17639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726389] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25235), 1,
      anon_sym_with,
    STATE(17640), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726403] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25237), 1,
      anon_sym_DOT,
    STATE(17641), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726417] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8986), 1,
      anon_sym_DASH_GT,
    STATE(17642), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726431] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25239), 1,
      anon_sym_RBRACE,
    STATE(17643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726445] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25241), 1,
      anon_sym_RBRACK,
    STATE(17644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726459] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25243), 1,
      sym__lowercase_identifier,
    STATE(17645), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726473] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25245), 1,
      anon_sym_DQUOTE,
    STATE(17646), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726487] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25247), 1,
      anon_sym_SQUOTE2,
    STATE(17647), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726501] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19435), 1,
      anon_sym_end,
    STATE(17648), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726515] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25249), 1,
      anon_sym_with,
    STATE(17649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726529] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25251), 1,
      anon_sym_with,
    STATE(17650), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726543] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22729), 1,
      anon_sym_GT_RBRACE,
    STATE(17651), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726557] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25253), 1,
      anon_sym_RBRACE,
    STATE(17652), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726571] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25255), 1,
      anon_sym_DOT,
    STATE(17653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726585] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25257), 1,
      anon_sym_in,
    STATE(17654), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726599] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25259), 1,
      anon_sym_in,
    STATE(17655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726613] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25261), 1,
      anon_sym_in,
    STATE(17656), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726627] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25263), 1,
      anon_sym_in,
    STATE(17657), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726641] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25265), 1,
      anon_sym_RPAREN,
    STATE(17658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726655] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17915), 1,
      anon_sym_RPAREN,
    STATE(17659), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726669] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3231), 1,
      anon_sym_RPAREN,
    STATE(17660), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726683] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25267), 1,
      anon_sym_RPAREN,
    STATE(17661), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726697] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25269), 1,
      anon_sym_LT_DASH,
    STATE(17662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726711] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25271), 1,
      anon_sym_RBRACK,
    STATE(17663), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726725] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25273), 1,
      anon_sym_RBRACE,
    STATE(17664), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726739] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25275), 1,
      anon_sym_RPAREN,
    STATE(17665), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726753] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25277), 1,
      anon_sym_RPAREN,
    STATE(17666), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726767] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25279), 1,
      anon_sym_RPAREN,
    STATE(17667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726781] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25279), 1,
      anon_sym_RBRACK,
    STATE(17668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726795] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25279), 1,
      anon_sym_RBRACE,
    STATE(17669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726809] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25281), 1,
      anon_sym_with,
    STATE(17670), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726823] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25283), 1,
      anon_sym_RPAREN,
    STATE(17671), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726837] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25285), 1,
      anon_sym_RPAREN,
    STATE(17672), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726851] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25287), 1,
      anon_sym_RBRACE,
    STATE(17673), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726865] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25289), 1,
      anon_sym_RBRACK,
    STATE(17674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726879] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25291), 1,
      anon_sym_RPAREN,
    STATE(17675), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726893] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25293), 1,
      anon_sym_RPAREN,
    STATE(17676), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726907] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25295), 1,
      anon_sym_RPAREN,
    STATE(17677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726921] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25297), 1,
      anon_sym_DOT,
    STATE(17678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726935] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25299), 1,
      anon_sym_RPAREN,
    STATE(17679), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726949] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25301), 1,
      anon_sym_RPAREN,
    STATE(17680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726963] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25303), 1,
      anon_sym_RBRACE,
    STATE(17681), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726977] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25305), 1,
      anon_sym_RBRACK,
    STATE(17682), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726991] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25307), 1,
      anon_sym_RPAREN,
    STATE(17683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727005] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25309), 1,
      anon_sym_DASH_GT,
    STATE(17684), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727019] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25311), 1,
      anon_sym_with,
    STATE(17685), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727033] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25313), 1,
      anon_sym_with,
    STATE(17686), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727047] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25315), 1,
      anon_sym_DOT,
    STATE(17687), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727061] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16591), 1,
      anon_sym_RPAREN,
    STATE(17688), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727075] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25317), 1,
      anon_sym_SQUOTE2,
    STATE(17689), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727089] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25319), 1,
      anon_sym_RPAREN,
    STATE(17690), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727103] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25321), 1,
      anon_sym_end,
    STATE(17691), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727117] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25323), 1,
      anon_sym_RBRACK,
    STATE(17692), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727131] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25325), 1,
      anon_sym_DASH_GT,
    STATE(17693), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727145] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8968), 1,
      anon_sym_DASH_GT,
    STATE(17694), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727159] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25327), 1,
      anon_sym_RBRACE,
    STATE(17695), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727173] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25329), 1,
      anon_sym_RPAREN,
    STATE(17696), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727187] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25331), 1,
      anon_sym_RBRACE,
    STATE(17697), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727201] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25333), 1,
      anon_sym_with,
    STATE(17698), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727215] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25335), 1,
      anon_sym_with,
    STATE(17699), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727229] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25337), 1,
      anon_sym_RBRACK,
    STATE(17700), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727243] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25339), 1,
      sym__lowercase_identifier,
    STATE(17701), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727257] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25341), 1,
      anon_sym_in,
    STATE(17702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727271] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25343), 1,
      anon_sym_DOT,
    STATE(17703), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727285] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25345), 1,
      anon_sym_DOT,
    STATE(17704), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727299] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25347), 1,
      anon_sym_RPAREN,
    STATE(17705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727313] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25349), 1,
      anon_sym_LT_DASH,
    STATE(17706), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727327] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25351), 1,
      anon_sym_DQUOTE,
    STATE(17707), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727341] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25353), 1,
      anon_sym_SQUOTE2,
    STATE(17708), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727355] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19679), 1,
      anon_sym_end,
    STATE(17709), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727369] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22236), 1,
      anon_sym_GT_RBRACE,
    STATE(17710), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727383] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3199), 1,
      anon_sym_RPAREN,
    STATE(17711), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727397] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25355), 1,
      anon_sym_RBRACE,
    STATE(17712), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727411] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17985), 1,
      anon_sym_RPAREN,
    STATE(17713), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727425] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25357), 1,
      anon_sym_in,
    STATE(17714), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727439] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25359), 1,
      anon_sym_RPAREN,
    STATE(17715), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727453] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25361), 1,
      anon_sym_in,
    STATE(17716), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727467] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25363), 1,
      anon_sym_in,
    STATE(17717), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727481] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25365), 1,
      anon_sym_in,
    STATE(17718), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727495] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25367), 1,
      anon_sym_RPAREN,
    STATE(17719), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727509] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25369), 1,
      anon_sym_RPAREN,
    STATE(17720), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727523] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25371), 1,
      anon_sym_RPAREN,
    STATE(17721), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727537] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25371), 1,
      anon_sym_RBRACK,
    STATE(17722), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727551] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25371), 1,
      anon_sym_RBRACE,
    STATE(17723), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727565] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25373), 1,
      anon_sym_in,
    STATE(17724), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727579] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3257), 1,
      anon_sym_RPAREN,
    STATE(17725), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727593] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25375), 1,
      anon_sym_in,
    STATE(17726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727607] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25377), 1,
      anon_sym_LT_DASH,
    STATE(17727), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727621] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25379), 1,
      anon_sym_in,
    STATE(17728), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727635] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25381), 1,
      anon_sym_in,
    STATE(17729), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727649] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25383), 1,
      anon_sym_RPAREN,
    STATE(17730), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727663] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25385), 1,
      anon_sym_RBRACE,
    STATE(17731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727677] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25387), 1,
      anon_sym_DOT,
    STATE(17732), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727691] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25389), 1,
      anon_sym_RPAREN,
    STATE(17733), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727705] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25391), 1,
      anon_sym_RBRACE,
    STATE(17734), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727719] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25393), 1,
      anon_sym_RBRACK,
    STATE(17735), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727733] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25395), 1,
      anon_sym_RPAREN,
    STATE(17736), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727747] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25397), 1,
      anon_sym_RPAREN,
    STATE(17737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727761] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25399), 1,
      anon_sym_RPAREN,
    STATE(17738), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727775] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25401), 1,
      anon_sym_with,
    STATE(17739), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727789] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25403), 1,
      anon_sym_with,
    STATE(17740), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727803] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25405), 1,
      anon_sym_DOT,
    STATE(17741), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727817] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22560), 1,
      anon_sym_GT_RBRACE,
    STATE(17742), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727831] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19481), 1,
      anon_sym_end,
    STATE(17743), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727845] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25407), 1,
      anon_sym_RPAREN,
    STATE(17744), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727859] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25409), 1,
      anon_sym_RBRACE,
    STATE(17745), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727873] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25411), 1,
      anon_sym_RBRACK,
    STATE(17746), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727887] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25413), 1,
      anon_sym_RPAREN,
    STATE(17747), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727901] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25415), 1,
      anon_sym_DASH_GT,
    STATE(17748), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727915] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25417), 1,
      anon_sym_RPAREN,
    STATE(17749), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727929] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16547), 1,
      anon_sym_RPAREN,
    STATE(17750), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727943] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25419), 1,
      anon_sym_RBRACE,
    STATE(17751), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727957] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25421), 1,
      anon_sym_with,
    STATE(17752), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727971] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25423), 1,
      anon_sym_with,
    STATE(17753), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727985] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25425), 1,
      anon_sym_end,
    STATE(17754), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727999] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25427), 1,
      anon_sym_DQUOTE,
    STATE(17755), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728013] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25429), 1,
      anon_sym_DASH_GT,
    STATE(17756), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728027] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25431), 1,
      anon_sym_DOT,
    STATE(17757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728041] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25433), 1,
      anon_sym_RBRACE,
    STATE(17758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728055] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25433), 1,
      anon_sym_RBRACK,
    STATE(17759), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728069] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25433), 1,
      anon_sym_RPAREN,
    STATE(17760), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728083] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8891), 1,
      anon_sym_DASH_GT,
    STATE(17761), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728097] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25435), 1,
      anon_sym_RPAREN,
    STATE(17762), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728111] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25437), 1,
      anon_sym_RBRACE,
    STATE(17763), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728125] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25439), 1,
      anon_sym_RBRACK,
    STATE(17764), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728139] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25441), 1,
      sym__lowercase_identifier,
    STATE(17765), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728153] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25443), 1,
      sym__lowercase_identifier,
    STATE(17766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728167] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18085), 1,
      anon_sym_RPAREN,
    STATE(17767), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728181] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25445), 1,
      anon_sym_DQUOTE,
    STATE(17768), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728195] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25447), 1,
      anon_sym_RBRACK,
    STATE(17769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728209] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25449), 1,
      anon_sym_SQUOTE2,
    STATE(17770), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728223] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19924), 1,
      anon_sym_end,
    STATE(17771), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728237] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21762), 1,
      anon_sym_GT_RBRACE,
    STATE(17772), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728251] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25451), 1,
      anon_sym_RBRACE,
    STATE(17773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728265] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25453), 1,
      anon_sym_RPAREN,
    STATE(17774), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728279] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25455), 1,
      anon_sym_RPAREN,
    STATE(17775), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728293] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25455), 1,
      anon_sym_RBRACK,
    STATE(17776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728307] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25455), 1,
      anon_sym_RBRACE,
    STATE(17777), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728321] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25457), 1,
      anon_sym_RBRACE,
    STATE(17778), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728335] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25459), 1,
      anon_sym_in,
    STATE(17779), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728349] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8949), 1,
      anon_sym_DASH_GT,
    STATE(17780), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728363] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25461), 1,
      anon_sym_end,
    STATE(17781), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728377] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25463), 1,
      anon_sym_in,
    STATE(17782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728391] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25465), 1,
      anon_sym_in,
    STATE(17783), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728405] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25467), 1,
      anon_sym_RPAREN,
    STATE(17784), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728419] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17937), 1,
      anon_sym_RPAREN,
    STATE(17785), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728433] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25469), 1,
      anon_sym_DOT,
    STATE(17786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728447] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25471), 1,
      anon_sym_RPAREN,
    STATE(17787), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728461] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25473), 1,
      anon_sym_LT_DASH,
    STATE(17788), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728475] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25475), 1,
      anon_sym_DASH_GT,
    STATE(17789), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728489] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25477), 1,
      anon_sym_end,
    STATE(17790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728503] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25479), 1,
      anon_sym_RPAREN,
    STATE(17791), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728517] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25481), 1,
      anon_sym_RBRACE,
    STATE(17792), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728531] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25483), 1,
      anon_sym_with,
    STATE(17793), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728545] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25485), 1,
      anon_sym_with,
    STATE(17794), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728559] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25487), 1,
      anon_sym_DOT,
    STATE(17795), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728573] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25489), 1,
      anon_sym_RPAREN,
    STATE(17796), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728587] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16559), 1,
      anon_sym_RPAREN,
    STATE(17797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728601] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25491), 1,
      anon_sym_RBRACE,
    STATE(17798), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728615] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25493), 1,
      anon_sym_RBRACK,
    STATE(17799), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728629] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25495), 1,
      anon_sym_RPAREN,
    STATE(17800), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728643] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25497), 1,
      anon_sym_RPAREN,
    STATE(17801), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728657] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25499), 1,
      anon_sym_RPAREN,
    STATE(17802), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728671] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25501), 1,
      anon_sym_DASH_GT,
    STATE(17803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728685] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25503), 1,
      anon_sym_DOT,
    STATE(17804), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728699] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25505), 1,
      anon_sym_RPAREN,
    STATE(17805), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728713] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25507), 1,
      anon_sym_with,
    STATE(17806), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728727] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25509), 1,
      anon_sym_with,
    STATE(17807), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728741] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25511), 1,
      anon_sym_RBRACE,
    STATE(17808), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728755] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25513), 1,
      anon_sym_RBRACK,
    STATE(17809), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728769] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25515), 1,
      anon_sym_RPAREN,
    STATE(17810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728783] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25517), 1,
      anon_sym_DOT,
    STATE(17811), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728797] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25519), 1,
      anon_sym_RPAREN,
    STATE(17812), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728811] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25521), 1,
      anon_sym_RBRACE,
    STATE(17813), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728825] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25523), 1,
      anon_sym_with,
    STATE(17814), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728839] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25525), 1,
      anon_sym_DASH_GT,
    STATE(17815), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728853] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16746), 1,
      anon_sym_RPAREN,
    STATE(17816), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728867] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25527), 1,
      anon_sym_RBRACE,
    STATE(17817), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728881] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25529), 1,
      anon_sym_RPAREN,
    STATE(17818), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728895] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25531), 1,
      anon_sym_DASH_GT,
    STATE(17819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728909] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25533), 1,
      anon_sym_DASH_GT,
    STATE(17820), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728923] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18165), 1,
      anon_sym_RPAREN,
    STATE(17821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728937] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9042), 1,
      anon_sym_DASH_GT,
    STATE(17822), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728951] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25535), 1,
      anon_sym_with,
    STATE(17823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728965] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25537), 1,
      anon_sym_RPAREN,
    STATE(17824), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728979] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25539), 1,
      anon_sym_RBRACE,
    STATE(17825), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728993] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25541), 1,
      anon_sym_RBRACK,
    STATE(17826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729007] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25543), 1,
      sym__lowercase_identifier,
    STATE(17827), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729021] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25545), 1,
      anon_sym_RPAREN,
    STATE(17828), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729035] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25547), 1,
      anon_sym_RPAREN,
    STATE(17829), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729049] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25547), 1,
      anon_sym_RBRACK,
    STATE(17830), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729063] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25547), 1,
      anon_sym_RBRACE,
    STATE(17831), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729077] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25549), 1,
      anon_sym_RPAREN,
    STATE(17832), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729091] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25551), 1,
      anon_sym_DQUOTE,
    STATE(17833), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729105] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25553), 1,
      anon_sym_RPAREN,
    STATE(17834), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729119] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25555), 1,
      anon_sym_SQUOTE2,
    STATE(17835), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729133] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20090), 1,
      anon_sym_end,
    STATE(17836), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729147] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21238), 1,
      anon_sym_GT_RBRACE,
    STATE(17837), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729161] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25557), 1,
      anon_sym_RBRACK,
    STATE(17838), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729175] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25559), 1,
      anon_sym_RBRACE,
    STATE(17839), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729189] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25561), 1,
      anon_sym_DOT,
    STATE(17840), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729203] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25563), 1,
      anon_sym_in,
    STATE(17841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729217] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25565), 1,
      anon_sym_in,
    STATE(17842), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729231] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25567), 1,
      anon_sym_in,
    STATE(17843), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729245] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25569), 1,
      anon_sym_in,
    STATE(17844), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729259] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25571), 1,
      anon_sym_RPAREN,
    STATE(17845), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729273] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25573), 1,
      anon_sym_RBRACE,
    STATE(17846), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729287] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25575), 1,
      anon_sym_with,
    STATE(17847), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729301] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25577), 1,
      anon_sym_with,
    STATE(17848), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729315] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25579), 1,
      anon_sym_DOT,
    STATE(17849), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729329] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3229), 1,
      anon_sym_RPAREN,
    STATE(17850), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729343] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25581), 1,
      anon_sym_RPAREN,
    STATE(17851), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729357] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25583), 1,
      anon_sym_LT_DASH,
    STATE(17852), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729371] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25585), 1,
      anon_sym_RPAREN,
    STATE(17853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729385] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25587), 1,
      anon_sym_DOT,
    STATE(17854), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729399] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25589), 1,
      anon_sym_RBRACK,
    STATE(17855), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729413] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25591), 1,
      anon_sym_with,
    STATE(17856), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729427] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25593), 1,
      anon_sym_RPAREN,
    STATE(17857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729441] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25595), 1,
      anon_sym_RPAREN,
    STATE(17858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729455] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25597), 1,
      anon_sym_RBRACE,
    STATE(17859), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729469] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25599), 1,
      anon_sym_with,
    STATE(17860), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729483] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25601), 1,
      anon_sym_with,
    STATE(17861), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729497] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25603), 1,
      anon_sym_RBRACK,
    STATE(17862), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729511] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25605), 1,
      anon_sym_RPAREN,
    STATE(17863), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729525] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25607), 1,
      anon_sym_RPAREN,
    STATE(17864), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729539] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25609), 1,
      anon_sym_DOT,
    STATE(17865), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729553] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25611), 1,
      anon_sym_LT_DASH,
    STATE(17866), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729567] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25613), 1,
      anon_sym_with,
    STATE(17867), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729581] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3185), 1,
      anon_sym_RPAREN,
    STATE(17868), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729595] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25615), 1,
      anon_sym_RPAREN,
    STATE(17869), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729609] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25617), 1,
      anon_sym_RPAREN,
    STATE(17870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729623] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25619), 1,
      anon_sym_RPAREN,
    STATE(17871), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729637] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25621), 1,
      anon_sym_RBRACE,
    STATE(17872), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729651] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25623), 1,
      anon_sym_RBRACK,
    STATE(17873), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729665] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25625), 1,
      anon_sym_RPAREN,
    STATE(17874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729679] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18255), 1,
      anon_sym_RPAREN,
    STATE(17875), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729693] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25627), 1,
      anon_sym_DASH_GT,
    STATE(17876), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729707] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25629), 1,
      anon_sym_in,
    STATE(17877), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729721] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16842), 1,
      anon_sym_RPAREN,
    STATE(17878), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729735] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25631), 1,
      anon_sym_RBRACE,
    STATE(17879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729749] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25633), 1,
      anon_sym_end,
    STATE(17880), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729763] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25635), 1,
      anon_sym_in,
    STATE(17881), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729777] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25637), 1,
      anon_sym_RPAREN,
    STATE(17882), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729791] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25639), 1,
      anon_sym_RPAREN,
    STATE(17883), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729805] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25639), 1,
      anon_sym_RBRACK,
    STATE(17884), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729819] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25639), 1,
      anon_sym_RBRACE,
    STATE(17885), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729833] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25641), 1,
      anon_sym_DASH_GT,
    STATE(17886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729847] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9034), 1,
      anon_sym_DASH_GT,
    STATE(17887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729861] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25643), 1,
      anon_sym_in,
    STATE(17888), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729875] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25645), 1,
      anon_sym_in,
    STATE(17889), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729889] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25647), 1,
      anon_sym_RBRACE,
    STATE(17890), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729903] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25649), 1,
      anon_sym_RBRACK,
    STATE(17891), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729917] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25651), 1,
      sym__lowercase_identifier,
    STATE(17892), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729931] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25653), 1,
      anon_sym_DOT,
    STATE(17893), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729945] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25655), 1,
      anon_sym_DOT,
    STATE(17894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729959] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25657), 1,
      anon_sym_DQUOTE,
    STATE(17895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729973] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25659), 1,
      anon_sym_SQUOTE2,
    STATE(17896), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729987] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20299), 1,
      anon_sym_end,
    STATE(17897), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730001] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20711), 1,
      anon_sym_GT_RBRACE,
    STATE(17898), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730015] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25661), 1,
      anon_sym_RBRACE,
    STATE(17899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730029] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25663), 1,
      anon_sym_RBRACE,
    STATE(17900), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730043] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25665), 1,
      anon_sym_with,
    STATE(17901), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730057] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25667), 1,
      anon_sym_with,
    STATE(17902), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730071] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25669), 1,
      anon_sym_DOT,
    STATE(17903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730085] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25671), 1,
      anon_sym_in,
    STATE(17904), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730099] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22162), 1,
      anon_sym_GT_RBRACE,
    STATE(17905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730113] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25673), 1,
      anon_sym_in,
    STATE(17906), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730127] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25675), 1,
      anon_sym_in,
    STATE(17907), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730141] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25677), 1,
      anon_sym_in,
    STATE(17908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730155] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25679), 1,
      anon_sym_RPAREN,
    STATE(17909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730169] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25681), 1,
      anon_sym_DOT,
    STATE(17910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730183] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19651), 1,
      anon_sym_end,
    STATE(17911), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730197] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3205), 1,
      anon_sym_RPAREN,
    STATE(17912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730211] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25683), 1,
      anon_sym_LT_DASH,
    STATE(17913), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730225] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25685), 1,
      anon_sym_with,
    STATE(17914), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730239] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25687), 1,
      anon_sym_with,
    STATE(17915), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730253] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25689), 1,
      anon_sym_SQUOTE2,
    STATE(17916), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730267] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25691), 1,
      anon_sym_DQUOTE,
    STATE(17917), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730281] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25693), 1,
      anon_sym_RPAREN,
    STATE(17918), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730295] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25695), 1,
      anon_sym_DOT,
    STATE(17919), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730309] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25697), 1,
      sym__lowercase_identifier,
    STATE(17920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730323] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25699), 1,
      anon_sym_RBRACK,
    STATE(17921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730337] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25701), 1,
      anon_sym_RBRACE,
    STATE(17922), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730351] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9046), 1,
      anon_sym_DASH_GT,
    STATE(17923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730365] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25703), 1,
      anon_sym_RPAREN,
    STATE(17924), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730379] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25705), 1,
      anon_sym_RBRACE,
    STATE(17925), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730393] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25707), 1,
      anon_sym_RBRACK,
    STATE(17926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730407] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25709), 1,
      anon_sym_RPAREN,
    STATE(17927), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730421] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25711), 1,
      anon_sym_RPAREN,
    STATE(17928), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730435] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18357), 1,
      anon_sym_RPAREN,
    STATE(17929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730449] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25713), 1,
      anon_sym_RPAREN,
    STATE(17930), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730463] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25715), 1,
      anon_sym_DASH_GT,
    STATE(17931), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730477] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25717), 1,
      anon_sym_end,
    STATE(17932), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730491] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25719), 1,
      anon_sym_RPAREN,
    STATE(17933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730505] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25721), 1,
      anon_sym_RBRACE,
    STATE(17934), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730519] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25723), 1,
      anon_sym_RBRACE,
    STATE(17935), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730533] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25725), 1,
      anon_sym_RPAREN,
    STATE(17936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730547] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25727), 1,
      anon_sym_RPAREN,
    STATE(17937), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730561] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25727), 1,
      anon_sym_RBRACK,
    STATE(17938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730575] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25727), 1,
      anon_sym_RBRACE,
    STATE(17939), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730589] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25729), 1,
      anon_sym_RPAREN,
    STATE(17940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730603] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25731), 1,
      anon_sym_DASH_GT,
    STATE(17941), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730617] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16798), 1,
      anon_sym_RPAREN,
    STATE(17942), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730631] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16880), 1,
      anon_sym_RPAREN,
    STATE(17943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730645] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25733), 1,
      anon_sym_RBRACE,
    STATE(17944), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730659] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25735), 1,
      anon_sym_end,
    STATE(17945), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730673] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25737), 1,
      anon_sym_end,
    STATE(17946), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730687] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25739), 1,
      anon_sym_DASH_GT,
    STATE(17947), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730701] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25741), 1,
      anon_sym_DOT,
    STATE(17948), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730715] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8992), 1,
      anon_sym_DASH_GT,
    STATE(17949), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730729] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25743), 1,
      anon_sym_with,
    STATE(17950), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730743] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25745), 1,
      anon_sym_RBRACE,
    STATE(17951), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730757] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25747), 1,
      anon_sym_RBRACK,
    STATE(17952), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730771] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25749), 1,
      sym__lowercase_identifier,
    STATE(17953), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730785] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25751), 1,
      anon_sym_RPAREN,
    STATE(17954), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730799] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25753), 1,
      anon_sym_with,
    STATE(17955), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730813] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25755), 1,
      anon_sym_with,
    STATE(17956), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730827] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25757), 1,
      anon_sym_DOT,
    STATE(17957), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730841] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25759), 1,
      anon_sym_DQUOTE,
    STATE(17958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730855] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25761), 1,
      anon_sym_RBRACK,
    STATE(17959), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730869] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25763), 1,
      anon_sym_SQUOTE2,
    STATE(17960), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730883] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20341), 1,
      anon_sym_end,
    STATE(17961), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730897] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20532), 1,
      anon_sym_GT_RBRACE,
    STATE(17962), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730911] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25765), 1,
      anon_sym_RBRACE,
    STATE(17963), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730925] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25767), 1,
      anon_sym_RBRACE,
    STATE(17964), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730939] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25769), 1,
      anon_sym_RPAREN,
    STATE(17965), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730953] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25771), 1,
      anon_sym_in,
    STATE(17966), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730967] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25773), 1,
      anon_sym_in,
    STATE(17967), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730981] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25775), 1,
      anon_sym_with,
    STATE(17968), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730995] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25777), 1,
      anon_sym_with,
    STATE(17969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731009] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25779), 1,
      anon_sym_in,
    STATE(17970), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731023] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25781), 1,
      anon_sym_in,
    STATE(17971), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731037] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25783), 1,
      anon_sym_RPAREN,
    STATE(17972), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731051] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25785), 1,
      anon_sym_DOT,
    STATE(17973), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731065] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25787), 1,
      anon_sym_RBRACE,
    STATE(17974), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731079] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25787), 1,
      anon_sym_RBRACK,
    STATE(17975), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731093] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25787), 1,
      anon_sym_RPAREN,
    STATE(17976), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731107] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25789), 1,
      anon_sym_RPAREN,
    STATE(17977), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731121] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3187), 1,
      anon_sym_RPAREN,
    STATE(17978), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731135] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25791), 1,
      anon_sym_LT_DASH,
    STATE(17979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731149] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25793), 1,
      anon_sym_RPAREN,
    STATE(17980), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731163] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25795), 1,
      anon_sym_RPAREN,
    STATE(17981), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731177] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25797), 1,
      anon_sym_RPAREN,
    STATE(17982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731191] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18229), 1,
      anon_sym_RPAREN,
    STATE(17983), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731205] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25799), 1,
      anon_sym_RPAREN,
    STATE(17984), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731219] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25801), 1,
      anon_sym_RBRACK,
    STATE(17985), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731233] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25803), 1,
      anon_sym_RBRACE,
    STATE(17986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731247] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25805), 1,
      anon_sym_RPAREN,
    STATE(17987), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731261] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25807), 1,
      anon_sym_RBRACE,
    STATE(17988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731275] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25809), 1,
      anon_sym_RBRACK,
    STATE(17989), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731289] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25811), 1,
      anon_sym_RPAREN,
    STATE(17990), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731303] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25813), 1,
      anon_sym_RPAREN,
    STATE(17991), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731317] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25813), 1,
      anon_sym_RBRACK,
    STATE(17992), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731331] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25813), 1,
      anon_sym_RBRACE,
    STATE(17993), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731345] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25815), 1,
      anon_sym_RPAREN,
    STATE(17994), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731359] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25817), 1,
      anon_sym_RPAREN,
    STATE(17995), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731373] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18045), 1,
      anon_sym_RPAREN,
    STATE(17996), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731387] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25819), 1,
      anon_sym_RPAREN,
    STATE(17997), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731401] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25821), 1,
      anon_sym_RPAREN,
    STATE(17998), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731415] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25823), 1,
      anon_sym_RPAREN,
    STATE(17999), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731429] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25825), 1,
      anon_sym_RBRACE,
    STATE(18000), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731443] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25827), 1,
      anon_sym_RBRACK,
    STATE(18001), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731457] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25829), 1,
      anon_sym_DOT,
    STATE(18002), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731471] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25831), 1,
      anon_sym_RPAREN,
    STATE(18003), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731485] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25833), 1,
      anon_sym_DASH_GT,
    STATE(18004), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731499] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25835), 1,
      anon_sym_RPAREN,
    STATE(18005), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731513] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16814), 1,
      anon_sym_RPAREN,
    STATE(18006), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731527] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25837), 1,
      anon_sym_RBRACE,
    STATE(18007), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731541] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25839), 1,
      anon_sym_LT_DASH,
    STATE(18008), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731555] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25841), 1,
      anon_sym_with,
    STATE(18009), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731569] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25843), 1,
      anon_sym_with,
    STATE(18010), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731583] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25845), 1,
      anon_sym_DOT,
    STATE(18011), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731597] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25847), 1,
      anon_sym_DOT,
    STATE(18012), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731611] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25849), 1,
      anon_sym_RPAREN,
    STATE(18013), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731625] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25851), 1,
      anon_sym_DASH_GT,
    STATE(18014), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731639] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8915), 1,
      anon_sym_DASH_GT,
    STATE(18015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731653] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25853), 1,
      anon_sym_in,
    STATE(18016), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731667] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25855), 1,
      anon_sym_RBRACE,
    STATE(18017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731681] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25857), 1,
      anon_sym_RBRACK,
    STATE(18018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731695] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25859), 1,
      anon_sym_with,
    STATE(18019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731709] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25861), 1,
      sym__lowercase_identifier,
    STATE(18020), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731723] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25863), 1,
      anon_sym_in,
    STATE(18021), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731737] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25865), 1,
      anon_sym_with,
    STATE(18022), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731751] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25867), 1,
      anon_sym_with,
    STATE(18023), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731765] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25869), 1,
      anon_sym_DQUOTE,
    STATE(18024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731779] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25871), 1,
      anon_sym_SQUOTE2,
    STATE(18025), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731793] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20205), 1,
      anon_sym_end,
    STATE(18026), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731807] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25873), 1,
      anon_sym_DOT,
    STATE(18027), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731821] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25875), 1,
      anon_sym_with,
    STATE(18028), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731835] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25877), 1,
      anon_sym_in,
    STATE(18029), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731849] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25879), 1,
      anon_sym_in,
    STATE(18030), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731863] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20901), 1,
      anon_sym_GT_RBRACE,
    STATE(18031), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731877] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25881), 1,
      anon_sym_RBRACE,
    STATE(18032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731891] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25883), 1,
      anon_sym_RBRACE,
    STATE(18033), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731905] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25885), 1,
      anon_sym_in,
    STATE(18034), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731919] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25887), 1,
      anon_sym_in,
    STATE(18035), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731933] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25889), 1,
      anon_sym_in,
    STATE(18036), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731947] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18101), 1,
      anon_sym_RPAREN,
    STATE(18037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731961] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25891), 1,
      anon_sym_in,
    STATE(18038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731975] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3135), 1,
      anon_sym_RPAREN,
    STATE(18039), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731989] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25893), 1,
      anon_sym_RPAREN,
    STATE(18040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732003] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19811), 1,
      anon_sym_end,
    STATE(18041), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732017] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25895), 1,
      anon_sym_RPAREN,
    STATE(18042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732031] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25897), 1,
      anon_sym_LT_DASH,
    STATE(18043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732045] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25899), 1,
      anon_sym_RPAREN,
    STATE(18044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732059] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25901), 1,
      anon_sym_RPAREN,
    STATE(18045), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732073] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25901), 1,
      anon_sym_RBRACK,
    STATE(18046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732087] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25901), 1,
      anon_sym_RBRACE,
    STATE(18047), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732101] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25903), 1,
      anon_sym_SQUOTE2,
    STATE(18048), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732115] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25905), 1,
      anon_sym_DQUOTE,
    STATE(18049), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732129] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25907), 1,
      sym__lowercase_identifier,
    STATE(18050), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732143] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25909), 1,
      anon_sym_RBRACK,
    STATE(18051), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732157] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25911), 1,
      anon_sym_RPAREN,
    STATE(18052), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732171] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25913), 1,
      anon_sym_DOT,
    STATE(18053), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732185] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25915), 1,
      anon_sym_GT,
    STATE(18054), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732199] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25917), 1,
      anon_sym_RPAREN,
    STATE(18055), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732213] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25919), 1,
      anon_sym_DOT,
    STATE(18056), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732227] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25921), 1,
      anon_sym_RBRACE,
    STATE(18057), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732241] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25923), 1,
      anon_sym_RBRACK,
    STATE(18058), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732255] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25925), 1,
      anon_sym_RPAREN,
    STATE(18059), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732269] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25927), 1,
      anon_sym_RPAREN,
    STATE(18060), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732283] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11753), 1,
      anon_sym_GT,
    STATE(18061), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732297] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25929), 1,
      anon_sym_RPAREN,
    STATE(18062), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732311] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25931), 1,
      anon_sym_with,
    STATE(18063), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732325] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25933), 1,
      anon_sym_with,
    STATE(18064), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732339] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25935), 1,
      anon_sym_DOT,
    STATE(18065), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732353] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25937), 1,
      anon_sym_with,
    STATE(18066), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732367] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25939), 1,
      anon_sym_RBRACE,
    STATE(18067), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732381] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25941), 1,
      anon_sym_RPAREN,
    STATE(18068), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732395] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25943), 1,
      anon_sym_RBRACE,
    STATE(18069), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732409] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25945), 1,
      anon_sym_RBRACK,
    STATE(18070), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732423] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25947), 1,
      anon_sym_RPAREN,
    STATE(18071), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732437] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25949), 1,
      anon_sym_DASH_GT,
    STATE(18072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732451] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25951), 1,
      anon_sym_end,
    STATE(18073), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732465] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25953), 1,
      anon_sym_end,
    STATE(18074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732479] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16631), 1,
      anon_sym_RPAREN,
    STATE(18075), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732493] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25955), 1,
      anon_sym_with,
    STATE(18076), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732507] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25957), 1,
      anon_sym_with,
    STATE(18077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732521] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25959), 1,
      anon_sym_RBRACE,
    STATE(18078), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732535] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8966), 1,
      anon_sym_DASH_GT,
    STATE(18079), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732549] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25961), 1,
      anon_sym_end,
    STATE(18080), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732563] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25963), 1,
      anon_sym_DOT,
    STATE(18081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732577] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25965), 1,
      anon_sym_RBRACE,
    STATE(18082), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732591] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16569), 1,
      anon_sym_RPAREN,
    STATE(18083), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732605] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25967), 1,
      anon_sym_DASH_GT,
    STATE(18084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732619] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25969), 1,
      anon_sym_DASH_GT,
    STATE(18085), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732633] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8885), 1,
      anon_sym_DASH_GT,
    STATE(18086), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732647] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17559), 1,
      anon_sym_GT,
    STATE(18087), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732661] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25971), 1,
      anon_sym_RPAREN,
    STATE(18088), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732675] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25973), 1,
      anon_sym_DOT,
    STATE(18089), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732689] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25975), 1,
      anon_sym_RBRACE,
    STATE(18090), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732703] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17913), 1,
      anon_sym_RPAREN,
    STATE(18091), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732717] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25977), 1,
      anon_sym_RBRACK,
    STATE(18092), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732731] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25979), 1,
      anon_sym_RBRACK,
    STATE(18093), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732745] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25981), 1,
      sym__lowercase_identifier,
    STATE(18094), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732759] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25983), 1,
      anon_sym_RBRACE,
    STATE(18095), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732773] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25985), 1,
      anon_sym_DQUOTE,
    STATE(18096), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732787] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25987), 1,
      anon_sym_SQUOTE2,
    STATE(18097), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732801] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25989), 1,
      anon_sym_RPAREN,
    STATE(18098), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732815] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25991), 1,
      anon_sym_RPAREN,
    STATE(18099), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732829] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25991), 1,
      anon_sym_RBRACK,
    STATE(18100), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732843] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25991), 1,
      anon_sym_RBRACE,
    STATE(18101), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732857] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20050), 1,
      anon_sym_end,
    STATE(18102), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732871] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21278), 1,
      anon_sym_GT_RBRACE,
    STATE(18103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732885] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25993), 1,
      anon_sym_DOT,
    STATE(18104), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732899] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25995), 1,
      anon_sym_RPAREN,
    STATE(18105), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732913] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25997), 1,
      anon_sym_RBRACE,
    STATE(18106), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732927] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(25999), 1,
      anon_sym_RPAREN,
    STATE(18107), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732941] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26001), 1,
      anon_sym_in,
    STATE(18108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732955] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26003), 1,
      anon_sym_in,
    STATE(18109), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732969] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26005), 1,
      anon_sym_DOT,
    STATE(18110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732983] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26007), 1,
      anon_sym_in,
    STATE(18111), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732997] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26009), 1,
      anon_sym_in,
    STATE(18112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733011] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26011), 1,
      anon_sym_RPAREN,
    STATE(18113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733025] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26013), 1,
      anon_sym_RPAREN,
    STATE(18114), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733039] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26015), 1,
      anon_sym_RPAREN,
    STATE(18115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733053] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26017), 1,
      anon_sym_LT_DASH,
    STATE(18116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733067] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26019), 1,
      anon_sym_with,
    STATE(18117), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733081] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26021), 1,
      anon_sym_with,
    STATE(18118), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733095] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26023), 1,
      anon_sym_DOT,
    STATE(18119), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733109] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26025), 1,
      anon_sym_RPAREN,
    STATE(18120), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733123] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26027), 1,
      anon_sym_RBRACK,
    STATE(18121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733137] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26029), 1,
      anon_sym_RBRACE,
    STATE(18122), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733151] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26031), 1,
      anon_sym_RPAREN,
    STATE(18123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733165] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26033), 1,
      anon_sym_RPAREN,
    STATE(18124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733179] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26035), 1,
      anon_sym_RPAREN,
    STATE(18125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733193] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26037), 1,
      anon_sym_GT,
    STATE(18126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733207] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26039), 1,
      anon_sym_LT_DASH,
    STATE(18127), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733221] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26041), 1,
      anon_sym_RPAREN,
    STATE(18128), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733235] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26043), 1,
      anon_sym_RBRACE,
    STATE(18129), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733249] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26045), 1,
      anon_sym_with,
    STATE(18130), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733263] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26047), 1,
      anon_sym_with,
    STATE(18131), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733277] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26049), 1,
      anon_sym_RBRACK,
    STATE(18132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733291] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26051), 1,
      anon_sym_RPAREN,
    STATE(18133), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733305] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26053), 1,
      anon_sym_RPAREN,
    STATE(18134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733319] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26055), 1,
      anon_sym_DOT,
    STATE(18135), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733333] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3173), 1,
      anon_sym_RPAREN,
    STATE(18136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733347] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26057), 1,
      anon_sym_RPAREN,
    STATE(18137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733361] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26059), 1,
      anon_sym_in,
    STATE(18138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733375] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11825), 1,
      anon_sym_GT,
    STATE(18139), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733389] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26061), 1,
      anon_sym_RPAREN,
    STATE(18140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733403] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26063), 1,
      anon_sym_in,
    STATE(18141), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733417] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26065), 1,
      anon_sym_RPAREN,
    STATE(18142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733431] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26067), 1,
      anon_sym_RBRACE,
    STATE(18143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733445] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17901), 1,
      anon_sym_RPAREN,
    STATE(18144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733459] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26069), 1,
      anon_sym_RBRACK,
    STATE(18145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733473] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26071), 1,
      anon_sym_in,
    STATE(18146), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733487] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26073), 1,
      anon_sym_RPAREN,
    STATE(18147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733501] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26075), 1,
      anon_sym_DASH_GT,
    STATE(18148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733515] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26077), 1,
      anon_sym_in,
    STATE(18149), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733529] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16595), 1,
      anon_sym_RPAREN,
    STATE(18150), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733543] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26079), 1,
      anon_sym_RPAREN,
    STATE(18151), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733557] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26081), 1,
      anon_sym_RPAREN,
    STATE(18152), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733571] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26081), 1,
      anon_sym_RBRACK,
    STATE(18153), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733585] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26081), 1,
      anon_sym_RBRACE,
    STATE(18154), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733599] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26083), 1,
      anon_sym_RBRACE,
    STATE(18155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733613] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26085), 1,
      anon_sym_end,
    STATE(18156), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733627] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26087), 1,
      anon_sym_RBRACE,
    STATE(18157), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733641] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21547), 1,
      anon_sym_GT_RBRACE,
    STATE(18158), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733655] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26089), 1,
      anon_sym_DASH_GT,
    STATE(18159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733669] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8933), 1,
      anon_sym_DASH_GT,
    STATE(18160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733683] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17523), 1,
      anon_sym_GT,
    STATE(18161), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733697] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26091), 1,
      anon_sym_RBRACE,
    STATE(18162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733711] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26093), 1,
      anon_sym_DOT,
    STATE(18163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733725] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26091), 1,
      anon_sym_RBRACK,
    STATE(18164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733739] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26095), 1,
      anon_sym_RBRACE,
    STATE(18165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733753] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26097), 1,
      anon_sym_RBRACK,
    STATE(18166), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733767] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26099), 1,
      anon_sym_with,
    STATE(18167), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733781] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26101), 1,
      anon_sym_with,
    STATE(18168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733795] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26103), 1,
      anon_sym_DOT,
    STATE(18169), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733809] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26105), 1,
      sym__lowercase_identifier,
    STATE(18170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733823] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26091), 1,
      anon_sym_RPAREN,
    STATE(18171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733837] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26107), 1,
      anon_sym_RPAREN,
    STATE(18172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733851] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26109), 1,
      anon_sym_DQUOTE,
    STATE(18173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733865] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19956), 1,
      anon_sym_end,
    STATE(18174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733879] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26111), 1,
      anon_sym_SQUOTE2,
    STATE(18175), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733893] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19920), 1,
      anon_sym_end,
    STATE(18176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733907] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26113), 1,
      anon_sym_with,
    STATE(18177), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733921] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26115), 1,
      anon_sym_with,
    STATE(18178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733935] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21609), 1,
      anon_sym_GT_RBRACE,
    STATE(18179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733949] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26117), 1,
      anon_sym_SQUOTE2,
    STATE(18180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733963] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26119), 1,
      anon_sym_RBRACE,
    STATE(18181), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733977] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26121), 1,
      anon_sym_DOT,
    STATE(18182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733991] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26123), 1,
      anon_sym_DQUOTE,
    STATE(18183), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734005] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26125), 1,
      sym__lowercase_identifier,
    STATE(18184), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734019] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18111), 1,
      anon_sym_RPAREN,
    STATE(18185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734033] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26127), 1,
      anon_sym_RBRACK,
    STATE(18186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734047] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18017), 1,
      anon_sym_RPAREN,
    STATE(18187), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734061] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26129), 1,
      anon_sym_in,
    STATE(18188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734075] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26131), 1,
      anon_sym_RBRACE,
    STATE(18189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734089] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26133), 1,
      anon_sym_in,
    STATE(18190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734103] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26135), 1,
      anon_sym_in,
    STATE(18191), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734117] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26137), 1,
      anon_sym_in,
    STATE(18192), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734131] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26139), 1,
      anon_sym_RPAREN,
    STATE(18193), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734145] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26141), 1,
      anon_sym_RPAREN,
    STATE(18194), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734159] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26141), 1,
      anon_sym_RBRACK,
    STATE(18195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734173] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26141), 1,
      anon_sym_RBRACE,
    STATE(18196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734187] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26143), 1,
      anon_sym_RPAREN,
    STATE(18197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734201] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8927), 1,
      anon_sym_DASH_GT,
    STATE(18198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734215] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21868), 1,
      anon_sym_GT_RBRACE,
    STATE(18199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734229] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26145), 1,
      anon_sym_RPAREN,
    STATE(18200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734243] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26147), 1,
      anon_sym_LT_DASH,
    STATE(18201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734257] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26149), 1,
      anon_sym_RBRACE,
    STATE(18202), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734271] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26151), 1,
      anon_sym_RBRACE,
    STATE(18203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734285] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26153), 1,
      anon_sym_DOT,
    STATE(18204), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734299] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26155), 1,
      anon_sym_DOT,
    STATE(18205), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734313] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26157), 1,
      anon_sym_RPAREN,
    STATE(18206), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734327] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26159), 1,
      anon_sym_RBRACE,
    STATE(18207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734341] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26161), 1,
      anon_sym_with,
    STATE(18208), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734355] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26163), 1,
      anon_sym_with,
    STATE(18209), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734369] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26165), 1,
      anon_sym_DOT,
    STATE(18210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734383] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26167), 1,
      anon_sym_GT,
    STATE(18211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734397] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16748), 1,
      anon_sym_RPAREN,
    STATE(18212), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734411] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26169), 1,
      anon_sym_RPAREN,
    STATE(18213), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734425] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26171), 1,
      anon_sym_RBRACE,
    STATE(18214), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734439] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26173), 1,
      anon_sym_RBRACK,
    STATE(18215), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734453] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26175), 1,
      anon_sym_RPAREN,
    STATE(18216), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734467] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26177), 1,
      anon_sym_with,
    STATE(18217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734481] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26179), 1,
      anon_sym_with,
    STATE(18218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734495] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26181), 1,
      anon_sym_RPAREN,
    STATE(18219), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734509] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11749), 1,
      anon_sym_GT,
    STATE(18220), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734523] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26183), 1,
      anon_sym_RPAREN,
    STATE(18221), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734537] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26185), 1,
      anon_sym_DOT,
    STATE(18222), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734551] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26187), 1,
      anon_sym_DASH_GT,
    STATE(18223), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734565] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26189), 1,
      anon_sym_with,
    STATE(18224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734579] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26191), 1,
      anon_sym_RPAREN,
    STATE(18225), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734593] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26193), 1,
      anon_sym_with,
    STATE(18226), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734607] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18183), 1,
      anon_sym_RPAREN,
    STATE(18227), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734621] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26195), 1,
      anon_sym_RPAREN,
    STATE(18228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734635] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26197), 1,
      anon_sym_RBRACK,
    STATE(18229), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734649] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26199), 1,
      anon_sym_RPAREN,
    STATE(18230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734663] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26201), 1,
      anon_sym_RBRACK,
    STATE(18231), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734677] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26203), 1,
      anon_sym_RPAREN,
    STATE(18232), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734691] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26205), 1,
      anon_sym_RPAREN,
    STATE(18233), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734705] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26207), 1,
      anon_sym_RPAREN,
    STATE(18234), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734719] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26207), 1,
      anon_sym_RBRACK,
    STATE(18235), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734733] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26207), 1,
      anon_sym_RBRACE,
    STATE(18236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734747] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26209), 1,
      anon_sym_DASH_GT,
    STATE(18237), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734761] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26211), 1,
      anon_sym_RBRACE,
    STATE(18238), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734775] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26213), 1,
      anon_sym_RPAREN,
    STATE(18239), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734789] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16830), 1,
      anon_sym_RPAREN,
    STATE(18240), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734803] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26215), 1,
      anon_sym_RBRACE,
    STATE(18241), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734817] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26217), 1,
      anon_sym_end,
    STATE(18242), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734831] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26219), 1,
      anon_sym_RPAREN,
    STATE(18243), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734845] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26221), 1,
      anon_sym_DOT,
    STATE(18244), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734859] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26223), 1,
      anon_sym_DASH_GT,
    STATE(18245), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734873] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9000), 1,
      anon_sym_DASH_GT,
    STATE(18246), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734887] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17695), 1,
      anon_sym_GT,
    STATE(18247), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734901] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26225), 1,
      anon_sym_with,
    STATE(18248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734915] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26227), 1,
      anon_sym_with,
    STATE(18249), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734929] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26229), 1,
      anon_sym_DOT,
    STATE(18250), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734943] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26231), 1,
      anon_sym_RPAREN,
    STATE(18251), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734957] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26233), 1,
      anon_sym_RPAREN,
    STATE(18252), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734971] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26235), 1,
      anon_sym_RBRACK,
    STATE(18253), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734985] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26237), 1,
      anon_sym_RBRACE,
    STATE(18254), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734999] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26239), 1,
      anon_sym_RBRACK,
    STATE(18255), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735013] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26241), 1,
      sym__lowercase_identifier,
    STATE(18256), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735027] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26243), 1,
      anon_sym_with,
    STATE(18257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735041] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26245), 1,
      anon_sym_with,
    STATE(18258), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735055] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26247), 1,
      anon_sym_RBRACE,
    STATE(18259), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735069] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26249), 1,
      anon_sym_DQUOTE,
    STATE(18260), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735083] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26251), 1,
      anon_sym_SQUOTE2,
    STATE(18261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735097] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26253), 1,
      anon_sym_DOT,
    STATE(18262), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735111] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26255), 1,
      anon_sym_RPAREN,
    STATE(18263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735125] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26257), 1,
      anon_sym_DOT,
    STATE(18264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735139] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26259), 1,
      anon_sym_with,
    STATE(18265), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735153] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19803), 1,
      anon_sym_end,
    STATE(18266), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735167] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18347), 1,
      anon_sym_RPAREN,
    STATE(18267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735181] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21921), 1,
      anon_sym_GT_RBRACE,
    STATE(18268), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735195] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26261), 1,
      anon_sym_RPAREN,
    STATE(18269), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735209] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26263), 1,
      anon_sym_with,
    STATE(18270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735223] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26265), 1,
      anon_sym_RBRACE,
    STATE(18271), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735237] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26267), 1,
      anon_sym_LT_DASH,
    STATE(18272), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735251] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26269), 1,
      anon_sym_RPAREN,
    STATE(18273), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735265] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26271), 1,
      anon_sym_RPAREN,
    STATE(18274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735279] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26271), 1,
      anon_sym_RBRACK,
    STATE(18275), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735293] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26271), 1,
      anon_sym_RBRACE,
    STATE(18276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735307] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26273), 1,
      anon_sym_in,
    STATE(18277), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735321] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3177), 1,
      anon_sym_RPAREN,
    STATE(18278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735335] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26275), 1,
      anon_sym_in,
    STATE(18279), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735349] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26277), 1,
      anon_sym_in,
    STATE(18280), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735363] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26279), 1,
      anon_sym_in,
    STATE(18281), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735377] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26281), 1,
      anon_sym_RPAREN,
    STATE(18282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735391] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26283), 1,
      anon_sym_RPAREN,
    STATE(18283), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735405] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26285), 1,
      anon_sym_DOT,
    STATE(18284), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735419] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26287), 1,
      anon_sym_RPAREN,
    STATE(18285), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735433] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26289), 1,
      anon_sym_LT_DASH,
    STATE(18286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735447] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26291), 1,
      anon_sym_in,
    STATE(18287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735461] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26293), 1,
      anon_sym_with,
    STATE(18288), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735475] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26295), 1,
      anon_sym_with,
    STATE(18289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735489] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26297), 1,
      anon_sym_DOT,
    STATE(18290), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735503] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26299), 1,
      anon_sym_in,
    STATE(18291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735517] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26301), 1,
      anon_sym_in,
    STATE(18292), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735531] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26303), 1,
      anon_sym_DOT,
    STATE(18293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735545] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26305), 1,
      anon_sym_RPAREN,
    STATE(18294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735559] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26307), 1,
      anon_sym_in,
    STATE(18295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735573] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26309), 1,
      anon_sym_GT,
    STATE(18296), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735587] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26311), 1,
      anon_sym_with,
    STATE(18297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735601] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26313), 1,
      anon_sym_with,
    STATE(18298), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735615] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26315), 1,
      anon_sym_RPAREN,
    STATE(18299), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735629] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26317), 1,
      anon_sym_RBRACE,
    STATE(18300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735643] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26319), 1,
      anon_sym_RBRACK,
    STATE(18301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735657] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26321), 1,
      anon_sym_DOT,
    STATE(18302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735671] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26323), 1,
      anon_sym_RBRACE,
    STATE(18303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735685] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26325), 1,
      anon_sym_DOT,
    STATE(18304), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735699] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21120), 1,
      anon_sym_GT_RBRACE,
    STATE(18305), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735713] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26327), 1,
      anon_sym_RPAREN,
    STATE(18306), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735727] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18317), 1,
      anon_sym_RPAREN,
    STATE(18307), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735741] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20108), 1,
      anon_sym_end,
    STATE(18308), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735755] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26329), 1,
      anon_sym_SQUOTE2,
    STATE(18309), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735769] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11670), 1,
      anon_sym_GT,
    STATE(18310), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735783] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26331), 1,
      anon_sym_RPAREN,
    STATE(18311), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735797] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26333), 1,
      anon_sym_DQUOTE,
    STATE(18312), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735811] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26335), 1,
      anon_sym_RPAREN,
    STATE(18313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735825] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26337), 1,
      anon_sym_RPAREN,
    STATE(18314), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735839] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26337), 1,
      anon_sym_RBRACK,
    STATE(18315), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735853] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26337), 1,
      anon_sym_RBRACE,
    STATE(18316), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735867] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26339), 1,
      anon_sym_RPAREN,
    STATE(18317), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735881] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26341), 1,
      sym__lowercase_identifier,
    STATE(18318), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735895] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26343), 1,
      anon_sym_RBRACE,
    STATE(18319), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735909] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26345), 1,
      anon_sym_RBRACK,
    STATE(18320), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735923] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26347), 1,
      anon_sym_RPAREN,
    STATE(18321), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735937] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26349), 1,
      anon_sym_DASH_GT,
    STATE(18322), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735951] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26351), 1,
      anon_sym_RBRACK,
    STATE(18323), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735965] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26353), 1,
      anon_sym_DOT,
    STATE(18324), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735979] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16738), 1,
      anon_sym_RPAREN,
    STATE(18325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735993] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26355), 1,
      anon_sym_RBRACE,
    STATE(18326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736007] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26357), 1,
      anon_sym_end,
    STATE(18327), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736021] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26359), 1,
      anon_sym_with,
    STATE(18328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736035] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26361), 1,
      anon_sym_with,
    STATE(18329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736049] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26363), 1,
      anon_sym_DOT,
    STATE(18330), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736063] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3219), 1,
      anon_sym_RPAREN,
    STATE(18331), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736077] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9026), 1,
      anon_sym_DASH_GT,
    STATE(18332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736091] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26365), 1,
      anon_sym_DASH_GT,
    STATE(18333), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736105] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9004), 1,
      anon_sym_DASH_GT,
    STATE(18334), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736119] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17710), 1,
      anon_sym_GT,
    STATE(18335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736133] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26367), 1,
      anon_sym_end,
    STATE(18336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736147] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26369), 1,
      anon_sym_with,
    STATE(18337), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736161] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26371), 1,
      anon_sym_with,
    STATE(18338), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736175] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26373), 1,
      anon_sym_RBRACE,
    STATE(18339), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736189] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26375), 1,
      anon_sym_RBRACE,
    STATE(18340), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736203] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26377), 1,
      anon_sym_RBRACK,
    STATE(18341), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736217] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26379), 1,
      anon_sym_DOT,
    STATE(18342), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736231] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16884), 1,
      anon_sym_RPAREN,
    STATE(18343), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736245] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26381), 1,
      anon_sym_DASH_GT,
    STATE(18344), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736259] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26383), 1,
      anon_sym_RPAREN,
    STATE(18345), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736273] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26385), 1,
      sym__lowercase_identifier,
    STATE(18346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736287] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18231), 1,
      anon_sym_RPAREN,
    STATE(18347), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736301] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26387), 1,
      anon_sym_RBRACK,
    STATE(18348), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736315] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26389), 1,
      anon_sym_RBRACE,
    STATE(18349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736329] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26391), 1,
      anon_sym_DQUOTE,
    STATE(18350), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736343] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26393), 1,
      anon_sym_SQUOTE2,
    STATE(18351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736357] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19647), 1,
      anon_sym_end,
    STATE(18352), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736371] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26395), 1,
      anon_sym_RPAREN,
    STATE(18353), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736385] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26397), 1,
      anon_sym_RPAREN,
    STATE(18354), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736399] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26397), 1,
      anon_sym_RBRACK,
    STATE(18355), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736413] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26397), 1,
      anon_sym_RBRACE,
    STATE(18356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736427] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22180), 1,
      anon_sym_GT_RBRACE,
    STATE(18357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736441] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26399), 1,
      anon_sym_RPAREN,
    STATE(18358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736455] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26401), 1,
      anon_sym_RBRACE,
    STATE(18359), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736469] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26403), 1,
      anon_sym_RBRACE,
    STATE(18360), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736483] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26401), 1,
      anon_sym_RBRACK,
    STATE(18361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736497] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26405), 1,
      anon_sym_in,
    STATE(18362), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736511] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26407), 1,
      anon_sym_in,
    STATE(18363), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736525] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26409), 1,
      anon_sym_DOT,
    STATE(18364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736539] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26411), 1,
      anon_sym_in,
    STATE(18365), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736553] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26413), 1,
      anon_sym_in,
    STATE(18366), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736567] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26415), 1,
      anon_sym_RPAREN,
    STATE(18367), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736581] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26417), 1,
      anon_sym_with,
    STATE(18368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736595] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26419), 1,
      anon_sym_with,
    STATE(18369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736609] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26421), 1,
      anon_sym_DOT,
    STATE(18370), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736623] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26401), 1,
      anon_sym_RPAREN,
    STATE(18371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736637] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26423), 1,
      anon_sym_RPAREN,
    STATE(18372), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736651] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3143), 1,
      anon_sym_RPAREN,
    STATE(18373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736665] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26425), 1,
      anon_sym_LT_DASH,
    STATE(18374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736679] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26427), 1,
      anon_sym_RPAREN,
    STATE(18375), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736693] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26429), 1,
      anon_sym_RPAREN,
    STATE(18376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736707] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26431), 1,
      anon_sym_with,
    STATE(18377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736721] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26433), 1,
      anon_sym_with,
    STATE(18378), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736735] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26435), 1,
      anon_sym_RPAREN,
    STATE(18379), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736749] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26437), 1,
      anon_sym_RPAREN,
    STATE(18380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736763] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26439), 1,
      anon_sym_RBRACK,
    STATE(18381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736777] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26441), 1,
      anon_sym_DOT,
    STATE(18382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736791] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26443), 1,
      anon_sym_RBRACE,
    STATE(18383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736805] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18263), 1,
      anon_sym_RPAREN,
    STATE(18384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736819] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26445), 1,
      anon_sym_RPAREN,
    STATE(18385), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736833] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26447), 1,
      anon_sym_GT,
    STATE(18386), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736847] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18163), 1,
      anon_sym_RPAREN,
    STATE(18387), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736861] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26449), 1,
      anon_sym_RPAREN,
    STATE(18388), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736875] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26451), 1,
      anon_sym_RPAREN,
    STATE(18389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736889] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26453), 1,
      anon_sym_RBRACE,
    STATE(18390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736903] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26455), 1,
      anon_sym_RBRACK,
    STATE(18391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736917] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26457), 1,
      anon_sym_RPAREN,
    STATE(18392), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736931] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26459), 1,
      anon_sym_RPAREN,
    STATE(18393), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736945] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26461), 1,
      anon_sym_RPAREN,
    STATE(18394), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736959] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26461), 1,
      anon_sym_RBRACK,
    STATE(18395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736973] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26461), 1,
      anon_sym_RBRACE,
    STATE(18396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736987] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26463), 1,
      anon_sym_RPAREN,
    STATE(18397), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737001] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26465), 1,
      anon_sym_LT_DASH,
    STATE(18398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737015] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11524), 1,
      anon_sym_GT,
    STATE(18399), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737029] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26467), 1,
      anon_sym_RPAREN,
    STATE(18400), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737043] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26469), 1,
      anon_sym_RBRACE,
    STATE(18401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737057] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26471), 1,
      anon_sym_RPAREN,
    STATE(18402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737071] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26473), 1,
      anon_sym_RBRACE,
    STATE(18403), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737085] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26475), 1,
      anon_sym_DOT,
    STATE(18404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737099] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26477), 1,
      anon_sym_RBRACK,
    STATE(18405), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737113] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26479), 1,
      anon_sym_RPAREN,
    STATE(18406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737127] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26481), 1,
      anon_sym_DASH_GT,
    STATE(18407), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737141] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26483), 1,
      anon_sym_with,
    STATE(18408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737155] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26485), 1,
      anon_sym_with,
    STATE(18409), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737169] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26487), 1,
      anon_sym_DOT,
    STATE(18410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737183] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26489), 1,
      anon_sym_DOT,
    STATE(18411), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737197] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26491), 1,
      anon_sym_RPAREN,
    STATE(18412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737211] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16691), 1,
      anon_sym_RPAREN,
    STATE(18413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737225] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26493), 1,
      anon_sym_RBRACE,
    STATE(18414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737239] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26495), 1,
      anon_sym_end,
    STATE(18415), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737253] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26497), 1,
      anon_sym_in,
    STATE(18416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737267] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26499), 1,
      anon_sym_with,
    STATE(18417), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737281] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26501), 1,
      anon_sym_with,
    STATE(18418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737295] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26503), 1,
      anon_sym_DASH_GT,
    STATE(18419), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737309] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8945), 1,
      anon_sym_DASH_GT,
    STATE(18420), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737323] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17545), 1,
      anon_sym_GT,
    STATE(18421), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737337] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26505), 1,
      anon_sym_DOT,
    STATE(18422), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737351] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26507), 1,
      anon_sym_in,
    STATE(18423), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737365] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26509), 1,
      anon_sym_with,
    STATE(18424), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737379] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26511), 1,
      anon_sym_in,
    STATE(18425), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737393] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26513), 1,
      anon_sym_with,
    STATE(18426), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737407] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18105), 1,
      anon_sym_RPAREN,
    STATE(18427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737421] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26515), 1,
      anon_sym_in,
    STATE(18428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737435] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26517), 1,
      anon_sym_RBRACE,
    STATE(18429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737449] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26519), 1,
      anon_sym_RBRACE,
    STATE(18430), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737463] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26521), 1,
      anon_sym_RBRACK,
    STATE(18431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737477] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26523), 1,
      sym__lowercase_identifier,
    STATE(18432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737491] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26525), 1,
      anon_sym_RPAREN,
    STATE(18433), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737505] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26527), 1,
      anon_sym_RPAREN,
    STATE(18434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737519] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26527), 1,
      anon_sym_RBRACK,
    STATE(18435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737533] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26527), 1,
      anon_sym_RBRACE,
    STATE(18436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737547] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20651), 1,
      anon_sym_GT_RBRACE,
    STATE(18437), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737561] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20291), 1,
      anon_sym_end,
    STATE(18438), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737575] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26529), 1,
      anon_sym_DQUOTE,
    STATE(18439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737589] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26531), 1,
      anon_sym_SQUOTE2,
    STATE(18440), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737603] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19557), 1,
      anon_sym_end,
    STATE(18441), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737617] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22377), 1,
      anon_sym_GT_RBRACE,
    STATE(18442), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737631] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26533), 1,
      anon_sym_SQUOTE2,
    STATE(18443), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737645] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26535), 1,
      anon_sym_DOT,
    STATE(18444), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737659] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26537), 1,
      anon_sym_RBRACE,
    STATE(18445), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737673] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26539), 1,
      anon_sym_DQUOTE,
    STATE(18446), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737687] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26541), 1,
      anon_sym_in,
    STATE(18447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737701] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26543), 1,
      anon_sym_with,
    STATE(18448), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737715] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26545), 1,
      anon_sym_with,
    STATE(18449), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737729] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26547), 1,
      anon_sym_DOT,
    STATE(18450), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737743] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26549), 1,
      anon_sym_in,
    STATE(18451), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737757] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26551), 1,
      sym__lowercase_identifier,
    STATE(18452), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737771] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26553), 1,
      anon_sym_in,
    STATE(18453), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737785] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26555), 1,
      anon_sym_in,
    STATE(18454), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737799] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26557), 1,
      anon_sym_RPAREN,
    STATE(18455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737813] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26559), 1,
      anon_sym_RBRACK,
    STATE(18456), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737827] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26561), 1,
      anon_sym_with,
    STATE(18457), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737841] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26563), 1,
      anon_sym_with,
    STATE(18458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737855] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26565), 1,
      anon_sym_LT_DASH,
    STATE(18459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737869] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26567), 1,
      anon_sym_RBRACK,
    STATE(18460), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737883] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26569), 1,
      anon_sym_DOT,
    STATE(18461), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737897] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26571), 1,
      anon_sym_DOT,
    STATE(18462), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737911] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26573), 1,
      anon_sym_with,
    STATE(18463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737925] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9016), 1,
      anon_sym_DASH_GT,
    STATE(18464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737939] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26575), 1,
      anon_sym_with,
    STATE(18465), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737953] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26577), 1,
      anon_sym_end,
    STATE(18466), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737967] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18087), 1,
      anon_sym_RPAREN,
    STATE(18467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737981] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26579), 1,
      anon_sym_RBRACE,
    STATE(18468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737995] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16758), 1,
      anon_sym_RPAREN,
    STATE(18469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738009] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26581), 1,
      anon_sym_RPAREN,
    STATE(18470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738023] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26583), 1,
      anon_sym_DASH_GT,
    STATE(18471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738037] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26585), 1,
      anon_sym_GT,
    STATE(18472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738051] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26587), 1,
      anon_sym_RPAREN,
    STATE(18473), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738065] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26589), 1,
      anon_sym_RPAREN,
    STATE(18474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738079] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26589), 1,
      anon_sym_RBRACK,
    STATE(18475), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738093] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26589), 1,
      anon_sym_RBRACE,
    STATE(18476), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738107] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26591), 1,
      anon_sym_RPAREN,
    STATE(18477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738121] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26593), 1,
      anon_sym_RPAREN,
    STATE(18478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738135] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26595), 1,
      anon_sym_RBRACE,
    STATE(18479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738149] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26597), 1,
      anon_sym_RBRACK,
    STATE(18480), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738163] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26599), 1,
      anon_sym_RPAREN,
    STATE(18481), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738177] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26601), 1,
      anon_sym_RPAREN,
    STATE(18482), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738191] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11468), 1,
      anon_sym_GT,
    STATE(18483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738205] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26603), 1,
      anon_sym_DOT,
    STATE(18484), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738219] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26605), 1,
      anon_sym_RPAREN,
    STATE(18485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738233] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26607), 1,
      anon_sym_RBRACK,
    STATE(18486), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738247] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26609), 1,
      anon_sym_RPAREN,
    STATE(18487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738261] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26611), 1,
      anon_sym_with,
    STATE(18488), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738275] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26613), 1,
      anon_sym_with,
    STATE(18489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738289] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26615), 1,
      anon_sym_DOT,
    STATE(18490), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738303] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26617), 1,
      anon_sym_RBRACE,
    STATE(18491), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738317] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26619), 1,
      anon_sym_DOT,
    STATE(18492), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738331] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26621), 1,
      anon_sym_RBRACK,
    STATE(18493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738345] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26623), 1,
      anon_sym_RPAREN,
    STATE(18494), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738359] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26625), 1,
      anon_sym_DASH_GT,
    STATE(18495), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738373] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26627), 1,
      anon_sym_RBRACE,
    STATE(18496), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738387] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26629), 1,
      anon_sym_with,
    STATE(18497), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738401] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26631), 1,
      anon_sym_with,
    STATE(18498), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738415] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16734), 1,
      anon_sym_RPAREN,
    STATE(18499), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738429] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26633), 1,
      anon_sym_RBRACE,
    STATE(18500), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738443] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26635), 1,
      anon_sym_end,
    STATE(18501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738457] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26637), 1,
      anon_sym_DOT,
    STATE(18502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738471] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26639), 1,
      anon_sym_RPAREN,
    STATE(18503), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738485] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26641), 1,
      anon_sym_DOT,
    STATE(18504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738499] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26643), 1,
      anon_sym_RPAREN,
    STATE(18505), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738513] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26645), 1,
      anon_sym_RPAREN,
    STATE(18506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738527] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18005), 1,
      anon_sym_RPAREN,
    STATE(18507), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738541] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26647), 1,
      anon_sym_DASH_GT,
    STATE(18508), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738555] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26649), 1,
      anon_sym_RPAREN,
    STATE(18509), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738569] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8903), 1,
      anon_sym_DASH_GT,
    STATE(18510), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738583] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17647), 1,
      anon_sym_GT,
    STATE(18511), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738597] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26651), 1,
      anon_sym_RBRACK,
    STATE(18512), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738611] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26653), 1,
      anon_sym_RPAREN,
    STATE(18513), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738625] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26655), 1,
      anon_sym_RPAREN,
    STATE(18514), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738639] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26655), 1,
      anon_sym_RBRACK,
    STATE(18515), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738653] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26655), 1,
      anon_sym_RBRACE,
    STATE(18516), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738667] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26657), 1,
      anon_sym_RBRACE,
    STATE(18517), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738681] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26659), 1,
      anon_sym_RPAREN,
    STATE(18518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738695] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26661), 1,
      anon_sym_RBRACE,
    STATE(18519), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738709] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26663), 1,
      anon_sym_RBRACK,
    STATE(18520), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738723] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26665), 1,
      sym__lowercase_identifier,
    STATE(18521), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738737] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26667), 1,
      anon_sym_RPAREN,
    STATE(18522), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738751] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26669), 1,
      anon_sym_DQUOTE,
    STATE(18523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738765] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26671), 1,
      anon_sym_DOT,
    STATE(18524), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738779] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26673), 1,
      anon_sym_SQUOTE2,
    STATE(18525), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738793] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19431), 1,
      anon_sym_end,
    STATE(18526), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738807] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22647), 1,
      anon_sym_GT_RBRACE,
    STATE(18527), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738821] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26675), 1,
      anon_sym_with,
    STATE(18528), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738835] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26677), 1,
      anon_sym_with,
    STATE(18529), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738849] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26679), 1,
      anon_sym_DOT,
    STATE(18530), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738863] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26681), 1,
      anon_sym_LT_DASH,
    STATE(18531), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738877] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3201), 1,
      anon_sym_RPAREN,
    STATE(18532), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738891] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26683), 1,
      anon_sym_RBRACE,
    STATE(18533), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738905] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26685), 1,
      anon_sym_RPAREN,
    STATE(18534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738919] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26687), 1,
      anon_sym_in,
    STATE(18535), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738933] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26689), 1,
      anon_sym_in,
    STATE(18536), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738947] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26691), 1,
      anon_sym_with,
    STATE(18537), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738961] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26693), 1,
      anon_sym_with,
    STATE(18538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738975] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26695), 1,
      anon_sym_in,
    STATE(18539), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738989] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26697), 1,
      anon_sym_in,
    STATE(18540), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739003] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26699), 1,
      anon_sym_RPAREN,
    STATE(18541), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739017] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26701), 1,
      anon_sym_DOT,
    STATE(18542), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739031] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26703), 1,
      anon_sym_in,
    STATE(18543), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739045] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26705), 1,
      anon_sym_in,
    STATE(18544), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739059] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26707), 1,
      anon_sym_in,
    STATE(18545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739073] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26709), 1,
      anon_sym_RPAREN,
    STATE(18546), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739087] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17965), 1,
      anon_sym_RPAREN,
    STATE(18547), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739101] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3169), 1,
      anon_sym_RPAREN,
    STATE(18548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739115] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26711), 1,
      anon_sym_RBRACE,
    STATE(18549), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739129] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26713), 1,
      anon_sym_LT_DASH,
    STATE(18550), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739143] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20508), 1,
      anon_sym_GT_RBRACE,
    STATE(18551), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739157] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20361), 1,
      anon_sym_end,
    STATE(18552), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739171] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26715), 1,
      anon_sym_RPAREN,
    STATE(18553), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739185] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26717), 1,
      anon_sym_RPAREN,
    STATE(18554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739199] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26717), 1,
      anon_sym_RBRACK,
    STATE(18555), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739213] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26717), 1,
      anon_sym_RBRACE,
    STATE(18556), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739227] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26719), 1,
      anon_sym_SQUOTE2,
    STATE(18557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739241] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26721), 1,
      anon_sym_DQUOTE,
    STATE(18558), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739255] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26723), 1,
      anon_sym_RPAREN,
    STATE(18559), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739269] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26725), 1,
      anon_sym_RBRACE,
    STATE(18560), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739283] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26727), 1,
      anon_sym_GT,
    STATE(18561), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739297] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26729), 1,
      anon_sym_RPAREN,
    STATE(18562), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739311] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26731), 1,
      anon_sym_RBRACE,
    STATE(18563), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739325] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26733), 1,
      anon_sym_DOT,
    STATE(18564), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739339] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26735), 1,
      anon_sym_RBRACK,
    STATE(18565), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739353] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26737), 1,
      anon_sym_RPAREN,
    STATE(18566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739367] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26739), 1,
      anon_sym_RPAREN,
    STATE(18567), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739381] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26741), 1,
      anon_sym_with,
    STATE(18568), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739395] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26743), 1,
      anon_sym_with,
    STATE(18569), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739409] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26745), 1,
      anon_sym_DOT,
    STATE(18570), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739423] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11398), 1,
      anon_sym_GT,
    STATE(18571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739437] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26725), 1,
      anon_sym_RBRACK,
    STATE(18572), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739451] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26747), 1,
      anon_sym_RPAREN,
    STATE(18573), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739465] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26725), 1,
      anon_sym_RPAREN,
    STATE(18574), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739479] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26749), 1,
      anon_sym_RPAREN,
    STATE(18575), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739493] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26751), 1,
      anon_sym_RBRACE,
    STATE(18576), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739507] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26753), 1,
      anon_sym_with,
    STATE(18577), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739521] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26755), 1,
      anon_sym_with,
    STATE(18578), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739535] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26757), 1,
      anon_sym_RBRACK,
    STATE(18579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739549] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26759), 1,
      anon_sym_RPAREN,
    STATE(18580), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739563] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26761), 1,
      anon_sym_DASH_GT,
    STATE(18581), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739577] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26763), 1,
      anon_sym_DOT,
    STATE(18582), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739591] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26765), 1,
      anon_sym_RPAREN,
    STATE(18583), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739605] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26767), 1,
      sym__lowercase_identifier,
    STATE(18584), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739619] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20721), 1,
      anon_sym_GT_RBRACE,
    STATE(18585), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739633] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26769), 1,
      anon_sym_RBRACE,
    STATE(18586), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739647] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17905), 1,
      anon_sym_RPAREN,
    STATE(18587), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739661] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16848), 1,
      anon_sym_RPAREN,
    STATE(18588), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739675] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18299), 1,
      anon_sym_RPAREN,
    STATE(18589), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739689] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26771), 1,
      anon_sym_RBRACE,
    STATE(18590), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739703] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26773), 1,
      anon_sym_end,
    STATE(18591), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739717] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8978), 1,
      anon_sym_DASH_GT,
    STATE(18592), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739731] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26775), 1,
      anon_sym_RPAREN,
    STATE(18593), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739745] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26777), 1,
      anon_sym_RPAREN,
    STATE(18594), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739759] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26777), 1,
      anon_sym_RBRACK,
    STATE(18595), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739773] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26777), 1,
      anon_sym_RBRACE,
    STATE(18596), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739787] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26779), 1,
      anon_sym_DASH_GT,
    STATE(18597), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739801] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8857), 1,
      anon_sym_DASH_GT,
    STATE(18598), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739815] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17615), 1,
      anon_sym_GT,
    STATE(18599), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739829] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26781), 1,
      anon_sym_end,
    STATE(18600), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739843] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26783), 1,
      anon_sym_RBRACE,
    STATE(18601), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739857] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26785), 1,
      anon_sym_RBRACE,
    STATE(18602), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739871] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26787), 1,
      anon_sym_DOT,
    STATE(18603), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739885] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26789), 1,
      anon_sym_RBRACK,
    STATE(18604), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739899] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26791), 1,
      sym__lowercase_identifier,
    STATE(18605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739913] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16846), 1,
      anon_sym_RPAREN,
    STATE(18606), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739927] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26793), 1,
      anon_sym_with,
    STATE(18607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739941] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26795), 1,
      anon_sym_with,
    STATE(18608), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739955] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26797), 1,
      anon_sym_DOT,
    STATE(18609), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739969] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26799), 1,
      anon_sym_DQUOTE,
    STATE(18610), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739983] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26801), 1,
      anon_sym_DASH_GT,
    STATE(18611), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739997] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26803), 1,
      anon_sym_SQUOTE2,
    STATE(18612), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740011] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_end,
    STATE(18613), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740025] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22937), 1,
      anon_sym_GT_RBRACE,
    STATE(18614), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740039] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26805), 1,
      anon_sym_RPAREN,
    STATE(18615), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740053] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26807), 1,
      anon_sym_with,
    STATE(18616), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740067] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26809), 1,
      anon_sym_with,
    STATE(18617), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740081] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26811), 1,
      anon_sym_RBRACE,
    STATE(18618), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740095] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26813), 1,
      anon_sym_in,
    STATE(18619), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740109] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26815), 1,
      anon_sym_in,
    STATE(18620), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740123] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26817), 1,
      anon_sym_DOT,
    STATE(18621), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740137] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26819), 1,
      anon_sym_DOT,
    STATE(18622), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740151] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26821), 1,
      anon_sym_RBRACK,
    STATE(18623), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740165] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26823), 1,
      anon_sym_RBRACE,
    STATE(18624), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740179] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26825), 1,
      anon_sym_in,
    STATE(18625), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740193] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17813), 1,
      anon_sym_RPAREN,
    STATE(18626), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740207] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26827), 1,
      anon_sym_in,
    STATE(18627), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740221] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26829), 1,
      anon_sym_RPAREN,
    STATE(18628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740235] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26831), 1,
      anon_sym_in,
    STATE(18629), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740249] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26833), 1,
      anon_sym_RPAREN,
    STATE(18630), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740263] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26835), 1,
      anon_sym_with,
    STATE(18631), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740277] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26837), 1,
      anon_sym_RPAREN,
    STATE(18632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740291] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26839), 1,
      anon_sym_RPAREN,
    STATE(18633), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740305] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26839), 1,
      anon_sym_RBRACK,
    STATE(18634), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740319] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26839), 1,
      anon_sym_RBRACE,
    STATE(18635), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740333] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26841), 1,
      anon_sym_RPAREN,
    STATE(18636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740347] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26843), 1,
      anon_sym_LT_DASH,
    STATE(18637), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740361] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26845), 1,
      anon_sym_with,
    STATE(18638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740375] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26847), 1,
      anon_sym_RPAREN,
    STATE(18639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740389] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26849), 1,
      anon_sym_RPAREN,
    STATE(18640), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740403] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26851), 1,
      anon_sym_RPAREN,
    STATE(18641), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740417] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26853), 1,
      anon_sym_DOT,
    STATE(18642), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740431] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26855), 1,
      anon_sym_RPAREN,
    STATE(18643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740445] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26857), 1,
      anon_sym_GT,
    STATE(18644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740459] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26859), 1,
      anon_sym_RPAREN,
    STATE(18645), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740473] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26861), 1,
      anon_sym_with,
    STATE(18646), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740487] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26863), 1,
      anon_sym_with,
    STATE(18647), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740501] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26865), 1,
      anon_sym_DOT,
    STATE(18648), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740515] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26867), 1,
      anon_sym_RBRACE,
    STATE(18649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740529] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26869), 1,
      anon_sym_RBRACK,
    STATE(18650), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740543] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26871), 1,
      anon_sym_RBRACK,
    STATE(18651), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740557] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26873), 1,
      anon_sym_RPAREN,
    STATE(18652), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740571] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26875), 1,
      anon_sym_RPAREN,
    STATE(18653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740585] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11574), 1,
      anon_sym_GT,
    STATE(18654), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740599] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26877), 1,
      anon_sym_with,
    STATE(18655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740613] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26879), 1,
      anon_sym_with,
    STATE(18656), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740627] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26881), 1,
      anon_sym_RPAREN,
    STATE(18657), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740641] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26883), 1,
      anon_sym_RBRACE,
    STATE(18658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740655] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26885), 1,
      anon_sym_RPAREN,
    STATE(18659), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740669] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26887), 1,
      anon_sym_DOT,
    STATE(18660), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740683] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26889), 1,
      anon_sym_RPAREN,
    STATE(18661), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740697] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26891), 1,
      anon_sym_in,
    STATE(18662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740711] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26893), 1,
      anon_sym_RPAREN,
    STATE(18663), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740725] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26895), 1,
      anon_sym_RBRACE,
    STATE(18664), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740739] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17969), 1,
      anon_sym_RPAREN,
    STATE(18665), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740753] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26897), 1,
      anon_sym_RBRACK,
    STATE(18666), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740767] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26899), 1,
      anon_sym_in,
    STATE(18667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740781] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26901), 1,
      anon_sym_RPAREN,
    STATE(18668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740795] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26903), 1,
      anon_sym_DASH_GT,
    STATE(18669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740809] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26905), 1,
      anon_sym_LT_DASH,
    STATE(18670), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740823] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26907), 1,
      anon_sym_RPAREN,
    STATE(18671), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740837] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26909), 1,
      anon_sym_RPAREN,
    STATE(18672), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740851] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26909), 1,
      anon_sym_RBRACK,
    STATE(18673), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740865] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26909), 1,
      anon_sym_RBRACE,
    STATE(18674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740879] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16603), 1,
      anon_sym_RPAREN,
    STATE(18675), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740893] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26911), 1,
      anon_sym_RBRACE,
    STATE(18676), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740907] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26913), 1,
      anon_sym_end,
    STATE(18677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740921] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26915), 1,
      anon_sym_in,
    STATE(18678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740935] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26917), 1,
      anon_sym_DASH_GT,
    STATE(18679), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740949] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26919), 1,
      anon_sym_DOT,
    STATE(18680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740963] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9024), 1,
      anon_sym_DASH_GT,
    STATE(18681), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740977] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17577), 1,
      anon_sym_GT,
    STATE(18682), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740991] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26921), 1,
      anon_sym_DOT,
    STATE(18683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741005] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26923), 1,
      anon_sym_with,
    STATE(18684), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741019] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26925), 1,
      anon_sym_with,
    STATE(18685), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741033] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26927), 1,
      anon_sym_DOT,
    STATE(18686), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741047] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26929), 1,
      anon_sym_with,
    STATE(18687), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741061] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3269), 1,
      anon_sym_RPAREN,
    STATE(18688), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741075] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26931), 1,
      anon_sym_RBRACE,
    STATE(18689), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741089] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26933), 1,
      anon_sym_RBRACK,
    STATE(18690), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741103] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26935), 1,
      sym__lowercase_identifier,
    STATE(18691), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741117] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26937), 1,
      anon_sym_RPAREN,
    STATE(18692), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741131] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26939), 1,
      anon_sym_with,
    STATE(18693), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741145] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26941), 1,
      anon_sym_with,
    STATE(18694), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741159] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26943), 1,
      anon_sym_DQUOTE,
    STATE(18695), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741173] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26945), 1,
      anon_sym_SQUOTE2,
    STATE(18696), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741187] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19726), 1,
      anon_sym_end,
    STATE(18697), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741201] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26947), 1,
      anon_sym_DOT,
    STATE(18698), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741215] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26949), 1,
      anon_sym_with,
    STATE(18699), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741229] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26951), 1,
      anon_sym_in,
    STATE(18700), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741243] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26953), 1,
      anon_sym_in,
    STATE(18701), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741257] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22216), 1,
      anon_sym_GT_RBRACE,
    STATE(18702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741271] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18257), 1,
      anon_sym_RPAREN,
    STATE(18703), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741285] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26955), 1,
      anon_sym_in,
    STATE(18704), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741299] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26957), 1,
      anon_sym_in,
    STATE(18705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741313] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26959), 1,
      anon_sym_RBRACE,
    STATE(18706), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741327] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26961), 1,
      anon_sym_RBRACE,
    STATE(18707), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741341] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16984), 1,
      anon_sym_DASH_GT,
    STATE(18708), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741355] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26963), 1,
      anon_sym_RPAREN,
    STATE(18709), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741369] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26965), 1,
      anon_sym_RPAREN,
    STATE(18710), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741383] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26965), 1,
      anon_sym_RBRACK,
    STATE(18711), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741397] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26965), 1,
      anon_sym_RBRACE,
    STATE(18712), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741411] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26967), 1,
      anon_sym_in,
    STATE(18713), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741425] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26969), 1,
      anon_sym_RBRACK,
    STATE(18714), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741439] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26971), 1,
      anon_sym_in,
    STATE(18715), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741453] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26973), 1,
      anon_sym_in,
    STATE(18716), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741467] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26975), 1,
      anon_sym_RPAREN,
    STATE(18717), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741481] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26977), 1,
      anon_sym_DOT,
    STATE(18718), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741495] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26979), 1,
      anon_sym_RBRACE,
    STATE(18719), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741509] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26981), 1,
      anon_sym_RPAREN,
    STATE(18720), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741523] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26983), 1,
      anon_sym_LT_DASH,
    STATE(18721), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741537] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26985), 1,
      anon_sym_with,
    STATE(18722), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741551] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26987), 1,
      anon_sym_with,
    STATE(18723), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741565] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26989), 1,
      anon_sym_DOT,
    STATE(18724), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741579] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20287), 1,
      anon_sym_end,
    STATE(18725), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741593] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26991), 1,
      anon_sym_DOT,
    STATE(18726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741607] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26993), 1,
      anon_sym_SQUOTE2,
    STATE(18727), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741621] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26995), 1,
      anon_sym_DOT,
    STATE(18728), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741635] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26997), 1,
      anon_sym_RPAREN,
    STATE(18729), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741649] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(26999), 1,
      anon_sym_DQUOTE,
    STATE(18730), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741663] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27001), 1,
      anon_sym_with,
    STATE(18731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741677] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27003), 1,
      anon_sym_with,
    STATE(18732), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741691] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27005), 1,
      anon_sym_GT,
    STATE(18733), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741705] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27007), 1,
      anon_sym_RPAREN,
    STATE(18734), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741719] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27009), 1,
      anon_sym_RBRACE,
    STATE(18735), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741733] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27011), 1,
      anon_sym_DOT,
    STATE(18736), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741747] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27013), 1,
      sym__lowercase_identifier,
    STATE(18737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741761] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27015), 1,
      anon_sym_DOT,
    STATE(18738), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741775] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27017), 1,
      anon_sym_RBRACK,
    STATE(18739), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741789] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27019), 1,
      anon_sym_RBRACK,
    STATE(18740), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741803] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18083), 1,
      anon_sym_RPAREN,
    STATE(18741), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741817] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27021), 1,
      anon_sym_RPAREN,
    STATE(18742), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741831] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20905), 1,
      anon_sym_GT_RBRACE,
    STATE(18743), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741845] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27023), 1,
      anon_sym_RPAREN,
    STATE(18744), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741859] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11809), 1,
      anon_sym_GT,
    STATE(18745), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741873] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27025), 1,
      anon_sym_RPAREN,
    STATE(18746), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741887] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27027), 1,
      anon_sym_RPAREN,
    STATE(18747), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741901] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27029), 1,
      anon_sym_RPAREN,
    STATE(18748), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741915] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27029), 1,
      anon_sym_RBRACK,
    STATE(18749), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741929] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27029), 1,
      anon_sym_RBRACE,
    STATE(18750), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741943] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27031), 1,
      anon_sym_end,
    STATE(18751), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741957] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27033), 1,
      anon_sym_RPAREN,
    STATE(18752), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741971] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27035), 1,
      anon_sym_RBRACE,
    STATE(18753), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741985] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27037), 1,
      anon_sym_RBRACE,
    STATE(18754), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741999] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27039), 1,
      anon_sym_RPAREN,
    STATE(18755), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742013] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27041), 1,
      anon_sym_DOT,
    STATE(18756), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742027] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27043), 1,
      anon_sym_DASH_GT,
    STATE(18757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742041] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16810), 1,
      anon_sym_RPAREN,
    STATE(18758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742055] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16617), 1,
      anon_sym_RPAREN,
    STATE(18759), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742069] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27045), 1,
      anon_sym_with,
    STATE(18760), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742083] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27047), 1,
      anon_sym_with,
    STATE(18761), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742097] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27049), 1,
      anon_sym_DOT,
    STATE(18762), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742111] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27051), 1,
      anon_sym_RBRACE,
    STATE(18763), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742125] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27053), 1,
      anon_sym_DASH_GT,
    STATE(18764), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742139] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27055), 1,
      anon_sym_end,
    STATE(18765), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742153] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27057), 1,
      anon_sym_RPAREN,
    STATE(18766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742167] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27059), 1,
      anon_sym_DASH_GT,
    STATE(18767), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742181] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8893), 1,
      anon_sym_DASH_GT,
    STATE(18768), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742195] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27061), 1,
      anon_sym_with,
    STATE(18769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742209] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27063), 1,
      anon_sym_with,
    STATE(18770), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742223] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17629), 1,
      anon_sym_GT,
    STATE(18771), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742237] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27065), 1,
      anon_sym_RBRACK,
    STATE(18772), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742251] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27067), 1,
      anon_sym_RBRACE,
    STATE(18773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742265] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27069), 1,
      anon_sym_DOT,
    STATE(18774), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742279] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27071), 1,
      anon_sym_RPAREN,
    STATE(18775), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742293] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27073), 1,
      anon_sym_RPAREN,
    STATE(18776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742307] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27075), 1,
      anon_sym_RPAREN,
    STATE(18777), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742321] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27077), 1,
      anon_sym_RBRACE,
    STATE(18778), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742335] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18207), 1,
      anon_sym_RPAREN,
    STATE(18779), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742349] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27079), 1,
      anon_sym_RBRACK,
    STATE(18780), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742363] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27081), 1,
      anon_sym_RPAREN,
    STATE(18781), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742377] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27083), 1,
      sym__lowercase_identifier,
    STATE(18782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742391] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27085), 1,
      anon_sym_RBRACK,
    STATE(18783), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742405] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27087), 1,
      anon_sym_DQUOTE,
    STATE(18784), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742419] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27089), 1,
      anon_sym_RPAREN,
    STATE(18785), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742433] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27091), 1,
      anon_sym_RPAREN,
    STATE(18786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742447] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27091), 1,
      anon_sym_RBRACK,
    STATE(18787), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742461] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27091), 1,
      anon_sym_RBRACE,
    STATE(18788), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742475] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27093), 1,
      anon_sym_SQUOTE2,
    STATE(18789), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742489] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20373), 1,
      anon_sym_end,
    STATE(18790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742503] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20613), 1,
      anon_sym_GT_RBRACE,
    STATE(18791), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742517] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27095), 1,
      anon_sym_RBRACE,
    STATE(18792), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742531] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27097), 1,
      anon_sym_RBRACE,
    STATE(18793), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742545] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27099), 1,
      anon_sym_DOT,
    STATE(18794), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742559] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27101), 1,
      anon_sym_RPAREN,
    STATE(18795), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742573] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12471), 1,
      anon_sym_DASH_GT,
    STATE(18796), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742587] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27103), 1,
      anon_sym_in,
    STATE(18797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742601] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27105), 1,
      anon_sym_with,
    STATE(18798), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742615] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27107), 1,
      anon_sym_with,
    STATE(18799), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742629] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27109), 1,
      anon_sym_DOT,
    STATE(18800), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742643] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27111), 1,
      anon_sym_in,
    STATE(18801), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742657] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27113), 1,
      anon_sym_RPAREN,
    STATE(18802), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742671] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27115), 1,
      anon_sym_in,
    STATE(18803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742685] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27117), 1,
      anon_sym_in,
    STATE(18804), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742699] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5191), 1,
      anon_sym_end,
    STATE(18805), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742713] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27119), 1,
      anon_sym_RPAREN,
    STATE(18806), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742727] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27121), 1,
      anon_sym_with,
    STATE(18807), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742741] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27123), 1,
      anon_sym_with,
    STATE(18808), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742755] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27125), 1,
      anon_sym_LT_DASH,
    STATE(18809), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742769] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27127), 1,
      anon_sym_RPAREN,
    STATE(18810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742783] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27129), 1,
      anon_sym_LT_DASH,
    STATE(18811), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742797] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27131), 1,
      anon_sym_DOT,
    STATE(18812), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742811] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3233), 1,
      anon_sym_RPAREN,
    STATE(18813), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742825] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27133), 1,
      anon_sym_RPAREN,
    STATE(18814), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742839] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27135), 1,
      anon_sym_in,
    STATE(18815), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742853] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27137), 1,
      anon_sym_in,
    STATE(18816), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742867] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18171), 1,
      anon_sym_RPAREN,
    STATE(18817), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742881] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27139), 1,
      anon_sym_DASH_GT,
    STATE(18818), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742895] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27141), 1,
      anon_sym_in,
    STATE(18819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742909] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27143), 1,
      anon_sym_RPAREN,
    STATE(18820), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742923] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27145), 1,
      anon_sym_in,
    STATE(18821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742937] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27147), 1,
      anon_sym_RPAREN,
    STATE(18822), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742951] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27149), 1,
      anon_sym_RPAREN,
    STATE(18823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742965] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27149), 1,
      anon_sym_RBRACK,
    STATE(18824), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742979] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27149), 1,
      anon_sym_RBRACE,
    STATE(18825), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742993] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27151), 1,
      anon_sym_GT,
    STATE(18826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743007] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27153), 1,
      anon_sym_RPAREN,
    STATE(18827), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743021] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27155), 1,
      anon_sym_DASH_GT,
    STATE(18828), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743035] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27157), 1,
      anon_sym_RPAREN,
    STATE(18829), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743049] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27159), 1,
      anon_sym_RBRACE,
    STATE(18830), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743063] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27161), 1,
      anon_sym_DOT,
    STATE(18831), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743077] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27163), 1,
      anon_sym_RBRACK,
    STATE(18832), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743091] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27165), 1,
      anon_sym_RPAREN,
    STATE(18833), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743105] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27167), 1,
      anon_sym_RPAREN,
    STATE(18834), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743119] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27169), 1,
      anon_sym_with,
    STATE(18835), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743133] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27171), 1,
      anon_sym_with,
    STATE(18836), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743147] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27173), 1,
      anon_sym_DOT,
    STATE(18837), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743161] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11833), 1,
      anon_sym_GT,
    STATE(18838), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743175] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27175), 1,
      anon_sym_RBRACE,
    STATE(18839), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743189] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27177), 1,
      anon_sym_RPAREN,
    STATE(18840), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743203] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27179), 1,
      anon_sym_RPAREN,
    STATE(18841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743217] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27181), 1,
      anon_sym_LT_DASH,
    STATE(18842), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743231] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27183), 1,
      anon_sym_DASH_GT,
    STATE(18843), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743245] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27185), 1,
      anon_sym_with,
    STATE(18844), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743259] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27187), 1,
      anon_sym_with,
    STATE(18845), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743273] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20221), 1,
      anon_sym_end,
    STATE(18846), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743287] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27189), 1,
      anon_sym_RPAREN,
    STATE(18847), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743301] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27191), 1,
      anon_sym_RBRACE,
    STATE(18848), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743315] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27193), 1,
      anon_sym_DOT,
    STATE(18849), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743329] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27195), 1,
      anon_sym_SQUOTE2,
    STATE(18850), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743343] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27197), 1,
      anon_sym_DQUOTE,
    STATE(18851), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743357] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27199), 1,
      sym__lowercase_identifier,
    STATE(18852), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743371] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27201), 1,
      anon_sym_RBRACK,
    STATE(18853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743385] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18011), 1,
      anon_sym_RPAREN,
    STATE(18854), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743399] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27203), 1,
      anon_sym_RPAREN,
    STATE(18855), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743413] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27205), 1,
      anon_sym_DASH_GT,
    STATE(18856), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743427] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27207), 1,
      anon_sym_RBRACE,
    STATE(18857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743441] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16601), 1,
      anon_sym_RPAREN,
    STATE(18858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743455] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27209), 1,
      anon_sym_RPAREN,
    STATE(18859), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743469] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27211), 1,
      anon_sym_RPAREN,
    STATE(18860), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743483] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27211), 1,
      anon_sym_RBRACK,
    STATE(18861), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743497] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27211), 1,
      anon_sym_RBRACE,
    STATE(18862), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743511] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27213), 1,
      anon_sym_RBRACE,
    STATE(18863), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743525] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27215), 1,
      anon_sym_DASH_GT,
    STATE(18864), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743539] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27217), 1,
      anon_sym_end,
    STATE(18865), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743553] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27207), 1,
      anon_sym_RBRACK,
    STATE(18866), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743567] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27219), 1,
      anon_sym_DASH_GT,
    STATE(18867), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743581] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27221), 1,
      anon_sym_DOT,
    STATE(18868), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743595] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9008), 1,
      anon_sym_DASH_GT,
    STATE(18869), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743609] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17541), 1,
      anon_sym_GT,
    STATE(18870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743623] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27207), 1,
      anon_sym_RPAREN,
    STATE(18871), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743637] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27223), 1,
      anon_sym_with,
    STATE(18872), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743651] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27225), 1,
      anon_sym_with,
    STATE(18873), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743665] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27227), 1,
      anon_sym_DOT,
    STATE(18874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743679] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27229), 1,
      anon_sym_RPAREN,
    STATE(18875), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743693] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27231), 1,
      anon_sym_RBRACK,
    STATE(18876), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743707] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27233), 1,
      anon_sym_RBRACE,
    STATE(18877), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743721] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27235), 1,
      anon_sym_RBRACK,
    STATE(18878), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743735] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27237), 1,
      anon_sym_DASH_GT,
    STATE(18879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743749] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27239), 1,
      anon_sym_DASH_GT,
    STATE(18880), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743763] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27241), 1,
      anon_sym_with,
    STATE(18881), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743777] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27243), 1,
      anon_sym_with,
    STATE(18882), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743791] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27245), 1,
      sym__lowercase_identifier,
    STATE(18883), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743805] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27247), 1,
      anon_sym_RBRACE,
    STATE(18884), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743819] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27249), 1,
      anon_sym_DQUOTE,
    STATE(18885), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743833] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27251), 1,
      anon_sym_DOT,
    STATE(18886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743847] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8941), 1,
      anon_sym_DASH_GT,
    STATE(18887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743861] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27253), 1,
      anon_sym_end,
    STATE(18888), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743875] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27255), 1,
      anon_sym_RBRACE,
    STATE(18889), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743889] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27257), 1,
      anon_sym_SQUOTE2,
    STATE(18890), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743903] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17885), 1,
      anon_sym_RPAREN,
    STATE(18891), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743917] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19477), 1,
      anon_sym_end,
    STATE(18892), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743931] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22861), 1,
      anon_sym_GT_RBRACE,
    STATE(18893), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743945] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27259), 1,
      anon_sym_RPAREN,
    STATE(18894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743959] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27261), 1,
      anon_sym_RBRACE,
    STATE(18895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743973] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27263), 1,
      anon_sym_RPAREN,
    STATE(18896), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743987] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27265), 1,
      anon_sym_RPAREN,
    STATE(18897), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744001] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27265), 1,
      anon_sym_RBRACK,
    STATE(18898), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744015] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27265), 1,
      anon_sym_RBRACE,
    STATE(18899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744029] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18107), 1,
      anon_sym_RPAREN,
    STATE(18900), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744043] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12430), 1,
      anon_sym_DASH_GT,
    STATE(18901), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744057] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27267), 1,
      anon_sym_in,
    STATE(18902), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744071] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27269), 1,
      anon_sym_in,
    STATE(18903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744085] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27271), 1,
      anon_sym_in,
    STATE(18904), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744099] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27273), 1,
      anon_sym_DOT,
    STATE(18905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744113] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27275), 1,
      anon_sym_in,
    STATE(18906), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744127] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27277), 1,
      aux_sym_number_token1,
    STATE(18907), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744141] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(4949), 1,
      anon_sym_end,
    STATE(18908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744155] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27279), 1,
      anon_sym_with,
    STATE(18909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744169] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27281), 1,
      anon_sym_with,
    STATE(18910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744183] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27283), 1,
      anon_sym_DOT,
    STATE(18911), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744197] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27285), 1,
      anon_sym_RPAREN,
    STATE(18912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744211] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16790), 1,
      anon_sym_RPAREN,
    STATE(18913), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744225] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27287), 1,
      anon_sym_DASH_GT,
    STATE(18914), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744239] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27289), 1,
      anon_sym_RPAREN,
    STATE(18915), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744253] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27291), 1,
      anon_sym_LT_DASH,
    STATE(18916), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744267] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27293), 1,
      anon_sym_RPAREN,
    STATE(18917), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744281] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27295), 1,
      anon_sym_with,
    STATE(18918), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744295] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27297), 1,
      anon_sym_with,
    STATE(18919), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744309] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27299), 1,
      anon_sym_RBRACK,
    STATE(18920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744323] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27301), 1,
      anon_sym_RBRACE,
    STATE(18921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744337] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27303), 1,
      anon_sym_RPAREN,
    STATE(18922), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744351] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27305), 1,
      anon_sym_DOT,
    STATE(18923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744365] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27307), 1,
      anon_sym_RPAREN,
    STATE(18924), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744379] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27309), 1,
      anon_sym_RPAREN,
    STATE(18925), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744393] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27311), 1,
      anon_sym_in,
    STATE(18926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744407] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27313), 1,
      anon_sym_DOT,
    STATE(18927), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744421] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18055), 1,
      anon_sym_RPAREN,
    STATE(18928), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744435] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27315), 1,
      anon_sym_GT,
    STATE(18929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744449] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27317), 1,
      anon_sym_RPAREN,
    STATE(18930), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744463] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27319), 1,
      anon_sym_DASH_GT,
    STATE(18931), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744477] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27321), 1,
      anon_sym_RPAREN,
    STATE(18932), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744491] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27323), 1,
      anon_sym_RPAREN,
    STATE(18933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744505] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27325), 1,
      anon_sym_RPAREN,
    STATE(18934), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744519] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27325), 1,
      anon_sym_RBRACK,
    STATE(18935), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744533] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27325), 1,
      anon_sym_RBRACE,
    STATE(18936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744547] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27327), 1,
      anon_sym_RBRACE,
    STATE(18937), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744561] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27329), 1,
      anon_sym_RBRACK,
    STATE(18938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744575] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27331), 1,
      anon_sym_RPAREN,
    STATE(18939), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744589] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27333), 1,
      anon_sym_RPAREN,
    STATE(18940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744603] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11556), 1,
      anon_sym_GT,
    STATE(18941), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744617] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27335), 1,
      anon_sym_RPAREN,
    STATE(18942), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744631] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27337), 1,
      anon_sym_RPAREN,
    STATE(18943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744645] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27339), 1,
      anon_sym_DASH_GT,
    STATE(18944), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744659] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27341), 1,
      anon_sym_with,
    STATE(18945), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744673] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27343), 1,
      anon_sym_with,
    STATE(18946), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744687] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27345), 1,
      anon_sym_DOT,
    STATE(18947), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744701] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27347), 1,
      anon_sym_DASH_GT,
    STATE(18948), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744715] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8957), 1,
      anon_sym_DASH_GT,
    STATE(18949), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744729] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27349), 1,
      anon_sym_RBRACK,
    STATE(18950), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744743] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27351), 1,
      anon_sym_DASH_GT,
    STATE(18951), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744757] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27353), 1,
      anon_sym_RBRACE,
    STATE(18952), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744771] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27355), 1,
      anon_sym_RBRACK,
    STATE(18953), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744785] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27357), 1,
      anon_sym_with,
    STATE(18954), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744799] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27359), 1,
      anon_sym_with,
    STATE(18955), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744813] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27361), 1,
      anon_sym_RPAREN,
    STATE(18956), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744827] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27363), 1,
      anon_sym_DASH_GT,
    STATE(18957), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744841] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27365), 1,
      anon_sym_RBRACE,
    STATE(18958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744855] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27367), 1,
      anon_sym_DOT,
    STATE(18959), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744869] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27369), 1,
      anon_sym_with,
    STATE(18960), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744883] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27371), 1,
      anon_sym_RPAREN,
    STATE(18961), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744897] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27373), 1,
      anon_sym_with,
    STATE(18962), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744911] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16573), 1,
      anon_sym_RPAREN,
    STATE(18963), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744925] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18093), 1,
      anon_sym_RPAREN,
    STATE(18964), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744939] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27375), 1,
      anon_sym_RBRACE,
    STATE(18965), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744953] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27377), 1,
      anon_sym_DASH_GT,
    STATE(18966), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744967] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27379), 1,
      anon_sym_end,
    STATE(18967), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744981] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27381), 1,
      anon_sym_RPAREN,
    STATE(18968), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744995] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27383), 1,
      anon_sym_RPAREN,
    STATE(18969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745009] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27385), 1,
      anon_sym_RPAREN,
    STATE(18970), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745023] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27385), 1,
      anon_sym_RBRACK,
    STATE(18971), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745037] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27385), 1,
      anon_sym_RBRACE,
    STATE(18972), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745051] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27387), 1,
      anon_sym_SQUOTE2,
    STATE(18973), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745065] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3255), 1,
      anon_sym_RPAREN,
    STATE(18974), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745079] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8905), 1,
      anon_sym_DASH_GT,
    STATE(18975), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745093] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17633), 1,
      anon_sym_GT,
    STATE(18976), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745107] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27389), 1,
      anon_sym_RPAREN,
    STATE(18977), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745121] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27391), 1,
      anon_sym_in,
    STATE(18978), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745135] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27393), 1,
      anon_sym_RBRACE,
    STATE(18979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745149] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27395), 1,
      anon_sym_with,
    STATE(18980), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745163] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27397), 1,
      anon_sym_with,
    STATE(18981), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745177] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27399), 1,
      anon_sym_DOT,
    STATE(18982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745191] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27401), 1,
      anon_sym_in,
    STATE(18983), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745205] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27403), 1,
      anon_sym_RBRACK,
    STATE(18984), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745219] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27405), 1,
      anon_sym_with,
    STATE(18985), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745233] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27407), 1,
      anon_sym_with,
    STATE(18986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745247] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27409), 1,
      anon_sym_DOT,
    STATE(18987), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745261] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27411), 1,
      anon_sym_in,
    STATE(18988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745275] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27413), 1,
      anon_sym_in,
    STATE(18989), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745289] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27415), 1,
      anon_sym_in,
    STATE(18990), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745303] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18063), 1,
      anon_sym_RPAREN,
    STATE(18991), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745317] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27417), 1,
      anon_sym_DASH_GT,
    STATE(18992), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745331] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27419), 1,
      anon_sym_RPAREN,
    STATE(18993), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745345] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27421), 1,
      anon_sym_RPAREN,
    STATE(18994), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745359] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27421), 1,
      anon_sym_RBRACK,
    STATE(18995), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745373] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27421), 1,
      anon_sym_RBRACE,
    STATE(18996), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745387] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27423), 1,
      anon_sym_DASH_GT,
    STATE(18997), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745401] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27425), 1,
      sym__lowercase_identifier,
    STATE(18998), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745415] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27427), 1,
      anon_sym_RBRACE,
    STATE(18999), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745429] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27429), 1,
      anon_sym_DQUOTE,
    STATE(19000), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745443] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27431), 1,
      anon_sym_SQUOTE2,
    STATE(19001), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745457] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27433), 1,
      anon_sym_DOT,
    STATE(19002), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745471] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27435), 1,
      anon_sym_DOT,
    STATE(19003), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745485] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20066), 1,
      anon_sym_end,
    STATE(19004), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745499] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27437), 1,
      anon_sym_with,
    STATE(19005), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745513] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21080), 1,
      anon_sym_GT_RBRACE,
    STATE(19006), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745527] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20146), 1,
      anon_sym_end,
    STATE(19007), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745541] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18161), 1,
      anon_sym_RPAREN,
    STATE(19008), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745555] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21437), 1,
      anon_sym_GT_RBRACE,
    STATE(19009), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745569] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27439), 1,
      anon_sym_RPAREN,
    STATE(19010), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745583] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27441), 1,
      anon_sym_RPAREN,
    STATE(19011), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745597] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27441), 1,
      anon_sym_RBRACK,
    STATE(19012), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745611] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27441), 1,
      anon_sym_RBRACE,
    STATE(19013), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745625] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27443), 1,
      anon_sym_with,
    STATE(19014), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745639] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27445), 1,
      anon_sym_RBRACE,
    STATE(19015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745653] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27447), 1,
      anon_sym_SQUOTE2,
    STATE(19016), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745667] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13388), 1,
      anon_sym_DASH_GT,
    STATE(19017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745681] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27449), 1,
      anon_sym_in,
    STATE(19018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745695] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27451), 1,
      anon_sym_DQUOTE,
    STATE(19019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745709] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27453), 1,
      sym__lowercase_identifier,
    STATE(19020), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745723] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27455), 1,
      anon_sym_RBRACK,
    STATE(19021), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745737] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27457), 1,
      anon_sym_RBRACE,
    STATE(19022), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745751] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27459), 1,
      anon_sym_RPAREN,
    STATE(19023), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745765] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27459), 1,
      anon_sym_RBRACK,
    STATE(19024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745779] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27459), 1,
      anon_sym_RBRACE,
    STATE(19025), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745793] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27461), 1,
      anon_sym_in,
    STATE(19026), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745807] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27463), 1,
      anon_sym_in,
    STATE(19027), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745821] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27465), 1,
      anon_sym_in,
    STATE(19028), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745835] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8925), 1,
      anon_sym_DASH_GT,
    STATE(19029), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745849] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27467), 1,
      anon_sym_DOT,
    STATE(19030), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745863] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27469), 1,
      anon_sym_RPAREN,
    STATE(19031), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745877] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27471), 1,
      anon_sym_DOT,
    STATE(19032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745891] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27473), 1,
      anon_sym_RPAREN,
    STATE(19033), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745905] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27473), 1,
      anon_sym_RBRACK,
    STATE(19034), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745919] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27473), 1,
      anon_sym_RBRACE,
    STATE(19035), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745933] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27475), 1,
      aux_sym_number_token1,
    STATE(19036), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745947] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6855), 1,
      anon_sym_end,
    STATE(19037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745961] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27477), 1,
      anon_sym_RPAREN,
    STATE(19038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745975] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27479), 1,
      anon_sym_end,
    STATE(19039), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745989] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27481), 1,
      anon_sym_RBRACE,
    STATE(19040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746003] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16723), 1,
      anon_sym_RPAREN,
    STATE(19041), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746017] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27483), 1,
      anon_sym_DOT,
    STATE(19042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746031] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27485), 1,
      anon_sym_RPAREN,
    STATE(19043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746045] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27485), 1,
      anon_sym_RBRACK,
    STATE(19044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746059] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27485), 1,
      anon_sym_RBRACE,
    STATE(19045), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746073] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27487), 1,
      anon_sym_DASH_GT,
    STATE(19046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746087] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3179), 1,
      anon_sym_RPAREN,
    STATE(19047), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746101] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27489), 1,
      anon_sym_with,
    STATE(19048), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746115] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27491), 1,
      anon_sym_RPAREN,
    STATE(19049), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746129] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27493), 1,
      anon_sym_RBRACK,
    STATE(19050), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746143] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27495), 1,
      anon_sym_RBRACE,
    STATE(19051), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746157] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27497), 1,
      anon_sym_RPAREN,
    STATE(19052), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746171] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27499), 1,
      anon_sym_RPAREN,
    STATE(19053), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746185] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27499), 1,
      anon_sym_RBRACK,
    STATE(19054), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746199] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27499), 1,
      anon_sym_RBRACE,
    STATE(19055), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746213] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27501), 1,
      anon_sym_RPAREN,
    STATE(19056), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746227] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27503), 1,
      anon_sym_RPAREN,
    STATE(19057), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746241] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27505), 1,
      anon_sym_RPAREN,
    STATE(19058), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746255] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27507), 1,
      anon_sym_RBRACK,
    STATE(19059), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746269] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27509), 1,
      anon_sym_RBRACE,
    STATE(19060), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746283] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27511), 1,
      anon_sym_RPAREN,
    STATE(19061), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746297] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27513), 1,
      anon_sym_RPAREN,
    STATE(19062), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746311] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27515), 1,
      anon_sym_RPAREN,
    STATE(19063), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746325] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27515), 1,
      anon_sym_RBRACK,
    STATE(19064), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746339] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27515), 1,
      anon_sym_RBRACE,
    STATE(19065), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746353] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27517), 1,
      anon_sym_RPAREN,
    STATE(19066), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746367] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27519), 1,
      anon_sym_LT_DASH,
    STATE(19067), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746381] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27521), 1,
      anon_sym_GT,
    STATE(19068), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746395] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3221), 1,
      anon_sym_RPAREN,
    STATE(19069), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746409] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27523), 1,
      anon_sym_RPAREN,
    STATE(19070), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746423] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27525), 1,
      anon_sym_in,
    STATE(19071), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746437] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27527), 1,
      anon_sym_in,
    STATE(19072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746451] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27529), 1,
      anon_sym_RPAREN,
    STATE(19073), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746465] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27529), 1,
      anon_sym_RBRACK,
    STATE(19074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746479] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27529), 1,
      anon_sym_RBRACE,
    STATE(19075), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746493] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27531), 1,
      anon_sym_RPAREN,
    STATE(19076), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746507] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27533), 1,
      anon_sym_DASH_GT,
    STATE(19077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746521] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27535), 1,
      anon_sym_RPAREN,
    STATE(19078), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746535] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27537), 1,
      anon_sym_in,
    STATE(19079), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746549] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27539), 1,
      anon_sym_in,
    STATE(19080), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746563] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21260), 1,
      anon_sym_GT_RBRACE,
    STATE(19081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746577] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20082), 1,
      anon_sym_end,
    STATE(19082), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746591] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27541), 1,
      anon_sym_RPAREN,
    STATE(19083), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746605] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27541), 1,
      anon_sym_RBRACK,
    STATE(19084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746619] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27541), 1,
      anon_sym_RBRACE,
    STATE(19085), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746633] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27543), 1,
      anon_sym_RBRACE,
    STATE(19086), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746647] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27545), 1,
      anon_sym_RBRACK,
    STATE(19087), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746661] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27547), 1,
      anon_sym_RPAREN,
    STATE(19088), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746675] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27549), 1,
      anon_sym_RBRACE,
    STATE(19089), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746689] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27551), 1,
      anon_sym_DQUOTE,
    STATE(19090), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746703] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27553), 1,
      sym__lowercase_identifier,
    STATE(19091), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746717] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27555), 1,
      anon_sym_RBRACK,
    STATE(19092), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746731] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27557), 1,
      anon_sym_RPAREN,
    STATE(19093), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746745] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27557), 1,
      anon_sym_RBRACK,
    STATE(19094), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746759] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27557), 1,
      anon_sym_RBRACE,
    STATE(19095), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746773] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27559), 1,
      anon_sym_RPAREN,
    STATE(19096), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746787] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11662), 1,
      anon_sym_GT,
    STATE(19097), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746801] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8990), 1,
      anon_sym_DASH_GT,
    STATE(19098), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746815] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27561), 1,
      anon_sym_in,
    STATE(19099), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746829] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8943), 1,
      anon_sym_DASH_GT,
    STATE(19100), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746843] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27563), 1,
      anon_sym_end,
    STATE(19101), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746857] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27565), 1,
      anon_sym_RBRACE,
    STATE(19102), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746871] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27567), 1,
      anon_sym_RPAREN,
    STATE(19103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746885] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27567), 1,
      anon_sym_RBRACK,
    STATE(19104), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746899] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27567), 1,
      anon_sym_RBRACE,
    STATE(19105), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746913] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27569), 1,
      anon_sym_RPAREN,
    STATE(19106), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746927] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27571), 1,
      anon_sym_DASH_GT,
    STATE(19107), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746941] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27573), 1,
      anon_sym_DASH_GT,
    STATE(19108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746955] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16587), 1,
      anon_sym_RPAREN,
    STATE(19109), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746969] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27575), 1,
      anon_sym_DASH_GT,
    STATE(19110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746983] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27577), 1,
      anon_sym_RPAREN,
    STATE(19111), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746997] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27579), 1,
      anon_sym_RBRACK,
    STATE(19112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747011] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27581), 1,
      anon_sym_RPAREN,
    STATE(19113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747025] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27581), 1,
      anon_sym_RBRACK,
    STATE(19114), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747039] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27581), 1,
      anon_sym_RBRACE,
    STATE(19115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747053] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27583), 1,
      anon_sym_RBRACE,
    STATE(19116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747067] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27585), 1,
      anon_sym_RPAREN,
    STATE(19117), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747081] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27587), 1,
      anon_sym_RBRACE,
    STATE(19118), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747095] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27589), 1,
      anon_sym_RPAREN,
    STATE(19119), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747109] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27591), 1,
      anon_sym_RPAREN,
    STATE(19120), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747123] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27593), 1,
      anon_sym_RPAREN,
    STATE(19121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747137] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27595), 1,
      anon_sym_RBRACK,
    STATE(19122), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747151] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27597), 1,
      anon_sym_RPAREN,
    STATE(19123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747165] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27597), 1,
      anon_sym_RBRACK,
    STATE(19124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747179] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27597), 1,
      anon_sym_RBRACE,
    STATE(19125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747193] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27599), 1,
      anon_sym_RBRACK,
    STATE(19126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747207] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27601), 1,
      anon_sym_RPAREN,
    STATE(19127), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747221] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27603), 1,
      anon_sym_DASH_GT,
    STATE(19128), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747235] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27605), 1,
      anon_sym_RBRACE,
    STATE(19129), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747249] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27607), 1,
      anon_sym_RPAREN,
    STATE(19130), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747263] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27609), 1,
      anon_sym_RPAREN,
    STATE(19131), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747277] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27611), 1,
      anon_sym_LT_DASH,
    STATE(19132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747291] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27613), 1,
      anon_sym_RPAREN,
    STATE(19133), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747305] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27613), 1,
      anon_sym_RBRACK,
    STATE(19134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747319] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27613), 1,
      anon_sym_RBRACE,
    STATE(19135), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747333] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3217), 1,
      anon_sym_RPAREN,
    STATE(19136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747347] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16774), 1,
      anon_sym_RPAREN,
    STATE(19137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747361] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27615), 1,
      anon_sym_RPAREN,
    STATE(19138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747375] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27617), 1,
      anon_sym_RBRACE,
    STATE(19139), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747389] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27619), 1,
      anon_sym_DASH_GT,
    STATE(19140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747403] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27621), 1,
      anon_sym_in,
    STATE(19141), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747417] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27623), 1,
      anon_sym_end,
    STATE(19142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747431] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27625), 1,
      anon_sym_in,
    STATE(19143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747445] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27627), 1,
      anon_sym_in,
    STATE(19144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747459] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27629), 1,
      anon_sym_DASH_GT,
    STATE(19145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747473] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27631), 1,
      anon_sym_RBRACE,
    STATE(19146), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747487] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27631), 1,
      anon_sym_RBRACK,
    STATE(19147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747501] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27631), 1,
      anon_sym_RPAREN,
    STATE(19148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747515] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17569), 1,
      anon_sym_GT,
    STATE(19149), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747529] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27633), 1,
      anon_sym_RPAREN,
    STATE(19150), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747543] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27635), 1,
      anon_sym_in,
    STATE(19151), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747557] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27637), 1,
      anon_sym_RBRACE,
    STATE(19152), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747571] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21409), 1,
      anon_sym_GT_RBRACE,
    STATE(19153), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747585] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27639), 1,
      anon_sym_RBRACE,
    STATE(19154), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747599] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27641), 1,
      anon_sym_RBRACK,
    STATE(19155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747613] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20030), 1,
      anon_sym_end,
    STATE(19156), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747627] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27643), 1,
      anon_sym_DASH_GT,
    STATE(19157), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747641] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27645), 1,
      anon_sym_DASH_GT,
    STATE(19158), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747655] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27647), 1,
      anon_sym_SQUOTE2,
    STATE(19159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747669] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27649), 1,
      sym__lowercase_identifier,
    STATE(19160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747683] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27651), 1,
      anon_sym_DQUOTE,
    STATE(19161), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747697] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27653), 1,
      sym__lowercase_identifier,
    STATE(19162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747711] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27655), 1,
      anon_sym_DQUOTE,
    STATE(19163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747725] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27657), 1,
      anon_sym_SQUOTE2,
    STATE(19164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747739] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27659), 1,
      anon_sym_RBRACK,
    STATE(19165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747753] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20034), 1,
      anon_sym_end,
    STATE(19166), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747767] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21328), 1,
      anon_sym_GT_RBRACE,
    STATE(19167), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747781] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27661), 1,
      anon_sym_RBRACE,
    STATE(19168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747795] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17773), 1,
      anon_sym_RPAREN,
    STATE(19169), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747809] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27663), 1,
      anon_sym_RBRACE,
    STATE(19170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747823] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8863), 1,
      anon_sym_DASH_GT,
    STATE(19171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747837] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27665), 1,
      anon_sym_RBRACE,
    STATE(19172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747851] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16533), 1,
      anon_sym_DASH_GT,
    STATE(19173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747865] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27667), 1,
      anon_sym_RBRACE,
    STATE(19174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747879] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27669), 1,
      anon_sym_in,
    STATE(19175), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747893] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27671), 1,
      anon_sym_in,
    STATE(19176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747907] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16551), 1,
      anon_sym_RPAREN,
    STATE(19177), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747921] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27673), 1,
      anon_sym_in,
    STATE(19178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747935] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27675), 1,
      anon_sym_in,
    STATE(19179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747949] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27677), 1,
      anon_sym_DASH_GT,
    STATE(19180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747963] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27679), 1,
      aux_sym_number_token1,
    STATE(19181), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747977] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5065), 1,
      anon_sym_end,
    STATE(19182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747991] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27681), 1,
      anon_sym_RPAREN,
    STATE(19183), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748005] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27683), 1,
      anon_sym_RPAREN,
    STATE(19184), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748019] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27685), 1,
      anon_sym_RBRACK,
    STATE(19185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748033] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27687), 1,
      anon_sym_RBRACE,
    STATE(19186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748047] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3195), 1,
      anon_sym_RPAREN,
    STATE(19187), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748061] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27689), 1,
      anon_sym_LT_DASH,
    STATE(19188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748075] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27691), 1,
      anon_sym_in,
    STATE(19189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748089] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27693), 1,
      anon_sym_RPAREN,
    STATE(19190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748103] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27695), 1,
      anon_sym_DOT,
    STATE(19191), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748117] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27697), 1,
      anon_sym_RPAREN,
    STATE(19192), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748131] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27699), 1,
      anon_sym_RPAREN,
    STATE(19193), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748145] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27701), 1,
      anon_sym_RPAREN,
    STATE(19194), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748159] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27703), 1,
      anon_sym_RBRACK,
    STATE(19195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748173] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27705), 1,
      anon_sym_with,
    STATE(19196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748187] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27707), 1,
      anon_sym_GT,
    STATE(19197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748201] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27709), 1,
      anon_sym_RBRACE,
    STATE(19198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748215] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27711), 1,
      anon_sym_RPAREN,
    STATE(19199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748229] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27713), 1,
      anon_sym_DASH_GT,
    STATE(19200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748243] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27715), 1,
      anon_sym_with,
    STATE(19201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748257] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27717), 1,
      anon_sym_RPAREN,
    STATE(19202), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748271] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27719), 1,
      anon_sym_RBRACE,
    STATE(19203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748285] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27721), 1,
      anon_sym_RPAREN,
    STATE(19204), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748299] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27723), 1,
      anon_sym_RBRACK,
    STATE(19205), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748313] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27725), 1,
      anon_sym_RPAREN,
    STATE(19206), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748327] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27727), 1,
      anon_sym_RPAREN,
    STATE(19207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748341] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11805), 1,
      anon_sym_GT,
    STATE(19208), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748355] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27729), 1,
      anon_sym_RPAREN,
    STATE(19209), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748369] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27731), 1,
      anon_sym_RPAREN,
    STATE(19210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748383] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27733), 1,
      anon_sym_DASH_GT,
    STATE(19211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748397] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27735), 1,
      anon_sym_RPAREN,
    STATE(19212), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748411] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23881), 1,
      anon_sym_RBRACK,
    STATE(19213), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748425] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27737), 1,
      anon_sym_DASH_GT,
    STATE(19214), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748439] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3203), 1,
      anon_sym_RPAREN,
    STATE(19215), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748453] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27739), 1,
      anon_sym_RPAREN,
    STATE(19216), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748467] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27741), 1,
      anon_sym_RBRACE,
    STATE(19217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748481] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27743), 1,
      anon_sym_RBRACK,
    STATE(19218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748495] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27745), 1,
      anon_sym_RPAREN,
    STATE(19219), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748509] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27747), 1,
      anon_sym_DASH_GT,
    STATE(19220), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748523] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27749), 1,
      anon_sym_RPAREN,
    STATE(19221), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748537] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16820), 1,
      anon_sym_RPAREN,
    STATE(19222), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748551] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27751), 1,
      anon_sym_RBRACE,
    STATE(19223), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748565] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27753), 1,
      anon_sym_DASH_GT,
    STATE(19224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748579] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27755), 1,
      anon_sym_end,
    STATE(19225), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748593] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27757), 1,
      anon_sym_RBRACE,
    STATE(19226), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748607] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27759), 1,
      anon_sym_DASH_GT,
    STATE(19227), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748621] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27761), 1,
      anon_sym_in,
    STATE(19228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748635] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8899), 1,
      anon_sym_DASH_GT,
    STATE(19229), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748649] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17679), 1,
      anon_sym_GT,
    STATE(19230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748663] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27763), 1,
      anon_sym_in,
    STATE(19231), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748677] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27765), 1,
      anon_sym_in,
    STATE(19232), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748691] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27767), 1,
      anon_sym_RBRACE,
    STATE(19233), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748705] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27769), 1,
      anon_sym_RBRACK,
    STATE(19234), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748719] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27771), 1,
      anon_sym_DASH_GT,
    STATE(19235), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748733] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27773), 1,
      anon_sym_DASH_GT,
    STATE(19236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748747] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27775), 1,
      anon_sym_in,
    STATE(19237), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748761] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27777), 1,
      sym__lowercase_identifier,
    STATE(19238), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748775] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27779), 1,
      anon_sym_in,
    STATE(19239), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748789] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27781), 1,
      anon_sym_DQUOTE,
    STATE(19240), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748803] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27783), 1,
      anon_sym_SQUOTE2,
    STATE(19241), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748817] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19734), 1,
      anon_sym_end,
    STATE(19242), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748831] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21979), 1,
      anon_sym_GT_RBRACE,
    STATE(19243), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748845] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27785), 1,
      anon_sym_DASH_GT,
    STATE(19244), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748859] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27787), 1,
      anon_sym_RBRACE,
    STATE(19245), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748873] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27789), 1,
      anon_sym_RBRACE,
    STATE(19246), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748887] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17751), 1,
      anon_sym_DASH_GT,
    STATE(19247), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748901] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27791), 1,
      anon_sym_in,
    STATE(19248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748915] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27793), 1,
      anon_sym_in,
    STATE(19249), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748929] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27795), 1,
      anon_sym_in,
    STATE(19250), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748943] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27797), 1,
      anon_sym_in,
    STATE(19251), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748957] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27799), 1,
      aux_sym_number_token1,
    STATE(19252), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748971] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6875), 1,
      anon_sym_end,
    STATE(19253), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748985] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27801), 1,
      sym__lowercase_identifier,
    STATE(19254), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748999] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27803), 1,
      anon_sym_RPAREN,
    STATE(19255), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749013] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21557), 1,
      anon_sym_GT_RBRACE,
    STATE(19256), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749027] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3213), 1,
      anon_sym_RPAREN,
    STATE(19257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749041] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27805), 1,
      anon_sym_LT_DASH,
    STATE(19258), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749055] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19970), 1,
      anon_sym_end,
    STATE(19259), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749069] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27807), 1,
      anon_sym_DOT,
    STATE(19260), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749083] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27809), 1,
      anon_sym_with,
    STATE(19261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749097] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27811), 1,
      anon_sym_PIPE,
    STATE(19262), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749111] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27813), 1,
      anon_sym_RPAREN,
    STATE(19263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749125] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27815), 1,
      sym__lowercase_identifier,
    STATE(19264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749139] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27817), 1,
      anon_sym_SQUOTE2,
    STATE(19265), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749153] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27819), 1,
      anon_sym_GT,
    STATE(19266), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749167] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27821), 1,
      anon_sym_RPAREN,
    STATE(19267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749181] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27823), 1,
      anon_sym_DASH_GT,
    STATE(19268), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749195] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27825), 1,
      anon_sym_RPAREN,
    STATE(19269), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749209] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27827), 1,
      anon_sym_RBRACE,
    STATE(19270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749223] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27829), 1,
      anon_sym_RBRACK,
    STATE(19271), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749237] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27831), 1,
      anon_sym_RPAREN,
    STATE(19272), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749251] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27833), 1,
      anon_sym_RPAREN,
    STATE(19273), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749265] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11614), 1,
      anon_sym_GT,
    STATE(19274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749279] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27835), 1,
      anon_sym_RPAREN,
    STATE(19275), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749293] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27837), 1,
      anon_sym_RPAREN,
    STATE(19276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749307] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27839), 1,
      anon_sym_DASH_GT,
    STATE(19277), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749321] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27841), 1,
      sym__lowercase_identifier,
    STATE(19278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749335] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27843), 1,
      anon_sym_COLON2,
    STATE(19279), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749349] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27845), 1,
      anon_sym_DQUOTE,
    STATE(19280), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749363] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27847), 1,
      anon_sym_with,
    STATE(19281), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749377] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27849), 1,
      anon_sym_RPAREN,
    STATE(19282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749391] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27851), 1,
      sym__lowercase_identifier,
    STATE(19283), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749405] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27853), 1,
      anon_sym_DOT_DOT,
    STATE(19284), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749419] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27855), 1,
      anon_sym_DOT_DOT,
    STATE(19285), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749433] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27857), 1,
      anon_sym_DOT_DOT,
    STATE(19286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749447] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27859), 1,
      anon_sym_RBRACE,
    STATE(19287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749461] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27861), 1,
      anon_sym_RBRACK,
    STATE(19288), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749475] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27863), 1,
      anon_sym_RPAREN,
    STATE(19289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749489] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27865), 1,
      anon_sym_DASH_GT,
    STATE(19290), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749503] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27867), 1,
      anon_sym_RBRACK,
    STATE(19291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749517] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16579), 1,
      anon_sym_RPAREN,
    STATE(19292), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749531] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27869), 1,
      anon_sym_RBRACE,
    STATE(19293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749545] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27871), 1,
      anon_sym_DASH_GT,
    STATE(19294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749559] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27873), 1,
      sym__lowercase_identifier,
    STATE(19295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749573] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27875), 1,
      anon_sym_end,
    STATE(19296), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749587] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27877), 1,
      anon_sym_RBRACE,
    STATE(19297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749601] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27879), 1,
      anon_sym_end,
    STATE(19298), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749615] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27881), 1,
      anon_sym_DASH_GT,
    STATE(19299), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749629] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8877), 1,
      anon_sym_DASH_GT,
    STATE(19300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749643] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8883), 1,
      anon_sym_DASH_GT,
    STATE(19301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749657] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17501), 1,
      anon_sym_GT,
    STATE(19302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749671] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27883), 1,
      anon_sym_end,
    STATE(19303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749685] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27885), 1,
      anon_sym_DOT,
    STATE(19304), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749699] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27887), 1,
      anon_sym_RBRACE,
    STATE(19305), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749713] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27889), 1,
      anon_sym_RBRACK,
    STATE(19306), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749727] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27891), 1,
      anon_sym_DASH_GT,
    STATE(19307), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749741] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27893), 1,
      anon_sym_DASH_GT,
    STATE(19308), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749755] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27895), 1,
      sym__lowercase_identifier,
    STATE(19309), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749769] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27897), 1,
      anon_sym_RBRACE,
    STATE(19310), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749783] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27899), 1,
      anon_sym_DQUOTE,
    STATE(19311), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749797] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27901), 1,
      anon_sym_SQUOTE2,
    STATE(19312), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749811] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19410), 1,
      anon_sym_end,
    STATE(19313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749825] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22691), 1,
      anon_sym_GT_RBRACE,
    STATE(19314), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749839] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27903), 1,
      anon_sym_DOT,
    STATE(19315), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749853] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27905), 1,
      anon_sym_RBRACE,
    STATE(19316), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749867] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16657), 1,
      anon_sym_RPAREN,
    STATE(19317), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749881] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(12601), 1,
      anon_sym_DASH_GT,
    STATE(19318), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749895] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27907), 1,
      anon_sym_in,
    STATE(19319), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749909] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27909), 1,
      anon_sym_in,
    STATE(19320), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749923] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27911), 1,
      anon_sym_in,
    STATE(19321), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749937] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27913), 1,
      anon_sym_in,
    STATE(19322), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749951] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27915), 1,
      aux_sym_number_token1,
    STATE(19323), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749965] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5113), 1,
      anon_sym_end,
    STATE(19324), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749979] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27917), 1,
      anon_sym_DASH_GT,
    STATE(19325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749993] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23823), 1,
      anon_sym_RBRACK,
    STATE(19326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750007] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27919), 1,
      anon_sym_RPAREN,
    STATE(19327), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750021] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27921), 1,
      anon_sym_RPAREN,
    STATE(19328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750035] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3251), 1,
      anon_sym_RPAREN,
    STATE(19329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750049] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27923), 1,
      anon_sym_LT_DASH,
    STATE(19330), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750063] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27925), 1,
      anon_sym_RBRACK,
    STATE(19331), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750077] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27927), 1,
      anon_sym_DOT,
    STATE(19332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750091] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27929), 1,
      anon_sym_RBRACE,
    STATE(19333), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750105] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27931), 1,
      anon_sym_RPAREN,
    STATE(19334), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750119] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27933), 1,
      anon_sym_RPAREN,
    STATE(19335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750133] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27935), 1,
      anon_sym_RBRACE,
    STATE(19336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750147] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27937), 1,
      anon_sym_RPAREN,
    STATE(19337), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750161] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27939), 1,
      anon_sym_GT,
    STATE(19338), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750175] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27941), 1,
      anon_sym_RPAREN,
    STATE(19339), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750189] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23801), 1,
      anon_sym_RBRACE,
    STATE(19340), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750203] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27943), 1,
      anon_sym_RPAREN,
    STATE(19341), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750217] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27945), 1,
      anon_sym_DASH_GT,
    STATE(19342), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750231] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27947), 1,
      anon_sym_RPAREN,
    STATE(19343), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750245] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27949), 1,
      anon_sym_RBRACE,
    STATE(19344), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750259] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27951), 1,
      anon_sym_RBRACK,
    STATE(19345), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750273] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27953), 1,
      anon_sym_RPAREN,
    STATE(19346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750287] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27955), 1,
      anon_sym_RPAREN,
    STATE(19347), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750301] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11492), 1,
      anon_sym_GT,
    STATE(19348), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750315] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27957), 1,
      anon_sym_RPAREN,
    STATE(19349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750329] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27959), 1,
      anon_sym_RBRACK,
    STATE(19350), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750343] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27961), 1,
      anon_sym_RPAREN,
    STATE(19351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750357] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27963), 1,
      anon_sym_DASH_GT,
    STATE(19352), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750371] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27965), 1,
      anon_sym_DASH_GT,
    STATE(19353), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750385] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27967), 1,
      anon_sym_RBRACE,
    STATE(19354), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750399] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27969), 1,
      anon_sym_RPAREN,
    STATE(19355), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750413] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27971), 1,
      anon_sym_RBRACE,
    STATE(19356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750427] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27973), 1,
      anon_sym_RBRACK,
    STATE(19357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750441] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27975), 1,
      anon_sym_RPAREN,
    STATE(19358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750455] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27977), 1,
      anon_sym_PIPE,
    STATE(19359), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750469] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27979), 1,
      anon_sym_DASH_GT,
    STATE(19360), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750483] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27981), 1,
      sym__lowercase_identifier,
    STATE(19361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750497] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27983), 1,
      anon_sym_RPAREN,
    STATE(19362), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750511] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16870), 1,
      anon_sym_RPAREN,
    STATE(19363), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750525] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23597), 1,
      anon_sym_RPAREN,
    STATE(19364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750539] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27985), 1,
      anon_sym_RBRACE,
    STATE(19365), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750553] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27987), 1,
      anon_sym_DASH_GT,
    STATE(19366), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750567] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27989), 1,
      anon_sym_end,
    STATE(19367), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750581] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3197), 1,
      anon_sym_RPAREN,
    STATE(19368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750595] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27991), 1,
      anon_sym_DASH_GT,
    STATE(19369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750609] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27993), 1,
      anon_sym_RPAREN,
    STATE(19370), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750623] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8895), 1,
      anon_sym_DASH_GT,
    STATE(19371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750637] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17725), 1,
      anon_sym_GT,
    STATE(19372), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750651] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27995), 1,
      anon_sym_in,
    STATE(19373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750665] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27997), 1,
      anon_sym_in,
    STATE(19374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750679] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(27999), 1,
      anon_sym_COLON2,
    STATE(19375), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750693] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28001), 1,
      anon_sym_RBRACE,
    STATE(19376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750707] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28003), 1,
      anon_sym_in,
    STATE(19377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750721] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28005), 1,
      anon_sym_DOT_DOT,
    STATE(19378), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750735] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28007), 1,
      anon_sym_DOT_DOT,
    STATE(19379), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750749] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28009), 1,
      anon_sym_DOT_DOT,
    STATE(19380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750763] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28011), 1,
      anon_sym_RBRACK,
    STATE(19381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750777] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28013), 1,
      anon_sym_DASH_GT,
    STATE(19382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750791] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28015), 1,
      anon_sym_DASH_GT,
    STATE(19383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750805] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28017), 1,
      sym__lowercase_identifier,
    STATE(19384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750819] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28019), 1,
      anon_sym_in,
    STATE(19385), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750833] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28021), 1,
      anon_sym_DQUOTE,
    STATE(19386), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750847] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28023), 1,
      anon_sym_SQUOTE2,
    STATE(19387), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750861] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19569), 1,
      anon_sym_end,
    STATE(19388), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750875] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22522), 1,
      anon_sym_GT_RBRACE,
    STATE(19389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750889] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28025), 1,
      anon_sym_RBRACK,
    STATE(19390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750903] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28027), 1,
      anon_sym_SQUOTE2,
    STATE(19391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750917] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28029), 1,
      anon_sym_RBRACE,
    STATE(19392), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750931] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28031), 1,
      anon_sym_DQUOTE,
    STATE(19393), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750945] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16053), 1,
      anon_sym_DASH_GT,
    STATE(19394), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750959] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28033), 1,
      anon_sym_in,
    STATE(19395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750973] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28035), 1,
      anon_sym_in,
    STATE(19396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750987] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28037), 1,
      anon_sym_in,
    STATE(19397), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751001] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28039), 1,
      anon_sym_in,
    STATE(19398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751015] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28041), 1,
      aux_sym_number_token1,
    STATE(19399), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751029] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28043), 1,
      anon_sym_RBRACK,
    STATE(19400), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751043] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23761), 1,
      anon_sym_RBRACK,
    STATE(19401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751057] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6885), 1,
      anon_sym_end,
    STATE(19402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751071] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28045), 1,
      anon_sym_RPAREN,
    STATE(19403), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751085] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28047), 1,
      anon_sym_RBRACE,
    STATE(19404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751099] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3207), 1,
      anon_sym_RPAREN,
    STATE(19405), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751113] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28049), 1,
      anon_sym_LT_DASH,
    STATE(19406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751127] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8889), 1,
      anon_sym_DASH_GT,
    STATE(19407), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751141] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28051), 1,
      anon_sym_RBRACE,
    STATE(19408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751155] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28053), 1,
      anon_sym_DASH_GT,
    STATE(19409), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751169] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28055), 1,
      anon_sym_RPAREN,
    STATE(19410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751183] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28057), 1,
      anon_sym_RPAREN,
    STATE(19411), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751197] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28059), 1,
      anon_sym_RBRACE,
    STATE(19412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751211] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28061), 1,
      anon_sym_RBRACE,
    STATE(19413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751225] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28063), 1,
      anon_sym_RPAREN,
    STATE(19414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751239] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28065), 1,
      anon_sym_GT,
    STATE(19415), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751253] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3193), 1,
      anon_sym_RPAREN,
    STATE(19416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751267] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23735), 1,
      anon_sym_RBRACE,
    STATE(19417), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751281] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28067), 1,
      anon_sym_RPAREN,
    STATE(19418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751295] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23731), 1,
      anon_sym_RBRACE,
    STATE(19419), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751309] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28069), 1,
      anon_sym_RPAREN,
    STATE(19420), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751323] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28071), 1,
      anon_sym_DASH_GT,
    STATE(19421), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751337] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28073), 1,
      anon_sym_RPAREN,
    STATE(19422), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751351] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28075), 1,
      anon_sym_RBRACE,
    STATE(19423), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751365] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28077), 1,
      anon_sym_RBRACK,
    STATE(19424), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751379] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28079), 1,
      anon_sym_RPAREN,
    STATE(19425), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751393] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28081), 1,
      anon_sym_RPAREN,
    STATE(19426), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751407] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11690), 1,
      anon_sym_GT,
    STATE(19427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751421] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28083), 1,
      anon_sym_RPAREN,
    STATE(19428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751435] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28085), 1,
      anon_sym_RBRACE,
    STATE(19429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751449] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28087), 1,
      anon_sym_SQUOTE2,
    STATE(19430), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751463] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28089), 1,
      anon_sym_RPAREN,
    STATE(19431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751477] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28091), 1,
      anon_sym_DASH_GT,
    STATE(19432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751491] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28093), 1,
      anon_sym_PIPE,
    STATE(19433), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751505] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28095), 1,
      anon_sym_DASH_GT,
    STATE(19434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751519] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28097), 1,
      sym__lowercase_identifier,
    STATE(19435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751533] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28099), 1,
      anon_sym_DQUOTE,
    STATE(19436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751547] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28101), 1,
      anon_sym_RPAREN,
    STATE(19437), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751561] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28103), 1,
      anon_sym_RBRACE,
    STATE(19438), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751575] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28105), 1,
      anon_sym_RBRACK,
    STATE(19439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751589] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28107), 1,
      anon_sym_RPAREN,
    STATE(19440), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751603] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28109), 1,
      anon_sym_DASH_GT,
    STATE(19441), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751617] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28111), 1,
      anon_sym_in,
    STATE(19442), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751631] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16792), 1,
      anon_sym_RPAREN,
    STATE(19443), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751645] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6855), 1,
      anon_sym_RPAREN,
    STATE(19444), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751659] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28113), 1,
      anon_sym_RPAREN,
    STATE(19445), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751673] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23507), 1,
      anon_sym_RPAREN,
    STATE(19446), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751687] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28115), 1,
      anon_sym_RBRACE,
    STATE(19447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751701] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28117), 1,
      anon_sym_DASH_GT,
    STATE(19448), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751715] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28119), 1,
      anon_sym_COLON2,
    STATE(19449), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751729] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28121), 1,
      anon_sym_end,
    STATE(19450), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751743] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28123), 1,
      anon_sym_RBRACK,
    STATE(19451), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751757] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28125), 1,
      anon_sym_DOT_DOT,
    STATE(19452), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751771] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28127), 1,
      anon_sym_DOT_DOT,
    STATE(19453), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751785] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28129), 1,
      anon_sym_DOT_DOT,
    STATE(19454), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751799] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28131), 1,
      anon_sym_RBRACE,
    STATE(19455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751813] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28133), 1,
      anon_sym_DASH_GT,
    STATE(19456), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751827] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28135), 1,
      anon_sym_RBRACE,
    STATE(19457), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751841] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8988), 1,
      anon_sym_DASH_GT,
    STATE(19458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751855] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17637), 1,
      anon_sym_GT,
    STATE(19459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751869] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28137), 1,
      anon_sym_RPAREN,
    STATE(19460), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751883] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28139), 1,
      anon_sym_RPAREN,
    STATE(19461), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751897] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28141), 1,
      anon_sym_RPAREN,
    STATE(19462), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751911] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28143), 1,
      anon_sym_RBRACE,
    STATE(19463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751925] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3189), 1,
      anon_sym_RPAREN,
    STATE(19464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751939] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28145), 1,
      anon_sym_RBRACK,
    STATE(19465), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751953] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28147), 1,
      anon_sym_DASH_GT,
    STATE(19466), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751967] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28149), 1,
      anon_sym_DASH_GT,
    STATE(19467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751981] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28151), 1,
      sym__lowercase_identifier,
    STATE(19468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751995] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28153), 1,
      anon_sym_RPAREN,
    STATE(19469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752009] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28155), 1,
      anon_sym_RBRACE,
    STATE(19470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752023] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23691), 1,
      anon_sym_RBRACK,
    STATE(19471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752037] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28157), 1,
      anon_sym_DQUOTE,
    STATE(19472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752051] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28159), 1,
      anon_sym_SQUOTE2,
    STATE(19473), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752065] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20327), 1,
      anon_sym_end,
    STATE(19474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752079] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21066), 1,
      anon_sym_GT_RBRACE,
    STATE(19475), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752093] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28161), 1,
      anon_sym_SQUOTE2,
    STATE(19476), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752107] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28163), 1,
      anon_sym_RBRACE,
    STATE(19477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752121] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28165), 1,
      anon_sym_DQUOTE,
    STATE(19478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752135] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(15266), 1,
      anon_sym_DASH_GT,
    STATE(19479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752149] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28167), 1,
      anon_sym_in,
    STATE(19480), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752163] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28169), 1,
      anon_sym_in,
    STATE(19481), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752177] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28171), 1,
      anon_sym_RPAREN,
    STATE(19482), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752191] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28173), 1,
      anon_sym_in,
    STATE(19483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752205] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28175), 1,
      aux_sym_number_token1,
    STATE(19484), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752219] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5123), 1,
      anon_sym_end,
    STATE(19485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752233] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28177), 1,
      anon_sym_RPAREN,
    STATE(19486), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752247] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28179), 1,
      anon_sym_RBRACE,
    STATE(19487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752261] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28181), 1,
      anon_sym_RPAREN,
    STATE(19488), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752275] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28183), 1,
      anon_sym_PIPE,
    STATE(19489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752289] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28185), 1,
      anon_sym_LT_DASH,
    STATE(19490), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752303] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28187), 1,
      sym__lowercase_identifier,
    STATE(19491), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752317] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28189), 1,
      anon_sym_RBRACE,
    STATE(19492), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752331] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28191), 1,
      anon_sym_RPAREN,
    STATE(19493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752345] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28193), 1,
      anon_sym_DASH_GT,
    STATE(19494), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752359] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28195), 1,
      anon_sym_RPAREN,
    STATE(19495), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752373] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28197), 1,
      anon_sym_RPAREN,
    STATE(19496), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752387] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28199), 1,
      anon_sym_RPAREN,
    STATE(19497), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752401] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28201), 1,
      anon_sym_COLON2,
    STATE(19498), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752415] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28203), 1,
      anon_sym_DOT_DOT,
    STATE(19499), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752429] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28205), 1,
      anon_sym_DOT_DOT,
    STATE(19500), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752443] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28207), 1,
      anon_sym_DOT_DOT,
    STATE(19501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752457] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28209), 1,
      anon_sym_RPAREN,
    STATE(19502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752471] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28211), 1,
      anon_sym_RBRACE,
    STATE(19503), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752485] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28213), 1,
      anon_sym_RBRACE,
    STATE(19504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752499] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3167), 1,
      anon_sym_RPAREN,
    STATE(19505), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752513] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23667), 1,
      anon_sym_RBRACK,
    STATE(19506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752527] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28215), 1,
      anon_sym_RPAREN,
    STATE(19507), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752541] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28217), 1,
      anon_sym_RPAREN,
    STATE(19508), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752555] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28219), 1,
      anon_sym_GT,
    STATE(19509), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752569] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28221), 1,
      anon_sym_RBRACE,
    STATE(19510), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752583] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23661), 1,
      anon_sym_RBRACE,
    STATE(19511), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752597] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28223), 1,
      anon_sym_SQUOTE2,
    STATE(19512), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752611] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23657), 1,
      anon_sym_RBRACE,
    STATE(19513), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752625] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28225), 1,
      anon_sym_RPAREN,
    STATE(19514), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752639] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28227), 1,
      anon_sym_RPAREN,
    STATE(19515), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752653] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28229), 1,
      anon_sym_DASH_GT,
    STATE(19516), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752667] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28231), 1,
      anon_sym_RPAREN,
    STATE(19517), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752681] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28233), 1,
      anon_sym_RBRACE,
    STATE(19518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752695] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28235), 1,
      anon_sym_RBRACK,
    STATE(19519), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752709] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28237), 1,
      anon_sym_RPAREN,
    STATE(19520), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752723] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28239), 1,
      anon_sym_RPAREN,
    STATE(19521), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752737] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11532), 1,
      anon_sym_GT,
    STATE(19522), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752751] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28241), 1,
      anon_sym_PIPE,
    STATE(19523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752765] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28243), 1,
      anon_sym_RPAREN,
    STATE(19524), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752779] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28245), 1,
      sym__lowercase_identifier,
    STATE(19525), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752793] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28247), 1,
      anon_sym_DQUOTE,
    STATE(19526), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752807] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28249), 1,
      anon_sym_RBRACK,
    STATE(19527), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752821] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28251), 1,
      anon_sym_RPAREN,
    STATE(19528), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752835] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28253), 1,
      anon_sym_DOT_DOT,
    STATE(19529), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752849] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28255), 1,
      anon_sym_DOT_DOT,
    STATE(19530), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752863] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28257), 1,
      anon_sym_DOT_DOT,
    STATE(19531), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752877] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28259), 1,
      anon_sym_RBRACE,
    STATE(19532), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752891] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28261), 1,
      anon_sym_RPAREN,
    STATE(19533), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752905] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28263), 1,
      anon_sym_RBRACE,
    STATE(19534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752919] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9786), 1,
      anon_sym_RBRACK,
    STATE(19535), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752933] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28265), 1,
      anon_sym_DASH_GT,
    STATE(19536), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752947] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28267), 1,
      anon_sym_DASH_GT,
    STATE(19537), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752961] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28269), 1,
      anon_sym_RPAREN,
    STATE(19538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752975] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28271), 1,
      anon_sym_RPAREN,
    STATE(19539), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752989] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28273), 1,
      anon_sym_RBRACE,
    STATE(19540), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753003] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28275), 1,
      anon_sym_RBRACK,
    STATE(19541), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753017] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28277), 1,
      anon_sym_RPAREN,
    STATE(19542), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753031] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28279), 1,
      anon_sym_DASH_GT,
    STATE(19543), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753045] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28281), 1,
      anon_sym_RPAREN,
    STATE(19544), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753059] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16725), 1,
      anon_sym_RPAREN,
    STATE(19545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753073] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6875), 1,
      anon_sym_RPAREN,
    STATE(19546), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753087] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28283), 1,
      anon_sym_RPAREN,
    STATE(19547), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753101] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23431), 1,
      anon_sym_RPAREN,
    STATE(19548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753115] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28285), 1,
      anon_sym_RBRACE,
    STATE(19549), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753129] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3141), 1,
      anon_sym_RPAREN,
    STATE(19550), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753143] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28287), 1,
      anon_sym_PIPE,
    STATE(19551), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753157] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28289), 1,
      anon_sym_end,
    STATE(19552), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753171] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28291), 1,
      sym__lowercase_identifier,
    STATE(19553), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753185] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28293), 1,
      anon_sym_RPAREN,
    STATE(19554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753199] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28295), 1,
      anon_sym_DASH_GT,
    STATE(19555), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753213] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28297), 1,
      anon_sym_RBRACE,
    STATE(19556), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753227] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28299), 1,
      anon_sym_DOT_DOT,
    STATE(19557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753241] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28301), 1,
      anon_sym_DOT_DOT,
    STATE(19558), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753255] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28303), 1,
      anon_sym_DOT_DOT,
    STATE(19559), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753269] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8909), 1,
      anon_sym_DASH_GT,
    STATE(19560), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753283] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17601), 1,
      anon_sym_GT,
    STATE(19561), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753297] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28305), 1,
      anon_sym_RBRACE,
    STATE(19562), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753311] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23625), 1,
      anon_sym_RBRACK,
    STATE(19563), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753325] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28305), 1,
      anon_sym_RBRACK,
    STATE(19564), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753339] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28305), 1,
      anon_sym_RPAREN,
    STATE(19565), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753353] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28307), 1,
      anon_sym_RPAREN,
    STATE(19566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753367] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28309), 1,
      anon_sym_RBRACE,
    STATE(19567), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753381] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28311), 1,
      anon_sym_RBRACK,
    STATE(19568), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753395] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28313), 1,
      anon_sym_DASH_GT,
    STATE(19569), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753409] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28315), 1,
      anon_sym_DASH_GT,
    STATE(19570), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753423] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28317), 1,
      sym__lowercase_identifier,
    STATE(19571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753437] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28319), 1,
      anon_sym_SQUOTE2,
    STATE(19572), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753451] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28321), 1,
      anon_sym_DQUOTE,
    STATE(19573), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753465] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28323), 1,
      anon_sym_SQUOTE2,
    STATE(19574), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753479] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20283), 1,
      anon_sym_end,
    STATE(19575), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753493] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20397), 1,
      anon_sym_GT_RBRACE,
    STATE(19576), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753507] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28325), 1,
      anon_sym_PIPE,
    STATE(19577), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753521] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28327), 1,
      anon_sym_RPAREN,
    STATE(19578), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753535] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28329), 1,
      sym__lowercase_identifier,
    STATE(19579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753549] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28331), 1,
      anon_sym_RBRACE,
    STATE(19580), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753563] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28333), 1,
      anon_sym_DQUOTE,
    STATE(19581), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753577] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14092), 1,
      anon_sym_DASH_GT,
    STATE(19582), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753591] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28335), 1,
      anon_sym_DOT_DOT,
    STATE(19583), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753605] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28337), 1,
      anon_sym_DOT_DOT,
    STATE(19584), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753619] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28339), 1,
      anon_sym_DOT_DOT,
    STATE(19585), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753633] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28341), 1,
      anon_sym_in,
    STATE(19586), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753647] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28343), 1,
      anon_sym_in,
    STATE(19587), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753661] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28345), 1,
      anon_sym_RBRACK,
    STATE(19588), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753675] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23613), 1,
      anon_sym_RBRACK,
    STATE(19589), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753689] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28347), 1,
      anon_sym_in,
    STATE(19590), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753703] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28349), 1,
      anon_sym_in,
    STATE(19591), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753717] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28351), 1,
      aux_sym_number_token1,
    STATE(19592), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753731] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6837), 1,
      anon_sym_end,
    STATE(19593), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753745] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28353), 1,
      anon_sym_RPAREN,
    STATE(19594), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753759] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28355), 1,
      anon_sym_RBRACE,
    STATE(19595), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753773] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3225), 1,
      anon_sym_RPAREN,
    STATE(19596), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753787] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28357), 1,
      anon_sym_LT_DASH,
    STATE(19597), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753801] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28359), 1,
      anon_sym_RPAREN,
    STATE(19598), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753815] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28361), 1,
      anon_sym_RBRACE,
    STATE(19599), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753829] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28363), 1,
      anon_sym_RPAREN,
    STATE(19600), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753843] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28365), 1,
      anon_sym_RPAREN,
    STATE(19601), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753857] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28367), 1,
      anon_sym_PIPE,
    STATE(19602), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753871] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3139), 1,
      anon_sym_RPAREN,
    STATE(19603), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753885] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28369), 1,
      sym__lowercase_identifier,
    STATE(19604), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753899] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28371), 1,
      anon_sym_RPAREN,
    STATE(19605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753913] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28373), 1,
      anon_sym_DOT_DOT,
    STATE(19606), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753927] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28375), 1,
      anon_sym_DOT_DOT,
    STATE(19607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753941] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28377), 1,
      anon_sym_DOT_DOT,
    STATE(19608), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753955] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28379), 1,
      anon_sym_SQUOTE2,
    STATE(19609), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753969] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23591), 1,
      anon_sym_RBRACK,
    STATE(19610), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753983] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28381), 1,
      anon_sym_GT,
    STATE(19611), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753997] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28383), 1,
      anon_sym_RPAREN,
    STATE(19612), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754011] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28385), 1,
      anon_sym_RBRACE,
    STATE(19613), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754025] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28387), 1,
      anon_sym_RBRACE,
    STATE(19614), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754039] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28389), 1,
      anon_sym_RPAREN,
    STATE(19615), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754053] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18241), 1,
      anon_sym_RPAREN,
    STATE(19616), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754067] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28391), 1,
      anon_sym_RBRACE,
    STATE(19617), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754081] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23007), 1,
      anon_sym_RBRACE,
    STATE(19618), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754095] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28393), 1,
      anon_sym_SQUOTE2,
    STATE(19619), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754109] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23583), 1,
      anon_sym_RBRACE,
    STATE(19620), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754123] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28395), 1,
      anon_sym_DQUOTE,
    STATE(19621), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754137] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28397), 1,
      anon_sym_PIPE,
    STATE(19622), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754151] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28399), 1,
      anon_sym_RPAREN,
    STATE(19623), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754165] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28401), 1,
      sym__lowercase_identifier,
    STATE(19624), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754179] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28403), 1,
      anon_sym_RPAREN,
    STATE(19625), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754193] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28405), 1,
      anon_sym_DOT_DOT,
    STATE(19626), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754207] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28407), 1,
      anon_sym_DOT_DOT,
    STATE(19627), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754221] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28409), 1,
      anon_sym_DOT_DOT,
    STATE(19628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754235] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28411), 1,
      anon_sym_RBRACK,
    STATE(19629), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754249] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9854), 1,
      anon_sym_RBRACK,
    STATE(19630), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754263] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28413), 1,
      anon_sym_DASH_GT,
    STATE(19631), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754277] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28415), 1,
      anon_sym_RPAREN,
    STATE(19632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754291] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28417), 1,
      anon_sym_RBRACE,
    STATE(19633), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754305] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28419), 1,
      anon_sym_RBRACK,
    STATE(19634), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754319] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28421), 1,
      anon_sym_RPAREN,
    STATE(19635), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754333] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28423), 1,
      anon_sym_RPAREN,
    STATE(19636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754347] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11488), 1,
      anon_sym_GT,
    STATE(19637), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754361] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28425), 1,
      anon_sym_RPAREN,
    STATE(19638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754375] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28427), 1,
      anon_sym_RPAREN,
    STATE(19639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754389] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28429), 1,
      anon_sym_RBRACE,
    STATE(19640), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754403] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28431), 1,
      anon_sym_PIPE,
    STATE(19641), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754417] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28433), 1,
      anon_sym_RPAREN,
    STATE(19642), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754431] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28435), 1,
      sym__lowercase_identifier,
    STATE(19643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754445] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28437), 1,
      anon_sym_RPAREN,
    STATE(19644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754459] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28439), 1,
      anon_sym_DOT_DOT,
    STATE(19645), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754473] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28441), 1,
      anon_sym_DOT_DOT,
    STATE(19646), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754487] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28443), 1,
      anon_sym_DOT_DOT,
    STATE(19647), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754501] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28445), 1,
      anon_sym_RPAREN,
    STATE(19648), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754515] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9814), 1,
      anon_sym_RBRACK,
    STATE(19649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754529] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28447), 1,
      anon_sym_in,
    STATE(19650), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754543] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28449), 1,
      anon_sym_RPAREN,
    STATE(19651), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754557] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28451), 1,
      anon_sym_DASH_GT,
    STATE(19652), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754571] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28453), 1,
      anon_sym_DASH_GT,
    STATE(19653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754585] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3253), 1,
      anon_sym_RPAREN,
    STATE(19654), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754599] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28455), 1,
      anon_sym_RPAREN,
    STATE(19655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754613] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28457), 1,
      anon_sym_RBRACE,
    STATE(19656), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754627] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28459), 1,
      anon_sym_RBRACK,
    STATE(19657), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754641] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28461), 1,
      anon_sym_RPAREN,
    STATE(19658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754655] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28463), 1,
      anon_sym_DASH_GT,
    STATE(19659), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754669] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28465), 1,
      anon_sym_PIPE,
    STATE(19660), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754683] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28467), 1,
      anon_sym_RPAREN,
    STATE(19661), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754697] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28469), 1,
      sym__lowercase_identifier,
    STATE(19662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754711] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16697), 1,
      anon_sym_RPAREN,
    STATE(19663), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754725] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28471), 1,
      anon_sym_DOT_DOT,
    STATE(19664), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754739] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28473), 1,
      anon_sym_DOT_DOT,
    STATE(19665), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754753] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28475), 1,
      anon_sym_DOT_DOT,
    STATE(19666), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754767] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28477), 1,
      anon_sym_RBRACE,
    STATE(19667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754781] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9838), 1,
      anon_sym_RBRACK,
    STATE(19668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754795] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6885), 1,
      anon_sym_RPAREN,
    STATE(19669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754809] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28479), 1,
      anon_sym_RPAREN,
    STATE(19670), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754823] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23321), 1,
      anon_sym_RPAREN,
    STATE(19671), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754837] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28481), 1,
      anon_sym_RBRACE,
    STATE(19672), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754851] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28483), 1,
      anon_sym_DASH_GT,
    STATE(19673), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754865] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28485), 1,
      anon_sym_end,
    STATE(19674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754879] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28487), 1,
      anon_sym_DOT,
    STATE(19675), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754893] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28489), 1,
      anon_sym_DASH_GT,
    STATE(19676), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754907] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28491), 1,
      anon_sym_SQUOTE2,
    STATE(19677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754921] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28493), 1,
      anon_sym_PIPE,
    STATE(19678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754935] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8980), 1,
      anon_sym_DASH_GT,
    STATE(19679), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754949] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28495), 1,
      sym__lowercase_identifier,
    STATE(19680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754963] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17589), 1,
      anon_sym_GT,
    STATE(19681), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754977] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28497), 1,
      anon_sym_DOT_DOT,
    STATE(19682), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754991] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28499), 1,
      anon_sym_DOT_DOT,
    STATE(19683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755005] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28501), 1,
      anon_sym_DOT_DOT,
    STATE(19684), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755019] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28503), 1,
      anon_sym_DQUOTE,
    STATE(19685), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755033] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28505), 1,
      anon_sym_RBRACE,
    STATE(19686), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755047] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28507), 1,
      anon_sym_with,
    STATE(19687), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755061] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28509), 1,
      anon_sym_RPAREN,
    STATE(19688), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755075] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28511), 1,
      anon_sym_RBRACE,
    STATE(19689), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755089] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28513), 1,
      anon_sym_RBRACK,
    STATE(19690), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755103] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28515), 1,
      anon_sym_DASH_GT,
    STATE(19691), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755117] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28517), 1,
      anon_sym_DASH_GT,
    STATE(19692), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755131] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28519), 1,
      anon_sym_DOT,
    STATE(19693), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755145] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28521), 1,
      anon_sym_PIPE,
    STATE(19694), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755159] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28523), 1,
      sym__lowercase_identifier,
    STATE(19695), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755173] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28525), 1,
      sym__lowercase_identifier,
    STATE(19696), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755187] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28527), 1,
      anon_sym_RBRACE,
    STATE(19697), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755201] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28529), 1,
      anon_sym_DOT_DOT,
    STATE(19698), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755215] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28531), 1,
      anon_sym_DOT_DOT,
    STATE(19699), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755229] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28533), 1,
      anon_sym_DOT_DOT,
    STATE(19700), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755243] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28535), 1,
      anon_sym_DQUOTE,
    STATE(19701), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755257] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28537), 1,
      anon_sym_SQUOTE2,
    STATE(19702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755271] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19712), 1,
      anon_sym_end,
    STATE(19703), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755285] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22114), 1,
      anon_sym_GT_RBRACE,
    STATE(19704), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755299] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28539), 1,
      anon_sym_with,
    STATE(19705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755313] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28541), 1,
      anon_sym_RBRACE,
    STATE(19706), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755327] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28543), 1,
      anon_sym_RBRACE,
    STATE(19707), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755341] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13414), 1,
      anon_sym_DASH_GT,
    STATE(19708), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755355] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28545), 1,
      anon_sym_in,
    STATE(19709), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755369] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28547), 1,
      anon_sym_PIPE,
    STATE(19710), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755383] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28549), 1,
      anon_sym_in,
    STATE(19711), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755397] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28551), 1,
      sym__lowercase_identifier,
    STATE(19712), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755411] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28553), 1,
      anon_sym_in,
    STATE(19713), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755425] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28555), 1,
      anon_sym_DOT_DOT,
    STATE(19714), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755439] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28557), 1,
      anon_sym_DOT_DOT,
    STATE(19715), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755453] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28559), 1,
      anon_sym_DOT_DOT,
    STATE(19716), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755467] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28561), 1,
      anon_sym_in,
    STATE(19717), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755481] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28563), 1,
      aux_sym_number_token1,
    STATE(19718), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755495] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14493), 1,
      anon_sym_end,
    STATE(19719), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755509] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28565), 1,
      anon_sym_RPAREN,
    STATE(19720), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755523] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28567), 1,
      anon_sym_RPAREN,
    STATE(19721), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755537] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28569), 1,
      anon_sym_RPAREN,
    STATE(19722), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755551] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28571), 1,
      anon_sym_LT_DASH,
    STATE(19723), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755565] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28573), 1,
      anon_sym_RPAREN,
    STATE(19724), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755579] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3223), 1,
      anon_sym_RPAREN,
    STATE(19725), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755593] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28575), 1,
      anon_sym_PIPE,
    STATE(19726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755607] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28577), 1,
      anon_sym_RBRACE,
    STATE(19727), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755621] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28579), 1,
      sym__lowercase_identifier,
    STATE(19728), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755635] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28581), 1,
      anon_sym_RPAREN,
    STATE(19729), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755649] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28583), 1,
      anon_sym_DOT_DOT,
    STATE(19730), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755663] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28585), 1,
      anon_sym_DOT_DOT,
    STATE(19731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755677] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28587), 1,
      anon_sym_DOT_DOT,
    STATE(19732), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755691] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28589), 1,
      anon_sym_RBRACE,
    STATE(19733), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755705] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28591), 1,
      anon_sym_RPAREN,
    STATE(19734), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755719] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28593), 1,
      anon_sym_RPAREN,
    STATE(19735), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755733] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28595), 1,
      anon_sym_RPAREN,
    STATE(19736), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755747] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28597), 1,
      anon_sym_RPAREN,
    STATE(19737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755761] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28599), 1,
      anon_sym_RPAREN,
    STATE(19738), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755775] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28601), 1,
      anon_sym_RBRACE,
    STATE(19739), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755789] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28603), 1,
      anon_sym_RBRACK,
    STATE(19740), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755803] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28605), 1,
      anon_sym_DQUOTE,
    STATE(19741), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755817] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28607), 1,
      anon_sym_PIPE,
    STATE(19742), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755831] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28609), 1,
      anon_sym_in,
    STATE(19743), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755845] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28611), 1,
      sym__lowercase_identifier,
    STATE(19744), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755859] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28613), 1,
      anon_sym_GT,
    STATE(19745), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755873] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28615), 1,
      anon_sym_DOT_DOT,
    STATE(19746), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755887] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28617), 1,
      anon_sym_DOT_DOT,
    STATE(19747), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755901] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28619), 1,
      anon_sym_DOT_DOT,
    STATE(19748), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755915] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28621), 1,
      anon_sym_RBRACK,
    STATE(19749), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755929] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23495), 1,
      anon_sym_RBRACE,
    STATE(19750), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755943] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28623), 1,
      anon_sym_RBRACE,
    STATE(19751), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755957] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23491), 1,
      anon_sym_RBRACE,
    STATE(19752), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755971] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28625), 1,
      anon_sym_RBRACE,
    STATE(19753), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755985] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28627), 1,
      anon_sym_RPAREN,
    STATE(19754), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755999] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28629), 1,
      anon_sym_RPAREN,
    STATE(19755), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756013] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28631), 1,
      anon_sym_DASH_GT,
    STATE(19756), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756027] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28633), 1,
      anon_sym_RPAREN,
    STATE(19757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756041] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28635), 1,
      anon_sym_PIPE,
    STATE(19758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756055] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28637), 1,
      anon_sym_RBRACE,
    STATE(19759), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756069] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28639), 1,
      sym__lowercase_identifier,
    STATE(19760), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756083] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28641), 1,
      anon_sym_RBRACK,
    STATE(19761), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756097] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28643), 1,
      anon_sym_DOT_DOT,
    STATE(19762), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756111] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28645), 1,
      anon_sym_DOT_DOT,
    STATE(19763), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756125] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28647), 1,
      anon_sym_DOT_DOT,
    STATE(19764), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756139] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28649), 1,
      anon_sym_RPAREN,
    STATE(19765), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756153] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28651), 1,
      anon_sym_RPAREN,
    STATE(19766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756167] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11829), 1,
      anon_sym_GT,
    STATE(19767), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756181] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28653), 1,
      anon_sym_RPAREN,
    STATE(19768), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756195] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28655), 1,
      anon_sym_RPAREN,
    STATE(19769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756209] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28657), 1,
      anon_sym_RPAREN,
    STATE(19770), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756223] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3183), 1,
      anon_sym_RPAREN,
    STATE(19771), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756237] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28659), 1,
      anon_sym_RPAREN,
    STATE(19772), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756251] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28661), 1,
      anon_sym_RBRACE,
    STATE(19773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756265] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28663), 1,
      anon_sym_PIPE,
    STATE(19774), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756279] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28665), 1,
      anon_sym_RPAREN,
    STATE(19775), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756293] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28667), 1,
      sym__lowercase_identifier,
    STATE(19776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756307] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28669), 1,
      sym__lowercase_identifier,
    STATE(19777), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756321] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28671), 1,
      anon_sym_DOT_DOT,
    STATE(19778), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756335] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28673), 1,
      anon_sym_DOT_DOT,
    STATE(19779), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756349] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28675), 1,
      anon_sym_DOT_DOT,
    STATE(19780), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756363] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28677), 1,
      anon_sym_DASH_GT,
    STATE(19781), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756377] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28679), 1,
      anon_sym_DASH_GT,
    STATE(19782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756391] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28681), 1,
      anon_sym_RBRACE,
    STATE(19783), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756405] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28683), 1,
      anon_sym_RPAREN,
    STATE(19784), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756419] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28685), 1,
      anon_sym_RBRACE,
    STATE(19785), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756433] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28687), 1,
      anon_sym_RBRACK,
    STATE(19786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756447] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28689), 1,
      anon_sym_RPAREN,
    STATE(19787), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756461] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28691), 1,
      anon_sym_done,
    STATE(19788), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756475] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28693), 1,
      anon_sym_DASH_GT,
    STATE(19789), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756489] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28695), 1,
      anon_sym_PIPE,
    STATE(19790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756503] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28697), 1,
      anon_sym_DOT,
    STATE(19791), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756517] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28699), 1,
      sym__lowercase_identifier,
    STATE(19792), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756531] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16651), 1,
      anon_sym_RPAREN,
    STATE(19793), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756545] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28701), 1,
      anon_sym_DOT_DOT,
    STATE(19794), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756559] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28703), 1,
      anon_sym_DOT_DOT,
    STATE(19795), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756573] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28705), 1,
      anon_sym_DOT_DOT,
    STATE(19796), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756587] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5123), 1,
      anon_sym_RPAREN,
    STATE(19797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756601] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28707), 1,
      anon_sym_RPAREN,
    STATE(19798), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756615] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28709), 1,
      anon_sym_RPAREN,
    STATE(19799), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756629] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28711), 1,
      sym__lowercase_identifier,
    STATE(19800), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756643] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28713), 1,
      anon_sym_RBRACE,
    STATE(19801), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756657] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28715), 1,
      anon_sym_DASH_GT,
    STATE(19802), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756671] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5133), 1,
      anon_sym_end,
    STATE(19803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756685] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28717), 1,
      anon_sym_end,
    STATE(19804), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756699] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28719), 1,
      anon_sym_with,
    STATE(19805), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756713] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28721), 1,
      anon_sym_PIPE,
    STATE(19806), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756727] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28723), 1,
      anon_sym_DASH_GT,
    STATE(19807), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756741] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28725), 1,
      sym__lowercase_identifier,
    STATE(19808), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756755] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28727), 1,
      anon_sym_SQUOTE2,
    STATE(19809), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756769] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28729), 1,
      anon_sym_DOT_DOT,
    STATE(19810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756783] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28731), 1,
      anon_sym_DOT_DOT,
    STATE(19811), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756797] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28733), 1,
      anon_sym_DOT_DOT,
    STATE(19812), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756811] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28735), 1,
      anon_sym_DQUOTE,
    STATE(19813), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756825] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9044), 1,
      anon_sym_DASH_GT,
    STATE(19814), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756839] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28737), 1,
      anon_sym_with,
    STATE(19815), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756853] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17691), 1,
      anon_sym_GT,
    STATE(19816), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756867] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28739), 1,
      anon_sym_RBRACK,
    STATE(19817), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756881] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28741), 1,
      anon_sym_RBRACE,
    STATE(19818), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756895] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28743), 1,
      anon_sym_RBRACE,
    STATE(19819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756909] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28745), 1,
      anon_sym_RPAREN,
    STATE(19820), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756923] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28747), 1,
      sym__lowercase_identifier,
    STATE(19821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756937] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28749), 1,
      anon_sym_PIPE,
    STATE(19822), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756951] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28751), 1,
      anon_sym_RBRACE,
    STATE(19823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756965] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28753), 1,
      sym__lowercase_identifier,
    STATE(19824), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756979] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28755), 1,
      anon_sym_RBRACK,
    STATE(19825), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756993] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28757), 1,
      anon_sym_DOT_DOT,
    STATE(19826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757007] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28759), 1,
      anon_sym_DOT_DOT,
    STATE(19827), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757021] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28761), 1,
      anon_sym_DOT_DOT,
    STATE(19828), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757035] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28763), 1,
      anon_sym_DASH_GT,
    STATE(19829), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757049] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28765), 1,
      anon_sym_DASH_GT,
    STATE(19830), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757063] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28767), 1,
      anon_sym_DOT,
    STATE(19831), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757077] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28769), 1,
      sym__lowercase_identifier,
    STATE(19832), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757091] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28771), 1,
      anon_sym_RPAREN,
    STATE(19833), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757105] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28773), 1,
      anon_sym_DQUOTE,
    STATE(19834), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757119] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28775), 1,
      anon_sym_SQUOTE2,
    STATE(19835), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757133] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20237), 1,
      anon_sym_end,
    STATE(19836), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757147] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20645), 1,
      anon_sym_GT_RBRACE,
    STATE(19837), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757161] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28777), 1,
      anon_sym_RPAREN,
    STATE(19838), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757175] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28779), 1,
      sym__lowercase_identifier,
    STATE(19839), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757189] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28781), 1,
      anon_sym_DOT,
    STATE(19840), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757203] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28783), 1,
      anon_sym_DOT_DOT,
    STATE(19841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757217] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28785), 1,
      anon_sym_DOT_DOT,
    STATE(19842), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757231] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28787), 1,
      anon_sym_DOT_DOT,
    STATE(19843), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757245] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28789), 1,
      anon_sym_RBRACE,
    STATE(19844), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757259] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3137), 1,
      anon_sym_RPAREN,
    STATE(19845), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757273] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13313), 1,
      anon_sym_DASH_GT,
    STATE(19846), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757287] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28791), 1,
      anon_sym_in,
    STATE(19847), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757301] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28793), 1,
      anon_sym_in,
    STATE(19848), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757315] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28795), 1,
      anon_sym_in,
    STATE(19849), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757329] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28797), 1,
      anon_sym_in,
    STATE(19850), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757343] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28799), 1,
      aux_sym_number_token1,
    STATE(19851), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757357] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28801), 1,
      anon_sym_RPAREN,
    STATE(19852), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757371] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28803), 1,
      anon_sym_RPAREN,
    STATE(19853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757385] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28805), 1,
      sym__lowercase_identifier,
    STATE(19854), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757399] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28807), 1,
      anon_sym_DOT,
    STATE(19855), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757413] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28809), 1,
      anon_sym_DOT_DOT,
    STATE(19856), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757427] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28811), 1,
      anon_sym_DOT_DOT,
    STATE(19857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757441] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28813), 1,
      anon_sym_DOT_DOT,
    STATE(19858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757455] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28815), 1,
      anon_sym_RPAREN,
    STATE(19859), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757469] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28817), 1,
      anon_sym_LT_DASH,
    STATE(19860), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757483] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28819), 1,
      anon_sym_RBRACE,
    STATE(19861), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757497] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28821), 1,
      anon_sym_SQUOTE2,
    STATE(19862), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757511] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28823), 1,
      anon_sym_DQUOTE,
    STATE(19863), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757525] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28825), 1,
      anon_sym_RBRACK,
    STATE(19864), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757539] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28827), 1,
      anon_sym_SQUOTE2,
    STATE(19865), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757553] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28829), 1,
      anon_sym_DASH_GT,
    STATE(19866), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757567] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28831), 1,
      anon_sym_RPAREN,
    STATE(19867), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757581] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28833), 1,
      anon_sym_RPAREN,
    STATE(19868), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757595] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28835), 1,
      sym__lowercase_identifier,
    STATE(19869), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757609] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28837), 1,
      anon_sym_RPAREN,
    STATE(19870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757623] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28839), 1,
      anon_sym_DOT_DOT,
    STATE(19871), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757637] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28841), 1,
      anon_sym_DOT_DOT,
    STATE(19872), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757651] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28843), 1,
      anon_sym_DOT_DOT,
    STATE(19873), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757665] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28845), 1,
      anon_sym_RBRACE,
    STATE(19874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757679] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28847), 1,
      anon_sym_RBRACE,
    STATE(19875), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757693] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28849), 1,
      anon_sym_RBRACE,
    STATE(19876), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757707] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28851), 1,
      anon_sym_RPAREN,
    STATE(19877), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757721] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28853), 1,
      anon_sym_RPAREN,
    STATE(19878), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757735] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28855), 1,
      anon_sym_DOT,
    STATE(19879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757749] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28857), 1,
      anon_sym_GT,
    STATE(19880), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757763] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28859), 1,
      anon_sym_RPAREN,
    STATE(19881), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757777] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23399), 1,
      anon_sym_RBRACE,
    STATE(19882), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757791] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3175), 1,
      anon_sym_RPAREN,
    STATE(19883), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757805] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28861), 1,
      sym__lowercase_identifier,
    STATE(19884), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757819] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23395), 1,
      anon_sym_RBRACE,
    STATE(19885), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757833] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28863), 1,
      anon_sym_DOT_DOT,
    STATE(19886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757847] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28865), 1,
      anon_sym_DOT_DOT,
    STATE(19887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757861] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28867), 1,
      anon_sym_DOT_DOT,
    STATE(19888), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757875] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28869), 1,
      anon_sym_RPAREN,
    STATE(19889), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757889] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28871), 1,
      anon_sym_RPAREN,
    STATE(19890), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757903] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28873), 1,
      anon_sym_RPAREN,
    STATE(19891), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757917] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28875), 1,
      anon_sym_DASH_GT,
    STATE(19892), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757931] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28877), 1,
      anon_sym_RPAREN,
    STATE(19893), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757945] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28879), 1,
      anon_sym_RBRACE,
    STATE(19894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757959] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28881), 1,
      anon_sym_RBRACK,
    STATE(19895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757973] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28883), 1,
      anon_sym_RPAREN,
    STATE(19896), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757987] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28885), 1,
      anon_sym_RPAREN,
    STATE(19897), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758001] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11710), 1,
      anon_sym_GT,
    STATE(19898), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758015] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28887), 1,
      sym__lowercase_identifier,
    STATE(19899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758029] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28889), 1,
      anon_sym_RPAREN,
    STATE(19900), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758043] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28891), 1,
      anon_sym_DOT_DOT,
    STATE(19901), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758057] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28893), 1,
      anon_sym_DOT_DOT,
    STATE(19902), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758071] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28895), 1,
      anon_sym_DOT_DOT,
    STATE(19903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758085] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28897), 1,
      anon_sym_RBRACE,
    STATE(19904), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758099] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28899), 1,
      anon_sym_SQUOTE2,
    STATE(19905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758113] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28901), 1,
      anon_sym_DQUOTE,
    STATE(19906), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758127] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28903), 1,
      anon_sym_RPAREN,
    STATE(19907), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758141] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28905), 1,
      anon_sym_RBRACK,
    STATE(19908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758155] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28907), 1,
      anon_sym_RPAREN,
    STATE(19909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758169] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28909), 1,
      sym__lowercase_identifier,
    STATE(19910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758183] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28911), 1,
      anon_sym_DASH_GT,
    STATE(19911), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758197] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28913), 1,
      anon_sym_DASH_GT,
    STATE(19912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758211] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28915), 1,
      anon_sym_RBRACE,
    STATE(19913), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758225] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28917), 1,
      sym__lowercase_identifier,
    STATE(19914), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758239] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28919), 1,
      anon_sym_RPAREN,
    STATE(19915), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758253] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28921), 1,
      anon_sym_DOT_DOT,
    STATE(19916), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758267] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28923), 1,
      anon_sym_DOT_DOT,
    STATE(19917), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758281] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28925), 1,
      anon_sym_DOT_DOT,
    STATE(19918), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758295] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28927), 1,
      anon_sym_RBRACE,
    STATE(19919), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758309] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28929), 1,
      anon_sym_RBRACK,
    STATE(19920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758323] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28931), 1,
      anon_sym_RPAREN,
    STATE(19921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758337] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28933), 1,
      anon_sym_done,
    STATE(19922), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758351] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28935), 1,
      anon_sym_DASH_GT,
    STATE(19923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758365] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28937), 1,
      anon_sym_RBRACE,
    STATE(19924), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758379] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16715), 1,
      anon_sym_RPAREN,
    STATE(19925), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758393] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6837), 1,
      anon_sym_RPAREN,
    STATE(19926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758407] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28939), 1,
      anon_sym_RPAREN,
    STATE(19927), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758421] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23221), 1,
      anon_sym_RPAREN,
    STATE(19928), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758435] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28941), 1,
      sym__lowercase_identifier,
    STATE(19929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758449] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28943), 1,
      sym__lowercase_identifier,
    STATE(19930), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758463] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28945), 1,
      anon_sym_DOT_DOT,
    STATE(19931), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758477] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28947), 1,
      anon_sym_DOT_DOT,
    STATE(19932), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758491] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28949), 1,
      anon_sym_DOT_DOT,
    STATE(19933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758505] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28951), 1,
      anon_sym_RBRACE,
    STATE(19934), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758519] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28953), 1,
      anon_sym_DASH_GT,
    STATE(19935), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758533] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28955), 1,
      anon_sym_RBRACK,
    STATE(19936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758547] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28957), 1,
      anon_sym_end,
    STATE(19937), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758561] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28959), 1,
      anon_sym_RPAREN,
    STATE(19938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758575] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28961), 1,
      anon_sym_DASH_GT,
    STATE(19939), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758589] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28963), 1,
      anon_sym_RPAREN,
    STATE(19940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758603] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3191), 1,
      anon_sym_RPAREN,
    STATE(19941), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758617] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8849), 1,
      anon_sym_DASH_GT,
    STATE(19942), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758631] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28965), 1,
      anon_sym_RPAREN,
    STATE(19943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758645] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28967), 1,
      sym__lowercase_identifier,
    STATE(19944), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758659] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17706), 1,
      anon_sym_GT,
    STATE(19945), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758673] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28969), 1,
      anon_sym_DOT_DOT,
    STATE(19946), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758687] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28971), 1,
      anon_sym_DOT_DOT,
    STATE(19947), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758701] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28973), 1,
      anon_sym_DOT_DOT,
    STATE(19948), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758715] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28975), 1,
      anon_sym_RBRACE,
    STATE(19949), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758729] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28977), 1,
      anon_sym_SQUOTE2,
    STATE(19950), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758743] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28979), 1,
      anon_sym_DQUOTE,
    STATE(19951), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758757] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28981), 1,
      anon_sym_RPAREN,
    STATE(19952), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758771] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28983), 1,
      sym__lowercase_identifier,
    STATE(19953), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758785] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28985), 1,
      anon_sym_RBRACE,
    STATE(19954), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758799] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28987), 1,
      anon_sym_RBRACK,
    STATE(19955), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758813] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28989), 1,
      anon_sym_DASH_GT,
    STATE(19956), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758827] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28991), 1,
      anon_sym_RBRACK,
    STATE(19957), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758841] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28993), 1,
      anon_sym_DOT,
    STATE(19958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758855] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28995), 1,
      sym__lowercase_identifier,
    STATE(19959), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758869] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28997), 1,
      sym__lowercase_identifier,
    STATE(19960), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758883] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(28999), 1,
      anon_sym_DOT_DOT,
    STATE(19961), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758897] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29001), 1,
      anon_sym_DOT_DOT,
    STATE(19962), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758911] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29003), 1,
      anon_sym_DOT_DOT,
    STATE(19963), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758925] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29005), 1,
      anon_sym_RBRACE,
    STATE(19964), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758939] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29007), 1,
      anon_sym_DQUOTE,
    STATE(19965), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758953] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29009), 1,
      anon_sym_SQUOTE2,
    STATE(19966), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758967] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19547), 1,
      anon_sym_end,
    STATE(19967), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758981] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(22580), 1,
      anon_sym_GT_RBRACE,
    STATE(19968), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758995] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29011), 1,
      anon_sym_RBRACE,
    STATE(19969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759009] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29013), 1,
      anon_sym_RPAREN,
    STATE(19970), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759023] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29015), 1,
      anon_sym_RBRACE,
    STATE(19971), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759037] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29017), 1,
      anon_sym_RPAREN,
    STATE(19972), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759051] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(14858), 1,
      anon_sym_DASH_GT,
    STATE(19973), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759065] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29019), 1,
      sym__lowercase_identifier,
    STATE(19974), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759079] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29021), 1,
      anon_sym_in,
    STATE(19975), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759093] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29023), 1,
      anon_sym_DOT_DOT,
    STATE(19976), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759107] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29025), 1,
      anon_sym_DOT_DOT,
    STATE(19977), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759121] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29027), 1,
      anon_sym_DOT_DOT,
    STATE(19978), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759135] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29029), 1,
      anon_sym_in,
    STATE(19979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759149] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29031), 1,
      anon_sym_in,
    STATE(19980), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759163] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29033), 1,
      anon_sym_in,
    STATE(19981), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759177] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23097), 1,
      aux_sym_number_token1,
    STATE(19982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759191] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2105), 1,
      anon_sym_end,
    STATE(19983), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759205] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29035), 1,
      anon_sym_RPAREN,
    STATE(19984), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759219] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3215), 1,
      anon_sym_RPAREN,
    STATE(19985), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759233] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3211), 1,
      anon_sym_RPAREN,
    STATE(19986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759247] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29037), 1,
      anon_sym_LT_DASH,
    STATE(19987), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759261] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29039), 1,
      anon_sym_RPAREN,
    STATE(19988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759275] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29041), 1,
      sym__lowercase_identifier,
    STATE(19989), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759289] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29043), 1,
      anon_sym_RBRACE,
    STATE(19990), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759303] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29045), 1,
      anon_sym_DOT_DOT,
    STATE(19991), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759317] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29047), 1,
      anon_sym_DOT_DOT,
    STATE(19992), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759331] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29049), 1,
      anon_sym_DOT_DOT,
    STATE(19993), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759345] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29051), 1,
      anon_sym_RBRACE,
    STATE(19994), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759359] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29053), 1,
      anon_sym_DQUOTE,
    STATE(19995), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759373] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29055), 1,
      anon_sym_RBRACK,
    STATE(19996), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759387] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29057), 1,
      anon_sym_RBRACE,
    STATE(19997), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759401] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29059), 1,
      anon_sym_RPAREN,
    STATE(19998), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759415] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29061), 1,
      anon_sym_RPAREN,
    STATE(19999), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759429] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29063), 1,
      anon_sym_RPAREN,
    STATE(20000), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759443] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29065), 1,
      anon_sym_RBRACE,
    STATE(20001), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759457] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29067), 1,
      anon_sym_RBRACE,
    STATE(20002), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759471] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29069), 1,
      anon_sym_RBRACE,
    STATE(20003), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759485] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29071), 1,
      sym__lowercase_identifier,
    STATE(20004), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759499] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29073), 1,
      anon_sym_RPAREN,
    STATE(20005), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759513] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29075), 1,
      anon_sym_DOT_DOT,
    STATE(20006), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759527] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29077), 1,
      anon_sym_DOT_DOT,
    STATE(20007), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759541] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29079), 1,
      anon_sym_DOT_DOT,
    STATE(20008), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759555] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29081), 1,
      anon_sym_RPAREN,
    STATE(20009), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759569] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29083), 1,
      anon_sym_RPAREN,
    STATE(20010), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759583] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29085), 1,
      anon_sym_GT,
    STATE(20011), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759597] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3235), 1,
      anon_sym_RPAREN,
    STATE(20012), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759611] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23301), 1,
      anon_sym_RBRACE,
    STATE(20013), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759625] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29087), 1,
      anon_sym_RPAREN,
    STATE(20014), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759639] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23297), 1,
      anon_sym_RBRACE,
    STATE(20015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759653] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29089), 1,
      anon_sym_RBRACE,
    STATE(20016), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759667] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29091), 1,
      anon_sym_RPAREN,
    STATE(20017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759681] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29093), 1,
      anon_sym_RPAREN,
    STATE(20018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759695] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29095), 1,
      sym__lowercase_identifier,
    STATE(20019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759709] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29097), 1,
      anon_sym_DASH_GT,
    STATE(20020), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759723] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29099), 1,
      anon_sym_DOT_DOT,
    STATE(20021), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759737] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29101), 1,
      anon_sym_DOT_DOT,
    STATE(20022), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759751] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29103), 1,
      anon_sym_DOT_DOT,
    STATE(20023), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759765] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29105), 1,
      anon_sym_RPAREN,
    STATE(20024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759779] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29107), 1,
      anon_sym_RBRACE,
    STATE(20025), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759793] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29109), 1,
      anon_sym_RBRACK,
    STATE(20026), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759807] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29111), 1,
      anon_sym_RPAREN,
    STATE(20027), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759821] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29113), 1,
      anon_sym_RPAREN,
    STATE(20028), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759835] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11544), 1,
      anon_sym_GT,
    STATE(20029), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759849] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29115), 1,
      anon_sym_RPAREN,
    STATE(20030), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759863] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29117), 1,
      anon_sym_DASH_GT,
    STATE(20031), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759877] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29119), 1,
      anon_sym_SQUOTE2,
    STATE(20032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759891] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29121), 1,
      anon_sym_DQUOTE,
    STATE(20033), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759905] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29123), 1,
      sym__lowercase_identifier,
    STATE(20034), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759919] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29125), 1,
      anon_sym_RPAREN,
    STATE(20035), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759933] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29127), 1,
      anon_sym_DOT_DOT,
    STATE(20036), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759947] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29129), 1,
      anon_sym_DOT_DOT,
    STATE(20037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759961] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29131), 1,
      anon_sym_DOT_DOT,
    STATE(20038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759975] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29133), 1,
      anon_sym_RBRACK,
    STATE(20039), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759989] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29135), 1,
      anon_sym_RPAREN,
    STATE(20040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760003] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29137), 1,
      sym__lowercase_identifier,
    STATE(20041), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760017] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29139), 1,
      anon_sym_RBRACE,
    STATE(20042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760031] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29141), 1,
      anon_sym_DASH_GT,
    STATE(20043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760045] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29143), 1,
      anon_sym_DASH_GT,
    STATE(20044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760059] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29145), 1,
      anon_sym_RBRACE,
    STATE(20045), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760073] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29147), 1,
      anon_sym_RPAREN,
    STATE(20046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760087] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29149), 1,
      anon_sym_RBRACE,
    STATE(20047), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760101] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29151), 1,
      anon_sym_RBRACK,
    STATE(20048), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760115] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29153), 1,
      sym__lowercase_identifier,
    STATE(20049), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760129] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29155), 1,
      anon_sym_RPAREN,
    STATE(20050), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760143] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29157), 1,
      anon_sym_DOT_DOT,
    STATE(20051), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760157] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29159), 1,
      anon_sym_DOT_DOT,
    STATE(20052), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760171] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29161), 1,
      anon_sym_DOT_DOT,
    STATE(20053), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760185] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29163), 1,
      anon_sym_done,
    STATE(20054), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760199] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29165), 1,
      anon_sym_DASH_GT,
    STATE(20055), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760213] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29167), 1,
      anon_sym_RPAREN,
    STATE(20056), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760227] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16844), 1,
      anon_sym_RPAREN,
    STATE(20057), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760241] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(2105), 1,
      anon_sym_RPAREN,
    STATE(20058), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760255] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29169), 1,
      anon_sym_RPAREN,
    STATE(20059), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760269] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29171), 1,
      anon_sym_RPAREN,
    STATE(20060), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760283] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29173), 1,
      anon_sym_in,
    STATE(20061), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760297] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29175), 1,
      anon_sym_RPAREN,
    STATE(20062), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760311] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29177), 1,
      sym__lowercase_identifier,
    STATE(20063), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760325] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29179), 1,
      sym__lowercase_identifier,
    STATE(20064), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760339] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29181), 1,
      anon_sym_RBRACE,
    STATE(20065), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760353] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29183), 1,
      anon_sym_DOT_DOT,
    STATE(20066), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760367] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29185), 1,
      anon_sym_DOT_DOT,
    STATE(20067), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760381] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29187), 1,
      anon_sym_DOT_DOT,
    STATE(20068), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760395] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29189), 1,
      anon_sym_RBRACK,
    STATE(20069), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760409] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29191), 1,
      anon_sym_DASH_GT,
    STATE(20070), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760423] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29193), 1,
      anon_sym_RBRACK,
    STATE(20071), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760437] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29195), 1,
      anon_sym_end,
    STATE(20072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760451] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29197), 1,
      anon_sym_DQUOTE,
    STATE(20073), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760465] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29199), 1,
      anon_sym_in,
    STATE(20074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760479] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29201), 1,
      anon_sym_RBRACK,
    STATE(20075), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760493] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29203), 1,
      anon_sym_RBRACE,
    STATE(20076), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760507] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8955), 1,
      anon_sym_DASH_GT,
    STATE(20077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760521] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29205), 1,
      anon_sym_RBRACE,
    STATE(20078), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760535] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17657), 1,
      anon_sym_GT,
    STATE(20079), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760549] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29207), 1,
      anon_sym_DOT_DOT,
    STATE(20080), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760563] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29209), 1,
      anon_sym_DOT_DOT,
    STATE(20081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760577] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29211), 1,
      anon_sym_DOT_DOT,
    STATE(20082), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760591] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29213), 1,
      anon_sym_RPAREN,
    STATE(20083), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760605] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29215), 1,
      anon_sym_RBRACK,
    STATE(20084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760619] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29217), 1,
      anon_sym_RBRACE,
    STATE(20085), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760633] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29219), 1,
      anon_sym_RBRACE,
    STATE(20086), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760647] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29221), 1,
      anon_sym_RPAREN,
    STATE(20087), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760661] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29223), 1,
      sym__lowercase_identifier,
    STATE(20088), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760675] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29225), 1,
      anon_sym_RPAREN,
    STATE(20089), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760689] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29227), 1,
      anon_sym_RBRACE,
    STATE(20090), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760703] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29229), 1,
      anon_sym_RBRACK,
    STATE(20091), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760717] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29231), 1,
      anon_sym_RPAREN,
    STATE(20092), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760731] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29233), 1,
      anon_sym_DASH_GT,
    STATE(20093), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760745] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29235), 1,
      anon_sym_DOT_DOT,
    STATE(20094), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760759] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29237), 1,
      anon_sym_DOT_DOT,
    STATE(20095), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760773] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29239), 1,
      anon_sym_DOT_DOT,
    STATE(20096), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760787] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29241), 1,
      anon_sym_DASH_GT,
    STATE(20097), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760801] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5391), 1,
      anon_sym_COLON_COLON,
    STATE(20098), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760815] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29243), 1,
      anon_sym_DOT,
    STATE(20099), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760829] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29245), 1,
      sym__lowercase_identifier,
    STATE(20100), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760843] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29247), 1,
      anon_sym_RBRACK,
    STATE(20101), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760857] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29249), 1,
      anon_sym_DQUOTE,
    STATE(20102), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760871] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29251), 1,
      anon_sym_SQUOTE2,
    STATE(20103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760885] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20150), 1,
      anon_sym_end,
    STATE(20104), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760899] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(20990), 1,
      anon_sym_GT_RBRACE,
    STATE(20105), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760913] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29253), 1,
      anon_sym_RBRACE,
    STATE(20106), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760927] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29255), 1,
      anon_sym_RBRACE,
    STATE(20107), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760941] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29257), 1,
      anon_sym_DOT_DOT,
    STATE(20108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760955] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29259), 1,
      anon_sym_DOT_DOT,
    STATE(20109), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760969] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29261), 1,
      anon_sym_DOT_DOT,
    STATE(20110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760983] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29263), 1,
      anon_sym_RBRACE,
    STATE(20111), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760997] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29265), 1,
      anon_sym_RPAREN,
    STATE(20112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761011] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(13543), 1,
      anon_sym_DASH_GT,
    STATE(20113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761025] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29267), 1,
      anon_sym_of,
    STATE(20114), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761039] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29269), 1,
      anon_sym_in,
    STATE(20115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761053] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29271), 1,
      anon_sym_in,
    STATE(20116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761067] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29273), 1,
      anon_sym_in,
    STATE(20117), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761081] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29275), 1,
      aux_sym_number_token1,
    STATE(20118), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761095] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_end,
    STATE(20119), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761109] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29277), 1,
      anon_sym_RBRACE,
    STATE(20120), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761123] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29279), 1,
      anon_sym_end,
    STATE(20121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761137] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29281), 1,
      anon_sym_DOT_DOT,
    STATE(20122), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761151] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29283), 1,
      anon_sym_DOT_DOT,
    STATE(20123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761165] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29285), 1,
      anon_sym_DOT_DOT,
    STATE(20124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761179] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29287), 1,
      anon_sym_RBRACK,
    STATE(20125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761193] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29289), 1,
      sym__uppercase_identifier,
    STATE(20126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761207] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29291), 1,
      anon_sym_end,
    STATE(20127), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761221] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29293), 1,
      anon_sym_RPAREN,
    STATE(20128), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761235] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29295), 1,
      anon_sym_RBRACK,
    STATE(20129), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761249] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3249), 1,
      anon_sym_RPAREN,
    STATE(20130), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761263] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29297), 1,
      anon_sym_LT_DASH,
    STATE(20131), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761277] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29299), 1,
      anon_sym_DOT,
    STATE(20132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761291] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29301), 1,
      anon_sym_RBRACE,
    STATE(20133), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761305] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29303), 1,
      anon_sym_RBRACE,
    STATE(20134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761319] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29305), 1,
      anon_sym_RBRACK,
    STATE(20135), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761333] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29307), 1,
      anon_sym_DOT_DOT,
    STATE(20136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761347] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29309), 1,
      anon_sym_DOT_DOT,
    STATE(20137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761361] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29311), 1,
      anon_sym_DOT_DOT,
    STATE(20138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761375] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29313), 1,
      anon_sym_RBRACE,
    STATE(20139), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761389] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23223), 1,
      anon_sym_RBRACK,
    STATE(20140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761403] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29315), 1,
      anon_sym_RBRACE,
    STATE(20141), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761417] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9118), 1,
      anon_sym_DASH_GT,
    STATE(20142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761431] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9124), 1,
      anon_sym_DASH_GT,
    STATE(20143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761445] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9114), 1,
      anon_sym_DASH_GT,
    STATE(20144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761459] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29317), 1,
      anon_sym_RBRACK,
    STATE(20145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761473] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29319), 1,
      anon_sym_RBRACE,
    STATE(20146), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761487] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29321), 1,
      anon_sym_RBRACE,
    STATE(20147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761501] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29323), 1,
      anon_sym_DOT_DOT,
    STATE(20148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761515] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29325), 1,
      anon_sym_DOT_DOT,
    STATE(20149), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761529] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29327), 1,
      anon_sym_DOT_DOT,
    STATE(20150), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761543] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29329), 1,
      anon_sym_RBRACE,
    STATE(20151), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761557] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29329), 1,
      anon_sym_RBRACK,
    STATE(20152), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761571] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29329), 1,
      anon_sym_RPAREN,
    STATE(20153), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761585] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29331), 1,
      anon_sym_RBRACK,
    STATE(20154), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761599] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29333), 1,
      anon_sym_DOT_DOT,
    STATE(20155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761613] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29335), 1,
      anon_sym_DOT_DOT,
    STATE(20156), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761627] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29337), 1,
      anon_sym_DOT_DOT,
    STATE(20157), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761641] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29339), 1,
      sym__uppercase_identifier,
    STATE(20158), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761655] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29341), 1,
      anon_sym_RPAREN,
    STATE(20159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761669] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29343), 1,
      anon_sym_DOT_DOT,
    STATE(20160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761683] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29345), 1,
      anon_sym_DOT_DOT,
    STATE(20161), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761697] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29347), 1,
      anon_sym_DOT_DOT,
    STATE(20162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761711] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29349), 1,
      anon_sym_RBRACE,
    STATE(20163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761725] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29351), 1,
      anon_sym_RBRACE,
    STATE(20164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761739] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29353), 1,
      anon_sym_DOT_DOT,
    STATE(20165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761753] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29355), 1,
      anon_sym_DOT_DOT,
    STATE(20166), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761767] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29357), 1,
      anon_sym_DOT_DOT,
    STATE(20167), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761781] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29359), 1,
      anon_sym_RBRACK,
    STATE(20168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761795] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29361), 1,
      anon_sym_RBRACE,
    STATE(20169), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761809] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29363), 1,
      anon_sym_DOT_DOT,
    STATE(20170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761823] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29365), 1,
      anon_sym_DOT_DOT,
    STATE(20171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761837] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29367), 1,
      anon_sym_DOT_DOT,
    STATE(20172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761851] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29369), 1,
      anon_sym_RPAREN,
    STATE(20173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761865] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29371), 1,
      anon_sym_RPAREN,
    STATE(20174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761879] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29373), 1,
      anon_sym_DOT_DOT,
    STATE(20175), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761893] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29375), 1,
      anon_sym_DOT_DOT,
    STATE(20176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761907] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29377), 1,
      anon_sym_DOT_DOT,
    STATE(20177), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761921] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29379), 1,
      anon_sym_RPAREN,
    STATE(20178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761935] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29381), 1,
      anon_sym_GT,
    STATE(20179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761949] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29383), 1,
      anon_sym_DOT_DOT,
    STATE(20180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761963] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29385), 1,
      anon_sym_DOT_DOT,
    STATE(20181), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761977] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29387), 1,
      anon_sym_DOT_DOT,
    STATE(20182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761991] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29389), 1,
      anon_sym_RBRACE,
    STATE(20183), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762005] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29391), 1,
      anon_sym_RBRACE,
    STATE(20184), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762019] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29393), 1,
      anon_sym_DOT_DOT,
    STATE(20185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762033] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29395), 1,
      anon_sym_DOT_DOT,
    STATE(20186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762047] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29397), 1,
      anon_sym_DOT_DOT,
    STATE(20187), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762061] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29399), 1,
      anon_sym_RBRACE,
    STATE(20188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762075] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29401), 1,
      anon_sym_RPAREN,
    STATE(20189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762089] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29403), 1,
      anon_sym_DOT_DOT,
    STATE(20190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762103] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29405), 1,
      anon_sym_DOT_DOT,
    STATE(20191), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762117] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29407), 1,
      anon_sym_DOT_DOT,
    STATE(20192), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762131] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29409), 1,
      anon_sym_EQ,
    STATE(20193), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762145] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29411), 1,
      anon_sym_RBRACK,
    STATE(20194), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762159] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29413), 1,
      anon_sym_DOT_DOT,
    STATE(20195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762173] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29415), 1,
      anon_sym_DOT_DOT,
    STATE(20196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762187] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29417), 1,
      anon_sym_DOT_DOT,
    STATE(20197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762201] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29419), 1,
      anon_sym_RBRACE,
    STATE(20198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762215] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29421), 1,
      anon_sym_RPAREN,
    STATE(20199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762229] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29423), 1,
      anon_sym_DOT_DOT,
    STATE(20200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762243] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29425), 1,
      anon_sym_DOT_DOT,
    STATE(20201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762257] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29427), 1,
      anon_sym_DOT_DOT,
    STATE(20202), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762271] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29429), 1,
      anon_sym_RBRACE,
    STATE(20203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762285] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23205), 1,
      anon_sym_RBRACE,
    STATE(20204), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762299] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29431), 1,
      anon_sym_DOT_DOT,
    STATE(20205), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762313] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29433), 1,
      anon_sym_DOT_DOT,
    STATE(20206), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762327] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29435), 1,
      anon_sym_DOT_DOT,
    STATE(20207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762341] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29437), 1,
      anon_sym_RBRACK,
    STATE(20208), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762355] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23201), 1,
      anon_sym_RBRACE,
    STATE(20209), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762369] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29439), 1,
      anon_sym_DOT_DOT,
    STATE(20210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762383] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29441), 1,
      anon_sym_DOT_DOT,
    STATE(20211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762397] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29443), 1,
      anon_sym_DOT_DOT,
    STATE(20212), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762411] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29445), 1,
      anon_sym_RBRACE,
    STATE(20213), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762425] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29447), 1,
      anon_sym_RBRACE,
    STATE(20214), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762439] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29449), 1,
      anon_sym_DOT_DOT,
    STATE(20215), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762453] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29451), 1,
      anon_sym_DOT_DOT,
    STATE(20216), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762467] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29453), 1,
      anon_sym_DOT_DOT,
    STATE(20217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762481] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18185), 1,
      anon_sym_RPAREN,
    STATE(20218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762495] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29455), 1,
      anon_sym_RPAREN,
    STATE(20219), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762509] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29457), 1,
      anon_sym_RPAREN,
    STATE(20220), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762523] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29459), 1,
      sym__lowercase_identifier,
    STATE(20221), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762537] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29461), 1,
      anon_sym_EQ,
    STATE(20222), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762551] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29463), 1,
      anon_sym_DASH_GT,
    STATE(20223), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762565] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29465), 1,
      anon_sym_RBRACE,
    STATE(20224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762579] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29467), 1,
      anon_sym_RBRACE,
    STATE(20225), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762593] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29469), 1,
      anon_sym_RBRACE,
    STATE(20226), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762607] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29469), 1,
      anon_sym_RBRACK,
    STATE(20227), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762621] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29469), 1,
      anon_sym_RPAREN,
    STATE(20228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762635] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29471), 1,
      anon_sym_RPAREN,
    STATE(20229), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762649] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29473), 1,
      anon_sym_RBRACE,
    STATE(20230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762663] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29475), 1,
      anon_sym_RBRACK,
    STATE(20231), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762677] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29477), 1,
      anon_sym_RPAREN,
    STATE(20232), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762691] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29479), 1,
      anon_sym_RPAREN,
    STATE(20233), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762705] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29481), 1,
      anon_sym_RBRACE,
    STATE(20234), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762719] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29483), 1,
      anon_sym_RBRACK,
    STATE(20235), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762733] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29485), 1,
      anon_sym_RBRACE,
    STATE(20236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762747] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(11726), 1,
      anon_sym_GT,
    STATE(20237), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762761] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29487), 1,
      anon_sym_RBRACE,
    STATE(20238), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762775] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29489), 1,
      anon_sym_RBRACK,
    STATE(20239), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762789] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29491), 1,
      anon_sym_RPAREN,
    STATE(20240), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762803] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29493), 1,
      anon_sym_RBRACE,
    STATE(20241), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762817] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29495), 1,
      anon_sym_PLUS_EQ,
    STATE(20242), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762831] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29497), 1,
      anon_sym_RBRACE,
    STATE(20243), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762845] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29499), 1,
      anon_sym_RBRACK,
    STATE(20244), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762859] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29501), 1,
      sym_indexing_operator,
    STATE(20245), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762873] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29503), 1,
      anon_sym_PLUS_EQ,
    STATE(20246), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762887] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29505), 1,
      anon_sym_in,
    STATE(20247), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762901] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29507), 1,
      anon_sym_RBRACE,
    STATE(20248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762915] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29509), 1,
      anon_sym_DOT,
    STATE(20249), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762929] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29511), 1,
      anon_sym_RBRACK,
    STATE(20250), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762943] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29513), 1,
      anon_sym_RBRACE,
    STATE(20251), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762957] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29515), 1,
      anon_sym_RPAREN,
    STATE(20252), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762971] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29517), 1,
      anon_sym_DASH_GT,
    STATE(20253), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762985] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29519), 1,
      anon_sym_RPAREN,
    STATE(20254), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762999] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29521), 1,
      sym__lowercase_identifier,
    STATE(20255), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763013] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29523), 1,
      sym__lowercase_identifier,
    STATE(20256), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763027] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29525), 1,
      sym__lowercase_identifier,
    STATE(20257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763041] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29527), 1,
      anon_sym_EQ,
    STATE(20258), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763055] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29529), 1,
      anon_sym_DOT,
    STATE(20259), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763069] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29531), 1,
      anon_sym_RBRACE,
    STATE(20260), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763083] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29533), 1,
      anon_sym_DASH_GT,
    STATE(20261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763097] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29535), 1,
      anon_sym_DASH_GT,
    STATE(20262), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763111] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29537), 1,
      anon_sym_RBRACK,
    STATE(20263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763125] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29539), 1,
      anon_sym_RBRACE,
    STATE(20264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763139] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29541), 1,
      anon_sym_DOT_DOT,
    STATE(20265), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763153] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29543), 1,
      anon_sym_DOT_DOT,
    STATE(20266), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763167] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29545), 1,
      anon_sym_DOT_DOT,
    STATE(20267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763181] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29547), 1,
      anon_sym_with,
    STATE(20268), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763195] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29549), 1,
      anon_sym_RPAREN,
    STATE(20269), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763209] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29551), 1,
      anon_sym_RBRACE,
    STATE(20270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763223] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29553), 1,
      anon_sym_RBRACK,
    STATE(20271), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763237] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29555), 1,
      anon_sym_PLUS_EQ,
    STATE(20272), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763251] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29557), 1,
      sym_indexing_operator,
    STATE(20273), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763265] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29559), 1,
      anon_sym_PLUS_EQ,
    STATE(20274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763279] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29561), 1,
      anon_sym_RPAREN,
    STATE(20275), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763293] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29563), 1,
      anon_sym_RBRACE,
    STATE(20276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763307] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29565), 1,
      anon_sym_with,
    STATE(20277), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763321] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29567), 1,
      anon_sym_RBRACK,
    STATE(20278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763335] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29569), 1,
      anon_sym_done,
    STATE(20279), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763349] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29571), 1,
      sym__lowercase_identifier,
    STATE(20280), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763363] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29573), 1,
      anon_sym_RBRACE,
    STATE(20281), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763377] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18057), 1,
      anon_sym_RPAREN,
    STATE(20282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763391] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29575), 1,
      anon_sym_RBRACE,
    STATE(20283), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763405] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29577), 1,
      anon_sym_RBRACK,
    STATE(20284), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763419] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29579), 1,
      anon_sym_RBRACE,
    STATE(20285), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763433] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29581), 1,
      anon_sym_RBRACE,
    STATE(20286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763447] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16800), 1,
      anon_sym_RPAREN,
    STATE(20287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763461] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29583), 1,
      anon_sym_RBRACK,
    STATE(20288), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763475] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29585), 1,
      anon_sym_PLUS_EQ,
    STATE(20289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763489] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29587), 1,
      sym_indexing_operator,
    STATE(20290), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763503] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29589), 1,
      anon_sym_PLUS_EQ,
    STATE(20291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763517] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_RPAREN,
    STATE(20292), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763531] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29591), 1,
      anon_sym_COMMA,
    STATE(20293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763545] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29593), 1,
      anon_sym_RPAREN,
    STATE(20294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763559] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29595), 1,
      anon_sym_RBRACE,
    STATE(20295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763573] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29597), 1,
      anon_sym_RBRACE,
    STATE(20296), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763587] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29599), 1,
      sym__lowercase_identifier,
    STATE(20297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763601] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29601), 1,
      anon_sym_COLON2,
    STATE(20298), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763615] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29603), 1,
      anon_sym_in,
    STATE(20299), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763629] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23213), 1,
      anon_sym_RPAREN,
    STATE(20300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763643] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29605), 1,
      anon_sym_RBRACE,
    STATE(20301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763657] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29607), 1,
      anon_sym_in,
    STATE(20302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763671] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29609), 1,
      sym__lowercase_identifier,
    STATE(20303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763685] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29611), 1,
      sym__lowercase_identifier,
    STATE(20304), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763699] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29613), 1,
      anon_sym_RBRACE,
    STATE(20305), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763713] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29615), 1,
      sym_indexing_operator,
    STATE(20306), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763727] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29617), 1,
      anon_sym_RBRACK,
    STATE(20307), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763741] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29619), 1,
      anon_sym_DASH_GT,
    STATE(20308), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763755] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17517), 1,
      sym__uppercase_identifier,
    STATE(20309), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763769] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29621), 1,
      anon_sym_RBRACK,
    STATE(20310), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763783] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29623), 1,
      sym__lowercase_identifier,
    STATE(20311), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763797] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29625), 1,
      anon_sym_RBRACE,
    STATE(20312), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763811] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29627), 1,
      sym__lowercase_identifier,
    STATE(20313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763825] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29629), 1,
      anon_sym_in,
    STATE(20314), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763839] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29631), 1,
      anon_sym_RBRACE,
    STATE(20315), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763853] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29633), 1,
      anon_sym_RBRACK,
    STATE(20316), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763867] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29635), 1,
      anon_sym_RBRACE,
    STATE(20317), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763881] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29637), 1,
      sym_indexing_operator,
    STATE(20318), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763895] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29639), 1,
      anon_sym_EQ,
    STATE(20319), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763909] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29641), 1,
      anon_sym_DOT,
    STATE(20320), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763923] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29643), 1,
      sym_indexing_operator,
    STATE(20321), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763937] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29645), 1,
      sym__lowercase_identifier,
    STATE(20322), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763951] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29647), 1,
      anon_sym_end,
    STATE(20323), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763965] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29649), 1,
      sym_indexing_operator,
    STATE(20324), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763979] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29651), 1,
      anon_sym_RBRACE,
    STATE(20325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763993] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29653), 1,
      anon_sym_with,
    STATE(20326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764007] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29655), 1,
      sym_indexing_operator,
    STATE(20327), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764021] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29657), 1,
      sym_indexing_operator,
    STATE(20328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764035] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29659), 1,
      sym_indexing_operator,
    STATE(20329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764049] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29661), 1,
      sym_indexing_operator,
    STATE(20330), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764063] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29663), 1,
      sym_indexing_operator,
    STATE(20331), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764077] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29665), 1,
      sym_indexing_operator,
    STATE(20332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764091] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29667), 1,
      sym_indexing_operator,
    STATE(20333), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764105] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29669), 1,
      sym_indexing_operator,
    STATE(20334), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764119] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29671), 1,
      sym_indexing_operator,
    STATE(20335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764133] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29673), 1,
      sym_indexing_operator,
    STATE(20336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764147] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29675), 1,
      sym_indexing_operator,
    STATE(20337), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764161] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29677), 1,
      sym_indexing_operator,
    STATE(20338), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764175] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29679), 1,
      sym_indexing_operator,
    STATE(20339), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764189] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29681), 1,
      sym_indexing_operator,
    STATE(20340), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764203] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29683), 1,
      sym_indexing_operator,
    STATE(20341), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764217] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29685), 1,
      sym_indexing_operator,
    STATE(20342), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764231] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29687), 1,
      sym_indexing_operator,
    STATE(20343), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764245] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29689), 1,
      sym_indexing_operator,
    STATE(20344), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764259] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29691), 1,
      sym_indexing_operator,
    STATE(20345), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764273] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29693), 1,
      sym_indexing_operator,
    STATE(20346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764287] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29695), 1,
      sym_indexing_operator,
    STATE(20347), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764301] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29697), 1,
      sym_indexing_operator,
    STATE(20348), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764315] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29699), 1,
      sym_indexing_operator,
    STATE(20349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764329] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29701), 1,
      sym_indexing_operator,
    STATE(20350), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764343] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29703), 1,
      sym_indexing_operator,
    STATE(20351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764357] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29705), 1,
      sym_indexing_operator,
    STATE(20352), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764371] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29707), 1,
      sym_indexing_operator,
    STATE(20353), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764385] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29709), 1,
      sym_indexing_operator,
    STATE(20354), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764399] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29711), 1,
      sym_indexing_operator,
    STATE(20355), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764413] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29713), 1,
      sym_indexing_operator,
    STATE(20356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764427] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29715), 1,
      sym_indexing_operator,
    STATE(20357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764441] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29717), 1,
      sym_indexing_operator,
    STATE(20358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764455] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29719), 1,
      sym_indexing_operator,
    STATE(20359), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764469] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29721), 1,
      sym_indexing_operator,
    STATE(20360), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764483] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29723), 1,
      sym_indexing_operator,
    STATE(20361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764497] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29725), 1,
      sym_indexing_operator,
    STATE(20362), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764511] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29727), 1,
      sym_indexing_operator,
    STATE(20363), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764525] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29729), 1,
      sym_indexing_operator,
    STATE(20364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764539] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29731), 1,
      sym_indexing_operator,
    STATE(20365), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764553] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29733), 1,
      sym_indexing_operator,
    STATE(20366), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764567] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29735), 1,
      sym_indexing_operator,
    STATE(20367), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764581] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29737), 1,
      sym_indexing_operator,
    STATE(20368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764595] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29739), 1,
      sym_indexing_operator,
    STATE(20369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764609] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29741), 1,
      sym_indexing_operator,
    STATE(20370), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764623] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29743), 1,
      sym_indexing_operator,
    STATE(20371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764637] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29745), 1,
      sym_indexing_operator,
    STATE(20372), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764651] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29747), 1,
      sym_indexing_operator,
    STATE(20373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764665] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29749), 1,
      sym_indexing_operator,
    STATE(20374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764679] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29751), 1,
      sym_indexing_operator,
    STATE(20375), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764693] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29753), 1,
      anon_sym_DASH_GT,
    STATE(20376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764707] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29755), 1,
      anon_sym_with,
    STATE(20377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764721] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29757), 1,
      anon_sym_PIPE,
    STATE(20378), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764735] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29759), 1,
      anon_sym_DASH_GT,
    STATE(20379), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764749] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29761), 1,
      anon_sym_RBRACK,
    STATE(20380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764763] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9048), 1,
      anon_sym_DASH_GT,
    STATE(20381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764777] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29763), 1,
      anon_sym_RBRACE,
    STATE(20382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764791] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29765), 1,
      anon_sym_RBRACE,
    STATE(20383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764805] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29767), 1,
      anon_sym_EQ,
    STATE(20384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764819] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(17699), 1,
      anon_sym_GT,
    STATE(20385), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764833] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29769), 1,
      anon_sym_type,
    STATE(20386), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764847] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29771), 1,
      anon_sym_EQ,
    STATE(20387), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764861] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29773), 1,
      anon_sym_EQ,
    STATE(20388), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764875] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29775), 1,
      anon_sym_COLON2,
    STATE(20389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764889] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29777), 1,
      anon_sym_DOT,
    STATE(20390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764903] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29779), 1,
      anon_sym_RBRACK,
    STATE(20391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764917] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29781), 1,
      anon_sym_COMMA,
    STATE(20392), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764931] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29783), 1,
      anon_sym_with,
    STATE(20393), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764945] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29785), 1,
      anon_sym_RBRACE,
    STATE(20394), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764959] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29787), 1,
      anon_sym_EQ,
    STATE(20395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764973] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29789), 1,
      sym__right_quoted_string_delimiter,
    STATE(20396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764987] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29791), 1,
      anon_sym_RBRACE,
    STATE(20397), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765001] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29793), 1,
      anon_sym_EQ,
    STATE(20398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765015] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29795), 1,
      anon_sym_DOT,
    STATE(20399), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765029] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29797), 1,
      anon_sym_DOT,
    STATE(20400), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765043] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29799), 1,
      anon_sym_with,
    STATE(20401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765057] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29801), 1,
      sym__lowercase_identifier,
    STATE(20402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765071] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29803), 1,
      anon_sym_RBRACK,
    STATE(20403), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765085] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29805), 1,
      anon_sym_RPAREN,
    STATE(20404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765099] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29807), 1,
      anon_sym_EQ,
    STATE(20405), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765113] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29809), 1,
      anon_sym_DOT,
    STATE(20406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765127] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18486), 1,
      anon_sym_DASH_GT,
    STATE(20407), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765141] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29811), 1,
      anon_sym_EQ,
    STATE(20408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765155] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29813), 1,
      anon_sym_in,
    STATE(20409), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765169] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29815), 1,
      sym__lowercase_identifier,
    STATE(20410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765183] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29817), 1,
      anon_sym_with,
    STATE(20411), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765197] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29819), 1,
      anon_sym_RPAREN,
    STATE(20412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765211] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29821), 1,
      anon_sym_RBRACE,
    STATE(20413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765225] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29823), 1,
      anon_sym_with,
    STATE(20414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765239] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29825), 1,
      anon_sym_RBRACK,
    STATE(20415), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765253] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29827), 1,
      anon_sym_RPAREN,
    STATE(20416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765267] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29829), 1,
      anon_sym_DASH_GT,
    STATE(20417), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765281] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29831), 1,
      anon_sym_DASH_GT,
    STATE(20418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765295] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29833), 1,
      anon_sym_DOT,
    STATE(20419), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765309] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5279), 1,
      anon_sym_COLON_COLON,
    STATE(20420), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765323] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29835), 1,
      anon_sym_DOT,
    STATE(20421), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765337] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29837), 1,
      anon_sym_DOT,
    STATE(20422), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765351] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29839), 1,
      anon_sym_DOT,
    STATE(20423), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765365] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29841), 1,
      anon_sym_EQ,
    STATE(20424), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765379] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29843), 1,
      anon_sym_DOT,
    STATE(20425), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765393] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29845), 1,
      ts_builtin_sym_end,
    STATE(20426), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765407] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29847), 1,
      sym__lowercase_identifier,
    STATE(20427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765421] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29849), 1,
      anon_sym_RBRACE,
    STATE(20428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765435] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29851), 1,
      anon_sym_DQUOTE,
    STATE(20429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765449] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29853), 1,
      anon_sym_SQUOTE2,
    STATE(20430), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765463] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16527), 1,
      anon_sym_SQUOTE2,
    STATE(20431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765477] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29855), 1,
      anon_sym_SQUOTE2,
    STATE(20432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765491] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(19860), 1,
      anon_sym_end,
    STATE(20433), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765505] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(21493), 1,
      anon_sym_GT_RBRACE,
    STATE(20434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765519] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29857), 1,
      anon_sym_DOT,
    STATE(20435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765533] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29859), 1,
      anon_sym_with,
    STATE(20436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765547] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29861), 1,
      anon_sym_with,
    STATE(20437), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765561] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29863), 1,
      anon_sym_EQ,
    STATE(20438), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765575] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29865), 1,
      anon_sym_DOT,
    STATE(20439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765589] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29867), 1,
      anon_sym_DOT,
    STATE(20440), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765603] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29869), 1,
      anon_sym_DOT,
    STATE(20441), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765617] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29871), 1,
      anon_sym_RBRACE,
    STATE(20442), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765631] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29873), 1,
      anon_sym_in,
    STATE(20443), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765645] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(16951), 1,
      anon_sym_DASH_GT,
    STATE(20444), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765659] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18209), 1,
      anon_sym_RBRACK,
    STATE(20445), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765673] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29875), 1,
      sym__lowercase_identifier,
    STATE(20446), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765687] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29877), 1,
      anon_sym_in,
    STATE(20447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765701] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29879), 1,
      anon_sym_DOT,
    STATE(20448), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765715] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29881), 1,
      anon_sym_in,
    STATE(20449), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765729] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29883), 1,
      anon_sym_in,
    STATE(20450), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765743] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29885), 1,
      anon_sym_in,
    STATE(20451), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765757] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29887), 1,
      anon_sym_RBRACK,
    STATE(20452), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765771] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29889), 1,
      anon_sym_COMMA,
    STATE(20453), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765785] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29891), 1,
      anon_sym_RBRACK,
    STATE(20454), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765799] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29893), 1,
      anon_sym_RBRACK,
    STATE(20455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765813] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29895), 1,
      anon_sym_DOT,
    STATE(20456), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765827] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29897), 1,
      anon_sym_DOT,
    STATE(20457), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765841] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29899), 1,
      aux_sym_number_token1,
    STATE(20458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765855] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(5147), 1,
      anon_sym_end,
    STATE(20459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765869] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29901), 1,
      anon_sym_EQ,
    STATE(20460), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765883] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29903), 1,
      anon_sym_with,
    STATE(20461), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765897] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29905), 1,
      anon_sym_with,
    STATE(20462), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765911] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29907), 1,
      anon_sym_end,
    STATE(20463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765925] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29909), 1,
      anon_sym_of,
    STATE(20464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765939] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29911), 1,
      anon_sym_DOT,
    STATE(20465), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765953] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      sym__uppercase_identifier,
    STATE(20466), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765967] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29913), 1,
      anon_sym_end,
    STATE(20467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765981] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29915), 1,
      anon_sym_in,
    STATE(20468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765995] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29917), 1,
      anon_sym_RPAREN,
    STATE(20469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766009] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(18043), 1,
      anon_sym_RPAREN,
    STATE(20470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766023] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29919), 1,
      anon_sym_DOT,
    STATE(20471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766037] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29921), 1,
      anon_sym_PLUS_EQ,
    STATE(20472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766051] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29923), 1,
      anon_sym_EQ,
    STATE(20473), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766065] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29925), 1,
      anon_sym_RPAREN,
    STATE(20474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766079] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29927), 1,
      anon_sym_RPAREN,
    STATE(20475), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766093] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(3171), 1,
      anon_sym_RPAREN,
    STATE(20476), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766107] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(10364), 1,
      anon_sym_RPAREN,
    STATE(20477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766121] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29929), 1,
      sym_indexing_operator,
    STATE(20478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766135] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29931), 1,
      anon_sym_LT_DASH,
    STATE(20479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766149] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29933), 1,
      anon_sym_DOT,
    STATE(20480), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766163] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29935), 1,
      anon_sym_LT_DASH,
    STATE(20481), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766177] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29925), 1,
      anon_sym_RBRACK,
    STATE(20482), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766191] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29937), 1,
      ts_builtin_sym_end,
    STATE(20483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766205] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(7875), 1,
      anon_sym_RBRACK,
    STATE(20484), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766219] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29939), 1,
      anon_sym_DASH_GT,
    STATE(20485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766233] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(8996), 1,
      anon_sym_DASH_GT,
    STATE(20486), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766247] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29941), 1,
      anon_sym_LT_DASH,
    STATE(20487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766261] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29925), 1,
      anon_sym_RBRACE,
    STATE(20488), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766275] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29943), 1,
      anon_sym_in,
    STATE(20489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766289] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29945), 1,
      anon_sym_in,
    STATE(20490), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766303] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29947), 1,
      anon_sym_in,
    STATE(20491), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766317] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29949), 1,
      anon_sym_in,
    STATE(20492), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766331] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29951), 1,
      anon_sym_LT_DASH,
    STATE(20493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766345] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29953), 1,
      anon_sym_type,
    STATE(20494), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766359] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29955), 1,
      anon_sym_LT_DASH,
    STATE(20495), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766373] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29957), 1,
      anon_sym_RPAREN,
    STATE(20496), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766387] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29959), 1,
      anon_sym_DOT,
    STATE(20497), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766401] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(23017), 1,
      anon_sym_RBRACK,
    STATE(20498), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766415] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29961), 1,
      anon_sym_in,
    STATE(20499), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766429] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29963), 1,
      anon_sym_PLUS_EQ,
    STATE(20500), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766443] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29965), 1,
      anon_sym_in,
    STATE(20501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766457] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(9014), 1,
      anon_sym_DASH_GT,
    STATE(20502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766471] = 4,
    ACTIONS(1095), 1,
      aux_sym_attribute_token1,
    ACTIONS(29967), 1,
      anon_sym_in,
    STATE(20503), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766485] = 1,
    ACTIONS(29969), 1,
      ts_builtin_sym_end,
  [766489] = 1,
    ACTIONS(29971), 1,
      ts_builtin_sym_end,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(2924)] = 0,
  [SMALL_STATE(2925)] = 75,
  [SMALL_STATE(2926)] = 150,
  [SMALL_STATE(2927)] = 225,
  [SMALL_STATE(2928)] = 300,
  [SMALL_STATE(2929)] = 435,
  [SMALL_STATE(2930)] = 510,
  [SMALL_STATE(2931)] = 585,
  [SMALL_STATE(2932)] = 660,
  [SMALL_STATE(2933)] = 735,
  [SMALL_STATE(2934)] = 810,
  [SMALL_STATE(2935)] = 885,
  [SMALL_STATE(2936)] = 960,
  [SMALL_STATE(2937)] = 1035,
  [SMALL_STATE(2938)] = 1110,
  [SMALL_STATE(2939)] = 1185,
  [SMALL_STATE(2940)] = 1260,
  [SMALL_STATE(2941)] = 1335,
  [SMALL_STATE(2942)] = 1410,
  [SMALL_STATE(2943)] = 1485,
  [SMALL_STATE(2944)] = 1620,
  [SMALL_STATE(2945)] = 1755,
  [SMALL_STATE(2946)] = 1890,
  [SMALL_STATE(2947)] = 2025,
  [SMALL_STATE(2948)] = 2160,
  [SMALL_STATE(2949)] = 2295,
  [SMALL_STATE(2950)] = 2430,
  [SMALL_STATE(2951)] = 2565,
  [SMALL_STATE(2952)] = 2700,
  [SMALL_STATE(2953)] = 2835,
  [SMALL_STATE(2954)] = 2970,
  [SMALL_STATE(2955)] = 3105,
  [SMALL_STATE(2956)] = 3228,
  [SMALL_STATE(2957)] = 3305,
  [SMALL_STATE(2958)] = 3382,
  [SMALL_STATE(2959)] = 3517,
  [SMALL_STATE(2960)] = 3652,
  [SMALL_STATE(2961)] = 3787,
  [SMALL_STATE(2962)] = 3922,
  [SMALL_STATE(2963)] = 3999,
  [SMALL_STATE(2964)] = 4076,
  [SMALL_STATE(2965)] = 4211,
  [SMALL_STATE(2966)] = 4346,
  [SMALL_STATE(2967)] = 4476,
  [SMALL_STATE(2968)] = 4606,
  [SMALL_STATE(2969)] = 4680,
  [SMALL_STATE(2970)] = 4810,
  [SMALL_STATE(2971)] = 4940,
  [SMALL_STATE(2972)] = 5072,
  [SMALL_STATE(2973)] = 5146,
  [SMALL_STATE(2974)] = 5220,
  [SMALL_STATE(2975)] = 5294,
  [SMALL_STATE(2976)] = 5368,
  [SMALL_STATE(2977)] = 5498,
  [SMALL_STATE(2978)] = 5630,
  [SMALL_STATE(2979)] = 5762,
  [SMALL_STATE(2980)] = 5836,
  [SMALL_STATE(2981)] = 5910,
  [SMALL_STATE(2982)] = 5984,
  [SMALL_STATE(2983)] = 6058,
  [SMALL_STATE(2984)] = 6132,
  [SMALL_STATE(2985)] = 6206,
  [SMALL_STATE(2986)] = 6280,
  [SMALL_STATE(2987)] = 6354,
  [SMALL_STATE(2988)] = 6428,
  [SMALL_STATE(2989)] = 6502,
  [SMALL_STATE(2990)] = 6576,
  [SMALL_STATE(2991)] = 6650,
  [SMALL_STATE(2992)] = 6724,
  [SMALL_STATE(2993)] = 6798,
  [SMALL_STATE(2994)] = 6872,
  [SMALL_STATE(2995)] = 7002,
  [SMALL_STATE(2996)] = 7134,
  [SMALL_STATE(2997)] = 7208,
  [SMALL_STATE(2998)] = 7282,
  [SMALL_STATE(2999)] = 7362,
  [SMALL_STATE(3000)] = 7436,
  [SMALL_STATE(3001)] = 7568,
  [SMALL_STATE(3002)] = 7642,
  [SMALL_STATE(3003)] = 7716,
  [SMALL_STATE(3004)] = 7790,
  [SMALL_STATE(3005)] = 7864,
  [SMALL_STATE(3006)] = 7938,
  [SMALL_STATE(3007)] = 8012,
  [SMALL_STATE(3008)] = 8086,
  [SMALL_STATE(3009)] = 8160,
  [SMALL_STATE(3010)] = 8234,
  [SMALL_STATE(3011)] = 8366,
  [SMALL_STATE(3012)] = 8440,
  [SMALL_STATE(3013)] = 8514,
  [SMALL_STATE(3014)] = 8646,
  [SMALL_STATE(3015)] = 8720,
  [SMALL_STATE(3016)] = 8794,
  [SMALL_STATE(3017)] = 8868,
  [SMALL_STATE(3018)] = 8942,
  [SMALL_STATE(3019)] = 9016,
  [SMALL_STATE(3020)] = 9090,
  [SMALL_STATE(3021)] = 9164,
  [SMALL_STATE(3022)] = 9238,
  [SMALL_STATE(3023)] = 9368,
  [SMALL_STATE(3024)] = 9444,
  [SMALL_STATE(3025)] = 9518,
  [SMALL_STATE(3026)] = 9592,
  [SMALL_STATE(3027)] = 9724,
  [SMALL_STATE(3028)] = 9856,
  [SMALL_STATE(3029)] = 9930,
  [SMALL_STATE(3030)] = 10004,
  [SMALL_STATE(3031)] = 10078,
  [SMALL_STATE(3032)] = 10152,
  [SMALL_STATE(3033)] = 10226,
  [SMALL_STATE(3034)] = 10300,
  [SMALL_STATE(3035)] = 10374,
  [SMALL_STATE(3036)] = 10448,
  [SMALL_STATE(3037)] = 10580,
  [SMALL_STATE(3038)] = 10654,
  [SMALL_STATE(3039)] = 10728,
  [SMALL_STATE(3040)] = 10860,
  [SMALL_STATE(3041)] = 10934,
  [SMALL_STATE(3042)] = 11066,
  [SMALL_STATE(3043)] = 11140,
  [SMALL_STATE(3044)] = 11216,
  [SMALL_STATE(3045)] = 11348,
  [SMALL_STATE(3046)] = 11478,
  [SMALL_STATE(3047)] = 11558,
  [SMALL_STATE(3048)] = 11632,
  [SMALL_STATE(3049)] = 11706,
  [SMALL_STATE(3050)] = 11780,
  [SMALL_STATE(3051)] = 11854,
  [SMALL_STATE(3052)] = 11928,
  [SMALL_STATE(3053)] = 12002,
  [SMALL_STATE(3054)] = 12134,
  [SMALL_STATE(3055)] = 12208,
  [SMALL_STATE(3056)] = 12338,
  [SMALL_STATE(3057)] = 12412,
  [SMALL_STATE(3058)] = 12542,
  [SMALL_STATE(3059)] = 12618,
  [SMALL_STATE(3060)] = 12750,
  [SMALL_STATE(3061)] = 12824,
  [SMALL_STATE(3062)] = 12898,
  [SMALL_STATE(3063)] = 12972,
  [SMALL_STATE(3064)] = 13046,
  [SMALL_STATE(3065)] = 13120,
  [SMALL_STATE(3066)] = 13250,
  [SMALL_STATE(3067)] = 13324,
  [SMALL_STATE(3068)] = 13398,
  [SMALL_STATE(3069)] = 13472,
  [SMALL_STATE(3070)] = 13604,
  [SMALL_STATE(3071)] = 13678,
  [SMALL_STATE(3072)] = 13752,
  [SMALL_STATE(3073)] = 13882,
  [SMALL_STATE(3074)] = 13956,
  [SMALL_STATE(3075)] = 14088,
  [SMALL_STATE(3076)] = 14162,
  [SMALL_STATE(3077)] = 14292,
  [SMALL_STATE(3078)] = 14366,
  [SMALL_STATE(3079)] = 14440,
  [SMALL_STATE(3080)] = 14570,
  [SMALL_STATE(3081)] = 14700,
  [SMALL_STATE(3082)] = 14774,
  [SMALL_STATE(3083)] = 14904,
  [SMALL_STATE(3084)] = 15036,
  [SMALL_STATE(3085)] = 15112,
  [SMALL_STATE(3086)] = 15186,
  [SMALL_STATE(3087)] = 15316,
  [SMALL_STATE(3088)] = 15392,
  [SMALL_STATE(3089)] = 15466,
  [SMALL_STATE(3090)] = 15540,
  [SMALL_STATE(3091)] = 15672,
  [SMALL_STATE(3092)] = 15746,
  [SMALL_STATE(3093)] = 15820,
  [SMALL_STATE(3094)] = 15952,
  [SMALL_STATE(3095)] = 16026,
  [SMALL_STATE(3096)] = 16100,
  [SMALL_STATE(3097)] = 16174,
  [SMALL_STATE(3098)] = 16306,
  [SMALL_STATE(3099)] = 16436,
  [SMALL_STATE(3100)] = 16568,
  [SMALL_STATE(3101)] = 16644,
  [SMALL_STATE(3102)] = 16720,
  [SMALL_STATE(3103)] = 16852,
  [SMALL_STATE(3104)] = 16926,
  [SMALL_STATE(3105)] = 17000,
  [SMALL_STATE(3106)] = 17132,
  [SMALL_STATE(3107)] = 17206,
  [SMALL_STATE(3108)] = 17280,
  [SMALL_STATE(3109)] = 17354,
  [SMALL_STATE(3110)] = 17428,
  [SMALL_STATE(3111)] = 17502,
  [SMALL_STATE(3112)] = 17576,
  [SMALL_STATE(3113)] = 17650,
  [SMALL_STATE(3114)] = 17724,
  [SMALL_STATE(3115)] = 17856,
  [SMALL_STATE(3116)] = 17930,
  [SMALL_STATE(3117)] = 18004,
  [SMALL_STATE(3118)] = 18084,
  [SMALL_STATE(3119)] = 18158,
  [SMALL_STATE(3120)] = 18232,
  [SMALL_STATE(3121)] = 18306,
  [SMALL_STATE(3122)] = 18380,
  [SMALL_STATE(3123)] = 18456,
  [SMALL_STATE(3124)] = 18530,
  [SMALL_STATE(3125)] = 18604,
  [SMALL_STATE(3126)] = 18678,
  [SMALL_STATE(3127)] = 18752,
  [SMALL_STATE(3128)] = 18826,
  [SMALL_STATE(3129)] = 18900,
  [SMALL_STATE(3130)] = 18974,
  [SMALL_STATE(3131)] = 19104,
  [SMALL_STATE(3132)] = 19178,
  [SMALL_STATE(3133)] = 19254,
  [SMALL_STATE(3134)] = 19328,
  [SMALL_STATE(3135)] = 19460,
  [SMALL_STATE(3136)] = 19534,
  [SMALL_STATE(3137)] = 19608,
  [SMALL_STATE(3138)] = 19682,
  [SMALL_STATE(3139)] = 19756,
  [SMALL_STATE(3140)] = 19888,
  [SMALL_STATE(3141)] = 19962,
  [SMALL_STATE(3142)] = 20094,
  [SMALL_STATE(3143)] = 20168,
  [SMALL_STATE(3144)] = 20242,
  [SMALL_STATE(3145)] = 20316,
  [SMALL_STATE(3146)] = 20448,
  [SMALL_STATE(3147)] = 20522,
  [SMALL_STATE(3148)] = 20596,
  [SMALL_STATE(3149)] = 20670,
  [SMALL_STATE(3150)] = 20744,
  [SMALL_STATE(3151)] = 20874,
  [SMALL_STATE(3152)] = 20948,
  [SMALL_STATE(3153)] = 21022,
  [SMALL_STATE(3154)] = 21096,
  [SMALL_STATE(3155)] = 21170,
  [SMALL_STATE(3156)] = 21300,
  [SMALL_STATE(3157)] = 21374,
  [SMALL_STATE(3158)] = 21448,
  [SMALL_STATE(3159)] = 21524,
  [SMALL_STATE(3160)] = 21598,
  [SMALL_STATE(3161)] = 21672,
  [SMALL_STATE(3162)] = 21746,
  [SMALL_STATE(3163)] = 21820,
  [SMALL_STATE(3164)] = 21894,
  [SMALL_STATE(3165)] = 21968,
  [SMALL_STATE(3166)] = 22042,
  [SMALL_STATE(3167)] = 22116,
  [SMALL_STATE(3168)] = 22196,
  [SMALL_STATE(3169)] = 22270,
  [SMALL_STATE(3170)] = 22344,
  [SMALL_STATE(3171)] = 22418,
  [SMALL_STATE(3172)] = 22492,
  [SMALL_STATE(3173)] = 22566,
  [SMALL_STATE(3174)] = 22640,
  [SMALL_STATE(3175)] = 22714,
  [SMALL_STATE(3176)] = 22788,
  [SMALL_STATE(3177)] = 22862,
  [SMALL_STATE(3178)] = 22936,
  [SMALL_STATE(3179)] = 23010,
  [SMALL_STATE(3180)] = 23142,
  [SMALL_STATE(3181)] = 23274,
  [SMALL_STATE(3182)] = 23406,
  [SMALL_STATE(3183)] = 23482,
  [SMALL_STATE(3184)] = 23556,
  [SMALL_STATE(3185)] = 23688,
  [SMALL_STATE(3186)] = 23762,
  [SMALL_STATE(3187)] = 23836,
  [SMALL_STATE(3188)] = 23968,
  [SMALL_STATE(3189)] = 24042,
  [SMALL_STATE(3190)] = 24116,
  [SMALL_STATE(3191)] = 24190,
  [SMALL_STATE(3192)] = 24322,
  [SMALL_STATE(3193)] = 24396,
  [SMALL_STATE(3194)] = 24470,
  [SMALL_STATE(3195)] = 24544,
  [SMALL_STATE(3196)] = 24620,
  [SMALL_STATE(3197)] = 24694,
  [SMALL_STATE(3198)] = 24768,
  [SMALL_STATE(3199)] = 24842,
  [SMALL_STATE(3200)] = 24974,
  [SMALL_STATE(3201)] = 25106,
  [SMALL_STATE(3202)] = 25180,
  [SMALL_STATE(3203)] = 25310,
  [SMALL_STATE(3204)] = 25440,
  [SMALL_STATE(3205)] = 25570,
  [SMALL_STATE(3206)] = 25644,
  [SMALL_STATE(3207)] = 25718,
  [SMALL_STATE(3208)] = 25792,
  [SMALL_STATE(3209)] = 25866,
  [SMALL_STATE(3210)] = 25998,
  [SMALL_STATE(3211)] = 26072,
  [SMALL_STATE(3212)] = 26146,
  [SMALL_STATE(3213)] = 26220,
  [SMALL_STATE(3214)] = 26294,
  [SMALL_STATE(3215)] = 26426,
  [SMALL_STATE(3216)] = 26558,
  [SMALL_STATE(3217)] = 26690,
  [SMALL_STATE(3218)] = 26822,
  [SMALL_STATE(3219)] = 26954,
  [SMALL_STATE(3220)] = 27084,
  [SMALL_STATE(3221)] = 27214,
  [SMALL_STATE(3222)] = 27346,
  [SMALL_STATE(3223)] = 27478,
  [SMALL_STATE(3224)] = 27610,
  [SMALL_STATE(3225)] = 27742,
  [SMALL_STATE(3226)] = 27874,
  [SMALL_STATE(3227)] = 28004,
  [SMALL_STATE(3228)] = 28136,
  [SMALL_STATE(3229)] = 28266,
  [SMALL_STATE(3230)] = 28398,
  [SMALL_STATE(3231)] = 28530,
  [SMALL_STATE(3232)] = 28660,
  [SMALL_STATE(3233)] = 28792,
  [SMALL_STATE(3234)] = 28924,
  [SMALL_STATE(3235)] = 29056,
  [SMALL_STATE(3236)] = 29186,
  [SMALL_STATE(3237)] = 29318,
  [SMALL_STATE(3238)] = 29450,
  [SMALL_STATE(3239)] = 29580,
  [SMALL_STATE(3240)] = 29712,
  [SMALL_STATE(3241)] = 29844,
  [SMALL_STATE(3242)] = 29976,
  [SMALL_STATE(3243)] = 30052,
  [SMALL_STATE(3244)] = 30128,
  [SMALL_STATE(3245)] = 30258,
  [SMALL_STATE(3246)] = 30390,
  [SMALL_STATE(3247)] = 30522,
  [SMALL_STATE(3248)] = 30654,
  [SMALL_STATE(3249)] = 30784,
  [SMALL_STATE(3250)] = 30914,
  [SMALL_STATE(3251)] = 31046,
  [SMALL_STATE(3252)] = 31178,
  [SMALL_STATE(3253)] = 31310,
  [SMALL_STATE(3254)] = 31442,
  [SMALL_STATE(3255)] = 31572,
  [SMALL_STATE(3256)] = 31704,
  [SMALL_STATE(3257)] = 31834,
  [SMALL_STATE(3258)] = 31966,
  [SMALL_STATE(3259)] = 32098,
  [SMALL_STATE(3260)] = 32230,
  [SMALL_STATE(3261)] = 32362,
  [SMALL_STATE(3262)] = 32494,
  [SMALL_STATE(3263)] = 32626,
  [SMALL_STATE(3264)] = 32758,
  [SMALL_STATE(3265)] = 32888,
  [SMALL_STATE(3266)] = 33020,
  [SMALL_STATE(3267)] = 33152,
  [SMALL_STATE(3268)] = 33284,
  [SMALL_STATE(3269)] = 33416,
  [SMALL_STATE(3270)] = 33548,
  [SMALL_STATE(3271)] = 33680,
  [SMALL_STATE(3272)] = 33812,
  [SMALL_STATE(3273)] = 33942,
  [SMALL_STATE(3274)] = 34074,
  [SMALL_STATE(3275)] = 34206,
  [SMALL_STATE(3276)] = 34336,
  [SMALL_STATE(3277)] = 34466,
  [SMALL_STATE(3278)] = 34598,
  [SMALL_STATE(3279)] = 34730,
  [SMALL_STATE(3280)] = 34862,
  [SMALL_STATE(3281)] = 34994,
  [SMALL_STATE(3282)] = 35126,
  [SMALL_STATE(3283)] = 35258,
  [SMALL_STATE(3284)] = 35390,
  [SMALL_STATE(3285)] = 35522,
  [SMALL_STATE(3286)] = 35654,
  [SMALL_STATE(3287)] = 35786,
  [SMALL_STATE(3288)] = 35918,
  [SMALL_STATE(3289)] = 36050,
  [SMALL_STATE(3290)] = 36182,
  [SMALL_STATE(3291)] = 36312,
  [SMALL_STATE(3292)] = 36444,
  [SMALL_STATE(3293)] = 36576,
  [SMALL_STATE(3294)] = 36708,
  [SMALL_STATE(3295)] = 36840,
  [SMALL_STATE(3296)] = 36970,
  [SMALL_STATE(3297)] = 37102,
  [SMALL_STATE(3298)] = 37234,
  [SMALL_STATE(3299)] = 37366,
  [SMALL_STATE(3300)] = 37498,
  [SMALL_STATE(3301)] = 37630,
  [SMALL_STATE(3302)] = 37762,
  [SMALL_STATE(3303)] = 37894,
  [SMALL_STATE(3304)] = 38026,
  [SMALL_STATE(3305)] = 38156,
  [SMALL_STATE(3306)] = 38286,
  [SMALL_STATE(3307)] = 38418,
  [SMALL_STATE(3308)] = 38550,
  [SMALL_STATE(3309)] = 38682,
  [SMALL_STATE(3310)] = 38814,
  [SMALL_STATE(3311)] = 38946,
  [SMALL_STATE(3312)] = 39078,
  [SMALL_STATE(3313)] = 39210,
  [SMALL_STATE(3314)] = 39339,
  [SMALL_STATE(3315)] = 39468,
  [SMALL_STATE(3316)] = 39541,
  [SMALL_STATE(3317)] = 39614,
  [SMALL_STATE(3318)] = 39687,
  [SMALL_STATE(3319)] = 39760,
  [SMALL_STATE(3320)] = 39889,
  [SMALL_STATE(3321)] = 39964,
  [SMALL_STATE(3322)] = 40093,
  [SMALL_STATE(3323)] = 40222,
  [SMALL_STATE(3324)] = 40351,
  [SMALL_STATE(3325)] = 40430,
  [SMALL_STATE(3326)] = 40505,
  [SMALL_STATE(3327)] = 40634,
  [SMALL_STATE(3328)] = 40763,
  [SMALL_STATE(3329)] = 40892,
  [SMALL_STATE(3330)] = 40965,
  [SMALL_STATE(3331)] = 41094,
  [SMALL_STATE(3332)] = 41167,
  [SMALL_STATE(3333)] = 41240,
  [SMALL_STATE(3334)] = 41369,
  [SMALL_STATE(3335)] = 41448,
  [SMALL_STATE(3336)] = 41589,
  [SMALL_STATE(3337)] = 41718,
  [SMALL_STATE(3338)] = 41791,
  [SMALL_STATE(3339)] = 41920,
  [SMALL_STATE(3340)] = 41993,
  [SMALL_STATE(3341)] = 42066,
  [SMALL_STATE(3342)] = 42145,
  [SMALL_STATE(3343)] = 42274,
  [SMALL_STATE(3344)] = 42403,
  [SMALL_STATE(3345)] = 42476,
  [SMALL_STATE(3346)] = 42549,
  [SMALL_STATE(3347)] = 42622,
  [SMALL_STATE(3348)] = 42695,
  [SMALL_STATE(3349)] = 42768,
  [SMALL_STATE(3350)] = 42841,
  [SMALL_STATE(3351)] = 42914,
  [SMALL_STATE(3352)] = 42987,
  [SMALL_STATE(3353)] = 43060,
  [SMALL_STATE(3354)] = 43133,
  [SMALL_STATE(3355)] = 43206,
  [SMALL_STATE(3356)] = 43279,
  [SMALL_STATE(3357)] = 43352,
  [SMALL_STATE(3358)] = 43425,
  [SMALL_STATE(3359)] = 43498,
  [SMALL_STATE(3360)] = 43627,
  [SMALL_STATE(3361)] = 43700,
  [SMALL_STATE(3362)] = 43773,
  [SMALL_STATE(3363)] = 43902,
  [SMALL_STATE(3364)] = 43975,
  [SMALL_STATE(3365)] = 44048,
  [SMALL_STATE(3366)] = 44121,
  [SMALL_STATE(3367)] = 44194,
  [SMALL_STATE(3368)] = 44267,
  [SMALL_STATE(3369)] = 44340,
  [SMALL_STATE(3370)] = 44413,
  [SMALL_STATE(3371)] = 44486,
  [SMALL_STATE(3372)] = 44559,
  [SMALL_STATE(3373)] = 44632,
  [SMALL_STATE(3374)] = 44705,
  [SMALL_STATE(3375)] = 44778,
  [SMALL_STATE(3376)] = 44851,
  [SMALL_STATE(3377)] = 44924,
  [SMALL_STATE(3378)] = 44997,
  [SMALL_STATE(3379)] = 45070,
  [SMALL_STATE(3380)] = 45143,
  [SMALL_STATE(3381)] = 45216,
  [SMALL_STATE(3382)] = 45289,
  [SMALL_STATE(3383)] = 45362,
  [SMALL_STATE(3384)] = 45435,
  [SMALL_STATE(3385)] = 45508,
  [SMALL_STATE(3386)] = 45581,
  [SMALL_STATE(3387)] = 45654,
  [SMALL_STATE(3388)] = 45783,
  [SMALL_STATE(3389)] = 45858,
  [SMALL_STATE(3390)] = 45931,
  [SMALL_STATE(3391)] = 46004,
  [SMALL_STATE(3392)] = 46133,
  [SMALL_STATE(3393)] = 46208,
  [SMALL_STATE(3394)] = 46281,
  [SMALL_STATE(3395)] = 46410,
  [SMALL_STATE(3396)] = 46483,
  [SMALL_STATE(3397)] = 46558,
  [SMALL_STATE(3398)] = 46631,
  [SMALL_STATE(3399)] = 46704,
  [SMALL_STATE(3400)] = 46779,
  [SMALL_STATE(3401)] = 46852,
  [SMALL_STATE(3402)] = 46925,
  [SMALL_STATE(3403)] = 47054,
  [SMALL_STATE(3404)] = 47127,
  [SMALL_STATE(3405)] = 47200,
  [SMALL_STATE(3406)] = 47273,
  [SMALL_STATE(3407)] = 47346,
  [SMALL_STATE(3408)] = 47419,
  [SMALL_STATE(3409)] = 47492,
  [SMALL_STATE(3410)] = 47621,
  [SMALL_STATE(3411)] = 47694,
  [SMALL_STATE(3412)] = 47767,
  [SMALL_STATE(3413)] = 47840,
  [SMALL_STATE(3414)] = 47913,
  [SMALL_STATE(3415)] = 48042,
  [SMALL_STATE(3416)] = 48171,
  [SMALL_STATE(3417)] = 48244,
  [SMALL_STATE(3418)] = 48373,
  [SMALL_STATE(3419)] = 48446,
  [SMALL_STATE(3420)] = 48519,
  [SMALL_STATE(3421)] = 48648,
  [SMALL_STATE(3422)] = 48723,
  [SMALL_STATE(3423)] = 48852,
  [SMALL_STATE(3424)] = 48981,
  [SMALL_STATE(3425)] = 49054,
  [SMALL_STATE(3426)] = 49183,
  [SMALL_STATE(3427)] = 49312,
  [SMALL_STATE(3428)] = 49391,
  [SMALL_STATE(3429)] = 49464,
  [SMALL_STATE(3430)] = 49537,
  [SMALL_STATE(3431)] = 49666,
  [SMALL_STATE(3432)] = 49741,
  [SMALL_STATE(3433)] = 49814,
  [SMALL_STATE(3434)] = 49955,
  [SMALL_STATE(3435)] = 50028,
  [SMALL_STATE(3436)] = 50101,
  [SMALL_STATE(3437)] = 50174,
  [SMALL_STATE(3438)] = 50247,
  [SMALL_STATE(3439)] = 50376,
  [SMALL_STATE(3440)] = 50449,
  [SMALL_STATE(3441)] = 50522,
  [SMALL_STATE(3442)] = 50651,
  [SMALL_STATE(3443)] = 50780,
  [SMALL_STATE(3444)] = 50853,
  [SMALL_STATE(3445)] = 50926,
  [SMALL_STATE(3446)] = 51055,
  [SMALL_STATE(3447)] = 51128,
  [SMALL_STATE(3448)] = 51201,
  [SMALL_STATE(3449)] = 51274,
  [SMALL_STATE(3450)] = 51347,
  [SMALL_STATE(3451)] = 51420,
  [SMALL_STATE(3452)] = 51493,
  [SMALL_STATE(3453)] = 51566,
  [SMALL_STATE(3454)] = 51695,
  [SMALL_STATE(3455)] = 51768,
  [SMALL_STATE(3456)] = 51843,
  [SMALL_STATE(3457)] = 51916,
  [SMALL_STATE(3458)] = 51989,
  [SMALL_STATE(3459)] = 52062,
  [SMALL_STATE(3460)] = 52135,
  [SMALL_STATE(3461)] = 52208,
  [SMALL_STATE(3462)] = 52281,
  [SMALL_STATE(3463)] = 52410,
  [SMALL_STATE(3464)] = 52483,
  [SMALL_STATE(3465)] = 52556,
  [SMALL_STATE(3466)] = 52629,
  [SMALL_STATE(3467)] = 52758,
  [SMALL_STATE(3468)] = 52831,
  [SMALL_STATE(3469)] = 52904,
  [SMALL_STATE(3470)] = 52977,
  [SMALL_STATE(3471)] = 53052,
  [SMALL_STATE(3472)] = 53125,
  [SMALL_STATE(3473)] = 53198,
  [SMALL_STATE(3474)] = 53271,
  [SMALL_STATE(3475)] = 53344,
  [SMALL_STATE(3476)] = 53417,
  [SMALL_STATE(3477)] = 53490,
  [SMALL_STATE(3478)] = 53619,
  [SMALL_STATE(3479)] = 53692,
  [SMALL_STATE(3480)] = 53765,
  [SMALL_STATE(3481)] = 53838,
  [SMALL_STATE(3482)] = 53911,
  [SMALL_STATE(3483)] = 54040,
  [SMALL_STATE(3484)] = 54113,
  [SMALL_STATE(3485)] = 54186,
  [SMALL_STATE(3486)] = 54259,
  [SMALL_STATE(3487)] = 54332,
  [SMALL_STATE(3488)] = 54405,
  [SMALL_STATE(3489)] = 54480,
  [SMALL_STATE(3490)] = 54553,
  [SMALL_STATE(3491)] = 54626,
  [SMALL_STATE(3492)] = 54699,
  [SMALL_STATE(3493)] = 54772,
  [SMALL_STATE(3494)] = 54845,
  [SMALL_STATE(3495)] = 54918,
  [SMALL_STATE(3496)] = 54991,
  [SMALL_STATE(3497)] = 55120,
  [SMALL_STATE(3498)] = 55193,
  [SMALL_STATE(3499)] = 55266,
  [SMALL_STATE(3500)] = 55395,
  [SMALL_STATE(3501)] = 55524,
  [SMALL_STATE(3502)] = 55597,
  [SMALL_STATE(3503)] = 55670,
  [SMALL_STATE(3504)] = 55743,
  [SMALL_STATE(3505)] = 55816,
  [SMALL_STATE(3506)] = 55945,
  [SMALL_STATE(3507)] = 56018,
  [SMALL_STATE(3508)] = 56091,
  [SMALL_STATE(3509)] = 56220,
  [SMALL_STATE(3510)] = 56293,
  [SMALL_STATE(3511)] = 56422,
  [SMALL_STATE(3512)] = 56551,
  [SMALL_STATE(3513)] = 56624,
  [SMALL_STATE(3514)] = 56697,
  [SMALL_STATE(3515)] = 56770,
  [SMALL_STATE(3516)] = 56843,
  [SMALL_STATE(3517)] = 56916,
  [SMALL_STATE(3518)] = 56989,
  [SMALL_STATE(3519)] = 57062,
  [SMALL_STATE(3520)] = 57135,
  [SMALL_STATE(3521)] = 57208,
  [SMALL_STATE(3522)] = 57337,
  [SMALL_STATE(3523)] = 57410,
  [SMALL_STATE(3524)] = 57483,
  [SMALL_STATE(3525)] = 57612,
  [SMALL_STATE(3526)] = 57741,
  [SMALL_STATE(3527)] = 57814,
  [SMALL_STATE(3528)] = 57887,
  [SMALL_STATE(3529)] = 57960,
  [SMALL_STATE(3530)] = 58089,
  [SMALL_STATE(3531)] = 58218,
  [SMALL_STATE(3532)] = 58347,
  [SMALL_STATE(3533)] = 58420,
  [SMALL_STATE(3534)] = 58549,
  [SMALL_STATE(3535)] = 58678,
  [SMALL_STATE(3536)] = 58751,
  [SMALL_STATE(3537)] = 58824,
  [SMALL_STATE(3538)] = 58953,
  [SMALL_STATE(3539)] = 59026,
  [SMALL_STATE(3540)] = 59099,
  [SMALL_STATE(3541)] = 59172,
  [SMALL_STATE(3542)] = 59247,
  [SMALL_STATE(3543)] = 59320,
  [SMALL_STATE(3544)] = 59393,
  [SMALL_STATE(3545)] = 59466,
  [SMALL_STATE(3546)] = 59595,
  [SMALL_STATE(3547)] = 59724,
  [SMALL_STATE(3548)] = 59797,
  [SMALL_STATE(3549)] = 59870,
  [SMALL_STATE(3550)] = 59943,
  [SMALL_STATE(3551)] = 60072,
  [SMALL_STATE(3552)] = 60145,
  [SMALL_STATE(3553)] = 60274,
  [SMALL_STATE(3554)] = 60403,
  [SMALL_STATE(3555)] = 60476,
  [SMALL_STATE(3556)] = 60549,
  [SMALL_STATE(3557)] = 60622,
  [SMALL_STATE(3558)] = 60695,
  [SMALL_STATE(3559)] = 60768,
  [SMALL_STATE(3560)] = 60899,
  [SMALL_STATE(3561)] = 60972,
  [SMALL_STATE(3562)] = 61103,
  [SMALL_STATE(3563)] = 61232,
  [SMALL_STATE(3564)] = 61305,
  [SMALL_STATE(3565)] = 61378,
  [SMALL_STATE(3566)] = 61451,
  [SMALL_STATE(3567)] = 61580,
  [SMALL_STATE(3568)] = 61653,
  [SMALL_STATE(3569)] = 61782,
  [SMALL_STATE(3570)] = 61923,
  [SMALL_STATE(3571)] = 62064,
  [SMALL_STATE(3572)] = 62137,
  [SMALL_STATE(3573)] = 62266,
  [SMALL_STATE(3574)] = 62339,
  [SMALL_STATE(3575)] = 62468,
  [SMALL_STATE(3576)] = 62541,
  [SMALL_STATE(3577)] = 62614,
  [SMALL_STATE(3578)] = 62755,
  [SMALL_STATE(3579)] = 62828,
  [SMALL_STATE(3580)] = 62901,
  [SMALL_STATE(3581)] = 63030,
  [SMALL_STATE(3582)] = 63159,
  [SMALL_STATE(3583)] = 63232,
  [SMALL_STATE(3584)] = 63305,
  [SMALL_STATE(3585)] = 63378,
  [SMALL_STATE(3586)] = 63507,
  [SMALL_STATE(3587)] = 63636,
  [SMALL_STATE(3588)] = 63765,
  [SMALL_STATE(3589)] = 63838,
  [SMALL_STATE(3590)] = 63911,
  [SMALL_STATE(3591)] = 63984,
  [SMALL_STATE(3592)] = 64113,
  [SMALL_STATE(3593)] = 64242,
  [SMALL_STATE(3594)] = 64315,
  [SMALL_STATE(3595)] = 64388,
  [SMALL_STATE(3596)] = 64461,
  [SMALL_STATE(3597)] = 64590,
  [SMALL_STATE(3598)] = 64663,
  [SMALL_STATE(3599)] = 64736,
  [SMALL_STATE(3600)] = 64809,
  [SMALL_STATE(3601)] = 64882,
  [SMALL_STATE(3602)] = 64955,
  [SMALL_STATE(3603)] = 65028,
  [SMALL_STATE(3604)] = 65101,
  [SMALL_STATE(3605)] = 65180,
  [SMALL_STATE(3606)] = 65259,
  [SMALL_STATE(3607)] = 65332,
  [SMALL_STATE(3608)] = 65405,
  [SMALL_STATE(3609)] = 65478,
  [SMALL_STATE(3610)] = 65551,
  [SMALL_STATE(3611)] = 65624,
  [SMALL_STATE(3612)] = 65697,
  [SMALL_STATE(3613)] = 65770,
  [SMALL_STATE(3614)] = 65899,
  [SMALL_STATE(3615)] = 65972,
  [SMALL_STATE(3616)] = 66045,
  [SMALL_STATE(3617)] = 66174,
  [SMALL_STATE(3618)] = 66303,
  [SMALL_STATE(3619)] = 66376,
  [SMALL_STATE(3620)] = 66449,
  [SMALL_STATE(3621)] = 66578,
  [SMALL_STATE(3622)] = 66707,
  [SMALL_STATE(3623)] = 66836,
  [SMALL_STATE(3624)] = 66965,
  [SMALL_STATE(3625)] = 67096,
  [SMALL_STATE(3626)] = 67227,
  [SMALL_STATE(3627)] = 67300,
  [SMALL_STATE(3628)] = 67429,
  [SMALL_STATE(3629)] = 67502,
  [SMALL_STATE(3630)] = 67575,
  [SMALL_STATE(3631)] = 67648,
  [SMALL_STATE(3632)] = 67777,
  [SMALL_STATE(3633)] = 67850,
  [SMALL_STATE(3634)] = 67923,
  [SMALL_STATE(3635)] = 67996,
  [SMALL_STATE(3636)] = 68069,
  [SMALL_STATE(3637)] = 68142,
  [SMALL_STATE(3638)] = 68215,
  [SMALL_STATE(3639)] = 68290,
  [SMALL_STATE(3640)] = 68365,
  [SMALL_STATE(3641)] = 68438,
  [SMALL_STATE(3642)] = 68567,
  [SMALL_STATE(3643)] = 68640,
  [SMALL_STATE(3644)] = 68713,
  [SMALL_STATE(3645)] = 68842,
  [SMALL_STATE(3646)] = 68915,
  [SMALL_STATE(3647)] = 69044,
  [SMALL_STATE(3648)] = 69117,
  [SMALL_STATE(3649)] = 69190,
  [SMALL_STATE(3650)] = 69263,
  [SMALL_STATE(3651)] = 69336,
  [SMALL_STATE(3652)] = 69409,
  [SMALL_STATE(3653)] = 69482,
  [SMALL_STATE(3654)] = 69555,
  [SMALL_STATE(3655)] = 69684,
  [SMALL_STATE(3656)] = 69757,
  [SMALL_STATE(3657)] = 69830,
  [SMALL_STATE(3658)] = 69903,
  [SMALL_STATE(3659)] = 69976,
  [SMALL_STATE(3660)] = 70049,
  [SMALL_STATE(3661)] = 70122,
  [SMALL_STATE(3662)] = 70195,
  [SMALL_STATE(3663)] = 70268,
  [SMALL_STATE(3664)] = 70341,
  [SMALL_STATE(3665)] = 70414,
  [SMALL_STATE(3666)] = 70543,
  [SMALL_STATE(3667)] = 70672,
  [SMALL_STATE(3668)] = 70745,
  [SMALL_STATE(3669)] = 70818,
  [SMALL_STATE(3670)] = 70891,
  [SMALL_STATE(3671)] = 71020,
  [SMALL_STATE(3672)] = 71149,
  [SMALL_STATE(3673)] = 71222,
  [SMALL_STATE(3674)] = 71297,
  [SMALL_STATE(3675)] = 71370,
  [SMALL_STATE(3676)] = 71449,
  [SMALL_STATE(3677)] = 71522,
  [SMALL_STATE(3678)] = 71595,
  [SMALL_STATE(3679)] = 71724,
  [SMALL_STATE(3680)] = 71797,
  [SMALL_STATE(3681)] = 71870,
  [SMALL_STATE(3682)] = 71999,
  [SMALL_STATE(3683)] = 72072,
  [SMALL_STATE(3684)] = 72145,
  [SMALL_STATE(3685)] = 72274,
  [SMALL_STATE(3686)] = 72415,
  [SMALL_STATE(3687)] = 72544,
  [SMALL_STATE(3688)] = 72673,
  [SMALL_STATE(3689)] = 72746,
  [SMALL_STATE(3690)] = 72819,
  [SMALL_STATE(3691)] = 72892,
  [SMALL_STATE(3692)] = 72965,
  [SMALL_STATE(3693)] = 73038,
  [SMALL_STATE(3694)] = 73167,
  [SMALL_STATE(3695)] = 73240,
  [SMALL_STATE(3696)] = 73315,
  [SMALL_STATE(3697)] = 73388,
  [SMALL_STATE(3698)] = 73461,
  [SMALL_STATE(3699)] = 73534,
  [SMALL_STATE(3700)] = 73663,
  [SMALL_STATE(3701)] = 73736,
  [SMALL_STATE(3702)] = 73865,
  [SMALL_STATE(3703)] = 73994,
  [SMALL_STATE(3704)] = 74123,
  [SMALL_STATE(3705)] = 74196,
  [SMALL_STATE(3706)] = 74269,
  [SMALL_STATE(3707)] = 74342,
  [SMALL_STATE(3708)] = 74471,
  [SMALL_STATE(3709)] = 74544,
  [SMALL_STATE(3710)] = 74617,
  [SMALL_STATE(3711)] = 74758,
  [SMALL_STATE(3712)] = 74887,
  [SMALL_STATE(3713)] = 75016,
  [SMALL_STATE(3714)] = 75145,
  [SMALL_STATE(3715)] = 75218,
  [SMALL_STATE(3716)] = 75291,
  [SMALL_STATE(3717)] = 75364,
  [SMALL_STATE(3718)] = 75493,
  [SMALL_STATE(3719)] = 75566,
  [SMALL_STATE(3720)] = 75695,
  [SMALL_STATE(3721)] = 75824,
  [SMALL_STATE(3722)] = 75897,
  [SMALL_STATE(3723)] = 75970,
  [SMALL_STATE(3724)] = 76043,
  [SMALL_STATE(3725)] = 76116,
  [SMALL_STATE(3726)] = 76189,
  [SMALL_STATE(3727)] = 76262,
  [SMALL_STATE(3728)] = 76335,
  [SMALL_STATE(3729)] = 76408,
  [SMALL_STATE(3730)] = 76481,
  [SMALL_STATE(3731)] = 76554,
  [SMALL_STATE(3732)] = 76627,
  [SMALL_STATE(3733)] = 76700,
  [SMALL_STATE(3734)] = 76773,
  [SMALL_STATE(3735)] = 76902,
  [SMALL_STATE(3736)] = 77031,
  [SMALL_STATE(3737)] = 77104,
  [SMALL_STATE(3738)] = 77177,
  [SMALL_STATE(3739)] = 77306,
  [SMALL_STATE(3740)] = 77435,
  [SMALL_STATE(3741)] = 77508,
  [SMALL_STATE(3742)] = 77581,
  [SMALL_STATE(3743)] = 77654,
  [SMALL_STATE(3744)] = 77727,
  [SMALL_STATE(3745)] = 77856,
  [SMALL_STATE(3746)] = 77935,
  [SMALL_STATE(3747)] = 78008,
  [SMALL_STATE(3748)] = 78137,
  [SMALL_STATE(3749)] = 78266,
  [SMALL_STATE(3750)] = 78338,
  [SMALL_STATE(3751)] = 78410,
  [SMALL_STATE(3752)] = 78482,
  [SMALL_STATE(3753)] = 78554,
  [SMALL_STATE(3754)] = 78626,
  [SMALL_STATE(3755)] = 78698,
  [SMALL_STATE(3756)] = 78770,
  [SMALL_STATE(3757)] = 78894,
  [SMALL_STATE(3758)] = 78966,
  [SMALL_STATE(3759)] = 79038,
  [SMALL_STATE(3760)] = 79110,
  [SMALL_STATE(3761)] = 79182,
  [SMALL_STATE(3762)] = 79306,
  [SMALL_STATE(3763)] = 79378,
  [SMALL_STATE(3764)] = 79450,
  [SMALL_STATE(3765)] = 79522,
  [SMALL_STATE(3766)] = 79594,
  [SMALL_STATE(3767)] = 79718,
  [SMALL_STATE(3768)] = 79790,
  [SMALL_STATE(3769)] = 79864,
  [SMALL_STATE(3770)] = 79936,
  [SMALL_STATE(3771)] = 80060,
  [SMALL_STATE(3772)] = 80184,
  [SMALL_STATE(3773)] = 80256,
  [SMALL_STATE(3774)] = 80328,
  [SMALL_STATE(3775)] = 80400,
  [SMALL_STATE(3776)] = 80472,
  [SMALL_STATE(3777)] = 80544,
  [SMALL_STATE(3778)] = 80616,
  [SMALL_STATE(3779)] = 80688,
  [SMALL_STATE(3780)] = 80762,
  [SMALL_STATE(3781)] = 80834,
  [SMALL_STATE(3782)] = 80906,
  [SMALL_STATE(3783)] = 80978,
  [SMALL_STATE(3784)] = 81050,
  [SMALL_STATE(3785)] = 81122,
  [SMALL_STATE(3786)] = 81194,
  [SMALL_STATE(3787)] = 81266,
  [SMALL_STATE(3788)] = 81338,
  [SMALL_STATE(3789)] = 81410,
  [SMALL_STATE(3790)] = 81482,
  [SMALL_STATE(3791)] = 81606,
  [SMALL_STATE(3792)] = 81678,
  [SMALL_STATE(3793)] = 81802,
  [SMALL_STATE(3794)] = 81926,
  [SMALL_STATE(3795)] = 82050,
  [SMALL_STATE(3796)] = 82174,
  [SMALL_STATE(3797)] = 82246,
  [SMALL_STATE(3798)] = 82324,
  [SMALL_STATE(3799)] = 82396,
  [SMALL_STATE(3800)] = 82468,
  [SMALL_STATE(3801)] = 82592,
  [SMALL_STATE(3802)] = 82664,
  [SMALL_STATE(3803)] = 82788,
  [SMALL_STATE(3804)] = 82912,
  [SMALL_STATE(3805)] = 82984,
  [SMALL_STATE(3806)] = 83056,
  [SMALL_STATE(3807)] = 83128,
  [SMALL_STATE(3808)] = 83252,
  [SMALL_STATE(3809)] = 83324,
  [SMALL_STATE(3810)] = 83448,
  [SMALL_STATE(3811)] = 83520,
  [SMALL_STATE(3812)] = 83644,
  [SMALL_STATE(3813)] = 83716,
  [SMALL_STATE(3814)] = 83840,
  [SMALL_STATE(3815)] = 83964,
  [SMALL_STATE(3816)] = 84036,
  [SMALL_STATE(3817)] = 84160,
  [SMALL_STATE(3818)] = 84232,
  [SMALL_STATE(3819)] = 84356,
  [SMALL_STATE(3820)] = 84428,
  [SMALL_STATE(3821)] = 84500,
  [SMALL_STATE(3822)] = 84572,
  [SMALL_STATE(3823)] = 84644,
  [SMALL_STATE(3824)] = 84716,
  [SMALL_STATE(3825)] = 84788,
  [SMALL_STATE(3826)] = 84860,
  [SMALL_STATE(3827)] = 84932,
  [SMALL_STATE(3828)] = 85006,
  [SMALL_STATE(3829)] = 85078,
  [SMALL_STATE(3830)] = 85150,
  [SMALL_STATE(3831)] = 85222,
  [SMALL_STATE(3832)] = 85346,
  [SMALL_STATE(3833)] = 85418,
  [SMALL_STATE(3834)] = 85490,
  [SMALL_STATE(3835)] = 85562,
  [SMALL_STATE(3836)] = 85686,
  [SMALL_STATE(3837)] = 85810,
  [SMALL_STATE(3838)] = 85934,
  [SMALL_STATE(3839)] = 86006,
  [SMALL_STATE(3840)] = 86078,
  [SMALL_STATE(3841)] = 86150,
  [SMALL_STATE(3842)] = 86222,
  [SMALL_STATE(3843)] = 86294,
  [SMALL_STATE(3844)] = 86368,
  [SMALL_STATE(3845)] = 86492,
  [SMALL_STATE(3846)] = 86566,
  [SMALL_STATE(3847)] = 86638,
  [SMALL_STATE(3848)] = 86710,
  [SMALL_STATE(3849)] = 86834,
  [SMALL_STATE(3850)] = 86906,
  [SMALL_STATE(3851)] = 87030,
  [SMALL_STATE(3852)] = 87154,
  [SMALL_STATE(3853)] = 87278,
  [SMALL_STATE(3854)] = 87402,
  [SMALL_STATE(3855)] = 87476,
  [SMALL_STATE(3856)] = 87550,
  [SMALL_STATE(3857)] = 87622,
  [SMALL_STATE(3858)] = 87694,
  [SMALL_STATE(3859)] = 87766,
  [SMALL_STATE(3860)] = 87844,
  [SMALL_STATE(3861)] = 87968,
  [SMALL_STATE(3862)] = 88040,
  [SMALL_STATE(3863)] = 88112,
  [SMALL_STATE(3864)] = 88184,
  [SMALL_STATE(3865)] = 88256,
  [SMALL_STATE(3866)] = 88328,
  [SMALL_STATE(3867)] = 88400,
  [SMALL_STATE(3868)] = 88472,
  [SMALL_STATE(3869)] = 88544,
  [SMALL_STATE(3870)] = 88668,
  [SMALL_STATE(3871)] = 88740,
  [SMALL_STATE(3872)] = 88812,
  [SMALL_STATE(3873)] = 88884,
  [SMALL_STATE(3874)] = 88956,
  [SMALL_STATE(3875)] = 89028,
  [SMALL_STATE(3876)] = 89100,
  [SMALL_STATE(3877)] = 89172,
  [SMALL_STATE(3878)] = 89250,
  [SMALL_STATE(3879)] = 89322,
  [SMALL_STATE(3880)] = 89394,
  [SMALL_STATE(3881)] = 89466,
  [SMALL_STATE(3882)] = 89538,
  [SMALL_STATE(3883)] = 89610,
  [SMALL_STATE(3884)] = 89682,
  [SMALL_STATE(3885)] = 89754,
  [SMALL_STATE(3886)] = 89826,
  [SMALL_STATE(3887)] = 89898,
  [SMALL_STATE(3888)] = 89972,
  [SMALL_STATE(3889)] = 90044,
  [SMALL_STATE(3890)] = 90116,
  [SMALL_STATE(3891)] = 90188,
  [SMALL_STATE(3892)] = 90260,
  [SMALL_STATE(3893)] = 90332,
  [SMALL_STATE(3894)] = 90404,
  [SMALL_STATE(3895)] = 90476,
  [SMALL_STATE(3896)] = 90600,
  [SMALL_STATE(3897)] = 90724,
  [SMALL_STATE(3898)] = 90796,
  [SMALL_STATE(3899)] = 90868,
  [SMALL_STATE(3900)] = 90940,
  [SMALL_STATE(3901)] = 91064,
  [SMALL_STATE(3902)] = 91136,
  [SMALL_STATE(3903)] = 91260,
  [SMALL_STATE(3904)] = 91332,
  [SMALL_STATE(3905)] = 91404,
  [SMALL_STATE(3906)] = 91476,
  [SMALL_STATE(3907)] = 91548,
  [SMALL_STATE(3908)] = 91620,
  [SMALL_STATE(3909)] = 91694,
  [SMALL_STATE(3910)] = 91768,
  [SMALL_STATE(3911)] = 91840,
  [SMALL_STATE(3912)] = 91964,
  [SMALL_STATE(3913)] = 92036,
  [SMALL_STATE(3914)] = 92108,
  [SMALL_STATE(3915)] = 92232,
  [SMALL_STATE(3916)] = 92356,
  [SMALL_STATE(3917)] = 92428,
  [SMALL_STATE(3918)] = 92552,
  [SMALL_STATE(3919)] = 92676,
  [SMALL_STATE(3920)] = 92800,
  [SMALL_STATE(3921)] = 92872,
  [SMALL_STATE(3922)] = 92944,
  [SMALL_STATE(3923)] = 93016,
  [SMALL_STATE(3924)] = 93140,
  [SMALL_STATE(3925)] = 93212,
  [SMALL_STATE(3926)] = 93336,
  [SMALL_STATE(3927)] = 93408,
  [SMALL_STATE(3928)] = 93480,
  [SMALL_STATE(3929)] = 93554,
  [SMALL_STATE(3930)] = 93628,
  [SMALL_STATE(3931)] = 93700,
  [SMALL_STATE(3932)] = 93772,
  [SMALL_STATE(3933)] = 93896,
  [SMALL_STATE(3934)] = 94020,
  [SMALL_STATE(3935)] = 94144,
  [SMALL_STATE(3936)] = 94216,
  [SMALL_STATE(3937)] = 94288,
  [SMALL_STATE(3938)] = 94360,
  [SMALL_STATE(3939)] = 94432,
  [SMALL_STATE(3940)] = 94556,
  [SMALL_STATE(3941)] = 94628,
  [SMALL_STATE(3942)] = 94752,
  [SMALL_STATE(3943)] = 94876,
  [SMALL_STATE(3944)] = 94948,
  [SMALL_STATE(3945)] = 95026,
  [SMALL_STATE(3946)] = 95098,
  [SMALL_STATE(3947)] = 95170,
  [SMALL_STATE(3948)] = 95242,
  [SMALL_STATE(3949)] = 95314,
  [SMALL_STATE(3950)] = 95386,
  [SMALL_STATE(3951)] = 95458,
  [SMALL_STATE(3952)] = 95530,
  [SMALL_STATE(3953)] = 95602,
  [SMALL_STATE(3954)] = 95674,
  [SMALL_STATE(3955)] = 95798,
  [SMALL_STATE(3956)] = 95870,
  [SMALL_STATE(3957)] = 95994,
  [SMALL_STATE(3958)] = 96066,
  [SMALL_STATE(3959)] = 96138,
  [SMALL_STATE(3960)] = 96210,
  [SMALL_STATE(3961)] = 96282,
  [SMALL_STATE(3962)] = 96354,
  [SMALL_STATE(3963)] = 96426,
  [SMALL_STATE(3964)] = 96498,
  [SMALL_STATE(3965)] = 96570,
  [SMALL_STATE(3966)] = 96642,
  [SMALL_STATE(3967)] = 96766,
  [SMALL_STATE(3968)] = 96838,
  [SMALL_STATE(3969)] = 96910,
  [SMALL_STATE(3970)] = 96982,
  [SMALL_STATE(3971)] = 97053,
  [SMALL_STATE(3972)] = 97124,
  [SMALL_STATE(3973)] = 97195,
  [SMALL_STATE(3974)] = 97266,
  [SMALL_STATE(3975)] = 97387,
  [SMALL_STATE(3976)] = 97460,
  [SMALL_STATE(3977)] = 97581,
  [SMALL_STATE(3978)] = 97652,
  [SMALL_STATE(3979)] = 97725,
  [SMALL_STATE(3980)] = 97796,
  [SMALL_STATE(3981)] = 97867,
  [SMALL_STATE(3982)] = 97938,
  [SMALL_STATE(3983)] = 98009,
  [SMALL_STATE(3984)] = 98130,
  [SMALL_STATE(3985)] = 98201,
  [SMALL_STATE(3986)] = 98322,
  [SMALL_STATE(3987)] = 98393,
  [SMALL_STATE(3988)] = 98464,
  [SMALL_STATE(3989)] = 98535,
  [SMALL_STATE(3990)] = 98606,
  [SMALL_STATE(3991)] = 98677,
  [SMALL_STATE(3992)] = 98798,
  [SMALL_STATE(3993)] = 98869,
  [SMALL_STATE(3994)] = 98940,
  [SMALL_STATE(3995)] = 99011,
  [SMALL_STATE(3996)] = 99082,
  [SMALL_STATE(3997)] = 99153,
  [SMALL_STATE(3998)] = 99224,
  [SMALL_STATE(3999)] = 99295,
  [SMALL_STATE(4000)] = 99366,
  [SMALL_STATE(4001)] = 99437,
  [SMALL_STATE(4002)] = 99508,
  [SMALL_STATE(4003)] = 99579,
  [SMALL_STATE(4004)] = 99650,
  [SMALL_STATE(4005)] = 99771,
  [SMALL_STATE(4006)] = 99842,
  [SMALL_STATE(4007)] = 99913,
  [SMALL_STATE(4008)] = 99990,
  [SMALL_STATE(4009)] = 100061,
  [SMALL_STATE(4010)] = 100132,
  [SMALL_STATE(4011)] = 100203,
  [SMALL_STATE(4012)] = 100324,
  [SMALL_STATE(4013)] = 100445,
  [SMALL_STATE(4014)] = 100516,
  [SMALL_STATE(4015)] = 100587,
  [SMALL_STATE(4016)] = 100664,
  [SMALL_STATE(4017)] = 100737,
  [SMALL_STATE(4018)] = 100858,
  [SMALL_STATE(4019)] = 100929,
  [SMALL_STATE(4020)] = 101000,
  [SMALL_STATE(4021)] = 101071,
  [SMALL_STATE(4022)] = 101206,
  [SMALL_STATE(4023)] = 101277,
  [SMALL_STATE(4024)] = 101398,
  [SMALL_STATE(4025)] = 101469,
  [SMALL_STATE(4026)] = 101540,
  [SMALL_STATE(4027)] = 101611,
  [SMALL_STATE(4028)] = 101682,
  [SMALL_STATE(4029)] = 101803,
  [SMALL_STATE(4030)] = 101874,
  [SMALL_STATE(4031)] = 101995,
  [SMALL_STATE(4032)] = 102066,
  [SMALL_STATE(4033)] = 102139,
  [SMALL_STATE(4034)] = 102210,
  [SMALL_STATE(4035)] = 102331,
  [SMALL_STATE(4036)] = 102402,
  [SMALL_STATE(4037)] = 102473,
  [SMALL_STATE(4038)] = 102608,
  [SMALL_STATE(4039)] = 102679,
  [SMALL_STATE(4040)] = 102800,
  [SMALL_STATE(4041)] = 102871,
  [SMALL_STATE(4042)] = 102942,
  [SMALL_STATE(4043)] = 103013,
  [SMALL_STATE(4044)] = 103084,
  [SMALL_STATE(4045)] = 103155,
  [SMALL_STATE(4046)] = 103226,
  [SMALL_STATE(4047)] = 103299,
  [SMALL_STATE(4048)] = 103370,
  [SMALL_STATE(4049)] = 103441,
  [SMALL_STATE(4050)] = 103562,
  [SMALL_STATE(4051)] = 103683,
  [SMALL_STATE(4052)] = 103754,
  [SMALL_STATE(4053)] = 103825,
  [SMALL_STATE(4054)] = 103902,
  [SMALL_STATE(4055)] = 103973,
  [SMALL_STATE(4056)] = 104044,
  [SMALL_STATE(4057)] = 104115,
  [SMALL_STATE(4058)] = 104236,
  [SMALL_STATE(4059)] = 104307,
  [SMALL_STATE(4060)] = 104378,
  [SMALL_STATE(4061)] = 104499,
  [SMALL_STATE(4062)] = 104570,
  [SMALL_STATE(4063)] = 104641,
  [SMALL_STATE(4064)] = 104712,
  [SMALL_STATE(4065)] = 104783,
  [SMALL_STATE(4066)] = 104904,
  [SMALL_STATE(4067)] = 104975,
  [SMALL_STATE(4068)] = 105046,
  [SMALL_STATE(4069)] = 105167,
  [SMALL_STATE(4070)] = 105288,
  [SMALL_STATE(4071)] = 105359,
  [SMALL_STATE(4072)] = 105430,
  [SMALL_STATE(4073)] = 105503,
  [SMALL_STATE(4074)] = 105624,
  [SMALL_STATE(4075)] = 105745,
  [SMALL_STATE(4076)] = 105816,
  [SMALL_STATE(4077)] = 105889,
  [SMALL_STATE(4078)] = 105962,
  [SMALL_STATE(4079)] = 106033,
  [SMALL_STATE(4080)] = 106106,
  [SMALL_STATE(4081)] = 106177,
  [SMALL_STATE(4082)] = 106248,
  [SMALL_STATE(4083)] = 106369,
  [SMALL_STATE(4084)] = 106490,
  [SMALL_STATE(4085)] = 106561,
  [SMALL_STATE(4086)] = 106632,
  [SMALL_STATE(4087)] = 106753,
  [SMALL_STATE(4088)] = 106824,
  [SMALL_STATE(4089)] = 106895,
  [SMALL_STATE(4090)] = 107016,
  [SMALL_STATE(4091)] = 107137,
  [SMALL_STATE(4092)] = 107208,
  [SMALL_STATE(4093)] = 107279,
  [SMALL_STATE(4094)] = 107350,
  [SMALL_STATE(4095)] = 107427,
  [SMALL_STATE(4096)] = 107548,
  [SMALL_STATE(4097)] = 107619,
  [SMALL_STATE(4098)] = 107690,
  [SMALL_STATE(4099)] = 107761,
  [SMALL_STATE(4100)] = 107832,
  [SMALL_STATE(4101)] = 107903,
  [SMALL_STATE(4102)] = 108024,
  [SMALL_STATE(4103)] = 108095,
  [SMALL_STATE(4104)] = 108166,
  [SMALL_STATE(4105)] = 108237,
  [SMALL_STATE(4106)] = 108358,
  [SMALL_STATE(4107)] = 108479,
  [SMALL_STATE(4108)] = 108550,
  [SMALL_STATE(4109)] = 108621,
  [SMALL_STATE(4110)] = 108742,
  [SMALL_STATE(4111)] = 108813,
  [SMALL_STATE(4112)] = 108884,
  [SMALL_STATE(4113)] = 108955,
  [SMALL_STATE(4114)] = 109026,
  [SMALL_STATE(4115)] = 109097,
  [SMALL_STATE(4116)] = 109168,
  [SMALL_STATE(4117)] = 109239,
  [SMALL_STATE(4118)] = 109310,
  [SMALL_STATE(4119)] = 109381,
  [SMALL_STATE(4120)] = 109452,
  [SMALL_STATE(4121)] = 109525,
  [SMALL_STATE(4122)] = 109596,
  [SMALL_STATE(4123)] = 109667,
  [SMALL_STATE(4124)] = 109738,
  [SMALL_STATE(4125)] = 109859,
  [SMALL_STATE(4126)] = 109930,
  [SMALL_STATE(4127)] = 110051,
  [SMALL_STATE(4128)] = 110122,
  [SMALL_STATE(4129)] = 110193,
  [SMALL_STATE(4130)] = 110264,
  [SMALL_STATE(4131)] = 110335,
  [SMALL_STATE(4132)] = 110456,
  [SMALL_STATE(4133)] = 110527,
  [SMALL_STATE(4134)] = 110598,
  [SMALL_STATE(4135)] = 110669,
  [SMALL_STATE(4136)] = 110790,
  [SMALL_STATE(4137)] = 110861,
  [SMALL_STATE(4138)] = 110932,
  [SMALL_STATE(4139)] = 111003,
  [SMALL_STATE(4140)] = 111074,
  [SMALL_STATE(4141)] = 111145,
  [SMALL_STATE(4142)] = 111216,
  [SMALL_STATE(4143)] = 111287,
  [SMALL_STATE(4144)] = 111358,
  [SMALL_STATE(4145)] = 111429,
  [SMALL_STATE(4146)] = 111500,
  [SMALL_STATE(4147)] = 111621,
  [SMALL_STATE(4148)] = 111692,
  [SMALL_STATE(4149)] = 111765,
  [SMALL_STATE(4150)] = 111886,
  [SMALL_STATE(4151)] = 111957,
  [SMALL_STATE(4152)] = 112028,
  [SMALL_STATE(4153)] = 112099,
  [SMALL_STATE(4154)] = 112170,
  [SMALL_STATE(4155)] = 112241,
  [SMALL_STATE(4156)] = 112312,
  [SMALL_STATE(4157)] = 112383,
  [SMALL_STATE(4158)] = 112504,
  [SMALL_STATE(4159)] = 112575,
  [SMALL_STATE(4160)] = 112646,
  [SMALL_STATE(4161)] = 112717,
  [SMALL_STATE(4162)] = 112788,
  [SMALL_STATE(4163)] = 112859,
  [SMALL_STATE(4164)] = 112930,
  [SMALL_STATE(4165)] = 113001,
  [SMALL_STATE(4166)] = 113072,
  [SMALL_STATE(4167)] = 113143,
  [SMALL_STATE(4168)] = 113214,
  [SMALL_STATE(4169)] = 113285,
  [SMALL_STATE(4170)] = 113356,
  [SMALL_STATE(4171)] = 113477,
  [SMALL_STATE(4172)] = 113548,
  [SMALL_STATE(4173)] = 113619,
  [SMALL_STATE(4174)] = 113690,
  [SMALL_STATE(4175)] = 113763,
  [SMALL_STATE(4176)] = 113834,
  [SMALL_STATE(4177)] = 113955,
  [SMALL_STATE(4178)] = 114026,
  [SMALL_STATE(4179)] = 114097,
  [SMALL_STATE(4180)] = 114168,
  [SMALL_STATE(4181)] = 114239,
  [SMALL_STATE(4182)] = 114360,
  [SMALL_STATE(4183)] = 114481,
  [SMALL_STATE(4184)] = 114554,
  [SMALL_STATE(4185)] = 114625,
  [SMALL_STATE(4186)] = 114698,
  [SMALL_STATE(4187)] = 114769,
  [SMALL_STATE(4188)] = 114840,
  [SMALL_STATE(4189)] = 114911,
  [SMALL_STATE(4190)] = 114982,
  [SMALL_STATE(4191)] = 115100,
  [SMALL_STATE(4192)] = 115218,
  [SMALL_STATE(4193)] = 115288,
  [SMALL_STATE(4194)] = 115406,
  [SMALL_STATE(4195)] = 115476,
  [SMALL_STATE(4196)] = 115546,
  [SMALL_STATE(4197)] = 115616,
  [SMALL_STATE(4198)] = 115686,
  [SMALL_STATE(4199)] = 115758,
  [SMALL_STATE(4200)] = 115828,
  [SMALL_STATE(4201)] = 115946,
  [SMALL_STATE(4202)] = 116064,
  [SMALL_STATE(4203)] = 116182,
  [SMALL_STATE(4204)] = 116300,
  [SMALL_STATE(4205)] = 116418,
  [SMALL_STATE(4206)] = 116536,
  [SMALL_STATE(4207)] = 116606,
  [SMALL_STATE(4208)] = 116724,
  [SMALL_STATE(4209)] = 116794,
  [SMALL_STATE(4210)] = 116864,
  [SMALL_STATE(4211)] = 116934,
  [SMALL_STATE(4212)] = 117052,
  [SMALL_STATE(4213)] = 117170,
  [SMALL_STATE(4214)] = 117288,
  [SMALL_STATE(4215)] = 117406,
  [SMALL_STATE(4216)] = 117476,
  [SMALL_STATE(4217)] = 117546,
  [SMALL_STATE(4218)] = 117664,
  [SMALL_STATE(4219)] = 117734,
  [SMALL_STATE(4220)] = 117804,
  [SMALL_STATE(4221)] = 117874,
  [SMALL_STATE(4222)] = 117944,
  [SMALL_STATE(4223)] = 118014,
  [SMALL_STATE(4224)] = 118084,
  [SMALL_STATE(4225)] = 118154,
  [SMALL_STATE(4226)] = 118224,
  [SMALL_STATE(4227)] = 118296,
  [SMALL_STATE(4228)] = 118366,
  [SMALL_STATE(4229)] = 118436,
  [SMALL_STATE(4230)] = 118554,
  [SMALL_STATE(4231)] = 118624,
  [SMALL_STATE(4232)] = 118694,
  [SMALL_STATE(4233)] = 118812,
  [SMALL_STATE(4234)] = 118930,
  [SMALL_STATE(4235)] = 119048,
  [SMALL_STATE(4236)] = 119166,
  [SMALL_STATE(4237)] = 119284,
  [SMALL_STATE(4238)] = 119402,
  [SMALL_STATE(4239)] = 119520,
  [SMALL_STATE(4240)] = 119590,
  [SMALL_STATE(4241)] = 119708,
  [SMALL_STATE(4242)] = 119778,
  [SMALL_STATE(4243)] = 119896,
  [SMALL_STATE(4244)] = 120014,
  [SMALL_STATE(4245)] = 120132,
  [SMALL_STATE(4246)] = 120202,
  [SMALL_STATE(4247)] = 120272,
  [SMALL_STATE(4248)] = 120342,
  [SMALL_STATE(4249)] = 120412,
  [SMALL_STATE(4250)] = 120484,
  [SMALL_STATE(4251)] = 120554,
  [SMALL_STATE(4252)] = 120624,
  [SMALL_STATE(4253)] = 120694,
  [SMALL_STATE(4254)] = 120812,
  [SMALL_STATE(4255)] = 120882,
  [SMALL_STATE(4256)] = 120952,
  [SMALL_STATE(4257)] = 121070,
  [SMALL_STATE(4258)] = 121140,
  [SMALL_STATE(4259)] = 121210,
  [SMALL_STATE(4260)] = 121280,
  [SMALL_STATE(4261)] = 121350,
  [SMALL_STATE(4262)] = 121420,
  [SMALL_STATE(4263)] = 121538,
  [SMALL_STATE(4264)] = 121608,
  [SMALL_STATE(4265)] = 121726,
  [SMALL_STATE(4266)] = 121844,
  [SMALL_STATE(4267)] = 121962,
  [SMALL_STATE(4268)] = 122032,
  [SMALL_STATE(4269)] = 122150,
  [SMALL_STATE(4270)] = 122220,
  [SMALL_STATE(4271)] = 122290,
  [SMALL_STATE(4272)] = 122408,
  [SMALL_STATE(4273)] = 122526,
  [SMALL_STATE(4274)] = 122644,
  [SMALL_STATE(4275)] = 122714,
  [SMALL_STATE(4276)] = 122784,
  [SMALL_STATE(4277)] = 122854,
  [SMALL_STATE(4278)] = 122924,
  [SMALL_STATE(4279)] = 122994,
  [SMALL_STATE(4280)] = 123064,
  [SMALL_STATE(4281)] = 123134,
  [SMALL_STATE(4282)] = 123204,
  [SMALL_STATE(4283)] = 123274,
  [SMALL_STATE(4284)] = 123392,
  [SMALL_STATE(4285)] = 123462,
  [SMALL_STATE(4286)] = 123532,
  [SMALL_STATE(4287)] = 123602,
  [SMALL_STATE(4288)] = 123672,
  [SMALL_STATE(4289)] = 123790,
  [SMALL_STATE(4290)] = 123908,
  [SMALL_STATE(4291)] = 124026,
  [SMALL_STATE(4292)] = 124144,
  [SMALL_STATE(4293)] = 124262,
  [SMALL_STATE(4294)] = 124380,
  [SMALL_STATE(4295)] = 124450,
  [SMALL_STATE(4296)] = 124520,
  [SMALL_STATE(4297)] = 124638,
  [SMALL_STATE(4298)] = 124708,
  [SMALL_STATE(4299)] = 124826,
  [SMALL_STATE(4300)] = 124944,
  [SMALL_STATE(4301)] = 125016,
  [SMALL_STATE(4302)] = 125134,
  [SMALL_STATE(4303)] = 125204,
  [SMALL_STATE(4304)] = 125274,
  [SMALL_STATE(4305)] = 125344,
  [SMALL_STATE(4306)] = 125414,
  [SMALL_STATE(4307)] = 125532,
  [SMALL_STATE(4308)] = 125650,
  [SMALL_STATE(4309)] = 125768,
  [SMALL_STATE(4310)] = 125838,
  [SMALL_STATE(4311)] = 125956,
  [SMALL_STATE(4312)] = 126074,
  [SMALL_STATE(4313)] = 126192,
  [SMALL_STATE(4314)] = 126262,
  [SMALL_STATE(4315)] = 126380,
  [SMALL_STATE(4316)] = 126450,
  [SMALL_STATE(4317)] = 126568,
  [SMALL_STATE(4318)] = 126638,
  [SMALL_STATE(4319)] = 126756,
  [SMALL_STATE(4320)] = 126826,
  [SMALL_STATE(4321)] = 126896,
  [SMALL_STATE(4322)] = 127014,
  [SMALL_STATE(4323)] = 127132,
  [SMALL_STATE(4324)] = 127202,
  [SMALL_STATE(4325)] = 127272,
  [SMALL_STATE(4326)] = 127342,
  [SMALL_STATE(4327)] = 127412,
  [SMALL_STATE(4328)] = 127530,
  [SMALL_STATE(4329)] = 127648,
  [SMALL_STATE(4330)] = 127718,
  [SMALL_STATE(4331)] = 127836,
  [SMALL_STATE(4332)] = 127906,
  [SMALL_STATE(4333)] = 128024,
  [SMALL_STATE(4334)] = 128142,
  [SMALL_STATE(4335)] = 128260,
  [SMALL_STATE(4336)] = 128330,
  [SMALL_STATE(4337)] = 128402,
  [SMALL_STATE(4338)] = 128472,
  [SMALL_STATE(4339)] = 128590,
  [SMALL_STATE(4340)] = 128708,
  [SMALL_STATE(4341)] = 128784,
  [SMALL_STATE(4342)] = 128854,
  [SMALL_STATE(4343)] = 128924,
  [SMALL_STATE(4344)] = 128994,
  [SMALL_STATE(4345)] = 129112,
  [SMALL_STATE(4346)] = 129182,
  [SMALL_STATE(4347)] = 129252,
  [SMALL_STATE(4348)] = 129322,
  [SMALL_STATE(4349)] = 129440,
  [SMALL_STATE(4350)] = 129510,
  [SMALL_STATE(4351)] = 129580,
  [SMALL_STATE(4352)] = 129650,
  [SMALL_STATE(4353)] = 129720,
  [SMALL_STATE(4354)] = 129790,
  [SMALL_STATE(4355)] = 129908,
  [SMALL_STATE(4356)] = 130026,
  [SMALL_STATE(4357)] = 130096,
  [SMALL_STATE(4358)] = 130168,
  [SMALL_STATE(4359)] = 130286,
  [SMALL_STATE(4360)] = 130404,
  [SMALL_STATE(4361)] = 130474,
  [SMALL_STATE(4362)] = 130592,
  [SMALL_STATE(4363)] = 130710,
  [SMALL_STATE(4364)] = 130828,
  [SMALL_STATE(4365)] = 130946,
  [SMALL_STATE(4366)] = 131016,
  [SMALL_STATE(4367)] = 131086,
  [SMALL_STATE(4368)] = 131204,
  [SMALL_STATE(4369)] = 131322,
  [SMALL_STATE(4370)] = 131440,
  [SMALL_STATE(4371)] = 131510,
  [SMALL_STATE(4372)] = 131580,
  [SMALL_STATE(4373)] = 131698,
  [SMALL_STATE(4374)] = 131768,
  [SMALL_STATE(4375)] = 131838,
  [SMALL_STATE(4376)] = 131956,
  [SMALL_STATE(4377)] = 132026,
  [SMALL_STATE(4378)] = 132096,
  [SMALL_STATE(4379)] = 132214,
  [SMALL_STATE(4380)] = 132332,
  [SMALL_STATE(4381)] = 132402,
  [SMALL_STATE(4382)] = 132520,
  [SMALL_STATE(4383)] = 132592,
  [SMALL_STATE(4384)] = 132662,
  [SMALL_STATE(4385)] = 132780,
  [SMALL_STATE(4386)] = 132898,
  [SMALL_STATE(4387)] = 133016,
  [SMALL_STATE(4388)] = 133134,
  [SMALL_STATE(4389)] = 133252,
  [SMALL_STATE(4390)] = 133370,
  [SMALL_STATE(4391)] = 133488,
  [SMALL_STATE(4392)] = 133558,
  [SMALL_STATE(4393)] = 133676,
  [SMALL_STATE(4394)] = 133794,
  [SMALL_STATE(4395)] = 133912,
  [SMALL_STATE(4396)] = 134030,
  [SMALL_STATE(4397)] = 134100,
  [SMALL_STATE(4398)] = 134218,
  [SMALL_STATE(4399)] = 134336,
  [SMALL_STATE(4400)] = 134454,
  [SMALL_STATE(4401)] = 134572,
  [SMALL_STATE(4402)] = 134642,
  [SMALL_STATE(4403)] = 134760,
  [SMALL_STATE(4404)] = 134836,
  [SMALL_STATE(4405)] = 134906,
  [SMALL_STATE(4406)] = 135024,
  [SMALL_STATE(4407)] = 135142,
  [SMALL_STATE(4408)] = 135260,
  [SMALL_STATE(4409)] = 135378,
  [SMALL_STATE(4410)] = 135448,
  [SMALL_STATE(4411)] = 135518,
  [SMALL_STATE(4412)] = 135588,
  [SMALL_STATE(4413)] = 135706,
  [SMALL_STATE(4414)] = 135776,
  [SMALL_STATE(4415)] = 135894,
  [SMALL_STATE(4416)] = 136012,
  [SMALL_STATE(4417)] = 136130,
  [SMALL_STATE(4418)] = 136200,
  [SMALL_STATE(4419)] = 136318,
  [SMALL_STATE(4420)] = 136388,
  [SMALL_STATE(4421)] = 136458,
  [SMALL_STATE(4422)] = 136576,
  [SMALL_STATE(4423)] = 136646,
  [SMALL_STATE(4424)] = 136716,
  [SMALL_STATE(4425)] = 136834,
  [SMALL_STATE(4426)] = 136904,
  [SMALL_STATE(4427)] = 137022,
  [SMALL_STATE(4428)] = 137098,
  [SMALL_STATE(4429)] = 137216,
  [SMALL_STATE(4430)] = 137292,
  [SMALL_STATE(4431)] = 137410,
  [SMALL_STATE(4432)] = 137528,
  [SMALL_STATE(4433)] = 137598,
  [SMALL_STATE(4434)] = 137716,
  [SMALL_STATE(4435)] = 137834,
  [SMALL_STATE(4436)] = 137904,
  [SMALL_STATE(4437)] = 138022,
  [SMALL_STATE(4438)] = 138140,
  [SMALL_STATE(4439)] = 138258,
  [SMALL_STATE(4440)] = 138328,
  [SMALL_STATE(4441)] = 138446,
  [SMALL_STATE(4442)] = 138516,
  [SMALL_STATE(4443)] = 138586,
  [SMALL_STATE(4444)] = 138656,
  [SMALL_STATE(4445)] = 138774,
  [SMALL_STATE(4446)] = 138892,
  [SMALL_STATE(4447)] = 139010,
  [SMALL_STATE(4448)] = 139080,
  [SMALL_STATE(4449)] = 139150,
  [SMALL_STATE(4450)] = 139268,
  [SMALL_STATE(4451)] = 139386,
  [SMALL_STATE(4452)] = 139456,
  [SMALL_STATE(4453)] = 139526,
  [SMALL_STATE(4454)] = 139596,
  [SMALL_STATE(4455)] = 139666,
  [SMALL_STATE(4456)] = 139736,
  [SMALL_STATE(4457)] = 139854,
  [SMALL_STATE(4458)] = 139972,
  [SMALL_STATE(4459)] = 140042,
  [SMALL_STATE(4460)] = 140160,
  [SMALL_STATE(4461)] = 140278,
  [SMALL_STATE(4462)] = 140348,
  [SMALL_STATE(4463)] = 140466,
  [SMALL_STATE(4464)] = 140584,
  [SMALL_STATE(4465)] = 140654,
  [SMALL_STATE(4466)] = 140724,
  [SMALL_STATE(4467)] = 140794,
  [SMALL_STATE(4468)] = 140912,
  [SMALL_STATE(4469)] = 140982,
  [SMALL_STATE(4470)] = 141052,
  [SMALL_STATE(4471)] = 141122,
  [SMALL_STATE(4472)] = 141194,
  [SMALL_STATE(4473)] = 141264,
  [SMALL_STATE(4474)] = 141382,
  [SMALL_STATE(4475)] = 141452,
  [SMALL_STATE(4476)] = 141522,
  [SMALL_STATE(4477)] = 141640,
  [SMALL_STATE(4478)] = 141758,
  [SMALL_STATE(4479)] = 141828,
  [SMALL_STATE(4480)] = 141946,
  [SMALL_STATE(4481)] = 142016,
  [SMALL_STATE(4482)] = 142134,
  [SMALL_STATE(4483)] = 142204,
  [SMALL_STATE(4484)] = 142333,
  [SMALL_STATE(4485)] = 142462,
  [SMALL_STATE(4486)] = 142591,
  [SMALL_STATE(4487)] = 142720,
  [SMALL_STATE(4488)] = 142789,
  [SMALL_STATE(4489)] = 142918,
  [SMALL_STATE(4490)] = 143047,
  [SMALL_STATE(4491)] = 143176,
  [SMALL_STATE(4492)] = 143305,
  [SMALL_STATE(4493)] = 143434,
  [SMALL_STATE(4494)] = 143563,
  [SMALL_STATE(4495)] = 143692,
  [SMALL_STATE(4496)] = 143821,
  [SMALL_STATE(4497)] = 143950,
  [SMALL_STATE(4498)] = 144079,
  [SMALL_STATE(4499)] = 144208,
  [SMALL_STATE(4500)] = 144337,
  [SMALL_STATE(4501)] = 144466,
  [SMALL_STATE(4502)] = 144595,
  [SMALL_STATE(4503)] = 144724,
  [SMALL_STATE(4504)] = 144853,
  [SMALL_STATE(4505)] = 144982,
  [SMALL_STATE(4506)] = 145111,
  [SMALL_STATE(4507)] = 145180,
  [SMALL_STATE(4508)] = 145251,
  [SMALL_STATE(4509)] = 145380,
  [SMALL_STATE(4510)] = 145509,
  [SMALL_STATE(4511)] = 145638,
  [SMALL_STATE(4512)] = 145767,
  [SMALL_STATE(4513)] = 145896,
  [SMALL_STATE(4514)] = 146025,
  [SMALL_STATE(4515)] = 146154,
  [SMALL_STATE(4516)] = 146283,
  [SMALL_STATE(4517)] = 146412,
  [SMALL_STATE(4518)] = 146541,
  [SMALL_STATE(4519)] = 146670,
  [SMALL_STATE(4520)] = 146799,
  [SMALL_STATE(4521)] = 146928,
  [SMALL_STATE(4522)] = 147057,
  [SMALL_STATE(4523)] = 147186,
  [SMALL_STATE(4524)] = 147315,
  [SMALL_STATE(4525)] = 147444,
  [SMALL_STATE(4526)] = 147573,
  [SMALL_STATE(4527)] = 147702,
  [SMALL_STATE(4528)] = 147831,
  [SMALL_STATE(4529)] = 147960,
  [SMALL_STATE(4530)] = 148089,
  [SMALL_STATE(4531)] = 148218,
  [SMALL_STATE(4532)] = 148289,
  [SMALL_STATE(4533)] = 148418,
  [SMALL_STATE(4534)] = 148547,
  [SMALL_STATE(4535)] = 148676,
  [SMALL_STATE(4536)] = 148805,
  [SMALL_STATE(4537)] = 148934,
  [SMALL_STATE(4538)] = 149063,
  [SMALL_STATE(4539)] = 149192,
  [SMALL_STATE(4540)] = 149321,
  [SMALL_STATE(4541)] = 149450,
  [SMALL_STATE(4542)] = 149579,
  [SMALL_STATE(4543)] = 149648,
  [SMALL_STATE(4544)] = 149777,
  [SMALL_STATE(4545)] = 149906,
  [SMALL_STATE(4546)] = 150035,
  [SMALL_STATE(4547)] = 150104,
  [SMALL_STATE(4548)] = 150233,
  [SMALL_STATE(4549)] = 150362,
  [SMALL_STATE(4550)] = 150491,
  [SMALL_STATE(4551)] = 150620,
  [SMALL_STATE(4552)] = 150749,
  [SMALL_STATE(4553)] = 150878,
  [SMALL_STATE(4554)] = 151004,
  [SMALL_STATE(4555)] = 151072,
  [SMALL_STATE(4556)] = 151198,
  [SMALL_STATE(4557)] = 151324,
  [SMALL_STATE(4558)] = 151450,
  [SMALL_STATE(4559)] = 151576,
  [SMALL_STATE(4560)] = 151702,
  [SMALL_STATE(4561)] = 151772,
  [SMALL_STATE(4562)] = 151898,
  [SMALL_STATE(4563)] = 152024,
  [SMALL_STATE(4564)] = 152150,
  [SMALL_STATE(4565)] = 152276,
  [SMALL_STATE(4566)] = 152402,
  [SMALL_STATE(4567)] = 152528,
  [SMALL_STATE(4568)] = 152654,
  [SMALL_STATE(4569)] = 152780,
  [SMALL_STATE(4570)] = 152906,
  [SMALL_STATE(4571)] = 153032,
  [SMALL_STATE(4572)] = 153158,
  [SMALL_STATE(4573)] = 153284,
  [SMALL_STATE(4574)] = 153410,
  [SMALL_STATE(4575)] = 153536,
  [SMALL_STATE(4576)] = 153604,
  [SMALL_STATE(4577)] = 153730,
  [SMALL_STATE(4578)] = 153856,
  [SMALL_STATE(4579)] = 153982,
  [SMALL_STATE(4580)] = 154108,
  [SMALL_STATE(4581)] = 154234,
  [SMALL_STATE(4582)] = 154360,
  [SMALL_STATE(4583)] = 154486,
  [SMALL_STATE(4584)] = 154612,
  [SMALL_STATE(4585)] = 154738,
  [SMALL_STATE(4586)] = 154864,
  [SMALL_STATE(4587)] = 154990,
  [SMALL_STATE(4588)] = 155116,
  [SMALL_STATE(4589)] = 155242,
  [SMALL_STATE(4590)] = 155368,
  [SMALL_STATE(4591)] = 155494,
  [SMALL_STATE(4592)] = 155620,
  [SMALL_STATE(4593)] = 155746,
  [SMALL_STATE(4594)] = 155872,
  [SMALL_STATE(4595)] = 155998,
  [SMALL_STATE(4596)] = 156124,
  [SMALL_STATE(4597)] = 156250,
  [SMALL_STATE(4598)] = 156376,
  [SMALL_STATE(4599)] = 156502,
  [SMALL_STATE(4600)] = 156628,
  [SMALL_STATE(4601)] = 156754,
  [SMALL_STATE(4602)] = 156880,
  [SMALL_STATE(4603)] = 156948,
  [SMALL_STATE(4604)] = 157074,
  [SMALL_STATE(4605)] = 157200,
  [SMALL_STATE(4606)] = 157326,
  [SMALL_STATE(4607)] = 157452,
  [SMALL_STATE(4608)] = 157578,
  [SMALL_STATE(4609)] = 157704,
  [SMALL_STATE(4610)] = 157830,
  [SMALL_STATE(4611)] = 157956,
  [SMALL_STATE(4612)] = 158082,
  [SMALL_STATE(4613)] = 158208,
  [SMALL_STATE(4614)] = 158276,
  [SMALL_STATE(4615)] = 158402,
  [SMALL_STATE(4616)] = 158528,
  [SMALL_STATE(4617)] = 158654,
  [SMALL_STATE(4618)] = 158724,
  [SMALL_STATE(4619)] = 158850,
  [SMALL_STATE(4620)] = 158976,
  [SMALL_STATE(4621)] = 159102,
  [SMALL_STATE(4622)] = 159223,
  [SMALL_STATE(4623)] = 159346,
  [SMALL_STATE(4624)] = 159469,
  [SMALL_STATE(4625)] = 159592,
  [SMALL_STATE(4626)] = 159715,
  [SMALL_STATE(4627)] = 159838,
  [SMALL_STATE(4628)] = 159961,
  [SMALL_STATE(4629)] = 160084,
  [SMALL_STATE(4630)] = 160199,
  [SMALL_STATE(4631)] = 160322,
  [SMALL_STATE(4632)] = 160445,
  [SMALL_STATE(4633)] = 160568,
  [SMALL_STATE(4634)] = 160691,
  [SMALL_STATE(4635)] = 160814,
  [SMALL_STATE(4636)] = 160937,
  [SMALL_STATE(4637)] = 161060,
  [SMALL_STATE(4638)] = 161183,
  [SMALL_STATE(4639)] = 161250,
  [SMALL_STATE(4640)] = 161373,
  [SMALL_STATE(4641)] = 161440,
  [SMALL_STATE(4642)] = 161563,
  [SMALL_STATE(4643)] = 161686,
  [SMALL_STATE(4644)] = 161809,
  [SMALL_STATE(4645)] = 161932,
  [SMALL_STATE(4646)] = 162055,
  [SMALL_STATE(4647)] = 162176,
  [SMALL_STATE(4648)] = 162299,
  [SMALL_STATE(4649)] = 162422,
  [SMALL_STATE(4650)] = 162489,
  [SMALL_STATE(4651)] = 162610,
  [SMALL_STATE(4652)] = 162731,
  [SMALL_STATE(4653)] = 162854,
  [SMALL_STATE(4654)] = 162977,
  [SMALL_STATE(4655)] = 163100,
  [SMALL_STATE(4656)] = 163223,
  [SMALL_STATE(4657)] = 163344,
  [SMALL_STATE(4658)] = 163467,
  [SMALL_STATE(4659)] = 163534,
  [SMALL_STATE(4660)] = 163657,
  [SMALL_STATE(4661)] = 163780,
  [SMALL_STATE(4662)] = 163903,
  [SMALL_STATE(4663)] = 164026,
  [SMALL_STATE(4664)] = 164149,
  [SMALL_STATE(4665)] = 164272,
  [SMALL_STATE(4666)] = 164395,
  [SMALL_STATE(4667)] = 164518,
  [SMALL_STATE(4668)] = 164636,
  [SMALL_STATE(4669)] = 164754,
  [SMALL_STATE(4670)] = 164872,
  [SMALL_STATE(4671)] = 164990,
  [SMALL_STATE(4672)] = 165108,
  [SMALL_STATE(4673)] = 165226,
  [SMALL_STATE(4674)] = 165344,
  [SMALL_STATE(4675)] = 165462,
  [SMALL_STATE(4676)] = 165580,
  [SMALL_STATE(4677)] = 165698,
  [SMALL_STATE(4678)] = 165816,
  [SMALL_STATE(4679)] = 165934,
  [SMALL_STATE(4680)] = 166052,
  [SMALL_STATE(4681)] = 166170,
  [SMALL_STATE(4682)] = 166236,
  [SMALL_STATE(4683)] = 166354,
  [SMALL_STATE(4684)] = 166420,
  [SMALL_STATE(4685)] = 166538,
  [SMALL_STATE(4686)] = 166656,
  [SMALL_STATE(4687)] = 166774,
  [SMALL_STATE(4688)] = 166892,
  [SMALL_STATE(4689)] = 167010,
  [SMALL_STATE(4690)] = 167076,
  [SMALL_STATE(4691)] = 167142,
  [SMALL_STATE(4692)] = 167260,
  [SMALL_STATE(4693)] = 167326,
  [SMALL_STATE(4694)] = 167444,
  [SMALL_STATE(4695)] = 167562,
  [SMALL_STATE(4696)] = 167680,
  [SMALL_STATE(4697)] = 167798,
  [SMALL_STATE(4698)] = 167916,
  [SMALL_STATE(4699)] = 167982,
  [SMALL_STATE(4700)] = 168100,
  [SMALL_STATE(4701)] = 168218,
  [SMALL_STATE(4702)] = 168336,
  [SMALL_STATE(4703)] = 168454,
  [SMALL_STATE(4704)] = 168522,
  [SMALL_STATE(4705)] = 168640,
  [SMALL_STATE(4706)] = 168758,
  [SMALL_STATE(4707)] = 168876,
  [SMALL_STATE(4708)] = 168994,
  [SMALL_STATE(4709)] = 169060,
  [SMALL_STATE(4710)] = 169130,
  [SMALL_STATE(4711)] = 169248,
  [SMALL_STATE(4712)] = 169366,
  [SMALL_STATE(4713)] = 169484,
  [SMALL_STATE(4714)] = 169602,
  [SMALL_STATE(4715)] = 169720,
  [SMALL_STATE(4716)] = 169838,
  [SMALL_STATE(4717)] = 169956,
  [SMALL_STATE(4718)] = 170074,
  [SMALL_STATE(4719)] = 170192,
  [SMALL_STATE(4720)] = 170310,
  [SMALL_STATE(4721)] = 170428,
  [SMALL_STATE(4722)] = 170496,
  [SMALL_STATE(4723)] = 170614,
  [SMALL_STATE(4724)] = 170732,
  [SMALL_STATE(4725)] = 170850,
  [SMALL_STATE(4726)] = 170968,
  [SMALL_STATE(4727)] = 171086,
  [SMALL_STATE(4728)] = 171154,
  [SMALL_STATE(4729)] = 171272,
  [SMALL_STATE(4730)] = 171390,
  [SMALL_STATE(4731)] = 171508,
  [SMALL_STATE(4732)] = 171626,
  [SMALL_STATE(4733)] = 171744,
  [SMALL_STATE(4734)] = 171862,
  [SMALL_STATE(4735)] = 171980,
  [SMALL_STATE(4736)] = 172098,
  [SMALL_STATE(4737)] = 172216,
  [SMALL_STATE(4738)] = 172334,
  [SMALL_STATE(4739)] = 172452,
  [SMALL_STATE(4740)] = 172570,
  [SMALL_STATE(4741)] = 172688,
  [SMALL_STATE(4742)] = 172806,
  [SMALL_STATE(4743)] = 172924,
  [SMALL_STATE(4744)] = 173042,
  [SMALL_STATE(4745)] = 173160,
  [SMALL_STATE(4746)] = 173278,
  [SMALL_STATE(4747)] = 173396,
  [SMALL_STATE(4748)] = 173514,
  [SMALL_STATE(4749)] = 173632,
  [SMALL_STATE(4750)] = 173750,
  [SMALL_STATE(4751)] = 173868,
  [SMALL_STATE(4752)] = 173986,
  [SMALL_STATE(4753)] = 174052,
  [SMALL_STATE(4754)] = 174170,
  [SMALL_STATE(4755)] = 174288,
  [SMALL_STATE(4756)] = 174406,
  [SMALL_STATE(4757)] = 174524,
  [SMALL_STATE(4758)] = 174642,
  [SMALL_STATE(4759)] = 174760,
  [SMALL_STATE(4760)] = 174878,
  [SMALL_STATE(4761)] = 174996,
  [SMALL_STATE(4762)] = 175114,
  [SMALL_STATE(4763)] = 175232,
  [SMALL_STATE(4764)] = 175350,
  [SMALL_STATE(4765)] = 175468,
  [SMALL_STATE(4766)] = 175586,
  [SMALL_STATE(4767)] = 175704,
  [SMALL_STATE(4768)] = 175822,
  [SMALL_STATE(4769)] = 175940,
  [SMALL_STATE(4770)] = 176006,
  [SMALL_STATE(4771)] = 176124,
  [SMALL_STATE(4772)] = 176242,
  [SMALL_STATE(4773)] = 176312,
  [SMALL_STATE(4774)] = 176377,
  [SMALL_STATE(4775)] = 176442,
  [SMALL_STATE(4776)] = 176507,
  [SMALL_STATE(4777)] = 176572,
  [SMALL_STATE(4778)] = 176637,
  [SMALL_STATE(4779)] = 176752,
  [SMALL_STATE(4780)] = 176819,
  [SMALL_STATE(4781)] = 176934,
  [SMALL_STATE(4782)] = 176999,
  [SMALL_STATE(4783)] = 177064,
  [SMALL_STATE(4784)] = 177129,
  [SMALL_STATE(4785)] = 177194,
  [SMALL_STATE(4786)] = 177309,
  [SMALL_STATE(4787)] = 177374,
  [SMALL_STATE(4788)] = 177439,
  [SMALL_STATE(4789)] = 177506,
  [SMALL_STATE(4790)] = 177571,
  [SMALL_STATE(4791)] = 177636,
  [SMALL_STATE(4792)] = 177751,
  [SMALL_STATE(4793)] = 177816,
  [SMALL_STATE(4794)] = 177931,
  [SMALL_STATE(4795)] = 177996,
  [SMALL_STATE(4796)] = 178111,
  [SMALL_STATE(4797)] = 178226,
  [SMALL_STATE(4798)] = 178341,
  [SMALL_STATE(4799)] = 178456,
  [SMALL_STATE(4800)] = 178571,
  [SMALL_STATE(4801)] = 178686,
  [SMALL_STATE(4802)] = 178753,
  [SMALL_STATE(4803)] = 178818,
  [SMALL_STATE(4804)] = 178883,
  [SMALL_STATE(4805)] = 178998,
  [SMALL_STATE(4806)] = 179113,
  [SMALL_STATE(4807)] = 179178,
  [SMALL_STATE(4808)] = 179243,
  [SMALL_STATE(4809)] = 179308,
  [SMALL_STATE(4810)] = 179423,
  [SMALL_STATE(4811)] = 179488,
  [SMALL_STATE(4812)] = 179553,
  [SMALL_STATE(4813)] = 179618,
  [SMALL_STATE(4814)] = 179683,
  [SMALL_STATE(4815)] = 179798,
  [SMALL_STATE(4816)] = 179913,
  [SMALL_STATE(4817)] = 179978,
  [SMALL_STATE(4818)] = 180043,
  [SMALL_STATE(4819)] = 180158,
  [SMALL_STATE(4820)] = 180273,
  [SMALL_STATE(4821)] = 180388,
  [SMALL_STATE(4822)] = 180453,
  [SMALL_STATE(4823)] = 180518,
  [SMALL_STATE(4824)] = 180583,
  [SMALL_STATE(4825)] = 180648,
  [SMALL_STATE(4826)] = 180713,
  [SMALL_STATE(4827)] = 180778,
  [SMALL_STATE(4828)] = 180893,
  [SMALL_STATE(4829)] = 181008,
  [SMALL_STATE(4830)] = 181075,
  [SMALL_STATE(4831)] = 181140,
  [SMALL_STATE(4832)] = 181255,
  [SMALL_STATE(4833)] = 181370,
  [SMALL_STATE(4834)] = 181485,
  [SMALL_STATE(4835)] = 181550,
  [SMALL_STATE(4836)] = 181615,
  [SMALL_STATE(4837)] = 181682,
  [SMALL_STATE(4838)] = 181747,
  [SMALL_STATE(4839)] = 181812,
  [SMALL_STATE(4840)] = 181927,
  [SMALL_STATE(4841)] = 182042,
  [SMALL_STATE(4842)] = 182109,
  [SMALL_STATE(4843)] = 182224,
  [SMALL_STATE(4844)] = 182339,
  [SMALL_STATE(4845)] = 182404,
  [SMALL_STATE(4846)] = 182519,
  [SMALL_STATE(4847)] = 182634,
  [SMALL_STATE(4848)] = 182699,
  [SMALL_STATE(4849)] = 182764,
  [SMALL_STATE(4850)] = 182829,
  [SMALL_STATE(4851)] = 182944,
  [SMALL_STATE(4852)] = 183009,
  [SMALL_STATE(4853)] = 183074,
  [SMALL_STATE(4854)] = 183189,
  [SMALL_STATE(4855)] = 183260,
  [SMALL_STATE(4856)] = 183375,
  [SMALL_STATE(4857)] = 183440,
  [SMALL_STATE(4858)] = 183505,
  [SMALL_STATE(4859)] = 183570,
  [SMALL_STATE(4860)] = 183685,
  [SMALL_STATE(4861)] = 183800,
  [SMALL_STATE(4862)] = 183915,
  [SMALL_STATE(4863)] = 183980,
  [SMALL_STATE(4864)] = 184045,
  [SMALL_STATE(4865)] = 184160,
  [SMALL_STATE(4866)] = 184225,
  [SMALL_STATE(4867)] = 184340,
  [SMALL_STATE(4868)] = 184405,
  [SMALL_STATE(4869)] = 184470,
  [SMALL_STATE(4870)] = 184535,
  [SMALL_STATE(4871)] = 184600,
  [SMALL_STATE(4872)] = 184665,
  [SMALL_STATE(4873)] = 184780,
  [SMALL_STATE(4874)] = 184845,
  [SMALL_STATE(4875)] = 184910,
  [SMALL_STATE(4876)] = 184975,
  [SMALL_STATE(4877)] = 185040,
  [SMALL_STATE(4878)] = 185111,
  [SMALL_STATE(4879)] = 185226,
  [SMALL_STATE(4880)] = 185291,
  [SMALL_STATE(4881)] = 185406,
  [SMALL_STATE(4882)] = 185471,
  [SMALL_STATE(4883)] = 185536,
  [SMALL_STATE(4884)] = 185651,
  [SMALL_STATE(4885)] = 185716,
  [SMALL_STATE(4886)] = 185781,
  [SMALL_STATE(4887)] = 185896,
  [SMALL_STATE(4888)] = 185961,
  [SMALL_STATE(4889)] = 186026,
  [SMALL_STATE(4890)] = 186091,
  [SMALL_STATE(4891)] = 186156,
  [SMALL_STATE(4892)] = 186221,
  [SMALL_STATE(4893)] = 186286,
  [SMALL_STATE(4894)] = 186401,
  [SMALL_STATE(4895)] = 186466,
  [SMALL_STATE(4896)] = 186531,
  [SMALL_STATE(4897)] = 186646,
  [SMALL_STATE(4898)] = 186711,
  [SMALL_STATE(4899)] = 186826,
  [SMALL_STATE(4900)] = 186891,
  [SMALL_STATE(4901)] = 186956,
  [SMALL_STATE(4902)] = 187021,
  [SMALL_STATE(4903)] = 187086,
  [SMALL_STATE(4904)] = 187151,
  [SMALL_STATE(4905)] = 187215,
  [SMALL_STATE(4906)] = 187279,
  [SMALL_STATE(4907)] = 187343,
  [SMALL_STATE(4908)] = 187407,
  [SMALL_STATE(4909)] = 187471,
  [SMALL_STATE(4910)] = 187535,
  [SMALL_STATE(4911)] = 187599,
  [SMALL_STATE(4912)] = 187663,
  [SMALL_STATE(4913)] = 187733,
  [SMALL_STATE(4914)] = 187797,
  [SMALL_STATE(4915)] = 187861,
  [SMALL_STATE(4916)] = 187927,
  [SMALL_STATE(4917)] = 187991,
  [SMALL_STATE(4918)] = 188055,
  [SMALL_STATE(4919)] = 188119,
  [SMALL_STATE(4920)] = 188183,
  [SMALL_STATE(4921)] = 188247,
  [SMALL_STATE(4922)] = 188317,
  [SMALL_STATE(4923)] = 188381,
  [SMALL_STATE(4924)] = 188445,
  [SMALL_STATE(4925)] = 188509,
  [SMALL_STATE(4926)] = 188573,
  [SMALL_STATE(4927)] = 188685,
  [SMALL_STATE(4928)] = 188749,
  [SMALL_STATE(4929)] = 188813,
  [SMALL_STATE(4930)] = 188877,
  [SMALL_STATE(4931)] = 188941,
  [SMALL_STATE(4932)] = 189005,
  [SMALL_STATE(4933)] = 189069,
  [SMALL_STATE(4934)] = 189133,
  [SMALL_STATE(4935)] = 189197,
  [SMALL_STATE(4936)] = 189261,
  [SMALL_STATE(4937)] = 189325,
  [SMALL_STATE(4938)] = 189389,
  [SMALL_STATE(4939)] = 189453,
  [SMALL_STATE(4940)] = 189517,
  [SMALL_STATE(4941)] = 189581,
  [SMALL_STATE(4942)] = 189693,
  [SMALL_STATE(4943)] = 189757,
  [SMALL_STATE(4944)] = 189821,
  [SMALL_STATE(4945)] = 189933,
  [SMALL_STATE(4946)] = 189999,
  [SMALL_STATE(4947)] = 190063,
  [SMALL_STATE(4948)] = 190127,
  [SMALL_STATE(4949)] = 190239,
  [SMALL_STATE(4950)] = 190303,
  [SMALL_STATE(4951)] = 190367,
  [SMALL_STATE(4952)] = 190431,
  [SMALL_STATE(4953)] = 190495,
  [SMALL_STATE(4954)] = 190559,
  [SMALL_STATE(4955)] = 190625,
  [SMALL_STATE(4956)] = 190689,
  [SMALL_STATE(4957)] = 190753,
  [SMALL_STATE(4958)] = 190817,
  [SMALL_STATE(4959)] = 190881,
  [SMALL_STATE(4960)] = 190945,
  [SMALL_STATE(4961)] = 191009,
  [SMALL_STATE(4962)] = 191073,
  [SMALL_STATE(4963)] = 191137,
  [SMALL_STATE(4964)] = 191201,
  [SMALL_STATE(4965)] = 191267,
  [SMALL_STATE(4966)] = 191331,
  [SMALL_STATE(4967)] = 191395,
  [SMALL_STATE(4968)] = 191459,
  [SMALL_STATE(4969)] = 191523,
  [SMALL_STATE(4970)] = 191587,
  [SMALL_STATE(4971)] = 191651,
  [SMALL_STATE(4972)] = 191715,
  [SMALL_STATE(4973)] = 191779,
  [SMALL_STATE(4974)] = 191843,
  [SMALL_STATE(4975)] = 191907,
  [SMALL_STATE(4976)] = 191971,
  [SMALL_STATE(4977)] = 192083,
  [SMALL_STATE(4978)] = 192147,
  [SMALL_STATE(4979)] = 192211,
  [SMALL_STATE(4980)] = 192277,
  [SMALL_STATE(4981)] = 192341,
  [SMALL_STATE(4982)] = 192453,
  [SMALL_STATE(4983)] = 192517,
  [SMALL_STATE(4984)] = 192581,
  [SMALL_STATE(4985)] = 192645,
  [SMALL_STATE(4986)] = 192709,
  [SMALL_STATE(4987)] = 192773,
  [SMALL_STATE(4988)] = 192837,
  [SMALL_STATE(4989)] = 192901,
  [SMALL_STATE(4990)] = 192965,
  [SMALL_STATE(4991)] = 193029,
  [SMALL_STATE(4992)] = 193093,
  [SMALL_STATE(4993)] = 193205,
  [SMALL_STATE(4994)] = 193269,
  [SMALL_STATE(4995)] = 193334,
  [SMALL_STATE(4996)] = 193399,
  [SMALL_STATE(4997)] = 193508,
  [SMALL_STATE(4998)] = 193571,
  [SMALL_STATE(4999)] = 193680,
  [SMALL_STATE(5000)] = 193743,
  [SMALL_STATE(5001)] = 193806,
  [SMALL_STATE(5002)] = 193869,
  [SMALL_STATE(5003)] = 193978,
  [SMALL_STATE(5004)] = 194041,
  [SMALL_STATE(5005)] = 194150,
  [SMALL_STATE(5006)] = 194213,
  [SMALL_STATE(5007)] = 194322,
  [SMALL_STATE(5008)] = 194385,
  [SMALL_STATE(5009)] = 194494,
  [SMALL_STATE(5010)] = 194557,
  [SMALL_STATE(5011)] = 194666,
  [SMALL_STATE(5012)] = 194731,
  [SMALL_STATE(5013)] = 194840,
  [SMALL_STATE(5014)] = 194903,
  [SMALL_STATE(5015)] = 194966,
  [SMALL_STATE(5016)] = 195029,
  [SMALL_STATE(5017)] = 195138,
  [SMALL_STATE(5018)] = 195201,
  [SMALL_STATE(5019)] = 195264,
  [SMALL_STATE(5020)] = 195327,
  [SMALL_STATE(5021)] = 195390,
  [SMALL_STATE(5022)] = 195453,
  [SMALL_STATE(5023)] = 195516,
  [SMALL_STATE(5024)] = 195579,
  [SMALL_STATE(5025)] = 195642,
  [SMALL_STATE(5026)] = 195751,
  [SMALL_STATE(5027)] = 195814,
  [SMALL_STATE(5028)] = 195923,
  [SMALL_STATE(5029)] = 196032,
  [SMALL_STATE(5030)] = 196141,
  [SMALL_STATE(5031)] = 196210,
  [SMALL_STATE(5032)] = 196319,
  [SMALL_STATE(5033)] = 196428,
  [SMALL_STATE(5034)] = 196491,
  [SMALL_STATE(5035)] = 196554,
  [SMALL_STATE(5036)] = 196663,
  [SMALL_STATE(5037)] = 196772,
  [SMALL_STATE(5038)] = 196881,
  [SMALL_STATE(5039)] = 196944,
  [SMALL_STATE(5040)] = 197053,
  [SMALL_STATE(5041)] = 197116,
  [SMALL_STATE(5042)] = 197225,
  [SMALL_STATE(5043)] = 197288,
  [SMALL_STATE(5044)] = 197351,
  [SMALL_STATE(5045)] = 197414,
  [SMALL_STATE(5046)] = 197477,
  [SMALL_STATE(5047)] = 197540,
  [SMALL_STATE(5048)] = 197649,
  [SMALL_STATE(5049)] = 197712,
  [SMALL_STATE(5050)] = 197821,
  [SMALL_STATE(5051)] = 197886,
  [SMALL_STATE(5052)] = 197995,
  [SMALL_STATE(5053)] = 198106,
  [SMALL_STATE(5054)] = 198215,
  [SMALL_STATE(5055)] = 198324,
  [SMALL_STATE(5056)] = 198433,
  [SMALL_STATE(5057)] = 198542,
  [SMALL_STATE(5058)] = 198605,
  [SMALL_STATE(5059)] = 198714,
  [SMALL_STATE(5060)] = 198777,
  [SMALL_STATE(5061)] = 198886,
  [SMALL_STATE(5062)] = 198949,
  [SMALL_STATE(5063)] = 199058,
  [SMALL_STATE(5064)] = 199121,
  [SMALL_STATE(5065)] = 199184,
  [SMALL_STATE(5066)] = 199247,
  [SMALL_STATE(5067)] = 199356,
  [SMALL_STATE(5068)] = 199419,
  [SMALL_STATE(5069)] = 199482,
  [SMALL_STATE(5070)] = 199591,
  [SMALL_STATE(5071)] = 199654,
  [SMALL_STATE(5072)] = 199763,
  [SMALL_STATE(5073)] = 199826,
  [SMALL_STATE(5074)] = 199935,
  [SMALL_STATE(5075)] = 199998,
  [SMALL_STATE(5076)] = 200061,
  [SMALL_STATE(5077)] = 200130,
  [SMALL_STATE(5078)] = 200193,
  [SMALL_STATE(5079)] = 200302,
  [SMALL_STATE(5080)] = 200365,
  [SMALL_STATE(5081)] = 200474,
  [SMALL_STATE(5082)] = 200537,
  [SMALL_STATE(5083)] = 200600,
  [SMALL_STATE(5084)] = 200663,
  [SMALL_STATE(5085)] = 200726,
  [SMALL_STATE(5086)] = 200791,
  [SMALL_STATE(5087)] = 200854,
  [SMALL_STATE(5088)] = 200963,
  [SMALL_STATE(5089)] = 201026,
  [SMALL_STATE(5090)] = 201089,
  [SMALL_STATE(5091)] = 201200,
  [SMALL_STATE(5092)] = 201263,
  [SMALL_STATE(5093)] = 201372,
  [SMALL_STATE(5094)] = 201437,
  [SMALL_STATE(5095)] = 201546,
  [SMALL_STATE(5096)] = 201609,
  [SMALL_STATE(5097)] = 201672,
  [SMALL_STATE(5098)] = 201783,
  [SMALL_STATE(5099)] = 201892,
  [SMALL_STATE(5100)] = 202001,
  [SMALL_STATE(5101)] = 202064,
  [SMALL_STATE(5102)] = 202129,
  [SMALL_STATE(5103)] = 202192,
  [SMALL_STATE(5104)] = 202255,
  [SMALL_STATE(5105)] = 202318,
  [SMALL_STATE(5106)] = 202381,
  [SMALL_STATE(5107)] = 202444,
  [SMALL_STATE(5108)] = 202507,
  [SMALL_STATE(5109)] = 202616,
  [SMALL_STATE(5110)] = 202679,
  [SMALL_STATE(5111)] = 202742,
  [SMALL_STATE(5112)] = 202805,
  [SMALL_STATE(5113)] = 202914,
  [SMALL_STATE(5114)] = 202977,
  [SMALL_STATE(5115)] = 203086,
  [SMALL_STATE(5116)] = 203149,
  [SMALL_STATE(5117)] = 203212,
  [SMALL_STATE(5118)] = 203275,
  [SMALL_STATE(5119)] = 203384,
  [SMALL_STATE(5120)] = 203449,
  [SMALL_STATE(5121)] = 203558,
  [SMALL_STATE(5122)] = 203621,
  [SMALL_STATE(5123)] = 203684,
  [SMALL_STATE(5124)] = 203747,
  [SMALL_STATE(5125)] = 203810,
  [SMALL_STATE(5126)] = 203873,
  [SMALL_STATE(5127)] = 203936,
  [SMALL_STATE(5128)] = 203999,
  [SMALL_STATE(5129)] = 204062,
  [SMALL_STATE(5130)] = 204125,
  [SMALL_STATE(5131)] = 204188,
  [SMALL_STATE(5132)] = 204251,
  [SMALL_STATE(5133)] = 204314,
  [SMALL_STATE(5134)] = 204423,
  [SMALL_STATE(5135)] = 204532,
  [SMALL_STATE(5136)] = 204641,
  [SMALL_STATE(5137)] = 204704,
  [SMALL_STATE(5138)] = 204767,
  [SMALL_STATE(5139)] = 204876,
  [SMALL_STATE(5140)] = 204939,
  [SMALL_STATE(5141)] = 205048,
  [SMALL_STATE(5142)] = 205111,
  [SMALL_STATE(5143)] = 205176,
  [SMALL_STATE(5144)] = 205285,
  [SMALL_STATE(5145)] = 205394,
  [SMALL_STATE(5146)] = 205457,
  [SMALL_STATE(5147)] = 205519,
  [SMALL_STATE(5148)] = 205581,
  [SMALL_STATE(5149)] = 205643,
  [SMALL_STATE(5150)] = 205705,
  [SMALL_STATE(5151)] = 205767,
  [SMALL_STATE(5152)] = 205831,
  [SMALL_STATE(5153)] = 205893,
  [SMALL_STATE(5154)] = 205955,
  [SMALL_STATE(5155)] = 206017,
  [SMALL_STATE(5156)] = 206081,
  [SMALL_STATE(5157)] = 206143,
  [SMALL_STATE(5158)] = 206205,
  [SMALL_STATE(5159)] = 206267,
  [SMALL_STATE(5160)] = 206329,
  [SMALL_STATE(5161)] = 206393,
  [SMALL_STATE(5162)] = 206455,
  [SMALL_STATE(5163)] = 206517,
  [SMALL_STATE(5164)] = 206579,
  [SMALL_STATE(5165)] = 206641,
  [SMALL_STATE(5166)] = 206703,
  [SMALL_STATE(5167)] = 206765,
  [SMALL_STATE(5168)] = 206827,
  [SMALL_STATE(5169)] = 206889,
  [SMALL_STATE(5170)] = 206951,
  [SMALL_STATE(5171)] = 207013,
  [SMALL_STATE(5172)] = 207075,
  [SMALL_STATE(5173)] = 207137,
  [SMALL_STATE(5174)] = 207199,
  [SMALL_STATE(5175)] = 207261,
  [SMALL_STATE(5176)] = 207323,
  [SMALL_STATE(5177)] = 207385,
  [SMALL_STATE(5178)] = 207447,
  [SMALL_STATE(5179)] = 207509,
  [SMALL_STATE(5180)] = 207571,
  [SMALL_STATE(5181)] = 207633,
  [SMALL_STATE(5182)] = 207697,
  [SMALL_STATE(5183)] = 207759,
  [SMALL_STATE(5184)] = 207821,
  [SMALL_STATE(5185)] = 207885,
  [SMALL_STATE(5186)] = 207947,
  [SMALL_STATE(5187)] = 208009,
  [SMALL_STATE(5188)] = 208073,
  [SMALL_STATE(5189)] = 208135,
  [SMALL_STATE(5190)] = 208197,
  [SMALL_STATE(5191)] = 208259,
  [SMALL_STATE(5192)] = 208321,
  [SMALL_STATE(5193)] = 208383,
  [SMALL_STATE(5194)] = 208445,
  [SMALL_STATE(5195)] = 208507,
  [SMALL_STATE(5196)] = 208569,
  [SMALL_STATE(5197)] = 208631,
  [SMALL_STATE(5198)] = 208695,
  [SMALL_STATE(5199)] = 208763,
  [SMALL_STATE(5200)] = 208831,
  [SMALL_STATE(5201)] = 208893,
  [SMALL_STATE(5202)] = 208955,
  [SMALL_STATE(5203)] = 209017,
  [SMALL_STATE(5204)] = 209079,
  [SMALL_STATE(5205)] = 209141,
  [SMALL_STATE(5206)] = 209203,
  [SMALL_STATE(5207)] = 209265,
  [SMALL_STATE(5208)] = 209329,
  [SMALL_STATE(5209)] = 209391,
  [SMALL_STATE(5210)] = 209453,
  [SMALL_STATE(5211)] = 209515,
  [SMALL_STATE(5212)] = 209577,
  [SMALL_STATE(5213)] = 209639,
  [SMALL_STATE(5214)] = 209701,
  [SMALL_STATE(5215)] = 209763,
  [SMALL_STATE(5216)] = 209825,
  [SMALL_STATE(5217)] = 209887,
  [SMALL_STATE(5218)] = 209949,
  [SMALL_STATE(5219)] = 210011,
  [SMALL_STATE(5220)] = 210073,
  [SMALL_STATE(5221)] = 210135,
  [SMALL_STATE(5222)] = 210197,
  [SMALL_STATE(5223)] = 210259,
  [SMALL_STATE(5224)] = 210321,
  [SMALL_STATE(5225)] = 210383,
  [SMALL_STATE(5226)] = 210445,
  [SMALL_STATE(5227)] = 210507,
  [SMALL_STATE(5228)] = 210569,
  [SMALL_STATE(5229)] = 210631,
  [SMALL_STATE(5230)] = 210693,
  [SMALL_STATE(5231)] = 210757,
  [SMALL_STATE(5232)] = 210819,
  [SMALL_STATE(5233)] = 210881,
  [SMALL_STATE(5234)] = 210943,
  [SMALL_STATE(5235)] = 211005,
  [SMALL_STATE(5236)] = 211067,
  [SMALL_STATE(5237)] = 211129,
  [SMALL_STATE(5238)] = 211191,
  [SMALL_STATE(5239)] = 211253,
  [SMALL_STATE(5240)] = 211315,
  [SMALL_STATE(5241)] = 211377,
  [SMALL_STATE(5242)] = 211439,
  [SMALL_STATE(5243)] = 211501,
  [SMALL_STATE(5244)] = 211563,
  [SMALL_STATE(5245)] = 211631,
  [SMALL_STATE(5246)] = 211693,
  [SMALL_STATE(5247)] = 211755,
  [SMALL_STATE(5248)] = 211817,
  [SMALL_STATE(5249)] = 211879,
  [SMALL_STATE(5250)] = 211943,
  [SMALL_STATE(5251)] = 212005,
  [SMALL_STATE(5252)] = 212067,
  [SMALL_STATE(5253)] = 212129,
  [SMALL_STATE(5254)] = 212191,
  [SMALL_STATE(5255)] = 212253,
  [SMALL_STATE(5256)] = 212315,
  [SMALL_STATE(5257)] = 212377,
  [SMALL_STATE(5258)] = 212439,
  [SMALL_STATE(5259)] = 212501,
  [SMALL_STATE(5260)] = 212563,
  [SMALL_STATE(5261)] = 212625,
  [SMALL_STATE(5262)] = 212687,
  [SMALL_STATE(5263)] = 212749,
  [SMALL_STATE(5264)] = 212811,
  [SMALL_STATE(5265)] = 212873,
  [SMALL_STATE(5266)] = 212935,
  [SMALL_STATE(5267)] = 212997,
  [SMALL_STATE(5268)] = 213059,
  [SMALL_STATE(5269)] = 213121,
  [SMALL_STATE(5270)] = 213183,
  [SMALL_STATE(5271)] = 213245,
  [SMALL_STATE(5272)] = 213307,
  [SMALL_STATE(5273)] = 213369,
  [SMALL_STATE(5274)] = 213431,
  [SMALL_STATE(5275)] = 213493,
  [SMALL_STATE(5276)] = 213555,
  [SMALL_STATE(5277)] = 213617,
  [SMALL_STATE(5278)] = 213681,
  [SMALL_STATE(5279)] = 213743,
  [SMALL_STATE(5280)] = 213805,
  [SMALL_STATE(5281)] = 213867,
  [SMALL_STATE(5282)] = 213929,
  [SMALL_STATE(5283)] = 213997,
  [SMALL_STATE(5284)] = 214059,
  [SMALL_STATE(5285)] = 214121,
  [SMALL_STATE(5286)] = 214183,
  [SMALL_STATE(5287)] = 214245,
  [SMALL_STATE(5288)] = 214309,
  [SMALL_STATE(5289)] = 214371,
  [SMALL_STATE(5290)] = 214433,
  [SMALL_STATE(5291)] = 214495,
  [SMALL_STATE(5292)] = 214557,
  [SMALL_STATE(5293)] = 214619,
  [SMALL_STATE(5294)] = 214681,
  [SMALL_STATE(5295)] = 214743,
  [SMALL_STATE(5296)] = 214805,
  [SMALL_STATE(5297)] = 214867,
  [SMALL_STATE(5298)] = 214929,
  [SMALL_STATE(5299)] = 214991,
  [SMALL_STATE(5300)] = 215053,
  [SMALL_STATE(5301)] = 215115,
  [SMALL_STATE(5302)] = 215179,
  [SMALL_STATE(5303)] = 215241,
  [SMALL_STATE(5304)] = 215303,
  [SMALL_STATE(5305)] = 215365,
  [SMALL_STATE(5306)] = 215427,
  [SMALL_STATE(5307)] = 215489,
  [SMALL_STATE(5308)] = 215553,
  [SMALL_STATE(5309)] = 215615,
  [SMALL_STATE(5310)] = 215677,
  [SMALL_STATE(5311)] = 215739,
  [SMALL_STATE(5312)] = 215800,
  [SMALL_STATE(5313)] = 215861,
  [SMALL_STATE(5314)] = 215922,
  [SMALL_STATE(5315)] = 215983,
  [SMALL_STATE(5316)] = 216046,
  [SMALL_STATE(5317)] = 216107,
  [SMALL_STATE(5318)] = 216168,
  [SMALL_STATE(5319)] = 216229,
  [SMALL_STATE(5320)] = 216290,
  [SMALL_STATE(5321)] = 216351,
  [SMALL_STATE(5322)] = 216412,
  [SMALL_STATE(5323)] = 216473,
  [SMALL_STATE(5324)] = 216534,
  [SMALL_STATE(5325)] = 216595,
  [SMALL_STATE(5326)] = 216656,
  [SMALL_STATE(5327)] = 216717,
  [SMALL_STATE(5328)] = 216778,
  [SMALL_STATE(5329)] = 216839,
  [SMALL_STATE(5330)] = 216900,
  [SMALL_STATE(5331)] = 216961,
  [SMALL_STATE(5332)] = 217022,
  [SMALL_STATE(5333)] = 217083,
  [SMALL_STATE(5334)] = 217144,
  [SMALL_STATE(5335)] = 217205,
  [SMALL_STATE(5336)] = 217268,
  [SMALL_STATE(5337)] = 217329,
  [SMALL_STATE(5338)] = 217390,
  [SMALL_STATE(5339)] = 217451,
  [SMALL_STATE(5340)] = 217512,
  [SMALL_STATE(5341)] = 217573,
  [SMALL_STATE(5342)] = 217634,
  [SMALL_STATE(5343)] = 217697,
  [SMALL_STATE(5344)] = 217758,
  [SMALL_STATE(5345)] = 217819,
  [SMALL_STATE(5346)] = 217880,
  [SMALL_STATE(5347)] = 217941,
  [SMALL_STATE(5348)] = 218002,
  [SMALL_STATE(5349)] = 218063,
  [SMALL_STATE(5350)] = 218126,
  [SMALL_STATE(5351)] = 218187,
  [SMALL_STATE(5352)] = 218248,
  [SMALL_STATE(5353)] = 218309,
  [SMALL_STATE(5354)] = 218372,
  [SMALL_STATE(5355)] = 218433,
  [SMALL_STATE(5356)] = 218494,
  [SMALL_STATE(5357)] = 218555,
  [SMALL_STATE(5358)] = 218616,
  [SMALL_STATE(5359)] = 218679,
  [SMALL_STATE(5360)] = 218746,
  [SMALL_STATE(5361)] = 218807,
  [SMALL_STATE(5362)] = 218868,
  [SMALL_STATE(5363)] = 218929,
  [SMALL_STATE(5364)] = 218992,
  [SMALL_STATE(5365)] = 219053,
  [SMALL_STATE(5366)] = 219114,
  [SMALL_STATE(5367)] = 219175,
  [SMALL_STATE(5368)] = 219236,
  [SMALL_STATE(5369)] = 219297,
  [SMALL_STATE(5370)] = 219358,
  [SMALL_STATE(5371)] = 219419,
  [SMALL_STATE(5372)] = 219486,
  [SMALL_STATE(5373)] = 219547,
  [SMALL_STATE(5374)] = 219608,
  [SMALL_STATE(5375)] = 219669,
  [SMALL_STATE(5376)] = 219730,
  [SMALL_STATE(5377)] = 219791,
  [SMALL_STATE(5378)] = 219852,
  [SMALL_STATE(5379)] = 219913,
  [SMALL_STATE(5380)] = 219974,
  [SMALL_STATE(5381)] = 220035,
  [SMALL_STATE(5382)] = 220096,
  [SMALL_STATE(5383)] = 220157,
  [SMALL_STATE(5384)] = 220218,
  [SMALL_STATE(5385)] = 220279,
  [SMALL_STATE(5386)] = 220342,
  [SMALL_STATE(5387)] = 220403,
  [SMALL_STATE(5388)] = 220464,
  [SMALL_STATE(5389)] = 220525,
  [SMALL_STATE(5390)] = 220586,
  [SMALL_STATE(5391)] = 220647,
  [SMALL_STATE(5392)] = 220708,
  [SMALL_STATE(5393)] = 220769,
  [SMALL_STATE(5394)] = 220830,
  [SMALL_STATE(5395)] = 220891,
  [SMALL_STATE(5396)] = 220954,
  [SMALL_STATE(5397)] = 221015,
  [SMALL_STATE(5398)] = 221076,
  [SMALL_STATE(5399)] = 221137,
  [SMALL_STATE(5400)] = 221198,
  [SMALL_STATE(5401)] = 221259,
  [SMALL_STATE(5402)] = 221320,
  [SMALL_STATE(5403)] = 221381,
  [SMALL_STATE(5404)] = 221442,
  [SMALL_STATE(5405)] = 221503,
  [SMALL_STATE(5406)] = 221566,
  [SMALL_STATE(5407)] = 221627,
  [SMALL_STATE(5408)] = 221688,
  [SMALL_STATE(5409)] = 221749,
  [SMALL_STATE(5410)] = 221810,
  [SMALL_STATE(5411)] = 221871,
  [SMALL_STATE(5412)] = 221932,
  [SMALL_STATE(5413)] = 221993,
  [SMALL_STATE(5414)] = 222054,
  [SMALL_STATE(5415)] = 222115,
  [SMALL_STATE(5416)] = 222176,
  [SMALL_STATE(5417)] = 222237,
  [SMALL_STATE(5418)] = 222298,
  [SMALL_STATE(5419)] = 222361,
  [SMALL_STATE(5420)] = 222422,
  [SMALL_STATE(5421)] = 222483,
  [SMALL_STATE(5422)] = 222544,
  [SMALL_STATE(5423)] = 222605,
  [SMALL_STATE(5424)] = 222666,
  [SMALL_STATE(5425)] = 222726,
  [SMALL_STATE(5426)] = 222786,
  [SMALL_STATE(5427)] = 222846,
  [SMALL_STATE(5428)] = 222906,
  [SMALL_STATE(5429)] = 222966,
  [SMALL_STATE(5430)] = 223026,
  [SMALL_STATE(5431)] = 223086,
  [SMALL_STATE(5432)] = 223146,
  [SMALL_STATE(5433)] = 223206,
  [SMALL_STATE(5434)] = 223266,
  [SMALL_STATE(5435)] = 223326,
  [SMALL_STATE(5436)] = 223386,
  [SMALL_STATE(5437)] = 223446,
  [SMALL_STATE(5438)] = 223506,
  [SMALL_STATE(5439)] = 223566,
  [SMALL_STATE(5440)] = 223626,
  [SMALL_STATE(5441)] = 223686,
  [SMALL_STATE(5442)] = 223746,
  [SMALL_STATE(5443)] = 223806,
  [SMALL_STATE(5444)] = 223868,
  [SMALL_STATE(5445)] = 223928,
  [SMALL_STATE(5446)] = 223988,
  [SMALL_STATE(5447)] = 224048,
  [SMALL_STATE(5448)] = 224110,
  [SMALL_STATE(5449)] = 224170,
  [SMALL_STATE(5450)] = 224230,
  [SMALL_STATE(5451)] = 224290,
  [SMALL_STATE(5452)] = 224350,
  [SMALL_STATE(5453)] = 224410,
  [SMALL_STATE(5454)] = 224470,
  [SMALL_STATE(5455)] = 224530,
  [SMALL_STATE(5456)] = 224590,
  [SMALL_STATE(5457)] = 224650,
  [SMALL_STATE(5458)] = 224710,
  [SMALL_STATE(5459)] = 224770,
  [SMALL_STATE(5460)] = 224830,
  [SMALL_STATE(5461)] = 224890,
  [SMALL_STATE(5462)] = 224950,
  [SMALL_STATE(5463)] = 225010,
  [SMALL_STATE(5464)] = 225070,
  [SMALL_STATE(5465)] = 225130,
  [SMALL_STATE(5466)] = 225190,
  [SMALL_STATE(5467)] = 225250,
  [SMALL_STATE(5468)] = 225310,
  [SMALL_STATE(5469)] = 225374,
  [SMALL_STATE(5470)] = 225434,
  [SMALL_STATE(5471)] = 225494,
  [SMALL_STATE(5472)] = 225554,
  [SMALL_STATE(5473)] = 225614,
  [SMALL_STATE(5474)] = 225674,
  [SMALL_STATE(5475)] = 225734,
  [SMALL_STATE(5476)] = 225794,
  [SMALL_STATE(5477)] = 225854,
  [SMALL_STATE(5478)] = 225914,
  [SMALL_STATE(5479)] = 225974,
  [SMALL_STATE(5480)] = 226034,
  [SMALL_STATE(5481)] = 226094,
  [SMALL_STATE(5482)] = 226154,
  [SMALL_STATE(5483)] = 226216,
  [SMALL_STATE(5484)] = 226276,
  [SMALL_STATE(5485)] = 226336,
  [SMALL_STATE(5486)] = 226396,
  [SMALL_STATE(5487)] = 226456,
  [SMALL_STATE(5488)] = 226516,
  [SMALL_STATE(5489)] = 226576,
  [SMALL_STATE(5490)] = 226636,
  [SMALL_STATE(5491)] = 226696,
  [SMALL_STATE(5492)] = 226756,
  [SMALL_STATE(5493)] = 226816,
  [SMALL_STATE(5494)] = 226876,
  [SMALL_STATE(5495)] = 226936,
  [SMALL_STATE(5496)] = 226996,
  [SMALL_STATE(5497)] = 227056,
  [SMALL_STATE(5498)] = 227116,
  [SMALL_STATE(5499)] = 227176,
  [SMALL_STATE(5500)] = 227236,
  [SMALL_STATE(5501)] = 227296,
  [SMALL_STATE(5502)] = 227356,
  [SMALL_STATE(5503)] = 227416,
  [SMALL_STATE(5504)] = 227478,
  [SMALL_STATE(5505)] = 227538,
  [SMALL_STATE(5506)] = 227598,
  [SMALL_STATE(5507)] = 227658,
  [SMALL_STATE(5508)] = 227720,
  [SMALL_STATE(5509)] = 227780,
  [SMALL_STATE(5510)] = 227840,
  [SMALL_STATE(5511)] = 227900,
  [SMALL_STATE(5512)] = 227960,
  [SMALL_STATE(5513)] = 228020,
  [SMALL_STATE(5514)] = 228080,
  [SMALL_STATE(5515)] = 228140,
  [SMALL_STATE(5516)] = 228200,
  [SMALL_STATE(5517)] = 228260,
  [SMALL_STATE(5518)] = 228320,
  [SMALL_STATE(5519)] = 228380,
  [SMALL_STATE(5520)] = 228440,
  [SMALL_STATE(5521)] = 228500,
  [SMALL_STATE(5522)] = 228560,
  [SMALL_STATE(5523)] = 228620,
  [SMALL_STATE(5524)] = 228680,
  [SMALL_STATE(5525)] = 228740,
  [SMALL_STATE(5526)] = 228800,
  [SMALL_STATE(5527)] = 228860,
  [SMALL_STATE(5528)] = 228920,
  [SMALL_STATE(5529)] = 228982,
  [SMALL_STATE(5530)] = 229042,
  [SMALL_STATE(5531)] = 229102,
  [SMALL_STATE(5532)] = 229162,
  [SMALL_STATE(5533)] = 229222,
  [SMALL_STATE(5534)] = 229282,
  [SMALL_STATE(5535)] = 229342,
  [SMALL_STATE(5536)] = 229404,
  [SMALL_STATE(5537)] = 229464,
  [SMALL_STATE(5538)] = 229524,
  [SMALL_STATE(5539)] = 229584,
  [SMALL_STATE(5540)] = 229644,
  [SMALL_STATE(5541)] = 229704,
  [SMALL_STATE(5542)] = 229764,
  [SMALL_STATE(5543)] = 229824,
  [SMALL_STATE(5544)] = 229884,
  [SMALL_STATE(5545)] = 229944,
  [SMALL_STATE(5546)] = 230004,
  [SMALL_STATE(5547)] = 230064,
  [SMALL_STATE(5548)] = 230124,
  [SMALL_STATE(5549)] = 230188,
  [SMALL_STATE(5550)] = 230248,
  [SMALL_STATE(5551)] = 230308,
  [SMALL_STATE(5552)] = 230368,
  [SMALL_STATE(5553)] = 230428,
  [SMALL_STATE(5554)] = 230488,
  [SMALL_STATE(5555)] = 230548,
  [SMALL_STATE(5556)] = 230608,
  [SMALL_STATE(5557)] = 230668,
  [SMALL_STATE(5558)] = 230728,
  [SMALL_STATE(5559)] = 230788,
  [SMALL_STATE(5560)] = 230848,
  [SMALL_STATE(5561)] = 230910,
  [SMALL_STATE(5562)] = 230972,
  [SMALL_STATE(5563)] = 231032,
  [SMALL_STATE(5564)] = 231094,
  [SMALL_STATE(5565)] = 231154,
  [SMALL_STATE(5566)] = 231214,
  [SMALL_STATE(5567)] = 231274,
  [SMALL_STATE(5568)] = 231333,
  [SMALL_STATE(5569)] = 231392,
  [SMALL_STATE(5570)] = 231451,
  [SMALL_STATE(5571)] = 231510,
  [SMALL_STATE(5572)] = 231569,
  [SMALL_STATE(5573)] = 231628,
  [SMALL_STATE(5574)] = 231687,
  [SMALL_STATE(5575)] = 231746,
  [SMALL_STATE(5576)] = 231805,
  [SMALL_STATE(5577)] = 231864,
  [SMALL_STATE(5578)] = 231923,
  [SMALL_STATE(5579)] = 231982,
  [SMALL_STATE(5580)] = 232041,
  [SMALL_STATE(5581)] = 232100,
  [SMALL_STATE(5582)] = 232159,
  [SMALL_STATE(5583)] = 232218,
  [SMALL_STATE(5584)] = 232277,
  [SMALL_STATE(5585)] = 232336,
  [SMALL_STATE(5586)] = 232395,
  [SMALL_STATE(5587)] = 232454,
  [SMALL_STATE(5588)] = 232513,
  [SMALL_STATE(5589)] = 232572,
  [SMALL_STATE(5590)] = 232631,
  [SMALL_STATE(5591)] = 232690,
  [SMALL_STATE(5592)] = 232749,
  [SMALL_STATE(5593)] = 232808,
  [SMALL_STATE(5594)] = 232867,
  [SMALL_STATE(5595)] = 232926,
  [SMALL_STATE(5596)] = 232985,
  [SMALL_STATE(5597)] = 233044,
  [SMALL_STATE(5598)] = 233103,
  [SMALL_STATE(5599)] = 233164,
  [SMALL_STATE(5600)] = 233223,
  [SMALL_STATE(5601)] = 233282,
  [SMALL_STATE(5602)] = 233341,
  [SMALL_STATE(5603)] = 233402,
  [SMALL_STATE(5604)] = 233461,
  [SMALL_STATE(5605)] = 233520,
  [SMALL_STATE(5606)] = 233579,
  [SMALL_STATE(5607)] = 233638,
  [SMALL_STATE(5608)] = 233697,
  [SMALL_STATE(5609)] = 233758,
  [SMALL_STATE(5610)] = 233817,
  [SMALL_STATE(5611)] = 233876,
  [SMALL_STATE(5612)] = 233935,
  [SMALL_STATE(5613)] = 233994,
  [SMALL_STATE(5614)] = 234053,
  [SMALL_STATE(5615)] = 234112,
  [SMALL_STATE(5616)] = 234171,
  [SMALL_STATE(5617)] = 234230,
  [SMALL_STATE(5618)] = 234289,
  [SMALL_STATE(5619)] = 234350,
  [SMALL_STATE(5620)] = 234409,
  [SMALL_STATE(5621)] = 234468,
  [SMALL_STATE(5622)] = 234527,
  [SMALL_STATE(5623)] = 234586,
  [SMALL_STATE(5624)] = 234645,
  [SMALL_STATE(5625)] = 234704,
  [SMALL_STATE(5626)] = 234763,
  [SMALL_STATE(5627)] = 234822,
  [SMALL_STATE(5628)] = 234881,
  [SMALL_STATE(5629)] = 234940,
  [SMALL_STATE(5630)] = 234999,
  [SMALL_STATE(5631)] = 235058,
  [SMALL_STATE(5632)] = 235117,
  [SMALL_STATE(5633)] = 235176,
  [SMALL_STATE(5634)] = 235235,
  [SMALL_STATE(5635)] = 235294,
  [SMALL_STATE(5636)] = 235353,
  [SMALL_STATE(5637)] = 235414,
  [SMALL_STATE(5638)] = 235473,
  [SMALL_STATE(5639)] = 235536,
  [SMALL_STATE(5640)] = 235597,
  [SMALL_STATE(5641)] = 235656,
  [SMALL_STATE(5642)] = 235715,
  [SMALL_STATE(5643)] = 235774,
  [SMALL_STATE(5644)] = 235833,
  [SMALL_STATE(5645)] = 235892,
  [SMALL_STATE(5646)] = 235951,
  [SMALL_STATE(5647)] = 236010,
  [SMALL_STATE(5648)] = 236069,
  [SMALL_STATE(5649)] = 236128,
  [SMALL_STATE(5650)] = 236187,
  [SMALL_STATE(5651)] = 236246,
  [SMALL_STATE(5652)] = 236305,
  [SMALL_STATE(5653)] = 236364,
  [SMALL_STATE(5654)] = 236423,
  [SMALL_STATE(5655)] = 236482,
  [SMALL_STATE(5656)] = 236541,
  [SMALL_STATE(5657)] = 236600,
  [SMALL_STATE(5658)] = 236659,
  [SMALL_STATE(5659)] = 236718,
  [SMALL_STATE(5660)] = 236777,
  [SMALL_STATE(5661)] = 236838,
  [SMALL_STATE(5662)] = 236897,
  [SMALL_STATE(5663)] = 236958,
  [SMALL_STATE(5664)] = 237017,
  [SMALL_STATE(5665)] = 237076,
  [SMALL_STATE(5666)] = 237135,
  [SMALL_STATE(5667)] = 237194,
  [SMALL_STATE(5668)] = 237253,
  [SMALL_STATE(5669)] = 237312,
  [SMALL_STATE(5670)] = 237371,
  [SMALL_STATE(5671)] = 237430,
  [SMALL_STATE(5672)] = 237489,
  [SMALL_STATE(5673)] = 237548,
  [SMALL_STATE(5674)] = 237607,
  [SMALL_STATE(5675)] = 237666,
  [SMALL_STATE(5676)] = 237725,
  [SMALL_STATE(5677)] = 237784,
  [SMALL_STATE(5678)] = 237843,
  [SMALL_STATE(5679)] = 237902,
  [SMALL_STATE(5680)] = 237961,
  [SMALL_STATE(5681)] = 238020,
  [SMALL_STATE(5682)] = 238079,
  [SMALL_STATE(5683)] = 238138,
  [SMALL_STATE(5684)] = 238197,
  [SMALL_STATE(5685)] = 238256,
  [SMALL_STATE(5686)] = 238315,
  [SMALL_STATE(5687)] = 238374,
  [SMALL_STATE(5688)] = 238433,
  [SMALL_STATE(5689)] = 238492,
  [SMALL_STATE(5690)] = 238551,
  [SMALL_STATE(5691)] = 238610,
  [SMALL_STATE(5692)] = 238669,
  [SMALL_STATE(5693)] = 238728,
  [SMALL_STATE(5694)] = 238787,
  [SMALL_STATE(5695)] = 238846,
  [SMALL_STATE(5696)] = 238905,
  [SMALL_STATE(5697)] = 238964,
  [SMALL_STATE(5698)] = 239025,
  [SMALL_STATE(5699)] = 239084,
  [SMALL_STATE(5700)] = 239143,
  [SMALL_STATE(5701)] = 239202,
  [SMALL_STATE(5702)] = 239265,
  [SMALL_STATE(5703)] = 239326,
  [SMALL_STATE(5704)] = 239385,
  [SMALL_STATE(5705)] = 239444,
  [SMALL_STATE(5706)] = 239503,
  [SMALL_STATE(5707)] = 239562,
  [SMALL_STATE(5708)] = 239621,
  [SMALL_STATE(5709)] = 239680,
  [SMALL_STATE(5710)] = 239739,
  [SMALL_STATE(5711)] = 239798,
  [SMALL_STATE(5712)] = 239857,
  [SMALL_STATE(5713)] = 239916,
  [SMALL_STATE(5714)] = 239975,
  [SMALL_STATE(5715)] = 240034,
  [SMALL_STATE(5716)] = 240093,
  [SMALL_STATE(5717)] = 240152,
  [SMALL_STATE(5718)] = 240211,
  [SMALL_STATE(5719)] = 240270,
  [SMALL_STATE(5720)] = 240329,
  [SMALL_STATE(5721)] = 240388,
  [SMALL_STATE(5722)] = 240447,
  [SMALL_STATE(5723)] = 240506,
  [SMALL_STATE(5724)] = 240565,
  [SMALL_STATE(5725)] = 240624,
  [SMALL_STATE(5726)] = 240683,
  [SMALL_STATE(5727)] = 240742,
  [SMALL_STATE(5728)] = 240801,
  [SMALL_STATE(5729)] = 240860,
  [SMALL_STATE(5730)] = 240919,
  [SMALL_STATE(5731)] = 240978,
  [SMALL_STATE(5732)] = 241037,
  [SMALL_STATE(5733)] = 241096,
  [SMALL_STATE(5734)] = 241155,
  [SMALL_STATE(5735)] = 241220,
  [SMALL_STATE(5736)] = 241279,
  [SMALL_STATE(5737)] = 241344,
  [SMALL_STATE(5738)] = 241403,
  [SMALL_STATE(5739)] = 241462,
  [SMALL_STATE(5740)] = 241521,
  [SMALL_STATE(5741)] = 241580,
  [SMALL_STATE(5742)] = 241639,
  [SMALL_STATE(5743)] = 241698,
  [SMALL_STATE(5744)] = 241757,
  [SMALL_STATE(5745)] = 241816,
  [SMALL_STATE(5746)] = 241875,
  [SMALL_STATE(5747)] = 241934,
  [SMALL_STATE(5748)] = 241993,
  [SMALL_STATE(5749)] = 242052,
  [SMALL_STATE(5750)] = 242111,
  [SMALL_STATE(5751)] = 242170,
  [SMALL_STATE(5752)] = 242229,
  [SMALL_STATE(5753)] = 242288,
  [SMALL_STATE(5754)] = 242349,
  [SMALL_STATE(5755)] = 242407,
  [SMALL_STATE(5756)] = 242465,
  [SMALL_STATE(5757)] = 242523,
  [SMALL_STATE(5758)] = 242581,
  [SMALL_STATE(5759)] = 242679,
  [SMALL_STATE(5760)] = 242777,
  [SMALL_STATE(5761)] = 242875,
  [SMALL_STATE(5762)] = 242973,
  [SMALL_STATE(5763)] = 243071,
  [SMALL_STATE(5764)] = 243169,
  [SMALL_STATE(5765)] = 243227,
  [SMALL_STATE(5766)] = 243285,
  [SMALL_STATE(5767)] = 243343,
  [SMALL_STATE(5768)] = 243441,
  [SMALL_STATE(5769)] = 243499,
  [SMALL_STATE(5770)] = 243557,
  [SMALL_STATE(5771)] = 243615,
  [SMALL_STATE(5772)] = 243673,
  [SMALL_STATE(5773)] = 243731,
  [SMALL_STATE(5774)] = 243789,
  [SMALL_STATE(5775)] = 243887,
  [SMALL_STATE(5776)] = 243985,
  [SMALL_STATE(5777)] = 244045,
  [SMALL_STATE(5778)] = 244105,
  [SMALL_STATE(5779)] = 244163,
  [SMALL_STATE(5780)] = 244221,
  [SMALL_STATE(5781)] = 244279,
  [SMALL_STATE(5782)] = 244337,
  [SMALL_STATE(5783)] = 244395,
  [SMALL_STATE(5784)] = 244453,
  [SMALL_STATE(5785)] = 244511,
  [SMALL_STATE(5786)] = 244569,
  [SMALL_STATE(5787)] = 244627,
  [SMALL_STATE(5788)] = 244685,
  [SMALL_STATE(5789)] = 244745,
  [SMALL_STATE(5790)] = 244803,
  [SMALL_STATE(5791)] = 244861,
  [SMALL_STATE(5792)] = 244919,
  [SMALL_STATE(5793)] = 244977,
  [SMALL_STATE(5794)] = 245035,
  [SMALL_STATE(5795)] = 245093,
  [SMALL_STATE(5796)] = 245151,
  [SMALL_STATE(5797)] = 245209,
  [SMALL_STATE(5798)] = 245267,
  [SMALL_STATE(5799)] = 245327,
  [SMALL_STATE(5800)] = 245385,
  [SMALL_STATE(5801)] = 245443,
  [SMALL_STATE(5802)] = 245501,
  [SMALL_STATE(5803)] = 245559,
  [SMALL_STATE(5804)] = 245617,
  [SMALL_STATE(5805)] = 245675,
  [SMALL_STATE(5806)] = 245733,
  [SMALL_STATE(5807)] = 245791,
  [SMALL_STATE(5808)] = 245849,
  [SMALL_STATE(5809)] = 245907,
  [SMALL_STATE(5810)] = 245967,
  [SMALL_STATE(5811)] = 246025,
  [SMALL_STATE(5812)] = 246083,
  [SMALL_STATE(5813)] = 246141,
  [SMALL_STATE(5814)] = 246199,
  [SMALL_STATE(5815)] = 246257,
  [SMALL_STATE(5816)] = 246315,
  [SMALL_STATE(5817)] = 246373,
  [SMALL_STATE(5818)] = 246431,
  [SMALL_STATE(5819)] = 246489,
  [SMALL_STATE(5820)] = 246547,
  [SMALL_STATE(5821)] = 246605,
  [SMALL_STATE(5822)] = 246663,
  [SMALL_STATE(5823)] = 246721,
  [SMALL_STATE(5824)] = 246779,
  [SMALL_STATE(5825)] = 246837,
  [SMALL_STATE(5826)] = 246895,
  [SMALL_STATE(5827)] = 246953,
  [SMALL_STATE(5828)] = 247011,
  [SMALL_STATE(5829)] = 247069,
  [SMALL_STATE(5830)] = 247127,
  [SMALL_STATE(5831)] = 247185,
  [SMALL_STATE(5832)] = 247243,
  [SMALL_STATE(5833)] = 247301,
  [SMALL_STATE(5834)] = 247359,
  [SMALL_STATE(5835)] = 247417,
  [SMALL_STATE(5836)] = 247475,
  [SMALL_STATE(5837)] = 247539,
  [SMALL_STATE(5838)] = 247597,
  [SMALL_STATE(5839)] = 247655,
  [SMALL_STATE(5840)] = 247713,
  [SMALL_STATE(5841)] = 247773,
  [SMALL_STATE(5842)] = 247831,
  [SMALL_STATE(5843)] = 247889,
  [SMALL_STATE(5844)] = 247947,
  [SMALL_STATE(5845)] = 248005,
  [SMALL_STATE(5846)] = 248063,
  [SMALL_STATE(5847)] = 248127,
  [SMALL_STATE(5848)] = 248185,
  [SMALL_STATE(5849)] = 248243,
  [SMALL_STATE(5850)] = 248300,
  [SMALL_STATE(5851)] = 248357,
  [SMALL_STATE(5852)] = 248414,
  [SMALL_STATE(5853)] = 248471,
  [SMALL_STATE(5854)] = 248528,
  [SMALL_STATE(5855)] = 248591,
  [SMALL_STATE(5856)] = 248648,
  [SMALL_STATE(5857)] = 248705,
  [SMALL_STATE(5858)] = 248762,
  [SMALL_STATE(5859)] = 248819,
  [SMALL_STATE(5860)] = 248876,
  [SMALL_STATE(5861)] = 248933,
  [SMALL_STATE(5862)] = 248990,
  [SMALL_STATE(5863)] = 249047,
  [SMALL_STATE(5864)] = 249104,
  [SMALL_STATE(5865)] = 249161,
  [SMALL_STATE(5866)] = 249218,
  [SMALL_STATE(5867)] = 249275,
  [SMALL_STATE(5868)] = 249332,
  [SMALL_STATE(5869)] = 249389,
  [SMALL_STATE(5870)] = 249446,
  [SMALL_STATE(5871)] = 249503,
  [SMALL_STATE(5872)] = 249560,
  [SMALL_STATE(5873)] = 249617,
  [SMALL_STATE(5874)] = 249674,
  [SMALL_STATE(5875)] = 249731,
  [SMALL_STATE(5876)] = 249788,
  [SMALL_STATE(5877)] = 249845,
  [SMALL_STATE(5878)] = 249902,
  [SMALL_STATE(5879)] = 249959,
  [SMALL_STATE(5880)] = 250018,
  [SMALL_STATE(5881)] = 250075,
  [SMALL_STATE(5882)] = 250132,
  [SMALL_STATE(5883)] = 250189,
  [SMALL_STATE(5884)] = 250246,
  [SMALL_STATE(5885)] = 250303,
  [SMALL_STATE(5886)] = 250360,
  [SMALL_STATE(5887)] = 250417,
  [SMALL_STATE(5888)] = 250474,
  [SMALL_STATE(5889)] = 250531,
  [SMALL_STATE(5890)] = 250588,
  [SMALL_STATE(5891)] = 250645,
  [SMALL_STATE(5892)] = 250702,
  [SMALL_STATE(5893)] = 250761,
  [SMALL_STATE(5894)] = 250818,
  [SMALL_STATE(5895)] = 250875,
  [SMALL_STATE(5896)] = 250934,
  [SMALL_STATE(5897)] = 250991,
  [SMALL_STATE(5898)] = 251050,
  [SMALL_STATE(5899)] = 251107,
  [SMALL_STATE(5900)] = 251164,
  [SMALL_STATE(5901)] = 251221,
  [SMALL_STATE(5902)] = 251278,
  [SMALL_STATE(5903)] = 251335,
  [SMALL_STATE(5904)] = 251392,
  [SMALL_STATE(5905)] = 251449,
  [SMALL_STATE(5906)] = 251506,
  [SMALL_STATE(5907)] = 251563,
  [SMALL_STATE(5908)] = 251622,
  [SMALL_STATE(5909)] = 251679,
  [SMALL_STATE(5910)] = 251736,
  [SMALL_STATE(5911)] = 251793,
  [SMALL_STATE(5912)] = 251850,
  [SMALL_STATE(5913)] = 251907,
  [SMALL_STATE(5914)] = 251964,
  [SMALL_STATE(5915)] = 252021,
  [SMALL_STATE(5916)] = 252084,
  [SMALL_STATE(5917)] = 252141,
  [SMALL_STATE(5918)] = 252198,
  [SMALL_STATE(5919)] = 252255,
  [SMALL_STATE(5920)] = 252312,
  [SMALL_STATE(5921)] = 252371,
  [SMALL_STATE(5922)] = 252428,
  [SMALL_STATE(5923)] = 252485,
  [SMALL_STATE(5924)] = 252542,
  [SMALL_STATE(5925)] = 252599,
  [SMALL_STATE(5926)] = 252656,
  [SMALL_STATE(5927)] = 252713,
  [SMALL_STATE(5928)] = 252770,
  [SMALL_STATE(5929)] = 252829,
  [SMALL_STATE(5930)] = 252886,
  [SMALL_STATE(5931)] = 252943,
  [SMALL_STATE(5932)] = 253006,
  [SMALL_STATE(5933)] = 253063,
  [SMALL_STATE(5934)] = 253120,
  [SMALL_STATE(5935)] = 253177,
  [SMALL_STATE(5936)] = 253234,
  [SMALL_STATE(5937)] = 253291,
  [SMALL_STATE(5938)] = 253348,
  [SMALL_STATE(5939)] = 253407,
  [SMALL_STATE(5940)] = 253464,
  [SMALL_STATE(5941)] = 253521,
  [SMALL_STATE(5942)] = 253578,
  [SMALL_STATE(5943)] = 253635,
  [SMALL_STATE(5944)] = 253692,
  [SMALL_STATE(5945)] = 253749,
  [SMALL_STATE(5946)] = 253806,
  [SMALL_STATE(5947)] = 253863,
  [SMALL_STATE(5948)] = 253920,
  [SMALL_STATE(5949)] = 253977,
  [SMALL_STATE(5950)] = 254034,
  [SMALL_STATE(5951)] = 254091,
  [SMALL_STATE(5952)] = 254148,
  [SMALL_STATE(5953)] = 254205,
  [SMALL_STATE(5954)] = 254262,
  [SMALL_STATE(5955)] = 254319,
  [SMALL_STATE(5956)] = 254376,
  [SMALL_STATE(5957)] = 254433,
  [SMALL_STATE(5958)] = 254490,
  [SMALL_STATE(5959)] = 254547,
  [SMALL_STATE(5960)] = 254604,
  [SMALL_STATE(5961)] = 254661,
  [SMALL_STATE(5962)] = 254718,
  [SMALL_STATE(5963)] = 254775,
  [SMALL_STATE(5964)] = 254832,
  [SMALL_STATE(5965)] = 254889,
  [SMALL_STATE(5966)] = 254946,
  [SMALL_STATE(5967)] = 255003,
  [SMALL_STATE(5968)] = 255060,
  [SMALL_STATE(5969)] = 255117,
  [SMALL_STATE(5970)] = 255174,
  [SMALL_STATE(5971)] = 255231,
  [SMALL_STATE(5972)] = 255288,
  [SMALL_STATE(5973)] = 255345,
  [SMALL_STATE(5974)] = 255402,
  [SMALL_STATE(5975)] = 255459,
  [SMALL_STATE(5976)] = 255516,
  [SMALL_STATE(5977)] = 255573,
  [SMALL_STATE(5978)] = 255630,
  [SMALL_STATE(5979)] = 255687,
  [SMALL_STATE(5980)] = 255744,
  [SMALL_STATE(5981)] = 255801,
  [SMALL_STATE(5982)] = 255858,
  [SMALL_STATE(5983)] = 255915,
  [SMALL_STATE(5984)] = 255972,
  [SMALL_STATE(5985)] = 256029,
  [SMALL_STATE(5986)] = 256086,
  [SMALL_STATE(5987)] = 256143,
  [SMALL_STATE(5988)] = 256200,
  [SMALL_STATE(5989)] = 256257,
  [SMALL_STATE(5990)] = 256314,
  [SMALL_STATE(5991)] = 256371,
  [SMALL_STATE(5992)] = 256430,
  [SMALL_STATE(5993)] = 256487,
  [SMALL_STATE(5994)] = 256544,
  [SMALL_STATE(5995)] = 256601,
  [SMALL_STATE(5996)] = 256658,
  [SMALL_STATE(5997)] = 256715,
  [SMALL_STATE(5998)] = 256772,
  [SMALL_STATE(5999)] = 256829,
  [SMALL_STATE(6000)] = 256886,
  [SMALL_STATE(6001)] = 256943,
  [SMALL_STATE(6002)] = 257000,
  [SMALL_STATE(6003)] = 257057,
  [SMALL_STATE(6004)] = 257114,
  [SMALL_STATE(6005)] = 257173,
  [SMALL_STATE(6006)] = 257230,
  [SMALL_STATE(6007)] = 257287,
  [SMALL_STATE(6008)] = 257344,
  [SMALL_STATE(6009)] = 257401,
  [SMALL_STATE(6010)] = 257460,
  [SMALL_STATE(6011)] = 257517,
  [SMALL_STATE(6012)] = 257574,
  [SMALL_STATE(6013)] = 257633,
  [SMALL_STATE(6014)] = 257690,
  [SMALL_STATE(6015)] = 257747,
  [SMALL_STATE(6016)] = 257804,
  [SMALL_STATE(6017)] = 257861,
  [SMALL_STATE(6018)] = 257918,
  [SMALL_STATE(6019)] = 257975,
  [SMALL_STATE(6020)] = 258032,
  [SMALL_STATE(6021)] = 258089,
  [SMALL_STATE(6022)] = 258146,
  [SMALL_STATE(6023)] = 258203,
  [SMALL_STATE(6024)] = 258260,
  [SMALL_STATE(6025)] = 258317,
  [SMALL_STATE(6026)] = 258376,
  [SMALL_STATE(6027)] = 258433,
  [SMALL_STATE(6028)] = 258490,
  [SMALL_STATE(6029)] = 258547,
  [SMALL_STATE(6030)] = 258604,
  [SMALL_STATE(6031)] = 258661,
  [SMALL_STATE(6032)] = 258718,
  [SMALL_STATE(6033)] = 258775,
  [SMALL_STATE(6034)] = 258834,
  [SMALL_STATE(6035)] = 258891,
  [SMALL_STATE(6036)] = 258948,
  [SMALL_STATE(6037)] = 259005,
  [SMALL_STATE(6038)] = 259062,
  [SMALL_STATE(6039)] = 259119,
  [SMALL_STATE(6040)] = 259176,
  [SMALL_STATE(6041)] = 259233,
  [SMALL_STATE(6042)] = 259290,
  [SMALL_STATE(6043)] = 259347,
  [SMALL_STATE(6044)] = 259404,
  [SMALL_STATE(6045)] = 259461,
  [SMALL_STATE(6046)] = 259520,
  [SMALL_STATE(6047)] = 259577,
  [SMALL_STATE(6048)] = 259634,
  [SMALL_STATE(6049)] = 259691,
  [SMALL_STATE(6050)] = 259748,
  [SMALL_STATE(6051)] = 259807,
  [SMALL_STATE(6052)] = 259864,
  [SMALL_STATE(6053)] = 259921,
  [SMALL_STATE(6054)] = 259978,
  [SMALL_STATE(6055)] = 260035,
  [SMALL_STATE(6056)] = 260092,
  [SMALL_STATE(6057)] = 260149,
  [SMALL_STATE(6058)] = 260206,
  [SMALL_STATE(6059)] = 260263,
  [SMALL_STATE(6060)] = 260322,
  [SMALL_STATE(6061)] = 260379,
  [SMALL_STATE(6062)] = 260436,
  [SMALL_STATE(6063)] = 260493,
  [SMALL_STATE(6064)] = 260550,
  [SMALL_STATE(6065)] = 260607,
  [SMALL_STATE(6066)] = 260664,
  [SMALL_STATE(6067)] = 260721,
  [SMALL_STATE(6068)] = 260784,
  [SMALL_STATE(6069)] = 260841,
  [SMALL_STATE(6070)] = 260898,
  [SMALL_STATE(6071)] = 260955,
  [SMALL_STATE(6072)] = 261012,
  [SMALL_STATE(6073)] = 261069,
  [SMALL_STATE(6074)] = 261126,
  [SMALL_STATE(6075)] = 261183,
  [SMALL_STATE(6076)] = 261240,
  [SMALL_STATE(6077)] = 261297,
  [SMALL_STATE(6078)] = 261354,
  [SMALL_STATE(6079)] = 261411,
  [SMALL_STATE(6080)] = 261468,
  [SMALL_STATE(6081)] = 261525,
  [SMALL_STATE(6082)] = 261582,
  [SMALL_STATE(6083)] = 261639,
  [SMALL_STATE(6084)] = 261696,
  [SMALL_STATE(6085)] = 261759,
  [SMALL_STATE(6086)] = 261816,
  [SMALL_STATE(6087)] = 261873,
  [SMALL_STATE(6088)] = 261930,
  [SMALL_STATE(6089)] = 261987,
  [SMALL_STATE(6090)] = 262044,
  [SMALL_STATE(6091)] = 262101,
  [SMALL_STATE(6092)] = 262158,
  [SMALL_STATE(6093)] = 262215,
  [SMALL_STATE(6094)] = 262272,
  [SMALL_STATE(6095)] = 262329,
  [SMALL_STATE(6096)] = 262388,
  [SMALL_STATE(6097)] = 262445,
  [SMALL_STATE(6098)] = 262502,
  [SMALL_STATE(6099)] = 262559,
  [SMALL_STATE(6100)] = 262622,
  [SMALL_STATE(6101)] = 262679,
  [SMALL_STATE(6102)] = 262736,
  [SMALL_STATE(6103)] = 262793,
  [SMALL_STATE(6104)] = 262850,
  [SMALL_STATE(6105)] = 262909,
  [SMALL_STATE(6106)] = 262966,
  [SMALL_STATE(6107)] = 263023,
  [SMALL_STATE(6108)] = 263080,
  [SMALL_STATE(6109)] = 263137,
  [SMALL_STATE(6110)] = 263194,
  [SMALL_STATE(6111)] = 263251,
  [SMALL_STATE(6112)] = 263308,
  [SMALL_STATE(6113)] = 263365,
  [SMALL_STATE(6114)] = 263422,
  [SMALL_STATE(6115)] = 263479,
  [SMALL_STATE(6116)] = 263536,
  [SMALL_STATE(6117)] = 263593,
  [SMALL_STATE(6118)] = 263652,
  [SMALL_STATE(6119)] = 263711,
  [SMALL_STATE(6120)] = 263768,
  [SMALL_STATE(6121)] = 263825,
  [SMALL_STATE(6122)] = 263882,
  [SMALL_STATE(6123)] = 263939,
  [SMALL_STATE(6124)] = 263998,
  [SMALL_STATE(6125)] = 264055,
  [SMALL_STATE(6126)] = 264112,
  [SMALL_STATE(6127)] = 264169,
  [SMALL_STATE(6128)] = 264226,
  [SMALL_STATE(6129)] = 264283,
  [SMALL_STATE(6130)] = 264340,
  [SMALL_STATE(6131)] = 264397,
  [SMALL_STATE(6132)] = 264454,
  [SMALL_STATE(6133)] = 264511,
  [SMALL_STATE(6134)] = 264568,
  [SMALL_STATE(6135)] = 264625,
  [SMALL_STATE(6136)] = 264682,
  [SMALL_STATE(6137)] = 264739,
  [SMALL_STATE(6138)] = 264796,
  [SMALL_STATE(6139)] = 264853,
  [SMALL_STATE(6140)] = 264910,
  [SMALL_STATE(6141)] = 264967,
  [SMALL_STATE(6142)] = 265024,
  [SMALL_STATE(6143)] = 265081,
  [SMALL_STATE(6144)] = 265138,
  [SMALL_STATE(6145)] = 265195,
  [SMALL_STATE(6146)] = 265252,
  [SMALL_STATE(6147)] = 265311,
  [SMALL_STATE(6148)] = 265368,
  [SMALL_STATE(6149)] = 265425,
  [SMALL_STATE(6150)] = 265482,
  [SMALL_STATE(6151)] = 265539,
  [SMALL_STATE(6152)] = 265595,
  [SMALL_STATE(6153)] = 265651,
  [SMALL_STATE(6154)] = 265707,
  [SMALL_STATE(6155)] = 265763,
  [SMALL_STATE(6156)] = 265819,
  [SMALL_STATE(6157)] = 265875,
  [SMALL_STATE(6158)] = 265931,
  [SMALL_STATE(6159)] = 265987,
  [SMALL_STATE(6160)] = 266043,
  [SMALL_STATE(6161)] = 266099,
  [SMALL_STATE(6162)] = 266155,
  [SMALL_STATE(6163)] = 266211,
  [SMALL_STATE(6164)] = 266267,
  [SMALL_STATE(6165)] = 266323,
  [SMALL_STATE(6166)] = 266379,
  [SMALL_STATE(6167)] = 266435,
  [SMALL_STATE(6168)] = 266491,
  [SMALL_STATE(6169)] = 266547,
  [SMALL_STATE(6170)] = 266603,
  [SMALL_STATE(6171)] = 266659,
  [SMALL_STATE(6172)] = 266715,
  [SMALL_STATE(6173)] = 266771,
  [SMALL_STATE(6174)] = 266827,
  [SMALL_STATE(6175)] = 266883,
  [SMALL_STATE(6176)] = 266939,
  [SMALL_STATE(6177)] = 266997,
  [SMALL_STATE(6178)] = 267053,
  [SMALL_STATE(6179)] = 267109,
  [SMALL_STATE(6180)] = 267165,
  [SMALL_STATE(6181)] = 267221,
  [SMALL_STATE(6182)] = 267277,
  [SMALL_STATE(6183)] = 267333,
  [SMALL_STATE(6184)] = 267391,
  [SMALL_STATE(6185)] = 267447,
  [SMALL_STATE(6186)] = 267503,
  [SMALL_STATE(6187)] = 267559,
  [SMALL_STATE(6188)] = 267615,
  [SMALL_STATE(6189)] = 267671,
  [SMALL_STATE(6190)] = 267727,
  [SMALL_STATE(6191)] = 267783,
  [SMALL_STATE(6192)] = 267839,
  [SMALL_STATE(6193)] = 267895,
  [SMALL_STATE(6194)] = 267951,
  [SMALL_STATE(6195)] = 268007,
  [SMALL_STATE(6196)] = 268063,
  [SMALL_STATE(6197)] = 268119,
  [SMALL_STATE(6198)] = 268175,
  [SMALL_STATE(6199)] = 268231,
  [SMALL_STATE(6200)] = 268287,
  [SMALL_STATE(6201)] = 268343,
  [SMALL_STATE(6202)] = 268399,
  [SMALL_STATE(6203)] = 268455,
  [SMALL_STATE(6204)] = 268511,
  [SMALL_STATE(6205)] = 268567,
  [SMALL_STATE(6206)] = 268625,
  [SMALL_STATE(6207)] = 268681,
  [SMALL_STATE(6208)] = 268737,
  [SMALL_STATE(6209)] = 268793,
  [SMALL_STATE(6210)] = 268849,
  [SMALL_STATE(6211)] = 268905,
  [SMALL_STATE(6212)] = 268961,
  [SMALL_STATE(6213)] = 269017,
  [SMALL_STATE(6214)] = 269073,
  [SMALL_STATE(6215)] = 269129,
  [SMALL_STATE(6216)] = 269185,
  [SMALL_STATE(6217)] = 269241,
  [SMALL_STATE(6218)] = 269297,
  [SMALL_STATE(6219)] = 269353,
  [SMALL_STATE(6220)] = 269409,
  [SMALL_STATE(6221)] = 269465,
  [SMALL_STATE(6222)] = 269521,
  [SMALL_STATE(6223)] = 269577,
  [SMALL_STATE(6224)] = 269633,
  [SMALL_STATE(6225)] = 269689,
  [SMALL_STATE(6226)] = 269745,
  [SMALL_STATE(6227)] = 269801,
  [SMALL_STATE(6228)] = 269857,
  [SMALL_STATE(6229)] = 269913,
  [SMALL_STATE(6230)] = 269969,
  [SMALL_STATE(6231)] = 270025,
  [SMALL_STATE(6232)] = 270081,
  [SMALL_STATE(6233)] = 270137,
  [SMALL_STATE(6234)] = 270193,
  [SMALL_STATE(6235)] = 270249,
  [SMALL_STATE(6236)] = 270305,
  [SMALL_STATE(6237)] = 270361,
  [SMALL_STATE(6238)] = 270417,
  [SMALL_STATE(6239)] = 270473,
  [SMALL_STATE(6240)] = 270529,
  [SMALL_STATE(6241)] = 270585,
  [SMALL_STATE(6242)] = 270641,
  [SMALL_STATE(6243)] = 270697,
  [SMALL_STATE(6244)] = 270753,
  [SMALL_STATE(6245)] = 270809,
  [SMALL_STATE(6246)] = 270865,
  [SMALL_STATE(6247)] = 270921,
  [SMALL_STATE(6248)] = 270977,
  [SMALL_STATE(6249)] = 271033,
  [SMALL_STATE(6250)] = 271089,
  [SMALL_STATE(6251)] = 271145,
  [SMALL_STATE(6252)] = 271201,
  [SMALL_STATE(6253)] = 271257,
  [SMALL_STATE(6254)] = 271315,
  [SMALL_STATE(6255)] = 271371,
  [SMALL_STATE(6256)] = 271427,
  [SMALL_STATE(6257)] = 271483,
  [SMALL_STATE(6258)] = 271541,
  [SMALL_STATE(6259)] = 271597,
  [SMALL_STATE(6260)] = 271653,
  [SMALL_STATE(6261)] = 271709,
  [SMALL_STATE(6262)] = 271765,
  [SMALL_STATE(6263)] = 271821,
  [SMALL_STATE(6264)] = 271877,
  [SMALL_STATE(6265)] = 271933,
  [SMALL_STATE(6266)] = 271989,
  [SMALL_STATE(6267)] = 272045,
  [SMALL_STATE(6268)] = 272101,
  [SMALL_STATE(6269)] = 272157,
  [SMALL_STATE(6270)] = 272213,
  [SMALL_STATE(6271)] = 272269,
  [SMALL_STATE(6272)] = 272325,
  [SMALL_STATE(6273)] = 272381,
  [SMALL_STATE(6274)] = 272437,
  [SMALL_STATE(6275)] = 272499,
  [SMALL_STATE(6276)] = 272607,
  [SMALL_STATE(6277)] = 272663,
  [SMALL_STATE(6278)] = 272771,
  [SMALL_STATE(6279)] = 272827,
  [SMALL_STATE(6280)] = 272883,
  [SMALL_STATE(6281)] = 272939,
  [SMALL_STATE(6282)] = 272995,
  [SMALL_STATE(6283)] = 273051,
  [SMALL_STATE(6284)] = 273107,
  [SMALL_STATE(6285)] = 273163,
  [SMALL_STATE(6286)] = 273219,
  [SMALL_STATE(6287)] = 273275,
  [SMALL_STATE(6288)] = 273331,
  [SMALL_STATE(6289)] = 273387,
  [SMALL_STATE(6290)] = 273443,
  [SMALL_STATE(6291)] = 273499,
  [SMALL_STATE(6292)] = 273555,
  [SMALL_STATE(6293)] = 273611,
  [SMALL_STATE(6294)] = 273667,
  [SMALL_STATE(6295)] = 273723,
  [SMALL_STATE(6296)] = 273779,
  [SMALL_STATE(6297)] = 273835,
  [SMALL_STATE(6298)] = 273893,
  [SMALL_STATE(6299)] = 274001,
  [SMALL_STATE(6300)] = 274057,
  [SMALL_STATE(6301)] = 274113,
  [SMALL_STATE(6302)] = 274169,
  [SMALL_STATE(6303)] = 274225,
  [SMALL_STATE(6304)] = 274281,
  [SMALL_STATE(6305)] = 274337,
  [SMALL_STATE(6306)] = 274393,
  [SMALL_STATE(6307)] = 274449,
  [SMALL_STATE(6308)] = 274505,
  [SMALL_STATE(6309)] = 274561,
  [SMALL_STATE(6310)] = 274617,
  [SMALL_STATE(6311)] = 274673,
  [SMALL_STATE(6312)] = 274729,
  [SMALL_STATE(6313)] = 274785,
  [SMALL_STATE(6314)] = 274841,
  [SMALL_STATE(6315)] = 274897,
  [SMALL_STATE(6316)] = 274953,
  [SMALL_STATE(6317)] = 275009,
  [SMALL_STATE(6318)] = 275065,
  [SMALL_STATE(6319)] = 275121,
  [SMALL_STATE(6320)] = 275177,
  [SMALL_STATE(6321)] = 275233,
  [SMALL_STATE(6322)] = 275289,
  [SMALL_STATE(6323)] = 275345,
  [SMALL_STATE(6324)] = 275401,
  [SMALL_STATE(6325)] = 275463,
  [SMALL_STATE(6326)] = 275519,
  [SMALL_STATE(6327)] = 275575,
  [SMALL_STATE(6328)] = 275631,
  [SMALL_STATE(6329)] = 275687,
  [SMALL_STATE(6330)] = 275745,
  [SMALL_STATE(6331)] = 275801,
  [SMALL_STATE(6332)] = 275857,
  [SMALL_STATE(6333)] = 275913,
  [SMALL_STATE(6334)] = 275969,
  [SMALL_STATE(6335)] = 276025,
  [SMALL_STATE(6336)] = 276083,
  [SMALL_STATE(6337)] = 276139,
  [SMALL_STATE(6338)] = 276195,
  [SMALL_STATE(6339)] = 276251,
  [SMALL_STATE(6340)] = 276307,
  [SMALL_STATE(6341)] = 276363,
  [SMALL_STATE(6342)] = 276419,
  [SMALL_STATE(6343)] = 276475,
  [SMALL_STATE(6344)] = 276531,
  [SMALL_STATE(6345)] = 276587,
  [SMALL_STATE(6346)] = 276643,
  [SMALL_STATE(6347)] = 276699,
  [SMALL_STATE(6348)] = 276755,
  [SMALL_STATE(6349)] = 276811,
  [SMALL_STATE(6350)] = 276867,
  [SMALL_STATE(6351)] = 276923,
  [SMALL_STATE(6352)] = 276979,
  [SMALL_STATE(6353)] = 277037,
  [SMALL_STATE(6354)] = 277093,
  [SMALL_STATE(6355)] = 277149,
  [SMALL_STATE(6356)] = 277207,
  [SMALL_STATE(6357)] = 277263,
  [SMALL_STATE(6358)] = 277319,
  [SMALL_STATE(6359)] = 277375,
  [SMALL_STATE(6360)] = 277431,
  [SMALL_STATE(6361)] = 277487,
  [SMALL_STATE(6362)] = 277543,
  [SMALL_STATE(6363)] = 277599,
  [SMALL_STATE(6364)] = 277655,
  [SMALL_STATE(6365)] = 277711,
  [SMALL_STATE(6366)] = 277767,
  [SMALL_STATE(6367)] = 277829,
  [SMALL_STATE(6368)] = 277885,
  [SMALL_STATE(6369)] = 277941,
  [SMALL_STATE(6370)] = 277997,
  [SMALL_STATE(6371)] = 278053,
  [SMALL_STATE(6372)] = 278109,
  [SMALL_STATE(6373)] = 278165,
  [SMALL_STATE(6374)] = 278221,
  [SMALL_STATE(6375)] = 278277,
  [SMALL_STATE(6376)] = 278333,
  [SMALL_STATE(6377)] = 278389,
  [SMALL_STATE(6378)] = 278445,
  [SMALL_STATE(6379)] = 278501,
  [SMALL_STATE(6380)] = 278557,
  [SMALL_STATE(6381)] = 278613,
  [SMALL_STATE(6382)] = 278669,
  [SMALL_STATE(6383)] = 278727,
  [SMALL_STATE(6384)] = 278785,
  [SMALL_STATE(6385)] = 278841,
  [SMALL_STATE(6386)] = 278899,
  [SMALL_STATE(6387)] = 278955,
  [SMALL_STATE(6388)] = 279011,
  [SMALL_STATE(6389)] = 279067,
  [SMALL_STATE(6390)] = 279123,
  [SMALL_STATE(6391)] = 279179,
  [SMALL_STATE(6392)] = 279241,
  [SMALL_STATE(6393)] = 279297,
  [SMALL_STATE(6394)] = 279353,
  [SMALL_STATE(6395)] = 279409,
  [SMALL_STATE(6396)] = 279465,
  [SMALL_STATE(6397)] = 279521,
  [SMALL_STATE(6398)] = 279629,
  [SMALL_STATE(6399)] = 279685,
  [SMALL_STATE(6400)] = 279741,
  [SMALL_STATE(6401)] = 279797,
  [SMALL_STATE(6402)] = 279853,
  [SMALL_STATE(6403)] = 279909,
  [SMALL_STATE(6404)] = 279965,
  [SMALL_STATE(6405)] = 280023,
  [SMALL_STATE(6406)] = 280079,
  [SMALL_STATE(6407)] = 280135,
  [SMALL_STATE(6408)] = 280191,
  [SMALL_STATE(6409)] = 280247,
  [SMALL_STATE(6410)] = 280303,
  [SMALL_STATE(6411)] = 280359,
  [SMALL_STATE(6412)] = 280415,
  [SMALL_STATE(6413)] = 280471,
  [SMALL_STATE(6414)] = 280527,
  [SMALL_STATE(6415)] = 280583,
  [SMALL_STATE(6416)] = 280639,
  [SMALL_STATE(6417)] = 280701,
  [SMALL_STATE(6418)] = 280759,
  [SMALL_STATE(6419)] = 280815,
  [SMALL_STATE(6420)] = 280871,
  [SMALL_STATE(6421)] = 280927,
  [SMALL_STATE(6422)] = 280983,
  [SMALL_STATE(6423)] = 281039,
  [SMALL_STATE(6424)] = 281095,
  [SMALL_STATE(6425)] = 281151,
  [SMALL_STATE(6426)] = 281207,
  [SMALL_STATE(6427)] = 281263,
  [SMALL_STATE(6428)] = 281319,
  [SMALL_STATE(6429)] = 281375,
  [SMALL_STATE(6430)] = 281431,
  [SMALL_STATE(6431)] = 281487,
  [SMALL_STATE(6432)] = 281543,
  [SMALL_STATE(6433)] = 281599,
  [SMALL_STATE(6434)] = 281655,
  [SMALL_STATE(6435)] = 281711,
  [SMALL_STATE(6436)] = 281767,
  [SMALL_STATE(6437)] = 281823,
  [SMALL_STATE(6438)] = 281879,
  [SMALL_STATE(6439)] = 281935,
  [SMALL_STATE(6440)] = 281991,
  [SMALL_STATE(6441)] = 282047,
  [SMALL_STATE(6442)] = 282103,
  [SMALL_STATE(6443)] = 282159,
  [SMALL_STATE(6444)] = 282217,
  [SMALL_STATE(6445)] = 282273,
  [SMALL_STATE(6446)] = 282329,
  [SMALL_STATE(6447)] = 282437,
  [SMALL_STATE(6448)] = 282493,
  [SMALL_STATE(6449)] = 282549,
  [SMALL_STATE(6450)] = 282605,
  [SMALL_STATE(6451)] = 282661,
  [SMALL_STATE(6452)] = 282717,
  [SMALL_STATE(6453)] = 282773,
  [SMALL_STATE(6454)] = 282829,
  [SMALL_STATE(6455)] = 282885,
  [SMALL_STATE(6456)] = 282941,
  [SMALL_STATE(6457)] = 282997,
  [SMALL_STATE(6458)] = 283053,
  [SMALL_STATE(6459)] = 283115,
  [SMALL_STATE(6460)] = 283171,
  [SMALL_STATE(6461)] = 283227,
  [SMALL_STATE(6462)] = 283283,
  [SMALL_STATE(6463)] = 283339,
  [SMALL_STATE(6464)] = 283395,
  [SMALL_STATE(6465)] = 283451,
  [SMALL_STATE(6466)] = 283509,
  [SMALL_STATE(6467)] = 283565,
  [SMALL_STATE(6468)] = 283621,
  [SMALL_STATE(6469)] = 283677,
  [SMALL_STATE(6470)] = 283733,
  [SMALL_STATE(6471)] = 283789,
  [SMALL_STATE(6472)] = 283845,
  [SMALL_STATE(6473)] = 283901,
  [SMALL_STATE(6474)] = 283957,
  [SMALL_STATE(6475)] = 284013,
  [SMALL_STATE(6476)] = 284069,
  [SMALL_STATE(6477)] = 284177,
  [SMALL_STATE(6478)] = 284233,
  [SMALL_STATE(6479)] = 284291,
  [SMALL_STATE(6480)] = 284347,
  [SMALL_STATE(6481)] = 284403,
  [SMALL_STATE(6482)] = 284459,
  [SMALL_STATE(6483)] = 284515,
  [SMALL_STATE(6484)] = 284571,
  [SMALL_STATE(6485)] = 284627,
  [SMALL_STATE(6486)] = 284683,
  [SMALL_STATE(6487)] = 284739,
  [SMALL_STATE(6488)] = 284795,
  [SMALL_STATE(6489)] = 284851,
  [SMALL_STATE(6490)] = 284907,
  [SMALL_STATE(6491)] = 284963,
  [SMALL_STATE(6492)] = 285021,
  [SMALL_STATE(6493)] = 285077,
  [SMALL_STATE(6494)] = 285133,
  [SMALL_STATE(6495)] = 285191,
  [SMALL_STATE(6496)] = 285247,
  [SMALL_STATE(6497)] = 285303,
  [SMALL_STATE(6498)] = 285359,
  [SMALL_STATE(6499)] = 285415,
  [SMALL_STATE(6500)] = 285471,
  [SMALL_STATE(6501)] = 285527,
  [SMALL_STATE(6502)] = 285583,
  [SMALL_STATE(6503)] = 285639,
  [SMALL_STATE(6504)] = 285695,
  [SMALL_STATE(6505)] = 285751,
  [SMALL_STATE(6506)] = 285807,
  [SMALL_STATE(6507)] = 285863,
  [SMALL_STATE(6508)] = 285919,
  [SMALL_STATE(6509)] = 285981,
  [SMALL_STATE(6510)] = 286037,
  [SMALL_STATE(6511)] = 286093,
  [SMALL_STATE(6512)] = 286149,
  [SMALL_STATE(6513)] = 286205,
  [SMALL_STATE(6514)] = 286263,
  [SMALL_STATE(6515)] = 286319,
  [SMALL_STATE(6516)] = 286375,
  [SMALL_STATE(6517)] = 286431,
  [SMALL_STATE(6518)] = 286487,
  [SMALL_STATE(6519)] = 286549,
  [SMALL_STATE(6520)] = 286605,
  [SMALL_STATE(6521)] = 286661,
  [SMALL_STATE(6522)] = 286719,
  [SMALL_STATE(6523)] = 286775,
  [SMALL_STATE(6524)] = 286831,
  [SMALL_STATE(6525)] = 286887,
  [SMALL_STATE(6526)] = 286943,
  [SMALL_STATE(6527)] = 286999,
  [SMALL_STATE(6528)] = 287055,
  [SMALL_STATE(6529)] = 287111,
  [SMALL_STATE(6530)] = 287167,
  [SMALL_STATE(6531)] = 287223,
  [SMALL_STATE(6532)] = 287279,
  [SMALL_STATE(6533)] = 287335,
  [SMALL_STATE(6534)] = 287391,
  [SMALL_STATE(6535)] = 287447,
  [SMALL_STATE(6536)] = 287503,
  [SMALL_STATE(6537)] = 287559,
  [SMALL_STATE(6538)] = 287615,
  [SMALL_STATE(6539)] = 287671,
  [SMALL_STATE(6540)] = 287727,
  [SMALL_STATE(6541)] = 287783,
  [SMALL_STATE(6542)] = 287839,
  [SMALL_STATE(6543)] = 287895,
  [SMALL_STATE(6544)] = 287951,
  [SMALL_STATE(6545)] = 288007,
  [SMALL_STATE(6546)] = 288063,
  [SMALL_STATE(6547)] = 288121,
  [SMALL_STATE(6548)] = 288177,
  [SMALL_STATE(6549)] = 288233,
  [SMALL_STATE(6550)] = 288289,
  [SMALL_STATE(6551)] = 288351,
  [SMALL_STATE(6552)] = 288407,
  [SMALL_STATE(6553)] = 288463,
  [SMALL_STATE(6554)] = 288519,
  [SMALL_STATE(6555)] = 288575,
  [SMALL_STATE(6556)] = 288631,
  [SMALL_STATE(6557)] = 288687,
  [SMALL_STATE(6558)] = 288743,
  [SMALL_STATE(6559)] = 288799,
  [SMALL_STATE(6560)] = 288857,
  [SMALL_STATE(6561)] = 288913,
  [SMALL_STATE(6562)] = 288969,
  [SMALL_STATE(6563)] = 289025,
  [SMALL_STATE(6564)] = 289081,
  [SMALL_STATE(6565)] = 289137,
  [SMALL_STATE(6566)] = 289193,
  [SMALL_STATE(6567)] = 289255,
  [SMALL_STATE(6568)] = 289311,
  [SMALL_STATE(6569)] = 289367,
  [SMALL_STATE(6570)] = 289423,
  [SMALL_STATE(6571)] = 289479,
  [SMALL_STATE(6572)] = 289535,
  [SMALL_STATE(6573)] = 289643,
  [SMALL_STATE(6574)] = 289699,
  [SMALL_STATE(6575)] = 289755,
  [SMALL_STATE(6576)] = 289811,
  [SMALL_STATE(6577)] = 289867,
  [SMALL_STATE(6578)] = 289923,
  [SMALL_STATE(6579)] = 289979,
  [SMALL_STATE(6580)] = 290035,
  [SMALL_STATE(6581)] = 290091,
  [SMALL_STATE(6582)] = 290147,
  [SMALL_STATE(6583)] = 290205,
  [SMALL_STATE(6584)] = 290263,
  [SMALL_STATE(6585)] = 290319,
  [SMALL_STATE(6586)] = 290375,
  [SMALL_STATE(6587)] = 290431,
  [SMALL_STATE(6588)] = 290487,
  [SMALL_STATE(6589)] = 290545,
  [SMALL_STATE(6590)] = 290601,
  [SMALL_STATE(6591)] = 290709,
  [SMALL_STATE(6592)] = 290765,
  [SMALL_STATE(6593)] = 290821,
  [SMALL_STATE(6594)] = 290877,
  [SMALL_STATE(6595)] = 290933,
  [SMALL_STATE(6596)] = 290989,
  [SMALL_STATE(6597)] = 291045,
  [SMALL_STATE(6598)] = 291101,
  [SMALL_STATE(6599)] = 291157,
  [SMALL_STATE(6600)] = 291213,
  [SMALL_STATE(6601)] = 291275,
  [SMALL_STATE(6602)] = 291331,
  [SMALL_STATE(6603)] = 291389,
  [SMALL_STATE(6604)] = 291445,
  [SMALL_STATE(6605)] = 291501,
  [SMALL_STATE(6606)] = 291559,
  [SMALL_STATE(6607)] = 291615,
  [SMALL_STATE(6608)] = 291673,
  [SMALL_STATE(6609)] = 291729,
  [SMALL_STATE(6610)] = 291785,
  [SMALL_STATE(6611)] = 291841,
  [SMALL_STATE(6612)] = 291897,
  [SMALL_STATE(6613)] = 291953,
  [SMALL_STATE(6614)] = 292009,
  [SMALL_STATE(6615)] = 292065,
  [SMALL_STATE(6616)] = 292121,
  [SMALL_STATE(6617)] = 292177,
  [SMALL_STATE(6618)] = 292235,
  [SMALL_STATE(6619)] = 292291,
  [SMALL_STATE(6620)] = 292347,
  [SMALL_STATE(6621)] = 292403,
  [SMALL_STATE(6622)] = 292459,
  [SMALL_STATE(6623)] = 292515,
  [SMALL_STATE(6624)] = 292571,
  [SMALL_STATE(6625)] = 292627,
  [SMALL_STATE(6626)] = 292683,
  [SMALL_STATE(6627)] = 292741,
  [SMALL_STATE(6628)] = 292797,
  [SMALL_STATE(6629)] = 292853,
  [SMALL_STATE(6630)] = 292909,
  [SMALL_STATE(6631)] = 292965,
  [SMALL_STATE(6632)] = 293021,
  [SMALL_STATE(6633)] = 293077,
  [SMALL_STATE(6634)] = 293133,
  [SMALL_STATE(6635)] = 293189,
  [SMALL_STATE(6636)] = 293245,
  [SMALL_STATE(6637)] = 293301,
  [SMALL_STATE(6638)] = 293357,
  [SMALL_STATE(6639)] = 293413,
  [SMALL_STATE(6640)] = 293469,
  [SMALL_STATE(6641)] = 293525,
  [SMALL_STATE(6642)] = 293581,
  [SMALL_STATE(6643)] = 293637,
  [SMALL_STATE(6644)] = 293693,
  [SMALL_STATE(6645)] = 293755,
  [SMALL_STATE(6646)] = 293811,
  [SMALL_STATE(6647)] = 293867,
  [SMALL_STATE(6648)] = 293923,
  [SMALL_STATE(6649)] = 293979,
  [SMALL_STATE(6650)] = 294035,
  [SMALL_STATE(6651)] = 294091,
  [SMALL_STATE(6652)] = 294147,
  [SMALL_STATE(6653)] = 294203,
  [SMALL_STATE(6654)] = 294259,
  [SMALL_STATE(6655)] = 294315,
  [SMALL_STATE(6656)] = 294371,
  [SMALL_STATE(6657)] = 294429,
  [SMALL_STATE(6658)] = 294485,
  [SMALL_STATE(6659)] = 294541,
  [SMALL_STATE(6660)] = 294597,
  [SMALL_STATE(6661)] = 294653,
  [SMALL_STATE(6662)] = 294709,
  [SMALL_STATE(6663)] = 294765,
  [SMALL_STATE(6664)] = 294821,
  [SMALL_STATE(6665)] = 294877,
  [SMALL_STATE(6666)] = 294933,
  [SMALL_STATE(6667)] = 294991,
  [SMALL_STATE(6668)] = 295046,
  [SMALL_STATE(6669)] = 295101,
  [SMALL_STATE(6670)] = 295156,
  [SMALL_STATE(6671)] = 295211,
  [SMALL_STATE(6672)] = 295266,
  [SMALL_STATE(6673)] = 295371,
  [SMALL_STATE(6674)] = 295426,
  [SMALL_STATE(6675)] = 295481,
  [SMALL_STATE(6676)] = 295536,
  [SMALL_STATE(6677)] = 295591,
  [SMALL_STATE(6678)] = 295646,
  [SMALL_STATE(6679)] = 295701,
  [SMALL_STATE(6680)] = 295756,
  [SMALL_STATE(6681)] = 295811,
  [SMALL_STATE(6682)] = 295866,
  [SMALL_STATE(6683)] = 295921,
  [SMALL_STATE(6684)] = 295976,
  [SMALL_STATE(6685)] = 296031,
  [SMALL_STATE(6686)] = 296086,
  [SMALL_STATE(6687)] = 296141,
  [SMALL_STATE(6688)] = 296196,
  [SMALL_STATE(6689)] = 296251,
  [SMALL_STATE(6690)] = 296306,
  [SMALL_STATE(6691)] = 296361,
  [SMALL_STATE(6692)] = 296416,
  [SMALL_STATE(6693)] = 296471,
  [SMALL_STATE(6694)] = 296526,
  [SMALL_STATE(6695)] = 296581,
  [SMALL_STATE(6696)] = 296636,
  [SMALL_STATE(6697)] = 296691,
  [SMALL_STATE(6698)] = 296746,
  [SMALL_STATE(6699)] = 296801,
  [SMALL_STATE(6700)] = 296856,
  [SMALL_STATE(6701)] = 296911,
  [SMALL_STATE(6702)] = 296966,
  [SMALL_STATE(6703)] = 297023,
  [SMALL_STATE(6704)] = 297078,
  [SMALL_STATE(6705)] = 297133,
  [SMALL_STATE(6706)] = 297188,
  [SMALL_STATE(6707)] = 297243,
  [SMALL_STATE(6708)] = 297298,
  [SMALL_STATE(6709)] = 297353,
  [SMALL_STATE(6710)] = 297408,
  [SMALL_STATE(6711)] = 297463,
  [SMALL_STATE(6712)] = 297518,
  [SMALL_STATE(6713)] = 297573,
  [SMALL_STATE(6714)] = 297628,
  [SMALL_STATE(6715)] = 297683,
  [SMALL_STATE(6716)] = 297738,
  [SMALL_STATE(6717)] = 297793,
  [SMALL_STATE(6718)] = 297848,
  [SMALL_STATE(6719)] = 297903,
  [SMALL_STATE(6720)] = 297958,
  [SMALL_STATE(6721)] = 298013,
  [SMALL_STATE(6722)] = 298068,
  [SMALL_STATE(6723)] = 298123,
  [SMALL_STATE(6724)] = 298178,
  [SMALL_STATE(6725)] = 298233,
  [SMALL_STATE(6726)] = 298288,
  [SMALL_STATE(6727)] = 298343,
  [SMALL_STATE(6728)] = 298398,
  [SMALL_STATE(6729)] = 298453,
  [SMALL_STATE(6730)] = 298508,
  [SMALL_STATE(6731)] = 298563,
  [SMALL_STATE(6732)] = 298620,
  [SMALL_STATE(6733)] = 298675,
  [SMALL_STATE(6734)] = 298730,
  [SMALL_STATE(6735)] = 298785,
  [SMALL_STATE(6736)] = 298840,
  [SMALL_STATE(6737)] = 298895,
  [SMALL_STATE(6738)] = 298950,
  [SMALL_STATE(6739)] = 299005,
  [SMALL_STATE(6740)] = 299060,
  [SMALL_STATE(6741)] = 299115,
  [SMALL_STATE(6742)] = 299170,
  [SMALL_STATE(6743)] = 299225,
  [SMALL_STATE(6744)] = 299280,
  [SMALL_STATE(6745)] = 299335,
  [SMALL_STATE(6746)] = 299390,
  [SMALL_STATE(6747)] = 299445,
  [SMALL_STATE(6748)] = 299502,
  [SMALL_STATE(6749)] = 299557,
  [SMALL_STATE(6750)] = 299612,
  [SMALL_STATE(6751)] = 299667,
  [SMALL_STATE(6752)] = 299722,
  [SMALL_STATE(6753)] = 299777,
  [SMALL_STATE(6754)] = 299832,
  [SMALL_STATE(6755)] = 299887,
  [SMALL_STATE(6756)] = 299942,
  [SMALL_STATE(6757)] = 299997,
  [SMALL_STATE(6758)] = 300054,
  [SMALL_STATE(6759)] = 300109,
  [SMALL_STATE(6760)] = 300164,
  [SMALL_STATE(6761)] = 300219,
  [SMALL_STATE(6762)] = 300274,
  [SMALL_STATE(6763)] = 300329,
  [SMALL_STATE(6764)] = 300384,
  [SMALL_STATE(6765)] = 300441,
  [SMALL_STATE(6766)] = 300496,
  [SMALL_STATE(6767)] = 300551,
  [SMALL_STATE(6768)] = 300606,
  [SMALL_STATE(6769)] = 300661,
  [SMALL_STATE(6770)] = 300716,
  [SMALL_STATE(6771)] = 300771,
  [SMALL_STATE(6772)] = 300826,
  [SMALL_STATE(6773)] = 300881,
  [SMALL_STATE(6774)] = 300936,
  [SMALL_STATE(6775)] = 300991,
  [SMALL_STATE(6776)] = 301046,
  [SMALL_STATE(6777)] = 301101,
  [SMALL_STATE(6778)] = 301156,
  [SMALL_STATE(6779)] = 301211,
  [SMALL_STATE(6780)] = 301266,
  [SMALL_STATE(6781)] = 301321,
  [SMALL_STATE(6782)] = 301376,
  [SMALL_STATE(6783)] = 301431,
  [SMALL_STATE(6784)] = 301486,
  [SMALL_STATE(6785)] = 301541,
  [SMALL_STATE(6786)] = 301596,
  [SMALL_STATE(6787)] = 301651,
  [SMALL_STATE(6788)] = 301706,
  [SMALL_STATE(6789)] = 301761,
  [SMALL_STATE(6790)] = 301816,
  [SMALL_STATE(6791)] = 301871,
  [SMALL_STATE(6792)] = 301926,
  [SMALL_STATE(6793)] = 301981,
  [SMALL_STATE(6794)] = 302036,
  [SMALL_STATE(6795)] = 302091,
  [SMALL_STATE(6796)] = 302146,
  [SMALL_STATE(6797)] = 302201,
  [SMALL_STATE(6798)] = 302256,
  [SMALL_STATE(6799)] = 302311,
  [SMALL_STATE(6800)] = 302366,
  [SMALL_STATE(6801)] = 302421,
  [SMALL_STATE(6802)] = 302476,
  [SMALL_STATE(6803)] = 302531,
  [SMALL_STATE(6804)] = 302586,
  [SMALL_STATE(6805)] = 302641,
  [SMALL_STATE(6806)] = 302696,
  [SMALL_STATE(6807)] = 302751,
  [SMALL_STATE(6808)] = 302806,
  [SMALL_STATE(6809)] = 302861,
  [SMALL_STATE(6810)] = 302916,
  [SMALL_STATE(6811)] = 302971,
  [SMALL_STATE(6812)] = 303028,
  [SMALL_STATE(6813)] = 303083,
  [SMALL_STATE(6814)] = 303138,
  [SMALL_STATE(6815)] = 303193,
  [SMALL_STATE(6816)] = 303248,
  [SMALL_STATE(6817)] = 303303,
  [SMALL_STATE(6818)] = 303358,
  [SMALL_STATE(6819)] = 303413,
  [SMALL_STATE(6820)] = 303468,
  [SMALL_STATE(6821)] = 303523,
  [SMALL_STATE(6822)] = 303578,
  [SMALL_STATE(6823)] = 303633,
  [SMALL_STATE(6824)] = 303688,
  [SMALL_STATE(6825)] = 303743,
  [SMALL_STATE(6826)] = 303798,
  [SMALL_STATE(6827)] = 303853,
  [SMALL_STATE(6828)] = 303908,
  [SMALL_STATE(6829)] = 303963,
  [SMALL_STATE(6830)] = 304018,
  [SMALL_STATE(6831)] = 304073,
  [SMALL_STATE(6832)] = 304128,
  [SMALL_STATE(6833)] = 304183,
  [SMALL_STATE(6834)] = 304238,
  [SMALL_STATE(6835)] = 304293,
  [SMALL_STATE(6836)] = 304348,
  [SMALL_STATE(6837)] = 304403,
  [SMALL_STATE(6838)] = 304458,
  [SMALL_STATE(6839)] = 304513,
  [SMALL_STATE(6840)] = 304568,
  [SMALL_STATE(6841)] = 304623,
  [SMALL_STATE(6842)] = 304678,
  [SMALL_STATE(6843)] = 304733,
  [SMALL_STATE(6844)] = 304788,
  [SMALL_STATE(6845)] = 304843,
  [SMALL_STATE(6846)] = 304898,
  [SMALL_STATE(6847)] = 304953,
  [SMALL_STATE(6848)] = 305008,
  [SMALL_STATE(6849)] = 305063,
  [SMALL_STATE(6850)] = 305124,
  [SMALL_STATE(6851)] = 305179,
  [SMALL_STATE(6852)] = 305234,
  [SMALL_STATE(6853)] = 305289,
  [SMALL_STATE(6854)] = 305344,
  [SMALL_STATE(6855)] = 305399,
  [SMALL_STATE(6856)] = 305454,
  [SMALL_STATE(6857)] = 305509,
  [SMALL_STATE(6858)] = 305564,
  [SMALL_STATE(6859)] = 305619,
  [SMALL_STATE(6860)] = 305680,
  [SMALL_STATE(6861)] = 305735,
  [SMALL_STATE(6862)] = 305790,
  [SMALL_STATE(6863)] = 305851,
  [SMALL_STATE(6864)] = 305906,
  [SMALL_STATE(6865)] = 305961,
  [SMALL_STATE(6866)] = 306016,
  [SMALL_STATE(6867)] = 306071,
  [SMALL_STATE(6868)] = 306126,
  [SMALL_STATE(6869)] = 306181,
  [SMALL_STATE(6870)] = 306238,
  [SMALL_STATE(6871)] = 306293,
  [SMALL_STATE(6872)] = 306348,
  [SMALL_STATE(6873)] = 306403,
  [SMALL_STATE(6874)] = 306458,
  [SMALL_STATE(6875)] = 306513,
  [SMALL_STATE(6876)] = 306570,
  [SMALL_STATE(6877)] = 306631,
  [SMALL_STATE(6878)] = 306686,
  [SMALL_STATE(6879)] = 306741,
  [SMALL_STATE(6880)] = 306796,
  [SMALL_STATE(6881)] = 306851,
  [SMALL_STATE(6882)] = 306912,
  [SMALL_STATE(6883)] = 306967,
  [SMALL_STATE(6884)] = 307022,
  [SMALL_STATE(6885)] = 307077,
  [SMALL_STATE(6886)] = 307132,
  [SMALL_STATE(6887)] = 307189,
  [SMALL_STATE(6888)] = 307244,
  [SMALL_STATE(6889)] = 307299,
  [SMALL_STATE(6890)] = 307354,
  [SMALL_STATE(6891)] = 307409,
  [SMALL_STATE(6892)] = 307464,
  [SMALL_STATE(6893)] = 307521,
  [SMALL_STATE(6894)] = 307576,
  [SMALL_STATE(6895)] = 307631,
  [SMALL_STATE(6896)] = 307686,
  [SMALL_STATE(6897)] = 307741,
  [SMALL_STATE(6898)] = 307796,
  [SMALL_STATE(6899)] = 307851,
  [SMALL_STATE(6900)] = 307906,
  [SMALL_STATE(6901)] = 307961,
  [SMALL_STATE(6902)] = 308016,
  [SMALL_STATE(6903)] = 308071,
  [SMALL_STATE(6904)] = 308126,
  [SMALL_STATE(6905)] = 308231,
  [SMALL_STATE(6906)] = 308286,
  [SMALL_STATE(6907)] = 308341,
  [SMALL_STATE(6908)] = 308396,
  [SMALL_STATE(6909)] = 308451,
  [SMALL_STATE(6910)] = 308506,
  [SMALL_STATE(6911)] = 308561,
  [SMALL_STATE(6912)] = 308616,
  [SMALL_STATE(6913)] = 308671,
  [SMALL_STATE(6914)] = 308726,
  [SMALL_STATE(6915)] = 308781,
  [SMALL_STATE(6916)] = 308838,
  [SMALL_STATE(6917)] = 308893,
  [SMALL_STATE(6918)] = 308998,
  [SMALL_STATE(6919)] = 309053,
  [SMALL_STATE(6920)] = 309108,
  [SMALL_STATE(6921)] = 309163,
  [SMALL_STATE(6922)] = 309218,
  [SMALL_STATE(6923)] = 309275,
  [SMALL_STATE(6924)] = 309330,
  [SMALL_STATE(6925)] = 309385,
  [SMALL_STATE(6926)] = 309440,
  [SMALL_STATE(6927)] = 309495,
  [SMALL_STATE(6928)] = 309550,
  [SMALL_STATE(6929)] = 309605,
  [SMALL_STATE(6930)] = 309660,
  [SMALL_STATE(6931)] = 309715,
  [SMALL_STATE(6932)] = 309770,
  [SMALL_STATE(6933)] = 309825,
  [SMALL_STATE(6934)] = 309880,
  [SMALL_STATE(6935)] = 309935,
  [SMALL_STATE(6936)] = 309990,
  [SMALL_STATE(6937)] = 310045,
  [SMALL_STATE(6938)] = 310100,
  [SMALL_STATE(6939)] = 310157,
  [SMALL_STATE(6940)] = 310212,
  [SMALL_STATE(6941)] = 310267,
  [SMALL_STATE(6942)] = 310324,
  [SMALL_STATE(6943)] = 310379,
  [SMALL_STATE(6944)] = 310434,
  [SMALL_STATE(6945)] = 310489,
  [SMALL_STATE(6946)] = 310544,
  [SMALL_STATE(6947)] = 310599,
  [SMALL_STATE(6948)] = 310654,
  [SMALL_STATE(6949)] = 310709,
  [SMALL_STATE(6950)] = 310764,
  [SMALL_STATE(6951)] = 310819,
  [SMALL_STATE(6952)] = 310874,
  [SMALL_STATE(6953)] = 310929,
  [SMALL_STATE(6954)] = 310984,
  [SMALL_STATE(6955)] = 311039,
  [SMALL_STATE(6956)] = 311094,
  [SMALL_STATE(6957)] = 311149,
  [SMALL_STATE(6958)] = 311204,
  [SMALL_STATE(6959)] = 311261,
  [SMALL_STATE(6960)] = 311316,
  [SMALL_STATE(6961)] = 311371,
  [SMALL_STATE(6962)] = 311426,
  [SMALL_STATE(6963)] = 311481,
  [SMALL_STATE(6964)] = 311536,
  [SMALL_STATE(6965)] = 311591,
  [SMALL_STATE(6966)] = 311646,
  [SMALL_STATE(6967)] = 311701,
  [SMALL_STATE(6968)] = 311756,
  [SMALL_STATE(6969)] = 311811,
  [SMALL_STATE(6970)] = 311866,
  [SMALL_STATE(6971)] = 311921,
  [SMALL_STATE(6972)] = 311976,
  [SMALL_STATE(6973)] = 312031,
  [SMALL_STATE(6974)] = 312086,
  [SMALL_STATE(6975)] = 312141,
  [SMALL_STATE(6976)] = 312196,
  [SMALL_STATE(6977)] = 312251,
  [SMALL_STATE(6978)] = 312306,
  [SMALL_STATE(6979)] = 312361,
  [SMALL_STATE(6980)] = 312416,
  [SMALL_STATE(6981)] = 312471,
  [SMALL_STATE(6982)] = 312526,
  [SMALL_STATE(6983)] = 312581,
  [SMALL_STATE(6984)] = 312636,
  [SMALL_STATE(6985)] = 312691,
  [SMALL_STATE(6986)] = 312748,
  [SMALL_STATE(6987)] = 312803,
  [SMALL_STATE(6988)] = 312858,
  [SMALL_STATE(6989)] = 312913,
  [SMALL_STATE(6990)] = 312968,
  [SMALL_STATE(6991)] = 313023,
  [SMALL_STATE(6992)] = 313078,
  [SMALL_STATE(6993)] = 313133,
  [SMALL_STATE(6994)] = 313188,
  [SMALL_STATE(6995)] = 313243,
  [SMALL_STATE(6996)] = 313298,
  [SMALL_STATE(6997)] = 313353,
  [SMALL_STATE(6998)] = 313408,
  [SMALL_STATE(6999)] = 313463,
  [SMALL_STATE(7000)] = 313518,
  [SMALL_STATE(7001)] = 313573,
  [SMALL_STATE(7002)] = 313628,
  [SMALL_STATE(7003)] = 313689,
  [SMALL_STATE(7004)] = 313744,
  [SMALL_STATE(7005)] = 313799,
  [SMALL_STATE(7006)] = 313854,
  [SMALL_STATE(7007)] = 313909,
  [SMALL_STATE(7008)] = 313964,
  [SMALL_STATE(7009)] = 314019,
  [SMALL_STATE(7010)] = 314074,
  [SMALL_STATE(7011)] = 314129,
  [SMALL_STATE(7012)] = 314184,
  [SMALL_STATE(7013)] = 314239,
  [SMALL_STATE(7014)] = 314294,
  [SMALL_STATE(7015)] = 314349,
  [SMALL_STATE(7016)] = 314404,
  [SMALL_STATE(7017)] = 314459,
  [SMALL_STATE(7018)] = 314514,
  [SMALL_STATE(7019)] = 314569,
  [SMALL_STATE(7020)] = 314624,
  [SMALL_STATE(7021)] = 314729,
  [SMALL_STATE(7022)] = 314784,
  [SMALL_STATE(7023)] = 314839,
  [SMALL_STATE(7024)] = 314894,
  [SMALL_STATE(7025)] = 314951,
  [SMALL_STATE(7026)] = 315006,
  [SMALL_STATE(7027)] = 315061,
  [SMALL_STATE(7028)] = 315116,
  [SMALL_STATE(7029)] = 315171,
  [SMALL_STATE(7030)] = 315226,
  [SMALL_STATE(7031)] = 315281,
  [SMALL_STATE(7032)] = 315336,
  [SMALL_STATE(7033)] = 315391,
  [SMALL_STATE(7034)] = 315446,
  [SMALL_STATE(7035)] = 315501,
  [SMALL_STATE(7036)] = 315556,
  [SMALL_STATE(7037)] = 315613,
  [SMALL_STATE(7038)] = 315668,
  [SMALL_STATE(7039)] = 315723,
  [SMALL_STATE(7040)] = 315778,
  [SMALL_STATE(7041)] = 315833,
  [SMALL_STATE(7042)] = 315894,
  [SMALL_STATE(7043)] = 315949,
  [SMALL_STATE(7044)] = 316004,
  [SMALL_STATE(7045)] = 316059,
  [SMALL_STATE(7046)] = 316114,
  [SMALL_STATE(7047)] = 316169,
  [SMALL_STATE(7048)] = 316224,
  [SMALL_STATE(7049)] = 316279,
  [SMALL_STATE(7050)] = 316340,
  [SMALL_STATE(7051)] = 316395,
  [SMALL_STATE(7052)] = 316450,
  [SMALL_STATE(7053)] = 316505,
  [SMALL_STATE(7054)] = 316560,
  [SMALL_STATE(7055)] = 316615,
  [SMALL_STATE(7056)] = 316670,
  [SMALL_STATE(7057)] = 316725,
  [SMALL_STATE(7058)] = 316782,
  [SMALL_STATE(7059)] = 316837,
  [SMALL_STATE(7060)] = 316892,
  [SMALL_STATE(7061)] = 316947,
  [SMALL_STATE(7062)] = 317002,
  [SMALL_STATE(7063)] = 317057,
  [SMALL_STATE(7064)] = 317118,
  [SMALL_STATE(7065)] = 317173,
  [SMALL_STATE(7066)] = 317228,
  [SMALL_STATE(7067)] = 317283,
  [SMALL_STATE(7068)] = 317338,
  [SMALL_STATE(7069)] = 317395,
  [SMALL_STATE(7070)] = 317450,
  [SMALL_STATE(7071)] = 317505,
  [SMALL_STATE(7072)] = 317562,
  [SMALL_STATE(7073)] = 317619,
  [SMALL_STATE(7074)] = 317674,
  [SMALL_STATE(7075)] = 317729,
  [SMALL_STATE(7076)] = 317784,
  [SMALL_STATE(7077)] = 317841,
  [SMALL_STATE(7078)] = 317896,
  [SMALL_STATE(7079)] = 317951,
  [SMALL_STATE(7080)] = 318006,
  [SMALL_STATE(7081)] = 318061,
  [SMALL_STATE(7082)] = 318116,
  [SMALL_STATE(7083)] = 318171,
  [SMALL_STATE(7084)] = 318226,
  [SMALL_STATE(7085)] = 318283,
  [SMALL_STATE(7086)] = 318338,
  [SMALL_STATE(7087)] = 318393,
  [SMALL_STATE(7088)] = 318448,
  [SMALL_STATE(7089)] = 318503,
  [SMALL_STATE(7090)] = 318564,
  [SMALL_STATE(7091)] = 318619,
  [SMALL_STATE(7092)] = 318674,
  [SMALL_STATE(7093)] = 318729,
  [SMALL_STATE(7094)] = 318784,
  [SMALL_STATE(7095)] = 318839,
  [SMALL_STATE(7096)] = 318894,
  [SMALL_STATE(7097)] = 318949,
  [SMALL_STATE(7098)] = 319004,
  [SMALL_STATE(7099)] = 319059,
  [SMALL_STATE(7100)] = 319114,
  [SMALL_STATE(7101)] = 319169,
  [SMALL_STATE(7102)] = 319224,
  [SMALL_STATE(7103)] = 319279,
  [SMALL_STATE(7104)] = 319340,
  [SMALL_STATE(7105)] = 319395,
  [SMALL_STATE(7106)] = 319450,
  [SMALL_STATE(7107)] = 319505,
  [SMALL_STATE(7108)] = 319560,
  [SMALL_STATE(7109)] = 319615,
  [SMALL_STATE(7110)] = 319670,
  [SMALL_STATE(7111)] = 319775,
  [SMALL_STATE(7112)] = 319830,
  [SMALL_STATE(7113)] = 319885,
  [SMALL_STATE(7114)] = 319940,
  [SMALL_STATE(7115)] = 319995,
  [SMALL_STATE(7116)] = 320056,
  [SMALL_STATE(7117)] = 320111,
  [SMALL_STATE(7118)] = 320166,
  [SMALL_STATE(7119)] = 320221,
  [SMALL_STATE(7120)] = 320276,
  [SMALL_STATE(7121)] = 320331,
  [SMALL_STATE(7122)] = 320386,
  [SMALL_STATE(7123)] = 320441,
  [SMALL_STATE(7124)] = 320496,
  [SMALL_STATE(7125)] = 320551,
  [SMALL_STATE(7126)] = 320606,
  [SMALL_STATE(7127)] = 320661,
  [SMALL_STATE(7128)] = 320716,
  [SMALL_STATE(7129)] = 320771,
  [SMALL_STATE(7130)] = 320826,
  [SMALL_STATE(7131)] = 320883,
  [SMALL_STATE(7132)] = 320938,
  [SMALL_STATE(7133)] = 320993,
  [SMALL_STATE(7134)] = 321048,
  [SMALL_STATE(7135)] = 321105,
  [SMALL_STATE(7136)] = 321160,
  [SMALL_STATE(7137)] = 321215,
  [SMALL_STATE(7138)] = 321270,
  [SMALL_STATE(7139)] = 321325,
  [SMALL_STATE(7140)] = 321380,
  [SMALL_STATE(7141)] = 321435,
  [SMALL_STATE(7142)] = 321490,
  [SMALL_STATE(7143)] = 321545,
  [SMALL_STATE(7144)] = 321600,
  [SMALL_STATE(7145)] = 321655,
  [SMALL_STATE(7146)] = 321710,
  [SMALL_STATE(7147)] = 321815,
  [SMALL_STATE(7148)] = 321870,
  [SMALL_STATE(7149)] = 321925,
  [SMALL_STATE(7150)] = 321980,
  [SMALL_STATE(7151)] = 322035,
  [SMALL_STATE(7152)] = 322096,
  [SMALL_STATE(7153)] = 322151,
  [SMALL_STATE(7154)] = 322206,
  [SMALL_STATE(7155)] = 322261,
  [SMALL_STATE(7156)] = 322316,
  [SMALL_STATE(7157)] = 322371,
  [SMALL_STATE(7158)] = 322426,
  [SMALL_STATE(7159)] = 322481,
  [SMALL_STATE(7160)] = 322536,
  [SMALL_STATE(7161)] = 322591,
  [SMALL_STATE(7162)] = 322646,
  [SMALL_STATE(7163)] = 322701,
  [SMALL_STATE(7164)] = 322756,
  [SMALL_STATE(7165)] = 322811,
  [SMALL_STATE(7166)] = 322866,
  [SMALL_STATE(7167)] = 322921,
  [SMALL_STATE(7168)] = 322976,
  [SMALL_STATE(7169)] = 323031,
  [SMALL_STATE(7170)] = 323086,
  [SMALL_STATE(7171)] = 323141,
  [SMALL_STATE(7172)] = 323196,
  [SMALL_STATE(7173)] = 323251,
  [SMALL_STATE(7174)] = 323308,
  [SMALL_STATE(7175)] = 323363,
  [SMALL_STATE(7176)] = 323418,
  [SMALL_STATE(7177)] = 323473,
  [SMALL_STATE(7178)] = 323528,
  [SMALL_STATE(7179)] = 323583,
  [SMALL_STATE(7180)] = 323638,
  [SMALL_STATE(7181)] = 323693,
  [SMALL_STATE(7182)] = 323748,
  [SMALL_STATE(7183)] = 323803,
  [SMALL_STATE(7184)] = 323858,
  [SMALL_STATE(7185)] = 323915,
  [SMALL_STATE(7186)] = 323970,
  [SMALL_STATE(7187)] = 324025,
  [SMALL_STATE(7188)] = 324080,
  [SMALL_STATE(7189)] = 324135,
  [SMALL_STATE(7190)] = 324190,
  [SMALL_STATE(7191)] = 324245,
  [SMALL_STATE(7192)] = 324302,
  [SMALL_STATE(7193)] = 324357,
  [SMALL_STATE(7194)] = 324412,
  [SMALL_STATE(7195)] = 324473,
  [SMALL_STATE(7196)] = 324528,
  [SMALL_STATE(7197)] = 324583,
  [SMALL_STATE(7198)] = 324638,
  [SMALL_STATE(7199)] = 324693,
  [SMALL_STATE(7200)] = 324748,
  [SMALL_STATE(7201)] = 324803,
  [SMALL_STATE(7202)] = 324858,
  [SMALL_STATE(7203)] = 324913,
  [SMALL_STATE(7204)] = 324968,
  [SMALL_STATE(7205)] = 325023,
  [SMALL_STATE(7206)] = 325078,
  [SMALL_STATE(7207)] = 325133,
  [SMALL_STATE(7208)] = 325188,
  [SMALL_STATE(7209)] = 325243,
  [SMALL_STATE(7210)] = 325298,
  [SMALL_STATE(7211)] = 325353,
  [SMALL_STATE(7212)] = 325408,
  [SMALL_STATE(7213)] = 325463,
  [SMALL_STATE(7214)] = 325518,
  [SMALL_STATE(7215)] = 325573,
  [SMALL_STATE(7216)] = 325628,
  [SMALL_STATE(7217)] = 325683,
  [SMALL_STATE(7218)] = 325738,
  [SMALL_STATE(7219)] = 325793,
  [SMALL_STATE(7220)] = 325848,
  [SMALL_STATE(7221)] = 325903,
  [SMALL_STATE(7222)] = 325958,
  [SMALL_STATE(7223)] = 326019,
  [SMALL_STATE(7224)] = 326074,
  [SMALL_STATE(7225)] = 326129,
  [SMALL_STATE(7226)] = 326184,
  [SMALL_STATE(7227)] = 326239,
  [SMALL_STATE(7228)] = 326294,
  [SMALL_STATE(7229)] = 326349,
  [SMALL_STATE(7230)] = 326404,
  [SMALL_STATE(7231)] = 326459,
  [SMALL_STATE(7232)] = 326514,
  [SMALL_STATE(7233)] = 326569,
  [SMALL_STATE(7234)] = 326626,
  [SMALL_STATE(7235)] = 326681,
  [SMALL_STATE(7236)] = 326736,
  [SMALL_STATE(7237)] = 326791,
  [SMALL_STATE(7238)] = 326846,
  [SMALL_STATE(7239)] = 326901,
  [SMALL_STATE(7240)] = 327006,
  [SMALL_STATE(7241)] = 327061,
  [SMALL_STATE(7242)] = 327116,
  [SMALL_STATE(7243)] = 327173,
  [SMALL_STATE(7244)] = 327230,
  [SMALL_STATE(7245)] = 327285,
  [SMALL_STATE(7246)] = 327342,
  [SMALL_STATE(7247)] = 327397,
  [SMALL_STATE(7248)] = 327452,
  [SMALL_STATE(7249)] = 327507,
  [SMALL_STATE(7250)] = 327562,
  [SMALL_STATE(7251)] = 327617,
  [SMALL_STATE(7252)] = 327672,
  [SMALL_STATE(7253)] = 327727,
  [SMALL_STATE(7254)] = 327782,
  [SMALL_STATE(7255)] = 327837,
  [SMALL_STATE(7256)] = 327892,
  [SMALL_STATE(7257)] = 327947,
  [SMALL_STATE(7258)] = 328002,
  [SMALL_STATE(7259)] = 328057,
  [SMALL_STATE(7260)] = 328112,
  [SMALL_STATE(7261)] = 328167,
  [SMALL_STATE(7262)] = 328222,
  [SMALL_STATE(7263)] = 328277,
  [SMALL_STATE(7264)] = 328332,
  [SMALL_STATE(7265)] = 328387,
  [SMALL_STATE(7266)] = 328442,
  [SMALL_STATE(7267)] = 328503,
  [SMALL_STATE(7268)] = 328558,
  [SMALL_STATE(7269)] = 328613,
  [SMALL_STATE(7270)] = 328668,
  [SMALL_STATE(7271)] = 328723,
  [SMALL_STATE(7272)] = 328778,
  [SMALL_STATE(7273)] = 328833,
  [SMALL_STATE(7274)] = 328888,
  [SMALL_STATE(7275)] = 328993,
  [SMALL_STATE(7276)] = 329048,
  [SMALL_STATE(7277)] = 329103,
  [SMALL_STATE(7278)] = 329158,
  [SMALL_STATE(7279)] = 329213,
  [SMALL_STATE(7280)] = 329268,
  [SMALL_STATE(7281)] = 329323,
  [SMALL_STATE(7282)] = 329377,
  [SMALL_STATE(7283)] = 329431,
  [SMALL_STATE(7284)] = 329485,
  [SMALL_STATE(7285)] = 329539,
  [SMALL_STATE(7286)] = 329595,
  [SMALL_STATE(7287)] = 329649,
  [SMALL_STATE(7288)] = 329703,
  [SMALL_STATE(7289)] = 329757,
  [SMALL_STATE(7290)] = 329811,
  [SMALL_STATE(7291)] = 329865,
  [SMALL_STATE(7292)] = 329919,
  [SMALL_STATE(7293)] = 329973,
  [SMALL_STATE(7294)] = 330027,
  [SMALL_STATE(7295)] = 330081,
  [SMALL_STATE(7296)] = 330135,
  [SMALL_STATE(7297)] = 330189,
  [SMALL_STATE(7298)] = 330243,
  [SMALL_STATE(7299)] = 330297,
  [SMALL_STATE(7300)] = 330351,
  [SMALL_STATE(7301)] = 330405,
  [SMALL_STATE(7302)] = 330459,
  [SMALL_STATE(7303)] = 330513,
  [SMALL_STATE(7304)] = 330567,
  [SMALL_STATE(7305)] = 330621,
  [SMALL_STATE(7306)] = 330675,
  [SMALL_STATE(7307)] = 330729,
  [SMALL_STATE(7308)] = 330783,
  [SMALL_STATE(7309)] = 330837,
  [SMALL_STATE(7310)] = 330891,
  [SMALL_STATE(7311)] = 330945,
  [SMALL_STATE(7312)] = 330999,
  [SMALL_STATE(7313)] = 331053,
  [SMALL_STATE(7314)] = 331107,
  [SMALL_STATE(7315)] = 331161,
  [SMALL_STATE(7316)] = 331217,
  [SMALL_STATE(7317)] = 331273,
  [SMALL_STATE(7318)] = 331327,
  [SMALL_STATE(7319)] = 331381,
  [SMALL_STATE(7320)] = 331435,
  [SMALL_STATE(7321)] = 331489,
  [SMALL_STATE(7322)] = 331543,
  [SMALL_STATE(7323)] = 331597,
  [SMALL_STATE(7324)] = 331651,
  [SMALL_STATE(7325)] = 331705,
  [SMALL_STATE(7326)] = 331759,
  [SMALL_STATE(7327)] = 331813,
  [SMALL_STATE(7328)] = 331867,
  [SMALL_STATE(7329)] = 331921,
  [SMALL_STATE(7330)] = 331975,
  [SMALL_STATE(7331)] = 332029,
  [SMALL_STATE(7332)] = 332083,
  [SMALL_STATE(7333)] = 332137,
  [SMALL_STATE(7334)] = 332191,
  [SMALL_STATE(7335)] = 332245,
  [SMALL_STATE(7336)] = 332299,
  [SMALL_STATE(7337)] = 332353,
  [SMALL_STATE(7338)] = 332407,
  [SMALL_STATE(7339)] = 332461,
  [SMALL_STATE(7340)] = 332515,
  [SMALL_STATE(7341)] = 332569,
  [SMALL_STATE(7342)] = 332623,
  [SMALL_STATE(7343)] = 332677,
  [SMALL_STATE(7344)] = 332731,
  [SMALL_STATE(7345)] = 332785,
  [SMALL_STATE(7346)] = 332839,
  [SMALL_STATE(7347)] = 332893,
  [SMALL_STATE(7348)] = 332947,
  [SMALL_STATE(7349)] = 333001,
  [SMALL_STATE(7350)] = 333055,
  [SMALL_STATE(7351)] = 333109,
  [SMALL_STATE(7352)] = 333163,
  [SMALL_STATE(7353)] = 333217,
  [SMALL_STATE(7354)] = 333271,
  [SMALL_STATE(7355)] = 333325,
  [SMALL_STATE(7356)] = 333379,
  [SMALL_STATE(7357)] = 333433,
  [SMALL_STATE(7358)] = 333487,
  [SMALL_STATE(7359)] = 333541,
  [SMALL_STATE(7360)] = 333595,
  [SMALL_STATE(7361)] = 333649,
  [SMALL_STATE(7362)] = 333705,
  [SMALL_STATE(7363)] = 333759,
  [SMALL_STATE(7364)] = 333813,
  [SMALL_STATE(7365)] = 333867,
  [SMALL_STATE(7366)] = 333921,
  [SMALL_STATE(7367)] = 333975,
  [SMALL_STATE(7368)] = 334029,
  [SMALL_STATE(7369)] = 334083,
  [SMALL_STATE(7370)] = 334137,
  [SMALL_STATE(7371)] = 334191,
  [SMALL_STATE(7372)] = 334245,
  [SMALL_STATE(7373)] = 334299,
  [SMALL_STATE(7374)] = 334353,
  [SMALL_STATE(7375)] = 334407,
  [SMALL_STATE(7376)] = 334463,
  [SMALL_STATE(7377)] = 334517,
  [SMALL_STATE(7378)] = 334571,
  [SMALL_STATE(7379)] = 334625,
  [SMALL_STATE(7380)] = 334679,
  [SMALL_STATE(7381)] = 334733,
  [SMALL_STATE(7382)] = 334787,
  [SMALL_STATE(7383)] = 334841,
  [SMALL_STATE(7384)] = 334895,
  [SMALL_STATE(7385)] = 334949,
  [SMALL_STATE(7386)] = 335003,
  [SMALL_STATE(7387)] = 335057,
  [SMALL_STATE(7388)] = 335111,
  [SMALL_STATE(7389)] = 335165,
  [SMALL_STATE(7390)] = 335219,
  [SMALL_STATE(7391)] = 335273,
  [SMALL_STATE(7392)] = 335327,
  [SMALL_STATE(7393)] = 335383,
  [SMALL_STATE(7394)] = 335437,
  [SMALL_STATE(7395)] = 335491,
  [SMALL_STATE(7396)] = 335545,
  [SMALL_STATE(7397)] = 335599,
  [SMALL_STATE(7398)] = 335653,
  [SMALL_STATE(7399)] = 335707,
  [SMALL_STATE(7400)] = 335761,
  [SMALL_STATE(7401)] = 335815,
  [SMALL_STATE(7402)] = 335869,
  [SMALL_STATE(7403)] = 335923,
  [SMALL_STATE(7404)] = 335977,
  [SMALL_STATE(7405)] = 336031,
  [SMALL_STATE(7406)] = 336085,
  [SMALL_STATE(7407)] = 336139,
  [SMALL_STATE(7408)] = 336193,
  [SMALL_STATE(7409)] = 336247,
  [SMALL_STATE(7410)] = 336301,
  [SMALL_STATE(7411)] = 336355,
  [SMALL_STATE(7412)] = 336409,
  [SMALL_STATE(7413)] = 336463,
  [SMALL_STATE(7414)] = 336517,
  [SMALL_STATE(7415)] = 336571,
  [SMALL_STATE(7416)] = 336625,
  [SMALL_STATE(7417)] = 336679,
  [SMALL_STATE(7418)] = 336733,
  [SMALL_STATE(7419)] = 336787,
  [SMALL_STATE(7420)] = 336841,
  [SMALL_STATE(7421)] = 336895,
  [SMALL_STATE(7422)] = 336949,
  [SMALL_STATE(7423)] = 337003,
  [SMALL_STATE(7424)] = 337057,
  [SMALL_STATE(7425)] = 337111,
  [SMALL_STATE(7426)] = 337165,
  [SMALL_STATE(7427)] = 337219,
  [SMALL_STATE(7428)] = 337273,
  [SMALL_STATE(7429)] = 337327,
  [SMALL_STATE(7430)] = 337383,
  [SMALL_STATE(7431)] = 337437,
  [SMALL_STATE(7432)] = 337493,
  [SMALL_STATE(7433)] = 337547,
  [SMALL_STATE(7434)] = 337601,
  [SMALL_STATE(7435)] = 337655,
  [SMALL_STATE(7436)] = 337709,
  [SMALL_STATE(7437)] = 337763,
  [SMALL_STATE(7438)] = 337819,
  [SMALL_STATE(7439)] = 337873,
  [SMALL_STATE(7440)] = 337927,
  [SMALL_STATE(7441)] = 337981,
  [SMALL_STATE(7442)] = 338035,
  [SMALL_STATE(7443)] = 338089,
  [SMALL_STATE(7444)] = 338143,
  [SMALL_STATE(7445)] = 338197,
  [SMALL_STATE(7446)] = 338251,
  [SMALL_STATE(7447)] = 338307,
  [SMALL_STATE(7448)] = 338363,
  [SMALL_STATE(7449)] = 338419,
  [SMALL_STATE(7450)] = 338473,
  [SMALL_STATE(7451)] = 338527,
  [SMALL_STATE(7452)] = 338581,
  [SMALL_STATE(7453)] = 338635,
  [SMALL_STATE(7454)] = 338689,
  [SMALL_STATE(7455)] = 338743,
  [SMALL_STATE(7456)] = 338797,
  [SMALL_STATE(7457)] = 338853,
  [SMALL_STATE(7458)] = 338907,
  [SMALL_STATE(7459)] = 338963,
  [SMALL_STATE(7460)] = 339017,
  [SMALL_STATE(7461)] = 339071,
  [SMALL_STATE(7462)] = 339125,
  [SMALL_STATE(7463)] = 339179,
  [SMALL_STATE(7464)] = 339233,
  [SMALL_STATE(7465)] = 339289,
  [SMALL_STATE(7466)] = 339343,
  [SMALL_STATE(7467)] = 339398,
  [SMALL_STATE(7468)] = 339451,
  [SMALL_STATE(7469)] = 339504,
  [SMALL_STATE(7470)] = 339557,
  [SMALL_STATE(7471)] = 339610,
  [SMALL_STATE(7472)] = 339665,
  [SMALL_STATE(7473)] = 339718,
  [SMALL_STATE(7474)] = 339771,
  [SMALL_STATE(7475)] = 339824,
  [SMALL_STATE(7476)] = 339877,
  [SMALL_STATE(7477)] = 339930,
  [SMALL_STATE(7478)] = 339983,
  [SMALL_STATE(7479)] = 340036,
  [SMALL_STATE(7480)] = 340089,
  [SMALL_STATE(7481)] = 340142,
  [SMALL_STATE(7482)] = 340197,
  [SMALL_STATE(7483)] = 340250,
  [SMALL_STATE(7484)] = 340303,
  [SMALL_STATE(7485)] = 340356,
  [SMALL_STATE(7486)] = 340409,
  [SMALL_STATE(7487)] = 340462,
  [SMALL_STATE(7488)] = 340515,
  [SMALL_STATE(7489)] = 340568,
  [SMALL_STATE(7490)] = 340621,
  [SMALL_STATE(7491)] = 340674,
  [SMALL_STATE(7492)] = 340727,
  [SMALL_STATE(7493)] = 340780,
  [SMALL_STATE(7494)] = 340833,
  [SMALL_STATE(7495)] = 340886,
  [SMALL_STATE(7496)] = 340939,
  [SMALL_STATE(7497)] = 340992,
  [SMALL_STATE(7498)] = 341045,
  [SMALL_STATE(7499)] = 341098,
  [SMALL_STATE(7500)] = 341151,
  [SMALL_STATE(7501)] = 341204,
  [SMALL_STATE(7502)] = 341259,
  [SMALL_STATE(7503)] = 341312,
  [SMALL_STATE(7504)] = 341365,
  [SMALL_STATE(7505)] = 341418,
  [SMALL_STATE(7506)] = 341471,
  [SMALL_STATE(7507)] = 341524,
  [SMALL_STATE(7508)] = 341577,
  [SMALL_STATE(7509)] = 341630,
  [SMALL_STATE(7510)] = 341683,
  [SMALL_STATE(7511)] = 341736,
  [SMALL_STATE(7512)] = 341789,
  [SMALL_STATE(7513)] = 341842,
  [SMALL_STATE(7514)] = 341895,
  [SMALL_STATE(7515)] = 341948,
  [SMALL_STATE(7516)] = 342001,
  [SMALL_STATE(7517)] = 342054,
  [SMALL_STATE(7518)] = 342107,
  [SMALL_STATE(7519)] = 342160,
  [SMALL_STATE(7520)] = 342213,
  [SMALL_STATE(7521)] = 342266,
  [SMALL_STATE(7522)] = 342319,
  [SMALL_STATE(7523)] = 342372,
  [SMALL_STATE(7524)] = 342425,
  [SMALL_STATE(7525)] = 342478,
  [SMALL_STATE(7526)] = 342531,
  [SMALL_STATE(7527)] = 342584,
  [SMALL_STATE(7528)] = 342639,
  [SMALL_STATE(7529)] = 342692,
  [SMALL_STATE(7530)] = 342745,
  [SMALL_STATE(7531)] = 342798,
  [SMALL_STATE(7532)] = 342851,
  [SMALL_STATE(7533)] = 342904,
  [SMALL_STATE(7534)] = 342957,
  [SMALL_STATE(7535)] = 343012,
  [SMALL_STATE(7536)] = 343065,
  [SMALL_STATE(7537)] = 343118,
  [SMALL_STATE(7538)] = 343171,
  [SMALL_STATE(7539)] = 343224,
  [SMALL_STATE(7540)] = 343277,
  [SMALL_STATE(7541)] = 343330,
  [SMALL_STATE(7542)] = 343383,
  [SMALL_STATE(7543)] = 343436,
  [SMALL_STATE(7544)] = 343489,
  [SMALL_STATE(7545)] = 343542,
  [SMALL_STATE(7546)] = 343595,
  [SMALL_STATE(7547)] = 343648,
  [SMALL_STATE(7548)] = 343701,
  [SMALL_STATE(7549)] = 343754,
  [SMALL_STATE(7550)] = 343807,
  [SMALL_STATE(7551)] = 343860,
  [SMALL_STATE(7552)] = 343919,
  [SMALL_STATE(7553)] = 343978,
  [SMALL_STATE(7554)] = 344031,
  [SMALL_STATE(7555)] = 344084,
  [SMALL_STATE(7556)] = 344137,
  [SMALL_STATE(7557)] = 344190,
  [SMALL_STATE(7558)] = 344249,
  [SMALL_STATE(7559)] = 344308,
  [SMALL_STATE(7560)] = 344361,
  [SMALL_STATE(7561)] = 344414,
  [SMALL_STATE(7562)] = 344467,
  [SMALL_STATE(7563)] = 344520,
  [SMALL_STATE(7564)] = 344573,
  [SMALL_STATE(7565)] = 344626,
  [SMALL_STATE(7566)] = 344679,
  [SMALL_STATE(7567)] = 344732,
  [SMALL_STATE(7568)] = 344785,
  [SMALL_STATE(7569)] = 344838,
  [SMALL_STATE(7570)] = 344891,
  [SMALL_STATE(7571)] = 344944,
  [SMALL_STATE(7572)] = 344999,
  [SMALL_STATE(7573)] = 345052,
  [SMALL_STATE(7574)] = 345105,
  [SMALL_STATE(7575)] = 345158,
  [SMALL_STATE(7576)] = 345211,
  [SMALL_STATE(7577)] = 345270,
  [SMALL_STATE(7578)] = 345329,
  [SMALL_STATE(7579)] = 345382,
  [SMALL_STATE(7580)] = 345435,
  [SMALL_STATE(7581)] = 345488,
  [SMALL_STATE(7582)] = 345541,
  [SMALL_STATE(7583)] = 345594,
  [SMALL_STATE(7584)] = 345647,
  [SMALL_STATE(7585)] = 345700,
  [SMALL_STATE(7586)] = 345753,
  [SMALL_STATE(7587)] = 345808,
  [SMALL_STATE(7588)] = 345863,
  [SMALL_STATE(7589)] = 345918,
  [SMALL_STATE(7590)] = 345971,
  [SMALL_STATE(7591)] = 346024,
  [SMALL_STATE(7592)] = 346077,
  [SMALL_STATE(7593)] = 346130,
  [SMALL_STATE(7594)] = 346183,
  [SMALL_STATE(7595)] = 346236,
  [SMALL_STATE(7596)] = 346289,
  [SMALL_STATE(7597)] = 346348,
  [SMALL_STATE(7598)] = 346407,
  [SMALL_STATE(7599)] = 346460,
  [SMALL_STATE(7600)] = 346513,
  [SMALL_STATE(7601)] = 346566,
  [SMALL_STATE(7602)] = 346619,
  [SMALL_STATE(7603)] = 346672,
  [SMALL_STATE(7604)] = 346725,
  [SMALL_STATE(7605)] = 346778,
  [SMALL_STATE(7606)] = 346831,
  [SMALL_STATE(7607)] = 346884,
  [SMALL_STATE(7608)] = 346937,
  [SMALL_STATE(7609)] = 346990,
  [SMALL_STATE(7610)] = 347043,
  [SMALL_STATE(7611)] = 347096,
  [SMALL_STATE(7612)] = 347149,
  [SMALL_STATE(7613)] = 347204,
  [SMALL_STATE(7614)] = 347257,
  [SMALL_STATE(7615)] = 347310,
  [SMALL_STATE(7616)] = 347363,
  [SMALL_STATE(7617)] = 347416,
  [SMALL_STATE(7618)] = 347469,
  [SMALL_STATE(7619)] = 347522,
  [SMALL_STATE(7620)] = 347575,
  [SMALL_STATE(7621)] = 347628,
  [SMALL_STATE(7622)] = 347681,
  [SMALL_STATE(7623)] = 347734,
  [SMALL_STATE(7624)] = 347789,
  [SMALL_STATE(7625)] = 347842,
  [SMALL_STATE(7626)] = 347895,
  [SMALL_STATE(7627)] = 347948,
  [SMALL_STATE(7628)] = 348001,
  [SMALL_STATE(7629)] = 348054,
  [SMALL_STATE(7630)] = 348107,
  [SMALL_STATE(7631)] = 348160,
  [SMALL_STATE(7632)] = 348213,
  [SMALL_STATE(7633)] = 348266,
  [SMALL_STATE(7634)] = 348319,
  [SMALL_STATE(7635)] = 348372,
  [SMALL_STATE(7636)] = 348425,
  [SMALL_STATE(7637)] = 348478,
  [SMALL_STATE(7638)] = 348531,
  [SMALL_STATE(7639)] = 348584,
  [SMALL_STATE(7640)] = 348637,
  [SMALL_STATE(7641)] = 348690,
  [SMALL_STATE(7642)] = 348743,
  [SMALL_STATE(7643)] = 348796,
  [SMALL_STATE(7644)] = 348849,
  [SMALL_STATE(7645)] = 348902,
  [SMALL_STATE(7646)] = 348955,
  [SMALL_STATE(7647)] = 349008,
  [SMALL_STATE(7648)] = 349061,
  [SMALL_STATE(7649)] = 349114,
  [SMALL_STATE(7650)] = 349167,
  [SMALL_STATE(7651)] = 349220,
  [SMALL_STATE(7652)] = 349273,
  [SMALL_STATE(7653)] = 349326,
  [SMALL_STATE(7654)] = 349379,
  [SMALL_STATE(7655)] = 349432,
  [SMALL_STATE(7656)] = 349485,
  [SMALL_STATE(7657)] = 349538,
  [SMALL_STATE(7658)] = 349591,
  [SMALL_STATE(7659)] = 349644,
  [SMALL_STATE(7660)] = 349697,
  [SMALL_STATE(7661)] = 349752,
  [SMALL_STATE(7662)] = 349805,
  [SMALL_STATE(7663)] = 349858,
  [SMALL_STATE(7664)] = 349911,
  [SMALL_STATE(7665)] = 349964,
  [SMALL_STATE(7666)] = 350017,
  [SMALL_STATE(7667)] = 350070,
  [SMALL_STATE(7668)] = 350123,
  [SMALL_STATE(7669)] = 350176,
  [SMALL_STATE(7670)] = 350229,
  [SMALL_STATE(7671)] = 350282,
  [SMALL_STATE(7672)] = 350335,
  [SMALL_STATE(7673)] = 350388,
  [SMALL_STATE(7674)] = 350441,
  [SMALL_STATE(7675)] = 350494,
  [SMALL_STATE(7676)] = 350547,
  [SMALL_STATE(7677)] = 350600,
  [SMALL_STATE(7678)] = 350653,
  [SMALL_STATE(7679)] = 350706,
  [SMALL_STATE(7680)] = 350759,
  [SMALL_STATE(7681)] = 350812,
  [SMALL_STATE(7682)] = 350865,
  [SMALL_STATE(7683)] = 350918,
  [SMALL_STATE(7684)] = 350971,
  [SMALL_STATE(7685)] = 351024,
  [SMALL_STATE(7686)] = 351079,
  [SMALL_STATE(7687)] = 351132,
  [SMALL_STATE(7688)] = 351185,
  [SMALL_STATE(7689)] = 351238,
  [SMALL_STATE(7690)] = 351291,
  [SMALL_STATE(7691)] = 351344,
  [SMALL_STATE(7692)] = 351397,
  [SMALL_STATE(7693)] = 351450,
  [SMALL_STATE(7694)] = 351503,
  [SMALL_STATE(7695)] = 351556,
  [SMALL_STATE(7696)] = 351609,
  [SMALL_STATE(7697)] = 351662,
  [SMALL_STATE(7698)] = 351715,
  [SMALL_STATE(7699)] = 351768,
  [SMALL_STATE(7700)] = 351821,
  [SMALL_STATE(7701)] = 351874,
  [SMALL_STATE(7702)] = 351927,
  [SMALL_STATE(7703)] = 351980,
  [SMALL_STATE(7704)] = 352035,
  [SMALL_STATE(7705)] = 352088,
  [SMALL_STATE(7706)] = 352141,
  [SMALL_STATE(7707)] = 352194,
  [SMALL_STATE(7708)] = 352247,
  [SMALL_STATE(7709)] = 352300,
  [SMALL_STATE(7710)] = 352353,
  [SMALL_STATE(7711)] = 352406,
  [SMALL_STATE(7712)] = 352459,
  [SMALL_STATE(7713)] = 352512,
  [SMALL_STATE(7714)] = 352565,
  [SMALL_STATE(7715)] = 352618,
  [SMALL_STATE(7716)] = 352671,
  [SMALL_STATE(7717)] = 352724,
  [SMALL_STATE(7718)] = 352777,
  [SMALL_STATE(7719)] = 352830,
  [SMALL_STATE(7720)] = 352883,
  [SMALL_STATE(7721)] = 352936,
  [SMALL_STATE(7722)] = 352989,
  [SMALL_STATE(7723)] = 353042,
  [SMALL_STATE(7724)] = 353095,
  [SMALL_STATE(7725)] = 353148,
  [SMALL_STATE(7726)] = 353201,
  [SMALL_STATE(7727)] = 353254,
  [SMALL_STATE(7728)] = 353307,
  [SMALL_STATE(7729)] = 353359,
  [SMALL_STATE(7730)] = 353411,
  [SMALL_STATE(7731)] = 353463,
  [SMALL_STATE(7732)] = 353515,
  [SMALL_STATE(7733)] = 353615,
  [SMALL_STATE(7734)] = 353715,
  [SMALL_STATE(7735)] = 353767,
  [SMALL_STATE(7736)] = 353867,
  [SMALL_STATE(7737)] = 353919,
  [SMALL_STATE(7738)] = 353971,
  [SMALL_STATE(7739)] = 354071,
  [SMALL_STATE(7740)] = 354123,
  [SMALL_STATE(7741)] = 354175,
  [SMALL_STATE(7742)] = 354227,
  [SMALL_STATE(7743)] = 354279,
  [SMALL_STATE(7744)] = 354331,
  [SMALL_STATE(7745)] = 354383,
  [SMALL_STATE(7746)] = 354435,
  [SMALL_STATE(7747)] = 354487,
  [SMALL_STATE(7748)] = 354539,
  [SMALL_STATE(7749)] = 354591,
  [SMALL_STATE(7750)] = 354643,
  [SMALL_STATE(7751)] = 354695,
  [SMALL_STATE(7752)] = 354747,
  [SMALL_STATE(7753)] = 354847,
  [SMALL_STATE(7754)] = 354947,
  [SMALL_STATE(7755)] = 354999,
  [SMALL_STATE(7756)] = 355099,
  [SMALL_STATE(7757)] = 355199,
  [SMALL_STATE(7758)] = 355251,
  [SMALL_STATE(7759)] = 355303,
  [SMALL_STATE(7760)] = 355355,
  [SMALL_STATE(7761)] = 355407,
  [SMALL_STATE(7762)] = 355459,
  [SMALL_STATE(7763)] = 355511,
  [SMALL_STATE(7764)] = 355563,
  [SMALL_STATE(7765)] = 355663,
  [SMALL_STATE(7766)] = 355715,
  [SMALL_STATE(7767)] = 355767,
  [SMALL_STATE(7768)] = 355867,
  [SMALL_STATE(7769)] = 355919,
  [SMALL_STATE(7770)] = 355971,
  [SMALL_STATE(7771)] = 356023,
  [SMALL_STATE(7772)] = 356075,
  [SMALL_STATE(7773)] = 356175,
  [SMALL_STATE(7774)] = 356275,
  [SMALL_STATE(7775)] = 356327,
  [SMALL_STATE(7776)] = 356379,
  [SMALL_STATE(7777)] = 356433,
  [SMALL_STATE(7778)] = 356485,
  [SMALL_STATE(7779)] = 356537,
  [SMALL_STATE(7780)] = 356637,
  [SMALL_STATE(7781)] = 356691,
  [SMALL_STATE(7782)] = 356743,
  [SMALL_STATE(7783)] = 356795,
  [SMALL_STATE(7784)] = 356895,
  [SMALL_STATE(7785)] = 356995,
  [SMALL_STATE(7786)] = 357047,
  [SMALL_STATE(7787)] = 357099,
  [SMALL_STATE(7788)] = 357151,
  [SMALL_STATE(7789)] = 357251,
  [SMALL_STATE(7790)] = 357351,
  [SMALL_STATE(7791)] = 357451,
  [SMALL_STATE(7792)] = 357503,
  [SMALL_STATE(7793)] = 357603,
  [SMALL_STATE(7794)] = 357703,
  [SMALL_STATE(7795)] = 357755,
  [SMALL_STATE(7796)] = 357807,
  [SMALL_STATE(7797)] = 357859,
  [SMALL_STATE(7798)] = 357911,
  [SMALL_STATE(7799)] = 358011,
  [SMALL_STATE(7800)] = 358063,
  [SMALL_STATE(7801)] = 358115,
  [SMALL_STATE(7802)] = 358167,
  [SMALL_STATE(7803)] = 358219,
  [SMALL_STATE(7804)] = 358271,
  [SMALL_STATE(7805)] = 358323,
  [SMALL_STATE(7806)] = 358375,
  [SMALL_STATE(7807)] = 358427,
  [SMALL_STATE(7808)] = 358479,
  [SMALL_STATE(7809)] = 358531,
  [SMALL_STATE(7810)] = 358583,
  [SMALL_STATE(7811)] = 358635,
  [SMALL_STATE(7812)] = 358687,
  [SMALL_STATE(7813)] = 358787,
  [SMALL_STATE(7814)] = 358839,
  [SMALL_STATE(7815)] = 358891,
  [SMALL_STATE(7816)] = 358943,
  [SMALL_STATE(7817)] = 358995,
  [SMALL_STATE(7818)] = 359047,
  [SMALL_STATE(7819)] = 359099,
  [SMALL_STATE(7820)] = 359151,
  [SMALL_STATE(7821)] = 359203,
  [SMALL_STATE(7822)] = 359303,
  [SMALL_STATE(7823)] = 359403,
  [SMALL_STATE(7824)] = 359455,
  [SMALL_STATE(7825)] = 359507,
  [SMALL_STATE(7826)] = 359559,
  [SMALL_STATE(7827)] = 359611,
  [SMALL_STATE(7828)] = 359663,
  [SMALL_STATE(7829)] = 359715,
  [SMALL_STATE(7830)] = 359767,
  [SMALL_STATE(7831)] = 359867,
  [SMALL_STATE(7832)] = 359919,
  [SMALL_STATE(7833)] = 359973,
  [SMALL_STATE(7834)] = 360073,
  [SMALL_STATE(7835)] = 360125,
  [SMALL_STATE(7836)] = 360176,
  [SMALL_STATE(7837)] = 360227,
  [SMALL_STATE(7838)] = 360324,
  [SMALL_STATE(7839)] = 360375,
  [SMALL_STATE(7840)] = 360472,
  [SMALL_STATE(7841)] = 360523,
  [SMALL_STATE(7842)] = 360574,
  [SMALL_STATE(7843)] = 360625,
  [SMALL_STATE(7844)] = 360718,
  [SMALL_STATE(7845)] = 360817,
  [SMALL_STATE(7846)] = 360914,
  [SMALL_STATE(7847)] = 361011,
  [SMALL_STATE(7848)] = 361062,
  [SMALL_STATE(7849)] = 361159,
  [SMALL_STATE(7850)] = 361210,
  [SMALL_STATE(7851)] = 361307,
  [SMALL_STATE(7852)] = 361358,
  [SMALL_STATE(7853)] = 361455,
  [SMALL_STATE(7854)] = 361554,
  [SMALL_STATE(7855)] = 361605,
  [SMALL_STATE(7856)] = 361656,
  [SMALL_STATE(7857)] = 361707,
  [SMALL_STATE(7858)] = 361758,
  [SMALL_STATE(7859)] = 361809,
  [SMALL_STATE(7860)] = 361906,
  [SMALL_STATE(7861)] = 361985,
  [SMALL_STATE(7862)] = 362082,
  [SMALL_STATE(7863)] = 362175,
  [SMALL_STATE(7864)] = 362226,
  [SMALL_STATE(7865)] = 362323,
  [SMALL_STATE(7866)] = 362374,
  [SMALL_STATE(7867)] = 362471,
  [SMALL_STATE(7868)] = 362522,
  [SMALL_STATE(7869)] = 362573,
  [SMALL_STATE(7870)] = 362624,
  [SMALL_STATE(7871)] = 362675,
  [SMALL_STATE(7872)] = 362772,
  [SMALL_STATE(7873)] = 362823,
  [SMALL_STATE(7874)] = 362916,
  [SMALL_STATE(7875)] = 363013,
  [SMALL_STATE(7876)] = 363110,
  [SMALL_STATE(7877)] = 363161,
  [SMALL_STATE(7878)] = 363212,
  [SMALL_STATE(7879)] = 363309,
  [SMALL_STATE(7880)] = 363408,
  [SMALL_STATE(7881)] = 363459,
  [SMALL_STATE(7882)] = 363556,
  [SMALL_STATE(7883)] = 363607,
  [SMALL_STATE(7884)] = 363658,
  [SMALL_STATE(7885)] = 363751,
  [SMALL_STATE(7886)] = 363802,
  [SMALL_STATE(7887)] = 363853,
  [SMALL_STATE(7888)] = 363904,
  [SMALL_STATE(7889)] = 363955,
  [SMALL_STATE(7890)] = 364006,
  [SMALL_STATE(7891)] = 364057,
  [SMALL_STATE(7892)] = 364108,
  [SMALL_STATE(7893)] = 364201,
  [SMALL_STATE(7894)] = 364252,
  [SMALL_STATE(7895)] = 364303,
  [SMALL_STATE(7896)] = 364354,
  [SMALL_STATE(7897)] = 364405,
  [SMALL_STATE(7898)] = 364502,
  [SMALL_STATE(7899)] = 364553,
  [SMALL_STATE(7900)] = 364604,
  [SMALL_STATE(7901)] = 364655,
  [SMALL_STATE(7902)] = 364748,
  [SMALL_STATE(7903)] = 364799,
  [SMALL_STATE(7904)] = 364850,
  [SMALL_STATE(7905)] = 364949,
  [SMALL_STATE(7906)] = 365000,
  [SMALL_STATE(7907)] = 365051,
  [SMALL_STATE(7908)] = 365150,
  [SMALL_STATE(7909)] = 365201,
  [SMALL_STATE(7910)] = 365294,
  [SMALL_STATE(7911)] = 365391,
  [SMALL_STATE(7912)] = 365488,
  [SMALL_STATE(7913)] = 365539,
  [SMALL_STATE(7914)] = 365636,
  [SMALL_STATE(7915)] = 365729,
  [SMALL_STATE(7916)] = 365780,
  [SMALL_STATE(7917)] = 365877,
  [SMALL_STATE(7918)] = 365928,
  [SMALL_STATE(7919)] = 365979,
  [SMALL_STATE(7920)] = 366076,
  [SMALL_STATE(7921)] = 366127,
  [SMALL_STATE(7922)] = 366220,
  [SMALL_STATE(7923)] = 366271,
  [SMALL_STATE(7924)] = 366350,
  [SMALL_STATE(7925)] = 366401,
  [SMALL_STATE(7926)] = 366452,
  [SMALL_STATE(7927)] = 366503,
  [SMALL_STATE(7928)] = 366554,
  [SMALL_STATE(7929)] = 366605,
  [SMALL_STATE(7930)] = 366656,
  [SMALL_STATE(7931)] = 366749,
  [SMALL_STATE(7932)] = 366800,
  [SMALL_STATE(7933)] = 366897,
  [SMALL_STATE(7934)] = 366994,
  [SMALL_STATE(7935)] = 367087,
  [SMALL_STATE(7936)] = 367184,
  [SMALL_STATE(7937)] = 367281,
  [SMALL_STATE(7938)] = 367332,
  [SMALL_STATE(7939)] = 367383,
  [SMALL_STATE(7940)] = 367480,
  [SMALL_STATE(7941)] = 367531,
  [SMALL_STATE(7942)] = 367582,
  [SMALL_STATE(7943)] = 367679,
  [SMALL_STATE(7944)] = 367730,
  [SMALL_STATE(7945)] = 367781,
  [SMALL_STATE(7946)] = 367878,
  [SMALL_STATE(7947)] = 367929,
  [SMALL_STATE(7948)] = 367980,
  [SMALL_STATE(7949)] = 368031,
  [SMALL_STATE(7950)] = 368082,
  [SMALL_STATE(7951)] = 368179,
  [SMALL_STATE(7952)] = 368230,
  [SMALL_STATE(7953)] = 368281,
  [SMALL_STATE(7954)] = 368332,
  [SMALL_STATE(7955)] = 368383,
  [SMALL_STATE(7956)] = 368434,
  [SMALL_STATE(7957)] = 368531,
  [SMALL_STATE(7958)] = 368582,
  [SMALL_STATE(7959)] = 368633,
  [SMALL_STATE(7960)] = 368730,
  [SMALL_STATE(7961)] = 368827,
  [SMALL_STATE(7962)] = 368878,
  [SMALL_STATE(7963)] = 368975,
  [SMALL_STATE(7964)] = 369072,
  [SMALL_STATE(7965)] = 369123,
  [SMALL_STATE(7966)] = 369174,
  [SMALL_STATE(7967)] = 369225,
  [SMALL_STATE(7968)] = 369276,
  [SMALL_STATE(7969)] = 369373,
  [SMALL_STATE(7970)] = 369424,
  [SMALL_STATE(7971)] = 369475,
  [SMALL_STATE(7972)] = 369568,
  [SMALL_STATE(7973)] = 369667,
  [SMALL_STATE(7974)] = 369760,
  [SMALL_STATE(7975)] = 369811,
  [SMALL_STATE(7976)] = 369908,
  [SMALL_STATE(7977)] = 369959,
  [SMALL_STATE(7978)] = 370010,
  [SMALL_STATE(7979)] = 370107,
  [SMALL_STATE(7980)] = 370158,
  [SMALL_STATE(7981)] = 370209,
  [SMALL_STATE(7982)] = 370262,
  [SMALL_STATE(7983)] = 370313,
  [SMALL_STATE(7984)] = 370364,
  [SMALL_STATE(7985)] = 370417,
  [SMALL_STATE(7986)] = 370468,
  [SMALL_STATE(7987)] = 370519,
  [SMALL_STATE(7988)] = 370570,
  [SMALL_STATE(7989)] = 370621,
  [SMALL_STATE(7990)] = 370672,
  [SMALL_STATE(7991)] = 370723,
  [SMALL_STATE(7992)] = 370774,
  [SMALL_STATE(7993)] = 370825,
  [SMALL_STATE(7994)] = 370876,
  [SMALL_STATE(7995)] = 370927,
  [SMALL_STATE(7996)] = 370978,
  [SMALL_STATE(7997)] = 371075,
  [SMALL_STATE(7998)] = 371172,
  [SMALL_STATE(7999)] = 371223,
  [SMALL_STATE(8000)] = 371274,
  [SMALL_STATE(8001)] = 371371,
  [SMALL_STATE(8002)] = 371422,
  [SMALL_STATE(8003)] = 371473,
  [SMALL_STATE(8004)] = 371566,
  [SMALL_STATE(8005)] = 371659,
  [SMALL_STATE(8006)] = 371710,
  [SMALL_STATE(8007)] = 371761,
  [SMALL_STATE(8008)] = 371812,
  [SMALL_STATE(8009)] = 371863,
  [SMALL_STATE(8010)] = 371914,
  [SMALL_STATE(8011)] = 371965,
  [SMALL_STATE(8012)] = 372058,
  [SMALL_STATE(8013)] = 372109,
  [SMALL_STATE(8014)] = 372160,
  [SMALL_STATE(8015)] = 372211,
  [SMALL_STATE(8016)] = 372262,
  [SMALL_STATE(8017)] = 372313,
  [SMALL_STATE(8018)] = 372364,
  [SMALL_STATE(8019)] = 372417,
  [SMALL_STATE(8020)] = 372468,
  [SMALL_STATE(8021)] = 372561,
  [SMALL_STATE(8022)] = 372658,
  [SMALL_STATE(8023)] = 372709,
  [SMALL_STATE(8024)] = 372760,
  [SMALL_STATE(8025)] = 372811,
  [SMALL_STATE(8026)] = 372862,
  [SMALL_STATE(8027)] = 372913,
  [SMALL_STATE(8028)] = 373010,
  [SMALL_STATE(8029)] = 373107,
  [SMALL_STATE(8030)] = 373158,
  [SMALL_STATE(8031)] = 373209,
  [SMALL_STATE(8032)] = 373306,
  [SMALL_STATE(8033)] = 373357,
  [SMALL_STATE(8034)] = 373408,
  [SMALL_STATE(8035)] = 373501,
  [SMALL_STATE(8036)] = 373552,
  [SMALL_STATE(8037)] = 373645,
  [SMALL_STATE(8038)] = 373696,
  [SMALL_STATE(8039)] = 373793,
  [SMALL_STATE(8040)] = 373844,
  [SMALL_STATE(8041)] = 373895,
  [SMALL_STATE(8042)] = 373946,
  [SMALL_STATE(8043)] = 373997,
  [SMALL_STATE(8044)] = 374048,
  [SMALL_STATE(8045)] = 374099,
  [SMALL_STATE(8046)] = 374150,
  [SMALL_STATE(8047)] = 374201,
  [SMALL_STATE(8048)] = 374298,
  [SMALL_STATE(8049)] = 374349,
  [SMALL_STATE(8050)] = 374446,
  [SMALL_STATE(8051)] = 374497,
  [SMALL_STATE(8052)] = 374552,
  [SMALL_STATE(8053)] = 374603,
  [SMALL_STATE(8054)] = 374654,
  [SMALL_STATE(8055)] = 374751,
  [SMALL_STATE(8056)] = 374848,
  [SMALL_STATE(8057)] = 374903,
  [SMALL_STATE(8058)] = 375000,
  [SMALL_STATE(8059)] = 375051,
  [SMALL_STATE(8060)] = 375102,
  [SMALL_STATE(8061)] = 375153,
  [SMALL_STATE(8062)] = 375204,
  [SMALL_STATE(8063)] = 375255,
  [SMALL_STATE(8064)] = 375306,
  [SMALL_STATE(8065)] = 375357,
  [SMALL_STATE(8066)] = 375408,
  [SMALL_STATE(8067)] = 375459,
  [SMALL_STATE(8068)] = 375556,
  [SMALL_STATE(8069)] = 375653,
  [SMALL_STATE(8070)] = 375704,
  [SMALL_STATE(8071)] = 375755,
  [SMALL_STATE(8072)] = 375806,
  [SMALL_STATE(8073)] = 375899,
  [SMALL_STATE(8074)] = 375950,
  [SMALL_STATE(8075)] = 376007,
  [SMALL_STATE(8076)] = 376060,
  [SMALL_STATE(8077)] = 376111,
  [SMALL_STATE(8078)] = 376162,
  [SMALL_STATE(8079)] = 376259,
  [SMALL_STATE(8080)] = 376310,
  [SMALL_STATE(8081)] = 376361,
  [SMALL_STATE(8082)] = 376458,
  [SMALL_STATE(8083)] = 376555,
  [SMALL_STATE(8084)] = 376652,
  [SMALL_STATE(8085)] = 376709,
  [SMALL_STATE(8086)] = 376806,
  [SMALL_STATE(8087)] = 376903,
  [SMALL_STATE(8088)] = 377000,
  [SMALL_STATE(8089)] = 377051,
  [SMALL_STATE(8090)] = 377102,
  [SMALL_STATE(8091)] = 377153,
  [SMALL_STATE(8092)] = 377250,
  [SMALL_STATE(8093)] = 377311,
  [SMALL_STATE(8094)] = 377362,
  [SMALL_STATE(8095)] = 377413,
  [SMALL_STATE(8096)] = 377510,
  [SMALL_STATE(8097)] = 377607,
  [SMALL_STATE(8098)] = 377704,
  [SMALL_STATE(8099)] = 377801,
  [SMALL_STATE(8100)] = 377898,
  [SMALL_STATE(8101)] = 377949,
  [SMALL_STATE(8102)] = 378046,
  [SMALL_STATE(8103)] = 378143,
  [SMALL_STATE(8104)] = 378194,
  [SMALL_STATE(8105)] = 378244,
  [SMALL_STATE(8106)] = 378338,
  [SMALL_STATE(8107)] = 378406,
  [SMALL_STATE(8108)] = 378500,
  [SMALL_STATE(8109)] = 378594,
  [SMALL_STATE(8110)] = 378644,
  [SMALL_STATE(8111)] = 378694,
  [SMALL_STATE(8112)] = 378788,
  [SMALL_STATE(8113)] = 378844,
  [SMALL_STATE(8114)] = 378938,
  [SMALL_STATE(8115)] = 379032,
  [SMALL_STATE(8116)] = 379126,
  [SMALL_STATE(8117)] = 379176,
  [SMALL_STATE(8118)] = 379226,
  [SMALL_STATE(8119)] = 379320,
  [SMALL_STATE(8120)] = 379414,
  [SMALL_STATE(8121)] = 379468,
  [SMALL_STATE(8122)] = 379522,
  [SMALL_STATE(8123)] = 379572,
  [SMALL_STATE(8124)] = 379622,
  [SMALL_STATE(8125)] = 379688,
  [SMALL_STATE(8126)] = 379738,
  [SMALL_STATE(8127)] = 379788,
  [SMALL_STATE(8128)] = 379838,
  [SMALL_STATE(8129)] = 379932,
  [SMALL_STATE(8130)] = 380004,
  [SMALL_STATE(8131)] = 380058,
  [SMALL_STATE(8132)] = 380108,
  [SMALL_STATE(8133)] = 380162,
  [SMALL_STATE(8134)] = 380214,
  [SMALL_STATE(8135)] = 380264,
  [SMALL_STATE(8136)] = 380316,
  [SMALL_STATE(8137)] = 380378,
  [SMALL_STATE(8138)] = 380432,
  [SMALL_STATE(8139)] = 380484,
  [SMALL_STATE(8140)] = 380578,
  [SMALL_STATE(8141)] = 380628,
  [SMALL_STATE(8142)] = 380722,
  [SMALL_STATE(8143)] = 380816,
  [SMALL_STATE(8144)] = 380866,
  [SMALL_STATE(8145)] = 380916,
  [SMALL_STATE(8146)] = 380988,
  [SMALL_STATE(8147)] = 381038,
  [SMALL_STATE(8148)] = 381132,
  [SMALL_STATE(8149)] = 381192,
  [SMALL_STATE(8150)] = 381286,
  [SMALL_STATE(8151)] = 381380,
  [SMALL_STATE(8152)] = 381474,
  [SMALL_STATE(8153)] = 381568,
  [SMALL_STATE(8154)] = 381662,
  [SMALL_STATE(8155)] = 381756,
  [SMALL_STATE(8156)] = 381828,
  [SMALL_STATE(8157)] = 381880,
  [SMALL_STATE(8158)] = 381930,
  [SMALL_STATE(8159)] = 382024,
  [SMALL_STATE(8160)] = 382092,
  [SMALL_STATE(8161)] = 382186,
  [SMALL_STATE(8162)] = 382236,
  [SMALL_STATE(8163)] = 382286,
  [SMALL_STATE(8164)] = 382336,
  [SMALL_STATE(8165)] = 382398,
  [SMALL_STATE(8166)] = 382450,
  [SMALL_STATE(8167)] = 382544,
  [SMALL_STATE(8168)] = 382598,
  [SMALL_STATE(8169)] = 382692,
  [SMALL_STATE(8170)] = 382786,
  [SMALL_STATE(8171)] = 382836,
  [SMALL_STATE(8172)] = 382890,
  [SMALL_STATE(8173)] = 382942,
  [SMALL_STATE(8174)] = 383036,
  [SMALL_STATE(8175)] = 383130,
  [SMALL_STATE(8176)] = 383224,
  [SMALL_STATE(8177)] = 383274,
  [SMALL_STATE(8178)] = 383324,
  [SMALL_STATE(8179)] = 383378,
  [SMALL_STATE(8180)] = 383472,
  [SMALL_STATE(8181)] = 383526,
  [SMALL_STATE(8182)] = 383620,
  [SMALL_STATE(8183)] = 383714,
  [SMALL_STATE(8184)] = 383808,
  [SMALL_STATE(8185)] = 383858,
  [SMALL_STATE(8186)] = 383908,
  [SMALL_STATE(8187)] = 383962,
  [SMALL_STATE(8188)] = 384034,
  [SMALL_STATE(8189)] = 384084,
  [SMALL_STATE(8190)] = 384178,
  [SMALL_STATE(8191)] = 384228,
  [SMALL_STATE(8192)] = 384322,
  [SMALL_STATE(8193)] = 384416,
  [SMALL_STATE(8194)] = 384510,
  [SMALL_STATE(8195)] = 384560,
  [SMALL_STATE(8196)] = 384632,
  [SMALL_STATE(8197)] = 384726,
  [SMALL_STATE(8198)] = 384820,
  [SMALL_STATE(8199)] = 384914,
  [SMALL_STATE(8200)] = 384964,
  [SMALL_STATE(8201)] = 385014,
  [SMALL_STATE(8202)] = 385108,
  [SMALL_STATE(8203)] = 385158,
  [SMALL_STATE(8204)] = 385208,
  [SMALL_STATE(8205)] = 385302,
  [SMALL_STATE(8206)] = 385396,
  [SMALL_STATE(8207)] = 385490,
  [SMALL_STATE(8208)] = 385540,
  [SMALL_STATE(8209)] = 385634,
  [SMALL_STATE(8210)] = 385728,
  [SMALL_STATE(8211)] = 385782,
  [SMALL_STATE(8212)] = 385832,
  [SMALL_STATE(8213)] = 385882,
  [SMALL_STATE(8214)] = 385932,
  [SMALL_STATE(8215)] = 386026,
  [SMALL_STATE(8216)] = 386076,
  [SMALL_STATE(8217)] = 386126,
  [SMALL_STATE(8218)] = 386176,
  [SMALL_STATE(8219)] = 386226,
  [SMALL_STATE(8220)] = 386276,
  [SMALL_STATE(8221)] = 386326,
  [SMALL_STATE(8222)] = 386376,
  [SMALL_STATE(8223)] = 386470,
  [SMALL_STATE(8224)] = 386564,
  [SMALL_STATE(8225)] = 386658,
  [SMALL_STATE(8226)] = 386718,
  [SMALL_STATE(8227)] = 386772,
  [SMALL_STATE(8228)] = 386840,
  [SMALL_STATE(8229)] = 386890,
  [SMALL_STATE(8230)] = 386984,
  [SMALL_STATE(8231)] = 387034,
  [SMALL_STATE(8232)] = 387128,
  [SMALL_STATE(8233)] = 387222,
  [SMALL_STATE(8234)] = 387316,
  [SMALL_STATE(8235)] = 387410,
  [SMALL_STATE(8236)] = 387504,
  [SMALL_STATE(8237)] = 387598,
  [SMALL_STATE(8238)] = 387648,
  [SMALL_STATE(8239)] = 387702,
  [SMALL_STATE(8240)] = 387776,
  [SMALL_STATE(8241)] = 387870,
  [SMALL_STATE(8242)] = 387930,
  [SMALL_STATE(8243)] = 387984,
  [SMALL_STATE(8244)] = 388034,
  [SMALL_STATE(8245)] = 388084,
  [SMALL_STATE(8246)] = 388156,
  [SMALL_STATE(8247)] = 388210,
  [SMALL_STATE(8248)] = 388272,
  [SMALL_STATE(8249)] = 388334,
  [SMALL_STATE(8250)] = 388428,
  [SMALL_STATE(8251)] = 388522,
  [SMALL_STATE(8252)] = 388616,
  [SMALL_STATE(8253)] = 388666,
  [SMALL_STATE(8254)] = 388760,
  [SMALL_STATE(8255)] = 388814,
  [SMALL_STATE(8256)] = 388868,
  [SMALL_STATE(8257)] = 388934,
  [SMALL_STATE(8258)] = 388984,
  [SMALL_STATE(8259)] = 389038,
  [SMALL_STATE(8260)] = 389088,
  [SMALL_STATE(8261)] = 389182,
  [SMALL_STATE(8262)] = 389234,
  [SMALL_STATE(8263)] = 389284,
  [SMALL_STATE(8264)] = 389334,
  [SMALL_STATE(8265)] = 389408,
  [SMALL_STATE(8266)] = 389502,
  [SMALL_STATE(8267)] = 389552,
  [SMALL_STATE(8268)] = 389646,
  [SMALL_STATE(8269)] = 389740,
  [SMALL_STATE(8270)] = 389790,
  [SMALL_STATE(8271)] = 389840,
  [SMALL_STATE(8272)] = 389890,
  [SMALL_STATE(8273)] = 389958,
  [SMALL_STATE(8274)] = 390030,
  [SMALL_STATE(8275)] = 390086,
  [SMALL_STATE(8276)] = 390158,
  [SMALL_STATE(8277)] = 390212,
  [SMALL_STATE(8278)] = 390262,
  [SMALL_STATE(8279)] = 390312,
  [SMALL_STATE(8280)] = 390406,
  [SMALL_STATE(8281)] = 390460,
  [SMALL_STATE(8282)] = 390510,
  [SMALL_STATE(8283)] = 390560,
  [SMALL_STATE(8284)] = 390610,
  [SMALL_STATE(8285)] = 390704,
  [SMALL_STATE(8286)] = 390755,
  [SMALL_STATE(8287)] = 390826,
  [SMALL_STATE(8288)] = 390875,
  [SMALL_STATE(8289)] = 390946,
  [SMALL_STATE(8290)] = 391001,
  [SMALL_STATE(8291)] = 391072,
  [SMALL_STATE(8292)] = 391121,
  [SMALL_STATE(8293)] = 391188,
  [SMALL_STATE(8294)] = 391261,
  [SMALL_STATE(8295)] = 391314,
  [SMALL_STATE(8296)] = 391373,
  [SMALL_STATE(8297)] = 391440,
  [SMALL_STATE(8298)] = 391493,
  [SMALL_STATE(8299)] = 391544,
  [SMALL_STATE(8300)] = 391617,
  [SMALL_STATE(8301)] = 391688,
  [SMALL_STATE(8302)] = 391753,
  [SMALL_STATE(8303)] = 391814,
  [SMALL_STATE(8304)] = 391867,
  [SMALL_STATE(8305)] = 391928,
  [SMALL_STATE(8306)] = 391981,
  [SMALL_STATE(8307)] = 392054,
  [SMALL_STATE(8308)] = 392107,
  [SMALL_STATE(8309)] = 392166,
  [SMALL_STATE(8310)] = 392233,
  [SMALL_STATE(8311)] = 392286,
  [SMALL_STATE(8312)] = 392337,
  [SMALL_STATE(8313)] = 392408,
  [SMALL_STATE(8314)] = 392461,
  [SMALL_STATE(8315)] = 392514,
  [SMALL_STATE(8316)] = 392585,
  [SMALL_STATE(8317)] = 392676,
  [SMALL_STATE(8318)] = 392731,
  [SMALL_STATE(8319)] = 392802,
  [SMALL_STATE(8320)] = 392855,
  [SMALL_STATE(8321)] = 392908,
  [SMALL_STATE(8322)] = 392975,
  [SMALL_STATE(8323)] = 393040,
  [SMALL_STATE(8324)] = 393093,
  [SMALL_STATE(8325)] = 393154,
  [SMALL_STATE(8326)] = 393207,
  [SMALL_STATE(8327)] = 393268,
  [SMALL_STATE(8328)] = 393321,
  [SMALL_STATE(8329)] = 393374,
  [SMALL_STATE(8330)] = 393433,
  [SMALL_STATE(8331)] = 393500,
  [SMALL_STATE(8332)] = 393571,
  [SMALL_STATE(8333)] = 393662,
  [SMALL_STATE(8334)] = 393735,
  [SMALL_STATE(8335)] = 393786,
  [SMALL_STATE(8336)] = 393847,
  [SMALL_STATE(8337)] = 393908,
  [SMALL_STATE(8338)] = 393959,
  [SMALL_STATE(8339)] = 394024,
  [SMALL_STATE(8340)] = 394077,
  [SMALL_STATE(8341)] = 394144,
  [SMALL_STATE(8342)] = 394197,
  [SMALL_STATE(8343)] = 394250,
  [SMALL_STATE(8344)] = 394301,
  [SMALL_STATE(8345)] = 394354,
  [SMALL_STATE(8346)] = 394405,
  [SMALL_STATE(8347)] = 394476,
  [SMALL_STATE(8348)] = 394529,
  [SMALL_STATE(8349)] = 394578,
  [SMALL_STATE(8350)] = 394649,
  [SMALL_STATE(8351)] = 394702,
  [SMALL_STATE(8352)] = 394755,
  [SMALL_STATE(8353)] = 394808,
  [SMALL_STATE(8354)] = 394861,
  [SMALL_STATE(8355)] = 394952,
  [SMALL_STATE(8356)] = 395005,
  [SMALL_STATE(8357)] = 395076,
  [SMALL_STATE(8358)] = 395127,
  [SMALL_STATE(8359)] = 395182,
  [SMALL_STATE(8360)] = 395235,
  [SMALL_STATE(8361)] = 395306,
  [SMALL_STATE(8362)] = 395361,
  [SMALL_STATE(8363)] = 395414,
  [SMALL_STATE(8364)] = 395467,
  [SMALL_STATE(8365)] = 395534,
  [SMALL_STATE(8366)] = 395605,
  [SMALL_STATE(8367)] = 395670,
  [SMALL_STATE(8368)] = 395723,
  [SMALL_STATE(8369)] = 395794,
  [SMALL_STATE(8370)] = 395847,
  [SMALL_STATE(8371)] = 395908,
  [SMALL_STATE(8372)] = 395969,
  [SMALL_STATE(8373)] = 396022,
  [SMALL_STATE(8374)] = 396081,
  [SMALL_STATE(8375)] = 396134,
  [SMALL_STATE(8376)] = 396201,
  [SMALL_STATE(8377)] = 396254,
  [SMALL_STATE(8378)] = 396345,
  [SMALL_STATE(8379)] = 396396,
  [SMALL_STATE(8380)] = 396480,
  [SMALL_STATE(8381)] = 396532,
  [SMALL_STATE(8382)] = 396582,
  [SMALL_STATE(8383)] = 396666,
  [SMALL_STATE(8384)] = 396738,
  [SMALL_STATE(8385)] = 396786,
  [SMALL_STATE(8386)] = 396868,
  [SMALL_STATE(8387)] = 396952,
  [SMALL_STATE(8388)] = 397024,
  [SMALL_STATE(8389)] = 397074,
  [SMALL_STATE(8390)] = 397146,
  [SMALL_STATE(8391)] = 397194,
  [SMALL_STATE(8392)] = 397246,
  [SMALL_STATE(8393)] = 397316,
  [SMALL_STATE(8394)] = 397368,
  [SMALL_STATE(8395)] = 397438,
  [SMALL_STATE(8396)] = 397492,
  [SMALL_STATE(8397)] = 397562,
  [SMALL_STATE(8398)] = 397628,
  [SMALL_STATE(8399)] = 397692,
  [SMALL_STATE(8400)] = 397752,
  [SMALL_STATE(8401)] = 397812,
  [SMALL_STATE(8402)] = 397864,
  [SMALL_STATE(8403)] = 397916,
  [SMALL_STATE(8404)] = 397974,
  [SMALL_STATE(8405)] = 398040,
  [SMALL_STATE(8406)] = 398124,
  [SMALL_STATE(8407)] = 398174,
  [SMALL_STATE(8408)] = 398222,
  [SMALL_STATE(8409)] = 398306,
  [SMALL_STATE(8410)] = 398390,
  [SMALL_STATE(8411)] = 398462,
  [SMALL_STATE(8412)] = 398510,
  [SMALL_STATE(8413)] = 398558,
  [SMALL_STATE(8414)] = 398610,
  [SMALL_STATE(8415)] = 398658,
  [SMALL_STATE(8416)] = 398710,
  [SMALL_STATE(8417)] = 398780,
  [SMALL_STATE(8418)] = 398828,
  [SMALL_STATE(8419)] = 398880,
  [SMALL_STATE(8420)] = 398930,
  [SMALL_STATE(8421)] = 398980,
  [SMALL_STATE(8422)] = 399064,
  [SMALL_STATE(8423)] = 399116,
  [SMALL_STATE(8424)] = 399166,
  [SMALL_STATE(8425)] = 399218,
  [SMALL_STATE(8426)] = 399268,
  [SMALL_STATE(8427)] = 399338,
  [SMALL_STATE(8428)] = 399420,
  [SMALL_STATE(8429)] = 399486,
  [SMALL_STATE(8430)] = 399544,
  [SMALL_STATE(8431)] = 399596,
  [SMALL_STATE(8432)] = 399648,
  [SMALL_STATE(8433)] = 399708,
  [SMALL_STATE(8434)] = 399768,
  [SMALL_STATE(8435)] = 399832,
  [SMALL_STATE(8436)] = 399898,
  [SMALL_STATE(8437)] = 399968,
  [SMALL_STATE(8438)] = 400022,
  [SMALL_STATE(8439)] = 400106,
  [SMALL_STATE(8440)] = 400156,
  [SMALL_STATE(8441)] = 400203,
  [SMALL_STATE(8442)] = 400288,
  [SMALL_STATE(8443)] = 400335,
  [SMALL_STATE(8444)] = 400420,
  [SMALL_STATE(8445)] = 400467,
  [SMALL_STATE(8446)] = 400514,
  [SMALL_STATE(8447)] = 400599,
  [SMALL_STATE(8448)] = 400684,
  [SMALL_STATE(8449)] = 400733,
  [SMALL_STATE(8450)] = 400780,
  [SMALL_STATE(8451)] = 400865,
  [SMALL_STATE(8452)] = 400950,
  [SMALL_STATE(8453)] = 401021,
  [SMALL_STATE(8454)] = 401106,
  [SMALL_STATE(8455)] = 401191,
  [SMALL_STATE(8456)] = 401238,
  [SMALL_STATE(8457)] = 401323,
  [SMALL_STATE(8458)] = 401408,
  [SMALL_STATE(8459)] = 401493,
  [SMALL_STATE(8460)] = 401578,
  [SMALL_STATE(8461)] = 401663,
  [SMALL_STATE(8462)] = 401714,
  [SMALL_STATE(8463)] = 401783,
  [SMALL_STATE(8464)] = 401868,
  [SMALL_STATE(8465)] = 401953,
  [SMALL_STATE(8466)] = 402002,
  [SMALL_STATE(8467)] = 402087,
  [SMALL_STATE(8468)] = 402172,
  [SMALL_STATE(8469)] = 402243,
  [SMALL_STATE(8470)] = 402328,
  [SMALL_STATE(8471)] = 402413,
  [SMALL_STATE(8472)] = 402498,
  [SMALL_STATE(8473)] = 402549,
  [SMALL_STATE(8474)] = 402600,
  [SMALL_STATE(8475)] = 402665,
  [SMALL_STATE(8476)] = 402714,
  [SMALL_STATE(8477)] = 402771,
  [SMALL_STATE(8478)] = 402822,
  [SMALL_STATE(8479)] = 402871,
  [SMALL_STATE(8480)] = 402956,
  [SMALL_STATE(8481)] = 403041,
  [SMALL_STATE(8482)] = 403092,
  [SMALL_STATE(8483)] = 403143,
  [SMALL_STATE(8484)] = 403194,
  [SMALL_STATE(8485)] = 403279,
  [SMALL_STATE(8486)] = 403330,
  [SMALL_STATE(8487)] = 403415,
  [SMALL_STATE(8488)] = 403500,
  [SMALL_STATE(8489)] = 403551,
  [SMALL_STATE(8490)] = 403602,
  [SMALL_STATE(8491)] = 403687,
  [SMALL_STATE(8492)] = 403772,
  [SMALL_STATE(8493)] = 403857,
  [SMALL_STATE(8494)] = 403942,
  [SMALL_STATE(8495)] = 404027,
  [SMALL_STATE(8496)] = 404112,
  [SMALL_STATE(8497)] = 404197,
  [SMALL_STATE(8498)] = 404282,
  [SMALL_STATE(8499)] = 404333,
  [SMALL_STATE(8500)] = 404392,
  [SMALL_STATE(8501)] = 404451,
  [SMALL_STATE(8502)] = 404514,
  [SMALL_STATE(8503)] = 404579,
  [SMALL_STATE(8504)] = 404648,
  [SMALL_STATE(8505)] = 404695,
  [SMALL_STATE(8506)] = 404766,
  [SMALL_STATE(8507)] = 404835,
  [SMALL_STATE(8508)] = 404920,
  [SMALL_STATE(8509)] = 405005,
  [SMALL_STATE(8510)] = 405056,
  [SMALL_STATE(8511)] = 405109,
  [SMALL_STATE(8512)] = 405178,
  [SMALL_STATE(8513)] = 405263,
  [SMALL_STATE(8514)] = 405312,
  [SMALL_STATE(8515)] = 405397,
  [SMALL_STATE(8516)] = 405482,
  [SMALL_STATE(8517)] = 405567,
  [SMALL_STATE(8518)] = 405652,
  [SMALL_STATE(8519)] = 405721,
  [SMALL_STATE(8520)] = 405790,
  [SMALL_STATE(8521)] = 405841,
  [SMALL_STATE(8522)] = 405888,
  [SMALL_STATE(8523)] = 405939,
  [SMALL_STATE(8524)] = 406024,
  [SMALL_STATE(8525)] = 406075,
  [SMALL_STATE(8526)] = 406126,
  [SMALL_STATE(8527)] = 406175,
  [SMALL_STATE(8528)] = 406260,
  [SMALL_STATE(8529)] = 406309,
  [SMALL_STATE(8530)] = 406394,
  [SMALL_STATE(8531)] = 406443,
  [SMALL_STATE(8532)] = 406528,
  [SMALL_STATE(8533)] = 406613,
  [SMALL_STATE(8534)] = 406678,
  [SMALL_STATE(8535)] = 406749,
  [SMALL_STATE(8536)] = 406834,
  [SMALL_STATE(8537)] = 406883,
  [SMALL_STATE(8538)] = 406968,
  [SMALL_STATE(8539)] = 407025,
  [SMALL_STATE(8540)] = 407110,
  [SMALL_STATE(8541)] = 407161,
  [SMALL_STATE(8542)] = 407246,
  [SMALL_STATE(8543)] = 407297,
  [SMALL_STATE(8544)] = 407382,
  [SMALL_STATE(8545)] = 407441,
  [SMALL_STATE(8546)] = 407500,
  [SMALL_STATE(8547)] = 407563,
  [SMALL_STATE(8548)] = 407648,
  [SMALL_STATE(8549)] = 407713,
  [SMALL_STATE(8550)] = 407798,
  [SMALL_STATE(8551)] = 407867,
  [SMALL_STATE(8552)] = 407918,
  [SMALL_STATE(8553)] = 407971,
  [SMALL_STATE(8554)] = 408056,
  [SMALL_STATE(8555)] = 408125,
  [SMALL_STATE(8556)] = 408210,
  [SMALL_STATE(8557)] = 408295,
  [SMALL_STATE(8558)] = 408346,
  [SMALL_STATE(8559)] = 408428,
  [SMALL_STATE(8560)] = 408510,
  [SMALL_STATE(8561)] = 408556,
  [SMALL_STATE(8562)] = 408602,
  [SMALL_STATE(8563)] = 408684,
  [SMALL_STATE(8564)] = 408766,
  [SMALL_STATE(8565)] = 408812,
  [SMALL_STATE(8566)] = 408858,
  [SMALL_STATE(8567)] = 408904,
  [SMALL_STATE(8568)] = 408950,
  [SMALL_STATE(8569)] = 408996,
  [SMALL_STATE(8570)] = 409042,
  [SMALL_STATE(8571)] = 409104,
  [SMALL_STATE(8572)] = 409150,
  [SMALL_STATE(8573)] = 409232,
  [SMALL_STATE(8574)] = 409314,
  [SMALL_STATE(8575)] = 409384,
  [SMALL_STATE(8576)] = 409466,
  [SMALL_STATE(8577)] = 409548,
  [SMALL_STATE(8578)] = 409630,
  [SMALL_STATE(8579)] = 409712,
  [SMALL_STATE(8580)] = 409758,
  [SMALL_STATE(8581)] = 409840,
  [SMALL_STATE(8582)] = 409886,
  [SMALL_STATE(8583)] = 409932,
  [SMALL_STATE(8584)] = 410014,
  [SMALL_STATE(8585)] = 410096,
  [SMALL_STATE(8586)] = 410178,
  [SMALL_STATE(8587)] = 410260,
  [SMALL_STATE(8588)] = 410342,
  [SMALL_STATE(8589)] = 410424,
  [SMALL_STATE(8590)] = 410506,
  [SMALL_STATE(8591)] = 410588,
  [SMALL_STATE(8592)] = 410638,
  [SMALL_STATE(8593)] = 410684,
  [SMALL_STATE(8594)] = 410766,
  [SMALL_STATE(8595)] = 410848,
  [SMALL_STATE(8596)] = 410894,
  [SMALL_STATE(8597)] = 410976,
  [SMALL_STATE(8598)] = 411058,
  [SMALL_STATE(8599)] = 411140,
  [SMALL_STATE(8600)] = 411222,
  [SMALL_STATE(8601)] = 411304,
  [SMALL_STATE(8602)] = 411350,
  [SMALL_STATE(8603)] = 411432,
  [SMALL_STATE(8604)] = 411514,
  [SMALL_STATE(8605)] = 411596,
  [SMALL_STATE(8606)] = 411642,
  [SMALL_STATE(8607)] = 411688,
  [SMALL_STATE(8608)] = 411770,
  [SMALL_STATE(8609)] = 411852,
  [SMALL_STATE(8610)] = 411934,
  [SMALL_STATE(8611)] = 411982,
  [SMALL_STATE(8612)] = 412028,
  [SMALL_STATE(8613)] = 412110,
  [SMALL_STATE(8614)] = 412156,
  [SMALL_STATE(8615)] = 412238,
  [SMALL_STATE(8616)] = 412320,
  [SMALL_STATE(8617)] = 412402,
  [SMALL_STATE(8618)] = 412484,
  [SMALL_STATE(8619)] = 412534,
  [SMALL_STATE(8620)] = 412580,
  [SMALL_STATE(8621)] = 412662,
  [SMALL_STATE(8622)] = 412744,
  [SMALL_STATE(8623)] = 412790,
  [SMALL_STATE(8624)] = 412872,
  [SMALL_STATE(8625)] = 412954,
  [SMALL_STATE(8626)] = 413036,
  [SMALL_STATE(8627)] = 413118,
  [SMALL_STATE(8628)] = 413200,
  [SMALL_STATE(8629)] = 413282,
  [SMALL_STATE(8630)] = 413364,
  [SMALL_STATE(8631)] = 413446,
  [SMALL_STATE(8632)] = 413528,
  [SMALL_STATE(8633)] = 413574,
  [SMALL_STATE(8634)] = 413622,
  [SMALL_STATE(8635)] = 413704,
  [SMALL_STATE(8636)] = 413786,
  [SMALL_STATE(8637)] = 413854,
  [SMALL_STATE(8638)] = 413900,
  [SMALL_STATE(8639)] = 413982,
  [SMALL_STATE(8640)] = 414028,
  [SMALL_STATE(8641)] = 414096,
  [SMALL_STATE(8642)] = 414142,
  [SMALL_STATE(8643)] = 414224,
  [SMALL_STATE(8644)] = 414306,
  [SMALL_STATE(8645)] = 414352,
  [SMALL_STATE(8646)] = 414398,
  [SMALL_STATE(8647)] = 414480,
  [SMALL_STATE(8648)] = 414526,
  [SMALL_STATE(8649)] = 414608,
  [SMALL_STATE(8650)] = 414654,
  [SMALL_STATE(8651)] = 414736,
  [SMALL_STATE(8652)] = 414818,
  [SMALL_STATE(8653)] = 414900,
  [SMALL_STATE(8654)] = 414946,
  [SMALL_STATE(8655)] = 415028,
  [SMALL_STATE(8656)] = 415110,
  [SMALL_STATE(8657)] = 415192,
  [SMALL_STATE(8658)] = 415274,
  [SMALL_STATE(8659)] = 415320,
  [SMALL_STATE(8660)] = 415402,
  [SMALL_STATE(8661)] = 415484,
  [SMALL_STATE(8662)] = 415566,
  [SMALL_STATE(8663)] = 415648,
  [SMALL_STATE(8664)] = 415730,
  [SMALL_STATE(8665)] = 415776,
  [SMALL_STATE(8666)] = 415858,
  [SMALL_STATE(8667)] = 415940,
  [SMALL_STATE(8668)] = 415986,
  [SMALL_STATE(8669)] = 416068,
  [SMALL_STATE(8670)] = 416150,
  [SMALL_STATE(8671)] = 416232,
  [SMALL_STATE(8672)] = 416314,
  [SMALL_STATE(8673)] = 416396,
  [SMALL_STATE(8674)] = 416478,
  [SMALL_STATE(8675)] = 416528,
  [SMALL_STATE(8676)] = 416610,
  [SMALL_STATE(8677)] = 416692,
  [SMALL_STATE(8678)] = 416774,
  [SMALL_STATE(8679)] = 416822,
  [SMALL_STATE(8680)] = 416872,
  [SMALL_STATE(8681)] = 416920,
  [SMALL_STATE(8682)] = 417002,
  [SMALL_STATE(8683)] = 417052,
  [SMALL_STATE(8684)] = 417134,
  [SMALL_STATE(8685)] = 417216,
  [SMALL_STATE(8686)] = 417298,
  [SMALL_STATE(8687)] = 417380,
  [SMALL_STATE(8688)] = 417462,
  [SMALL_STATE(8689)] = 417544,
  [SMALL_STATE(8690)] = 417626,
  [SMALL_STATE(8691)] = 417708,
  [SMALL_STATE(8692)] = 417790,
  [SMALL_STATE(8693)] = 417872,
  [SMALL_STATE(8694)] = 417918,
  [SMALL_STATE(8695)] = 418000,
  [SMALL_STATE(8696)] = 418082,
  [SMALL_STATE(8697)] = 418164,
  [SMALL_STATE(8698)] = 418246,
  [SMALL_STATE(8699)] = 418328,
  [SMALL_STATE(8700)] = 418374,
  [SMALL_STATE(8701)] = 418456,
  [SMALL_STATE(8702)] = 418502,
  [SMALL_STATE(8703)] = 418548,
  [SMALL_STATE(8704)] = 418630,
  [SMALL_STATE(8705)] = 418712,
  [SMALL_STATE(8706)] = 418794,
  [SMALL_STATE(8707)] = 418876,
  [SMALL_STATE(8708)] = 418922,
  [SMALL_STATE(8709)] = 418970,
  [SMALL_STATE(8710)] = 419052,
  [SMALL_STATE(8711)] = 419134,
  [SMALL_STATE(8712)] = 419182,
  [SMALL_STATE(8713)] = 419252,
  [SMALL_STATE(8714)] = 419314,
  [SMALL_STATE(8715)] = 419364,
  [SMALL_STATE(8716)] = 419410,
  [SMALL_STATE(8717)] = 419492,
  [SMALL_STATE(8718)] = 419574,
  [SMALL_STATE(8719)] = 419620,
  [SMALL_STATE(8720)] = 419702,
  [SMALL_STATE(8721)] = 419764,
  [SMALL_STATE(8722)] = 419810,
  [SMALL_STATE(8723)] = 419892,
  [SMALL_STATE(8724)] = 419974,
  [SMALL_STATE(8725)] = 420056,
  [SMALL_STATE(8726)] = 420138,
  [SMALL_STATE(8727)] = 420184,
  [SMALL_STATE(8728)] = 420230,
  [SMALL_STATE(8729)] = 420312,
  [SMALL_STATE(8730)] = 420394,
  [SMALL_STATE(8731)] = 420476,
  [SMALL_STATE(8732)] = 420558,
  [SMALL_STATE(8733)] = 420640,
  [SMALL_STATE(8734)] = 420722,
  [SMALL_STATE(8735)] = 420804,
  [SMALL_STATE(8736)] = 420886,
  [SMALL_STATE(8737)] = 420968,
  [SMALL_STATE(8738)] = 421050,
  [SMALL_STATE(8739)] = 421132,
  [SMALL_STATE(8740)] = 421214,
  [SMALL_STATE(8741)] = 421296,
  [SMALL_STATE(8742)] = 421378,
  [SMALL_STATE(8743)] = 421460,
  [SMALL_STATE(8744)] = 421542,
  [SMALL_STATE(8745)] = 421624,
  [SMALL_STATE(8746)] = 421706,
  [SMALL_STATE(8747)] = 421788,
  [SMALL_STATE(8748)] = 421870,
  [SMALL_STATE(8749)] = 421916,
  [SMALL_STATE(8750)] = 421998,
  [SMALL_STATE(8751)] = 422080,
  [SMALL_STATE(8752)] = 422162,
  [SMALL_STATE(8753)] = 422244,
  [SMALL_STATE(8754)] = 422326,
  [SMALL_STATE(8755)] = 422408,
  [SMALL_STATE(8756)] = 422490,
  [SMALL_STATE(8757)] = 422536,
  [SMALL_STATE(8758)] = 422582,
  [SMALL_STATE(8759)] = 422628,
  [SMALL_STATE(8760)] = 422674,
  [SMALL_STATE(8761)] = 422720,
  [SMALL_STATE(8762)] = 422802,
  [SMALL_STATE(8763)] = 422848,
  [SMALL_STATE(8764)] = 422930,
  [SMALL_STATE(8765)] = 422976,
  [SMALL_STATE(8766)] = 423058,
  [SMALL_STATE(8767)] = 423104,
  [SMALL_STATE(8768)] = 423186,
  [SMALL_STATE(8769)] = 423268,
  [SMALL_STATE(8770)] = 423314,
  [SMALL_STATE(8771)] = 423360,
  [SMALL_STATE(8772)] = 423408,
  [SMALL_STATE(8773)] = 423490,
  [SMALL_STATE(8774)] = 423572,
  [SMALL_STATE(8775)] = 423654,
  [SMALL_STATE(8776)] = 423736,
  [SMALL_STATE(8777)] = 423818,
  [SMALL_STATE(8778)] = 423864,
  [SMALL_STATE(8779)] = 423912,
  [SMALL_STATE(8780)] = 423958,
  [SMALL_STATE(8781)] = 424040,
  [SMALL_STATE(8782)] = 424122,
  [SMALL_STATE(8783)] = 424168,
  [SMALL_STATE(8784)] = 424250,
  [SMALL_STATE(8785)] = 424332,
  [SMALL_STATE(8786)] = 424414,
  [SMALL_STATE(8787)] = 424496,
  [SMALL_STATE(8788)] = 424542,
  [SMALL_STATE(8789)] = 424624,
  [SMALL_STATE(8790)] = 424706,
  [SMALL_STATE(8791)] = 424752,
  [SMALL_STATE(8792)] = 424834,
  [SMALL_STATE(8793)] = 424916,
  [SMALL_STATE(8794)] = 424962,
  [SMALL_STATE(8795)] = 425024,
  [SMALL_STATE(8796)] = 425106,
  [SMALL_STATE(8797)] = 425188,
  [SMALL_STATE(8798)] = 425270,
  [SMALL_STATE(8799)] = 425352,
  [SMALL_STATE(8800)] = 425398,
  [SMALL_STATE(8801)] = 425480,
  [SMALL_STATE(8802)] = 425562,
  [SMALL_STATE(8803)] = 425644,
  [SMALL_STATE(8804)] = 425726,
  [SMALL_STATE(8805)] = 425808,
  [SMALL_STATE(8806)] = 425854,
  [SMALL_STATE(8807)] = 425900,
  [SMALL_STATE(8808)] = 425968,
  [SMALL_STATE(8809)] = 426050,
  [SMALL_STATE(8810)] = 426132,
  [SMALL_STATE(8811)] = 426184,
  [SMALL_STATE(8812)] = 426230,
  [SMALL_STATE(8813)] = 426298,
  [SMALL_STATE(8814)] = 426344,
  [SMALL_STATE(8815)] = 426390,
  [SMALL_STATE(8816)] = 426436,
  [SMALL_STATE(8817)] = 426518,
  [SMALL_STATE(8818)] = 426564,
  [SMALL_STATE(8819)] = 426646,
  [SMALL_STATE(8820)] = 426692,
  [SMALL_STATE(8821)] = 426738,
  [SMALL_STATE(8822)] = 426820,
  [SMALL_STATE(8823)] = 426902,
  [SMALL_STATE(8824)] = 426948,
  [SMALL_STATE(8825)] = 427030,
  [SMALL_STATE(8826)] = 427112,
  [SMALL_STATE(8827)] = 427176,
  [SMALL_STATE(8828)] = 427258,
  [SMALL_STATE(8829)] = 427340,
  [SMALL_STATE(8830)] = 427408,
  [SMALL_STATE(8831)] = 427460,
  [SMALL_STATE(8832)] = 427528,
  [SMALL_STATE(8833)] = 427592,
  [SMALL_STATE(8834)] = 427650,
  [SMALL_STATE(8835)] = 427712,
  [SMALL_STATE(8836)] = 427794,
  [SMALL_STATE(8837)] = 427852,
  [SMALL_STATE(8838)] = 427910,
  [SMALL_STATE(8839)] = 427956,
  [SMALL_STATE(8840)] = 428002,
  [SMALL_STATE(8841)] = 428048,
  [SMALL_STATE(8842)] = 428094,
  [SMALL_STATE(8843)] = 428152,
  [SMALL_STATE(8844)] = 428202,
  [SMALL_STATE(8845)] = 428252,
  [SMALL_STATE(8846)] = 428302,
  [SMALL_STATE(8847)] = 428358,
  [SMALL_STATE(8848)] = 428408,
  [SMALL_STATE(8849)] = 428490,
  [SMALL_STATE(8850)] = 428546,
  [SMALL_STATE(8851)] = 428628,
  [SMALL_STATE(8852)] = 428674,
  [SMALL_STATE(8853)] = 428738,
  [SMALL_STATE(8854)] = 428802,
  [SMALL_STATE(8855)] = 428884,
  [SMALL_STATE(8856)] = 428966,
  [SMALL_STATE(8857)] = 429012,
  [SMALL_STATE(8858)] = 429094,
  [SMALL_STATE(8859)] = 429176,
  [SMALL_STATE(8860)] = 429258,
  [SMALL_STATE(8861)] = 429340,
  [SMALL_STATE(8862)] = 429390,
  [SMALL_STATE(8863)] = 429440,
  [SMALL_STATE(8864)] = 429522,
  [SMALL_STATE(8865)] = 429604,
  [SMALL_STATE(8866)] = 429686,
  [SMALL_STATE(8867)] = 429732,
  [SMALL_STATE(8868)] = 429778,
  [SMALL_STATE(8869)] = 429824,
  [SMALL_STATE(8870)] = 429906,
  [SMALL_STATE(8871)] = 429952,
  [SMALL_STATE(8872)] = 429998,
  [SMALL_STATE(8873)] = 430043,
  [SMALL_STATE(8874)] = 430088,
  [SMALL_STATE(8875)] = 430133,
  [SMALL_STATE(8876)] = 430184,
  [SMALL_STATE(8877)] = 430235,
  [SMALL_STATE(8878)] = 430304,
  [SMALL_STATE(8879)] = 430349,
  [SMALL_STATE(8880)] = 430418,
  [SMALL_STATE(8881)] = 430463,
  [SMALL_STATE(8882)] = 430508,
  [SMALL_STATE(8883)] = 430553,
  [SMALL_STATE(8884)] = 430630,
  [SMALL_STATE(8885)] = 430675,
  [SMALL_STATE(8886)] = 430720,
  [SMALL_STATE(8887)] = 430765,
  [SMALL_STATE(8888)] = 430810,
  [SMALL_STATE(8889)] = 430855,
  [SMALL_STATE(8890)] = 430900,
  [SMALL_STATE(8891)] = 430945,
  [SMALL_STATE(8892)] = 430990,
  [SMALL_STATE(8893)] = 431035,
  [SMALL_STATE(8894)] = 431096,
  [SMALL_STATE(8895)] = 431141,
  [SMALL_STATE(8896)] = 431186,
  [SMALL_STATE(8897)] = 431231,
  [SMALL_STATE(8898)] = 431276,
  [SMALL_STATE(8899)] = 431321,
  [SMALL_STATE(8900)] = 431366,
  [SMALL_STATE(8901)] = 431443,
  [SMALL_STATE(8902)] = 431488,
  [SMALL_STATE(8903)] = 431539,
  [SMALL_STATE(8904)] = 431590,
  [SMALL_STATE(8905)] = 431635,
  [SMALL_STATE(8906)] = 431680,
  [SMALL_STATE(8907)] = 431725,
  [SMALL_STATE(8908)] = 431770,
  [SMALL_STATE(8909)] = 431815,
  [SMALL_STATE(8910)] = 431860,
  [SMALL_STATE(8911)] = 431905,
  [SMALL_STATE(8912)] = 431950,
  [SMALL_STATE(8913)] = 431995,
  [SMALL_STATE(8914)] = 432040,
  [SMALL_STATE(8915)] = 432085,
  [SMALL_STATE(8916)] = 432130,
  [SMALL_STATE(8917)] = 432175,
  [SMALL_STATE(8918)] = 432222,
  [SMALL_STATE(8919)] = 432267,
  [SMALL_STATE(8920)] = 432328,
  [SMALL_STATE(8921)] = 432373,
  [SMALL_STATE(8922)] = 432418,
  [SMALL_STATE(8923)] = 432463,
  [SMALL_STATE(8924)] = 432508,
  [SMALL_STATE(8925)] = 432553,
  [SMALL_STATE(8926)] = 432598,
  [SMALL_STATE(8927)] = 432643,
  [SMALL_STATE(8928)] = 432688,
  [SMALL_STATE(8929)] = 432733,
  [SMALL_STATE(8930)] = 432782,
  [SMALL_STATE(8931)] = 432827,
  [SMALL_STATE(8932)] = 432872,
  [SMALL_STATE(8933)] = 432917,
  [SMALL_STATE(8934)] = 432978,
  [SMALL_STATE(8935)] = 433023,
  [SMALL_STATE(8936)] = 433070,
  [SMALL_STATE(8937)] = 433115,
  [SMALL_STATE(8938)] = 433160,
  [SMALL_STATE(8939)] = 433205,
  [SMALL_STATE(8940)] = 433250,
  [SMALL_STATE(8941)] = 433295,
  [SMALL_STATE(8942)] = 433340,
  [SMALL_STATE(8943)] = 433385,
  [SMALL_STATE(8944)] = 433430,
  [SMALL_STATE(8945)] = 433475,
  [SMALL_STATE(8946)] = 433520,
  [SMALL_STATE(8947)] = 433574,
  [SMALL_STATE(8948)] = 433628,
  [SMALL_STATE(8949)] = 433682,
  [SMALL_STATE(8950)] = 433754,
  [SMALL_STATE(8951)] = 433826,
  [SMALL_STATE(8952)] = 433900,
  [SMALL_STATE(8953)] = 433944,
  [SMALL_STATE(8954)] = 434018,
  [SMALL_STATE(8955)] = 434072,
  [SMALL_STATE(8956)] = 434144,
  [SMALL_STATE(8957)] = 434198,
  [SMALL_STATE(8958)] = 434272,
  [SMALL_STATE(8959)] = 434326,
  [SMALL_STATE(8960)] = 434403,
  [SMALL_STATE(8961)] = 434480,
  [SMALL_STATE(8962)] = 434551,
  [SMALL_STATE(8963)] = 434628,
  [SMALL_STATE(8964)] = 434705,
  [SMALL_STATE(8965)] = 434782,
  [SMALL_STATE(8966)] = 434841,
  [SMALL_STATE(8967)] = 434918,
  [SMALL_STATE(8968)] = 434971,
  [SMALL_STATE(8969)] = 435048,
  [SMALL_STATE(8970)] = 435093,
  [SMALL_STATE(8971)] = 435138,
  [SMALL_STATE(8972)] = 435197,
  [SMALL_STATE(8973)] = 435244,
  [SMALL_STATE(8974)] = 435321,
  [SMALL_STATE(8975)] = 435398,
  [SMALL_STATE(8976)] = 435475,
  [SMALL_STATE(8977)] = 435546,
  [SMALL_STATE(8978)] = 435623,
  [SMALL_STATE(8979)] = 435694,
  [SMALL_STATE(8980)] = 435771,
  [SMALL_STATE(8981)] = 435848,
  [SMALL_STATE(8982)] = 435925,
  [SMALL_STATE(8983)] = 435970,
  [SMALL_STATE(8984)] = 436047,
  [SMALL_STATE(8985)] = 436090,
  [SMALL_STATE(8986)] = 436167,
  [SMALL_STATE(8987)] = 436244,
  [SMALL_STATE(8988)] = 436321,
  [SMALL_STATE(8989)] = 436374,
  [SMALL_STATE(8990)] = 436445,
  [SMALL_STATE(8991)] = 436498,
  [SMALL_STATE(8992)] = 436575,
  [SMALL_STATE(8993)] = 436628,
  [SMALL_STATE(8994)] = 436699,
  [SMALL_STATE(8995)] = 436776,
  [SMALL_STATE(8996)] = 436853,
  [SMALL_STATE(8997)] = 436930,
  [SMALL_STATE(8998)] = 437007,
  [SMALL_STATE(8999)] = 437084,
  [SMALL_STATE(9000)] = 437161,
  [SMALL_STATE(9001)] = 437238,
  [SMALL_STATE(9002)] = 437315,
  [SMALL_STATE(9003)] = 437392,
  [SMALL_STATE(9004)] = 437463,
  [SMALL_STATE(9005)] = 437506,
  [SMALL_STATE(9006)] = 437583,
  [SMALL_STATE(9007)] = 437660,
  [SMALL_STATE(9008)] = 437705,
  [SMALL_STATE(9009)] = 437782,
  [SMALL_STATE(9010)] = 437859,
  [SMALL_STATE(9011)] = 437936,
  [SMALL_STATE(9012)] = 437979,
  [SMALL_STATE(9013)] = 438022,
  [SMALL_STATE(9014)] = 438065,
  [SMALL_STATE(9015)] = 438118,
  [SMALL_STATE(9016)] = 438195,
  [SMALL_STATE(9017)] = 438272,
  [SMALL_STATE(9018)] = 438349,
  [SMALL_STATE(9019)] = 438426,
  [SMALL_STATE(9020)] = 438503,
  [SMALL_STATE(9021)] = 438580,
  [SMALL_STATE(9022)] = 438652,
  [SMALL_STATE(9023)] = 438724,
  [SMALL_STATE(9024)] = 438796,
  [SMALL_STATE(9025)] = 438868,
  [SMALL_STATE(9026)] = 438920,
  [SMALL_STATE(9027)] = 438992,
  [SMALL_STATE(9028)] = 439064,
  [SMALL_STATE(9029)] = 439136,
  [SMALL_STATE(9030)] = 439208,
  [SMALL_STATE(9031)] = 439280,
  [SMALL_STATE(9032)] = 439352,
  [SMALL_STATE(9033)] = 439394,
  [SMALL_STATE(9034)] = 439436,
  [SMALL_STATE(9035)] = 439478,
  [SMALL_STATE(9036)] = 439520,
  [SMALL_STATE(9037)] = 439592,
  [SMALL_STATE(9038)] = 439664,
  [SMALL_STATE(9039)] = 439706,
  [SMALL_STATE(9040)] = 439748,
  [SMALL_STATE(9041)] = 439790,
  [SMALL_STATE(9042)] = 439862,
  [SMALL_STATE(9043)] = 439934,
  [SMALL_STATE(9044)] = 439976,
  [SMALL_STATE(9045)] = 440048,
  [SMALL_STATE(9046)] = 440090,
  [SMALL_STATE(9047)] = 440132,
  [SMALL_STATE(9048)] = 440174,
  [SMALL_STATE(9049)] = 440218,
  [SMALL_STATE(9050)] = 440260,
  [SMALL_STATE(9051)] = 440302,
  [SMALL_STATE(9052)] = 440374,
  [SMALL_STATE(9053)] = 440432,
  [SMALL_STATE(9054)] = 440474,
  [SMALL_STATE(9055)] = 440532,
  [SMALL_STATE(9056)] = 440604,
  [SMALL_STATE(9057)] = 440676,
  [SMALL_STATE(9058)] = 440718,
  [SMALL_STATE(9059)] = 440760,
  [SMALL_STATE(9060)] = 440802,
  [SMALL_STATE(9061)] = 440844,
  [SMALL_STATE(9062)] = 440916,
  [SMALL_STATE(9063)] = 440958,
  [SMALL_STATE(9064)] = 441030,
  [SMALL_STATE(9065)] = 441102,
  [SMALL_STATE(9066)] = 441174,
  [SMALL_STATE(9067)] = 441216,
  [SMALL_STATE(9068)] = 441288,
  [SMALL_STATE(9069)] = 441330,
  [SMALL_STATE(9070)] = 441402,
  [SMALL_STATE(9071)] = 441444,
  [SMALL_STATE(9072)] = 441486,
  [SMALL_STATE(9073)] = 441528,
  [SMALL_STATE(9074)] = 441586,
  [SMALL_STATE(9075)] = 441628,
  [SMALL_STATE(9076)] = 441700,
  [SMALL_STATE(9077)] = 441772,
  [SMALL_STATE(9078)] = 441814,
  [SMALL_STATE(9079)] = 441856,
  [SMALL_STATE(9080)] = 441928,
  [SMALL_STATE(9081)] = 441970,
  [SMALL_STATE(9082)] = 442012,
  [SMALL_STATE(9083)] = 442054,
  [SMALL_STATE(9084)] = 442096,
  [SMALL_STATE(9085)] = 442138,
  [SMALL_STATE(9086)] = 442180,
  [SMALL_STATE(9087)] = 442228,
  [SMALL_STATE(9088)] = 442270,
  [SMALL_STATE(9089)] = 442342,
  [SMALL_STATE(9090)] = 442414,
  [SMALL_STATE(9091)] = 442486,
  [SMALL_STATE(9092)] = 442558,
  [SMALL_STATE(9093)] = 442630,
  [SMALL_STATE(9094)] = 442702,
  [SMALL_STATE(9095)] = 442774,
  [SMALL_STATE(9096)] = 442846,
  [SMALL_STATE(9097)] = 442918,
  [SMALL_STATE(9098)] = 442990,
  [SMALL_STATE(9099)] = 443062,
  [SMALL_STATE(9100)] = 443104,
  [SMALL_STATE(9101)] = 443146,
  [SMALL_STATE(9102)] = 443188,
  [SMALL_STATE(9103)] = 443260,
  [SMALL_STATE(9104)] = 443302,
  [SMALL_STATE(9105)] = 443374,
  [SMALL_STATE(9106)] = 443416,
  [SMALL_STATE(9107)] = 443458,
  [SMALL_STATE(9108)] = 443530,
  [SMALL_STATE(9109)] = 443572,
  [SMALL_STATE(9110)] = 443644,
  [SMALL_STATE(9111)] = 443716,
  [SMALL_STATE(9112)] = 443774,
  [SMALL_STATE(9113)] = 443846,
  [SMALL_STATE(9114)] = 443888,
  [SMALL_STATE(9115)] = 443930,
  [SMALL_STATE(9116)] = 443972,
  [SMALL_STATE(9117)] = 444044,
  [SMALL_STATE(9118)] = 444116,
  [SMALL_STATE(9119)] = 444188,
  [SMALL_STATE(9120)] = 444260,
  [SMALL_STATE(9121)] = 444318,
  [SMALL_STATE(9122)] = 444390,
  [SMALL_STATE(9123)] = 444442,
  [SMALL_STATE(9124)] = 444514,
  [SMALL_STATE(9125)] = 444586,
  [SMALL_STATE(9126)] = 444628,
  [SMALL_STATE(9127)] = 444700,
  [SMALL_STATE(9128)] = 444744,
  [SMALL_STATE(9129)] = 444816,
  [SMALL_STATE(9130)] = 444858,
  [SMALL_STATE(9131)] = 444900,
  [SMALL_STATE(9132)] = 444972,
  [SMALL_STATE(9133)] = 445014,
  [SMALL_STATE(9134)] = 445086,
  [SMALL_STATE(9135)] = 445128,
  [SMALL_STATE(9136)] = 445170,
  [SMALL_STATE(9137)] = 445242,
  [SMALL_STATE(9138)] = 445300,
  [SMALL_STATE(9139)] = 445372,
  [SMALL_STATE(9140)] = 445444,
  [SMALL_STATE(9141)] = 445502,
  [SMALL_STATE(9142)] = 445546,
  [SMALL_STATE(9143)] = 445588,
  [SMALL_STATE(9144)] = 445660,
  [SMALL_STATE(9145)] = 445702,
  [SMALL_STATE(9146)] = 445774,
  [SMALL_STATE(9147)] = 445816,
  [SMALL_STATE(9148)] = 445858,
  [SMALL_STATE(9149)] = 445900,
  [SMALL_STATE(9150)] = 445972,
  [SMALL_STATE(9151)] = 446044,
  [SMALL_STATE(9152)] = 446116,
  [SMALL_STATE(9153)] = 446158,
  [SMALL_STATE(9154)] = 446230,
  [SMALL_STATE(9155)] = 446302,
  [SMALL_STATE(9156)] = 446344,
  [SMALL_STATE(9157)] = 446386,
  [SMALL_STATE(9158)] = 446428,
  [SMALL_STATE(9159)] = 446500,
  [SMALL_STATE(9160)] = 446542,
  [SMALL_STATE(9161)] = 446584,
  [SMALL_STATE(9162)] = 446642,
  [SMALL_STATE(9163)] = 446714,
  [SMALL_STATE(9164)] = 446756,
  [SMALL_STATE(9165)] = 446798,
  [SMALL_STATE(9166)] = 446840,
  [SMALL_STATE(9167)] = 446912,
  [SMALL_STATE(9168)] = 446964,
  [SMALL_STATE(9169)] = 447036,
  [SMALL_STATE(9170)] = 447108,
  [SMALL_STATE(9171)] = 447150,
  [SMALL_STATE(9172)] = 447192,
  [SMALL_STATE(9173)] = 447240,
  [SMALL_STATE(9174)] = 447282,
  [SMALL_STATE(9175)] = 447324,
  [SMALL_STATE(9176)] = 447366,
  [SMALL_STATE(9177)] = 447408,
  [SMALL_STATE(9178)] = 447450,
  [SMALL_STATE(9179)] = 447492,
  [SMALL_STATE(9180)] = 447534,
  [SMALL_STATE(9181)] = 447582,
  [SMALL_STATE(9182)] = 447654,
  [SMALL_STATE(9183)] = 447702,
  [SMALL_STATE(9184)] = 447754,
  [SMALL_STATE(9185)] = 447796,
  [SMALL_STATE(9186)] = 447868,
  [SMALL_STATE(9187)] = 447940,
  [SMALL_STATE(9188)] = 447992,
  [SMALL_STATE(9189)] = 448034,
  [SMALL_STATE(9190)] = 448106,
  [SMALL_STATE(9191)] = 448178,
  [SMALL_STATE(9192)] = 448226,
  [SMALL_STATE(9193)] = 448298,
  [SMALL_STATE(9194)] = 448370,
  [SMALL_STATE(9195)] = 448442,
  [SMALL_STATE(9196)] = 448514,
  [SMALL_STATE(9197)] = 448556,
  [SMALL_STATE(9198)] = 448598,
  [SMALL_STATE(9199)] = 448670,
  [SMALL_STATE(9200)] = 448742,
  [SMALL_STATE(9201)] = 448784,
  [SMALL_STATE(9202)] = 448826,
  [SMALL_STATE(9203)] = 448868,
  [SMALL_STATE(9204)] = 448940,
  [SMALL_STATE(9205)] = 448982,
  [SMALL_STATE(9206)] = 449054,
  [SMALL_STATE(9207)] = 449126,
  [SMALL_STATE(9208)] = 449168,
  [SMALL_STATE(9209)] = 449226,
  [SMALL_STATE(9210)] = 449298,
  [SMALL_STATE(9211)] = 449340,
  [SMALL_STATE(9212)] = 449392,
  [SMALL_STATE(9213)] = 449434,
  [SMALL_STATE(9214)] = 449502,
  [SMALL_STATE(9215)] = 449544,
  [SMALL_STATE(9216)] = 449596,
  [SMALL_STATE(9217)] = 449668,
  [SMALL_STATE(9218)] = 449710,
  [SMALL_STATE(9219)] = 449782,
  [SMALL_STATE(9220)] = 449824,
  [SMALL_STATE(9221)] = 449896,
  [SMALL_STATE(9222)] = 449940,
  [SMALL_STATE(9223)] = 449982,
  [SMALL_STATE(9224)] = 450024,
  [SMALL_STATE(9225)] = 450066,
  [SMALL_STATE(9226)] = 450108,
  [SMALL_STATE(9227)] = 450150,
  [SMALL_STATE(9228)] = 450192,
  [SMALL_STATE(9229)] = 450240,
  [SMALL_STATE(9230)] = 450282,
  [SMALL_STATE(9231)] = 450354,
  [SMALL_STATE(9232)] = 450396,
  [SMALL_STATE(9233)] = 450438,
  [SMALL_STATE(9234)] = 450480,
  [SMALL_STATE(9235)] = 450552,
  [SMALL_STATE(9236)] = 450594,
  [SMALL_STATE(9237)] = 450636,
  [SMALL_STATE(9238)] = 450678,
  [SMALL_STATE(9239)] = 450720,
  [SMALL_STATE(9240)] = 450792,
  [SMALL_STATE(9241)] = 450834,
  [SMALL_STATE(9242)] = 450876,
  [SMALL_STATE(9243)] = 450918,
  [SMALL_STATE(9244)] = 450960,
  [SMALL_STATE(9245)] = 451032,
  [SMALL_STATE(9246)] = 451074,
  [SMALL_STATE(9247)] = 451116,
  [SMALL_STATE(9248)] = 451188,
  [SMALL_STATE(9249)] = 451230,
  [SMALL_STATE(9250)] = 451302,
  [SMALL_STATE(9251)] = 451374,
  [SMALL_STATE(9252)] = 451446,
  [SMALL_STATE(9253)] = 451498,
  [SMALL_STATE(9254)] = 451570,
  [SMALL_STATE(9255)] = 451642,
  [SMALL_STATE(9256)] = 451700,
  [SMALL_STATE(9257)] = 451768,
  [SMALL_STATE(9258)] = 451810,
  [SMALL_STATE(9259)] = 451878,
  [SMALL_STATE(9260)] = 451950,
  [SMALL_STATE(9261)] = 451992,
  [SMALL_STATE(9262)] = 452064,
  [SMALL_STATE(9263)] = 452136,
  [SMALL_STATE(9264)] = 452208,
  [SMALL_STATE(9265)] = 452280,
  [SMALL_STATE(9266)] = 452322,
  [SMALL_STATE(9267)] = 452364,
  [SMALL_STATE(9268)] = 452436,
  [SMALL_STATE(9269)] = 452478,
  [SMALL_STATE(9270)] = 452550,
  [SMALL_STATE(9271)] = 452592,
  [SMALL_STATE(9272)] = 452664,
  [SMALL_STATE(9273)] = 452710,
  [SMALL_STATE(9274)] = 452782,
  [SMALL_STATE(9275)] = 452854,
  [SMALL_STATE(9276)] = 452926,
  [SMALL_STATE(9277)] = 452968,
  [SMALL_STATE(9278)] = 453040,
  [SMALL_STATE(9279)] = 453082,
  [SMALL_STATE(9280)] = 453154,
  [SMALL_STATE(9281)] = 453196,
  [SMALL_STATE(9282)] = 453268,
  [SMALL_STATE(9283)] = 453310,
  [SMALL_STATE(9284)] = 453382,
  [SMALL_STATE(9285)] = 453454,
  [SMALL_STATE(9286)] = 453526,
  [SMALL_STATE(9287)] = 453598,
  [SMALL_STATE(9288)] = 453670,
  [SMALL_STATE(9289)] = 453728,
  [SMALL_STATE(9290)] = 453770,
  [SMALL_STATE(9291)] = 453812,
  [SMALL_STATE(9292)] = 453884,
  [SMALL_STATE(9293)] = 453956,
  [SMALL_STATE(9294)] = 454028,
  [SMALL_STATE(9295)] = 454070,
  [SMALL_STATE(9296)] = 454112,
  [SMALL_STATE(9297)] = 454184,
  [SMALL_STATE(9298)] = 454226,
  [SMALL_STATE(9299)] = 454268,
  [SMALL_STATE(9300)] = 454310,
  [SMALL_STATE(9301)] = 454352,
  [SMALL_STATE(9302)] = 454424,
  [SMALL_STATE(9303)] = 454466,
  [SMALL_STATE(9304)] = 454538,
  [SMALL_STATE(9305)] = 454610,
  [SMALL_STATE(9306)] = 454652,
  [SMALL_STATE(9307)] = 454724,
  [SMALL_STATE(9308)] = 454796,
  [SMALL_STATE(9309)] = 454838,
  [SMALL_STATE(9310)] = 454910,
  [SMALL_STATE(9311)] = 454952,
  [SMALL_STATE(9312)] = 455024,
  [SMALL_STATE(9313)] = 455096,
  [SMALL_STATE(9314)] = 455138,
  [SMALL_STATE(9315)] = 455180,
  [SMALL_STATE(9316)] = 455222,
  [SMALL_STATE(9317)] = 455264,
  [SMALL_STATE(9318)] = 455306,
  [SMALL_STATE(9319)] = 455348,
  [SMALL_STATE(9320)] = 455420,
  [SMALL_STATE(9321)] = 455462,
  [SMALL_STATE(9322)] = 455534,
  [SMALL_STATE(9323)] = 455606,
  [SMALL_STATE(9324)] = 455678,
  [SMALL_STATE(9325)] = 455750,
  [SMALL_STATE(9326)] = 455822,
  [SMALL_STATE(9327)] = 455864,
  [SMALL_STATE(9328)] = 455936,
  [SMALL_STATE(9329)] = 455994,
  [SMALL_STATE(9330)] = 456066,
  [SMALL_STATE(9331)] = 456138,
  [SMALL_STATE(9332)] = 456210,
  [SMALL_STATE(9333)] = 456282,
  [SMALL_STATE(9334)] = 456324,
  [SMALL_STATE(9335)] = 456396,
  [SMALL_STATE(9336)] = 456438,
  [SMALL_STATE(9337)] = 456480,
  [SMALL_STATE(9338)] = 456552,
  [SMALL_STATE(9339)] = 456596,
  [SMALL_STATE(9340)] = 456638,
  [SMALL_STATE(9341)] = 456710,
  [SMALL_STATE(9342)] = 456782,
  [SMALL_STATE(9343)] = 456851,
  [SMALL_STATE(9344)] = 456908,
  [SMALL_STATE(9345)] = 456949,
  [SMALL_STATE(9346)] = 456990,
  [SMALL_STATE(9347)] = 457031,
  [SMALL_STATE(9348)] = 457082,
  [SMALL_STATE(9349)] = 457123,
  [SMALL_STATE(9350)] = 457166,
  [SMALL_STATE(9351)] = 457207,
  [SMALL_STATE(9352)] = 457248,
  [SMALL_STATE(9353)] = 457289,
  [SMALL_STATE(9354)] = 457330,
  [SMALL_STATE(9355)] = 457387,
  [SMALL_STATE(9356)] = 457446,
  [SMALL_STATE(9357)] = 457487,
  [SMALL_STATE(9358)] = 457528,
  [SMALL_STATE(9359)] = 457569,
  [SMALL_STATE(9360)] = 457610,
  [SMALL_STATE(9361)] = 457651,
  [SMALL_STATE(9362)] = 457692,
  [SMALL_STATE(9363)] = 457751,
  [SMALL_STATE(9364)] = 457792,
  [SMALL_STATE(9365)] = 457833,
  [SMALL_STATE(9366)] = 457874,
  [SMALL_STATE(9367)] = 457943,
  [SMALL_STATE(9368)] = 457984,
  [SMALL_STATE(9369)] = 458025,
  [SMALL_STATE(9370)] = 458066,
  [SMALL_STATE(9371)] = 458107,
  [SMALL_STATE(9372)] = 458148,
  [SMALL_STATE(9373)] = 458189,
  [SMALL_STATE(9374)] = 458230,
  [SMALL_STATE(9375)] = 458271,
  [SMALL_STATE(9376)] = 458330,
  [SMALL_STATE(9377)] = 458371,
  [SMALL_STATE(9378)] = 458412,
  [SMALL_STATE(9379)] = 458453,
  [SMALL_STATE(9380)] = 458494,
  [SMALL_STATE(9381)] = 458535,
  [SMALL_STATE(9382)] = 458576,
  [SMALL_STATE(9383)] = 458617,
  [SMALL_STATE(9384)] = 458660,
  [SMALL_STATE(9385)] = 458701,
  [SMALL_STATE(9386)] = 458742,
  [SMALL_STATE(9387)] = 458783,
  [SMALL_STATE(9388)] = 458840,
  [SMALL_STATE(9389)] = 458881,
  [SMALL_STATE(9390)] = 458926,
  [SMALL_STATE(9391)] = 458971,
  [SMALL_STATE(9392)] = 459012,
  [SMALL_STATE(9393)] = 459053,
  [SMALL_STATE(9394)] = 459110,
  [SMALL_STATE(9395)] = 459155,
  [SMALL_STATE(9396)] = 459200,
  [SMALL_STATE(9397)] = 459257,
  [SMALL_STATE(9398)] = 459314,
  [SMALL_STATE(9399)] = 459355,
  [SMALL_STATE(9400)] = 459424,
  [SMALL_STATE(9401)] = 459465,
  [SMALL_STATE(9402)] = 459506,
  [SMALL_STATE(9403)] = 459575,
  [SMALL_STATE(9404)] = 459636,
  [SMALL_STATE(9405)] = 459695,
  [SMALL_STATE(9406)] = 459752,
  [SMALL_STATE(9407)] = 459793,
  [SMALL_STATE(9408)] = 459862,
  [SMALL_STATE(9409)] = 459907,
  [SMALL_STATE(9410)] = 459952,
  [SMALL_STATE(9411)] = 459995,
  [SMALL_STATE(9412)] = 460036,
  [SMALL_STATE(9413)] = 460077,
  [SMALL_STATE(9414)] = 460118,
  [SMALL_STATE(9415)] = 460159,
  [SMALL_STATE(9416)] = 460200,
  [SMALL_STATE(9417)] = 460241,
  [SMALL_STATE(9418)] = 460282,
  [SMALL_STATE(9419)] = 460323,
  [SMALL_STATE(9420)] = 460364,
  [SMALL_STATE(9421)] = 460419,
  [SMALL_STATE(9422)] = 460472,
  [SMALL_STATE(9423)] = 460513,
  [SMALL_STATE(9424)] = 460554,
  [SMALL_STATE(9425)] = 460595,
  [SMALL_STATE(9426)] = 460658,
  [SMALL_STATE(9427)] = 460715,
  [SMALL_STATE(9428)] = 460756,
  [SMALL_STATE(9429)] = 460797,
  [SMALL_STATE(9430)] = 460838,
  [SMALL_STATE(9431)] = 460879,
  [SMALL_STATE(9432)] = 460932,
  [SMALL_STATE(9433)] = 460989,
  [SMALL_STATE(9434)] = 461048,
  [SMALL_STATE(9435)] = 461113,
  [SMALL_STATE(9436)] = 461154,
  [SMALL_STATE(9437)] = 461195,
  [SMALL_STATE(9438)] = 461236,
  [SMALL_STATE(9439)] = 461277,
  [SMALL_STATE(9440)] = 461318,
  [SMALL_STATE(9441)] = 461359,
  [SMALL_STATE(9442)] = 461400,
  [SMALL_STATE(9443)] = 461441,
  [SMALL_STATE(9444)] = 461498,
  [SMALL_STATE(9445)] = 461567,
  [SMALL_STATE(9446)] = 461608,
  [SMALL_STATE(9447)] = 461649,
  [SMALL_STATE(9448)] = 461690,
  [SMALL_STATE(9449)] = 461747,
  [SMALL_STATE(9450)] = 461804,
  [SMALL_STATE(9451)] = 461847,
  [SMALL_STATE(9452)] = 461888,
  [SMALL_STATE(9453)] = 461945,
  [SMALL_STATE(9454)] = 462002,
  [SMALL_STATE(9455)] = 462063,
  [SMALL_STATE(9456)] = 462120,
  [SMALL_STATE(9457)] = 462165,
  [SMALL_STATE(9458)] = 462206,
  [SMALL_STATE(9459)] = 462265,
  [SMALL_STATE(9460)] = 462306,
  [SMALL_STATE(9461)] = 462363,
  [SMALL_STATE(9462)] = 462404,
  [SMALL_STATE(9463)] = 462473,
  [SMALL_STATE(9464)] = 462514,
  [SMALL_STATE(9465)] = 462555,
  [SMALL_STATE(9466)] = 462602,
  [SMALL_STATE(9467)] = 462643,
  [SMALL_STATE(9468)] = 462700,
  [SMALL_STATE(9469)] = 462741,
  [SMALL_STATE(9470)] = 462782,
  [SMALL_STATE(9471)] = 462823,
  [SMALL_STATE(9472)] = 462864,
  [SMALL_STATE(9473)] = 462905,
  [SMALL_STATE(9474)] = 462968,
  [SMALL_STATE(9475)] = 463011,
  [SMALL_STATE(9476)] = 463052,
  [SMALL_STATE(9477)] = 463103,
  [SMALL_STATE(9478)] = 463144,
  [SMALL_STATE(9479)] = 463185,
  [SMALL_STATE(9480)] = 463230,
  [SMALL_STATE(9481)] = 463275,
  [SMALL_STATE(9482)] = 463344,
  [SMALL_STATE(9483)] = 463395,
  [SMALL_STATE(9484)] = 463436,
  [SMALL_STATE(9485)] = 463499,
  [SMALL_STATE(9486)] = 463540,
  [SMALL_STATE(9487)] = 463581,
  [SMALL_STATE(9488)] = 463622,
  [SMALL_STATE(9489)] = 463663,
  [SMALL_STATE(9490)] = 463704,
  [SMALL_STATE(9491)] = 463745,
  [SMALL_STATE(9492)] = 463786,
  [SMALL_STATE(9493)] = 463827,
  [SMALL_STATE(9494)] = 463884,
  [SMALL_STATE(9495)] = 463925,
  [SMALL_STATE(9496)] = 463966,
  [SMALL_STATE(9497)] = 464007,
  [SMALL_STATE(9498)] = 464048,
  [SMALL_STATE(9499)] = 464117,
  [SMALL_STATE(9500)] = 464158,
  [SMALL_STATE(9501)] = 464199,
  [SMALL_STATE(9502)] = 464240,
  [SMALL_STATE(9503)] = 464281,
  [SMALL_STATE(9504)] = 464322,
  [SMALL_STATE(9505)] = 464363,
  [SMALL_STATE(9506)] = 464404,
  [SMALL_STATE(9507)] = 464455,
  [SMALL_STATE(9508)] = 464518,
  [SMALL_STATE(9509)] = 464559,
  [SMALL_STATE(9510)] = 464616,
  [SMALL_STATE(9511)] = 464657,
  [SMALL_STATE(9512)] = 464728,
  [SMALL_STATE(9513)] = 464797,
  [SMALL_STATE(9514)] = 464838,
  [SMALL_STATE(9515)] = 464899,
  [SMALL_STATE(9516)] = 464940,
  [SMALL_STATE(9517)] = 464985,
  [SMALL_STATE(9518)] = 465026,
  [SMALL_STATE(9519)] = 465067,
  [SMALL_STATE(9520)] = 465122,
  [SMALL_STATE(9521)] = 465183,
  [SMALL_STATE(9522)] = 465224,
  [SMALL_STATE(9523)] = 465269,
  [SMALL_STATE(9524)] = 465312,
  [SMALL_STATE(9525)] = 465353,
  [SMALL_STATE(9526)] = 465396,
  [SMALL_STATE(9527)] = 465436,
  [SMALL_STATE(9528)] = 465504,
  [SMALL_STATE(9529)] = 465544,
  [SMALL_STATE(9530)] = 465584,
  [SMALL_STATE(9531)] = 465624,
  [SMALL_STATE(9532)] = 465664,
  [SMALL_STATE(9533)] = 465726,
  [SMALL_STATE(9534)] = 465766,
  [SMALL_STATE(9535)] = 465810,
  [SMALL_STATE(9536)] = 465850,
  [SMALL_STATE(9537)] = 465912,
  [SMALL_STATE(9538)] = 465952,
  [SMALL_STATE(9539)] = 465992,
  [SMALL_STATE(9540)] = 466038,
  [SMALL_STATE(9541)] = 466078,
  [SMALL_STATE(9542)] = 466118,
  [SMALL_STATE(9543)] = 466158,
  [SMALL_STATE(9544)] = 466220,
  [SMALL_STATE(9545)] = 466278,
  [SMALL_STATE(9546)] = 466334,
  [SMALL_STATE(9547)] = 466386,
  [SMALL_STATE(9548)] = 466442,
  [SMALL_STATE(9549)] = 466494,
  [SMALL_STATE(9550)] = 466538,
  [SMALL_STATE(9551)] = 466582,
  [SMALL_STATE(9552)] = 466632,
  [SMALL_STATE(9553)] = 466690,
  [SMALL_STATE(9554)] = 466730,
  [SMALL_STATE(9555)] = 466770,
  [SMALL_STATE(9556)] = 466810,
  [SMALL_STATE(9557)] = 466850,
  [SMALL_STATE(9558)] = 466890,
  [SMALL_STATE(9559)] = 466930,
  [SMALL_STATE(9560)] = 466970,
  [SMALL_STATE(9561)] = 467010,
  [SMALL_STATE(9562)] = 467050,
  [SMALL_STATE(9563)] = 467090,
  [SMALL_STATE(9564)] = 467130,
  [SMALL_STATE(9565)] = 467174,
  [SMALL_STATE(9566)] = 467214,
  [SMALL_STATE(9567)] = 467254,
  [SMALL_STATE(9568)] = 467294,
  [SMALL_STATE(9569)] = 467362,
  [SMALL_STATE(9570)] = 467430,
  [SMALL_STATE(9571)] = 467470,
  [SMALL_STATE(9572)] = 467510,
  [SMALL_STATE(9573)] = 467550,
  [SMALL_STATE(9574)] = 467590,
  [SMALL_STATE(9575)] = 467630,
  [SMALL_STATE(9576)] = 467670,
  [SMALL_STATE(9577)] = 467710,
  [SMALL_STATE(9578)] = 467750,
  [SMALL_STATE(9579)] = 467792,
  [SMALL_STATE(9580)] = 467832,
  [SMALL_STATE(9581)] = 467872,
  [SMALL_STATE(9582)] = 467940,
  [SMALL_STATE(9583)] = 467980,
  [SMALL_STATE(9584)] = 468020,
  [SMALL_STATE(9585)] = 468088,
  [SMALL_STATE(9586)] = 468156,
  [SMALL_STATE(9587)] = 468196,
  [SMALL_STATE(9588)] = 468236,
  [SMALL_STATE(9589)] = 468276,
  [SMALL_STATE(9590)] = 468326,
  [SMALL_STATE(9591)] = 468384,
  [SMALL_STATE(9592)] = 468452,
  [SMALL_STATE(9593)] = 468492,
  [SMALL_STATE(9594)] = 468560,
  [SMALL_STATE(9595)] = 468628,
  [SMALL_STATE(9596)] = 468678,
  [SMALL_STATE(9597)] = 468722,
  [SMALL_STATE(9598)] = 468762,
  [SMALL_STATE(9599)] = 468812,
  [SMALL_STATE(9600)] = 468856,
  [SMALL_STATE(9601)] = 468896,
  [SMALL_STATE(9602)] = 468940,
  [SMALL_STATE(9603)] = 468992,
  [SMALL_STATE(9604)] = 469044,
  [SMALL_STATE(9605)] = 469090,
  [SMALL_STATE(9606)] = 469154,
  [SMALL_STATE(9607)] = 469210,
  [SMALL_STATE(9608)] = 469250,
  [SMALL_STATE(9609)] = 469302,
  [SMALL_STATE(9610)] = 469342,
  [SMALL_STATE(9611)] = 469392,
  [SMALL_STATE(9612)] = 469450,
  [SMALL_STATE(9613)] = 469512,
  [SMALL_STATE(9614)] = 469558,
  [SMALL_STATE(9615)] = 469626,
  [SMALL_STATE(9616)] = 469694,
  [SMALL_STATE(9617)] = 469762,
  [SMALL_STATE(9618)] = 469824,
  [SMALL_STATE(9619)] = 469870,
  [SMALL_STATE(9620)] = 469910,
  [SMALL_STATE(9621)] = 469972,
  [SMALL_STATE(9622)] = 470040,
  [SMALL_STATE(9623)] = 470080,
  [SMALL_STATE(9624)] = 470120,
  [SMALL_STATE(9625)] = 470160,
  [SMALL_STATE(9626)] = 470200,
  [SMALL_STATE(9627)] = 470240,
  [SMALL_STATE(9628)] = 470308,
  [SMALL_STATE(9629)] = 470348,
  [SMALL_STATE(9630)] = 470388,
  [SMALL_STATE(9631)] = 470428,
  [SMALL_STATE(9632)] = 470468,
  [SMALL_STATE(9633)] = 470508,
  [SMALL_STATE(9634)] = 470548,
  [SMALL_STATE(9635)] = 470616,
  [SMALL_STATE(9636)] = 470684,
  [SMALL_STATE(9637)] = 470752,
  [SMALL_STATE(9638)] = 470792,
  [SMALL_STATE(9639)] = 470846,
  [SMALL_STATE(9640)] = 470886,
  [SMALL_STATE(9641)] = 470954,
  [SMALL_STATE(9642)] = 470994,
  [SMALL_STATE(9643)] = 471062,
  [SMALL_STATE(9644)] = 471102,
  [SMALL_STATE(9645)] = 471142,
  [SMALL_STATE(9646)] = 471182,
  [SMALL_STATE(9647)] = 471250,
  [SMALL_STATE(9648)] = 471290,
  [SMALL_STATE(9649)] = 471332,
  [SMALL_STATE(9650)] = 471372,
  [SMALL_STATE(9651)] = 471440,
  [SMALL_STATE(9652)] = 471508,
  [SMALL_STATE(9653)] = 471576,
  [SMALL_STATE(9654)] = 471616,
  [SMALL_STATE(9655)] = 471684,
  [SMALL_STATE(9656)] = 471752,
  [SMALL_STATE(9657)] = 471820,
  [SMALL_STATE(9658)] = 471860,
  [SMALL_STATE(9659)] = 471910,
  [SMALL_STATE(9660)] = 471950,
  [SMALL_STATE(9661)] = 472018,
  [SMALL_STATE(9662)] = 472060,
  [SMALL_STATE(9663)] = 472100,
  [SMALL_STATE(9664)] = 472168,
  [SMALL_STATE(9665)] = 472236,
  [SMALL_STATE(9666)] = 472304,
  [SMALL_STATE(9667)] = 472344,
  [SMALL_STATE(9668)] = 472384,
  [SMALL_STATE(9669)] = 472452,
  [SMALL_STATE(9670)] = 472492,
  [SMALL_STATE(9671)] = 472532,
  [SMALL_STATE(9672)] = 472576,
  [SMALL_STATE(9673)] = 472616,
  [SMALL_STATE(9674)] = 472656,
  [SMALL_STATE(9675)] = 472696,
  [SMALL_STATE(9676)] = 472736,
  [SMALL_STATE(9677)] = 472804,
  [SMALL_STATE(9678)] = 472872,
  [SMALL_STATE(9679)] = 472912,
  [SMALL_STATE(9680)] = 472980,
  [SMALL_STATE(9681)] = 473020,
  [SMALL_STATE(9682)] = 473060,
  [SMALL_STATE(9683)] = 473128,
  [SMALL_STATE(9684)] = 473172,
  [SMALL_STATE(9685)] = 473218,
  [SMALL_STATE(9686)] = 473258,
  [SMALL_STATE(9687)] = 473298,
  [SMALL_STATE(9688)] = 473360,
  [SMALL_STATE(9689)] = 473416,
  [SMALL_STATE(9690)] = 473484,
  [SMALL_STATE(9691)] = 473524,
  [SMALL_STATE(9692)] = 473592,
  [SMALL_STATE(9693)] = 473632,
  [SMALL_STATE(9694)] = 473688,
  [SMALL_STATE(9695)] = 473756,
  [SMALL_STATE(9696)] = 473812,
  [SMALL_STATE(9697)] = 473852,
  [SMALL_STATE(9698)] = 473920,
  [SMALL_STATE(9699)] = 473988,
  [SMALL_STATE(9700)] = 474044,
  [SMALL_STATE(9701)] = 474112,
  [SMALL_STATE(9702)] = 474168,
  [SMALL_STATE(9703)] = 474208,
  [SMALL_STATE(9704)] = 474248,
  [SMALL_STATE(9705)] = 474294,
  [SMALL_STATE(9706)] = 474334,
  [SMALL_STATE(9707)] = 474378,
  [SMALL_STATE(9708)] = 474418,
  [SMALL_STATE(9709)] = 474474,
  [SMALL_STATE(9710)] = 474542,
  [SMALL_STATE(9711)] = 474610,
  [SMALL_STATE(9712)] = 474650,
  [SMALL_STATE(9713)] = 474696,
  [SMALL_STATE(9714)] = 474736,
  [SMALL_STATE(9715)] = 474776,
  [SMALL_STATE(9716)] = 474832,
  [SMALL_STATE(9717)] = 474872,
  [SMALL_STATE(9718)] = 474912,
  [SMALL_STATE(9719)] = 474980,
  [SMALL_STATE(9720)] = 475020,
  [SMALL_STATE(9721)] = 475060,
  [SMALL_STATE(9722)] = 475102,
  [SMALL_STATE(9723)] = 475142,
  [SMALL_STATE(9724)] = 475210,
  [SMALL_STATE(9725)] = 475250,
  [SMALL_STATE(9726)] = 475318,
  [SMALL_STATE(9727)] = 475382,
  [SMALL_STATE(9728)] = 475422,
  [SMALL_STATE(9729)] = 475480,
  [SMALL_STATE(9730)] = 475520,
  [SMALL_STATE(9731)] = 475560,
  [SMALL_STATE(9732)] = 475600,
  [SMALL_STATE(9733)] = 475640,
  [SMALL_STATE(9734)] = 475680,
  [SMALL_STATE(9735)] = 475720,
  [SMALL_STATE(9736)] = 475760,
  [SMALL_STATE(9737)] = 475802,
  [SMALL_STATE(9738)] = 475842,
  [SMALL_STATE(9739)] = 475910,
  [SMALL_STATE(9740)] = 475950,
  [SMALL_STATE(9741)] = 475990,
  [SMALL_STATE(9742)] = 476030,
  [SMALL_STATE(9743)] = 476086,
  [SMALL_STATE(9744)] = 476154,
  [SMALL_STATE(9745)] = 476194,
  [SMALL_STATE(9746)] = 476262,
  [SMALL_STATE(9747)] = 476302,
  [SMALL_STATE(9748)] = 476342,
  [SMALL_STATE(9749)] = 476386,
  [SMALL_STATE(9750)] = 476454,
  [SMALL_STATE(9751)] = 476522,
  [SMALL_STATE(9752)] = 476590,
  [SMALL_STATE(9753)] = 476632,
  [SMALL_STATE(9754)] = 476674,
  [SMALL_STATE(9755)] = 476742,
  [SMALL_STATE(9756)] = 476782,
  [SMALL_STATE(9757)] = 476822,
  [SMALL_STATE(9758)] = 476862,
  [SMALL_STATE(9759)] = 476902,
  [SMALL_STATE(9760)] = 476942,
  [SMALL_STATE(9761)] = 476992,
  [SMALL_STATE(9762)] = 477060,
  [SMALL_STATE(9763)] = 477116,
  [SMALL_STATE(9764)] = 477170,
  [SMALL_STATE(9765)] = 477238,
  [SMALL_STATE(9766)] = 477288,
  [SMALL_STATE(9767)] = 477328,
  [SMALL_STATE(9768)] = 477368,
  [SMALL_STATE(9769)] = 477410,
  [SMALL_STATE(9770)] = 477450,
  [SMALL_STATE(9771)] = 477490,
  [SMALL_STATE(9772)] = 477558,
  [SMALL_STATE(9773)] = 477598,
  [SMALL_STATE(9774)] = 477638,
  [SMALL_STATE(9775)] = 477706,
  [SMALL_STATE(9776)] = 477746,
  [SMALL_STATE(9777)] = 477814,
  [SMALL_STATE(9778)] = 477882,
  [SMALL_STATE(9779)] = 477950,
  [SMALL_STATE(9780)] = 478018,
  [SMALL_STATE(9781)] = 478058,
  [SMALL_STATE(9782)] = 478126,
  [SMALL_STATE(9783)] = 478168,
  [SMALL_STATE(9784)] = 478210,
  [SMALL_STATE(9785)] = 478250,
  [SMALL_STATE(9786)] = 478318,
  [SMALL_STATE(9787)] = 478358,
  [SMALL_STATE(9788)] = 478398,
  [SMALL_STATE(9789)] = 478438,
  [SMALL_STATE(9790)] = 478482,
  [SMALL_STATE(9791)] = 478538,
  [SMALL_STATE(9792)] = 478578,
  [SMALL_STATE(9793)] = 478618,
  [SMALL_STATE(9794)] = 478674,
  [SMALL_STATE(9795)] = 478732,
  [SMALL_STATE(9796)] = 478772,
  [SMALL_STATE(9797)] = 478818,
  [SMALL_STATE(9798)] = 478864,
  [SMALL_STATE(9799)] = 478932,
  [SMALL_STATE(9800)] = 479000,
  [SMALL_STATE(9801)] = 479068,
  [SMALL_STATE(9802)] = 479136,
  [SMALL_STATE(9803)] = 479204,
  [SMALL_STATE(9804)] = 479244,
  [SMALL_STATE(9805)] = 479284,
  [SMALL_STATE(9806)] = 479352,
  [SMALL_STATE(9807)] = 479420,
  [SMALL_STATE(9808)] = 479488,
  [SMALL_STATE(9809)] = 479556,
  [SMALL_STATE(9810)] = 479624,
  [SMALL_STATE(9811)] = 479692,
  [SMALL_STATE(9812)] = 479732,
  [SMALL_STATE(9813)] = 479800,
  [SMALL_STATE(9814)] = 479840,
  [SMALL_STATE(9815)] = 479880,
  [SMALL_STATE(9816)] = 479920,
  [SMALL_STATE(9817)] = 479988,
  [SMALL_STATE(9818)] = 480054,
  [SMALL_STATE(9819)] = 480122,
  [SMALL_STATE(9820)] = 480190,
  [SMALL_STATE(9821)] = 480230,
  [SMALL_STATE(9822)] = 480298,
  [SMALL_STATE(9823)] = 480366,
  [SMALL_STATE(9824)] = 480406,
  [SMALL_STATE(9825)] = 480446,
  [SMALL_STATE(9826)] = 480492,
  [SMALL_STATE(9827)] = 480534,
  [SMALL_STATE(9828)] = 480602,
  [SMALL_STATE(9829)] = 480670,
  [SMALL_STATE(9830)] = 480738,
  [SMALL_STATE(9831)] = 480794,
  [SMALL_STATE(9832)] = 480848,
  [SMALL_STATE(9833)] = 480916,
  [SMALL_STATE(9834)] = 480984,
  [SMALL_STATE(9835)] = 481052,
  [SMALL_STATE(9836)] = 481092,
  [SMALL_STATE(9837)] = 481132,
  [SMALL_STATE(9838)] = 481200,
  [SMALL_STATE(9839)] = 481240,
  [SMALL_STATE(9840)] = 481308,
  [SMALL_STATE(9841)] = 481376,
  [SMALL_STATE(9842)] = 481444,
  [SMALL_STATE(9843)] = 481512,
  [SMALL_STATE(9844)] = 481580,
  [SMALL_STATE(9845)] = 481648,
  [SMALL_STATE(9846)] = 481704,
  [SMALL_STATE(9847)] = 481772,
  [SMALL_STATE(9848)] = 481840,
  [SMALL_STATE(9849)] = 481880,
  [SMALL_STATE(9850)] = 481948,
  [SMALL_STATE(9851)] = 482016,
  [SMALL_STATE(9852)] = 482084,
  [SMALL_STATE(9853)] = 482124,
  [SMALL_STATE(9854)] = 482170,
  [SMALL_STATE(9855)] = 482222,
  [SMALL_STATE(9856)] = 482290,
  [SMALL_STATE(9857)] = 482330,
  [SMALL_STATE(9858)] = 482376,
  [SMALL_STATE(9859)] = 482416,
  [SMALL_STATE(9860)] = 482456,
  [SMALL_STATE(9861)] = 482502,
  [SMALL_STATE(9862)] = 482570,
  [SMALL_STATE(9863)] = 482638,
  [SMALL_STATE(9864)] = 482678,
  [SMALL_STATE(9865)] = 482718,
  [SMALL_STATE(9866)] = 482764,
  [SMALL_STATE(9867)] = 482804,
  [SMALL_STATE(9868)] = 482872,
  [SMALL_STATE(9869)] = 482912,
  [SMALL_STATE(9870)] = 482980,
  [SMALL_STATE(9871)] = 483043,
  [SMALL_STATE(9872)] = 483084,
  [SMALL_STATE(9873)] = 483123,
  [SMALL_STATE(9874)] = 483186,
  [SMALL_STATE(9875)] = 483241,
  [SMALL_STATE(9876)] = 483298,
  [SMALL_STATE(9877)] = 483353,
  [SMALL_STATE(9878)] = 483408,
  [SMALL_STATE(9879)] = 483471,
  [SMALL_STATE(9880)] = 483520,
  [SMALL_STATE(9881)] = 483575,
  [SMALL_STATE(9882)] = 483638,
  [SMALL_STATE(9883)] = 483701,
  [SMALL_STATE(9884)] = 483752,
  [SMALL_STATE(9885)] = 483815,
  [SMALL_STATE(9886)] = 483858,
  [SMALL_STATE(9887)] = 483901,
  [SMALL_STATE(9888)] = 483964,
  [SMALL_STATE(9889)] = 484027,
  [SMALL_STATE(9890)] = 484090,
  [SMALL_STATE(9891)] = 484153,
  [SMALL_STATE(9892)] = 484202,
  [SMALL_STATE(9893)] = 484241,
  [SMALL_STATE(9894)] = 484298,
  [SMALL_STATE(9895)] = 484343,
  [SMALL_STATE(9896)] = 484382,
  [SMALL_STATE(9897)] = 484445,
  [SMALL_STATE(9898)] = 484508,
  [SMALL_STATE(9899)] = 484557,
  [SMALL_STATE(9900)] = 484598,
  [SMALL_STATE(9901)] = 484661,
  [SMALL_STATE(9902)] = 484724,
  [SMALL_STATE(9903)] = 484787,
  [SMALL_STATE(9904)] = 484850,
  [SMALL_STATE(9905)] = 484905,
  [SMALL_STATE(9906)] = 484944,
  [SMALL_STATE(9907)] = 485007,
  [SMALL_STATE(9908)] = 485058,
  [SMALL_STATE(9909)] = 485121,
  [SMALL_STATE(9910)] = 485184,
  [SMALL_STATE(9911)] = 485247,
  [SMALL_STATE(9912)] = 485310,
  [SMALL_STATE(9913)] = 485373,
  [SMALL_STATE(9914)] = 485436,
  [SMALL_STATE(9915)] = 485499,
  [SMALL_STATE(9916)] = 485562,
  [SMALL_STATE(9917)] = 485601,
  [SMALL_STATE(9918)] = 485662,
  [SMALL_STATE(9919)] = 485725,
  [SMALL_STATE(9920)] = 485788,
  [SMALL_STATE(9921)] = 485837,
  [SMALL_STATE(9922)] = 485900,
  [SMALL_STATE(9923)] = 485963,
  [SMALL_STATE(9924)] = 486008,
  [SMALL_STATE(9925)] = 486047,
  [SMALL_STATE(9926)] = 486110,
  [SMALL_STATE(9927)] = 486171,
  [SMALL_STATE(9928)] = 486234,
  [SMALL_STATE(9929)] = 486297,
  [SMALL_STATE(9930)] = 486360,
  [SMALL_STATE(9931)] = 486399,
  [SMALL_STATE(9932)] = 486462,
  [SMALL_STATE(9933)] = 486525,
  [SMALL_STATE(9934)] = 486588,
  [SMALL_STATE(9935)] = 486651,
  [SMALL_STATE(9936)] = 486706,
  [SMALL_STATE(9937)] = 486769,
  [SMALL_STATE(9938)] = 486832,
  [SMALL_STATE(9939)] = 486895,
  [SMALL_STATE(9940)] = 486958,
  [SMALL_STATE(9941)] = 487021,
  [SMALL_STATE(9942)] = 487084,
  [SMALL_STATE(9943)] = 487147,
  [SMALL_STATE(9944)] = 487210,
  [SMALL_STATE(9945)] = 487273,
  [SMALL_STATE(9946)] = 487336,
  [SMALL_STATE(9947)] = 487399,
  [SMALL_STATE(9948)] = 487448,
  [SMALL_STATE(9949)] = 487491,
  [SMALL_STATE(9950)] = 487540,
  [SMALL_STATE(9951)] = 487603,
  [SMALL_STATE(9952)] = 487642,
  [SMALL_STATE(9953)] = 487705,
  [SMALL_STATE(9954)] = 487768,
  [SMALL_STATE(9955)] = 487831,
  [SMALL_STATE(9956)] = 487878,
  [SMALL_STATE(9957)] = 487941,
  [SMALL_STATE(9958)] = 487996,
  [SMALL_STATE(9959)] = 488059,
  [SMALL_STATE(9960)] = 488122,
  [SMALL_STATE(9961)] = 488179,
  [SMALL_STATE(9962)] = 488242,
  [SMALL_STATE(9963)] = 488291,
  [SMALL_STATE(9964)] = 488354,
  [SMALL_STATE(9965)] = 488393,
  [SMALL_STATE(9966)] = 488432,
  [SMALL_STATE(9967)] = 488495,
  [SMALL_STATE(9968)] = 488558,
  [SMALL_STATE(9969)] = 488597,
  [SMALL_STATE(9970)] = 488636,
  [SMALL_STATE(9971)] = 488699,
  [SMALL_STATE(9972)] = 488748,
  [SMALL_STATE(9973)] = 488789,
  [SMALL_STATE(9974)] = 488844,
  [SMALL_STATE(9975)] = 488907,
  [SMALL_STATE(9976)] = 488970,
  [SMALL_STATE(9977)] = 489009,
  [SMALL_STATE(9978)] = 489072,
  [SMALL_STATE(9979)] = 489111,
  [SMALL_STATE(9980)] = 489166,
  [SMALL_STATE(9981)] = 489205,
  [SMALL_STATE(9982)] = 489260,
  [SMALL_STATE(9983)] = 489299,
  [SMALL_STATE(9984)] = 489362,
  [SMALL_STATE(9985)] = 489401,
  [SMALL_STATE(9986)] = 489464,
  [SMALL_STATE(9987)] = 489503,
  [SMALL_STATE(9988)] = 489560,
  [SMALL_STATE(9989)] = 489615,
  [SMALL_STATE(9990)] = 489664,
  [SMALL_STATE(9991)] = 489703,
  [SMALL_STATE(9992)] = 489766,
  [SMALL_STATE(9993)] = 489829,
  [SMALL_STATE(9994)] = 489874,
  [SMALL_STATE(9995)] = 489937,
  [SMALL_STATE(9996)] = 489990,
  [SMALL_STATE(9997)] = 490053,
  [SMALL_STATE(9998)] = 490116,
  [SMALL_STATE(9999)] = 490161,
  [SMALL_STATE(10000)] = 490224,
  [SMALL_STATE(10001)] = 490287,
  [SMALL_STATE(10002)] = 490350,
  [SMALL_STATE(10003)] = 490395,
  [SMALL_STATE(10004)] = 490458,
  [SMALL_STATE(10005)] = 490521,
  [SMALL_STATE(10006)] = 490584,
  [SMALL_STATE(10007)] = 490647,
  [SMALL_STATE(10008)] = 490710,
  [SMALL_STATE(10009)] = 490773,
  [SMALL_STATE(10010)] = 490836,
  [SMALL_STATE(10011)] = 490885,
  [SMALL_STATE(10012)] = 490930,
  [SMALL_STATE(10013)] = 490993,
  [SMALL_STATE(10014)] = 491056,
  [SMALL_STATE(10015)] = 491111,
  [SMALL_STATE(10016)] = 491150,
  [SMALL_STATE(10017)] = 491195,
  [SMALL_STATE(10018)] = 491234,
  [SMALL_STATE(10019)] = 491273,
  [SMALL_STATE(10020)] = 491324,
  [SMALL_STATE(10021)] = 491363,
  [SMALL_STATE(10022)] = 491418,
  [SMALL_STATE(10023)] = 491457,
  [SMALL_STATE(10024)] = 491512,
  [SMALL_STATE(10025)] = 491553,
  [SMALL_STATE(10026)] = 491616,
  [SMALL_STATE(10027)] = 491655,
  [SMALL_STATE(10028)] = 491694,
  [SMALL_STATE(10029)] = 491733,
  [SMALL_STATE(10030)] = 491784,
  [SMALL_STATE(10031)] = 491829,
  [SMALL_STATE(10032)] = 491868,
  [SMALL_STATE(10033)] = 491909,
  [SMALL_STATE(10034)] = 491972,
  [SMALL_STATE(10035)] = 492035,
  [SMALL_STATE(10036)] = 492074,
  [SMALL_STATE(10037)] = 492129,
  [SMALL_STATE(10038)] = 492168,
  [SMALL_STATE(10039)] = 492207,
  [SMALL_STATE(10040)] = 492262,
  [SMALL_STATE(10041)] = 492309,
  [SMALL_STATE(10042)] = 492348,
  [SMALL_STATE(10043)] = 492411,
  [SMALL_STATE(10044)] = 492456,
  [SMALL_STATE(10045)] = 492501,
  [SMALL_STATE(10046)] = 492540,
  [SMALL_STATE(10047)] = 492589,
  [SMALL_STATE(10048)] = 492652,
  [SMALL_STATE(10049)] = 492707,
  [SMALL_STATE(10050)] = 492768,
  [SMALL_STATE(10051)] = 492807,
  [SMALL_STATE(10052)] = 492846,
  [SMALL_STATE(10053)] = 492901,
  [SMALL_STATE(10054)] = 492952,
  [SMALL_STATE(10055)] = 492991,
  [SMALL_STATE(10056)] = 493054,
  [SMALL_STATE(10057)] = 493117,
  [SMALL_STATE(10058)] = 493180,
  [SMALL_STATE(10059)] = 493235,
  [SMALL_STATE(10060)] = 493298,
  [SMALL_STATE(10061)] = 493337,
  [SMALL_STATE(10062)] = 493376,
  [SMALL_STATE(10063)] = 493415,
  [SMALL_STATE(10064)] = 493454,
  [SMALL_STATE(10065)] = 493509,
  [SMALL_STATE(10066)] = 493572,
  [SMALL_STATE(10067)] = 493621,
  [SMALL_STATE(10068)] = 493684,
  [SMALL_STATE(10069)] = 493733,
  [SMALL_STATE(10070)] = 493796,
  [SMALL_STATE(10071)] = 493835,
  [SMALL_STATE(10072)] = 493898,
  [SMALL_STATE(10073)] = 493949,
  [SMALL_STATE(10074)] = 494012,
  [SMALL_STATE(10075)] = 494063,
  [SMALL_STATE(10076)] = 494102,
  [SMALL_STATE(10077)] = 494141,
  [SMALL_STATE(10078)] = 494204,
  [SMALL_STATE(10079)] = 494243,
  [SMALL_STATE(10080)] = 494286,
  [SMALL_STATE(10081)] = 494335,
  [SMALL_STATE(10082)] = 494376,
  [SMALL_STATE(10083)] = 494417,
  [SMALL_STATE(10084)] = 494480,
  [SMALL_STATE(10085)] = 494525,
  [SMALL_STATE(10086)] = 494588,
  [SMALL_STATE(10087)] = 494651,
  [SMALL_STATE(10088)] = 494714,
  [SMALL_STATE(10089)] = 494777,
  [SMALL_STATE(10090)] = 494816,
  [SMALL_STATE(10091)] = 494855,
  [SMALL_STATE(10092)] = 494918,
  [SMALL_STATE(10093)] = 494981,
  [SMALL_STATE(10094)] = 495020,
  [SMALL_STATE(10095)] = 495069,
  [SMALL_STATE(10096)] = 495118,
  [SMALL_STATE(10097)] = 495171,
  [SMALL_STATE(10098)] = 495210,
  [SMALL_STATE(10099)] = 495249,
  [SMALL_STATE(10100)] = 495312,
  [SMALL_STATE(10101)] = 495351,
  [SMALL_STATE(10102)] = 495414,
  [SMALL_STATE(10103)] = 495477,
  [SMALL_STATE(10104)] = 495540,
  [SMALL_STATE(10105)] = 495579,
  [SMALL_STATE(10106)] = 495618,
  [SMALL_STATE(10107)] = 495667,
  [SMALL_STATE(10108)] = 495722,
  [SMALL_STATE(10109)] = 495785,
  [SMALL_STATE(10110)] = 495848,
  [SMALL_STATE(10111)] = 495886,
  [SMALL_STATE(10112)] = 495952,
  [SMALL_STATE(10113)] = 495990,
  [SMALL_STATE(10114)] = 496044,
  [SMALL_STATE(10115)] = 496082,
  [SMALL_STATE(10116)] = 496120,
  [SMALL_STATE(10117)] = 496158,
  [SMALL_STATE(10118)] = 496224,
  [SMALL_STATE(10119)] = 496262,
  [SMALL_STATE(10120)] = 496300,
  [SMALL_STATE(10121)] = 496338,
  [SMALL_STATE(10122)] = 496386,
  [SMALL_STATE(10123)] = 496424,
  [SMALL_STATE(10124)] = 496462,
  [SMALL_STATE(10125)] = 496510,
  [SMALL_STATE(10126)] = 496548,
  [SMALL_STATE(10127)] = 496586,
  [SMALL_STATE(10128)] = 496624,
  [SMALL_STATE(10129)] = 496666,
  [SMALL_STATE(10130)] = 496732,
  [SMALL_STATE(10131)] = 496770,
  [SMALL_STATE(10132)] = 496818,
  [SMALL_STATE(10133)] = 496856,
  [SMALL_STATE(10134)] = 496904,
  [SMALL_STATE(10135)] = 496942,
  [SMALL_STATE(10136)] = 497008,
  [SMALL_STATE(10137)] = 497056,
  [SMALL_STATE(10138)] = 497098,
  [SMALL_STATE(10139)] = 497136,
  [SMALL_STATE(10140)] = 497174,
  [SMALL_STATE(10141)] = 497212,
  [SMALL_STATE(10142)] = 497278,
  [SMALL_STATE(10143)] = 497316,
  [SMALL_STATE(10144)] = 497354,
  [SMALL_STATE(10145)] = 497420,
  [SMALL_STATE(10146)] = 497458,
  [SMALL_STATE(10147)] = 497496,
  [SMALL_STATE(10148)] = 497534,
  [SMALL_STATE(10149)] = 497572,
  [SMALL_STATE(10150)] = 497614,
  [SMALL_STATE(10151)] = 497654,
  [SMALL_STATE(10152)] = 497692,
  [SMALL_STATE(10153)] = 497758,
  [SMALL_STATE(10154)] = 497796,
  [SMALL_STATE(10155)] = 497834,
  [SMALL_STATE(10156)] = 497872,
  [SMALL_STATE(10157)] = 497910,
  [SMALL_STATE(10158)] = 497948,
  [SMALL_STATE(10159)] = 497986,
  [SMALL_STATE(10160)] = 498028,
  [SMALL_STATE(10161)] = 498066,
  [SMALL_STATE(10162)] = 498116,
  [SMALL_STATE(10163)] = 498154,
  [SMALL_STATE(10164)] = 498192,
  [SMALL_STATE(10165)] = 498244,
  [SMALL_STATE(10166)] = 498282,
  [SMALL_STATE(10167)] = 498330,
  [SMALL_STATE(10168)] = 498368,
  [SMALL_STATE(10169)] = 498406,
  [SMALL_STATE(10170)] = 498472,
  [SMALL_STATE(10171)] = 498510,
  [SMALL_STATE(10172)] = 498548,
  [SMALL_STATE(10173)] = 498590,
  [SMALL_STATE(10174)] = 498634,
  [SMALL_STATE(10175)] = 498676,
  [SMALL_STATE(10176)] = 498724,
  [SMALL_STATE(10177)] = 498762,
  [SMALL_STATE(10178)] = 498804,
  [SMALL_STATE(10179)] = 498870,
  [SMALL_STATE(10180)] = 498908,
  [SMALL_STATE(10181)] = 498946,
  [SMALL_STATE(10182)] = 498984,
  [SMALL_STATE(10183)] = 499036,
  [SMALL_STATE(10184)] = 499074,
  [SMALL_STATE(10185)] = 499122,
  [SMALL_STATE(10186)] = 499160,
  [SMALL_STATE(10187)] = 499198,
  [SMALL_STATE(10188)] = 499264,
  [SMALL_STATE(10189)] = 499330,
  [SMALL_STATE(10190)] = 499368,
  [SMALL_STATE(10191)] = 499406,
  [SMALL_STATE(10192)] = 499444,
  [SMALL_STATE(10193)] = 499498,
  [SMALL_STATE(10194)] = 499564,
  [SMALL_STATE(10195)] = 499604,
  [SMALL_STATE(10196)] = 499670,
  [SMALL_STATE(10197)] = 499710,
  [SMALL_STATE(10198)] = 499758,
  [SMALL_STATE(10199)] = 499824,
  [SMALL_STATE(10200)] = 499862,
  [SMALL_STATE(10201)] = 499904,
  [SMALL_STATE(10202)] = 499942,
  [SMALL_STATE(10203)] = 499980,
  [SMALL_STATE(10204)] = 500034,
  [SMALL_STATE(10205)] = 500072,
  [SMALL_STATE(10206)] = 500110,
  [SMALL_STATE(10207)] = 500162,
  [SMALL_STATE(10208)] = 500214,
  [SMALL_STATE(10209)] = 500266,
  [SMALL_STATE(10210)] = 500304,
  [SMALL_STATE(10211)] = 500352,
  [SMALL_STATE(10212)] = 500394,
  [SMALL_STATE(10213)] = 500460,
  [SMALL_STATE(10214)] = 500502,
  [SMALL_STATE(10215)] = 500568,
  [SMALL_STATE(10216)] = 500606,
  [SMALL_STATE(10217)] = 500654,
  [SMALL_STATE(10218)] = 500698,
  [SMALL_STATE(10219)] = 500764,
  [SMALL_STATE(10220)] = 500806,
  [SMALL_STATE(10221)] = 500844,
  [SMALL_STATE(10222)] = 500892,
  [SMALL_STATE(10223)] = 500958,
  [SMALL_STATE(10224)] = 501024,
  [SMALL_STATE(10225)] = 501086,
  [SMALL_STATE(10226)] = 501124,
  [SMALL_STATE(10227)] = 501164,
  [SMALL_STATE(10228)] = 501202,
  [SMALL_STATE(10229)] = 501268,
  [SMALL_STATE(10230)] = 501316,
  [SMALL_STATE(10231)] = 501354,
  [SMALL_STATE(10232)] = 501392,
  [SMALL_STATE(10233)] = 501440,
  [SMALL_STATE(10234)] = 501478,
  [SMALL_STATE(10235)] = 501516,
  [SMALL_STATE(10236)] = 501554,
  [SMALL_STATE(10237)] = 501592,
  [SMALL_STATE(10238)] = 501630,
  [SMALL_STATE(10239)] = 501668,
  [SMALL_STATE(10240)] = 501734,
  [SMALL_STATE(10241)] = 501782,
  [SMALL_STATE(10242)] = 501820,
  [SMALL_STATE(10243)] = 501864,
  [SMALL_STATE(10244)] = 501902,
  [SMALL_STATE(10245)] = 501940,
  [SMALL_STATE(10246)] = 502000,
  [SMALL_STATE(10247)] = 502038,
  [SMALL_STATE(10248)] = 502076,
  [SMALL_STATE(10249)] = 502114,
  [SMALL_STATE(10250)] = 502162,
  [SMALL_STATE(10251)] = 502200,
  [SMALL_STATE(10252)] = 502238,
  [SMALL_STATE(10253)] = 502304,
  [SMALL_STATE(10254)] = 502342,
  [SMALL_STATE(10255)] = 502380,
  [SMALL_STATE(10256)] = 502418,
  [SMALL_STATE(10257)] = 502456,
  [SMALL_STATE(10258)] = 502494,
  [SMALL_STATE(10259)] = 502532,
  [SMALL_STATE(10260)] = 502570,
  [SMALL_STATE(10261)] = 502608,
  [SMALL_STATE(10262)] = 502646,
  [SMALL_STATE(10263)] = 502686,
  [SMALL_STATE(10264)] = 502728,
  [SMALL_STATE(10265)] = 502770,
  [SMALL_STATE(10266)] = 502836,
  [SMALL_STATE(10267)] = 502874,
  [SMALL_STATE(10268)] = 502912,
  [SMALL_STATE(10269)] = 502952,
  [SMALL_STATE(10270)] = 502990,
  [SMALL_STATE(10271)] = 503038,
  [SMALL_STATE(10272)] = 503094,
  [SMALL_STATE(10273)] = 503142,
  [SMALL_STATE(10274)] = 503184,
  [SMALL_STATE(10275)] = 503222,
  [SMALL_STATE(10276)] = 503264,
  [SMALL_STATE(10277)] = 503314,
  [SMALL_STATE(10278)] = 503354,
  [SMALL_STATE(10279)] = 503392,
  [SMALL_STATE(10280)] = 503440,
  [SMALL_STATE(10281)] = 503478,
  [SMALL_STATE(10282)] = 503528,
  [SMALL_STATE(10283)] = 503566,
  [SMALL_STATE(10284)] = 503604,
  [SMALL_STATE(10285)] = 503642,
  [SMALL_STATE(10286)] = 503680,
  [SMALL_STATE(10287)] = 503718,
  [SMALL_STATE(10288)] = 503756,
  [SMALL_STATE(10289)] = 503796,
  [SMALL_STATE(10290)] = 503834,
  [SMALL_STATE(10291)] = 503872,
  [SMALL_STATE(10292)] = 503910,
  [SMALL_STATE(10293)] = 503950,
  [SMALL_STATE(10294)] = 503988,
  [SMALL_STATE(10295)] = 504030,
  [SMALL_STATE(10296)] = 504070,
  [SMALL_STATE(10297)] = 504108,
  [SMALL_STATE(10298)] = 504156,
  [SMALL_STATE(10299)] = 504206,
  [SMALL_STATE(10300)] = 504248,
  [SMALL_STATE(10301)] = 504302,
  [SMALL_STATE(10302)] = 504358,
  [SMALL_STATE(10303)] = 504398,
  [SMALL_STATE(10304)] = 504436,
  [SMALL_STATE(10305)] = 504474,
  [SMALL_STATE(10306)] = 504522,
  [SMALL_STATE(10307)] = 504560,
  [SMALL_STATE(10308)] = 504598,
  [SMALL_STATE(10309)] = 504636,
  [SMALL_STATE(10310)] = 504684,
  [SMALL_STATE(10311)] = 504744,
  [SMALL_STATE(10312)] = 504792,
  [SMALL_STATE(10313)] = 504830,
  [SMALL_STATE(10314)] = 504878,
  [SMALL_STATE(10315)] = 504922,
  [SMALL_STATE(10316)] = 504982,
  [SMALL_STATE(10317)] = 505036,
  [SMALL_STATE(10318)] = 505078,
  [SMALL_STATE(10319)] = 505120,
  [SMALL_STATE(10320)] = 505158,
  [SMALL_STATE(10321)] = 505210,
  [SMALL_STATE(10322)] = 505248,
  [SMALL_STATE(10323)] = 505302,
  [SMALL_STATE(10324)] = 505350,
  [SMALL_STATE(10325)] = 505398,
  [SMALL_STATE(10326)] = 505436,
  [SMALL_STATE(10327)] = 505474,
  [SMALL_STATE(10328)] = 505512,
  [SMALL_STATE(10329)] = 505550,
  [SMALL_STATE(10330)] = 505588,
  [SMALL_STATE(10331)] = 505626,
  [SMALL_STATE(10332)] = 505668,
  [SMALL_STATE(10333)] = 505706,
  [SMALL_STATE(10334)] = 505748,
  [SMALL_STATE(10335)] = 505808,
  [SMALL_STATE(10336)] = 505852,
  [SMALL_STATE(10337)] = 505896,
  [SMALL_STATE(10338)] = 505962,
  [SMALL_STATE(10339)] = 506004,
  [SMALL_STATE(10340)] = 506046,
  [SMALL_STATE(10341)] = 506084,
  [SMALL_STATE(10342)] = 506122,
  [SMALL_STATE(10343)] = 506164,
  [SMALL_STATE(10344)] = 506202,
  [SMALL_STATE(10345)] = 506250,
  [SMALL_STATE(10346)] = 506292,
  [SMALL_STATE(10347)] = 506344,
  [SMALL_STATE(10348)] = 506398,
  [SMALL_STATE(10349)] = 506464,
  [SMALL_STATE(10350)] = 506502,
  [SMALL_STATE(10351)] = 506540,
  [SMALL_STATE(10352)] = 506578,
  [SMALL_STATE(10353)] = 506644,
  [SMALL_STATE(10354)] = 506681,
  [SMALL_STATE(10355)] = 506718,
  [SMALL_STATE(10356)] = 506765,
  [SMALL_STATE(10357)] = 506812,
  [SMALL_STATE(10358)] = 506859,
  [SMALL_STATE(10359)] = 506896,
  [SMALL_STATE(10360)] = 506939,
  [SMALL_STATE(10361)] = 506976,
  [SMALL_STATE(10362)] = 507013,
  [SMALL_STATE(10363)] = 507054,
  [SMALL_STATE(10364)] = 507117,
  [SMALL_STATE(10365)] = 507158,
  [SMALL_STATE(10366)] = 507201,
  [SMALL_STATE(10367)] = 507242,
  [SMALL_STATE(10368)] = 507279,
  [SMALL_STATE(10369)] = 507322,
  [SMALL_STATE(10370)] = 507359,
  [SMALL_STATE(10371)] = 507422,
  [SMALL_STATE(10372)] = 507459,
  [SMALL_STATE(10373)] = 507502,
  [SMALL_STATE(10374)] = 507545,
  [SMALL_STATE(10375)] = 507608,
  [SMALL_STATE(10376)] = 507651,
  [SMALL_STATE(10377)] = 507694,
  [SMALL_STATE(10378)] = 507737,
  [SMALL_STATE(10379)] = 507778,
  [SMALL_STATE(10380)] = 507817,
  [SMALL_STATE(10381)] = 507860,
  [SMALL_STATE(10382)] = 507897,
  [SMALL_STATE(10383)] = 507940,
  [SMALL_STATE(10384)] = 507983,
  [SMALL_STATE(10385)] = 508026,
  [SMALL_STATE(10386)] = 508089,
  [SMALL_STATE(10387)] = 508132,
  [SMALL_STATE(10388)] = 508175,
  [SMALL_STATE(10389)] = 508238,
  [SMALL_STATE(10390)] = 508285,
  [SMALL_STATE(10391)] = 508328,
  [SMALL_STATE(10392)] = 508371,
  [SMALL_STATE(10393)] = 508414,
  [SMALL_STATE(10394)] = 508453,
  [SMALL_STATE(10395)] = 508494,
  [SMALL_STATE(10396)] = 508537,
  [SMALL_STATE(10397)] = 508580,
  [SMALL_STATE(10398)] = 508623,
  [SMALL_STATE(10399)] = 508672,
  [SMALL_STATE(10400)] = 508715,
  [SMALL_STATE(10401)] = 508752,
  [SMALL_STATE(10402)] = 508791,
  [SMALL_STATE(10403)] = 508854,
  [SMALL_STATE(10404)] = 508903,
  [SMALL_STATE(10405)] = 508966,
  [SMALL_STATE(10406)] = 509009,
  [SMALL_STATE(10407)] = 509052,
  [SMALL_STATE(10408)] = 509095,
  [SMALL_STATE(10409)] = 509138,
  [SMALL_STATE(10410)] = 509181,
  [SMALL_STATE(10411)] = 509224,
  [SMALL_STATE(10412)] = 509267,
  [SMALL_STATE(10413)] = 509308,
  [SMALL_STATE(10414)] = 509345,
  [SMALL_STATE(10415)] = 509388,
  [SMALL_STATE(10416)] = 509431,
  [SMALL_STATE(10417)] = 509474,
  [SMALL_STATE(10418)] = 509517,
  [SMALL_STATE(10419)] = 509564,
  [SMALL_STATE(10420)] = 509607,
  [SMALL_STATE(10421)] = 509650,
  [SMALL_STATE(10422)] = 509697,
  [SMALL_STATE(10423)] = 509740,
  [SMALL_STATE(10424)] = 509783,
  [SMALL_STATE(10425)] = 509826,
  [SMALL_STATE(10426)] = 509869,
  [SMALL_STATE(10427)] = 509912,
  [SMALL_STATE(10428)] = 509949,
  [SMALL_STATE(10429)] = 510012,
  [SMALL_STATE(10430)] = 510061,
  [SMALL_STATE(10431)] = 510102,
  [SMALL_STATE(10432)] = 510141,
  [SMALL_STATE(10433)] = 510184,
  [SMALL_STATE(10434)] = 510227,
  [SMALL_STATE(10435)] = 510270,
  [SMALL_STATE(10436)] = 510313,
  [SMALL_STATE(10437)] = 510356,
  [SMALL_STATE(10438)] = 510403,
  [SMALL_STATE(10439)] = 510444,
  [SMALL_STATE(10440)] = 510487,
  [SMALL_STATE(10441)] = 510536,
  [SMALL_STATE(10442)] = 510573,
  [SMALL_STATE(10443)] = 510614,
  [SMALL_STATE(10444)] = 510657,
  [SMALL_STATE(10445)] = 510700,
  [SMALL_STATE(10446)] = 510763,
  [SMALL_STATE(10447)] = 510804,
  [SMALL_STATE(10448)] = 510867,
  [SMALL_STATE(10449)] = 510930,
  [SMALL_STATE(10450)] = 510979,
  [SMALL_STATE(10451)] = 511042,
  [SMALL_STATE(10452)] = 511085,
  [SMALL_STATE(10453)] = 511132,
  [SMALL_STATE(10454)] = 511171,
  [SMALL_STATE(10455)] = 511218,
  [SMALL_STATE(10456)] = 511267,
  [SMALL_STATE(10457)] = 511304,
  [SMALL_STATE(10458)] = 511367,
  [SMALL_STATE(10459)] = 511404,
  [SMALL_STATE(10460)] = 511441,
  [SMALL_STATE(10461)] = 511478,
  [SMALL_STATE(10462)] = 511517,
  [SMALL_STATE(10463)] = 511554,
  [SMALL_STATE(10464)] = 511597,
  [SMALL_STATE(10465)] = 511644,
  [SMALL_STATE(10466)] = 511687,
  [SMALL_STATE(10467)] = 511730,
  [SMALL_STATE(10468)] = 511793,
  [SMALL_STATE(10469)] = 511830,
  [SMALL_STATE(10470)] = 511867,
  [SMALL_STATE(10471)] = 511904,
  [SMALL_STATE(10472)] = 511941,
  [SMALL_STATE(10473)] = 511984,
  [SMALL_STATE(10474)] = 512021,
  [SMALL_STATE(10475)] = 512058,
  [SMALL_STATE(10476)] = 512101,
  [SMALL_STATE(10477)] = 512144,
  [SMALL_STATE(10478)] = 512181,
  [SMALL_STATE(10479)] = 512224,
  [SMALL_STATE(10480)] = 512271,
  [SMALL_STATE(10481)] = 512334,
  [SMALL_STATE(10482)] = 512397,
  [SMALL_STATE(10483)] = 512436,
  [SMALL_STATE(10484)] = 512477,
  [SMALL_STATE(10485)] = 512540,
  [SMALL_STATE(10486)] = 512583,
  [SMALL_STATE(10487)] = 512626,
  [SMALL_STATE(10488)] = 512689,
  [SMALL_STATE(10489)] = 512726,
  [SMALL_STATE(10490)] = 512777,
  [SMALL_STATE(10491)] = 512820,
  [SMALL_STATE(10492)] = 512881,
  [SMALL_STATE(10493)] = 512918,
  [SMALL_STATE(10494)] = 512955,
  [SMALL_STATE(10495)] = 513018,
  [SMALL_STATE(10496)] = 513061,
  [SMALL_STATE(10497)] = 513098,
  [SMALL_STATE(10498)] = 513141,
  [SMALL_STATE(10499)] = 513182,
  [SMALL_STATE(10500)] = 513225,
  [SMALL_STATE(10501)] = 513268,
  [SMALL_STATE(10502)] = 513311,
  [SMALL_STATE(10503)] = 513354,
  [SMALL_STATE(10504)] = 513417,
  [SMALL_STATE(10505)] = 513480,
  [SMALL_STATE(10506)] = 513527,
  [SMALL_STATE(10507)] = 513570,
  [SMALL_STATE(10508)] = 513613,
  [SMALL_STATE(10509)] = 513666,
  [SMALL_STATE(10510)] = 513729,
  [SMALL_STATE(10511)] = 513766,
  [SMALL_STATE(10512)] = 513815,
  [SMALL_STATE(10513)] = 513874,
  [SMALL_STATE(10514)] = 513937,
  [SMALL_STATE(10515)] = 513978,
  [SMALL_STATE(10516)] = 514041,
  [SMALL_STATE(10517)] = 514090,
  [SMALL_STATE(10518)] = 514153,
  [SMALL_STATE(10519)] = 514202,
  [SMALL_STATE(10520)] = 514239,
  [SMALL_STATE(10521)] = 514288,
  [SMALL_STATE(10522)] = 514337,
  [SMALL_STATE(10523)] = 514400,
  [SMALL_STATE(10524)] = 514459,
  [SMALL_STATE(10525)] = 514502,
  [SMALL_STATE(10526)] = 514551,
  [SMALL_STATE(10527)] = 514600,
  [SMALL_STATE(10528)] = 514649,
  [SMALL_STATE(10529)] = 514698,
  [SMALL_STATE(10530)] = 514747,
  [SMALL_STATE(10531)] = 514806,
  [SMALL_STATE(10532)] = 514865,
  [SMALL_STATE(10533)] = 514920,
  [SMALL_STATE(10534)] = 514963,
  [SMALL_STATE(10535)] = 515006,
  [SMALL_STATE(10536)] = 515043,
  [SMALL_STATE(10537)] = 515086,
  [SMALL_STATE(10538)] = 515135,
  [SMALL_STATE(10539)] = 515178,
  [SMALL_STATE(10540)] = 515227,
  [SMALL_STATE(10541)] = 515276,
  [SMALL_STATE(10542)] = 515325,
  [SMALL_STATE(10543)] = 515368,
  [SMALL_STATE(10544)] = 515417,
  [SMALL_STATE(10545)] = 515460,
  [SMALL_STATE(10546)] = 515499,
  [SMALL_STATE(10547)] = 515540,
  [SMALL_STATE(10548)] = 515577,
  [SMALL_STATE(10549)] = 515618,
  [SMALL_STATE(10550)] = 515659,
  [SMALL_STATE(10551)] = 515702,
  [SMALL_STATE(10552)] = 515745,
  [SMALL_STATE(10553)] = 515808,
  [SMALL_STATE(10554)] = 515855,
  [SMALL_STATE(10555)] = 515910,
  [SMALL_STATE(10556)] = 515951,
  [SMALL_STATE(10557)] = 516000,
  [SMALL_STATE(10558)] = 516043,
  [SMALL_STATE(10559)] = 516086,
  [SMALL_STATE(10560)] = 516135,
  [SMALL_STATE(10561)] = 516198,
  [SMALL_STATE(10562)] = 516247,
  [SMALL_STATE(10563)] = 516296,
  [SMALL_STATE(10564)] = 516343,
  [SMALL_STATE(10565)] = 516386,
  [SMALL_STATE(10566)] = 516423,
  [SMALL_STATE(10567)] = 516466,
  [SMALL_STATE(10568)] = 516529,
  [SMALL_STATE(10569)] = 516566,
  [SMALL_STATE(10570)] = 516615,
  [SMALL_STATE(10571)] = 516652,
  [SMALL_STATE(10572)] = 516695,
  [SMALL_STATE(10573)] = 516738,
  [SMALL_STATE(10574)] = 516779,
  [SMALL_STATE(10575)] = 516828,
  [SMALL_STATE(10576)] = 516875,
  [SMALL_STATE(10577)] = 516936,
  [SMALL_STATE(10578)] = 516985,
  [SMALL_STATE(10579)] = 517028,
  [SMALL_STATE(10580)] = 517069,
  [SMALL_STATE(10581)] = 517112,
  [SMALL_STATE(10582)] = 517161,
  [SMALL_STATE(10583)] = 517224,
  [SMALL_STATE(10584)] = 517263,
  [SMALL_STATE(10585)] = 517306,
  [SMALL_STATE(10586)] = 517343,
  [SMALL_STATE(10587)] = 517406,
  [SMALL_STATE(10588)] = 517445,
  [SMALL_STATE(10589)] = 517488,
  [SMALL_STATE(10590)] = 517547,
  [SMALL_STATE(10591)] = 517584,
  [SMALL_STATE(10592)] = 517625,
  [SMALL_STATE(10593)] = 517672,
  [SMALL_STATE(10594)] = 517721,
  [SMALL_STATE(10595)] = 517768,
  [SMALL_STATE(10596)] = 517817,
  [SMALL_STATE(10597)] = 517860,
  [SMALL_STATE(10598)] = 517909,
  [SMALL_STATE(10599)] = 517968,
  [SMALL_STATE(10600)] = 518011,
  [SMALL_STATE(10601)] = 518070,
  [SMALL_STATE(10602)] = 518133,
  [SMALL_STATE(10603)] = 518180,
  [SMALL_STATE(10604)] = 518235,
  [SMALL_STATE(10605)] = 518272,
  [SMALL_STATE(10606)] = 518309,
  [SMALL_STATE(10607)] = 518372,
  [SMALL_STATE(10608)] = 518409,
  [SMALL_STATE(10609)] = 518458,
  [SMALL_STATE(10610)] = 518501,
  [SMALL_STATE(10611)] = 518554,
  [SMALL_STATE(10612)] = 518591,
  [SMALL_STATE(10613)] = 518640,
  [SMALL_STATE(10614)] = 518677,
  [SMALL_STATE(10615)] = 518726,
  [SMALL_STATE(10616)] = 518763,
  [SMALL_STATE(10617)] = 518812,
  [SMALL_STATE(10618)] = 518875,
  [SMALL_STATE(10619)] = 518938,
  [SMALL_STATE(10620)] = 518979,
  [SMALL_STATE(10621)] = 519018,
  [SMALL_STATE(10622)] = 519059,
  [SMALL_STATE(10623)] = 519106,
  [SMALL_STATE(10624)] = 519161,
  [SMALL_STATE(10625)] = 519200,
  [SMALL_STATE(10626)] = 519241,
  [SMALL_STATE(10627)] = 519304,
  [SMALL_STATE(10628)] = 519367,
  [SMALL_STATE(10629)] = 519420,
  [SMALL_STATE(10630)] = 519473,
  [SMALL_STATE(10631)] = 519516,
  [SMALL_STATE(10632)] = 519579,
  [SMALL_STATE(10633)] = 519622,
  [SMALL_STATE(10634)] = 519665,
  [SMALL_STATE(10635)] = 519708,
  [SMALL_STATE(10636)] = 519771,
  [SMALL_STATE(10637)] = 519808,
  [SMALL_STATE(10638)] = 519851,
  [SMALL_STATE(10639)] = 519888,
  [SMALL_STATE(10640)] = 519931,
  [SMALL_STATE(10641)] = 519972,
  [SMALL_STATE(10642)] = 520009,
  [SMALL_STATE(10643)] = 520046,
  [SMALL_STATE(10644)] = 520089,
  [SMALL_STATE(10645)] = 520126,
  [SMALL_STATE(10646)] = 520189,
  [SMALL_STATE(10647)] = 520252,
  [SMALL_STATE(10648)] = 520305,
  [SMALL_STATE(10649)] = 520342,
  [SMALL_STATE(10650)] = 520379,
  [SMALL_STATE(10651)] = 520422,
  [SMALL_STATE(10652)] = 520459,
  [SMALL_STATE(10653)] = 520502,
  [SMALL_STATE(10654)] = 520539,
  [SMALL_STATE(10655)] = 520576,
  [SMALL_STATE(10656)] = 520619,
  [SMALL_STATE(10657)] = 520656,
  [SMALL_STATE(10658)] = 520699,
  [SMALL_STATE(10659)] = 520762,
  [SMALL_STATE(10660)] = 520799,
  [SMALL_STATE(10661)] = 520836,
  [SMALL_STATE(10662)] = 520879,
  [SMALL_STATE(10663)] = 520922,
  [SMALL_STATE(10664)] = 520965,
  [SMALL_STATE(10665)] = 521014,
  [SMALL_STATE(10666)] = 521067,
  [SMALL_STATE(10667)] = 521108,
  [SMALL_STATE(10668)] = 521151,
  [SMALL_STATE(10669)] = 521194,
  [SMALL_STATE(10670)] = 521231,
  [SMALL_STATE(10671)] = 521272,
  [SMALL_STATE(10672)] = 521309,
  [SMALL_STATE(10673)] = 521346,
  [SMALL_STATE(10674)] = 521395,
  [SMALL_STATE(10675)] = 521432,
  [SMALL_STATE(10676)] = 521469,
  [SMALL_STATE(10677)] = 521532,
  [SMALL_STATE(10678)] = 521569,
  [SMALL_STATE(10679)] = 521606,
  [SMALL_STATE(10680)] = 521643,
  [SMALL_STATE(10681)] = 521680,
  [SMALL_STATE(10682)] = 521717,
  [SMALL_STATE(10683)] = 521754,
  [SMALL_STATE(10684)] = 521791,
  [SMALL_STATE(10685)] = 521834,
  [SMALL_STATE(10686)] = 521871,
  [SMALL_STATE(10687)] = 521908,
  [SMALL_STATE(10688)] = 521945,
  [SMALL_STATE(10689)] = 521982,
  [SMALL_STATE(10690)] = 522031,
  [SMALL_STATE(10691)] = 522068,
  [SMALL_STATE(10692)] = 522115,
  [SMALL_STATE(10693)] = 522178,
  [SMALL_STATE(10694)] = 522231,
  [SMALL_STATE(10695)] = 522284,
  [SMALL_STATE(10696)] = 522321,
  [SMALL_STATE(10697)] = 522358,
  [SMALL_STATE(10698)] = 522395,
  [SMALL_STATE(10699)] = 522432,
  [SMALL_STATE(10700)] = 522475,
  [SMALL_STATE(10701)] = 522538,
  [SMALL_STATE(10702)] = 522581,
  [SMALL_STATE(10703)] = 522624,
  [SMALL_STATE(10704)] = 522667,
  [SMALL_STATE(10705)] = 522704,
  [SMALL_STATE(10706)] = 522747,
  [SMALL_STATE(10707)] = 522790,
  [SMALL_STATE(10708)] = 522826,
  [SMALL_STATE(10709)] = 522886,
  [SMALL_STATE(10710)] = 522922,
  [SMALL_STATE(10711)] = 522958,
  [SMALL_STATE(10712)] = 523004,
  [SMALL_STATE(10713)] = 523064,
  [SMALL_STATE(10714)] = 523110,
  [SMALL_STATE(10715)] = 523170,
  [SMALL_STATE(10716)] = 523230,
  [SMALL_STATE(10717)] = 523276,
  [SMALL_STATE(10718)] = 523318,
  [SMALL_STATE(10719)] = 523354,
  [SMALL_STATE(10720)] = 523392,
  [SMALL_STATE(10721)] = 523452,
  [SMALL_STATE(10722)] = 523512,
  [SMALL_STATE(10723)] = 523548,
  [SMALL_STATE(10724)] = 523608,
  [SMALL_STATE(10725)] = 523668,
  [SMALL_STATE(10726)] = 523728,
  [SMALL_STATE(10727)] = 523774,
  [SMALL_STATE(10728)] = 523820,
  [SMALL_STATE(10729)] = 523880,
  [SMALL_STATE(10730)] = 523926,
  [SMALL_STATE(10731)] = 523986,
  [SMALL_STATE(10732)] = 524032,
  [SMALL_STATE(10733)] = 524092,
  [SMALL_STATE(10734)] = 524134,
  [SMALL_STATE(10735)] = 524176,
  [SMALL_STATE(10736)] = 524212,
  [SMALL_STATE(10737)] = 524250,
  [SMALL_STATE(10738)] = 524286,
  [SMALL_STATE(10739)] = 524332,
  [SMALL_STATE(10740)] = 524368,
  [SMALL_STATE(10741)] = 524428,
  [SMALL_STATE(10742)] = 524468,
  [SMALL_STATE(10743)] = 524514,
  [SMALL_STATE(10744)] = 524550,
  [SMALL_STATE(10745)] = 524610,
  [SMALL_STATE(10746)] = 524650,
  [SMALL_STATE(10747)] = 524710,
  [SMALL_STATE(10748)] = 524768,
  [SMALL_STATE(10749)] = 524804,
  [SMALL_STATE(10750)] = 524864,
  [SMALL_STATE(10751)] = 524924,
  [SMALL_STATE(10752)] = 524960,
  [SMALL_STATE(10753)] = 524996,
  [SMALL_STATE(10754)] = 525032,
  [SMALL_STATE(10755)] = 525092,
  [SMALL_STATE(10756)] = 525152,
  [SMALL_STATE(10757)] = 525198,
  [SMALL_STATE(10758)] = 525244,
  [SMALL_STATE(10759)] = 525280,
  [SMALL_STATE(10760)] = 525316,
  [SMALL_STATE(10761)] = 525352,
  [SMALL_STATE(10762)] = 525412,
  [SMALL_STATE(10763)] = 525448,
  [SMALL_STATE(10764)] = 525484,
  [SMALL_STATE(10765)] = 525544,
  [SMALL_STATE(10766)] = 525604,
  [SMALL_STATE(10767)] = 525664,
  [SMALL_STATE(10768)] = 525724,
  [SMALL_STATE(10769)] = 525764,
  [SMALL_STATE(10770)] = 525800,
  [SMALL_STATE(10771)] = 525850,
  [SMALL_STATE(10772)] = 525910,
  [SMALL_STATE(10773)] = 525952,
  [SMALL_STATE(10774)] = 526012,
  [SMALL_STATE(10775)] = 526048,
  [SMALL_STATE(10776)] = 526090,
  [SMALL_STATE(10777)] = 526126,
  [SMALL_STATE(10778)] = 526162,
  [SMALL_STATE(10779)] = 526202,
  [SMALL_STATE(10780)] = 526238,
  [SMALL_STATE(10781)] = 526274,
  [SMALL_STATE(10782)] = 526310,
  [SMALL_STATE(10783)] = 526370,
  [SMALL_STATE(10784)] = 526410,
  [SMALL_STATE(10785)] = 526446,
  [SMALL_STATE(10786)] = 526482,
  [SMALL_STATE(10787)] = 526518,
  [SMALL_STATE(10788)] = 526578,
  [SMALL_STATE(10789)] = 526620,
  [SMALL_STATE(10790)] = 526680,
  [SMALL_STATE(10791)] = 526716,
  [SMALL_STATE(10792)] = 526752,
  [SMALL_STATE(10793)] = 526788,
  [SMALL_STATE(10794)] = 526824,
  [SMALL_STATE(10795)] = 526870,
  [SMALL_STATE(10796)] = 526906,
  [SMALL_STATE(10797)] = 526952,
  [SMALL_STATE(10798)] = 526988,
  [SMALL_STATE(10799)] = 527024,
  [SMALL_STATE(10800)] = 527064,
  [SMALL_STATE(10801)] = 527124,
  [SMALL_STATE(10802)] = 527164,
  [SMALL_STATE(10803)] = 527200,
  [SMALL_STATE(10804)] = 527236,
  [SMALL_STATE(10805)] = 527296,
  [SMALL_STATE(10806)] = 527334,
  [SMALL_STATE(10807)] = 527394,
  [SMALL_STATE(10808)] = 527430,
  [SMALL_STATE(10809)] = 527490,
  [SMALL_STATE(10810)] = 527550,
  [SMALL_STATE(10811)] = 527586,
  [SMALL_STATE(10812)] = 527646,
  [SMALL_STATE(10813)] = 527706,
  [SMALL_STATE(10814)] = 527766,
  [SMALL_STATE(10815)] = 527812,
  [SMALL_STATE(10816)] = 527850,
  [SMALL_STATE(10817)] = 527896,
  [SMALL_STATE(10818)] = 527932,
  [SMALL_STATE(10819)] = 527968,
  [SMALL_STATE(10820)] = 528010,
  [SMALL_STATE(10821)] = 528052,
  [SMALL_STATE(10822)] = 528098,
  [SMALL_STATE(10823)] = 528140,
  [SMALL_STATE(10824)] = 528200,
  [SMALL_STATE(10825)] = 528236,
  [SMALL_STATE(10826)] = 528272,
  [SMALL_STATE(10827)] = 528308,
  [SMALL_STATE(10828)] = 528354,
  [SMALL_STATE(10829)] = 528414,
  [SMALL_STATE(10830)] = 528450,
  [SMALL_STATE(10831)] = 528486,
  [SMALL_STATE(10832)] = 528522,
  [SMALL_STATE(10833)] = 528558,
  [SMALL_STATE(10834)] = 528594,
  [SMALL_STATE(10835)] = 528632,
  [SMALL_STATE(10836)] = 528678,
  [SMALL_STATE(10837)] = 528724,
  [SMALL_STATE(10838)] = 528784,
  [SMALL_STATE(10839)] = 528820,
  [SMALL_STATE(10840)] = 528856,
  [SMALL_STATE(10841)] = 528892,
  [SMALL_STATE(10842)] = 528928,
  [SMALL_STATE(10843)] = 528964,
  [SMALL_STATE(10844)] = 529024,
  [SMALL_STATE(10845)] = 529060,
  [SMALL_STATE(10846)] = 529120,
  [SMALL_STATE(10847)] = 529156,
  [SMALL_STATE(10848)] = 529192,
  [SMALL_STATE(10849)] = 529228,
  [SMALL_STATE(10850)] = 529274,
  [SMALL_STATE(10851)] = 529310,
  [SMALL_STATE(10852)] = 529346,
  [SMALL_STATE(10853)] = 529382,
  [SMALL_STATE(10854)] = 529422,
  [SMALL_STATE(10855)] = 529458,
  [SMALL_STATE(10856)] = 529494,
  [SMALL_STATE(10857)] = 529532,
  [SMALL_STATE(10858)] = 529568,
  [SMALL_STATE(10859)] = 529608,
  [SMALL_STATE(10860)] = 529668,
  [SMALL_STATE(10861)] = 529728,
  [SMALL_STATE(10862)] = 529764,
  [SMALL_STATE(10863)] = 529824,
  [SMALL_STATE(10864)] = 529870,
  [SMALL_STATE(10865)] = 529906,
  [SMALL_STATE(10866)] = 529966,
  [SMALL_STATE(10867)] = 530006,
  [SMALL_STATE(10868)] = 530042,
  [SMALL_STATE(10869)] = 530102,
  [SMALL_STATE(10870)] = 530138,
  [SMALL_STATE(10871)] = 530178,
  [SMALL_STATE(10872)] = 530238,
  [SMALL_STATE(10873)] = 530274,
  [SMALL_STATE(10874)] = 530310,
  [SMALL_STATE(10875)] = 530352,
  [SMALL_STATE(10876)] = 530412,
  [SMALL_STATE(10877)] = 530472,
  [SMALL_STATE(10878)] = 530508,
  [SMALL_STATE(10879)] = 530544,
  [SMALL_STATE(10880)] = 530580,
  [SMALL_STATE(10881)] = 530626,
  [SMALL_STATE(10882)] = 530662,
  [SMALL_STATE(10883)] = 530708,
  [SMALL_STATE(10884)] = 530768,
  [SMALL_STATE(10885)] = 530814,
  [SMALL_STATE(10886)] = 530850,
  [SMALL_STATE(10887)] = 530886,
  [SMALL_STATE(10888)] = 530922,
  [SMALL_STATE(10889)] = 530958,
  [SMALL_STATE(10890)] = 531000,
  [SMALL_STATE(10891)] = 531060,
  [SMALL_STATE(10892)] = 531096,
  [SMALL_STATE(10893)] = 531132,
  [SMALL_STATE(10894)] = 531168,
  [SMALL_STATE(10895)] = 531228,
  [SMALL_STATE(10896)] = 531274,
  [SMALL_STATE(10897)] = 531320,
  [SMALL_STATE(10898)] = 531380,
  [SMALL_STATE(10899)] = 531422,
  [SMALL_STATE(10900)] = 531458,
  [SMALL_STATE(10901)] = 531498,
  [SMALL_STATE(10902)] = 531534,
  [SMALL_STATE(10903)] = 531570,
  [SMALL_STATE(10904)] = 531606,
  [SMALL_STATE(10905)] = 531642,
  [SMALL_STATE(10906)] = 531678,
  [SMALL_STATE(10907)] = 531718,
  [SMALL_STATE(10908)] = 531754,
  [SMALL_STATE(10909)] = 531800,
  [SMALL_STATE(10910)] = 531842,
  [SMALL_STATE(10911)] = 531882,
  [SMALL_STATE(10912)] = 531942,
  [SMALL_STATE(10913)] = 531978,
  [SMALL_STATE(10914)] = 532020,
  [SMALL_STATE(10915)] = 532056,
  [SMALL_STATE(10916)] = 532098,
  [SMALL_STATE(10917)] = 532134,
  [SMALL_STATE(10918)] = 532170,
  [SMALL_STATE(10919)] = 532206,
  [SMALL_STATE(10920)] = 532248,
  [SMALL_STATE(10921)] = 532290,
  [SMALL_STATE(10922)] = 532326,
  [SMALL_STATE(10923)] = 532362,
  [SMALL_STATE(10924)] = 532398,
  [SMALL_STATE(10925)] = 532434,
  [SMALL_STATE(10926)] = 532494,
  [SMALL_STATE(10927)] = 532530,
  [SMALL_STATE(10928)] = 532590,
  [SMALL_STATE(10929)] = 532632,
  [SMALL_STATE(10930)] = 532692,
  [SMALL_STATE(10931)] = 532738,
  [SMALL_STATE(10932)] = 532776,
  [SMALL_STATE(10933)] = 532812,
  [SMALL_STATE(10934)] = 532852,
  [SMALL_STATE(10935)] = 532888,
  [SMALL_STATE(10936)] = 532924,
  [SMALL_STATE(10937)] = 532984,
  [SMALL_STATE(10938)] = 533026,
  [SMALL_STATE(10939)] = 533062,
  [SMALL_STATE(10940)] = 533098,
  [SMALL_STATE(10941)] = 533158,
  [SMALL_STATE(10942)] = 533204,
  [SMALL_STATE(10943)] = 533240,
  [SMALL_STATE(10944)] = 533288,
  [SMALL_STATE(10945)] = 533324,
  [SMALL_STATE(10946)] = 533370,
  [SMALL_STATE(10947)] = 533406,
  [SMALL_STATE(10948)] = 533452,
  [SMALL_STATE(10949)] = 533488,
  [SMALL_STATE(10950)] = 533528,
  [SMALL_STATE(10951)] = 533564,
  [SMALL_STATE(10952)] = 533624,
  [SMALL_STATE(10953)] = 533660,
  [SMALL_STATE(10954)] = 533696,
  [SMALL_STATE(10955)] = 533738,
  [SMALL_STATE(10956)] = 533780,
  [SMALL_STATE(10957)] = 533816,
  [SMALL_STATE(10958)] = 533852,
  [SMALL_STATE(10959)] = 533898,
  [SMALL_STATE(10960)] = 533934,
  [SMALL_STATE(10961)] = 533970,
  [SMALL_STATE(10962)] = 534006,
  [SMALL_STATE(10963)] = 534060,
  [SMALL_STATE(10964)] = 534096,
  [SMALL_STATE(10965)] = 534144,
  [SMALL_STATE(10966)] = 534204,
  [SMALL_STATE(10967)] = 534240,
  [SMALL_STATE(10968)] = 534286,
  [SMALL_STATE(10969)] = 534322,
  [SMALL_STATE(10970)] = 534358,
  [SMALL_STATE(10971)] = 534394,
  [SMALL_STATE(10972)] = 534430,
  [SMALL_STATE(10973)] = 534470,
  [SMALL_STATE(10974)] = 534510,
  [SMALL_STATE(10975)] = 534548,
  [SMALL_STATE(10976)] = 534584,
  [SMALL_STATE(10977)] = 534644,
  [SMALL_STATE(10978)] = 534704,
  [SMALL_STATE(10979)] = 534744,
  [SMALL_STATE(10980)] = 534782,
  [SMALL_STATE(10981)] = 534828,
  [SMALL_STATE(10982)] = 534888,
  [SMALL_STATE(10983)] = 534948,
  [SMALL_STATE(10984)] = 534988,
  [SMALL_STATE(10985)] = 535028,
  [SMALL_STATE(10986)] = 535076,
  [SMALL_STATE(10987)] = 535124,
  [SMALL_STATE(10988)] = 535164,
  [SMALL_STATE(10989)] = 535210,
  [SMALL_STATE(10990)] = 535262,
  [SMALL_STATE(10991)] = 535316,
  [SMALL_STATE(10992)] = 535374,
  [SMALL_STATE(10993)] = 535416,
  [SMALL_STATE(10994)] = 535462,
  [SMALL_STATE(10995)] = 535498,
  [SMALL_STATE(10996)] = 535556,
  [SMALL_STATE(10997)] = 535596,
  [SMALL_STATE(10998)] = 535638,
  [SMALL_STATE(10999)] = 535698,
  [SMALL_STATE(11000)] = 535737,
  [SMALL_STATE(11001)] = 535780,
  [SMALL_STATE(11002)] = 535823,
  [SMALL_STATE(11003)] = 535866,
  [SMALL_STATE(11004)] = 535907,
  [SMALL_STATE(11005)] = 535948,
  [SMALL_STATE(11006)] = 535991,
  [SMALL_STATE(11007)] = 536026,
  [SMALL_STATE(11008)] = 536083,
  [SMALL_STATE(11009)] = 536126,
  [SMALL_STATE(11010)] = 536167,
  [SMALL_STATE(11011)] = 536202,
  [SMALL_STATE(11012)] = 536239,
  [SMALL_STATE(11013)] = 536296,
  [SMALL_STATE(11014)] = 536331,
  [SMALL_STATE(11015)] = 536388,
  [SMALL_STATE(11016)] = 536427,
  [SMALL_STATE(11017)] = 536484,
  [SMALL_STATE(11018)] = 536519,
  [SMALL_STATE(11019)] = 536554,
  [SMALL_STATE(11020)] = 536599,
  [SMALL_STATE(11021)] = 536656,
  [SMALL_STATE(11022)] = 536713,
  [SMALL_STATE(11023)] = 536748,
  [SMALL_STATE(11024)] = 536787,
  [SMALL_STATE(11025)] = 536822,
  [SMALL_STATE(11026)] = 536861,
  [SMALL_STATE(11027)] = 536896,
  [SMALL_STATE(11028)] = 536931,
  [SMALL_STATE(11029)] = 536988,
  [SMALL_STATE(11030)] = 537033,
  [SMALL_STATE(11031)] = 537090,
  [SMALL_STATE(11032)] = 537125,
  [SMALL_STATE(11033)] = 537160,
  [SMALL_STATE(11034)] = 537205,
  [SMALL_STATE(11035)] = 537240,
  [SMALL_STATE(11036)] = 537297,
  [SMALL_STATE(11037)] = 537342,
  [SMALL_STATE(11038)] = 537387,
  [SMALL_STATE(11039)] = 537422,
  [SMALL_STATE(11040)] = 537467,
  [SMALL_STATE(11041)] = 537502,
  [SMALL_STATE(11042)] = 537541,
  [SMALL_STATE(11043)] = 537576,
  [SMALL_STATE(11044)] = 537613,
  [SMALL_STATE(11045)] = 537652,
  [SMALL_STATE(11046)] = 537709,
  [SMALL_STATE(11047)] = 537766,
  [SMALL_STATE(11048)] = 537805,
  [SMALL_STATE(11049)] = 537862,
  [SMALL_STATE(11050)] = 537903,
  [SMALL_STATE(11051)] = 537960,
  [SMALL_STATE(11052)] = 538017,
  [SMALL_STATE(11053)] = 538062,
  [SMALL_STATE(11054)] = 538101,
  [SMALL_STATE(11055)] = 538158,
  [SMALL_STATE(11056)] = 538201,
  [SMALL_STATE(11057)] = 538240,
  [SMALL_STATE(11058)] = 538279,
  [SMALL_STATE(11059)] = 538314,
  [SMALL_STATE(11060)] = 538371,
  [SMALL_STATE(11061)] = 538416,
  [SMALL_STATE(11062)] = 538473,
  [SMALL_STATE(11063)] = 538518,
  [SMALL_STATE(11064)] = 538563,
  [SMALL_STATE(11065)] = 538602,
  [SMALL_STATE(11066)] = 538659,
  [SMALL_STATE(11067)] = 538698,
  [SMALL_STATE(11068)] = 538755,
  [SMALL_STATE(11069)] = 538800,
  [SMALL_STATE(11070)] = 538843,
  [SMALL_STATE(11071)] = 538888,
  [SMALL_STATE(11072)] = 538923,
  [SMALL_STATE(11073)] = 538958,
  [SMALL_STATE(11074)] = 538995,
  [SMALL_STATE(11075)] = 539038,
  [SMALL_STATE(11076)] = 539095,
  [SMALL_STATE(11077)] = 539132,
  [SMALL_STATE(11078)] = 539171,
  [SMALL_STATE(11079)] = 539228,
  [SMALL_STATE(11080)] = 539273,
  [SMALL_STATE(11081)] = 539310,
  [SMALL_STATE(11082)] = 539351,
  [SMALL_STATE(11083)] = 539390,
  [SMALL_STATE(11084)] = 539425,
  [SMALL_STATE(11085)] = 539482,
  [SMALL_STATE(11086)] = 539539,
  [SMALL_STATE(11087)] = 539596,
  [SMALL_STATE(11088)] = 539635,
  [SMALL_STATE(11089)] = 539670,
  [SMALL_STATE(11090)] = 539705,
  [SMALL_STATE(11091)] = 539762,
  [SMALL_STATE(11092)] = 539797,
  [SMALL_STATE(11093)] = 539836,
  [SMALL_STATE(11094)] = 539881,
  [SMALL_STATE(11095)] = 539916,
  [SMALL_STATE(11096)] = 539961,
  [SMALL_STATE(11097)] = 539996,
  [SMALL_STATE(11098)] = 540041,
  [SMALL_STATE(11099)] = 540086,
  [SMALL_STATE(11100)] = 540127,
  [SMALL_STATE(11101)] = 540162,
  [SMALL_STATE(11102)] = 540199,
  [SMALL_STATE(11103)] = 540244,
  [SMALL_STATE(11104)] = 540301,
  [SMALL_STATE(11105)] = 540346,
  [SMALL_STATE(11106)] = 540403,
  [SMALL_STATE(11107)] = 540438,
  [SMALL_STATE(11108)] = 540483,
  [SMALL_STATE(11109)] = 540526,
  [SMALL_STATE(11110)] = 540569,
  [SMALL_STATE(11111)] = 540604,
  [SMALL_STATE(11112)] = 540639,
  [SMALL_STATE(11113)] = 540682,
  [SMALL_STATE(11114)] = 540739,
  [SMALL_STATE(11115)] = 540796,
  [SMALL_STATE(11116)] = 540839,
  [SMALL_STATE(11117)] = 540882,
  [SMALL_STATE(11118)] = 540921,
  [SMALL_STATE(11119)] = 540960,
  [SMALL_STATE(11120)] = 541017,
  [SMALL_STATE(11121)] = 541056,
  [SMALL_STATE(11122)] = 541113,
  [SMALL_STATE(11123)] = 541170,
  [SMALL_STATE(11124)] = 541205,
  [SMALL_STATE(11125)] = 541240,
  [SMALL_STATE(11126)] = 541279,
  [SMALL_STATE(11127)] = 541318,
  [SMALL_STATE(11128)] = 541357,
  [SMALL_STATE(11129)] = 541402,
  [SMALL_STATE(11130)] = 541459,
  [SMALL_STATE(11131)] = 541504,
  [SMALL_STATE(11132)] = 541541,
  [SMALL_STATE(11133)] = 541580,
  [SMALL_STATE(11134)] = 541617,
  [SMALL_STATE(11135)] = 541652,
  [SMALL_STATE(11136)] = 541697,
  [SMALL_STATE(11137)] = 541732,
  [SMALL_STATE(11138)] = 541771,
  [SMALL_STATE(11139)] = 541814,
  [SMALL_STATE(11140)] = 541857,
  [SMALL_STATE(11141)] = 541902,
  [SMALL_STATE(11142)] = 541937,
  [SMALL_STATE(11143)] = 541972,
  [SMALL_STATE(11144)] = 542015,
  [SMALL_STATE(11145)] = 542054,
  [SMALL_STATE(11146)] = 542111,
  [SMALL_STATE(11147)] = 542150,
  [SMALL_STATE(11148)] = 542193,
  [SMALL_STATE(11149)] = 542250,
  [SMALL_STATE(11150)] = 542289,
  [SMALL_STATE(11151)] = 542332,
  [SMALL_STATE(11152)] = 542375,
  [SMALL_STATE(11153)] = 542432,
  [SMALL_STATE(11154)] = 542471,
  [SMALL_STATE(11155)] = 542506,
  [SMALL_STATE(11156)] = 542545,
  [SMALL_STATE(11157)] = 542582,
  [SMALL_STATE(11158)] = 542639,
  [SMALL_STATE(11159)] = 542696,
  [SMALL_STATE(11160)] = 542739,
  [SMALL_STATE(11161)] = 542782,
  [SMALL_STATE(11162)] = 542827,
  [SMALL_STATE(11163)] = 542870,
  [SMALL_STATE(11164)] = 542927,
  [SMALL_STATE(11165)] = 542966,
  [SMALL_STATE(11166)] = 543001,
  [SMALL_STATE(11167)] = 543048,
  [SMALL_STATE(11168)] = 543095,
  [SMALL_STATE(11169)] = 543140,
  [SMALL_STATE(11170)] = 543197,
  [SMALL_STATE(11171)] = 543234,
  [SMALL_STATE(11172)] = 543285,
  [SMALL_STATE(11173)] = 543342,
  [SMALL_STATE(11174)] = 543399,
  [SMALL_STATE(11175)] = 543444,
  [SMALL_STATE(11176)] = 543479,
  [SMALL_STATE(11177)] = 543522,
  [SMALL_STATE(11178)] = 543561,
  [SMALL_STATE(11179)] = 543596,
  [SMALL_STATE(11180)] = 543655,
  [SMALL_STATE(11181)] = 543694,
  [SMALL_STATE(11182)] = 543751,
  [SMALL_STATE(11183)] = 543790,
  [SMALL_STATE(11184)] = 543847,
  [SMALL_STATE(11185)] = 543886,
  [SMALL_STATE(11186)] = 543939,
  [SMALL_STATE(11187)] = 543976,
  [SMALL_STATE(11188)] = 544015,
  [SMALL_STATE(11189)] = 544060,
  [SMALL_STATE(11190)] = 544103,
  [SMALL_STATE(11191)] = 544160,
  [SMALL_STATE(11192)] = 544197,
  [SMALL_STATE(11193)] = 544254,
  [SMALL_STATE(11194)] = 544293,
  [SMALL_STATE(11195)] = 544338,
  [SMALL_STATE(11196)] = 544379,
  [SMALL_STATE(11197)] = 544436,
  [SMALL_STATE(11198)] = 544471,
  [SMALL_STATE(11199)] = 544524,
  [SMALL_STATE(11200)] = 544563,
  [SMALL_STATE(11201)] = 544602,
  [SMALL_STATE(11202)] = 544659,
  [SMALL_STATE(11203)] = 544704,
  [SMALL_STATE(11204)] = 544749,
  [SMALL_STATE(11205)] = 544806,
  [SMALL_STATE(11206)] = 544863,
  [SMALL_STATE(11207)] = 544902,
  [SMALL_STATE(11208)] = 544937,
  [SMALL_STATE(11209)] = 544994,
  [SMALL_STATE(11210)] = 545032,
  [SMALL_STATE(11211)] = 545086,
  [SMALL_STATE(11212)] = 545140,
  [SMALL_STATE(11213)] = 545194,
  [SMALL_STATE(11214)] = 545248,
  [SMALL_STATE(11215)] = 545302,
  [SMALL_STATE(11216)] = 545356,
  [SMALL_STATE(11217)] = 545410,
  [SMALL_STATE(11218)] = 545464,
  [SMALL_STATE(11219)] = 545518,
  [SMALL_STATE(11220)] = 545572,
  [SMALL_STATE(11221)] = 545626,
  [SMALL_STATE(11222)] = 545680,
  [SMALL_STATE(11223)] = 545734,
  [SMALL_STATE(11224)] = 545788,
  [SMALL_STATE(11225)] = 545842,
  [SMALL_STATE(11226)] = 545896,
  [SMALL_STATE(11227)] = 545950,
  [SMALL_STATE(11228)] = 546004,
  [SMALL_STATE(11229)] = 546062,
  [SMALL_STATE(11230)] = 546116,
  [SMALL_STATE(11231)] = 546170,
  [SMALL_STATE(11232)] = 546224,
  [SMALL_STATE(11233)] = 546278,
  [SMALL_STATE(11234)] = 546332,
  [SMALL_STATE(11235)] = 546386,
  [SMALL_STATE(11236)] = 546440,
  [SMALL_STATE(11237)] = 546478,
  [SMALL_STATE(11238)] = 546532,
  [SMALL_STATE(11239)] = 546586,
  [SMALL_STATE(11240)] = 546640,
  [SMALL_STATE(11241)] = 546694,
  [SMALL_STATE(11242)] = 546748,
  [SMALL_STATE(11243)] = 546802,
  [SMALL_STATE(11244)] = 546856,
  [SMALL_STATE(11245)] = 546910,
  [SMALL_STATE(11246)] = 546964,
  [SMALL_STATE(11247)] = 547018,
  [SMALL_STATE(11248)] = 547058,
  [SMALL_STATE(11249)] = 547098,
  [SMALL_STATE(11250)] = 547152,
  [SMALL_STATE(11251)] = 547206,
  [SMALL_STATE(11252)] = 547260,
  [SMALL_STATE(11253)] = 547314,
  [SMALL_STATE(11254)] = 547354,
  [SMALL_STATE(11255)] = 547392,
  [SMALL_STATE(11256)] = 547446,
  [SMALL_STATE(11257)] = 547500,
  [SMALL_STATE(11258)] = 547554,
  [SMALL_STATE(11259)] = 547590,
  [SMALL_STATE(11260)] = 547624,
  [SMALL_STATE(11261)] = 547678,
  [SMALL_STATE(11262)] = 547732,
  [SMALL_STATE(11263)] = 547786,
  [SMALL_STATE(11264)] = 547840,
  [SMALL_STATE(11265)] = 547894,
  [SMALL_STATE(11266)] = 547948,
  [SMALL_STATE(11267)] = 548002,
  [SMALL_STATE(11268)] = 548056,
  [SMALL_STATE(11269)] = 548110,
  [SMALL_STATE(11270)] = 548164,
  [SMALL_STATE(11271)] = 548218,
  [SMALL_STATE(11272)] = 548272,
  [SMALL_STATE(11273)] = 548326,
  [SMALL_STATE(11274)] = 548380,
  [SMALL_STATE(11275)] = 548434,
  [SMALL_STATE(11276)] = 548488,
  [SMALL_STATE(11277)] = 548528,
  [SMALL_STATE(11278)] = 548582,
  [SMALL_STATE(11279)] = 548636,
  [SMALL_STATE(11280)] = 548690,
  [SMALL_STATE(11281)] = 548744,
  [SMALL_STATE(11282)] = 548798,
  [SMALL_STATE(11283)] = 548852,
  [SMALL_STATE(11284)] = 548906,
  [SMALL_STATE(11285)] = 548962,
  [SMALL_STATE(11286)] = 549018,
  [SMALL_STATE(11287)] = 549058,
  [SMALL_STATE(11288)] = 549114,
  [SMALL_STATE(11289)] = 549168,
  [SMALL_STATE(11290)] = 549220,
  [SMALL_STATE(11291)] = 549270,
  [SMALL_STATE(11292)] = 549316,
  [SMALL_STATE(11293)] = 549362,
  [SMALL_STATE(11294)] = 549400,
  [SMALL_STATE(11295)] = 549438,
  [SMALL_STATE(11296)] = 549482,
  [SMALL_STATE(11297)] = 549534,
  [SMALL_STATE(11298)] = 549588,
  [SMALL_STATE(11299)] = 549642,
  [SMALL_STATE(11300)] = 549696,
  [SMALL_STATE(11301)] = 549738,
  [SMALL_STATE(11302)] = 549792,
  [SMALL_STATE(11303)] = 549846,
  [SMALL_STATE(11304)] = 549900,
  [SMALL_STATE(11305)] = 549954,
  [SMALL_STATE(11306)] = 550008,
  [SMALL_STATE(11307)] = 550062,
  [SMALL_STATE(11308)] = 550116,
  [SMALL_STATE(11309)] = 550170,
  [SMALL_STATE(11310)] = 550224,
  [SMALL_STATE(11311)] = 550278,
  [SMALL_STATE(11312)] = 550332,
  [SMALL_STATE(11313)] = 550370,
  [SMALL_STATE(11314)] = 550410,
  [SMALL_STATE(11315)] = 550464,
  [SMALL_STATE(11316)] = 550518,
  [SMALL_STATE(11317)] = 550572,
  [SMALL_STATE(11318)] = 550626,
  [SMALL_STATE(11319)] = 550680,
  [SMALL_STATE(11320)] = 550734,
  [SMALL_STATE(11321)] = 550788,
  [SMALL_STATE(11322)] = 550842,
  [SMALL_STATE(11323)] = 550896,
  [SMALL_STATE(11324)] = 550950,
  [SMALL_STATE(11325)] = 551004,
  [SMALL_STATE(11326)] = 551058,
  [SMALL_STATE(11327)] = 551112,
  [SMALL_STATE(11328)] = 551166,
  [SMALL_STATE(11329)] = 551220,
  [SMALL_STATE(11330)] = 551274,
  [SMALL_STATE(11331)] = 551328,
  [SMALL_STATE(11332)] = 551382,
  [SMALL_STATE(11333)] = 551436,
  [SMALL_STATE(11334)] = 551490,
  [SMALL_STATE(11335)] = 551544,
  [SMALL_STATE(11336)] = 551598,
  [SMALL_STATE(11337)] = 551652,
  [SMALL_STATE(11338)] = 551706,
  [SMALL_STATE(11339)] = 551760,
  [SMALL_STATE(11340)] = 551814,
  [SMALL_STATE(11341)] = 551868,
  [SMALL_STATE(11342)] = 551922,
  [SMALL_STATE(11343)] = 551976,
  [SMALL_STATE(11344)] = 552030,
  [SMALL_STATE(11345)] = 552084,
  [SMALL_STATE(11346)] = 552138,
  [SMALL_STATE(11347)] = 552174,
  [SMALL_STATE(11348)] = 552210,
  [SMALL_STATE(11349)] = 552264,
  [SMALL_STATE(11350)] = 552302,
  [SMALL_STATE(11351)] = 552356,
  [SMALL_STATE(11352)] = 552410,
  [SMALL_STATE(11353)] = 552464,
  [SMALL_STATE(11354)] = 552518,
  [SMALL_STATE(11355)] = 552572,
  [SMALL_STATE(11356)] = 552626,
  [SMALL_STATE(11357)] = 552680,
  [SMALL_STATE(11358)] = 552734,
  [SMALL_STATE(11359)] = 552788,
  [SMALL_STATE(11360)] = 552842,
  [SMALL_STATE(11361)] = 552896,
  [SMALL_STATE(11362)] = 552950,
  [SMALL_STATE(11363)] = 553004,
  [SMALL_STATE(11364)] = 553044,
  [SMALL_STATE(11365)] = 553098,
  [SMALL_STATE(11366)] = 553152,
  [SMALL_STATE(11367)] = 553206,
  [SMALL_STATE(11368)] = 553260,
  [SMALL_STATE(11369)] = 553314,
  [SMALL_STATE(11370)] = 553368,
  [SMALL_STATE(11371)] = 553422,
  [SMALL_STATE(11372)] = 553476,
  [SMALL_STATE(11373)] = 553530,
  [SMALL_STATE(11374)] = 553584,
  [SMALL_STATE(11375)] = 553638,
  [SMALL_STATE(11376)] = 553692,
  [SMALL_STATE(11377)] = 553746,
  [SMALL_STATE(11378)] = 553800,
  [SMALL_STATE(11379)] = 553854,
  [SMALL_STATE(11380)] = 553908,
  [SMALL_STATE(11381)] = 553962,
  [SMALL_STATE(11382)] = 554016,
  [SMALL_STATE(11383)] = 554070,
  [SMALL_STATE(11384)] = 554124,
  [SMALL_STATE(11385)] = 554178,
  [SMALL_STATE(11386)] = 554232,
  [SMALL_STATE(11387)] = 554286,
  [SMALL_STATE(11388)] = 554340,
  [SMALL_STATE(11389)] = 554394,
  [SMALL_STATE(11390)] = 554448,
  [SMALL_STATE(11391)] = 554486,
  [SMALL_STATE(11392)] = 554526,
  [SMALL_STATE(11393)] = 554580,
  [SMALL_STATE(11394)] = 554634,
  [SMALL_STATE(11395)] = 554688,
  [SMALL_STATE(11396)] = 554742,
  [SMALL_STATE(11397)] = 554796,
  [SMALL_STATE(11398)] = 554850,
  [SMALL_STATE(11399)] = 554904,
  [SMALL_STATE(11400)] = 554958,
  [SMALL_STATE(11401)] = 555012,
  [SMALL_STATE(11402)] = 555066,
  [SMALL_STATE(11403)] = 555106,
  [SMALL_STATE(11404)] = 555160,
  [SMALL_STATE(11405)] = 555214,
  [SMALL_STATE(11406)] = 555268,
  [SMALL_STATE(11407)] = 555322,
  [SMALL_STATE(11408)] = 555376,
  [SMALL_STATE(11409)] = 555416,
  [SMALL_STATE(11410)] = 555470,
  [SMALL_STATE(11411)] = 555510,
  [SMALL_STATE(11412)] = 555550,
  [SMALL_STATE(11413)] = 555604,
  [SMALL_STATE(11414)] = 555658,
  [SMALL_STATE(11415)] = 555712,
  [SMALL_STATE(11416)] = 555766,
  [SMALL_STATE(11417)] = 555820,
  [SMALL_STATE(11418)] = 555860,
  [SMALL_STATE(11419)] = 555900,
  [SMALL_STATE(11420)] = 555954,
  [SMALL_STATE(11421)] = 556008,
  [SMALL_STATE(11422)] = 556062,
  [SMALL_STATE(11423)] = 556116,
  [SMALL_STATE(11424)] = 556170,
  [SMALL_STATE(11425)] = 556224,
  [SMALL_STATE(11426)] = 556278,
  [SMALL_STATE(11427)] = 556332,
  [SMALL_STATE(11428)] = 556386,
  [SMALL_STATE(11429)] = 556424,
  [SMALL_STATE(11430)] = 556478,
  [SMALL_STATE(11431)] = 556532,
  [SMALL_STATE(11432)] = 556586,
  [SMALL_STATE(11433)] = 556640,
  [SMALL_STATE(11434)] = 556680,
  [SMALL_STATE(11435)] = 556734,
  [SMALL_STATE(11436)] = 556788,
  [SMALL_STATE(11437)] = 556842,
  [SMALL_STATE(11438)] = 556896,
  [SMALL_STATE(11439)] = 556950,
  [SMALL_STATE(11440)] = 557004,
  [SMALL_STATE(11441)] = 557058,
  [SMALL_STATE(11442)] = 557112,
  [SMALL_STATE(11443)] = 557166,
  [SMALL_STATE(11444)] = 557220,
  [SMALL_STATE(11445)] = 557274,
  [SMALL_STATE(11446)] = 557328,
  [SMALL_STATE(11447)] = 557382,
  [SMALL_STATE(11448)] = 557436,
  [SMALL_STATE(11449)] = 557490,
  [SMALL_STATE(11450)] = 557544,
  [SMALL_STATE(11451)] = 557584,
  [SMALL_STATE(11452)] = 557618,
  [SMALL_STATE(11453)] = 557660,
  [SMALL_STATE(11454)] = 557698,
  [SMALL_STATE(11455)] = 557752,
  [SMALL_STATE(11456)] = 557806,
  [SMALL_STATE(11457)] = 557840,
  [SMALL_STATE(11458)] = 557894,
  [SMALL_STATE(11459)] = 557948,
  [SMALL_STATE(11460)] = 558002,
  [SMALL_STATE(11461)] = 558060,
  [SMALL_STATE(11462)] = 558114,
  [SMALL_STATE(11463)] = 558168,
  [SMALL_STATE(11464)] = 558222,
  [SMALL_STATE(11465)] = 558262,
  [SMALL_STATE(11466)] = 558316,
  [SMALL_STATE(11467)] = 558370,
  [SMALL_STATE(11468)] = 558424,
  [SMALL_STATE(11469)] = 558478,
  [SMALL_STATE(11470)] = 558532,
  [SMALL_STATE(11471)] = 558586,
  [SMALL_STATE(11472)] = 558640,
  [SMALL_STATE(11473)] = 558694,
  [SMALL_STATE(11474)] = 558748,
  [SMALL_STATE(11475)] = 558790,
  [SMALL_STATE(11476)] = 558834,
  [SMALL_STATE(11477)] = 558886,
  [SMALL_STATE(11478)] = 558930,
  [SMALL_STATE(11479)] = 558968,
  [SMALL_STATE(11480)] = 559006,
  [SMALL_STATE(11481)] = 559052,
  [SMALL_STATE(11482)] = 559098,
  [SMALL_STATE(11483)] = 559148,
  [SMALL_STATE(11484)] = 559200,
  [SMALL_STATE(11485)] = 559254,
  [SMALL_STATE(11486)] = 559310,
  [SMALL_STATE(11487)] = 559350,
  [SMALL_STATE(11488)] = 559406,
  [SMALL_STATE(11489)] = 559444,
  [SMALL_STATE(11490)] = 559488,
  [SMALL_STATE(11491)] = 559524,
  [SMALL_STATE(11492)] = 559578,
  [SMALL_STATE(11493)] = 559632,
  [SMALL_STATE(11494)] = 559688,
  [SMALL_STATE(11495)] = 559742,
  [SMALL_STATE(11496)] = 559796,
  [SMALL_STATE(11497)] = 559850,
  [SMALL_STATE(11498)] = 559904,
  [SMALL_STATE(11499)] = 559958,
  [SMALL_STATE(11500)] = 560012,
  [SMALL_STATE(11501)] = 560064,
  [SMALL_STATE(11502)] = 560118,
  [SMALL_STATE(11503)] = 560172,
  [SMALL_STATE(11504)] = 560226,
  [SMALL_STATE(11505)] = 560280,
  [SMALL_STATE(11506)] = 560334,
  [SMALL_STATE(11507)] = 560388,
  [SMALL_STATE(11508)] = 560432,
  [SMALL_STATE(11509)] = 560486,
  [SMALL_STATE(11510)] = 560540,
  [SMALL_STATE(11511)] = 560578,
  [SMALL_STATE(11512)] = 560632,
  [SMALL_STATE(11513)] = 560686,
  [SMALL_STATE(11514)] = 560740,
  [SMALL_STATE(11515)] = 560776,
  [SMALL_STATE(11516)] = 560820,
  [SMALL_STATE(11517)] = 560874,
  [SMALL_STATE(11518)] = 560918,
  [SMALL_STATE(11519)] = 560972,
  [SMALL_STATE(11520)] = 561026,
  [SMALL_STATE(11521)] = 561080,
  [SMALL_STATE(11522)] = 561134,
  [SMALL_STATE(11523)] = 561188,
  [SMALL_STATE(11524)] = 561242,
  [SMALL_STATE(11525)] = 561296,
  [SMALL_STATE(11526)] = 561350,
  [SMALL_STATE(11527)] = 561404,
  [SMALL_STATE(11528)] = 561458,
  [SMALL_STATE(11529)] = 561512,
  [SMALL_STATE(11530)] = 561566,
  [SMALL_STATE(11531)] = 561620,
  [SMALL_STATE(11532)] = 561674,
  [SMALL_STATE(11533)] = 561728,
  [SMALL_STATE(11534)] = 561782,
  [SMALL_STATE(11535)] = 561836,
  [SMALL_STATE(11536)] = 561890,
  [SMALL_STATE(11537)] = 561944,
  [SMALL_STATE(11538)] = 561980,
  [SMALL_STATE(11539)] = 562018,
  [SMALL_STATE(11540)] = 562072,
  [SMALL_STATE(11541)] = 562126,
  [SMALL_STATE(11542)] = 562180,
  [SMALL_STATE(11543)] = 562224,
  [SMALL_STATE(11544)] = 562278,
  [SMALL_STATE(11545)] = 562332,
  [SMALL_STATE(11546)] = 562386,
  [SMALL_STATE(11547)] = 562440,
  [SMALL_STATE(11548)] = 562494,
  [SMALL_STATE(11549)] = 562548,
  [SMALL_STATE(11550)] = 562602,
  [SMALL_STATE(11551)] = 562656,
  [SMALL_STATE(11552)] = 562710,
  [SMALL_STATE(11553)] = 562764,
  [SMALL_STATE(11554)] = 562802,
  [SMALL_STATE(11555)] = 562856,
  [SMALL_STATE(11556)] = 562910,
  [SMALL_STATE(11557)] = 562964,
  [SMALL_STATE(11558)] = 563002,
  [SMALL_STATE(11559)] = 563056,
  [SMALL_STATE(11560)] = 563110,
  [SMALL_STATE(11561)] = 563148,
  [SMALL_STATE(11562)] = 563202,
  [SMALL_STATE(11563)] = 563256,
  [SMALL_STATE(11564)] = 563310,
  [SMALL_STATE(11565)] = 563364,
  [SMALL_STATE(11566)] = 563418,
  [SMALL_STATE(11567)] = 563472,
  [SMALL_STATE(11568)] = 563526,
  [SMALL_STATE(11569)] = 563580,
  [SMALL_STATE(11570)] = 563618,
  [SMALL_STATE(11571)] = 563658,
  [SMALL_STATE(11572)] = 563712,
  [SMALL_STATE(11573)] = 563766,
  [SMALL_STATE(11574)] = 563806,
  [SMALL_STATE(11575)] = 563846,
  [SMALL_STATE(11576)] = 563900,
  [SMALL_STATE(11577)] = 563954,
  [SMALL_STATE(11578)] = 564008,
  [SMALL_STATE(11579)] = 564046,
  [SMALL_STATE(11580)] = 564100,
  [SMALL_STATE(11581)] = 564136,
  [SMALL_STATE(11582)] = 564190,
  [SMALL_STATE(11583)] = 564244,
  [SMALL_STATE(11584)] = 564282,
  [SMALL_STATE(11585)] = 564320,
  [SMALL_STATE(11586)] = 564374,
  [SMALL_STATE(11587)] = 564428,
  [SMALL_STATE(11588)] = 564466,
  [SMALL_STATE(11589)] = 564520,
  [SMALL_STATE(11590)] = 564558,
  [SMALL_STATE(11591)] = 564612,
  [SMALL_STATE(11592)] = 564666,
  [SMALL_STATE(11593)] = 564720,
  [SMALL_STATE(11594)] = 564774,
  [SMALL_STATE(11595)] = 564828,
  [SMALL_STATE(11596)] = 564866,
  [SMALL_STATE(11597)] = 564920,
  [SMALL_STATE(11598)] = 564974,
  [SMALL_STATE(11599)] = 565028,
  [SMALL_STATE(11600)] = 565082,
  [SMALL_STATE(11601)] = 565120,
  [SMALL_STATE(11602)] = 565174,
  [SMALL_STATE(11603)] = 565228,
  [SMALL_STATE(11604)] = 565284,
  [SMALL_STATE(11605)] = 565338,
  [SMALL_STATE(11606)] = 565392,
  [SMALL_STATE(11607)] = 565446,
  [SMALL_STATE(11608)] = 565500,
  [SMALL_STATE(11609)] = 565554,
  [SMALL_STATE(11610)] = 565608,
  [SMALL_STATE(11611)] = 565662,
  [SMALL_STATE(11612)] = 565716,
  [SMALL_STATE(11613)] = 565770,
  [SMALL_STATE(11614)] = 565824,
  [SMALL_STATE(11615)] = 565878,
  [SMALL_STATE(11616)] = 565932,
  [SMALL_STATE(11617)] = 565986,
  [SMALL_STATE(11618)] = 566040,
  [SMALL_STATE(11619)] = 566094,
  [SMALL_STATE(11620)] = 566148,
  [SMALL_STATE(11621)] = 566186,
  [SMALL_STATE(11622)] = 566220,
  [SMALL_STATE(11623)] = 566274,
  [SMALL_STATE(11624)] = 566328,
  [SMALL_STATE(11625)] = 566382,
  [SMALL_STATE(11626)] = 566436,
  [SMALL_STATE(11627)] = 566490,
  [SMALL_STATE(11628)] = 566544,
  [SMALL_STATE(11629)] = 566580,
  [SMALL_STATE(11630)] = 566634,
  [SMALL_STATE(11631)] = 566688,
  [SMALL_STATE(11632)] = 566726,
  [SMALL_STATE(11633)] = 566766,
  [SMALL_STATE(11634)] = 566804,
  [SMALL_STATE(11635)] = 566844,
  [SMALL_STATE(11636)] = 566898,
  [SMALL_STATE(11637)] = 566952,
  [SMALL_STATE(11638)] = 567006,
  [SMALL_STATE(11639)] = 567060,
  [SMALL_STATE(11640)] = 567100,
  [SMALL_STATE(11641)] = 567154,
  [SMALL_STATE(11642)] = 567194,
  [SMALL_STATE(11643)] = 567248,
  [SMALL_STATE(11644)] = 567302,
  [SMALL_STATE(11645)] = 567356,
  [SMALL_STATE(11646)] = 567410,
  [SMALL_STATE(11647)] = 567464,
  [SMALL_STATE(11648)] = 567518,
  [SMALL_STATE(11649)] = 567556,
  [SMALL_STATE(11650)] = 567610,
  [SMALL_STATE(11651)] = 567664,
  [SMALL_STATE(11652)] = 567718,
  [SMALL_STATE(11653)] = 567772,
  [SMALL_STATE(11654)] = 567826,
  [SMALL_STATE(11655)] = 567880,
  [SMALL_STATE(11656)] = 567934,
  [SMALL_STATE(11657)] = 567988,
  [SMALL_STATE(11658)] = 568042,
  [SMALL_STATE(11659)] = 568080,
  [SMALL_STATE(11660)] = 568134,
  [SMALL_STATE(11661)] = 568188,
  [SMALL_STATE(11662)] = 568242,
  [SMALL_STATE(11663)] = 568296,
  [SMALL_STATE(11664)] = 568350,
  [SMALL_STATE(11665)] = 568404,
  [SMALL_STATE(11666)] = 568458,
  [SMALL_STATE(11667)] = 568512,
  [SMALL_STATE(11668)] = 568566,
  [SMALL_STATE(11669)] = 568600,
  [SMALL_STATE(11670)] = 568654,
  [SMALL_STATE(11671)] = 568708,
  [SMALL_STATE(11672)] = 568762,
  [SMALL_STATE(11673)] = 568816,
  [SMALL_STATE(11674)] = 568856,
  [SMALL_STATE(11675)] = 568896,
  [SMALL_STATE(11676)] = 568950,
  [SMALL_STATE(11677)] = 569004,
  [SMALL_STATE(11678)] = 569062,
  [SMALL_STATE(11679)] = 569102,
  [SMALL_STATE(11680)] = 569156,
  [SMALL_STATE(11681)] = 569210,
  [SMALL_STATE(11682)] = 569264,
  [SMALL_STATE(11683)] = 569318,
  [SMALL_STATE(11684)] = 569372,
  [SMALL_STATE(11685)] = 569426,
  [SMALL_STATE(11686)] = 569480,
  [SMALL_STATE(11687)] = 569534,
  [SMALL_STATE(11688)] = 569588,
  [SMALL_STATE(11689)] = 569642,
  [SMALL_STATE(11690)] = 569696,
  [SMALL_STATE(11691)] = 569750,
  [SMALL_STATE(11692)] = 569788,
  [SMALL_STATE(11693)] = 569826,
  [SMALL_STATE(11694)] = 569880,
  [SMALL_STATE(11695)] = 569934,
  [SMALL_STATE(11696)] = 569988,
  [SMALL_STATE(11697)] = 570024,
  [SMALL_STATE(11698)] = 570078,
  [SMALL_STATE(11699)] = 570132,
  [SMALL_STATE(11700)] = 570178,
  [SMALL_STATE(11701)] = 570232,
  [SMALL_STATE(11702)] = 570286,
  [SMALL_STATE(11703)] = 570340,
  [SMALL_STATE(11704)] = 570394,
  [SMALL_STATE(11705)] = 570448,
  [SMALL_STATE(11706)] = 570484,
  [SMALL_STATE(11707)] = 570526,
  [SMALL_STATE(11708)] = 570560,
  [SMALL_STATE(11709)] = 570596,
  [SMALL_STATE(11710)] = 570634,
  [SMALL_STATE(11711)] = 570672,
  [SMALL_STATE(11712)] = 570726,
  [SMALL_STATE(11713)] = 570780,
  [SMALL_STATE(11714)] = 570834,
  [SMALL_STATE(11715)] = 570888,
  [SMALL_STATE(11716)] = 570942,
  [SMALL_STATE(11717)] = 570996,
  [SMALL_STATE(11718)] = 571050,
  [SMALL_STATE(11719)] = 571104,
  [SMALL_STATE(11720)] = 571158,
  [SMALL_STATE(11721)] = 571196,
  [SMALL_STATE(11722)] = 571250,
  [SMALL_STATE(11723)] = 571304,
  [SMALL_STATE(11724)] = 571358,
  [SMALL_STATE(11725)] = 571412,
  [SMALL_STATE(11726)] = 571466,
  [SMALL_STATE(11727)] = 571520,
  [SMALL_STATE(11728)] = 571574,
  [SMALL_STATE(11729)] = 571628,
  [SMALL_STATE(11730)] = 571682,
  [SMALL_STATE(11731)] = 571736,
  [SMALL_STATE(11732)] = 571790,
  [SMALL_STATE(11733)] = 571830,
  [SMALL_STATE(11734)] = 571881,
  [SMALL_STATE(11735)] = 571914,
  [SMALL_STATE(11736)] = 571953,
  [SMALL_STATE(11737)] = 571992,
  [SMALL_STATE(11738)] = 572031,
  [SMALL_STATE(11739)] = 572070,
  [SMALL_STATE(11740)] = 572107,
  [SMALL_STATE(11741)] = 572140,
  [SMALL_STATE(11742)] = 572173,
  [SMALL_STATE(11743)] = 572206,
  [SMALL_STATE(11744)] = 572245,
  [SMALL_STATE(11745)] = 572284,
  [SMALL_STATE(11746)] = 572323,
  [SMALL_STATE(11747)] = 572362,
  [SMALL_STATE(11748)] = 572401,
  [SMALL_STATE(11749)] = 572444,
  [SMALL_STATE(11750)] = 572483,
  [SMALL_STATE(11751)] = 572522,
  [SMALL_STATE(11752)] = 572561,
  [SMALL_STATE(11753)] = 572612,
  [SMALL_STATE(11754)] = 572649,
  [SMALL_STATE(11755)] = 572692,
  [SMALL_STATE(11756)] = 572731,
  [SMALL_STATE(11757)] = 572772,
  [SMALL_STATE(11758)] = 572809,
  [SMALL_STATE(11759)] = 572844,
  [SMALL_STATE(11760)] = 572881,
  [SMALL_STATE(11761)] = 572918,
  [SMALL_STATE(11762)] = 572955,
  [SMALL_STATE(11763)] = 572992,
  [SMALL_STATE(11764)] = 573031,
  [SMALL_STATE(11765)] = 573074,
  [SMALL_STATE(11766)] = 573117,
  [SMALL_STATE(11767)] = 573156,
  [SMALL_STATE(11768)] = 573195,
  [SMALL_STATE(11769)] = 573234,
  [SMALL_STATE(11770)] = 573273,
  [SMALL_STATE(11771)] = 573312,
  [SMALL_STATE(11772)] = 573345,
  [SMALL_STATE(11773)] = 573384,
  [SMALL_STATE(11774)] = 573417,
  [SMALL_STATE(11775)] = 573456,
  [SMALL_STATE(11776)] = 573489,
  [SMALL_STATE(11777)] = 573522,
  [SMALL_STATE(11778)] = 573555,
  [SMALL_STATE(11779)] = 573592,
  [SMALL_STATE(11780)] = 573631,
  [SMALL_STATE(11781)] = 573670,
  [SMALL_STATE(11782)] = 573709,
  [SMALL_STATE(11783)] = 573746,
  [SMALL_STATE(11784)] = 573785,
  [SMALL_STATE(11785)] = 573824,
  [SMALL_STATE(11786)] = 573857,
  [SMALL_STATE(11787)] = 573896,
  [SMALL_STATE(11788)] = 573933,
  [SMALL_STATE(11789)] = 573976,
  [SMALL_STATE(11790)] = 574009,
  [SMALL_STATE(11791)] = 574042,
  [SMALL_STATE(11792)] = 574099,
  [SMALL_STATE(11793)] = 574132,
  [SMALL_STATE(11794)] = 574169,
  [SMALL_STATE(11795)] = 574202,
  [SMALL_STATE(11796)] = 574245,
  [SMALL_STATE(11797)] = 574284,
  [SMALL_STATE(11798)] = 574317,
  [SMALL_STATE(11799)] = 574350,
  [SMALL_STATE(11800)] = 574383,
  [SMALL_STATE(11801)] = 574420,
  [SMALL_STATE(11802)] = 574457,
  [SMALL_STATE(11803)] = 574490,
  [SMALL_STATE(11804)] = 574523,
  [SMALL_STATE(11805)] = 574556,
  [SMALL_STATE(11806)] = 574591,
  [SMALL_STATE(11807)] = 574624,
  [SMALL_STATE(11808)] = 574657,
  [SMALL_STATE(11809)] = 574690,
  [SMALL_STATE(11810)] = 574723,
  [SMALL_STATE(11811)] = 574780,
  [SMALL_STATE(11812)] = 574817,
  [SMALL_STATE(11813)] = 574852,
  [SMALL_STATE(11814)] = 574885,
  [SMALL_STATE(11815)] = 574918,
  [SMALL_STATE(11816)] = 574969,
  [SMALL_STATE(11817)] = 575006,
  [SMALL_STATE(11818)] = 575041,
  [SMALL_STATE(11819)] = 575080,
  [SMALL_STATE(11820)] = 575113,
  [SMALL_STATE(11821)] = 575146,
  [SMALL_STATE(11822)] = 575185,
  [SMALL_STATE(11823)] = 575218,
  [SMALL_STATE(11824)] = 575255,
  [SMALL_STATE(11825)] = 575306,
  [SMALL_STATE(11826)] = 575343,
  [SMALL_STATE(11827)] = 575386,
  [SMALL_STATE(11828)] = 575423,
  [SMALL_STATE(11829)] = 575460,
  [SMALL_STATE(11830)] = 575505,
  [SMALL_STATE(11831)] = 575550,
  [SMALL_STATE(11832)] = 575599,
  [SMALL_STATE(11833)] = 575638,
  [SMALL_STATE(11834)] = 575689,
  [SMALL_STATE(11835)] = 575744,
  [SMALL_STATE(11836)] = 575783,
  [SMALL_STATE(11837)] = 575838,
  [SMALL_STATE(11838)] = 575889,
  [SMALL_STATE(11839)] = 575926,
  [SMALL_STATE(11840)] = 575965,
  [SMALL_STATE(11841)] = 576020,
  [SMALL_STATE(11842)] = 576057,
  [SMALL_STATE(11843)] = 576094,
  [SMALL_STATE(11844)] = 576135,
  [SMALL_STATE(11845)] = 576178,
  [SMALL_STATE(11846)] = 576229,
  [SMALL_STATE(11847)] = 576280,
  [SMALL_STATE(11848)] = 576317,
  [SMALL_STATE(11849)] = 576352,
  [SMALL_STATE(11850)] = 576391,
  [SMALL_STATE(11851)] = 576434,
  [SMALL_STATE(11852)] = 576471,
  [SMALL_STATE(11853)] = 576506,
  [SMALL_STATE(11854)] = 576545,
  [SMALL_STATE(11855)] = 576578,
  [SMALL_STATE(11856)] = 576611,
  [SMALL_STATE(11857)] = 576654,
  [SMALL_STATE(11858)] = 576691,
  [SMALL_STATE(11859)] = 576730,
  [SMALL_STATE(11860)] = 576769,
  [SMALL_STATE(11861)] = 576808,
  [SMALL_STATE(11862)] = 576849,
  [SMALL_STATE(11863)] = 576888,
  [SMALL_STATE(11864)] = 576939,
  [SMALL_STATE(11865)] = 576994,
  [SMALL_STATE(11866)] = 577027,
  [SMALL_STATE(11867)] = 577078,
  [SMALL_STATE(11868)] = 577113,
  [SMALL_STATE(11869)] = 577152,
  [SMALL_STATE(11870)] = 577189,
  [SMALL_STATE(11871)] = 577240,
  [SMALL_STATE(11872)] = 577283,
  [SMALL_STATE(11873)] = 577336,
  [SMALL_STATE(11874)] = 577377,
  [SMALL_STATE(11875)] = 577414,
  [SMALL_STATE(11876)] = 577451,
  [SMALL_STATE(11877)] = 577496,
  [SMALL_STATE(11878)] = 577535,
  [SMALL_STATE(11879)] = 577580,
  [SMALL_STATE(11880)] = 577629,
  [SMALL_STATE(11881)] = 577666,
  [SMALL_STATE(11882)] = 577703,
  [SMALL_STATE(11883)] = 577754,
  [SMALL_STATE(11884)] = 577797,
  [SMALL_STATE(11885)] = 577852,
  [SMALL_STATE(11886)] = 577891,
  [SMALL_STATE(11887)] = 577946,
  [SMALL_STATE(11888)] = 577983,
  [SMALL_STATE(11889)] = 578038,
  [SMALL_STATE(11890)] = 578077,
  [SMALL_STATE(11891)] = 578116,
  [SMALL_STATE(11892)] = 578153,
  [SMALL_STATE(11893)] = 578192,
  [SMALL_STATE(11894)] = 578225,
  [SMALL_STATE(11895)] = 578264,
  [SMALL_STATE(11896)] = 578315,
  [SMALL_STATE(11897)] = 578350,
  [SMALL_STATE(11898)] = 578387,
  [SMALL_STATE(11899)] = 578430,
  [SMALL_STATE(11900)] = 578465,
  [SMALL_STATE(11901)] = 578522,
  [SMALL_STATE(11902)] = 578570,
  [SMALL_STATE(11903)] = 578626,
  [SMALL_STATE(11904)] = 578662,
  [SMALL_STATE(11905)] = 578696,
  [SMALL_STATE(11906)] = 578750,
  [SMALL_STATE(11907)] = 578786,
  [SMALL_STATE(11908)] = 578834,
  [SMALL_STATE(11909)] = 578882,
  [SMALL_STATE(11910)] = 578918,
  [SMALL_STATE(11911)] = 578966,
  [SMALL_STATE(11912)] = 579014,
  [SMALL_STATE(11913)] = 579068,
  [SMALL_STATE(11914)] = 579104,
  [SMALL_STATE(11915)] = 579152,
  [SMALL_STATE(11916)] = 579190,
  [SMALL_STATE(11917)] = 579244,
  [SMALL_STATE(11918)] = 579292,
  [SMALL_STATE(11919)] = 579328,
  [SMALL_STATE(11920)] = 579378,
  [SMALL_STATE(11921)] = 579416,
  [SMALL_STATE(11922)] = 579454,
  [SMALL_STATE(11923)] = 579492,
  [SMALL_STATE(11924)] = 579530,
  [SMALL_STATE(11925)] = 579566,
  [SMALL_STATE(11926)] = 579602,
  [SMALL_STATE(11927)] = 579638,
  [SMALL_STATE(11928)] = 579686,
  [SMALL_STATE(11929)] = 579730,
  [SMALL_STATE(11930)] = 579766,
  [SMALL_STATE(11931)] = 579814,
  [SMALL_STATE(11932)] = 579858,
  [SMALL_STATE(11933)] = 579892,
  [SMALL_STATE(11934)] = 579940,
  [SMALL_STATE(11935)] = 579976,
  [SMALL_STATE(11936)] = 580024,
  [SMALL_STATE(11937)] = 580060,
  [SMALL_STATE(11938)] = 580102,
  [SMALL_STATE(11939)] = 580152,
  [SMALL_STATE(11940)] = 580188,
  [SMALL_STATE(11941)] = 580220,
  [SMALL_STATE(11942)] = 580268,
  [SMALL_STATE(11943)] = 580316,
  [SMALL_STATE(11944)] = 580370,
  [SMALL_STATE(11945)] = 580428,
  [SMALL_STATE(11946)] = 580486,
  [SMALL_STATE(11947)] = 580522,
  [SMALL_STATE(11948)] = 580576,
  [SMALL_STATE(11949)] = 580614,
  [SMALL_STATE(11950)] = 580668,
  [SMALL_STATE(11951)] = 580716,
  [SMALL_STATE(11952)] = 580766,
  [SMALL_STATE(11953)] = 580814,
  [SMALL_STATE(11954)] = 580858,
  [SMALL_STATE(11955)] = 580902,
  [SMALL_STATE(11956)] = 580950,
  [SMALL_STATE(11957)] = 580986,
  [SMALL_STATE(11958)] = 581034,
  [SMALL_STATE(11959)] = 581070,
  [SMALL_STATE(11960)] = 581106,
  [SMALL_STATE(11961)] = 581148,
  [SMALL_STATE(11962)] = 581204,
  [SMALL_STATE(11963)] = 581254,
  [SMALL_STATE(11964)] = 581290,
  [SMALL_STATE(11965)] = 581338,
  [SMALL_STATE(11966)] = 581392,
  [SMALL_STATE(11967)] = 581430,
  [SMALL_STATE(11968)] = 581478,
  [SMALL_STATE(11969)] = 581516,
  [SMALL_STATE(11970)] = 581572,
  [SMALL_STATE(11971)] = 581606,
  [SMALL_STATE(11972)] = 581638,
  [SMALL_STATE(11973)] = 581694,
  [SMALL_STATE(11974)] = 581726,
  [SMALL_STATE(11975)] = 581758,
  [SMALL_STATE(11976)] = 581790,
  [SMALL_STATE(11977)] = 581826,
  [SMALL_STATE(11978)] = 581880,
  [SMALL_STATE(11979)] = 581940,
  [SMALL_STATE(11980)] = 581988,
  [SMALL_STATE(11981)] = 582036,
  [SMALL_STATE(11982)] = 582070,
  [SMALL_STATE(11983)] = 582104,
  [SMALL_STATE(11984)] = 582140,
  [SMALL_STATE(11985)] = 582176,
  [SMALL_STATE(11986)] = 582212,
  [SMALL_STATE(11987)] = 582248,
  [SMALL_STATE(11988)] = 582284,
  [SMALL_STATE(11989)] = 582320,
  [SMALL_STATE(11990)] = 582356,
  [SMALL_STATE(11991)] = 582392,
  [SMALL_STATE(11992)] = 582428,
  [SMALL_STATE(11993)] = 582464,
  [SMALL_STATE(11994)] = 582500,
  [SMALL_STATE(11995)] = 582536,
  [SMALL_STATE(11996)] = 582572,
  [SMALL_STATE(11997)] = 582606,
  [SMALL_STATE(11998)] = 582654,
  [SMALL_STATE(11999)] = 582688,
  [SMALL_STATE(12000)] = 582726,
  [SMALL_STATE(12001)] = 582764,
  [SMALL_STATE(12002)] = 582820,
  [SMALL_STATE(12003)] = 582868,
  [SMALL_STATE(12004)] = 582918,
  [SMALL_STATE(12005)] = 582954,
  [SMALL_STATE(12006)] = 582990,
  [SMALL_STATE(12007)] = 583022,
  [SMALL_STATE(12008)] = 583054,
  [SMALL_STATE(12009)] = 583102,
  [SMALL_STATE(12010)] = 583134,
  [SMALL_STATE(12011)] = 583170,
  [SMALL_STATE(12012)] = 583224,
  [SMALL_STATE(12013)] = 583278,
  [SMALL_STATE(12014)] = 583326,
  [SMALL_STATE(12015)] = 583382,
  [SMALL_STATE(12016)] = 583418,
  [SMALL_STATE(12017)] = 583478,
  [SMALL_STATE(12018)] = 583526,
  [SMALL_STATE(12019)] = 583562,
  [SMALL_STATE(12020)] = 583610,
  [SMALL_STATE(12021)] = 583658,
  [SMALL_STATE(12022)] = 583706,
  [SMALL_STATE(12023)] = 583754,
  [SMALL_STATE(12024)] = 583788,
  [SMALL_STATE(12025)] = 583836,
  [SMALL_STATE(12026)] = 583872,
  [SMALL_STATE(12027)] = 583908,
  [SMALL_STATE(12028)] = 583956,
  [SMALL_STATE(12029)] = 583992,
  [SMALL_STATE(12030)] = 584028,
  [SMALL_STATE(12031)] = 584064,
  [SMALL_STATE(12032)] = 584118,
  [SMALL_STATE(12033)] = 584154,
  [SMALL_STATE(12034)] = 584208,
  [SMALL_STATE(12035)] = 584258,
  [SMALL_STATE(12036)] = 584292,
  [SMALL_STATE(12037)] = 584328,
  [SMALL_STATE(12038)] = 584364,
  [SMALL_STATE(12039)] = 584412,
  [SMALL_STATE(12040)] = 584468,
  [SMALL_STATE(12041)] = 584506,
  [SMALL_STATE(12042)] = 584560,
  [SMALL_STATE(12043)] = 584610,
  [SMALL_STATE(12044)] = 584658,
  [SMALL_STATE(12045)] = 584702,
  [SMALL_STATE(12046)] = 584750,
  [SMALL_STATE(12047)] = 584794,
  [SMALL_STATE(12048)] = 584842,
  [SMALL_STATE(12049)] = 584878,
  [SMALL_STATE(12050)] = 584914,
  [SMALL_STATE(12051)] = 584950,
  [SMALL_STATE(12052)] = 584986,
  [SMALL_STATE(12053)] = 585022,
  [SMALL_STATE(12054)] = 585058,
  [SMALL_STATE(12055)] = 585106,
  [SMALL_STATE(12056)] = 585148,
  [SMALL_STATE(12057)] = 585198,
  [SMALL_STATE(12058)] = 585230,
  [SMALL_STATE(12059)] = 585264,
  [SMALL_STATE(12060)] = 585300,
  [SMALL_STATE(12061)] = 585336,
  [SMALL_STATE(12062)] = 585384,
  [SMALL_STATE(12063)] = 585426,
  [SMALL_STATE(12064)] = 585474,
  [SMALL_STATE(12065)] = 585522,
  [SMALL_STATE(12066)] = 585570,
  [SMALL_STATE(12067)] = 585604,
  [SMALL_STATE(12068)] = 585638,
  [SMALL_STATE(12069)] = 585674,
  [SMALL_STATE(12070)] = 585710,
  [SMALL_STATE(12071)] = 585746,
  [SMALL_STATE(12072)] = 585782,
  [SMALL_STATE(12073)] = 585818,
  [SMALL_STATE(12074)] = 585852,
  [SMALL_STATE(12075)] = 585888,
  [SMALL_STATE(12076)] = 585926,
  [SMALL_STATE(12077)] = 585962,
  [SMALL_STATE(12078)] = 585998,
  [SMALL_STATE(12079)] = 586034,
  [SMALL_STATE(12080)] = 586082,
  [SMALL_STATE(12081)] = 586130,
  [SMALL_STATE(12082)] = 586166,
  [SMALL_STATE(12083)] = 586200,
  [SMALL_STATE(12084)] = 586260,
  [SMALL_STATE(12085)] = 586294,
  [SMALL_STATE(12086)] = 586342,
  [SMALL_STATE(12087)] = 586378,
  [SMALL_STATE(12088)] = 586414,
  [SMALL_STATE(12089)] = 586450,
  [SMALL_STATE(12090)] = 586486,
  [SMALL_STATE(12091)] = 586534,
  [SMALL_STATE(12092)] = 586570,
  [SMALL_STATE(12093)] = 586618,
  [SMALL_STATE(12094)] = 586654,
  [SMALL_STATE(12095)] = 586688,
  [SMALL_STATE(12096)] = 586736,
  [SMALL_STATE(12097)] = 586784,
  [SMALL_STATE(12098)] = 586818,
  [SMALL_STATE(12099)] = 586854,
  [SMALL_STATE(12100)] = 586888,
  [SMALL_STATE(12101)] = 586924,
  [SMALL_STATE(12102)] = 586960,
  [SMALL_STATE(12103)] = 586996,
  [SMALL_STATE(12104)] = 587032,
  [SMALL_STATE(12105)] = 587082,
  [SMALL_STATE(12106)] = 587124,
  [SMALL_STATE(12107)] = 587160,
  [SMALL_STATE(12108)] = 587196,
  [SMALL_STATE(12109)] = 587240,
  [SMALL_STATE(12110)] = 587284,
  [SMALL_STATE(12111)] = 587332,
  [SMALL_STATE(12112)] = 587366,
  [SMALL_STATE(12113)] = 587402,
  [SMALL_STATE(12114)] = 587452,
  [SMALL_STATE(12115)] = 587506,
  [SMALL_STATE(12116)] = 587542,
  [SMALL_STATE(12117)] = 587580,
  [SMALL_STATE(12118)] = 587628,
  [SMALL_STATE(12119)] = 587682,
  [SMALL_STATE(12120)] = 587718,
  [SMALL_STATE(12121)] = 587772,
  [SMALL_STATE(12122)] = 587806,
  [SMALL_STATE(12123)] = 587842,
  [SMALL_STATE(12124)] = 587896,
  [SMALL_STATE(12125)] = 587932,
  [SMALL_STATE(12126)] = 587966,
  [SMALL_STATE(12127)] = 588002,
  [SMALL_STATE(12128)] = 588038,
  [SMALL_STATE(12129)] = 588086,
  [SMALL_STATE(12130)] = 588136,
  [SMALL_STATE(12131)] = 588178,
  [SMALL_STATE(12132)] = 588214,
  [SMALL_STATE(12133)] = 588246,
  [SMALL_STATE(12134)] = 588282,
  [SMALL_STATE(12135)] = 588318,
  [SMALL_STATE(12136)] = 588354,
  [SMALL_STATE(12137)] = 588398,
  [SMALL_STATE(12138)] = 588446,
  [SMALL_STATE(12139)] = 588494,
  [SMALL_STATE(12140)] = 588538,
  [SMALL_STATE(12141)] = 588586,
  [SMALL_STATE(12142)] = 588636,
  [SMALL_STATE(12143)] = 588672,
  [SMALL_STATE(12144)] = 588706,
  [SMALL_STATE(12145)] = 588754,
  [SMALL_STATE(12146)] = 588808,
  [SMALL_STATE(12147)] = 588846,
  [SMALL_STATE(12148)] = 588900,
  [SMALL_STATE(12149)] = 588936,
  [SMALL_STATE(12150)] = 588978,
  [SMALL_STATE(12151)] = 589014,
  [SMALL_STATE(12152)] = 589050,
  [SMALL_STATE(12153)] = 589086,
  [SMALL_STATE(12154)] = 589140,
  [SMALL_STATE(12155)] = 589176,
  [SMALL_STATE(12156)] = 589208,
  [SMALL_STATE(12157)] = 589256,
  [SMALL_STATE(12158)] = 589310,
  [SMALL_STATE(12159)] = 589342,
  [SMALL_STATE(12160)] = 589378,
  [SMALL_STATE(12161)] = 589416,
  [SMALL_STATE(12162)] = 589450,
  [SMALL_STATE(12163)] = 589498,
  [SMALL_STATE(12164)] = 589552,
  [SMALL_STATE(12165)] = 589602,
  [SMALL_STATE(12166)] = 589650,
  [SMALL_STATE(12167)] = 589698,
  [SMALL_STATE(12168)] = 589742,
  [SMALL_STATE(12169)] = 589786,
  [SMALL_STATE(12170)] = 589822,
  [SMALL_STATE(12171)] = 589876,
  [SMALL_STATE(12172)] = 589912,
  [SMALL_STATE(12173)] = 589948,
  [SMALL_STATE(12174)] = 589984,
  [SMALL_STATE(12175)] = 590016,
  [SMALL_STATE(12176)] = 590070,
  [SMALL_STATE(12177)] = 590108,
  [SMALL_STATE(12178)] = 590156,
  [SMALL_STATE(12179)] = 590204,
  [SMALL_STATE(12180)] = 590258,
  [SMALL_STATE(12181)] = 590306,
  [SMALL_STATE(12182)] = 590356,
  [SMALL_STATE(12183)] = 590398,
  [SMALL_STATE(12184)] = 590448,
  [SMALL_STATE(12185)] = 590498,
  [SMALL_STATE(12186)] = 590546,
  [SMALL_STATE(12187)] = 590582,
  [SMALL_STATE(12188)] = 590630,
  [SMALL_STATE(12189)] = 590684,
  [SMALL_STATE(12190)] = 590720,
  [SMALL_STATE(12191)] = 590764,
  [SMALL_STATE(12192)] = 590808,
  [SMALL_STATE(12193)] = 590868,
  [SMALL_STATE(12194)] = 590904,
  [SMALL_STATE(12195)] = 590952,
  [SMALL_STATE(12196)] = 590988,
  [SMALL_STATE(12197)] = 591030,
  [SMALL_STATE(12198)] = 591080,
  [SMALL_STATE(12199)] = 591114,
  [SMALL_STATE(12200)] = 591148,
  [SMALL_STATE(12201)] = 591180,
  [SMALL_STATE(12202)] = 591216,
  [SMALL_STATE(12203)] = 591252,
  [SMALL_STATE(12204)] = 591288,
  [SMALL_STATE(12205)] = 591336,
  [SMALL_STATE(12206)] = 591370,
  [SMALL_STATE(12207)] = 591404,
  [SMALL_STATE(12208)] = 591452,
  [SMALL_STATE(12209)] = 591488,
  [SMALL_STATE(12210)] = 591530,
  [SMALL_STATE(12211)] = 591584,
  [SMALL_STATE(12212)] = 591620,
  [SMALL_STATE(12213)] = 591675,
  [SMALL_STATE(12214)] = 591710,
  [SMALL_STATE(12215)] = 591763,
  [SMALL_STATE(12216)] = 591804,
  [SMALL_STATE(12217)] = 591859,
  [SMALL_STATE(12218)] = 591914,
  [SMALL_STATE(12219)] = 591955,
  [SMALL_STATE(12220)] = 592008,
  [SMALL_STATE(12221)] = 592049,
  [SMALL_STATE(12222)] = 592090,
  [SMALL_STATE(12223)] = 592123,
  [SMALL_STATE(12224)] = 592154,
  [SMALL_STATE(12225)] = 592189,
  [SMALL_STATE(12226)] = 592226,
  [SMALL_STATE(12227)] = 592257,
  [SMALL_STATE(12228)] = 592292,
  [SMALL_STATE(12229)] = 592345,
  [SMALL_STATE(12230)] = 592380,
  [SMALL_STATE(12231)] = 592411,
  [SMALL_STATE(12232)] = 592460,
  [SMALL_STATE(12233)] = 592491,
  [SMALL_STATE(12234)] = 592546,
  [SMALL_STATE(12235)] = 592581,
  [SMALL_STATE(12236)] = 592636,
  [SMALL_STATE(12237)] = 592683,
  [SMALL_STATE(12238)] = 592724,
  [SMALL_STATE(12239)] = 592767,
  [SMALL_STATE(12240)] = 592810,
  [SMALL_STATE(12241)] = 592851,
  [SMALL_STATE(12242)] = 592894,
  [SMALL_STATE(12243)] = 592929,
  [SMALL_STATE(12244)] = 592970,
  [SMALL_STATE(12245)] = 593011,
  [SMALL_STATE(12246)] = 593052,
  [SMALL_STATE(12247)] = 593107,
  [SMALL_STATE(12248)] = 593162,
  [SMALL_STATE(12249)] = 593197,
  [SMALL_STATE(12250)] = 593228,
  [SMALL_STATE(12251)] = 593283,
  [SMALL_STATE(12252)] = 593324,
  [SMALL_STATE(12253)] = 593357,
  [SMALL_STATE(12254)] = 593392,
  [SMALL_STATE(12255)] = 593433,
  [SMALL_STATE(12256)] = 593474,
  [SMALL_STATE(12257)] = 593529,
  [SMALL_STATE(12258)] = 593578,
  [SMALL_STATE(12259)] = 593619,
  [SMALL_STATE(12260)] = 593654,
  [SMALL_STATE(12261)] = 593709,
  [SMALL_STATE(12262)] = 593764,
  [SMALL_STATE(12263)] = 593819,
  [SMALL_STATE(12264)] = 593860,
  [SMALL_STATE(12265)] = 593915,
  [SMALL_STATE(12266)] = 593956,
  [SMALL_STATE(12267)] = 593997,
  [SMALL_STATE(12268)] = 594052,
  [SMALL_STATE(12269)] = 594093,
  [SMALL_STATE(12270)] = 594148,
  [SMALL_STATE(12271)] = 594199,
  [SMALL_STATE(12272)] = 594254,
  [SMALL_STATE(12273)] = 594309,
  [SMALL_STATE(12274)] = 594364,
  [SMALL_STATE(12275)] = 594399,
  [SMALL_STATE(12276)] = 594434,
  [SMALL_STATE(12277)] = 594489,
  [SMALL_STATE(12278)] = 594522,
  [SMALL_STATE(12279)] = 594577,
  [SMALL_STATE(12280)] = 594612,
  [SMALL_STATE(12281)] = 594667,
  [SMALL_STATE(12282)] = 594706,
  [SMALL_STATE(12283)] = 594739,
  [SMALL_STATE(12284)] = 594772,
  [SMALL_STATE(12285)] = 594807,
  [SMALL_STATE(12286)] = 594840,
  [SMALL_STATE(12287)] = 594881,
  [SMALL_STATE(12288)] = 594912,
  [SMALL_STATE(12289)] = 594943,
  [SMALL_STATE(12290)] = 594974,
  [SMALL_STATE(12291)] = 595015,
  [SMALL_STATE(12292)] = 595046,
  [SMALL_STATE(12293)] = 595087,
  [SMALL_STATE(12294)] = 595122,
  [SMALL_STATE(12295)] = 595163,
  [SMALL_STATE(12296)] = 595198,
  [SMALL_STATE(12297)] = 595233,
  [SMALL_STATE(12298)] = 595288,
  [SMALL_STATE(12299)] = 595331,
  [SMALL_STATE(12300)] = 595374,
  [SMALL_STATE(12301)] = 595429,
  [SMALL_STATE(12302)] = 595476,
  [SMALL_STATE(12303)] = 595517,
  [SMALL_STATE(12304)] = 595564,
  [SMALL_STATE(12305)] = 595615,
  [SMALL_STATE(12306)] = 595646,
  [SMALL_STATE(12307)] = 595701,
  [SMALL_STATE(12308)] = 595738,
  [SMALL_STATE(12309)] = 595779,
  [SMALL_STATE(12310)] = 595830,
  [SMALL_STATE(12311)] = 595861,
  [SMALL_STATE(12312)] = 595902,
  [SMALL_STATE(12313)] = 595937,
  [SMALL_STATE(12314)] = 595988,
  [SMALL_STATE(12315)] = 596029,
  [SMALL_STATE(12316)] = 596060,
  [SMALL_STATE(12317)] = 596091,
  [SMALL_STATE(12318)] = 596146,
  [SMALL_STATE(12319)] = 596187,
  [SMALL_STATE(12320)] = 596222,
  [SMALL_STATE(12321)] = 596277,
  [SMALL_STATE(12322)] = 596312,
  [SMALL_STATE(12323)] = 596353,
  [SMALL_STATE(12324)] = 596386,
  [SMALL_STATE(12325)] = 596427,
  [SMALL_STATE(12326)] = 596478,
  [SMALL_STATE(12327)] = 596519,
  [SMALL_STATE(12328)] = 596554,
  [SMALL_STATE(12329)] = 596605,
  [SMALL_STATE(12330)] = 596652,
  [SMALL_STATE(12331)] = 596689,
  [SMALL_STATE(12332)] = 596740,
  [SMALL_STATE(12333)] = 596795,
  [SMALL_STATE(12334)] = 596828,
  [SMALL_STATE(12335)] = 596869,
  [SMALL_STATE(12336)] = 596904,
  [SMALL_STATE(12337)] = 596939,
  [SMALL_STATE(12338)] = 596974,
  [SMALL_STATE(12339)] = 597029,
  [SMALL_STATE(12340)] = 597084,
  [SMALL_STATE(12341)] = 597119,
  [SMALL_STATE(12342)] = 597174,
  [SMALL_STATE(12343)] = 597221,
  [SMALL_STATE(12344)] = 597262,
  [SMALL_STATE(12345)] = 597309,
  [SMALL_STATE(12346)] = 597350,
  [SMALL_STATE(12347)] = 597405,
  [SMALL_STATE(12348)] = 597440,
  [SMALL_STATE(12349)] = 597473,
  [SMALL_STATE(12350)] = 597516,
  [SMALL_STATE(12351)] = 597547,
  [SMALL_STATE(12352)] = 597590,
  [SMALL_STATE(12353)] = 597645,
  [SMALL_STATE(12354)] = 597678,
  [SMALL_STATE(12355)] = 597709,
  [SMALL_STATE(12356)] = 597740,
  [SMALL_STATE(12357)] = 597771,
  [SMALL_STATE(12358)] = 597806,
  [SMALL_STATE(12359)] = 597849,
  [SMALL_STATE(12360)] = 597884,
  [SMALL_STATE(12361)] = 597939,
  [SMALL_STATE(12362)] = 597970,
  [SMALL_STATE(12363)] = 598001,
  [SMALL_STATE(12364)] = 598056,
  [SMALL_STATE(12365)] = 598097,
  [SMALL_STATE(12366)] = 598152,
  [SMALL_STATE(12367)] = 598185,
  [SMALL_STATE(12368)] = 598240,
  [SMALL_STATE(12369)] = 598281,
  [SMALL_STATE(12370)] = 598312,
  [SMALL_STATE(12371)] = 598367,
  [SMALL_STATE(12372)] = 598422,
  [SMALL_STATE(12373)] = 598469,
  [SMALL_STATE(12374)] = 598524,
  [SMALL_STATE(12375)] = 598555,
  [SMALL_STATE(12376)] = 598602,
  [SMALL_STATE(12377)] = 598633,
  [SMALL_STATE(12378)] = 598688,
  [SMALL_STATE(12379)] = 598719,
  [SMALL_STATE(12380)] = 598772,
  [SMALL_STATE(12381)] = 598825,
  [SMALL_STATE(12382)] = 598862,
  [SMALL_STATE(12383)] = 598903,
  [SMALL_STATE(12384)] = 598934,
  [SMALL_STATE(12385)] = 598989,
  [SMALL_STATE(12386)] = 599024,
  [SMALL_STATE(12387)] = 599065,
  [SMALL_STATE(12388)] = 599098,
  [SMALL_STATE(12389)] = 599129,
  [SMALL_STATE(12390)] = 599184,
  [SMALL_STATE(12391)] = 599219,
  [SMALL_STATE(12392)] = 599274,
  [SMALL_STATE(12393)] = 599305,
  [SMALL_STATE(12394)] = 599348,
  [SMALL_STATE(12395)] = 599381,
  [SMALL_STATE(12396)] = 599422,
  [SMALL_STATE(12397)] = 599469,
  [SMALL_STATE(12398)] = 599512,
  [SMALL_STATE(12399)] = 599559,
  [SMALL_STATE(12400)] = 599612,
  [SMALL_STATE(12401)] = 599663,
  [SMALL_STATE(12402)] = 599700,
  [SMALL_STATE(12403)] = 599751,
  [SMALL_STATE(12404)] = 599800,
  [SMALL_STATE(12405)] = 599841,
  [SMALL_STATE(12406)] = 599888,
  [SMALL_STATE(12407)] = 599923,
  [SMALL_STATE(12408)] = 599966,
  [SMALL_STATE(12409)] = 600009,
  [SMALL_STATE(12410)] = 600044,
  [SMALL_STATE(12411)] = 600095,
  [SMALL_STATE(12412)] = 600128,
  [SMALL_STATE(12413)] = 600183,
  [SMALL_STATE(12414)] = 600218,
  [SMALL_STATE(12415)] = 600259,
  [SMALL_STATE(12416)] = 600314,
  [SMALL_STATE(12417)] = 600363,
  [SMALL_STATE(12418)] = 600404,
  [SMALL_STATE(12419)] = 600457,
  [SMALL_STATE(12420)] = 600510,
  [SMALL_STATE(12421)] = 600565,
  [SMALL_STATE(12422)] = 600620,
  [SMALL_STATE(12423)] = 600673,
  [SMALL_STATE(12424)] = 600710,
  [SMALL_STATE(12425)] = 600763,
  [SMALL_STATE(12426)] = 600812,
  [SMALL_STATE(12427)] = 600859,
  [SMALL_STATE(12428)] = 600890,
  [SMALL_STATE(12429)] = 600933,
  [SMALL_STATE(12430)] = 600966,
  [SMALL_STATE(12431)] = 601001,
  [SMALL_STATE(12432)] = 601036,
  [SMALL_STATE(12433)] = 601069,
  [SMALL_STATE(12434)] = 601104,
  [SMALL_STATE(12435)] = 601139,
  [SMALL_STATE(12436)] = 601174,
  [SMALL_STATE(12437)] = 601209,
  [SMALL_STATE(12438)] = 601244,
  [SMALL_STATE(12439)] = 601299,
  [SMALL_STATE(12440)] = 601350,
  [SMALL_STATE(12441)] = 601383,
  [SMALL_STATE(12442)] = 601418,
  [SMALL_STATE(12443)] = 601473,
  [SMALL_STATE(12444)] = 601514,
  [SMALL_STATE(12445)] = 601557,
  [SMALL_STATE(12446)] = 601592,
  [SMALL_STATE(12447)] = 601633,
  [SMALL_STATE(12448)] = 601668,
  [SMALL_STATE(12449)] = 601709,
  [SMALL_STATE(12450)] = 601750,
  [SMALL_STATE(12451)] = 601799,
  [SMALL_STATE(12452)] = 601834,
  [SMALL_STATE(12453)] = 601887,
  [SMALL_STATE(12454)] = 601940,
  [SMALL_STATE(12455)] = 601987,
  [SMALL_STATE(12456)] = 602022,
  [SMALL_STATE(12457)] = 602063,
  [SMALL_STATE(12458)] = 602106,
  [SMALL_STATE(12459)] = 602139,
  [SMALL_STATE(12460)] = 602174,
  [SMALL_STATE(12461)] = 602207,
  [SMALL_STATE(12462)] = 602244,
  [SMALL_STATE(12463)] = 602279,
  [SMALL_STATE(12464)] = 602322,
  [SMALL_STATE(12465)] = 602375,
  [SMALL_STATE(12466)] = 602416,
  [SMALL_STATE(12467)] = 602469,
  [SMALL_STATE(12468)] = 602512,
  [SMALL_STATE(12469)] = 602561,
  [SMALL_STATE(12470)] = 602608,
  [SMALL_STATE(12471)] = 602663,
  [SMALL_STATE(12472)] = 602710,
  [SMALL_STATE(12473)] = 602759,
  [SMALL_STATE(12474)] = 602806,
  [SMALL_STATE(12475)] = 602857,
  [SMALL_STATE(12476)] = 602890,
  [SMALL_STATE(12477)] = 602921,
  [SMALL_STATE(12478)] = 602952,
  [SMALL_STATE(12479)] = 602983,
  [SMALL_STATE(12480)] = 603026,
  [SMALL_STATE(12481)] = 603057,
  [SMALL_STATE(12482)] = 603108,
  [SMALL_STATE(12483)] = 603149,
  [SMALL_STATE(12484)] = 603184,
  [SMALL_STATE(12485)] = 603219,
  [SMALL_STATE(12486)] = 603262,
  [SMALL_STATE(12487)] = 603313,
  [SMALL_STATE(12488)] = 603344,
  [SMALL_STATE(12489)] = 603385,
  [SMALL_STATE(12490)] = 603416,
  [SMALL_STATE(12491)] = 603471,
  [SMALL_STATE(12492)] = 603506,
  [SMALL_STATE(12493)] = 603549,
  [SMALL_STATE(12494)] = 603584,
  [SMALL_STATE(12495)] = 603625,
  [SMALL_STATE(12496)] = 603680,
  [SMALL_STATE(12497)] = 603713,
  [SMALL_STATE(12498)] = 603768,
  [SMALL_STATE(12499)] = 603809,
  [SMALL_STATE(12500)] = 603850,
  [SMALL_STATE(12501)] = 603885,
  [SMALL_STATE(12502)] = 603920,
  [SMALL_STATE(12503)] = 603967,
  [SMALL_STATE(12504)] = 604006,
  [SMALL_STATE(12505)] = 604047,
  [SMALL_STATE(12506)] = 604096,
  [SMALL_STATE(12507)] = 604149,
  [SMALL_STATE(12508)] = 604186,
  [SMALL_STATE(12509)] = 604223,
  [SMALL_STATE(12510)] = 604278,
  [SMALL_STATE(12511)] = 604333,
  [SMALL_STATE(12512)] = 604386,
  [SMALL_STATE(12513)] = 604441,
  [SMALL_STATE(12514)] = 604496,
  [SMALL_STATE(12515)] = 604531,
  [SMALL_STATE(12516)] = 604566,
  [SMALL_STATE(12517)] = 604615,
  [SMALL_STATE(12518)] = 604646,
  [SMALL_STATE(12519)] = 604679,
  [SMALL_STATE(12520)] = 604734,
  [SMALL_STATE(12521)] = 604767,
  [SMALL_STATE(12522)] = 604822,
  [SMALL_STATE(12523)] = 604863,
  [SMALL_STATE(12524)] = 604912,
  [SMALL_STATE(12525)] = 604967,
  [SMALL_STATE(12526)] = 604998,
  [SMALL_STATE(12527)] = 605053,
  [SMALL_STATE(12528)] = 605094,
  [SMALL_STATE(12529)] = 605147,
  [SMALL_STATE(12530)] = 605178,
  [SMALL_STATE(12531)] = 605219,
  [SMALL_STATE(12532)] = 605250,
  [SMALL_STATE(12533)] = 605281,
  [SMALL_STATE(12534)] = 605322,
  [SMALL_STATE(12535)] = 605353,
  [SMALL_STATE(12536)] = 605386,
  [SMALL_STATE(12537)] = 605439,
  [SMALL_STATE(12538)] = 605474,
  [SMALL_STATE(12539)] = 605505,
  [SMALL_STATE(12540)] = 605558,
  [SMALL_STATE(12541)] = 605595,
  [SMALL_STATE(12542)] = 605650,
  [SMALL_STATE(12543)] = 605705,
  [SMALL_STATE(12544)] = 605738,
  [SMALL_STATE(12545)] = 605769,
  [SMALL_STATE(12546)] = 605822,
  [SMALL_STATE(12547)] = 605877,
  [SMALL_STATE(12548)] = 605924,
  [SMALL_STATE(12549)] = 605967,
  [SMALL_STATE(12550)] = 606010,
  [SMALL_STATE(12551)] = 606045,
  [SMALL_STATE(12552)] = 606086,
  [SMALL_STATE(12553)] = 606141,
  [SMALL_STATE(12554)] = 606196,
  [SMALL_STATE(12555)] = 606229,
  [SMALL_STATE(12556)] = 606270,
  [SMALL_STATE(12557)] = 606311,
  [SMALL_STATE(12558)] = 606360,
  [SMALL_STATE(12559)] = 606415,
  [SMALL_STATE(12560)] = 606470,
  [SMALL_STATE(12561)] = 606525,
  [SMALL_STATE(12562)] = 606566,
  [SMALL_STATE(12563)] = 606621,
  [SMALL_STATE(12564)] = 606662,
  [SMALL_STATE(12565)] = 606713,
  [SMALL_STATE(12566)] = 606768,
  [SMALL_STATE(12567)] = 606801,
  [SMALL_STATE(12568)] = 606854,
  [SMALL_STATE(12569)] = 606907,
  [SMALL_STATE(12570)] = 606940,
  [SMALL_STATE(12571)] = 606973,
  [SMALL_STATE(12572)] = 607028,
  [SMALL_STATE(12573)] = 607059,
  [SMALL_STATE(12574)] = 607114,
  [SMALL_STATE(12575)] = 607145,
  [SMALL_STATE(12576)] = 607188,
  [SMALL_STATE(12577)] = 607223,
  [SMALL_STATE(12578)] = 607258,
  [SMALL_STATE(12579)] = 607293,
  [SMALL_STATE(12580)] = 607326,
  [SMALL_STATE(12581)] = 607367,
  [SMALL_STATE(12582)] = 607418,
  [SMALL_STATE(12583)] = 607453,
  [SMALL_STATE(12584)] = 607508,
  [SMALL_STATE(12585)] = 607563,
  [SMALL_STATE(12586)] = 607618,
  [SMALL_STATE(12587)] = 607673,
  [SMALL_STATE(12588)] = 607714,
  [SMALL_STATE(12589)] = 607769,
  [SMALL_STATE(12590)] = 607824,
  [SMALL_STATE(12591)] = 607855,
  [SMALL_STATE(12592)] = 607888,
  [SMALL_STATE(12593)] = 607943,
  [SMALL_STATE(12594)] = 607974,
  [SMALL_STATE(12595)] = 608029,
  [SMALL_STATE(12596)] = 608060,
  [SMALL_STATE(12597)] = 608091,
  [SMALL_STATE(12598)] = 608122,
  [SMALL_STATE(12599)] = 608163,
  [SMALL_STATE(12600)] = 608204,
  [SMALL_STATE(12601)] = 608235,
  [SMALL_STATE(12602)] = 608266,
  [SMALL_STATE(12603)] = 608321,
  [SMALL_STATE(12604)] = 608362,
  [SMALL_STATE(12605)] = 608397,
  [SMALL_STATE(12606)] = 608428,
  [SMALL_STATE(12607)] = 608483,
  [SMALL_STATE(12608)] = 608516,
  [SMALL_STATE(12609)] = 608571,
  [SMALL_STATE(12610)] = 608626,
  [SMALL_STATE(12611)] = 608661,
  [SMALL_STATE(12612)] = 608694,
  [SMALL_STATE(12613)] = 608729,
  [SMALL_STATE(12614)] = 608784,
  [SMALL_STATE(12615)] = 608839,
  [SMALL_STATE(12616)] = 608880,
  [SMALL_STATE(12617)] = 608921,
  [SMALL_STATE(12618)] = 608976,
  [SMALL_STATE(12619)] = 609031,
  [SMALL_STATE(12620)] = 609086,
  [SMALL_STATE(12621)] = 609139,
  [SMALL_STATE(12622)] = 609174,
  [SMALL_STATE(12623)] = 609229,
  [SMALL_STATE(12624)] = 609284,
  [SMALL_STATE(12625)] = 609332,
  [SMALL_STATE(12626)] = 609380,
  [SMALL_STATE(12627)] = 609428,
  [SMALL_STATE(12628)] = 609466,
  [SMALL_STATE(12629)] = 609494,
  [SMALL_STATE(12630)] = 609524,
  [SMALL_STATE(12631)] = 609554,
  [SMALL_STATE(12632)] = 609584,
  [SMALL_STATE(12633)] = 609632,
  [SMALL_STATE(12634)] = 609662,
  [SMALL_STATE(12635)] = 609692,
  [SMALL_STATE(12636)] = 609734,
  [SMALL_STATE(12637)] = 609782,
  [SMALL_STATE(12638)] = 609812,
  [SMALL_STATE(12639)] = 609842,
  [SMALL_STATE(12640)] = 609872,
  [SMALL_STATE(12641)] = 609904,
  [SMALL_STATE(12642)] = 609934,
  [SMALL_STATE(12643)] = 609982,
  [SMALL_STATE(12644)] = 610012,
  [SMALL_STATE(12645)] = 610042,
  [SMALL_STATE(12646)] = 610088,
  [SMALL_STATE(12647)] = 610136,
  [SMALL_STATE(12648)] = 610166,
  [SMALL_STATE(12649)] = 610198,
  [SMALL_STATE(12650)] = 610226,
  [SMALL_STATE(12651)] = 610254,
  [SMALL_STATE(12652)] = 610284,
  [SMALL_STATE(12653)] = 610324,
  [SMALL_STATE(12654)] = 610354,
  [SMALL_STATE(12655)] = 610390,
  [SMALL_STATE(12656)] = 610424,
  [SMALL_STATE(12657)] = 610472,
  [SMALL_STATE(12658)] = 610518,
  [SMALL_STATE(12659)] = 610548,
  [SMALL_STATE(12660)] = 610600,
  [SMALL_STATE(12661)] = 610632,
  [SMALL_STATE(12662)] = 610680,
  [SMALL_STATE(12663)] = 610710,
  [SMALL_STATE(12664)] = 610744,
  [SMALL_STATE(12665)] = 610784,
  [SMALL_STATE(12666)] = 610814,
  [SMALL_STATE(12667)] = 610844,
  [SMALL_STATE(12668)] = 610892,
  [SMALL_STATE(12669)] = 610924,
  [SMALL_STATE(12670)] = 610976,
  [SMALL_STATE(12671)] = 611008,
  [SMALL_STATE(12672)] = 611054,
  [SMALL_STATE(12673)] = 611106,
  [SMALL_STATE(12674)] = 611148,
  [SMALL_STATE(12675)] = 611200,
  [SMALL_STATE(12676)] = 611232,
  [SMALL_STATE(12677)] = 611280,
  [SMALL_STATE(12678)] = 611328,
  [SMALL_STATE(12679)] = 611378,
  [SMALL_STATE(12680)] = 611428,
  [SMALL_STATE(12681)] = 611458,
  [SMALL_STATE(12682)] = 611506,
  [SMALL_STATE(12683)] = 611558,
  [SMALL_STATE(12684)] = 611606,
  [SMALL_STATE(12685)] = 611636,
  [SMALL_STATE(12686)] = 611686,
  [SMALL_STATE(12687)] = 611716,
  [SMALL_STATE(12688)] = 611746,
  [SMALL_STATE(12689)] = 611792,
  [SMALL_STATE(12690)] = 611846,
  [SMALL_STATE(12691)] = 611896,
  [SMALL_STATE(12692)] = 611926,
  [SMALL_STATE(12693)] = 611972,
  [SMALL_STATE(12694)] = 612020,
  [SMALL_STATE(12695)] = 612066,
  [SMALL_STATE(12696)] = 612096,
  [SMALL_STATE(12697)] = 612146,
  [SMALL_STATE(12698)] = 612176,
  [SMALL_STATE(12699)] = 612224,
  [SMALL_STATE(12700)] = 612272,
  [SMALL_STATE(12701)] = 612324,
  [SMALL_STATE(12702)] = 612372,
  [SMALL_STATE(12703)] = 612402,
  [SMALL_STATE(12704)] = 612452,
  [SMALL_STATE(12705)] = 612500,
  [SMALL_STATE(12706)] = 612546,
  [SMALL_STATE(12707)] = 612594,
  [SMALL_STATE(12708)] = 612624,
  [SMALL_STATE(12709)] = 612664,
  [SMALL_STATE(12710)] = 612712,
  [SMALL_STATE(12711)] = 612744,
  [SMALL_STATE(12712)] = 612792,
  [SMALL_STATE(12713)] = 612844,
  [SMALL_STATE(12714)] = 612892,
  [SMALL_STATE(12715)] = 612922,
  [SMALL_STATE(12716)] = 612952,
  [SMALL_STATE(12717)] = 612984,
  [SMALL_STATE(12718)] = 613014,
  [SMALL_STATE(12719)] = 613068,
  [SMALL_STATE(12720)] = 613116,
  [SMALL_STATE(12721)] = 613164,
  [SMALL_STATE(12722)] = 613212,
  [SMALL_STATE(12723)] = 613260,
  [SMALL_STATE(12724)] = 613292,
  [SMALL_STATE(12725)] = 613328,
  [SMALL_STATE(12726)] = 613358,
  [SMALL_STATE(12727)] = 613404,
  [SMALL_STATE(12728)] = 613434,
  [SMALL_STATE(12729)] = 613480,
  [SMALL_STATE(12730)] = 613510,
  [SMALL_STATE(12731)] = 613540,
  [SMALL_STATE(12732)] = 613572,
  [SMALL_STATE(12733)] = 613604,
  [SMALL_STATE(12734)] = 613644,
  [SMALL_STATE(12735)] = 613684,
  [SMALL_STATE(12736)] = 613738,
  [SMALL_STATE(12737)] = 613778,
  [SMALL_STATE(12738)] = 613818,
  [SMALL_STATE(12739)] = 613852,
  [SMALL_STATE(12740)] = 613886,
  [SMALL_STATE(12741)] = 613936,
  [SMALL_STATE(12742)] = 613976,
  [SMALL_STATE(12743)] = 614018,
  [SMALL_STATE(12744)] = 614066,
  [SMALL_STATE(12745)] = 614098,
  [SMALL_STATE(12746)] = 614130,
  [SMALL_STATE(12747)] = 614180,
  [SMALL_STATE(12748)] = 614228,
  [SMALL_STATE(12749)] = 614276,
  [SMALL_STATE(12750)] = 614316,
  [SMALL_STATE(12751)] = 614348,
  [SMALL_STATE(12752)] = 614400,
  [SMALL_STATE(12753)] = 614432,
  [SMALL_STATE(12754)] = 614482,
  [SMALL_STATE(12755)] = 614522,
  [SMALL_STATE(12756)] = 614554,
  [SMALL_STATE(12757)] = 614584,
  [SMALL_STATE(12758)] = 614636,
  [SMALL_STATE(12759)] = 614684,
  [SMALL_STATE(12760)] = 614716,
  [SMALL_STATE(12761)] = 614750,
  [SMALL_STATE(12762)] = 614796,
  [SMALL_STATE(12763)] = 614836,
  [SMALL_STATE(12764)] = 614884,
  [SMALL_STATE(12765)] = 614918,
  [SMALL_STATE(12766)] = 614958,
  [SMALL_STATE(12767)] = 615006,
  [SMALL_STATE(12768)] = 615038,
  [SMALL_STATE(12769)] = 615080,
  [SMALL_STATE(12770)] = 615128,
  [SMALL_STATE(12771)] = 615176,
  [SMALL_STATE(12772)] = 615218,
  [SMALL_STATE(12773)] = 615266,
  [SMALL_STATE(12774)] = 615298,
  [SMALL_STATE(12775)] = 615344,
  [SMALL_STATE(12776)] = 615390,
  [SMALL_STATE(12777)] = 615420,
  [SMALL_STATE(12778)] = 615452,
  [SMALL_STATE(12779)] = 615484,
  [SMALL_STATE(12780)] = 615516,
  [SMALL_STATE(12781)] = 615566,
  [SMALL_STATE(12782)] = 615614,
  [SMALL_STATE(12783)] = 615660,
  [SMALL_STATE(12784)] = 615692,
  [SMALL_STATE(12785)] = 615742,
  [SMALL_STATE(12786)] = 615774,
  [SMALL_STATE(12787)] = 615820,
  [SMALL_STATE(12788)] = 615860,
  [SMALL_STATE(12789)] = 615914,
  [SMALL_STATE(12790)] = 615960,
  [SMALL_STATE(12791)] = 616002,
  [SMALL_STATE(12792)] = 616052,
  [SMALL_STATE(12793)] = 616104,
  [SMALL_STATE(12794)] = 616152,
  [SMALL_STATE(12795)] = 616200,
  [SMALL_STATE(12796)] = 616246,
  [SMALL_STATE(12797)] = 616280,
  [SMALL_STATE(12798)] = 616314,
  [SMALL_STATE(12799)] = 616344,
  [SMALL_STATE(12800)] = 616386,
  [SMALL_STATE(12801)] = 616432,
  [SMALL_STATE(12802)] = 616480,
  [SMALL_STATE(12803)] = 616512,
  [SMALL_STATE(12804)] = 616548,
  [SMALL_STATE(12805)] = 616596,
  [SMALL_STATE(12806)] = 616646,
  [SMALL_STATE(12807)] = 616688,
  [SMALL_STATE(12808)] = 616738,
  [SMALL_STATE(12809)] = 616770,
  [SMALL_STATE(12810)] = 616818,
  [SMALL_STATE(12811)] = 616850,
  [SMALL_STATE(12812)] = 616896,
  [SMALL_STATE(12813)] = 616942,
  [SMALL_STATE(12814)] = 616992,
  [SMALL_STATE(12815)] = 617040,
  [SMALL_STATE(12816)] = 617068,
  [SMALL_STATE(12817)] = 617104,
  [SMALL_STATE(12818)] = 617150,
  [SMALL_STATE(12819)] = 617200,
  [SMALL_STATE(12820)] = 617232,
  [SMALL_STATE(12821)] = 617280,
  [SMALL_STATE(12822)] = 617316,
  [SMALL_STATE(12823)] = 617348,
  [SMALL_STATE(12824)] = 617398,
  [SMALL_STATE(12825)] = 617446,
  [SMALL_STATE(12826)] = 617497,
  [SMALL_STATE(12827)] = 617526,
  [SMALL_STATE(12828)] = 617577,
  [SMALL_STATE(12829)] = 617608,
  [SMALL_STATE(12830)] = 617651,
  [SMALL_STATE(12831)] = 617684,
  [SMALL_STATE(12832)] = 617735,
  [SMALL_STATE(12833)] = 617786,
  [SMALL_STATE(12834)] = 617837,
  [SMALL_STATE(12835)] = 617888,
  [SMALL_STATE(12836)] = 617939,
  [SMALL_STATE(12837)] = 617976,
  [SMALL_STATE(12838)] = 618013,
  [SMALL_STATE(12839)] = 618064,
  [SMALL_STATE(12840)] = 618095,
  [SMALL_STATE(12841)] = 618132,
  [SMALL_STATE(12842)] = 618183,
  [SMALL_STATE(12843)] = 618234,
  [SMALL_STATE(12844)] = 618285,
  [SMALL_STATE(12845)] = 618336,
  [SMALL_STATE(12846)] = 618373,
  [SMALL_STATE(12847)] = 618416,
  [SMALL_STATE(12848)] = 618459,
  [SMALL_STATE(12849)] = 618487,
  [SMALL_STATE(12850)] = 618535,
  [SMALL_STATE(12851)] = 618563,
  [SMALL_STATE(12852)] = 618597,
  [SMALL_STATE(12853)] = 618631,
  [SMALL_STATE(12854)] = 618659,
  [SMALL_STATE(12855)] = 618687,
  [SMALL_STATE(12856)] = 618715,
  [SMALL_STATE(12857)] = 618743,
  [SMALL_STATE(12858)] = 618771,
  [SMALL_STATE(12859)] = 618799,
  [SMALL_STATE(12860)] = 618827,
  [SMALL_STATE(12861)] = 618855,
  [SMALL_STATE(12862)] = 618883,
  [SMALL_STATE(12863)] = 618911,
  [SMALL_STATE(12864)] = 618945,
  [SMALL_STATE(12865)] = 618991,
  [SMALL_STATE(12866)] = 619019,
  [SMALL_STATE(12867)] = 619057,
  [SMALL_STATE(12868)] = 619085,
  [SMALL_STATE(12869)] = 619117,
  [SMALL_STATE(12870)] = 619151,
  [SMALL_STATE(12871)] = 619179,
  [SMALL_STATE(12872)] = 619207,
  [SMALL_STATE(12873)] = 619249,
  [SMALL_STATE(12874)] = 619297,
  [SMALL_STATE(12875)] = 619325,
  [SMALL_STATE(12876)] = 619353,
  [SMALL_STATE(12877)] = 619381,
  [SMALL_STATE(12878)] = 619415,
  [SMALL_STATE(12879)] = 619443,
  [SMALL_STATE(12880)] = 619475,
  [SMALL_STATE(12881)] = 619503,
  [SMALL_STATE(12882)] = 619545,
  [SMALL_STATE(12883)] = 619575,
  [SMALL_STATE(12884)] = 619603,
  [SMALL_STATE(12885)] = 619637,
  [SMALL_STATE(12886)] = 619685,
  [SMALL_STATE(12887)] = 619733,
  [SMALL_STATE(12888)] = 619761,
  [SMALL_STATE(12889)] = 619789,
  [SMALL_STATE(12890)] = 619817,
  [SMALL_STATE(12891)] = 619865,
  [SMALL_STATE(12892)] = 619893,
  [SMALL_STATE(12893)] = 619921,
  [SMALL_STATE(12894)] = 619967,
  [SMALL_STATE(12895)] = 620013,
  [SMALL_STATE(12896)] = 620041,
  [SMALL_STATE(12897)] = 620073,
  [SMALL_STATE(12898)] = 620119,
  [SMALL_STATE(12899)] = 620157,
  [SMALL_STATE(12900)] = 620203,
  [SMALL_STATE(12901)] = 620231,
  [SMALL_STATE(12902)] = 620265,
  [SMALL_STATE(12903)] = 620293,
  [SMALL_STATE(12904)] = 620321,
  [SMALL_STATE(12905)] = 620349,
  [SMALL_STATE(12906)] = 620377,
  [SMALL_STATE(12907)] = 620403,
  [SMALL_STATE(12908)] = 620437,
  [SMALL_STATE(12909)] = 620483,
  [SMALL_STATE(12910)] = 620511,
  [SMALL_STATE(12911)] = 620557,
  [SMALL_STATE(12912)] = 620603,
  [SMALL_STATE(12913)] = 620631,
  [SMALL_STATE(12914)] = 620659,
  [SMALL_STATE(12915)] = 620687,
  [SMALL_STATE(12916)] = 620729,
  [SMALL_STATE(12917)] = 620777,
  [SMALL_STATE(12918)] = 620805,
  [SMALL_STATE(12919)] = 620843,
  [SMALL_STATE(12920)] = 620879,
  [SMALL_STATE(12921)] = 620907,
  [SMALL_STATE(12922)] = 620937,
  [SMALL_STATE(12923)] = 620965,
  [SMALL_STATE(12924)] = 620993,
  [SMALL_STATE(12925)] = 621021,
  [SMALL_STATE(12926)] = 621060,
  [SMALL_STATE(12927)] = 621091,
  [SMALL_STATE(12928)] = 621122,
  [SMALL_STATE(12929)] = 621149,
  [SMALL_STATE(12930)] = 621176,
  [SMALL_STATE(12931)] = 621215,
  [SMALL_STATE(12932)] = 621244,
  [SMALL_STATE(12933)] = 621283,
  [SMALL_STATE(12934)] = 621310,
  [SMALL_STATE(12935)] = 621341,
  [SMALL_STATE(12936)] = 621368,
  [SMALL_STATE(12937)] = 621407,
  [SMALL_STATE(12938)] = 621450,
  [SMALL_STATE(12939)] = 621481,
  [SMALL_STATE(12940)] = 621512,
  [SMALL_STATE(12941)] = 621551,
  [SMALL_STATE(12942)] = 621590,
  [SMALL_STATE(12943)] = 621629,
  [SMALL_STATE(12944)] = 621660,
  [SMALL_STATE(12945)] = 621689,
  [SMALL_STATE(12946)] = 621728,
  [SMALL_STATE(12947)] = 621767,
  [SMALL_STATE(12948)] = 621794,
  [SMALL_STATE(12949)] = 621833,
  [SMALL_STATE(12950)] = 621864,
  [SMALL_STATE(12951)] = 621895,
  [SMALL_STATE(12952)] = 621934,
  [SMALL_STATE(12953)] = 621973,
  [SMALL_STATE(12954)] = 622004,
  [SMALL_STATE(12955)] = 622033,
  [SMALL_STATE(12956)] = 622076,
  [SMALL_STATE(12957)] = 622101,
  [SMALL_STATE(12958)] = 622140,
  [SMALL_STATE(12959)] = 622171,
  [SMALL_STATE(12960)] = 622210,
  [SMALL_STATE(12961)] = 622237,
  [SMALL_STATE(12962)] = 622276,
  [SMALL_STATE(12963)] = 622315,
  [SMALL_STATE(12964)] = 622354,
  [SMALL_STATE(12965)] = 622393,
  [SMALL_STATE(12966)] = 622432,
  [SMALL_STATE(12967)] = 622471,
  [SMALL_STATE(12968)] = 622502,
  [SMALL_STATE(12969)] = 622545,
  [SMALL_STATE(12970)] = 622572,
  [SMALL_STATE(12971)] = 622603,
  [SMALL_STATE(12972)] = 622642,
  [SMALL_STATE(12973)] = 622681,
  [SMALL_STATE(12974)] = 622720,
  [SMALL_STATE(12975)] = 622759,
  [SMALL_STATE(12976)] = 622798,
  [SMALL_STATE(12977)] = 622837,
  [SMALL_STATE(12978)] = 622864,
  [SMALL_STATE(12979)] = 622891,
  [SMALL_STATE(12980)] = 622918,
  [SMALL_STATE(12981)] = 622957,
  [SMALL_STATE(12982)] = 622988,
  [SMALL_STATE(12983)] = 623027,
  [SMALL_STATE(12984)] = 623054,
  [SMALL_STATE(12985)] = 623085,
  [SMALL_STATE(12986)] = 623116,
  [SMALL_STATE(12987)] = 623155,
  [SMALL_STATE(12988)] = 623194,
  [SMALL_STATE(12989)] = 623225,
  [SMALL_STATE(12990)] = 623256,
  [SMALL_STATE(12991)] = 623295,
  [SMALL_STATE(12992)] = 623326,
  [SMALL_STATE(12993)] = 623365,
  [SMALL_STATE(12994)] = 623392,
  [SMALL_STATE(12995)] = 623431,
  [SMALL_STATE(12996)] = 623470,
  [SMALL_STATE(12997)] = 623509,
  [SMALL_STATE(12998)] = 623540,
  [SMALL_STATE(12999)] = 623571,
  [SMALL_STATE(13000)] = 623602,
  [SMALL_STATE(13001)] = 623633,
  [SMALL_STATE(13002)] = 623664,
  [SMALL_STATE(13003)] = 623695,
  [SMALL_STATE(13004)] = 623726,
  [SMALL_STATE(13005)] = 623757,
  [SMALL_STATE(13006)] = 623788,
  [SMALL_STATE(13007)] = 623819,
  [SMALL_STATE(13008)] = 623858,
  [SMALL_STATE(13009)] = 623901,
  [SMALL_STATE(13010)] = 623932,
  [SMALL_STATE(13011)] = 623963,
  [SMALL_STATE(13012)] = 623994,
  [SMALL_STATE(13013)] = 624025,
  [SMALL_STATE(13014)] = 624064,
  [SMALL_STATE(13015)] = 624095,
  [SMALL_STATE(13016)] = 624126,
  [SMALL_STATE(13017)] = 624153,
  [SMALL_STATE(13018)] = 624184,
  [SMALL_STATE(13019)] = 624223,
  [SMALL_STATE(13020)] = 624254,
  [SMALL_STATE(13021)] = 624281,
  [SMALL_STATE(13022)] = 624312,
  [SMALL_STATE(13023)] = 624351,
  [SMALL_STATE(13024)] = 624382,
  [SMALL_STATE(13025)] = 624413,
  [SMALL_STATE(13026)] = 624444,
  [SMALL_STATE(13027)] = 624475,
  [SMALL_STATE(13028)] = 624506,
  [SMALL_STATE(13029)] = 624533,
  [SMALL_STATE(13030)] = 624564,
  [SMALL_STATE(13031)] = 624595,
  [SMALL_STATE(13032)] = 624634,
  [SMALL_STATE(13033)] = 624673,
  [SMALL_STATE(13034)] = 624700,
  [SMALL_STATE(13035)] = 624739,
  [SMALL_STATE(13036)] = 624778,
  [SMALL_STATE(13037)] = 624809,
  [SMALL_STATE(13038)] = 624852,
  [SMALL_STATE(13039)] = 624883,
  [SMALL_STATE(13040)] = 624910,
  [SMALL_STATE(13041)] = 624949,
  [SMALL_STATE(13042)] = 624988,
  [SMALL_STATE(13043)] = 625027,
  [SMALL_STATE(13044)] = 625056,
  [SMALL_STATE(13045)] = 625087,
  [SMALL_STATE(13046)] = 625118,
  [SMALL_STATE(13047)] = 625149,
  [SMALL_STATE(13048)] = 625180,
  [SMALL_STATE(13049)] = 625207,
  [SMALL_STATE(13050)] = 625246,
  [SMALL_STATE(13051)] = 625277,
  [SMALL_STATE(13052)] = 625316,
  [SMALL_STATE(13053)] = 625343,
  [SMALL_STATE(13054)] = 625382,
  [SMALL_STATE(13055)] = 625413,
  [SMALL_STATE(13056)] = 625448,
  [SMALL_STATE(13057)] = 625479,
  [SMALL_STATE(13058)] = 625522,
  [SMALL_STATE(13059)] = 625561,
  [SMALL_STATE(13060)] = 625600,
  [SMALL_STATE(13061)] = 625631,
  [SMALL_STATE(13062)] = 625662,
  [SMALL_STATE(13063)] = 625693,
  [SMALL_STATE(13064)] = 625732,
  [SMALL_STATE(13065)] = 625763,
  [SMALL_STATE(13066)] = 625802,
  [SMALL_STATE(13067)] = 625829,
  [SMALL_STATE(13068)] = 625868,
  [SMALL_STATE(13069)] = 625907,
  [SMALL_STATE(13070)] = 625946,
  [SMALL_STATE(13071)] = 625977,
  [SMALL_STATE(13072)] = 626008,
  [SMALL_STATE(13073)] = 626039,
  [SMALL_STATE(13074)] = 626070,
  [SMALL_STATE(13075)] = 626095,
  [SMALL_STATE(13076)] = 626134,
  [SMALL_STATE(13077)] = 626177,
  [SMALL_STATE(13078)] = 626204,
  [SMALL_STATE(13079)] = 626235,
  [SMALL_STATE(13080)] = 626262,
  [SMALL_STATE(13081)] = 626289,
  [SMALL_STATE(13082)] = 626328,
  [SMALL_STATE(13083)] = 626359,
  [SMALL_STATE(13084)] = 626386,
  [SMALL_STATE(13085)] = 626417,
  [SMALL_STATE(13086)] = 626456,
  [SMALL_STATE(13087)] = 626483,
  [SMALL_STATE(13088)] = 626514,
  [SMALL_STATE(13089)] = 626553,
  [SMALL_STATE(13090)] = 626584,
  [SMALL_STATE(13091)] = 626623,
  [SMALL_STATE(13092)] = 626662,
  [SMALL_STATE(13093)] = 626693,
  [SMALL_STATE(13094)] = 626736,
  [SMALL_STATE(13095)] = 626775,
  [SMALL_STATE(13096)] = 626814,
  [SMALL_STATE(13097)] = 626841,
  [SMALL_STATE(13098)] = 626880,
  [SMALL_STATE(13099)] = 626919,
  [SMALL_STATE(13100)] = 626958,
  [SMALL_STATE(13101)] = 626989,
  [SMALL_STATE(13102)] = 627020,
  [SMALL_STATE(13103)] = 627051,
  [SMALL_STATE(13104)] = 627090,
  [SMALL_STATE(13105)] = 627129,
  [SMALL_STATE(13106)] = 627156,
  [SMALL_STATE(13107)] = 627195,
  [SMALL_STATE(13108)] = 627238,
  [SMALL_STATE(13109)] = 627265,
  [SMALL_STATE(13110)] = 627304,
  [SMALL_STATE(13111)] = 627331,
  [SMALL_STATE(13112)] = 627362,
  [SMALL_STATE(13113)] = 627389,
  [SMALL_STATE(13114)] = 627416,
  [SMALL_STATE(13115)] = 627455,
  [SMALL_STATE(13116)] = 627494,
  [SMALL_STATE(13117)] = 627533,
  [SMALL_STATE(13118)] = 627572,
  [SMALL_STATE(13119)] = 627611,
  [SMALL_STATE(13120)] = 627650,
  [SMALL_STATE(13121)] = 627689,
  [SMALL_STATE(13122)] = 627728,
  [SMALL_STATE(13123)] = 627767,
  [SMALL_STATE(13124)] = 627806,
  [SMALL_STATE(13125)] = 627833,
  [SMALL_STATE(13126)] = 627860,
  [SMALL_STATE(13127)] = 627887,
  [SMALL_STATE(13128)] = 627926,
  [SMALL_STATE(13129)] = 627965,
  [SMALL_STATE(13130)] = 628004,
  [SMALL_STATE(13131)] = 628043,
  [SMALL_STATE(13132)] = 628086,
  [SMALL_STATE(13133)] = 628125,
  [SMALL_STATE(13134)] = 628156,
  [SMALL_STATE(13135)] = 628195,
  [SMALL_STATE(13136)] = 628222,
  [SMALL_STATE(13137)] = 628249,
  [SMALL_STATE(13138)] = 628288,
  [SMALL_STATE(13139)] = 628312,
  [SMALL_STATE(13140)] = 628336,
  [SMALL_STATE(13141)] = 628362,
  [SMALL_STATE(13142)] = 628392,
  [SMALL_STATE(13143)] = 628418,
  [SMALL_STATE(13144)] = 628448,
  [SMALL_STATE(13145)] = 628478,
  [SMALL_STATE(13146)] = 628508,
  [SMALL_STATE(13147)] = 628536,
  [SMALL_STATE(13148)] = 628566,
  [SMALL_STATE(13149)] = 628596,
  [SMALL_STATE(13150)] = 628626,
  [SMALL_STATE(13151)] = 628656,
  [SMALL_STATE(13152)] = 628686,
  [SMALL_STATE(13153)] = 628716,
  [SMALL_STATE(13154)] = 628746,
  [SMALL_STATE(13155)] = 628776,
  [SMALL_STATE(13156)] = 628802,
  [SMALL_STATE(13157)] = 628828,
  [SMALL_STATE(13158)] = 628854,
  [SMALL_STATE(13159)] = 628882,
  [SMALL_STATE(13160)] = 628908,
  [SMALL_STATE(13161)] = 628934,
  [SMALL_STATE(13162)] = 628964,
  [SMALL_STATE(13163)] = 628990,
  [SMALL_STATE(13164)] = 629016,
  [SMALL_STATE(13165)] = 629042,
  [SMALL_STATE(13166)] = 629072,
  [SMALL_STATE(13167)] = 629096,
  [SMALL_STATE(13168)] = 629122,
  [SMALL_STATE(13169)] = 629148,
  [SMALL_STATE(13170)] = 629174,
  [SMALL_STATE(13171)] = 629200,
  [SMALL_STATE(13172)] = 629226,
  [SMALL_STATE(13173)] = 629252,
  [SMALL_STATE(13174)] = 629278,
  [SMALL_STATE(13175)] = 629304,
  [SMALL_STATE(13176)] = 629330,
  [SMALL_STATE(13177)] = 629356,
  [SMALL_STATE(13178)] = 629382,
  [SMALL_STATE(13179)] = 629412,
  [SMALL_STATE(13180)] = 629438,
  [SMALL_STATE(13181)] = 629464,
  [SMALL_STATE(13182)] = 629490,
  [SMALL_STATE(13183)] = 629516,
  [SMALL_STATE(13184)] = 629542,
  [SMALL_STATE(13185)] = 629568,
  [SMALL_STATE(13186)] = 629594,
  [SMALL_STATE(13187)] = 629620,
  [SMALL_STATE(13188)] = 629646,
  [SMALL_STATE(13189)] = 629672,
  [SMALL_STATE(13190)] = 629702,
  [SMALL_STATE(13191)] = 629728,
  [SMALL_STATE(13192)] = 629754,
  [SMALL_STATE(13193)] = 629780,
  [SMALL_STATE(13194)] = 629813,
  [SMALL_STATE(13195)] = 629854,
  [SMALL_STATE(13196)] = 629893,
  [SMALL_STATE(13197)] = 629916,
  [SMALL_STATE(13198)] = 629939,
  [SMALL_STATE(13199)] = 629968,
  [SMALL_STATE(13200)] = 630007,
  [SMALL_STATE(13201)] = 630048,
  [SMALL_STATE(13202)] = 630089,
  [SMALL_STATE(13203)] = 630118,
  [SMALL_STATE(13204)] = 630141,
  [SMALL_STATE(13205)] = 630164,
  [SMALL_STATE(13206)] = 630203,
  [SMALL_STATE(13207)] = 630226,
  [SMALL_STATE(13208)] = 630249,
  [SMALL_STATE(13209)] = 630288,
  [SMALL_STATE(13210)] = 630313,
  [SMALL_STATE(13211)] = 630336,
  [SMALL_STATE(13212)] = 630359,
  [SMALL_STATE(13213)] = 630398,
  [SMALL_STATE(13214)] = 630421,
  [SMALL_STATE(13215)] = 630450,
  [SMALL_STATE(13216)] = 630473,
  [SMALL_STATE(13217)] = 630512,
  [SMALL_STATE(13218)] = 630545,
  [SMALL_STATE(13219)] = 630572,
  [SMALL_STATE(13220)] = 630599,
  [SMALL_STATE(13221)] = 630640,
  [SMALL_STATE(13222)] = 630665,
  [SMALL_STATE(13223)] = 630694,
  [SMALL_STATE(13224)] = 630717,
  [SMALL_STATE(13225)] = 630742,
  [SMALL_STATE(13226)] = 630769,
  [SMALL_STATE(13227)] = 630792,
  [SMALL_STATE(13228)] = 630819,
  [SMALL_STATE(13229)] = 630844,
  [SMALL_STATE(13230)] = 630883,
  [SMALL_STATE(13231)] = 630912,
  [SMALL_STATE(13232)] = 630935,
  [SMALL_STATE(13233)] = 630974,
  [SMALL_STATE(13234)] = 630997,
  [SMALL_STATE(13235)] = 631038,
  [SMALL_STATE(13236)] = 631079,
  [SMALL_STATE(13237)] = 631102,
  [SMALL_STATE(13238)] = 631127,
  [SMALL_STATE(13239)] = 631150,
  [SMALL_STATE(13240)] = 631173,
  [SMALL_STATE(13241)] = 631199,
  [SMALL_STATE(13242)] = 631229,
  [SMALL_STATE(13243)] = 631267,
  [SMALL_STATE(13244)] = 631297,
  [SMALL_STATE(13245)] = 631319,
  [SMALL_STATE(13246)] = 631357,
  [SMALL_STATE(13247)] = 631395,
  [SMALL_STATE(13248)] = 631425,
  [SMALL_STATE(13249)] = 631459,
  [SMALL_STATE(13250)] = 631495,
  [SMALL_STATE(13251)] = 631529,
  [SMALL_STATE(13252)] = 631559,
  [SMALL_STATE(13253)] = 631583,
  [SMALL_STATE(13254)] = 631613,
  [SMALL_STATE(13255)] = 631643,
  [SMALL_STATE(13256)] = 631681,
  [SMALL_STATE(13257)] = 631711,
  [SMALL_STATE(13258)] = 631749,
  [SMALL_STATE(13259)] = 631771,
  [SMALL_STATE(13260)] = 631809,
  [SMALL_STATE(13261)] = 631833,
  [SMALL_STATE(13262)] = 631869,
  [SMALL_STATE(13263)] = 631907,
  [SMALL_STATE(13264)] = 631931,
  [SMALL_STATE(13265)] = 631961,
  [SMALL_STATE(13266)] = 631985,
  [SMALL_STATE(13267)] = 632015,
  [SMALL_STATE(13268)] = 632049,
  [SMALL_STATE(13269)] = 632079,
  [SMALL_STATE(13270)] = 632109,
  [SMALL_STATE(13271)] = 632139,
  [SMALL_STATE(13272)] = 632173,
  [SMALL_STATE(13273)] = 632207,
  [SMALL_STATE(13274)] = 632237,
  [SMALL_STATE(13275)] = 632267,
  [SMALL_STATE(13276)] = 632305,
  [SMALL_STATE(13277)] = 632343,
  [SMALL_STATE(13278)] = 632381,
  [SMALL_STATE(13279)] = 632411,
  [SMALL_STATE(13280)] = 632435,
  [SMALL_STATE(13281)] = 632473,
  [SMALL_STATE(13282)] = 632511,
  [SMALL_STATE(13283)] = 632535,
  [SMALL_STATE(13284)] = 632569,
  [SMALL_STATE(13285)] = 632607,
  [SMALL_STATE(13286)] = 632637,
  [SMALL_STATE(13287)] = 632661,
  [SMALL_STATE(13288)] = 632695,
  [SMALL_STATE(13289)] = 632733,
  [SMALL_STATE(13290)] = 632771,
  [SMALL_STATE(13291)] = 632805,
  [SMALL_STATE(13292)] = 632843,
  [SMALL_STATE(13293)] = 632873,
  [SMALL_STATE(13294)] = 632897,
  [SMALL_STATE(13295)] = 632921,
  [SMALL_STATE(13296)] = 632951,
  [SMALL_STATE(13297)] = 632981,
  [SMALL_STATE(13298)] = 633005,
  [SMALL_STATE(13299)] = 633039,
  [SMALL_STATE(13300)] = 633063,
  [SMALL_STATE(13301)] = 633093,
  [SMALL_STATE(13302)] = 633129,
  [SMALL_STATE(13303)] = 633153,
  [SMALL_STATE(13304)] = 633189,
  [SMALL_STATE(13305)] = 633219,
  [SMALL_STATE(13306)] = 633257,
  [SMALL_STATE(13307)] = 633283,
  [SMALL_STATE(13308)] = 633317,
  [SMALL_STATE(13309)] = 633341,
  [SMALL_STATE(13310)] = 633365,
  [SMALL_STATE(13311)] = 633389,
  [SMALL_STATE(13312)] = 633411,
  [SMALL_STATE(13313)] = 633435,
  [SMALL_STATE(13314)] = 633473,
  [SMALL_STATE(13315)] = 633497,
  [SMALL_STATE(13316)] = 633521,
  [SMALL_STATE(13317)] = 633545,
  [SMALL_STATE(13318)] = 633575,
  [SMALL_STATE(13319)] = 633605,
  [SMALL_STATE(13320)] = 633635,
  [SMALL_STATE(13321)] = 633665,
  [SMALL_STATE(13322)] = 633703,
  [SMALL_STATE(13323)] = 633733,
  [SMALL_STATE(13324)] = 633763,
  [SMALL_STATE(13325)] = 633793,
  [SMALL_STATE(13326)] = 633819,
  [SMALL_STATE(13327)] = 633849,
  [SMALL_STATE(13328)] = 633871,
  [SMALL_STATE(13329)] = 633901,
  [SMALL_STATE(13330)] = 633929,
  [SMALL_STATE(13331)] = 633953,
  [SMALL_STATE(13332)] = 633991,
  [SMALL_STATE(13333)] = 634015,
  [SMALL_STATE(13334)] = 634041,
  [SMALL_STATE(13335)] = 634071,
  [SMALL_STATE(13336)] = 634105,
  [SMALL_STATE(13337)] = 634135,
  [SMALL_STATE(13338)] = 634165,
  [SMALL_STATE(13339)] = 634199,
  [SMALL_STATE(13340)] = 634221,
  [SMALL_STATE(13341)] = 634251,
  [SMALL_STATE(13342)] = 634281,
  [SMALL_STATE(13343)] = 634319,
  [SMALL_STATE(13344)] = 634349,
  [SMALL_STATE(13345)] = 634387,
  [SMALL_STATE(13346)] = 634421,
  [SMALL_STATE(13347)] = 634459,
  [SMALL_STATE(13348)] = 634497,
  [SMALL_STATE(13349)] = 634535,
  [SMALL_STATE(13350)] = 634559,
  [SMALL_STATE(13351)] = 634589,
  [SMALL_STATE(13352)] = 634623,
  [SMALL_STATE(13353)] = 634653,
  [SMALL_STATE(13354)] = 634691,
  [SMALL_STATE(13355)] = 634715,
  [SMALL_STATE(13356)] = 634739,
  [SMALL_STATE(13357)] = 634773,
  [SMALL_STATE(13358)] = 634797,
  [SMALL_STATE(13359)] = 634821,
  [SMALL_STATE(13360)] = 634859,
  [SMALL_STATE(13361)] = 634897,
  [SMALL_STATE(13362)] = 634921,
  [SMALL_STATE(13363)] = 634951,
  [SMALL_STATE(13364)] = 634975,
  [SMALL_STATE(13365)] = 635013,
  [SMALL_STATE(13366)] = 635043,
  [SMALL_STATE(13367)] = 635073,
  [SMALL_STATE(13368)] = 635107,
  [SMALL_STATE(13369)] = 635131,
  [SMALL_STATE(13370)] = 635161,
  [SMALL_STATE(13371)] = 635197,
  [SMALL_STATE(13372)] = 635227,
  [SMALL_STATE(13373)] = 635263,
  [SMALL_STATE(13374)] = 635293,
  [SMALL_STATE(13375)] = 635331,
  [SMALL_STATE(13376)] = 635369,
  [SMALL_STATE(13377)] = 635399,
  [SMALL_STATE(13378)] = 635433,
  [SMALL_STATE(13379)] = 635463,
  [SMALL_STATE(13380)] = 635499,
  [SMALL_STATE(13381)] = 635535,
  [SMALL_STATE(13382)] = 635573,
  [SMALL_STATE(13383)] = 635611,
  [SMALL_STATE(13384)] = 635647,
  [SMALL_STATE(13385)] = 635685,
  [SMALL_STATE(13386)] = 635715,
  [SMALL_STATE(13387)] = 635753,
  [SMALL_STATE(13388)] = 635783,
  [SMALL_STATE(13389)] = 635813,
  [SMALL_STATE(13390)] = 635843,
  [SMALL_STATE(13391)] = 635873,
  [SMALL_STATE(13392)] = 635909,
  [SMALL_STATE(13393)] = 635939,
  [SMALL_STATE(13394)] = 635969,
  [SMALL_STATE(13395)] = 636003,
  [SMALL_STATE(13396)] = 636041,
  [SMALL_STATE(13397)] = 636071,
  [SMALL_STATE(13398)] = 636109,
  [SMALL_STATE(13399)] = 636131,
  [SMALL_STATE(13400)] = 636155,
  [SMALL_STATE(13401)] = 636185,
  [SMALL_STATE(13402)] = 636221,
  [SMALL_STATE(13403)] = 636247,
  [SMALL_STATE(13404)] = 636269,
  [SMALL_STATE(13405)] = 636307,
  [SMALL_STATE(13406)] = 636329,
  [SMALL_STATE(13407)] = 636367,
  [SMALL_STATE(13408)] = 636403,
  [SMALL_STATE(13409)] = 636439,
  [SMALL_STATE(13410)] = 636463,
  [SMALL_STATE(13411)] = 636497,
  [SMALL_STATE(13412)] = 636533,
  [SMALL_STATE(13413)] = 636563,
  [SMALL_STATE(13414)] = 636593,
  [SMALL_STATE(13415)] = 636631,
  [SMALL_STATE(13416)] = 636669,
  [SMALL_STATE(13417)] = 636707,
  [SMALL_STATE(13418)] = 636745,
  [SMALL_STATE(13419)] = 636769,
  [SMALL_STATE(13420)] = 636799,
  [SMALL_STATE(13421)] = 636837,
  [SMALL_STATE(13422)] = 636875,
  [SMALL_STATE(13423)] = 636910,
  [SMALL_STATE(13424)] = 636945,
  [SMALL_STATE(13425)] = 636980,
  [SMALL_STATE(13426)] = 637013,
  [SMALL_STATE(13427)] = 637040,
  [SMALL_STATE(13428)] = 637075,
  [SMALL_STATE(13429)] = 637110,
  [SMALL_STATE(13430)] = 637135,
  [SMALL_STATE(13431)] = 637170,
  [SMALL_STATE(13432)] = 637203,
  [SMALL_STATE(13433)] = 637238,
  [SMALL_STATE(13434)] = 637273,
  [SMALL_STATE(13435)] = 637300,
  [SMALL_STATE(13436)] = 637333,
  [SMALL_STATE(13437)] = 637366,
  [SMALL_STATE(13438)] = 637387,
  [SMALL_STATE(13439)] = 637422,
  [SMALL_STATE(13440)] = 637447,
  [SMALL_STATE(13441)] = 637480,
  [SMALL_STATE(13442)] = 637501,
  [SMALL_STATE(13443)] = 637536,
  [SMALL_STATE(13444)] = 637569,
  [SMALL_STATE(13445)] = 637604,
  [SMALL_STATE(13446)] = 637637,
  [SMALL_STATE(13447)] = 637664,
  [SMALL_STATE(13448)] = 637699,
  [SMALL_STATE(13449)] = 637734,
  [SMALL_STATE(13450)] = 637767,
  [SMALL_STATE(13451)] = 637802,
  [SMALL_STATE(13452)] = 637827,
  [SMALL_STATE(13453)] = 637862,
  [SMALL_STATE(13454)] = 637895,
  [SMALL_STATE(13455)] = 637928,
  [SMALL_STATE(13456)] = 637961,
  [SMALL_STATE(13457)] = 637996,
  [SMALL_STATE(13458)] = 638023,
  [SMALL_STATE(13459)] = 638048,
  [SMALL_STATE(13460)] = 638081,
  [SMALL_STATE(13461)] = 638116,
  [SMALL_STATE(13462)] = 638151,
  [SMALL_STATE(13463)] = 638186,
  [SMALL_STATE(13464)] = 638219,
  [SMALL_STATE(13465)] = 638242,
  [SMALL_STATE(13466)] = 638277,
  [SMALL_STATE(13467)] = 638310,
  [SMALL_STATE(13468)] = 638343,
  [SMALL_STATE(13469)] = 638378,
  [SMALL_STATE(13470)] = 638411,
  [SMALL_STATE(13471)] = 638444,
  [SMALL_STATE(13472)] = 638471,
  [SMALL_STATE(13473)] = 638504,
  [SMALL_STATE(13474)] = 638537,
  [SMALL_STATE(13475)] = 638570,
  [SMALL_STATE(13476)] = 638605,
  [SMALL_STATE(13477)] = 638638,
  [SMALL_STATE(13478)] = 638663,
  [SMALL_STATE(13479)] = 638696,
  [SMALL_STATE(13480)] = 638731,
  [SMALL_STATE(13481)] = 638766,
  [SMALL_STATE(13482)] = 638789,
  [SMALL_STATE(13483)] = 638812,
  [SMALL_STATE(13484)] = 638847,
  [SMALL_STATE(13485)] = 638872,
  [SMALL_STATE(13486)] = 638907,
  [SMALL_STATE(13487)] = 638942,
  [SMALL_STATE(13488)] = 638965,
  [SMALL_STATE(13489)] = 638998,
  [SMALL_STATE(13490)] = 639019,
  [SMALL_STATE(13491)] = 639052,
  [SMALL_STATE(13492)] = 639085,
  [SMALL_STATE(13493)] = 639120,
  [SMALL_STATE(13494)] = 639153,
  [SMALL_STATE(13495)] = 639186,
  [SMALL_STATE(13496)] = 639219,
  [SMALL_STATE(13497)] = 639251,
  [SMALL_STATE(13498)] = 639275,
  [SMALL_STATE(13499)] = 639307,
  [SMALL_STATE(13500)] = 639337,
  [SMALL_STATE(13501)] = 639357,
  [SMALL_STATE(13502)] = 639381,
  [SMALL_STATE(13503)] = 639413,
  [SMALL_STATE(13504)] = 639445,
  [SMALL_STATE(13505)] = 639477,
  [SMALL_STATE(13506)] = 639509,
  [SMALL_STATE(13507)] = 639531,
  [SMALL_STATE(13508)] = 639563,
  [SMALL_STATE(13509)] = 639587,
  [SMALL_STATE(13510)] = 639609,
  [SMALL_STATE(13511)] = 639641,
  [SMALL_STATE(13512)] = 639673,
  [SMALL_STATE(13513)] = 639705,
  [SMALL_STATE(13514)] = 639737,
  [SMALL_STATE(13515)] = 639769,
  [SMALL_STATE(13516)] = 639801,
  [SMALL_STATE(13517)] = 639829,
  [SMALL_STATE(13518)] = 639853,
  [SMALL_STATE(13519)] = 639885,
  [SMALL_STATE(13520)] = 639915,
  [SMALL_STATE(13521)] = 639947,
  [SMALL_STATE(13522)] = 639979,
  [SMALL_STATE(13523)] = 639999,
  [SMALL_STATE(13524)] = 640021,
  [SMALL_STATE(13525)] = 640053,
  [SMALL_STATE(13526)] = 640085,
  [SMALL_STATE(13527)] = 640117,
  [SMALL_STATE(13528)] = 640149,
  [SMALL_STATE(13529)] = 640181,
  [SMALL_STATE(13530)] = 640213,
  [SMALL_STATE(13531)] = 640245,
  [SMALL_STATE(13532)] = 640277,
  [SMALL_STATE(13533)] = 640309,
  [SMALL_STATE(13534)] = 640341,
  [SMALL_STATE(13535)] = 640373,
  [SMALL_STATE(13536)] = 640405,
  [SMALL_STATE(13537)] = 640437,
  [SMALL_STATE(13538)] = 640467,
  [SMALL_STATE(13539)] = 640499,
  [SMALL_STATE(13540)] = 640531,
  [SMALL_STATE(13541)] = 640551,
  [SMALL_STATE(13542)] = 640583,
  [SMALL_STATE(13543)] = 640613,
  [SMALL_STATE(13544)] = 640645,
  [SMALL_STATE(13545)] = 640677,
  [SMALL_STATE(13546)] = 640709,
  [SMALL_STATE(13547)] = 640741,
  [SMALL_STATE(13548)] = 640773,
  [SMALL_STATE(13549)] = 640805,
  [SMALL_STATE(13550)] = 640827,
  [SMALL_STATE(13551)] = 640859,
  [SMALL_STATE(13552)] = 640889,
  [SMALL_STATE(13553)] = 640921,
  [SMALL_STATE(13554)] = 640951,
  [SMALL_STATE(13555)] = 640983,
  [SMALL_STATE(13556)] = 641015,
  [SMALL_STATE(13557)] = 641047,
  [SMALL_STATE(13558)] = 641079,
  [SMALL_STATE(13559)] = 641109,
  [SMALL_STATE(13560)] = 641141,
  [SMALL_STATE(13561)] = 641173,
  [SMALL_STATE(13562)] = 641205,
  [SMALL_STATE(13563)] = 641227,
  [SMALL_STATE(13564)] = 641259,
  [SMALL_STATE(13565)] = 641281,
  [SMALL_STATE(13566)] = 641311,
  [SMALL_STATE(13567)] = 641341,
  [SMALL_STATE(13568)] = 641373,
  [SMALL_STATE(13569)] = 641403,
  [SMALL_STATE(13570)] = 641435,
  [SMALL_STATE(13571)] = 641467,
  [SMALL_STATE(13572)] = 641489,
  [SMALL_STATE(13573)] = 641521,
  [SMALL_STATE(13574)] = 641553,
  [SMALL_STATE(13575)] = 641577,
  [SMALL_STATE(13576)] = 641609,
  [SMALL_STATE(13577)] = 641641,
  [SMALL_STATE(13578)] = 641663,
  [SMALL_STATE(13579)] = 641687,
  [SMALL_STATE(13580)] = 641719,
  [SMALL_STATE(13581)] = 641741,
  [SMALL_STATE(13582)] = 641773,
  [SMALL_STATE(13583)] = 641797,
  [SMALL_STATE(13584)] = 641827,
  [SMALL_STATE(13585)] = 641859,
  [SMALL_STATE(13586)] = 641881,
  [SMALL_STATE(13587)] = 641913,
  [SMALL_STATE(13588)] = 641945,
  [SMALL_STATE(13589)] = 641977,
  [SMALL_STATE(13590)] = 642009,
  [SMALL_STATE(13591)] = 642041,
  [SMALL_STATE(13592)] = 642073,
  [SMALL_STATE(13593)] = 642105,
  [SMALL_STATE(13594)] = 642135,
  [SMALL_STATE(13595)] = 642155,
  [SMALL_STATE(13596)] = 642187,
  [SMALL_STATE(13597)] = 642219,
  [SMALL_STATE(13598)] = 642251,
  [SMALL_STATE(13599)] = 642271,
  [SMALL_STATE(13600)] = 642301,
  [SMALL_STATE(13601)] = 642333,
  [SMALL_STATE(13602)] = 642357,
  [SMALL_STATE(13603)] = 642389,
  [SMALL_STATE(13604)] = 642421,
  [SMALL_STATE(13605)] = 642443,
  [SMALL_STATE(13606)] = 642465,
  [SMALL_STATE(13607)] = 642497,
  [SMALL_STATE(13608)] = 642521,
  [SMALL_STATE(13609)] = 642553,
  [SMALL_STATE(13610)] = 642585,
  [SMALL_STATE(13611)] = 642617,
  [SMALL_STATE(13612)] = 642649,
  [SMALL_STATE(13613)] = 642681,
  [SMALL_STATE(13614)] = 642713,
  [SMALL_STATE(13615)] = 642743,
  [SMALL_STATE(13616)] = 642775,
  [SMALL_STATE(13617)] = 642807,
  [SMALL_STATE(13618)] = 642839,
  [SMALL_STATE(13619)] = 642871,
  [SMALL_STATE(13620)] = 642903,
  [SMALL_STATE(13621)] = 642925,
  [SMALL_STATE(13622)] = 642957,
  [SMALL_STATE(13623)] = 642989,
  [SMALL_STATE(13624)] = 643019,
  [SMALL_STATE(13625)] = 643051,
  [SMALL_STATE(13626)] = 643083,
  [SMALL_STATE(13627)] = 643115,
  [SMALL_STATE(13628)] = 643147,
  [SMALL_STATE(13629)] = 643179,
  [SMALL_STATE(13630)] = 643211,
  [SMALL_STATE(13631)] = 643241,
  [SMALL_STATE(13632)] = 643273,
  [SMALL_STATE(13633)] = 643305,
  [SMALL_STATE(13634)] = 643333,
  [SMALL_STATE(13635)] = 643365,
  [SMALL_STATE(13636)] = 643397,
  [SMALL_STATE(13637)] = 643429,
  [SMALL_STATE(13638)] = 643453,
  [SMALL_STATE(13639)] = 643475,
  [SMALL_STATE(13640)] = 643497,
  [SMALL_STATE(13641)] = 643529,
  [SMALL_STATE(13642)] = 643561,
  [SMALL_STATE(13643)] = 643593,
  [SMALL_STATE(13644)] = 643625,
  [SMALL_STATE(13645)] = 643657,
  [SMALL_STATE(13646)] = 643687,
  [SMALL_STATE(13647)] = 643719,
  [SMALL_STATE(13648)] = 643751,
  [SMALL_STATE(13649)] = 643783,
  [SMALL_STATE(13650)] = 643815,
  [SMALL_STATE(13651)] = 643847,
  [SMALL_STATE(13652)] = 643879,
  [SMALL_STATE(13653)] = 643911,
  [SMALL_STATE(13654)] = 643943,
  [SMALL_STATE(13655)] = 643973,
  [SMALL_STATE(13656)] = 644005,
  [SMALL_STATE(13657)] = 644037,
  [SMALL_STATE(13658)] = 644059,
  [SMALL_STATE(13659)] = 644091,
  [SMALL_STATE(13660)] = 644123,
  [SMALL_STATE(13661)] = 644155,
  [SMALL_STATE(13662)] = 644179,
  [SMALL_STATE(13663)] = 644211,
  [SMALL_STATE(13664)] = 644243,
  [SMALL_STATE(13665)] = 644275,
  [SMALL_STATE(13666)] = 644307,
  [SMALL_STATE(13667)] = 644339,
  [SMALL_STATE(13668)] = 644371,
  [SMALL_STATE(13669)] = 644401,
  [SMALL_STATE(13670)] = 644433,
  [SMALL_STATE(13671)] = 644453,
  [SMALL_STATE(13672)] = 644485,
  [SMALL_STATE(13673)] = 644517,
  [SMALL_STATE(13674)] = 644549,
  [SMALL_STATE(13675)] = 644571,
  [SMALL_STATE(13676)] = 644603,
  [SMALL_STATE(13677)] = 644625,
  [SMALL_STATE(13678)] = 644653,
  [SMALL_STATE(13679)] = 644685,
  [SMALL_STATE(13680)] = 644707,
  [SMALL_STATE(13681)] = 644737,
  [SMALL_STATE(13682)] = 644769,
  [SMALL_STATE(13683)] = 644801,
  [SMALL_STATE(13684)] = 644833,
  [SMALL_STATE(13685)] = 644863,
  [SMALL_STATE(13686)] = 644895,
  [SMALL_STATE(13687)] = 644927,
  [SMALL_STATE(13688)] = 644959,
  [SMALL_STATE(13689)] = 644991,
  [SMALL_STATE(13690)] = 645023,
  [SMALL_STATE(13691)] = 645053,
  [SMALL_STATE(13692)] = 645085,
  [SMALL_STATE(13693)] = 645109,
  [SMALL_STATE(13694)] = 645141,
  [SMALL_STATE(13695)] = 645163,
  [SMALL_STATE(13696)] = 645193,
  [SMALL_STATE(13697)] = 645225,
  [SMALL_STATE(13698)] = 645257,
  [SMALL_STATE(13699)] = 645289,
  [SMALL_STATE(13700)] = 645321,
  [SMALL_STATE(13701)] = 645343,
  [SMALL_STATE(13702)] = 645365,
  [SMALL_STATE(13703)] = 645397,
  [SMALL_STATE(13704)] = 645419,
  [SMALL_STATE(13705)] = 645451,
  [SMALL_STATE(13706)] = 645481,
  [SMALL_STATE(13707)] = 645513,
  [SMALL_STATE(13708)] = 645545,
  [SMALL_STATE(13709)] = 645577,
  [SMALL_STATE(13710)] = 645605,
  [SMALL_STATE(13711)] = 645633,
  [SMALL_STATE(13712)] = 645655,
  [SMALL_STATE(13713)] = 645687,
  [SMALL_STATE(13714)] = 645719,
  [SMALL_STATE(13715)] = 645749,
  [SMALL_STATE(13716)] = 645779,
  [SMALL_STATE(13717)] = 645811,
  [SMALL_STATE(13718)] = 645833,
  [SMALL_STATE(13719)] = 645855,
  [SMALL_STATE(13720)] = 645887,
  [SMALL_STATE(13721)] = 645913,
  [SMALL_STATE(13722)] = 645945,
  [SMALL_STATE(13723)] = 645977,
  [SMALL_STATE(13724)] = 646009,
  [SMALL_STATE(13725)] = 646031,
  [SMALL_STATE(13726)] = 646053,
  [SMALL_STATE(13727)] = 646075,
  [SMALL_STATE(13728)] = 646097,
  [SMALL_STATE(13729)] = 646129,
  [SMALL_STATE(13730)] = 646151,
  [SMALL_STATE(13731)] = 646173,
  [SMALL_STATE(13732)] = 646205,
  [SMALL_STATE(13733)] = 646237,
  [SMALL_STATE(13734)] = 646269,
  [SMALL_STATE(13735)] = 646289,
  [SMALL_STATE(13736)] = 646311,
  [SMALL_STATE(13737)] = 646343,
  [SMALL_STATE(13738)] = 646365,
  [SMALL_STATE(13739)] = 646397,
  [SMALL_STATE(13740)] = 646429,
  [SMALL_STATE(13741)] = 646451,
  [SMALL_STATE(13742)] = 646483,
  [SMALL_STATE(13743)] = 646515,
  [SMALL_STATE(13744)] = 646547,
  [SMALL_STATE(13745)] = 646579,
  [SMALL_STATE(13746)] = 646611,
  [SMALL_STATE(13747)] = 646643,
  [SMALL_STATE(13748)] = 646675,
  [SMALL_STATE(13749)] = 646707,
  [SMALL_STATE(13750)] = 646729,
  [SMALL_STATE(13751)] = 646761,
  [SMALL_STATE(13752)] = 646793,
  [SMALL_STATE(13753)] = 646815,
  [SMALL_STATE(13754)] = 646847,
  [SMALL_STATE(13755)] = 646869,
  [SMALL_STATE(13756)] = 646891,
  [SMALL_STATE(13757)] = 646923,
  [SMALL_STATE(13758)] = 646953,
  [SMALL_STATE(13759)] = 646985,
  [SMALL_STATE(13760)] = 647017,
  [SMALL_STATE(13761)] = 647049,
  [SMALL_STATE(13762)] = 647079,
  [SMALL_STATE(13763)] = 647103,
  [SMALL_STATE(13764)] = 647133,
  [SMALL_STATE(13765)] = 647155,
  [SMALL_STATE(13766)] = 647187,
  [SMALL_STATE(13767)] = 647219,
  [SMALL_STATE(13768)] = 647251,
  [SMALL_STATE(13769)] = 647283,
  [SMALL_STATE(13770)] = 647315,
  [SMALL_STATE(13771)] = 647347,
  [SMALL_STATE(13772)] = 647377,
  [SMALL_STATE(13773)] = 647409,
  [SMALL_STATE(13774)] = 647441,
  [SMALL_STATE(13775)] = 647473,
  [SMALL_STATE(13776)] = 647505,
  [SMALL_STATE(13777)] = 647537,
  [SMALL_STATE(13778)] = 647569,
  [SMALL_STATE(13779)] = 647601,
  [SMALL_STATE(13780)] = 647633,
  [SMALL_STATE(13781)] = 647657,
  [SMALL_STATE(13782)] = 647689,
  [SMALL_STATE(13783)] = 647721,
  [SMALL_STATE(13784)] = 647751,
  [SMALL_STATE(13785)] = 647783,
  [SMALL_STATE(13786)] = 647815,
  [SMALL_STATE(13787)] = 647845,
  [SMALL_STATE(13788)] = 647877,
  [SMALL_STATE(13789)] = 647909,
  [SMALL_STATE(13790)] = 647941,
  [SMALL_STATE(13791)] = 647973,
  [SMALL_STATE(13792)] = 648005,
  [SMALL_STATE(13793)] = 648037,
  [SMALL_STATE(13794)] = 648069,
  [SMALL_STATE(13795)] = 648099,
  [SMALL_STATE(13796)] = 648121,
  [SMALL_STATE(13797)] = 648143,
  [SMALL_STATE(13798)] = 648165,
  [SMALL_STATE(13799)] = 648193,
  [SMALL_STATE(13800)] = 648213,
  [SMALL_STATE(13801)] = 648245,
  [SMALL_STATE(13802)] = 648277,
  [SMALL_STATE(13803)] = 648309,
  [SMALL_STATE(13804)] = 648341,
  [SMALL_STATE(13805)] = 648373,
  [SMALL_STATE(13806)] = 648405,
  [SMALL_STATE(13807)] = 648437,
  [SMALL_STATE(13808)] = 648469,
  [SMALL_STATE(13809)] = 648501,
  [SMALL_STATE(13810)] = 648521,
  [SMALL_STATE(13811)] = 648553,
  [SMALL_STATE(13812)] = 648585,
  [SMALL_STATE(13813)] = 648617,
  [SMALL_STATE(13814)] = 648641,
  [SMALL_STATE(13815)] = 648673,
  [SMALL_STATE(13816)] = 648705,
  [SMALL_STATE(13817)] = 648737,
  [SMALL_STATE(13818)] = 648769,
  [SMALL_STATE(13819)] = 648801,
  [SMALL_STATE(13820)] = 648833,
  [SMALL_STATE(13821)] = 648865,
  [SMALL_STATE(13822)] = 648897,
  [SMALL_STATE(13823)] = 648929,
  [SMALL_STATE(13824)] = 648961,
  [SMALL_STATE(13825)] = 648993,
  [SMALL_STATE(13826)] = 649013,
  [SMALL_STATE(13827)] = 649035,
  [SMALL_STATE(13828)] = 649067,
  [SMALL_STATE(13829)] = 649099,
  [SMALL_STATE(13830)] = 649129,
  [SMALL_STATE(13831)] = 649151,
  [SMALL_STATE(13832)] = 649180,
  [SMALL_STATE(13833)] = 649201,
  [SMALL_STATE(13834)] = 649228,
  [SMALL_STATE(13835)] = 649257,
  [SMALL_STATE(13836)] = 649286,
  [SMALL_STATE(13837)] = 649307,
  [SMALL_STATE(13838)] = 649328,
  [SMALL_STATE(13839)] = 649357,
  [SMALL_STATE(13840)] = 649386,
  [SMALL_STATE(13841)] = 649413,
  [SMALL_STATE(13842)] = 649440,
  [SMALL_STATE(13843)] = 649469,
  [SMALL_STATE(13844)] = 649490,
  [SMALL_STATE(13845)] = 649519,
  [SMALL_STATE(13846)] = 649548,
  [SMALL_STATE(13847)] = 649569,
  [SMALL_STATE(13848)] = 649590,
  [SMALL_STATE(13849)] = 649619,
  [SMALL_STATE(13850)] = 649648,
  [SMALL_STATE(13851)] = 649677,
  [SMALL_STATE(13852)] = 649698,
  [SMALL_STATE(13853)] = 649727,
  [SMALL_STATE(13854)] = 649748,
  [SMALL_STATE(13855)] = 649769,
  [SMALL_STATE(13856)] = 649798,
  [SMALL_STATE(13857)] = 649827,
  [SMALL_STATE(13858)] = 649848,
  [SMALL_STATE(13859)] = 649875,
  [SMALL_STATE(13860)] = 649904,
  [SMALL_STATE(13861)] = 649933,
  [SMALL_STATE(13862)] = 649960,
  [SMALL_STATE(13863)] = 649989,
  [SMALL_STATE(13864)] = 650018,
  [SMALL_STATE(13865)] = 650047,
  [SMALL_STATE(13866)] = 650076,
  [SMALL_STATE(13867)] = 650105,
  [SMALL_STATE(13868)] = 650134,
  [SMALL_STATE(13869)] = 650159,
  [SMALL_STATE(13870)] = 650188,
  [SMALL_STATE(13871)] = 650209,
  [SMALL_STATE(13872)] = 650236,
  [SMALL_STATE(13873)] = 650265,
  [SMALL_STATE(13874)] = 650286,
  [SMALL_STATE(13875)] = 650315,
  [SMALL_STATE(13876)] = 650344,
  [SMALL_STATE(13877)] = 650373,
  [SMALL_STATE(13878)] = 650402,
  [SMALL_STATE(13879)] = 650431,
  [SMALL_STATE(13880)] = 650452,
  [SMALL_STATE(13881)] = 650481,
  [SMALL_STATE(13882)] = 650510,
  [SMALL_STATE(13883)] = 650539,
  [SMALL_STATE(13884)] = 650560,
  [SMALL_STATE(13885)] = 650589,
  [SMALL_STATE(13886)] = 650618,
  [SMALL_STATE(13887)] = 650647,
  [SMALL_STATE(13888)] = 650668,
  [SMALL_STATE(13889)] = 650697,
  [SMALL_STATE(13890)] = 650726,
  [SMALL_STATE(13891)] = 650755,
  [SMALL_STATE(13892)] = 650776,
  [SMALL_STATE(13893)] = 650803,
  [SMALL_STATE(13894)] = 650832,
  [SMALL_STATE(13895)] = 650855,
  [SMALL_STATE(13896)] = 650884,
  [SMALL_STATE(13897)] = 650913,
  [SMALL_STATE(13898)] = 650942,
  [SMALL_STATE(13899)] = 650971,
  [SMALL_STATE(13900)] = 651000,
  [SMALL_STATE(13901)] = 651021,
  [SMALL_STATE(13902)] = 651042,
  [SMALL_STATE(13903)] = 651071,
  [SMALL_STATE(13904)] = 651100,
  [SMALL_STATE(13905)] = 651121,
  [SMALL_STATE(13906)] = 651150,
  [SMALL_STATE(13907)] = 651179,
  [SMALL_STATE(13908)] = 651200,
  [SMALL_STATE(13909)] = 651221,
  [SMALL_STATE(13910)] = 651242,
  [SMALL_STATE(13911)] = 651271,
  [SMALL_STATE(13912)] = 651292,
  [SMALL_STATE(13913)] = 651313,
  [SMALL_STATE(13914)] = 651342,
  [SMALL_STATE(13915)] = 651371,
  [SMALL_STATE(13916)] = 651400,
  [SMALL_STATE(13917)] = 651429,
  [SMALL_STATE(13918)] = 651458,
  [SMALL_STATE(13919)] = 651485,
  [SMALL_STATE(13920)] = 651506,
  [SMALL_STATE(13921)] = 651527,
  [SMALL_STATE(13922)] = 651556,
  [SMALL_STATE(13923)] = 651583,
  [SMALL_STATE(13924)] = 651612,
  [SMALL_STATE(13925)] = 651641,
  [SMALL_STATE(13926)] = 651662,
  [SMALL_STATE(13927)] = 651683,
  [SMALL_STATE(13928)] = 651704,
  [SMALL_STATE(13929)] = 651733,
  [SMALL_STATE(13930)] = 651754,
  [SMALL_STATE(13931)] = 651775,
  [SMALL_STATE(13932)] = 651804,
  [SMALL_STATE(13933)] = 651833,
  [SMALL_STATE(13934)] = 651862,
  [SMALL_STATE(13935)] = 651889,
  [SMALL_STATE(13936)] = 651918,
  [SMALL_STATE(13937)] = 651947,
  [SMALL_STATE(13938)] = 651976,
  [SMALL_STATE(13939)] = 652005,
  [SMALL_STATE(13940)] = 652034,
  [SMALL_STATE(13941)] = 652055,
  [SMALL_STATE(13942)] = 652082,
  [SMALL_STATE(13943)] = 652103,
  [SMALL_STATE(13944)] = 652124,
  [SMALL_STATE(13945)] = 652153,
  [SMALL_STATE(13946)] = 652182,
  [SMALL_STATE(13947)] = 652211,
  [SMALL_STATE(13948)] = 652240,
  [SMALL_STATE(13949)] = 652269,
  [SMALL_STATE(13950)] = 652298,
  [SMALL_STATE(13951)] = 652327,
  [SMALL_STATE(13952)] = 652356,
  [SMALL_STATE(13953)] = 652385,
  [SMALL_STATE(13954)] = 652414,
  [SMALL_STATE(13955)] = 652435,
  [SMALL_STATE(13956)] = 652458,
  [SMALL_STATE(13957)] = 652487,
  [SMALL_STATE(13958)] = 652508,
  [SMALL_STATE(13959)] = 652537,
  [SMALL_STATE(13960)] = 652566,
  [SMALL_STATE(13961)] = 652595,
  [SMALL_STATE(13962)] = 652624,
  [SMALL_STATE(13963)] = 652653,
  [SMALL_STATE(13964)] = 652682,
  [SMALL_STATE(13965)] = 652711,
  [SMALL_STATE(13966)] = 652740,
  [SMALL_STATE(13967)] = 652769,
  [SMALL_STATE(13968)] = 652798,
  [SMALL_STATE(13969)] = 652827,
  [SMALL_STATE(13970)] = 652848,
  [SMALL_STATE(13971)] = 652877,
  [SMALL_STATE(13972)] = 652906,
  [SMALL_STATE(13973)] = 652935,
  [SMALL_STATE(13974)] = 652962,
  [SMALL_STATE(13975)] = 652983,
  [SMALL_STATE(13976)] = 653004,
  [SMALL_STATE(13977)] = 653033,
  [SMALL_STATE(13978)] = 653062,
  [SMALL_STATE(13979)] = 653091,
  [SMALL_STATE(13980)] = 653120,
  [SMALL_STATE(13981)] = 653149,
  [SMALL_STATE(13982)] = 653178,
  [SMALL_STATE(13983)] = 653199,
  [SMALL_STATE(13984)] = 653220,
  [SMALL_STATE(13985)] = 653249,
  [SMALL_STATE(13986)] = 653278,
  [SMALL_STATE(13987)] = 653305,
  [SMALL_STATE(13988)] = 653326,
  [SMALL_STATE(13989)] = 653355,
  [SMALL_STATE(13990)] = 653384,
  [SMALL_STATE(13991)] = 653413,
  [SMALL_STATE(13992)] = 653442,
  [SMALL_STATE(13993)] = 653471,
  [SMALL_STATE(13994)] = 653492,
  [SMALL_STATE(13995)] = 653519,
  [SMALL_STATE(13996)] = 653544,
  [SMALL_STATE(13997)] = 653573,
  [SMALL_STATE(13998)] = 653602,
  [SMALL_STATE(13999)] = 653625,
  [SMALL_STATE(14000)] = 653654,
  [SMALL_STATE(14001)] = 653683,
  [SMALL_STATE(14002)] = 653704,
  [SMALL_STATE(14003)] = 653731,
  [SMALL_STATE(14004)] = 653760,
  [SMALL_STATE(14005)] = 653789,
  [SMALL_STATE(14006)] = 653818,
  [SMALL_STATE(14007)] = 653847,
  [SMALL_STATE(14008)] = 653874,
  [SMALL_STATE(14009)] = 653903,
  [SMALL_STATE(14010)] = 653932,
  [SMALL_STATE(14011)] = 653955,
  [SMALL_STATE(14012)] = 653976,
  [SMALL_STATE(14013)] = 653997,
  [SMALL_STATE(14014)] = 654026,
  [SMALL_STATE(14015)] = 654055,
  [SMALL_STATE(14016)] = 654084,
  [SMALL_STATE(14017)] = 654113,
  [SMALL_STATE(14018)] = 654142,
  [SMALL_STATE(14019)] = 654171,
  [SMALL_STATE(14020)] = 654192,
  [SMALL_STATE(14021)] = 654217,
  [SMALL_STATE(14022)] = 654246,
  [SMALL_STATE(14023)] = 654275,
  [SMALL_STATE(14024)] = 654304,
  [SMALL_STATE(14025)] = 654325,
  [SMALL_STATE(14026)] = 654346,
  [SMALL_STATE(14027)] = 654367,
  [SMALL_STATE(14028)] = 654388,
  [SMALL_STATE(14029)] = 654417,
  [SMALL_STATE(14030)] = 654446,
  [SMALL_STATE(14031)] = 654469,
  [SMALL_STATE(14032)] = 654490,
  [SMALL_STATE(14033)] = 654511,
  [SMALL_STATE(14034)] = 654540,
  [SMALL_STATE(14035)] = 654561,
  [SMALL_STATE(14036)] = 654584,
  [SMALL_STATE(14037)] = 654613,
  [SMALL_STATE(14038)] = 654642,
  [SMALL_STATE(14039)] = 654671,
  [SMALL_STATE(14040)] = 654700,
  [SMALL_STATE(14041)] = 654721,
  [SMALL_STATE(14042)] = 654750,
  [SMALL_STATE(14043)] = 654779,
  [SMALL_STATE(14044)] = 654808,
  [SMALL_STATE(14045)] = 654837,
  [SMALL_STATE(14046)] = 654858,
  [SMALL_STATE(14047)] = 654879,
  [SMALL_STATE(14048)] = 654906,
  [SMALL_STATE(14049)] = 654935,
  [SMALL_STATE(14050)] = 654956,
  [SMALL_STATE(14051)] = 654985,
  [SMALL_STATE(14052)] = 655012,
  [SMALL_STATE(14053)] = 655041,
  [SMALL_STATE(14054)] = 655070,
  [SMALL_STATE(14055)] = 655099,
  [SMALL_STATE(14056)] = 655120,
  [SMALL_STATE(14057)] = 655149,
  [SMALL_STATE(14058)] = 655178,
  [SMALL_STATE(14059)] = 655207,
  [SMALL_STATE(14060)] = 655236,
  [SMALL_STATE(14061)] = 655265,
  [SMALL_STATE(14062)] = 655294,
  [SMALL_STATE(14063)] = 655323,
  [SMALL_STATE(14064)] = 655352,
  [SMALL_STATE(14065)] = 655373,
  [SMALL_STATE(14066)] = 655394,
  [SMALL_STATE(14067)] = 655423,
  [SMALL_STATE(14068)] = 655452,
  [SMALL_STATE(14069)] = 655481,
  [SMALL_STATE(14070)] = 655508,
  [SMALL_STATE(14071)] = 655537,
  [SMALL_STATE(14072)] = 655566,
  [SMALL_STATE(14073)] = 655595,
  [SMALL_STATE(14074)] = 655624,
  [SMALL_STATE(14075)] = 655653,
  [SMALL_STATE(14076)] = 655682,
  [SMALL_STATE(14077)] = 655703,
  [SMALL_STATE(14078)] = 655732,
  [SMALL_STATE(14079)] = 655755,
  [SMALL_STATE(14080)] = 655784,
  [SMALL_STATE(14081)] = 655813,
  [SMALL_STATE(14082)] = 655842,
  [SMALL_STATE(14083)] = 655871,
  [SMALL_STATE(14084)] = 655900,
  [SMALL_STATE(14085)] = 655929,
  [SMALL_STATE(14086)] = 655952,
  [SMALL_STATE(14087)] = 655981,
  [SMALL_STATE(14088)] = 656002,
  [SMALL_STATE(14089)] = 656031,
  [SMALL_STATE(14090)] = 656060,
  [SMALL_STATE(14091)] = 656089,
  [SMALL_STATE(14092)] = 656118,
  [SMALL_STATE(14093)] = 656143,
  [SMALL_STATE(14094)] = 656164,
  [SMALL_STATE(14095)] = 656185,
  [SMALL_STATE(14096)] = 656214,
  [SMALL_STATE(14097)] = 656235,
  [SMALL_STATE(14098)] = 656264,
  [SMALL_STATE(14099)] = 656293,
  [SMALL_STATE(14100)] = 656322,
  [SMALL_STATE(14101)] = 656351,
  [SMALL_STATE(14102)] = 656380,
  [SMALL_STATE(14103)] = 656401,
  [SMALL_STATE(14104)] = 656422,
  [SMALL_STATE(14105)] = 656445,
  [SMALL_STATE(14106)] = 656474,
  [SMALL_STATE(14107)] = 656503,
  [SMALL_STATE(14108)] = 656532,
  [SMALL_STATE(14109)] = 656553,
  [SMALL_STATE(14110)] = 656582,
  [SMALL_STATE(14111)] = 656603,
  [SMALL_STATE(14112)] = 656630,
  [SMALL_STATE(14113)] = 656659,
  [SMALL_STATE(14114)] = 656688,
  [SMALL_STATE(14115)] = 656717,
  [SMALL_STATE(14116)] = 656746,
  [SMALL_STATE(14117)] = 656773,
  [SMALL_STATE(14118)] = 656794,
  [SMALL_STATE(14119)] = 656823,
  [SMALL_STATE(14120)] = 656852,
  [SMALL_STATE(14121)] = 656881,
  [SMALL_STATE(14122)] = 656910,
  [SMALL_STATE(14123)] = 656939,
  [SMALL_STATE(14124)] = 656968,
  [SMALL_STATE(14125)] = 656995,
  [SMALL_STATE(14126)] = 657024,
  [SMALL_STATE(14127)] = 657053,
  [SMALL_STATE(14128)] = 657082,
  [SMALL_STATE(14129)] = 657111,
  [SMALL_STATE(14130)] = 657140,
  [SMALL_STATE(14131)] = 657169,
  [SMALL_STATE(14132)] = 657190,
  [SMALL_STATE(14133)] = 657219,
  [SMALL_STATE(14134)] = 657248,
  [SMALL_STATE(14135)] = 657277,
  [SMALL_STATE(14136)] = 657306,
  [SMALL_STATE(14137)] = 657335,
  [SMALL_STATE(14138)] = 657356,
  [SMALL_STATE(14139)] = 657385,
  [SMALL_STATE(14140)] = 657414,
  [SMALL_STATE(14141)] = 657443,
  [SMALL_STATE(14142)] = 657464,
  [SMALL_STATE(14143)] = 657491,
  [SMALL_STATE(14144)] = 657520,
  [SMALL_STATE(14145)] = 657549,
  [SMALL_STATE(14146)] = 657576,
  [SMALL_STATE(14147)] = 657605,
  [SMALL_STATE(14148)] = 657632,
  [SMALL_STATE(14149)] = 657661,
  [SMALL_STATE(14150)] = 657682,
  [SMALL_STATE(14151)] = 657709,
  [SMALL_STATE(14152)] = 657738,
  [SMALL_STATE(14153)] = 657767,
  [SMALL_STATE(14154)] = 657796,
  [SMALL_STATE(14155)] = 657825,
  [SMALL_STATE(14156)] = 657854,
  [SMALL_STATE(14157)] = 657883,
  [SMALL_STATE(14158)] = 657904,
  [SMALL_STATE(14159)] = 657933,
  [SMALL_STATE(14160)] = 657962,
  [SMALL_STATE(14161)] = 657991,
  [SMALL_STATE(14162)] = 658020,
  [SMALL_STATE(14163)] = 658047,
  [SMALL_STATE(14164)] = 658076,
  [SMALL_STATE(14165)] = 658105,
  [SMALL_STATE(14166)] = 658126,
  [SMALL_STATE(14167)] = 658155,
  [SMALL_STATE(14168)] = 658184,
  [SMALL_STATE(14169)] = 658213,
  [SMALL_STATE(14170)] = 658242,
  [SMALL_STATE(14171)] = 658264,
  [SMALL_STATE(14172)] = 658290,
  [SMALL_STATE(14173)] = 658316,
  [SMALL_STATE(14174)] = 658342,
  [SMALL_STATE(14175)] = 658368,
  [SMALL_STATE(14176)] = 658394,
  [SMALL_STATE(14177)] = 658420,
  [SMALL_STATE(14178)] = 658446,
  [SMALL_STATE(14179)] = 658472,
  [SMALL_STATE(14180)] = 658498,
  [SMALL_STATE(14181)] = 658520,
  [SMALL_STATE(14182)] = 658546,
  [SMALL_STATE(14183)] = 658572,
  [SMALL_STATE(14184)] = 658598,
  [SMALL_STATE(14185)] = 658624,
  [SMALL_STATE(14186)] = 658646,
  [SMALL_STATE(14187)] = 658672,
  [SMALL_STATE(14188)] = 658698,
  [SMALL_STATE(14189)] = 658722,
  [SMALL_STATE(14190)] = 658748,
  [SMALL_STATE(14191)] = 658774,
  [SMALL_STATE(14192)] = 658800,
  [SMALL_STATE(14193)] = 658826,
  [SMALL_STATE(14194)] = 658852,
  [SMALL_STATE(14195)] = 658876,
  [SMALL_STATE(14196)] = 658902,
  [SMALL_STATE(14197)] = 658928,
  [SMALL_STATE(14198)] = 658954,
  [SMALL_STATE(14199)] = 658980,
  [SMALL_STATE(14200)] = 659006,
  [SMALL_STATE(14201)] = 659032,
  [SMALL_STATE(14202)] = 659058,
  [SMALL_STATE(14203)] = 659084,
  [SMALL_STATE(14204)] = 659102,
  [SMALL_STATE(14205)] = 659120,
  [SMALL_STATE(14206)] = 659146,
  [SMALL_STATE(14207)] = 659172,
  [SMALL_STATE(14208)] = 659198,
  [SMALL_STATE(14209)] = 659224,
  [SMALL_STATE(14210)] = 659250,
  [SMALL_STATE(14211)] = 659276,
  [SMALL_STATE(14212)] = 659302,
  [SMALL_STATE(14213)] = 659328,
  [SMALL_STATE(14214)] = 659350,
  [SMALL_STATE(14215)] = 659376,
  [SMALL_STATE(14216)] = 659402,
  [SMALL_STATE(14217)] = 659428,
  [SMALL_STATE(14218)] = 659454,
  [SMALL_STATE(14219)] = 659480,
  [SMALL_STATE(14220)] = 659506,
  [SMALL_STATE(14221)] = 659528,
  [SMALL_STATE(14222)] = 659552,
  [SMALL_STATE(14223)] = 659578,
  [SMALL_STATE(14224)] = 659604,
  [SMALL_STATE(14225)] = 659626,
  [SMALL_STATE(14226)] = 659650,
  [SMALL_STATE(14227)] = 659676,
  [SMALL_STATE(14228)] = 659702,
  [SMALL_STATE(14229)] = 659728,
  [SMALL_STATE(14230)] = 659752,
  [SMALL_STATE(14231)] = 659778,
  [SMALL_STATE(14232)] = 659804,
  [SMALL_STATE(14233)] = 659830,
  [SMALL_STATE(14234)] = 659856,
  [SMALL_STATE(14235)] = 659882,
  [SMALL_STATE(14236)] = 659908,
  [SMALL_STATE(14237)] = 659934,
  [SMALL_STATE(14238)] = 659960,
  [SMALL_STATE(14239)] = 659986,
  [SMALL_STATE(14240)] = 660012,
  [SMALL_STATE(14241)] = 660038,
  [SMALL_STATE(14242)] = 660064,
  [SMALL_STATE(14243)] = 660090,
  [SMALL_STATE(14244)] = 660116,
  [SMALL_STATE(14245)] = 660142,
  [SMALL_STATE(14246)] = 660168,
  [SMALL_STATE(14247)] = 660194,
  [SMALL_STATE(14248)] = 660216,
  [SMALL_STATE(14249)] = 660242,
  [SMALL_STATE(14250)] = 660268,
  [SMALL_STATE(14251)] = 660294,
  [SMALL_STATE(14252)] = 660320,
  [SMALL_STATE(14253)] = 660346,
  [SMALL_STATE(14254)] = 660372,
  [SMALL_STATE(14255)] = 660398,
  [SMALL_STATE(14256)] = 660424,
  [SMALL_STATE(14257)] = 660450,
  [SMALL_STATE(14258)] = 660470,
  [SMALL_STATE(14259)] = 660496,
  [SMALL_STATE(14260)] = 660522,
  [SMALL_STATE(14261)] = 660548,
  [SMALL_STATE(14262)] = 660570,
  [SMALL_STATE(14263)] = 660592,
  [SMALL_STATE(14264)] = 660618,
  [SMALL_STATE(14265)] = 660644,
  [SMALL_STATE(14266)] = 660666,
  [SMALL_STATE(14267)] = 660692,
  [SMALL_STATE(14268)] = 660718,
  [SMALL_STATE(14269)] = 660744,
  [SMALL_STATE(14270)] = 660770,
  [SMALL_STATE(14271)] = 660796,
  [SMALL_STATE(14272)] = 660822,
  [SMALL_STATE(14273)] = 660848,
  [SMALL_STATE(14274)] = 660870,
  [SMALL_STATE(14275)] = 660896,
  [SMALL_STATE(14276)] = 660922,
  [SMALL_STATE(14277)] = 660940,
  [SMALL_STATE(14278)] = 660966,
  [SMALL_STATE(14279)] = 660990,
  [SMALL_STATE(14280)] = 661016,
  [SMALL_STATE(14281)] = 661042,
  [SMALL_STATE(14282)] = 661066,
  [SMALL_STATE(14283)] = 661092,
  [SMALL_STATE(14284)] = 661118,
  [SMALL_STATE(14285)] = 661144,
  [SMALL_STATE(14286)] = 661170,
  [SMALL_STATE(14287)] = 661194,
  [SMALL_STATE(14288)] = 661218,
  [SMALL_STATE(14289)] = 661244,
  [SMALL_STATE(14290)] = 661268,
  [SMALL_STATE(14291)] = 661294,
  [SMALL_STATE(14292)] = 661316,
  [SMALL_STATE(14293)] = 661338,
  [SMALL_STATE(14294)] = 661364,
  [SMALL_STATE(14295)] = 661390,
  [SMALL_STATE(14296)] = 661412,
  [SMALL_STATE(14297)] = 661438,
  [SMALL_STATE(14298)] = 661464,
  [SMALL_STATE(14299)] = 661490,
  [SMALL_STATE(14300)] = 661516,
  [SMALL_STATE(14301)] = 661538,
  [SMALL_STATE(14302)] = 661560,
  [SMALL_STATE(14303)] = 661586,
  [SMALL_STATE(14304)] = 661612,
  [SMALL_STATE(14305)] = 661638,
  [SMALL_STATE(14306)] = 661662,
  [SMALL_STATE(14307)] = 661688,
  [SMALL_STATE(14308)] = 661714,
  [SMALL_STATE(14309)] = 661740,
  [SMALL_STATE(14310)] = 661766,
  [SMALL_STATE(14311)] = 661792,
  [SMALL_STATE(14312)] = 661818,
  [SMALL_STATE(14313)] = 661844,
  [SMALL_STATE(14314)] = 661870,
  [SMALL_STATE(14315)] = 661892,
  [SMALL_STATE(14316)] = 661918,
  [SMALL_STATE(14317)] = 661944,
  [SMALL_STATE(14318)] = 661962,
  [SMALL_STATE(14319)] = 661988,
  [SMALL_STATE(14320)] = 662014,
  [SMALL_STATE(14321)] = 662040,
  [SMALL_STATE(14322)] = 662066,
  [SMALL_STATE(14323)] = 662092,
  [SMALL_STATE(14324)] = 662118,
  [SMALL_STATE(14325)] = 662136,
  [SMALL_STATE(14326)] = 662154,
  [SMALL_STATE(14327)] = 662180,
  [SMALL_STATE(14328)] = 662206,
  [SMALL_STATE(14329)] = 662232,
  [SMALL_STATE(14330)] = 662254,
  [SMALL_STATE(14331)] = 662280,
  [SMALL_STATE(14332)] = 662306,
  [SMALL_STATE(14333)] = 662332,
  [SMALL_STATE(14334)] = 662358,
  [SMALL_STATE(14335)] = 662380,
  [SMALL_STATE(14336)] = 662398,
  [SMALL_STATE(14337)] = 662422,
  [SMALL_STATE(14338)] = 662444,
  [SMALL_STATE(14339)] = 662466,
  [SMALL_STATE(14340)] = 662492,
  [SMALL_STATE(14341)] = 662518,
  [SMALL_STATE(14342)] = 662544,
  [SMALL_STATE(14343)] = 662570,
  [SMALL_STATE(14344)] = 662592,
  [SMALL_STATE(14345)] = 662618,
  [SMALL_STATE(14346)] = 662644,
  [SMALL_STATE(14347)] = 662670,
  [SMALL_STATE(14348)] = 662692,
  [SMALL_STATE(14349)] = 662718,
  [SMALL_STATE(14350)] = 662742,
  [SMALL_STATE(14351)] = 662768,
  [SMALL_STATE(14352)] = 662794,
  [SMALL_STATE(14353)] = 662820,
  [SMALL_STATE(14354)] = 662846,
  [SMALL_STATE(14355)] = 662872,
  [SMALL_STATE(14356)] = 662898,
  [SMALL_STATE(14357)] = 662924,
  [SMALL_STATE(14358)] = 662950,
  [SMALL_STATE(14359)] = 662976,
  [SMALL_STATE(14360)] = 663000,
  [SMALL_STATE(14361)] = 663024,
  [SMALL_STATE(14362)] = 663050,
  [SMALL_STATE(14363)] = 663076,
  [SMALL_STATE(14364)] = 663102,
  [SMALL_STATE(14365)] = 663128,
  [SMALL_STATE(14366)] = 663154,
  [SMALL_STATE(14367)] = 663180,
  [SMALL_STATE(14368)] = 663206,
  [SMALL_STATE(14369)] = 663232,
  [SMALL_STATE(14370)] = 663258,
  [SMALL_STATE(14371)] = 663284,
  [SMALL_STATE(14372)] = 663310,
  [SMALL_STATE(14373)] = 663334,
  [SMALL_STATE(14374)] = 663360,
  [SMALL_STATE(14375)] = 663382,
  [SMALL_STATE(14376)] = 663408,
  [SMALL_STATE(14377)] = 663434,
  [SMALL_STATE(14378)] = 663460,
  [SMALL_STATE(14379)] = 663484,
  [SMALL_STATE(14380)] = 663510,
  [SMALL_STATE(14381)] = 663536,
  [SMALL_STATE(14382)] = 663562,
  [SMALL_STATE(14383)] = 663588,
  [SMALL_STATE(14384)] = 663614,
  [SMALL_STATE(14385)] = 663640,
  [SMALL_STATE(14386)] = 663666,
  [SMALL_STATE(14387)] = 663692,
  [SMALL_STATE(14388)] = 663716,
  [SMALL_STATE(14389)] = 663742,
  [SMALL_STATE(14390)] = 663768,
  [SMALL_STATE(14391)] = 663794,
  [SMALL_STATE(14392)] = 663818,
  [SMALL_STATE(14393)] = 663844,
  [SMALL_STATE(14394)] = 663870,
  [SMALL_STATE(14395)] = 663896,
  [SMALL_STATE(14396)] = 663922,
  [SMALL_STATE(14397)] = 663948,
  [SMALL_STATE(14398)] = 663974,
  [SMALL_STATE(14399)] = 664000,
  [SMALL_STATE(14400)] = 664026,
  [SMALL_STATE(14401)] = 664052,
  [SMALL_STATE(14402)] = 664074,
  [SMALL_STATE(14403)] = 664100,
  [SMALL_STATE(14404)] = 664123,
  [SMALL_STATE(14405)] = 664146,
  [SMALL_STATE(14406)] = 664169,
  [SMALL_STATE(14407)] = 664192,
  [SMALL_STATE(14408)] = 664215,
  [SMALL_STATE(14409)] = 664238,
  [SMALL_STATE(14410)] = 664261,
  [SMALL_STATE(14411)] = 664284,
  [SMALL_STATE(14412)] = 664307,
  [SMALL_STATE(14413)] = 664330,
  [SMALL_STATE(14414)] = 664353,
  [SMALL_STATE(14415)] = 664376,
  [SMALL_STATE(14416)] = 664399,
  [SMALL_STATE(14417)] = 664422,
  [SMALL_STATE(14418)] = 664445,
  [SMALL_STATE(14419)] = 664468,
  [SMALL_STATE(14420)] = 664491,
  [SMALL_STATE(14421)] = 664514,
  [SMALL_STATE(14422)] = 664537,
  [SMALL_STATE(14423)] = 664560,
  [SMALL_STATE(14424)] = 664583,
  [SMALL_STATE(14425)] = 664606,
  [SMALL_STATE(14426)] = 664629,
  [SMALL_STATE(14427)] = 664652,
  [SMALL_STATE(14428)] = 664675,
  [SMALL_STATE(14429)] = 664698,
  [SMALL_STATE(14430)] = 664721,
  [SMALL_STATE(14431)] = 664744,
  [SMALL_STATE(14432)] = 664767,
  [SMALL_STATE(14433)] = 664790,
  [SMALL_STATE(14434)] = 664813,
  [SMALL_STATE(14435)] = 664836,
  [SMALL_STATE(14436)] = 664859,
  [SMALL_STATE(14437)] = 664882,
  [SMALL_STATE(14438)] = 664905,
  [SMALL_STATE(14439)] = 664926,
  [SMALL_STATE(14440)] = 664949,
  [SMALL_STATE(14441)] = 664972,
  [SMALL_STATE(14442)] = 664995,
  [SMALL_STATE(14443)] = 665018,
  [SMALL_STATE(14444)] = 665041,
  [SMALL_STATE(14445)] = 665064,
  [SMALL_STATE(14446)] = 665087,
  [SMALL_STATE(14447)] = 665110,
  [SMALL_STATE(14448)] = 665133,
  [SMALL_STATE(14449)] = 665154,
  [SMALL_STATE(14450)] = 665177,
  [SMALL_STATE(14451)] = 665200,
  [SMALL_STATE(14452)] = 665223,
  [SMALL_STATE(14453)] = 665246,
  [SMALL_STATE(14454)] = 665269,
  [SMALL_STATE(14455)] = 665292,
  [SMALL_STATE(14456)] = 665315,
  [SMALL_STATE(14457)] = 665338,
  [SMALL_STATE(14458)] = 665361,
  [SMALL_STATE(14459)] = 665384,
  [SMALL_STATE(14460)] = 665407,
  [SMALL_STATE(14461)] = 665430,
  [SMALL_STATE(14462)] = 665453,
  [SMALL_STATE(14463)] = 665476,
  [SMALL_STATE(14464)] = 665497,
  [SMALL_STATE(14465)] = 665520,
  [SMALL_STATE(14466)] = 665541,
  [SMALL_STATE(14467)] = 665564,
  [SMALL_STATE(14468)] = 665585,
  [SMALL_STATE(14469)] = 665606,
  [SMALL_STATE(14470)] = 665629,
  [SMALL_STATE(14471)] = 665648,
  [SMALL_STATE(14472)] = 665671,
  [SMALL_STATE(14473)] = 665694,
  [SMALL_STATE(14474)] = 665717,
  [SMALL_STATE(14475)] = 665740,
  [SMALL_STATE(14476)] = 665763,
  [SMALL_STATE(14477)] = 665786,
  [SMALL_STATE(14478)] = 665809,
  [SMALL_STATE(14479)] = 665832,
  [SMALL_STATE(14480)] = 665855,
  [SMALL_STATE(14481)] = 665878,
  [SMALL_STATE(14482)] = 665901,
  [SMALL_STATE(14483)] = 665922,
  [SMALL_STATE(14484)] = 665945,
  [SMALL_STATE(14485)] = 665968,
  [SMALL_STATE(14486)] = 665989,
  [SMALL_STATE(14487)] = 666012,
  [SMALL_STATE(14488)] = 666035,
  [SMALL_STATE(14489)] = 666056,
  [SMALL_STATE(14490)] = 666079,
  [SMALL_STATE(14491)] = 666102,
  [SMALL_STATE(14492)] = 666125,
  [SMALL_STATE(14493)] = 666148,
  [SMALL_STATE(14494)] = 666171,
  [SMALL_STATE(14495)] = 666194,
  [SMALL_STATE(14496)] = 666217,
  [SMALL_STATE(14497)] = 666240,
  [SMALL_STATE(14498)] = 666263,
  [SMALL_STATE(14499)] = 666286,
  [SMALL_STATE(14500)] = 666309,
  [SMALL_STATE(14501)] = 666328,
  [SMALL_STATE(14502)] = 666351,
  [SMALL_STATE(14503)] = 666374,
  [SMALL_STATE(14504)] = 666397,
  [SMALL_STATE(14505)] = 666420,
  [SMALL_STATE(14506)] = 666443,
  [SMALL_STATE(14507)] = 666466,
  [SMALL_STATE(14508)] = 666489,
  [SMALL_STATE(14509)] = 666512,
  [SMALL_STATE(14510)] = 666535,
  [SMALL_STATE(14511)] = 666558,
  [SMALL_STATE(14512)] = 666581,
  [SMALL_STATE(14513)] = 666604,
  [SMALL_STATE(14514)] = 666627,
  [SMALL_STATE(14515)] = 666650,
  [SMALL_STATE(14516)] = 666673,
  [SMALL_STATE(14517)] = 666696,
  [SMALL_STATE(14518)] = 666719,
  [SMALL_STATE(14519)] = 666742,
  [SMALL_STATE(14520)] = 666765,
  [SMALL_STATE(14521)] = 666788,
  [SMALL_STATE(14522)] = 666811,
  [SMALL_STATE(14523)] = 666834,
  [SMALL_STATE(14524)] = 666857,
  [SMALL_STATE(14525)] = 666880,
  [SMALL_STATE(14526)] = 666903,
  [SMALL_STATE(14527)] = 666926,
  [SMALL_STATE(14528)] = 666949,
  [SMALL_STATE(14529)] = 666970,
  [SMALL_STATE(14530)] = 666993,
  [SMALL_STATE(14531)] = 667016,
  [SMALL_STATE(14532)] = 667039,
  [SMALL_STATE(14533)] = 667062,
  [SMALL_STATE(14534)] = 667085,
  [SMALL_STATE(14535)] = 667108,
  [SMALL_STATE(14536)] = 667131,
  [SMALL_STATE(14537)] = 667154,
  [SMALL_STATE(14538)] = 667175,
  [SMALL_STATE(14539)] = 667198,
  [SMALL_STATE(14540)] = 667221,
  [SMALL_STATE(14541)] = 667244,
  [SMALL_STATE(14542)] = 667267,
  [SMALL_STATE(14543)] = 667290,
  [SMALL_STATE(14544)] = 667313,
  [SMALL_STATE(14545)] = 667336,
  [SMALL_STATE(14546)] = 667359,
  [SMALL_STATE(14547)] = 667382,
  [SMALL_STATE(14548)] = 667405,
  [SMALL_STATE(14549)] = 667428,
  [SMALL_STATE(14550)] = 667451,
  [SMALL_STATE(14551)] = 667474,
  [SMALL_STATE(14552)] = 667497,
  [SMALL_STATE(14553)] = 667520,
  [SMALL_STATE(14554)] = 667543,
  [SMALL_STATE(14555)] = 667566,
  [SMALL_STATE(14556)] = 667589,
  [SMALL_STATE(14557)] = 667612,
  [SMALL_STATE(14558)] = 667635,
  [SMALL_STATE(14559)] = 667658,
  [SMALL_STATE(14560)] = 667681,
  [SMALL_STATE(14561)] = 667702,
  [SMALL_STATE(14562)] = 667725,
  [SMALL_STATE(14563)] = 667748,
  [SMALL_STATE(14564)] = 667771,
  [SMALL_STATE(14565)] = 667794,
  [SMALL_STATE(14566)] = 667817,
  [SMALL_STATE(14567)] = 667840,
  [SMALL_STATE(14568)] = 667863,
  [SMALL_STATE(14569)] = 667886,
  [SMALL_STATE(14570)] = 667909,
  [SMALL_STATE(14571)] = 667932,
  [SMALL_STATE(14572)] = 667955,
  [SMALL_STATE(14573)] = 667978,
  [SMALL_STATE(14574)] = 668001,
  [SMALL_STATE(14575)] = 668024,
  [SMALL_STATE(14576)] = 668047,
  [SMALL_STATE(14577)] = 668070,
  [SMALL_STATE(14578)] = 668093,
  [SMALL_STATE(14579)] = 668116,
  [SMALL_STATE(14580)] = 668139,
  [SMALL_STATE(14581)] = 668162,
  [SMALL_STATE(14582)] = 668185,
  [SMALL_STATE(14583)] = 668208,
  [SMALL_STATE(14584)] = 668231,
  [SMALL_STATE(14585)] = 668254,
  [SMALL_STATE(14586)] = 668277,
  [SMALL_STATE(14587)] = 668300,
  [SMALL_STATE(14588)] = 668323,
  [SMALL_STATE(14589)] = 668346,
  [SMALL_STATE(14590)] = 668369,
  [SMALL_STATE(14591)] = 668392,
  [SMALL_STATE(14592)] = 668415,
  [SMALL_STATE(14593)] = 668438,
  [SMALL_STATE(14594)] = 668461,
  [SMALL_STATE(14595)] = 668484,
  [SMALL_STATE(14596)] = 668507,
  [SMALL_STATE(14597)] = 668528,
  [SMALL_STATE(14598)] = 668551,
  [SMALL_STATE(14599)] = 668574,
  [SMALL_STATE(14600)] = 668597,
  [SMALL_STATE(14601)] = 668620,
  [SMALL_STATE(14602)] = 668643,
  [SMALL_STATE(14603)] = 668666,
  [SMALL_STATE(14604)] = 668689,
  [SMALL_STATE(14605)] = 668712,
  [SMALL_STATE(14606)] = 668735,
  [SMALL_STATE(14607)] = 668758,
  [SMALL_STATE(14608)] = 668781,
  [SMALL_STATE(14609)] = 668802,
  [SMALL_STATE(14610)] = 668825,
  [SMALL_STATE(14611)] = 668848,
  [SMALL_STATE(14612)] = 668871,
  [SMALL_STATE(14613)] = 668894,
  [SMALL_STATE(14614)] = 668917,
  [SMALL_STATE(14615)] = 668940,
  [SMALL_STATE(14616)] = 668963,
  [SMALL_STATE(14617)] = 668986,
  [SMALL_STATE(14618)] = 669009,
  [SMALL_STATE(14619)] = 669032,
  [SMALL_STATE(14620)] = 669055,
  [SMALL_STATE(14621)] = 669078,
  [SMALL_STATE(14622)] = 669101,
  [SMALL_STATE(14623)] = 669124,
  [SMALL_STATE(14624)] = 669147,
  [SMALL_STATE(14625)] = 669170,
  [SMALL_STATE(14626)] = 669193,
  [SMALL_STATE(14627)] = 669214,
  [SMALL_STATE(14628)] = 669237,
  [SMALL_STATE(14629)] = 669260,
  [SMALL_STATE(14630)] = 669283,
  [SMALL_STATE(14631)] = 669306,
  [SMALL_STATE(14632)] = 669329,
  [SMALL_STATE(14633)] = 669352,
  [SMALL_STATE(14634)] = 669373,
  [SMALL_STATE(14635)] = 669396,
  [SMALL_STATE(14636)] = 669419,
  [SMALL_STATE(14637)] = 669442,
  [SMALL_STATE(14638)] = 669465,
  [SMALL_STATE(14639)] = 669488,
  [SMALL_STATE(14640)] = 669511,
  [SMALL_STATE(14641)] = 669534,
  [SMALL_STATE(14642)] = 669557,
  [SMALL_STATE(14643)] = 669580,
  [SMALL_STATE(14644)] = 669603,
  [SMALL_STATE(14645)] = 669622,
  [SMALL_STATE(14646)] = 669645,
  [SMALL_STATE(14647)] = 669668,
  [SMALL_STATE(14648)] = 669691,
  [SMALL_STATE(14649)] = 669714,
  [SMALL_STATE(14650)] = 669737,
  [SMALL_STATE(14651)] = 669760,
  [SMALL_STATE(14652)] = 669783,
  [SMALL_STATE(14653)] = 669806,
  [SMALL_STATE(14654)] = 669829,
  [SMALL_STATE(14655)] = 669852,
  [SMALL_STATE(14656)] = 669875,
  [SMALL_STATE(14657)] = 669896,
  [SMALL_STATE(14658)] = 669919,
  [SMALL_STATE(14659)] = 669942,
  [SMALL_STATE(14660)] = 669965,
  [SMALL_STATE(14661)] = 669988,
  [SMALL_STATE(14662)] = 670011,
  [SMALL_STATE(14663)] = 670034,
  [SMALL_STATE(14664)] = 670057,
  [SMALL_STATE(14665)] = 670076,
  [SMALL_STATE(14666)] = 670099,
  [SMALL_STATE(14667)] = 670122,
  [SMALL_STATE(14668)] = 670145,
  [SMALL_STATE(14669)] = 670168,
  [SMALL_STATE(14670)] = 670187,
  [SMALL_STATE(14671)] = 670210,
  [SMALL_STATE(14672)] = 670233,
  [SMALL_STATE(14673)] = 670256,
  [SMALL_STATE(14674)] = 670279,
  [SMALL_STATE(14675)] = 670300,
  [SMALL_STATE(14676)] = 670323,
  [SMALL_STATE(14677)] = 670344,
  [SMALL_STATE(14678)] = 670367,
  [SMALL_STATE(14679)] = 670390,
  [SMALL_STATE(14680)] = 670413,
  [SMALL_STATE(14681)] = 670436,
  [SMALL_STATE(14682)] = 670459,
  [SMALL_STATE(14683)] = 670482,
  [SMALL_STATE(14684)] = 670505,
  [SMALL_STATE(14685)] = 670528,
  [SMALL_STATE(14686)] = 670551,
  [SMALL_STATE(14687)] = 670574,
  [SMALL_STATE(14688)] = 670597,
  [SMALL_STATE(14689)] = 670620,
  [SMALL_STATE(14690)] = 670643,
  [SMALL_STATE(14691)] = 670666,
  [SMALL_STATE(14692)] = 670689,
  [SMALL_STATE(14693)] = 670712,
  [SMALL_STATE(14694)] = 670735,
  [SMALL_STATE(14695)] = 670758,
  [SMALL_STATE(14696)] = 670781,
  [SMALL_STATE(14697)] = 670804,
  [SMALL_STATE(14698)] = 670827,
  [SMALL_STATE(14699)] = 670850,
  [SMALL_STATE(14700)] = 670873,
  [SMALL_STATE(14701)] = 670896,
  [SMALL_STATE(14702)] = 670919,
  [SMALL_STATE(14703)] = 670942,
  [SMALL_STATE(14704)] = 670965,
  [SMALL_STATE(14705)] = 670988,
  [SMALL_STATE(14706)] = 671011,
  [SMALL_STATE(14707)] = 671034,
  [SMALL_STATE(14708)] = 671053,
  [SMALL_STATE(14709)] = 671076,
  [SMALL_STATE(14710)] = 671099,
  [SMALL_STATE(14711)] = 671122,
  [SMALL_STATE(14712)] = 671145,
  [SMALL_STATE(14713)] = 671168,
  [SMALL_STATE(14714)] = 671187,
  [SMALL_STATE(14715)] = 671210,
  [SMALL_STATE(14716)] = 671233,
  [SMALL_STATE(14717)] = 671254,
  [SMALL_STATE(14718)] = 671277,
  [SMALL_STATE(14719)] = 671300,
  [SMALL_STATE(14720)] = 671323,
  [SMALL_STATE(14721)] = 671346,
  [SMALL_STATE(14722)] = 671369,
  [SMALL_STATE(14723)] = 671392,
  [SMALL_STATE(14724)] = 671413,
  [SMALL_STATE(14725)] = 671436,
  [SMALL_STATE(14726)] = 671459,
  [SMALL_STATE(14727)] = 671482,
  [SMALL_STATE(14728)] = 671505,
  [SMALL_STATE(14729)] = 671526,
  [SMALL_STATE(14730)] = 671549,
  [SMALL_STATE(14731)] = 671572,
  [SMALL_STATE(14732)] = 671595,
  [SMALL_STATE(14733)] = 671618,
  [SMALL_STATE(14734)] = 671641,
  [SMALL_STATE(14735)] = 671664,
  [SMALL_STATE(14736)] = 671687,
  [SMALL_STATE(14737)] = 671710,
  [SMALL_STATE(14738)] = 671731,
  [SMALL_STATE(14739)] = 671754,
  [SMALL_STATE(14740)] = 671777,
  [SMALL_STATE(14741)] = 671800,
  [SMALL_STATE(14742)] = 671821,
  [SMALL_STATE(14743)] = 671844,
  [SMALL_STATE(14744)] = 671867,
  [SMALL_STATE(14745)] = 671888,
  [SMALL_STATE(14746)] = 671911,
  [SMALL_STATE(14747)] = 671934,
  [SMALL_STATE(14748)] = 671957,
  [SMALL_STATE(14749)] = 671980,
  [SMALL_STATE(14750)] = 672003,
  [SMALL_STATE(14751)] = 672026,
  [SMALL_STATE(14752)] = 672049,
  [SMALL_STATE(14753)] = 672072,
  [SMALL_STATE(14754)] = 672095,
  [SMALL_STATE(14755)] = 672118,
  [SMALL_STATE(14756)] = 672141,
  [SMALL_STATE(14757)] = 672164,
  [SMALL_STATE(14758)] = 672187,
  [SMALL_STATE(14759)] = 672210,
  [SMALL_STATE(14760)] = 672233,
  [SMALL_STATE(14761)] = 672256,
  [SMALL_STATE(14762)] = 672279,
  [SMALL_STATE(14763)] = 672302,
  [SMALL_STATE(14764)] = 672325,
  [SMALL_STATE(14765)] = 672348,
  [SMALL_STATE(14766)] = 672371,
  [SMALL_STATE(14767)] = 672394,
  [SMALL_STATE(14768)] = 672417,
  [SMALL_STATE(14769)] = 672440,
  [SMALL_STATE(14770)] = 672463,
  [SMALL_STATE(14771)] = 672486,
  [SMALL_STATE(14772)] = 672509,
  [SMALL_STATE(14773)] = 672532,
  [SMALL_STATE(14774)] = 672555,
  [SMALL_STATE(14775)] = 672576,
  [SMALL_STATE(14776)] = 672599,
  [SMALL_STATE(14777)] = 672622,
  [SMALL_STATE(14778)] = 672645,
  [SMALL_STATE(14779)] = 672668,
  [SMALL_STATE(14780)] = 672691,
  [SMALL_STATE(14781)] = 672714,
  [SMALL_STATE(14782)] = 672737,
  [SMALL_STATE(14783)] = 672760,
  [SMALL_STATE(14784)] = 672783,
  [SMALL_STATE(14785)] = 672806,
  [SMALL_STATE(14786)] = 672829,
  [SMALL_STATE(14787)] = 672852,
  [SMALL_STATE(14788)] = 672875,
  [SMALL_STATE(14789)] = 672898,
  [SMALL_STATE(14790)] = 672921,
  [SMALL_STATE(14791)] = 672944,
  [SMALL_STATE(14792)] = 672967,
  [SMALL_STATE(14793)] = 672990,
  [SMALL_STATE(14794)] = 673013,
  [SMALL_STATE(14795)] = 673036,
  [SMALL_STATE(14796)] = 673059,
  [SMALL_STATE(14797)] = 673082,
  [SMALL_STATE(14798)] = 673105,
  [SMALL_STATE(14799)] = 673128,
  [SMALL_STATE(14800)] = 673151,
  [SMALL_STATE(14801)] = 673174,
  [SMALL_STATE(14802)] = 673197,
  [SMALL_STATE(14803)] = 673220,
  [SMALL_STATE(14804)] = 673243,
  [SMALL_STATE(14805)] = 673266,
  [SMALL_STATE(14806)] = 673289,
  [SMALL_STATE(14807)] = 673312,
  [SMALL_STATE(14808)] = 673335,
  [SMALL_STATE(14809)] = 673358,
  [SMALL_STATE(14810)] = 673381,
  [SMALL_STATE(14811)] = 673404,
  [SMALL_STATE(14812)] = 673427,
  [SMALL_STATE(14813)] = 673450,
  [SMALL_STATE(14814)] = 673473,
  [SMALL_STATE(14815)] = 673496,
  [SMALL_STATE(14816)] = 673519,
  [SMALL_STATE(14817)] = 673542,
  [SMALL_STATE(14818)] = 673565,
  [SMALL_STATE(14819)] = 673588,
  [SMALL_STATE(14820)] = 673611,
  [SMALL_STATE(14821)] = 673634,
  [SMALL_STATE(14822)] = 673657,
  [SMALL_STATE(14823)] = 673680,
  [SMALL_STATE(14824)] = 673703,
  [SMALL_STATE(14825)] = 673726,
  [SMALL_STATE(14826)] = 673749,
  [SMALL_STATE(14827)] = 673772,
  [SMALL_STATE(14828)] = 673795,
  [SMALL_STATE(14829)] = 673816,
  [SMALL_STATE(14830)] = 673839,
  [SMALL_STATE(14831)] = 673862,
  [SMALL_STATE(14832)] = 673885,
  [SMALL_STATE(14833)] = 673908,
  [SMALL_STATE(14834)] = 673931,
  [SMALL_STATE(14835)] = 673954,
  [SMALL_STATE(14836)] = 673977,
  [SMALL_STATE(14837)] = 674000,
  [SMALL_STATE(14838)] = 674023,
  [SMALL_STATE(14839)] = 674046,
  [SMALL_STATE(14840)] = 674069,
  [SMALL_STATE(14841)] = 674092,
  [SMALL_STATE(14842)] = 674115,
  [SMALL_STATE(14843)] = 674136,
  [SMALL_STATE(14844)] = 674159,
  [SMALL_STATE(14845)] = 674182,
  [SMALL_STATE(14846)] = 674203,
  [SMALL_STATE(14847)] = 674224,
  [SMALL_STATE(14848)] = 674247,
  [SMALL_STATE(14849)] = 674268,
  [SMALL_STATE(14850)] = 674291,
  [SMALL_STATE(14851)] = 674314,
  [SMALL_STATE(14852)] = 674337,
  [SMALL_STATE(14853)] = 674360,
  [SMALL_STATE(14854)] = 674383,
  [SMALL_STATE(14855)] = 674406,
  [SMALL_STATE(14856)] = 674429,
  [SMALL_STATE(14857)] = 674452,
  [SMALL_STATE(14858)] = 674475,
  [SMALL_STATE(14859)] = 674498,
  [SMALL_STATE(14860)] = 674521,
  [SMALL_STATE(14861)] = 674544,
  [SMALL_STATE(14862)] = 674567,
  [SMALL_STATE(14863)] = 674590,
  [SMALL_STATE(14864)] = 674613,
  [SMALL_STATE(14865)] = 674636,
  [SMALL_STATE(14866)] = 674659,
  [SMALL_STATE(14867)] = 674682,
  [SMALL_STATE(14868)] = 674705,
  [SMALL_STATE(14869)] = 674726,
  [SMALL_STATE(14870)] = 674749,
  [SMALL_STATE(14871)] = 674772,
  [SMALL_STATE(14872)] = 674795,
  [SMALL_STATE(14873)] = 674818,
  [SMALL_STATE(14874)] = 674839,
  [SMALL_STATE(14875)] = 674862,
  [SMALL_STATE(14876)] = 674885,
  [SMALL_STATE(14877)] = 674908,
  [SMALL_STATE(14878)] = 674931,
  [SMALL_STATE(14879)] = 674952,
  [SMALL_STATE(14880)] = 674975,
  [SMALL_STATE(14881)] = 674998,
  [SMALL_STATE(14882)] = 675021,
  [SMALL_STATE(14883)] = 675044,
  [SMALL_STATE(14884)] = 675067,
  [SMALL_STATE(14885)] = 675090,
  [SMALL_STATE(14886)] = 675113,
  [SMALL_STATE(14887)] = 675136,
  [SMALL_STATE(14888)] = 675159,
  [SMALL_STATE(14889)] = 675182,
  [SMALL_STATE(14890)] = 675205,
  [SMALL_STATE(14891)] = 675228,
  [SMALL_STATE(14892)] = 675251,
  [SMALL_STATE(14893)] = 675272,
  [SMALL_STATE(14894)] = 675295,
  [SMALL_STATE(14895)] = 675318,
  [SMALL_STATE(14896)] = 675339,
  [SMALL_STATE(14897)] = 675362,
  [SMALL_STATE(14898)] = 675385,
  [SMALL_STATE(14899)] = 675408,
  [SMALL_STATE(14900)] = 675431,
  [SMALL_STATE(14901)] = 675454,
  [SMALL_STATE(14902)] = 675477,
  [SMALL_STATE(14903)] = 675500,
  [SMALL_STATE(14904)] = 675523,
  [SMALL_STATE(14905)] = 675546,
  [SMALL_STATE(14906)] = 675569,
  [SMALL_STATE(14907)] = 675592,
  [SMALL_STATE(14908)] = 675615,
  [SMALL_STATE(14909)] = 675638,
  [SMALL_STATE(14910)] = 675661,
  [SMALL_STATE(14911)] = 675684,
  [SMALL_STATE(14912)] = 675707,
  [SMALL_STATE(14913)] = 675730,
  [SMALL_STATE(14914)] = 675753,
  [SMALL_STATE(14915)] = 675776,
  [SMALL_STATE(14916)] = 675799,
  [SMALL_STATE(14917)] = 675822,
  [SMALL_STATE(14918)] = 675845,
  [SMALL_STATE(14919)] = 675868,
  [SMALL_STATE(14920)] = 675891,
  [SMALL_STATE(14921)] = 675914,
  [SMALL_STATE(14922)] = 675937,
  [SMALL_STATE(14923)] = 675960,
  [SMALL_STATE(14924)] = 675983,
  [SMALL_STATE(14925)] = 676006,
  [SMALL_STATE(14926)] = 676029,
  [SMALL_STATE(14927)] = 676052,
  [SMALL_STATE(14928)] = 676075,
  [SMALL_STATE(14929)] = 676098,
  [SMALL_STATE(14930)] = 676121,
  [SMALL_STATE(14931)] = 676144,
  [SMALL_STATE(14932)] = 676167,
  [SMALL_STATE(14933)] = 676190,
  [SMALL_STATE(14934)] = 676213,
  [SMALL_STATE(14935)] = 676236,
  [SMALL_STATE(14936)] = 676259,
  [SMALL_STATE(14937)] = 676282,
  [SMALL_STATE(14938)] = 676305,
  [SMALL_STATE(14939)] = 676328,
  [SMALL_STATE(14940)] = 676351,
  [SMALL_STATE(14941)] = 676374,
  [SMALL_STATE(14942)] = 676397,
  [SMALL_STATE(14943)] = 676420,
  [SMALL_STATE(14944)] = 676443,
  [SMALL_STATE(14945)] = 676466,
  [SMALL_STATE(14946)] = 676489,
  [SMALL_STATE(14947)] = 676512,
  [SMALL_STATE(14948)] = 676535,
  [SMALL_STATE(14949)] = 676558,
  [SMALL_STATE(14950)] = 676581,
  [SMALL_STATE(14951)] = 676604,
  [SMALL_STATE(14952)] = 676627,
  [SMALL_STATE(14953)] = 676650,
  [SMALL_STATE(14954)] = 676673,
  [SMALL_STATE(14955)] = 676696,
  [SMALL_STATE(14956)] = 676719,
  [SMALL_STATE(14957)] = 676742,
  [SMALL_STATE(14958)] = 676763,
  [SMALL_STATE(14959)] = 676786,
  [SMALL_STATE(14960)] = 676809,
  [SMALL_STATE(14961)] = 676830,
  [SMALL_STATE(14962)] = 676849,
  [SMALL_STATE(14963)] = 676870,
  [SMALL_STATE(14964)] = 676893,
  [SMALL_STATE(14965)] = 676916,
  [SMALL_STATE(14966)] = 676939,
  [SMALL_STATE(14967)] = 676962,
  [SMALL_STATE(14968)] = 676985,
  [SMALL_STATE(14969)] = 677008,
  [SMALL_STATE(14970)] = 677031,
  [SMALL_STATE(14971)] = 677054,
  [SMALL_STATE(14972)] = 677077,
  [SMALL_STATE(14973)] = 677100,
  [SMALL_STATE(14974)] = 677123,
  [SMALL_STATE(14975)] = 677146,
  [SMALL_STATE(14976)] = 677169,
  [SMALL_STATE(14977)] = 677192,
  [SMALL_STATE(14978)] = 677215,
  [SMALL_STATE(14979)] = 677238,
  [SMALL_STATE(14980)] = 677261,
  [SMALL_STATE(14981)] = 677284,
  [SMALL_STATE(14982)] = 677307,
  [SMALL_STATE(14983)] = 677330,
  [SMALL_STATE(14984)] = 677353,
  [SMALL_STATE(14985)] = 677376,
  [SMALL_STATE(14986)] = 677399,
  [SMALL_STATE(14987)] = 677422,
  [SMALL_STATE(14988)] = 677441,
  [SMALL_STATE(14989)] = 677464,
  [SMALL_STATE(14990)] = 677487,
  [SMALL_STATE(14991)] = 677510,
  [SMALL_STATE(14992)] = 677533,
  [SMALL_STATE(14993)] = 677556,
  [SMALL_STATE(14994)] = 677579,
  [SMALL_STATE(14995)] = 677602,
  [SMALL_STATE(14996)] = 677625,
  [SMALL_STATE(14997)] = 677646,
  [SMALL_STATE(14998)] = 677669,
  [SMALL_STATE(14999)] = 677692,
  [SMALL_STATE(15000)] = 677715,
  [SMALL_STATE(15001)] = 677738,
  [SMALL_STATE(15002)] = 677757,
  [SMALL_STATE(15003)] = 677776,
  [SMALL_STATE(15004)] = 677799,
  [SMALL_STATE(15005)] = 677822,
  [SMALL_STATE(15006)] = 677845,
  [SMALL_STATE(15007)] = 677868,
  [SMALL_STATE(15008)] = 677891,
  [SMALL_STATE(15009)] = 677914,
  [SMALL_STATE(15010)] = 677937,
  [SMALL_STATE(15011)] = 677960,
  [SMALL_STATE(15012)] = 677983,
  [SMALL_STATE(15013)] = 678006,
  [SMALL_STATE(15014)] = 678029,
  [SMALL_STATE(15015)] = 678052,
  [SMALL_STATE(15016)] = 678075,
  [SMALL_STATE(15017)] = 678098,
  [SMALL_STATE(15018)] = 678121,
  [SMALL_STATE(15019)] = 678144,
  [SMALL_STATE(15020)] = 678167,
  [SMALL_STATE(15021)] = 678186,
  [SMALL_STATE(15022)] = 678209,
  [SMALL_STATE(15023)] = 678232,
  [SMALL_STATE(15024)] = 678255,
  [SMALL_STATE(15025)] = 678278,
  [SMALL_STATE(15026)] = 678301,
  [SMALL_STATE(15027)] = 678324,
  [SMALL_STATE(15028)] = 678345,
  [SMALL_STATE(15029)] = 678368,
  [SMALL_STATE(15030)] = 678391,
  [SMALL_STATE(15031)] = 678414,
  [SMALL_STATE(15032)] = 678437,
  [SMALL_STATE(15033)] = 678460,
  [SMALL_STATE(15034)] = 678483,
  [SMALL_STATE(15035)] = 678506,
  [SMALL_STATE(15036)] = 678529,
  [SMALL_STATE(15037)] = 678550,
  [SMALL_STATE(15038)] = 678573,
  [SMALL_STATE(15039)] = 678596,
  [SMALL_STATE(15040)] = 678619,
  [SMALL_STATE(15041)] = 678640,
  [SMALL_STATE(15042)] = 678663,
  [SMALL_STATE(15043)] = 678686,
  [SMALL_STATE(15044)] = 678709,
  [SMALL_STATE(15045)] = 678730,
  [SMALL_STATE(15046)] = 678753,
  [SMALL_STATE(15047)] = 678774,
  [SMALL_STATE(15048)] = 678797,
  [SMALL_STATE(15049)] = 678820,
  [SMALL_STATE(15050)] = 678843,
  [SMALL_STATE(15051)] = 678866,
  [SMALL_STATE(15052)] = 678889,
  [SMALL_STATE(15053)] = 678912,
  [SMALL_STATE(15054)] = 678935,
  [SMALL_STATE(15055)] = 678958,
  [SMALL_STATE(15056)] = 678981,
  [SMALL_STATE(15057)] = 679004,
  [SMALL_STATE(15058)] = 679027,
  [SMALL_STATE(15059)] = 679050,
  [SMALL_STATE(15060)] = 679073,
  [SMALL_STATE(15061)] = 679096,
  [SMALL_STATE(15062)] = 679119,
  [SMALL_STATE(15063)] = 679142,
  [SMALL_STATE(15064)] = 679165,
  [SMALL_STATE(15065)] = 679186,
  [SMALL_STATE(15066)] = 679209,
  [SMALL_STATE(15067)] = 679232,
  [SMALL_STATE(15068)] = 679255,
  [SMALL_STATE(15069)] = 679278,
  [SMALL_STATE(15070)] = 679301,
  [SMALL_STATE(15071)] = 679324,
  [SMALL_STATE(15072)] = 679347,
  [SMALL_STATE(15073)] = 679370,
  [SMALL_STATE(15074)] = 679393,
  [SMALL_STATE(15075)] = 679416,
  [SMALL_STATE(15076)] = 679439,
  [SMALL_STATE(15077)] = 679462,
  [SMALL_STATE(15078)] = 679485,
  [SMALL_STATE(15079)] = 679508,
  [SMALL_STATE(15080)] = 679531,
  [SMALL_STATE(15081)] = 679554,
  [SMALL_STATE(15082)] = 679577,
  [SMALL_STATE(15083)] = 679598,
  [SMALL_STATE(15084)] = 679618,
  [SMALL_STATE(15085)] = 679638,
  [SMALL_STATE(15086)] = 679658,
  [SMALL_STATE(15087)] = 679678,
  [SMALL_STATE(15088)] = 679698,
  [SMALL_STATE(15089)] = 679718,
  [SMALL_STATE(15090)] = 679738,
  [SMALL_STATE(15091)] = 679758,
  [SMALL_STATE(15092)] = 679778,
  [SMALL_STATE(15093)] = 679798,
  [SMALL_STATE(15094)] = 679818,
  [SMALL_STATE(15095)] = 679836,
  [SMALL_STATE(15096)] = 679856,
  [SMALL_STATE(15097)] = 679876,
  [SMALL_STATE(15098)] = 679896,
  [SMALL_STATE(15099)] = 679916,
  [SMALL_STATE(15100)] = 679936,
  [SMALL_STATE(15101)] = 679956,
  [SMALL_STATE(15102)] = 679976,
  [SMALL_STATE(15103)] = 679996,
  [SMALL_STATE(15104)] = 680016,
  [SMALL_STATE(15105)] = 680036,
  [SMALL_STATE(15106)] = 680056,
  [SMALL_STATE(15107)] = 680076,
  [SMALL_STATE(15108)] = 680096,
  [SMALL_STATE(15109)] = 680114,
  [SMALL_STATE(15110)] = 680132,
  [SMALL_STATE(15111)] = 680152,
  [SMALL_STATE(15112)] = 680172,
  [SMALL_STATE(15113)] = 680190,
  [SMALL_STATE(15114)] = 680210,
  [SMALL_STATE(15115)] = 680230,
  [SMALL_STATE(15116)] = 680250,
  [SMALL_STATE(15117)] = 680270,
  [SMALL_STATE(15118)] = 680290,
  [SMALL_STATE(15119)] = 680310,
  [SMALL_STATE(15120)] = 680330,
  [SMALL_STATE(15121)] = 680350,
  [SMALL_STATE(15122)] = 680370,
  [SMALL_STATE(15123)] = 680390,
  [SMALL_STATE(15124)] = 680410,
  [SMALL_STATE(15125)] = 680428,
  [SMALL_STATE(15126)] = 680448,
  [SMALL_STATE(15127)] = 680468,
  [SMALL_STATE(15128)] = 680488,
  [SMALL_STATE(15129)] = 680508,
  [SMALL_STATE(15130)] = 680528,
  [SMALL_STATE(15131)] = 680548,
  [SMALL_STATE(15132)] = 680568,
  [SMALL_STATE(15133)] = 680588,
  [SMALL_STATE(15134)] = 680608,
  [SMALL_STATE(15135)] = 680628,
  [SMALL_STATE(15136)] = 680648,
  [SMALL_STATE(15137)] = 680668,
  [SMALL_STATE(15138)] = 680688,
  [SMALL_STATE(15139)] = 680708,
  [SMALL_STATE(15140)] = 680728,
  [SMALL_STATE(15141)] = 680746,
  [SMALL_STATE(15142)] = 680764,
  [SMALL_STATE(15143)] = 680784,
  [SMALL_STATE(15144)] = 680804,
  [SMALL_STATE(15145)] = 680824,
  [SMALL_STATE(15146)] = 680844,
  [SMALL_STATE(15147)] = 680864,
  [SMALL_STATE(15148)] = 680884,
  [SMALL_STATE(15149)] = 680904,
  [SMALL_STATE(15150)] = 680924,
  [SMALL_STATE(15151)] = 680944,
  [SMALL_STATE(15152)] = 680964,
  [SMALL_STATE(15153)] = 680984,
  [SMALL_STATE(15154)] = 681004,
  [SMALL_STATE(15155)] = 681022,
  [SMALL_STATE(15156)] = 681042,
  [SMALL_STATE(15157)] = 681062,
  [SMALL_STATE(15158)] = 681082,
  [SMALL_STATE(15159)] = 681102,
  [SMALL_STATE(15160)] = 681122,
  [SMALL_STATE(15161)] = 681142,
  [SMALL_STATE(15162)] = 681160,
  [SMALL_STATE(15163)] = 681180,
  [SMALL_STATE(15164)] = 681198,
  [SMALL_STATE(15165)] = 681216,
  [SMALL_STATE(15166)] = 681236,
  [SMALL_STATE(15167)] = 681256,
  [SMALL_STATE(15168)] = 681276,
  [SMALL_STATE(15169)] = 681294,
  [SMALL_STATE(15170)] = 681314,
  [SMALL_STATE(15171)] = 681334,
  [SMALL_STATE(15172)] = 681352,
  [SMALL_STATE(15173)] = 681372,
  [SMALL_STATE(15174)] = 681392,
  [SMALL_STATE(15175)] = 681410,
  [SMALL_STATE(15176)] = 681428,
  [SMALL_STATE(15177)] = 681448,
  [SMALL_STATE(15178)] = 681468,
  [SMALL_STATE(15179)] = 681488,
  [SMALL_STATE(15180)] = 681508,
  [SMALL_STATE(15181)] = 681528,
  [SMALL_STATE(15182)] = 681548,
  [SMALL_STATE(15183)] = 681568,
  [SMALL_STATE(15184)] = 681588,
  [SMALL_STATE(15185)] = 681608,
  [SMALL_STATE(15186)] = 681628,
  [SMALL_STATE(15187)] = 681648,
  [SMALL_STATE(15188)] = 681666,
  [SMALL_STATE(15189)] = 681686,
  [SMALL_STATE(15190)] = 681706,
  [SMALL_STATE(15191)] = 681726,
  [SMALL_STATE(15192)] = 681746,
  [SMALL_STATE(15193)] = 681766,
  [SMALL_STATE(15194)] = 681784,
  [SMALL_STATE(15195)] = 681804,
  [SMALL_STATE(15196)] = 681824,
  [SMALL_STATE(15197)] = 681844,
  [SMALL_STATE(15198)] = 681864,
  [SMALL_STATE(15199)] = 681884,
  [SMALL_STATE(15200)] = 681904,
  [SMALL_STATE(15201)] = 681924,
  [SMALL_STATE(15202)] = 681944,
  [SMALL_STATE(15203)] = 681964,
  [SMALL_STATE(15204)] = 681984,
  [SMALL_STATE(15205)] = 682004,
  [SMALL_STATE(15206)] = 682024,
  [SMALL_STATE(15207)] = 682044,
  [SMALL_STATE(15208)] = 682062,
  [SMALL_STATE(15209)] = 682082,
  [SMALL_STATE(15210)] = 682102,
  [SMALL_STATE(15211)] = 682120,
  [SMALL_STATE(15212)] = 682138,
  [SMALL_STATE(15213)] = 682158,
  [SMALL_STATE(15214)] = 682178,
  [SMALL_STATE(15215)] = 682198,
  [SMALL_STATE(15216)] = 682218,
  [SMALL_STATE(15217)] = 682238,
  [SMALL_STATE(15218)] = 682258,
  [SMALL_STATE(15219)] = 682278,
  [SMALL_STATE(15220)] = 682298,
  [SMALL_STATE(15221)] = 682318,
  [SMALL_STATE(15222)] = 682338,
  [SMALL_STATE(15223)] = 682358,
  [SMALL_STATE(15224)] = 682378,
  [SMALL_STATE(15225)] = 682396,
  [SMALL_STATE(15226)] = 682416,
  [SMALL_STATE(15227)] = 682434,
  [SMALL_STATE(15228)] = 682454,
  [SMALL_STATE(15229)] = 682474,
  [SMALL_STATE(15230)] = 682494,
  [SMALL_STATE(15231)] = 682514,
  [SMALL_STATE(15232)] = 682534,
  [SMALL_STATE(15233)] = 682554,
  [SMALL_STATE(15234)] = 682574,
  [SMALL_STATE(15235)] = 682592,
  [SMALL_STATE(15236)] = 682612,
  [SMALL_STATE(15237)] = 682632,
  [SMALL_STATE(15238)] = 682652,
  [SMALL_STATE(15239)] = 682672,
  [SMALL_STATE(15240)] = 682692,
  [SMALL_STATE(15241)] = 682710,
  [SMALL_STATE(15242)] = 682728,
  [SMALL_STATE(15243)] = 682748,
  [SMALL_STATE(15244)] = 682768,
  [SMALL_STATE(15245)] = 682788,
  [SMALL_STATE(15246)] = 682808,
  [SMALL_STATE(15247)] = 682828,
  [SMALL_STATE(15248)] = 682846,
  [SMALL_STATE(15249)] = 682866,
  [SMALL_STATE(15250)] = 682886,
  [SMALL_STATE(15251)] = 682906,
  [SMALL_STATE(15252)] = 682926,
  [SMALL_STATE(15253)] = 682944,
  [SMALL_STATE(15254)] = 682964,
  [SMALL_STATE(15255)] = 682984,
  [SMALL_STATE(15256)] = 683004,
  [SMALL_STATE(15257)] = 683024,
  [SMALL_STATE(15258)] = 683042,
  [SMALL_STATE(15259)] = 683062,
  [SMALL_STATE(15260)] = 683082,
  [SMALL_STATE(15261)] = 683102,
  [SMALL_STATE(15262)] = 683122,
  [SMALL_STATE(15263)] = 683142,
  [SMALL_STATE(15264)] = 683162,
  [SMALL_STATE(15265)] = 683182,
  [SMALL_STATE(15266)] = 683200,
  [SMALL_STATE(15267)] = 683220,
  [SMALL_STATE(15268)] = 683240,
  [SMALL_STATE(15269)] = 683260,
  [SMALL_STATE(15270)] = 683280,
  [SMALL_STATE(15271)] = 683298,
  [SMALL_STATE(15272)] = 683318,
  [SMALL_STATE(15273)] = 683338,
  [SMALL_STATE(15274)] = 683358,
  [SMALL_STATE(15275)] = 683378,
  [SMALL_STATE(15276)] = 683398,
  [SMALL_STATE(15277)] = 683418,
  [SMALL_STATE(15278)] = 683438,
  [SMALL_STATE(15279)] = 683458,
  [SMALL_STATE(15280)] = 683478,
  [SMALL_STATE(15281)] = 683498,
  [SMALL_STATE(15282)] = 683518,
  [SMALL_STATE(15283)] = 683538,
  [SMALL_STATE(15284)] = 683558,
  [SMALL_STATE(15285)] = 683578,
  [SMALL_STATE(15286)] = 683598,
  [SMALL_STATE(15287)] = 683618,
  [SMALL_STATE(15288)] = 683638,
  [SMALL_STATE(15289)] = 683658,
  [SMALL_STATE(15290)] = 683678,
  [SMALL_STATE(15291)] = 683698,
  [SMALL_STATE(15292)] = 683718,
  [SMALL_STATE(15293)] = 683736,
  [SMALL_STATE(15294)] = 683756,
  [SMALL_STATE(15295)] = 683776,
  [SMALL_STATE(15296)] = 683796,
  [SMALL_STATE(15297)] = 683812,
  [SMALL_STATE(15298)] = 683832,
  [SMALL_STATE(15299)] = 683852,
  [SMALL_STATE(15300)] = 683872,
  [SMALL_STATE(15301)] = 683892,
  [SMALL_STATE(15302)] = 683912,
  [SMALL_STATE(15303)] = 683932,
  [SMALL_STATE(15304)] = 683952,
  [SMALL_STATE(15305)] = 683970,
  [SMALL_STATE(15306)] = 683990,
  [SMALL_STATE(15307)] = 684008,
  [SMALL_STATE(15308)] = 684026,
  [SMALL_STATE(15309)] = 684046,
  [SMALL_STATE(15310)] = 684066,
  [SMALL_STATE(15311)] = 684086,
  [SMALL_STATE(15312)] = 684104,
  [SMALL_STATE(15313)] = 684124,
  [SMALL_STATE(15314)] = 684144,
  [SMALL_STATE(15315)] = 684164,
  [SMALL_STATE(15316)] = 684184,
  [SMALL_STATE(15317)] = 684204,
  [SMALL_STATE(15318)] = 684224,
  [SMALL_STATE(15319)] = 684244,
  [SMALL_STATE(15320)] = 684264,
  [SMALL_STATE(15321)] = 684284,
  [SMALL_STATE(15322)] = 684304,
  [SMALL_STATE(15323)] = 684322,
  [SMALL_STATE(15324)] = 684340,
  [SMALL_STATE(15325)] = 684360,
  [SMALL_STATE(15326)] = 684380,
  [SMALL_STATE(15327)] = 684400,
  [SMALL_STATE(15328)] = 684420,
  [SMALL_STATE(15329)] = 684438,
  [SMALL_STATE(15330)] = 684458,
  [SMALL_STATE(15331)] = 684478,
  [SMALL_STATE(15332)] = 684498,
  [SMALL_STATE(15333)] = 684518,
  [SMALL_STATE(15334)] = 684538,
  [SMALL_STATE(15335)] = 684556,
  [SMALL_STATE(15336)] = 684576,
  [SMALL_STATE(15337)] = 684596,
  [SMALL_STATE(15338)] = 684616,
  [SMALL_STATE(15339)] = 684636,
  [SMALL_STATE(15340)] = 684656,
  [SMALL_STATE(15341)] = 684676,
  [SMALL_STATE(15342)] = 684696,
  [SMALL_STATE(15343)] = 684716,
  [SMALL_STATE(15344)] = 684736,
  [SMALL_STATE(15345)] = 684756,
  [SMALL_STATE(15346)] = 684776,
  [SMALL_STATE(15347)] = 684796,
  [SMALL_STATE(15348)] = 684816,
  [SMALL_STATE(15349)] = 684836,
  [SMALL_STATE(15350)] = 684856,
  [SMALL_STATE(15351)] = 684876,
  [SMALL_STATE(15352)] = 684896,
  [SMALL_STATE(15353)] = 684916,
  [SMALL_STATE(15354)] = 684936,
  [SMALL_STATE(15355)] = 684956,
  [SMALL_STATE(15356)] = 684974,
  [SMALL_STATE(15357)] = 684994,
  [SMALL_STATE(15358)] = 685014,
  [SMALL_STATE(15359)] = 685034,
  [SMALL_STATE(15360)] = 685054,
  [SMALL_STATE(15361)] = 685072,
  [SMALL_STATE(15362)] = 685090,
  [SMALL_STATE(15363)] = 685110,
  [SMALL_STATE(15364)] = 685130,
  [SMALL_STATE(15365)] = 685150,
  [SMALL_STATE(15366)] = 685170,
  [SMALL_STATE(15367)] = 685190,
  [SMALL_STATE(15368)] = 685210,
  [SMALL_STATE(15369)] = 685230,
  [SMALL_STATE(15370)] = 685250,
  [SMALL_STATE(15371)] = 685270,
  [SMALL_STATE(15372)] = 685290,
  [SMALL_STATE(15373)] = 685310,
  [SMALL_STATE(15374)] = 685330,
  [SMALL_STATE(15375)] = 685348,
  [SMALL_STATE(15376)] = 685368,
  [SMALL_STATE(15377)] = 685388,
  [SMALL_STATE(15378)] = 685408,
  [SMALL_STATE(15379)] = 685428,
  [SMALL_STATE(15380)] = 685448,
  [SMALL_STATE(15381)] = 685468,
  [SMALL_STATE(15382)] = 685488,
  [SMALL_STATE(15383)] = 685508,
  [SMALL_STATE(15384)] = 685526,
  [SMALL_STATE(15385)] = 685544,
  [SMALL_STATE(15386)] = 685564,
  [SMALL_STATE(15387)] = 685584,
  [SMALL_STATE(15388)] = 685602,
  [SMALL_STATE(15389)] = 685622,
  [SMALL_STATE(15390)] = 685642,
  [SMALL_STATE(15391)] = 685662,
  [SMALL_STATE(15392)] = 685682,
  [SMALL_STATE(15393)] = 685702,
  [SMALL_STATE(15394)] = 685720,
  [SMALL_STATE(15395)] = 685740,
  [SMALL_STATE(15396)] = 685760,
  [SMALL_STATE(15397)] = 685778,
  [SMALL_STATE(15398)] = 685798,
  [SMALL_STATE(15399)] = 685818,
  [SMALL_STATE(15400)] = 685838,
  [SMALL_STATE(15401)] = 685858,
  [SMALL_STATE(15402)] = 685876,
  [SMALL_STATE(15403)] = 685896,
  [SMALL_STATE(15404)] = 685916,
  [SMALL_STATE(15405)] = 685936,
  [SMALL_STATE(15406)] = 685954,
  [SMALL_STATE(15407)] = 685974,
  [SMALL_STATE(15408)] = 685994,
  [SMALL_STATE(15409)] = 686014,
  [SMALL_STATE(15410)] = 686034,
  [SMALL_STATE(15411)] = 686054,
  [SMALL_STATE(15412)] = 686074,
  [SMALL_STATE(15413)] = 686094,
  [SMALL_STATE(15414)] = 686114,
  [SMALL_STATE(15415)] = 686132,
  [SMALL_STATE(15416)] = 686152,
  [SMALL_STATE(15417)] = 686172,
  [SMALL_STATE(15418)] = 686192,
  [SMALL_STATE(15419)] = 686212,
  [SMALL_STATE(15420)] = 686232,
  [SMALL_STATE(15421)] = 686252,
  [SMALL_STATE(15422)] = 686272,
  [SMALL_STATE(15423)] = 686292,
  [SMALL_STATE(15424)] = 686310,
  [SMALL_STATE(15425)] = 686330,
  [SMALL_STATE(15426)] = 686350,
  [SMALL_STATE(15427)] = 686368,
  [SMALL_STATE(15428)] = 686388,
  [SMALL_STATE(15429)] = 686408,
  [SMALL_STATE(15430)] = 686426,
  [SMALL_STATE(15431)] = 686444,
  [SMALL_STATE(15432)] = 686464,
  [SMALL_STATE(15433)] = 686484,
  [SMALL_STATE(15434)] = 686504,
  [SMALL_STATE(15435)] = 686524,
  [SMALL_STATE(15436)] = 686544,
  [SMALL_STATE(15437)] = 686564,
  [SMALL_STATE(15438)] = 686582,
  [SMALL_STATE(15439)] = 686602,
  [SMALL_STATE(15440)] = 686620,
  [SMALL_STATE(15441)] = 686640,
  [SMALL_STATE(15442)] = 686660,
  [SMALL_STATE(15443)] = 686680,
  [SMALL_STATE(15444)] = 686700,
  [SMALL_STATE(15445)] = 686720,
  [SMALL_STATE(15446)] = 686738,
  [SMALL_STATE(15447)] = 686758,
  [SMALL_STATE(15448)] = 686778,
  [SMALL_STATE(15449)] = 686798,
  [SMALL_STATE(15450)] = 686818,
  [SMALL_STATE(15451)] = 686838,
  [SMALL_STATE(15452)] = 686858,
  [SMALL_STATE(15453)] = 686878,
  [SMALL_STATE(15454)] = 686898,
  [SMALL_STATE(15455)] = 686918,
  [SMALL_STATE(15456)] = 686936,
  [SMALL_STATE(15457)] = 686956,
  [SMALL_STATE(15458)] = 686976,
  [SMALL_STATE(15459)] = 686996,
  [SMALL_STATE(15460)] = 687014,
  [SMALL_STATE(15461)] = 687034,
  [SMALL_STATE(15462)] = 687054,
  [SMALL_STATE(15463)] = 687074,
  [SMALL_STATE(15464)] = 687094,
  [SMALL_STATE(15465)] = 687112,
  [SMALL_STATE(15466)] = 687132,
  [SMALL_STATE(15467)] = 687152,
  [SMALL_STATE(15468)] = 687172,
  [SMALL_STATE(15469)] = 687192,
  [SMALL_STATE(15470)] = 687212,
  [SMALL_STATE(15471)] = 687232,
  [SMALL_STATE(15472)] = 687252,
  [SMALL_STATE(15473)] = 687272,
  [SMALL_STATE(15474)] = 687292,
  [SMALL_STATE(15475)] = 687312,
  [SMALL_STATE(15476)] = 687330,
  [SMALL_STATE(15477)] = 687350,
  [SMALL_STATE(15478)] = 687370,
  [SMALL_STATE(15479)] = 687390,
  [SMALL_STATE(15480)] = 687410,
  [SMALL_STATE(15481)] = 687430,
  [SMALL_STATE(15482)] = 687450,
  [SMALL_STATE(15483)] = 687470,
  [SMALL_STATE(15484)] = 687490,
  [SMALL_STATE(15485)] = 687510,
  [SMALL_STATE(15486)] = 687528,
  [SMALL_STATE(15487)] = 687548,
  [SMALL_STATE(15488)] = 687568,
  [SMALL_STATE(15489)] = 687588,
  [SMALL_STATE(15490)] = 687608,
  [SMALL_STATE(15491)] = 687628,
  [SMALL_STATE(15492)] = 687648,
  [SMALL_STATE(15493)] = 687668,
  [SMALL_STATE(15494)] = 687688,
  [SMALL_STATE(15495)] = 687706,
  [SMALL_STATE(15496)] = 687724,
  [SMALL_STATE(15497)] = 687742,
  [SMALL_STATE(15498)] = 687760,
  [SMALL_STATE(15499)] = 687778,
  [SMALL_STATE(15500)] = 687798,
  [SMALL_STATE(15501)] = 687818,
  [SMALL_STATE(15502)] = 687836,
  [SMALL_STATE(15503)] = 687856,
  [SMALL_STATE(15504)] = 687876,
  [SMALL_STATE(15505)] = 687896,
  [SMALL_STATE(15506)] = 687916,
  [SMALL_STATE(15507)] = 687936,
  [SMALL_STATE(15508)] = 687954,
  [SMALL_STATE(15509)] = 687974,
  [SMALL_STATE(15510)] = 687994,
  [SMALL_STATE(15511)] = 688014,
  [SMALL_STATE(15512)] = 688032,
  [SMALL_STATE(15513)] = 688052,
  [SMALL_STATE(15514)] = 688072,
  [SMALL_STATE(15515)] = 688092,
  [SMALL_STATE(15516)] = 688112,
  [SMALL_STATE(15517)] = 688132,
  [SMALL_STATE(15518)] = 688152,
  [SMALL_STATE(15519)] = 688172,
  [SMALL_STATE(15520)] = 688192,
  [SMALL_STATE(15521)] = 688210,
  [SMALL_STATE(15522)] = 688230,
  [SMALL_STATE(15523)] = 688250,
  [SMALL_STATE(15524)] = 688268,
  [SMALL_STATE(15525)] = 688286,
  [SMALL_STATE(15526)] = 688306,
  [SMALL_STATE(15527)] = 688324,
  [SMALL_STATE(15528)] = 688344,
  [SMALL_STATE(15529)] = 688364,
  [SMALL_STATE(15530)] = 688384,
  [SMALL_STATE(15531)] = 688404,
  [SMALL_STATE(15532)] = 688424,
  [SMALL_STATE(15533)] = 688444,
  [SMALL_STATE(15534)] = 688462,
  [SMALL_STATE(15535)] = 688478,
  [SMALL_STATE(15536)] = 688498,
  [SMALL_STATE(15537)] = 688516,
  [SMALL_STATE(15538)] = 688536,
  [SMALL_STATE(15539)] = 688556,
  [SMALL_STATE(15540)] = 688576,
  [SMALL_STATE(15541)] = 688594,
  [SMALL_STATE(15542)] = 688612,
  [SMALL_STATE(15543)] = 688630,
  [SMALL_STATE(15544)] = 688650,
  [SMALL_STATE(15545)] = 688670,
  [SMALL_STATE(15546)] = 688690,
  [SMALL_STATE(15547)] = 688710,
  [SMALL_STATE(15548)] = 688728,
  [SMALL_STATE(15549)] = 688748,
  [SMALL_STATE(15550)] = 688766,
  [SMALL_STATE(15551)] = 688786,
  [SMALL_STATE(15552)] = 688806,
  [SMALL_STATE(15553)] = 688826,
  [SMALL_STATE(15554)] = 688846,
  [SMALL_STATE(15555)] = 688866,
  [SMALL_STATE(15556)] = 688886,
  [SMALL_STATE(15557)] = 688906,
  [SMALL_STATE(15558)] = 688926,
  [SMALL_STATE(15559)] = 688944,
  [SMALL_STATE(15560)] = 688964,
  [SMALL_STATE(15561)] = 688982,
  [SMALL_STATE(15562)] = 689002,
  [SMALL_STATE(15563)] = 689022,
  [SMALL_STATE(15564)] = 689042,
  [SMALL_STATE(15565)] = 689062,
  [SMALL_STATE(15566)] = 689082,
  [SMALL_STATE(15567)] = 689100,
  [SMALL_STATE(15568)] = 689120,
  [SMALL_STATE(15569)] = 689138,
  [SMALL_STATE(15570)] = 689158,
  [SMALL_STATE(15571)] = 689176,
  [SMALL_STATE(15572)] = 689196,
  [SMALL_STATE(15573)] = 689216,
  [SMALL_STATE(15574)] = 689234,
  [SMALL_STATE(15575)] = 689254,
  [SMALL_STATE(15576)] = 689274,
  [SMALL_STATE(15577)] = 689292,
  [SMALL_STATE(15578)] = 689312,
  [SMALL_STATE(15579)] = 689332,
  [SMALL_STATE(15580)] = 689350,
  [SMALL_STATE(15581)] = 689370,
  [SMALL_STATE(15582)] = 689390,
  [SMALL_STATE(15583)] = 689408,
  [SMALL_STATE(15584)] = 689428,
  [SMALL_STATE(15585)] = 689448,
  [SMALL_STATE(15586)] = 689466,
  [SMALL_STATE(15587)] = 689486,
  [SMALL_STATE(15588)] = 689506,
  [SMALL_STATE(15589)] = 689526,
  [SMALL_STATE(15590)] = 689546,
  [SMALL_STATE(15591)] = 689564,
  [SMALL_STATE(15592)] = 689584,
  [SMALL_STATE(15593)] = 689604,
  [SMALL_STATE(15594)] = 689624,
  [SMALL_STATE(15595)] = 689644,
  [SMALL_STATE(15596)] = 689664,
  [SMALL_STATE(15597)] = 689680,
  [SMALL_STATE(15598)] = 689700,
  [SMALL_STATE(15599)] = 689720,
  [SMALL_STATE(15600)] = 689738,
  [SMALL_STATE(15601)] = 689758,
  [SMALL_STATE(15602)] = 689778,
  [SMALL_STATE(15603)] = 689794,
  [SMALL_STATE(15604)] = 689814,
  [SMALL_STATE(15605)] = 689834,
  [SMALL_STATE(15606)] = 689854,
  [SMALL_STATE(15607)] = 689874,
  [SMALL_STATE(15608)] = 689892,
  [SMALL_STATE(15609)] = 689910,
  [SMALL_STATE(15610)] = 689930,
  [SMALL_STATE(15611)] = 689950,
  [SMALL_STATE(15612)] = 689968,
  [SMALL_STATE(15613)] = 689988,
  [SMALL_STATE(15614)] = 690008,
  [SMALL_STATE(15615)] = 690028,
  [SMALL_STATE(15616)] = 690048,
  [SMALL_STATE(15617)] = 690068,
  [SMALL_STATE(15618)] = 690088,
  [SMALL_STATE(15619)] = 690108,
  [SMALL_STATE(15620)] = 690128,
  [SMALL_STATE(15621)] = 690148,
  [SMALL_STATE(15622)] = 690166,
  [SMALL_STATE(15623)] = 690186,
  [SMALL_STATE(15624)] = 690206,
  [SMALL_STATE(15625)] = 690226,
  [SMALL_STATE(15626)] = 690246,
  [SMALL_STATE(15627)] = 690266,
  [SMALL_STATE(15628)] = 690284,
  [SMALL_STATE(15629)] = 690304,
  [SMALL_STATE(15630)] = 690324,
  [SMALL_STATE(15631)] = 690344,
  [SMALL_STATE(15632)] = 690364,
  [SMALL_STATE(15633)] = 690384,
  [SMALL_STATE(15634)] = 690402,
  [SMALL_STATE(15635)] = 690422,
  [SMALL_STATE(15636)] = 690442,
  [SMALL_STATE(15637)] = 690462,
  [SMALL_STATE(15638)] = 690482,
  [SMALL_STATE(15639)] = 690502,
  [SMALL_STATE(15640)] = 690522,
  [SMALL_STATE(15641)] = 690542,
  [SMALL_STATE(15642)] = 690562,
  [SMALL_STATE(15643)] = 690582,
  [SMALL_STATE(15644)] = 690602,
  [SMALL_STATE(15645)] = 690622,
  [SMALL_STATE(15646)] = 690640,
  [SMALL_STATE(15647)] = 690660,
  [SMALL_STATE(15648)] = 690680,
  [SMALL_STATE(15649)] = 690698,
  [SMALL_STATE(15650)] = 690716,
  [SMALL_STATE(15651)] = 690736,
  [SMALL_STATE(15652)] = 690754,
  [SMALL_STATE(15653)] = 690774,
  [SMALL_STATE(15654)] = 690792,
  [SMALL_STATE(15655)] = 690812,
  [SMALL_STATE(15656)] = 690832,
  [SMALL_STATE(15657)] = 690852,
  [SMALL_STATE(15658)] = 690872,
  [SMALL_STATE(15659)] = 690892,
  [SMALL_STATE(15660)] = 690912,
  [SMALL_STATE(15661)] = 690932,
  [SMALL_STATE(15662)] = 690952,
  [SMALL_STATE(15663)] = 690972,
  [SMALL_STATE(15664)] = 690990,
  [SMALL_STATE(15665)] = 691010,
  [SMALL_STATE(15666)] = 691030,
  [SMALL_STATE(15667)] = 691050,
  [SMALL_STATE(15668)] = 691068,
  [SMALL_STATE(15669)] = 691088,
  [SMALL_STATE(15670)] = 691108,
  [SMALL_STATE(15671)] = 691128,
  [SMALL_STATE(15672)] = 691146,
  [SMALL_STATE(15673)] = 691166,
  [SMALL_STATE(15674)] = 691186,
  [SMALL_STATE(15675)] = 691206,
  [SMALL_STATE(15676)] = 691226,
  [SMALL_STATE(15677)] = 691246,
  [SMALL_STATE(15678)] = 691266,
  [SMALL_STATE(15679)] = 691286,
  [SMALL_STATE(15680)] = 691306,
  [SMALL_STATE(15681)] = 691326,
  [SMALL_STATE(15682)] = 691346,
  [SMALL_STATE(15683)] = 691366,
  [SMALL_STATE(15684)] = 691386,
  [SMALL_STATE(15685)] = 691406,
  [SMALL_STATE(15686)] = 691426,
  [SMALL_STATE(15687)] = 691446,
  [SMALL_STATE(15688)] = 691466,
  [SMALL_STATE(15689)] = 691482,
  [SMALL_STATE(15690)] = 691502,
  [SMALL_STATE(15691)] = 691522,
  [SMALL_STATE(15692)] = 691542,
  [SMALL_STATE(15693)] = 691562,
  [SMALL_STATE(15694)] = 691582,
  [SMALL_STATE(15695)] = 691602,
  [SMALL_STATE(15696)] = 691622,
  [SMALL_STATE(15697)] = 691642,
  [SMALL_STATE(15698)] = 691662,
  [SMALL_STATE(15699)] = 691682,
  [SMALL_STATE(15700)] = 691700,
  [SMALL_STATE(15701)] = 691720,
  [SMALL_STATE(15702)] = 691740,
  [SMALL_STATE(15703)] = 691758,
  [SMALL_STATE(15704)] = 691778,
  [SMALL_STATE(15705)] = 691796,
  [SMALL_STATE(15706)] = 691816,
  [SMALL_STATE(15707)] = 691836,
  [SMALL_STATE(15708)] = 691856,
  [SMALL_STATE(15709)] = 691876,
  [SMALL_STATE(15710)] = 691896,
  [SMALL_STATE(15711)] = 691916,
  [SMALL_STATE(15712)] = 691936,
  [SMALL_STATE(15713)] = 691956,
  [SMALL_STATE(15714)] = 691976,
  [SMALL_STATE(15715)] = 691996,
  [SMALL_STATE(15716)] = 692016,
  [SMALL_STATE(15717)] = 692036,
  [SMALL_STATE(15718)] = 692056,
  [SMALL_STATE(15719)] = 692074,
  [SMALL_STATE(15720)] = 692094,
  [SMALL_STATE(15721)] = 692114,
  [SMALL_STATE(15722)] = 692134,
  [SMALL_STATE(15723)] = 692154,
  [SMALL_STATE(15724)] = 692174,
  [SMALL_STATE(15725)] = 692194,
  [SMALL_STATE(15726)] = 692212,
  [SMALL_STATE(15727)] = 692232,
  [SMALL_STATE(15728)] = 692252,
  [SMALL_STATE(15729)] = 692272,
  [SMALL_STATE(15730)] = 692292,
  [SMALL_STATE(15731)] = 692312,
  [SMALL_STATE(15732)] = 692332,
  [SMALL_STATE(15733)] = 692352,
  [SMALL_STATE(15734)] = 692372,
  [SMALL_STATE(15735)] = 692392,
  [SMALL_STATE(15736)] = 692412,
  [SMALL_STATE(15737)] = 692432,
  [SMALL_STATE(15738)] = 692452,
  [SMALL_STATE(15739)] = 692472,
  [SMALL_STATE(15740)] = 692492,
  [SMALL_STATE(15741)] = 692512,
  [SMALL_STATE(15742)] = 692532,
  [SMALL_STATE(15743)] = 692550,
  [SMALL_STATE(15744)] = 692570,
  [SMALL_STATE(15745)] = 692588,
  [SMALL_STATE(15746)] = 692608,
  [SMALL_STATE(15747)] = 692626,
  [SMALL_STATE(15748)] = 692646,
  [SMALL_STATE(15749)] = 692664,
  [SMALL_STATE(15750)] = 692682,
  [SMALL_STATE(15751)] = 692700,
  [SMALL_STATE(15752)] = 692720,
  [SMALL_STATE(15753)] = 692740,
  [SMALL_STATE(15754)] = 692760,
  [SMALL_STATE(15755)] = 692778,
  [SMALL_STATE(15756)] = 692798,
  [SMALL_STATE(15757)] = 692818,
  [SMALL_STATE(15758)] = 692838,
  [SMALL_STATE(15759)] = 692858,
  [SMALL_STATE(15760)] = 692876,
  [SMALL_STATE(15761)] = 692896,
  [SMALL_STATE(15762)] = 692916,
  [SMALL_STATE(15763)] = 692934,
  [SMALL_STATE(15764)] = 692954,
  [SMALL_STATE(15765)] = 692972,
  [SMALL_STATE(15766)] = 692992,
  [SMALL_STATE(15767)] = 693012,
  [SMALL_STATE(15768)] = 693032,
  [SMALL_STATE(15769)] = 693052,
  [SMALL_STATE(15770)] = 693070,
  [SMALL_STATE(15771)] = 693088,
  [SMALL_STATE(15772)] = 693108,
  [SMALL_STATE(15773)] = 693126,
  [SMALL_STATE(15774)] = 693144,
  [SMALL_STATE(15775)] = 693162,
  [SMALL_STATE(15776)] = 693182,
  [SMALL_STATE(15777)] = 693202,
  [SMALL_STATE(15778)] = 693222,
  [SMALL_STATE(15779)] = 693240,
  [SMALL_STATE(15780)] = 693260,
  [SMALL_STATE(15781)] = 693280,
  [SMALL_STATE(15782)] = 693298,
  [SMALL_STATE(15783)] = 693318,
  [SMALL_STATE(15784)] = 693338,
  [SMALL_STATE(15785)] = 693358,
  [SMALL_STATE(15786)] = 693378,
  [SMALL_STATE(15787)] = 693398,
  [SMALL_STATE(15788)] = 693418,
  [SMALL_STATE(15789)] = 693438,
  [SMALL_STATE(15790)] = 693458,
  [SMALL_STATE(15791)] = 693478,
  [SMALL_STATE(15792)] = 693496,
  [SMALL_STATE(15793)] = 693516,
  [SMALL_STATE(15794)] = 693536,
  [SMALL_STATE(15795)] = 693556,
  [SMALL_STATE(15796)] = 693576,
  [SMALL_STATE(15797)] = 693596,
  [SMALL_STATE(15798)] = 693616,
  [SMALL_STATE(15799)] = 693636,
  [SMALL_STATE(15800)] = 693656,
  [SMALL_STATE(15801)] = 693676,
  [SMALL_STATE(15802)] = 693694,
  [SMALL_STATE(15803)] = 693714,
  [SMALL_STATE(15804)] = 693734,
  [SMALL_STATE(15805)] = 693754,
  [SMALL_STATE(15806)] = 693772,
  [SMALL_STATE(15807)] = 693792,
  [SMALL_STATE(15808)] = 693812,
  [SMALL_STATE(15809)] = 693832,
  [SMALL_STATE(15810)] = 693852,
  [SMALL_STATE(15811)] = 693872,
  [SMALL_STATE(15812)] = 693892,
  [SMALL_STATE(15813)] = 693912,
  [SMALL_STATE(15814)] = 693932,
  [SMALL_STATE(15815)] = 693952,
  [SMALL_STATE(15816)] = 693972,
  [SMALL_STATE(15817)] = 693992,
  [SMALL_STATE(15818)] = 694012,
  [SMALL_STATE(15819)] = 694032,
  [SMALL_STATE(15820)] = 694052,
  [SMALL_STATE(15821)] = 694072,
  [SMALL_STATE(15822)] = 694092,
  [SMALL_STATE(15823)] = 694112,
  [SMALL_STATE(15824)] = 694132,
  [SMALL_STATE(15825)] = 694152,
  [SMALL_STATE(15826)] = 694172,
  [SMALL_STATE(15827)] = 694192,
  [SMALL_STATE(15828)] = 694212,
  [SMALL_STATE(15829)] = 694232,
  [SMALL_STATE(15830)] = 694252,
  [SMALL_STATE(15831)] = 694272,
  [SMALL_STATE(15832)] = 694292,
  [SMALL_STATE(15833)] = 694312,
  [SMALL_STATE(15834)] = 694332,
  [SMALL_STATE(15835)] = 694352,
  [SMALL_STATE(15836)] = 694372,
  [SMALL_STATE(15837)] = 694392,
  [SMALL_STATE(15838)] = 694412,
  [SMALL_STATE(15839)] = 694432,
  [SMALL_STATE(15840)] = 694450,
  [SMALL_STATE(15841)] = 694470,
  [SMALL_STATE(15842)] = 694490,
  [SMALL_STATE(15843)] = 694510,
  [SMALL_STATE(15844)] = 694530,
  [SMALL_STATE(15845)] = 694550,
  [SMALL_STATE(15846)] = 694570,
  [SMALL_STATE(15847)] = 694588,
  [SMALL_STATE(15848)] = 694608,
  [SMALL_STATE(15849)] = 694628,
  [SMALL_STATE(15850)] = 694648,
  [SMALL_STATE(15851)] = 694668,
  [SMALL_STATE(15852)] = 694688,
  [SMALL_STATE(15853)] = 694708,
  [SMALL_STATE(15854)] = 694728,
  [SMALL_STATE(15855)] = 694748,
  [SMALL_STATE(15856)] = 694768,
  [SMALL_STATE(15857)] = 694788,
  [SMALL_STATE(15858)] = 694808,
  [SMALL_STATE(15859)] = 694828,
  [SMALL_STATE(15860)] = 694848,
  [SMALL_STATE(15861)] = 694868,
  [SMALL_STATE(15862)] = 694888,
  [SMALL_STATE(15863)] = 694908,
  [SMALL_STATE(15864)] = 694928,
  [SMALL_STATE(15865)] = 694948,
  [SMALL_STATE(15866)] = 694968,
  [SMALL_STATE(15867)] = 694988,
  [SMALL_STATE(15868)] = 695008,
  [SMALL_STATE(15869)] = 695028,
  [SMALL_STATE(15870)] = 695048,
  [SMALL_STATE(15871)] = 695068,
  [SMALL_STATE(15872)] = 695086,
  [SMALL_STATE(15873)] = 695106,
  [SMALL_STATE(15874)] = 695126,
  [SMALL_STATE(15875)] = 695146,
  [SMALL_STATE(15876)] = 695164,
  [SMALL_STATE(15877)] = 695184,
  [SMALL_STATE(15878)] = 695200,
  [SMALL_STATE(15879)] = 695220,
  [SMALL_STATE(15880)] = 695240,
  [SMALL_STATE(15881)] = 695260,
  [SMALL_STATE(15882)] = 695280,
  [SMALL_STATE(15883)] = 695300,
  [SMALL_STATE(15884)] = 695320,
  [SMALL_STATE(15885)] = 695340,
  [SMALL_STATE(15886)] = 695360,
  [SMALL_STATE(15887)] = 695380,
  [SMALL_STATE(15888)] = 695400,
  [SMALL_STATE(15889)] = 695420,
  [SMALL_STATE(15890)] = 695440,
  [SMALL_STATE(15891)] = 695460,
  [SMALL_STATE(15892)] = 695480,
  [SMALL_STATE(15893)] = 695500,
  [SMALL_STATE(15894)] = 695518,
  [SMALL_STATE(15895)] = 695538,
  [SMALL_STATE(15896)] = 695556,
  [SMALL_STATE(15897)] = 695576,
  [SMALL_STATE(15898)] = 695596,
  [SMALL_STATE(15899)] = 695616,
  [SMALL_STATE(15900)] = 695636,
  [SMALL_STATE(15901)] = 695656,
  [SMALL_STATE(15902)] = 695676,
  [SMALL_STATE(15903)] = 695696,
  [SMALL_STATE(15904)] = 695714,
  [SMALL_STATE(15905)] = 695734,
  [SMALL_STATE(15906)] = 695754,
  [SMALL_STATE(15907)] = 695774,
  [SMALL_STATE(15908)] = 695792,
  [SMALL_STATE(15909)] = 695812,
  [SMALL_STATE(15910)] = 695832,
  [SMALL_STATE(15911)] = 695852,
  [SMALL_STATE(15912)] = 695872,
  [SMALL_STATE(15913)] = 695892,
  [SMALL_STATE(15914)] = 695912,
  [SMALL_STATE(15915)] = 695932,
  [SMALL_STATE(15916)] = 695952,
  [SMALL_STATE(15917)] = 695972,
  [SMALL_STATE(15918)] = 695992,
  [SMALL_STATE(15919)] = 696012,
  [SMALL_STATE(15920)] = 696030,
  [SMALL_STATE(15921)] = 696050,
  [SMALL_STATE(15922)] = 696070,
  [SMALL_STATE(15923)] = 696090,
  [SMALL_STATE(15924)] = 696110,
  [SMALL_STATE(15925)] = 696130,
  [SMALL_STATE(15926)] = 696150,
  [SMALL_STATE(15927)] = 696166,
  [SMALL_STATE(15928)] = 696186,
  [SMALL_STATE(15929)] = 696204,
  [SMALL_STATE(15930)] = 696224,
  [SMALL_STATE(15931)] = 696244,
  [SMALL_STATE(15932)] = 696262,
  [SMALL_STATE(15933)] = 696282,
  [SMALL_STATE(15934)] = 696300,
  [SMALL_STATE(15935)] = 696320,
  [SMALL_STATE(15936)] = 696340,
  [SMALL_STATE(15937)] = 696360,
  [SMALL_STATE(15938)] = 696380,
  [SMALL_STATE(15939)] = 696400,
  [SMALL_STATE(15940)] = 696418,
  [SMALL_STATE(15941)] = 696438,
  [SMALL_STATE(15942)] = 696458,
  [SMALL_STATE(15943)] = 696478,
  [SMALL_STATE(15944)] = 696498,
  [SMALL_STATE(15945)] = 696518,
  [SMALL_STATE(15946)] = 696538,
  [SMALL_STATE(15947)] = 696558,
  [SMALL_STATE(15948)] = 696578,
  [SMALL_STATE(15949)] = 696596,
  [SMALL_STATE(15950)] = 696616,
  [SMALL_STATE(15951)] = 696634,
  [SMALL_STATE(15952)] = 696654,
  [SMALL_STATE(15953)] = 696674,
  [SMALL_STATE(15954)] = 696692,
  [SMALL_STATE(15955)] = 696712,
  [SMALL_STATE(15956)] = 696730,
  [SMALL_STATE(15957)] = 696750,
  [SMALL_STATE(15958)] = 696770,
  [SMALL_STATE(15959)] = 696790,
  [SMALL_STATE(15960)] = 696808,
  [SMALL_STATE(15961)] = 696828,
  [SMALL_STATE(15962)] = 696848,
  [SMALL_STATE(15963)] = 696868,
  [SMALL_STATE(15964)] = 696888,
  [SMALL_STATE(15965)] = 696908,
  [SMALL_STATE(15966)] = 696928,
  [SMALL_STATE(15967)] = 696948,
  [SMALL_STATE(15968)] = 696968,
  [SMALL_STATE(15969)] = 696988,
  [SMALL_STATE(15970)] = 697008,
  [SMALL_STATE(15971)] = 697028,
  [SMALL_STATE(15972)] = 697048,
  [SMALL_STATE(15973)] = 697068,
  [SMALL_STATE(15974)] = 697088,
  [SMALL_STATE(15975)] = 697108,
  [SMALL_STATE(15976)] = 697128,
  [SMALL_STATE(15977)] = 697148,
  [SMALL_STATE(15978)] = 697168,
  [SMALL_STATE(15979)] = 697188,
  [SMALL_STATE(15980)] = 697206,
  [SMALL_STATE(15981)] = 697226,
  [SMALL_STATE(15982)] = 697246,
  [SMALL_STATE(15983)] = 697266,
  [SMALL_STATE(15984)] = 697286,
  [SMALL_STATE(15985)] = 697306,
  [SMALL_STATE(15986)] = 697326,
  [SMALL_STATE(15987)] = 697346,
  [SMALL_STATE(15988)] = 697364,
  [SMALL_STATE(15989)] = 697384,
  [SMALL_STATE(15990)] = 697404,
  [SMALL_STATE(15991)] = 697424,
  [SMALL_STATE(15992)] = 697444,
  [SMALL_STATE(15993)] = 697464,
  [SMALL_STATE(15994)] = 697484,
  [SMALL_STATE(15995)] = 697504,
  [SMALL_STATE(15996)] = 697524,
  [SMALL_STATE(15997)] = 697544,
  [SMALL_STATE(15998)] = 697562,
  [SMALL_STATE(15999)] = 697582,
  [SMALL_STATE(16000)] = 697602,
  [SMALL_STATE(16001)] = 697622,
  [SMALL_STATE(16002)] = 697640,
  [SMALL_STATE(16003)] = 697660,
  [SMALL_STATE(16004)] = 697678,
  [SMALL_STATE(16005)] = 697698,
  [SMALL_STATE(16006)] = 697718,
  [SMALL_STATE(16007)] = 697738,
  [SMALL_STATE(16008)] = 697758,
  [SMALL_STATE(16009)] = 697774,
  [SMALL_STATE(16010)] = 697794,
  [SMALL_STATE(16011)] = 697814,
  [SMALL_STATE(16012)] = 697834,
  [SMALL_STATE(16013)] = 697854,
  [SMALL_STATE(16014)] = 697874,
  [SMALL_STATE(16015)] = 697894,
  [SMALL_STATE(16016)] = 697912,
  [SMALL_STATE(16017)] = 697932,
  [SMALL_STATE(16018)] = 697952,
  [SMALL_STATE(16019)] = 697972,
  [SMALL_STATE(16020)] = 697992,
  [SMALL_STATE(16021)] = 698012,
  [SMALL_STATE(16022)] = 698032,
  [SMALL_STATE(16023)] = 698052,
  [SMALL_STATE(16024)] = 698072,
  [SMALL_STATE(16025)] = 698092,
  [SMALL_STATE(16026)] = 698112,
  [SMALL_STATE(16027)] = 698132,
  [SMALL_STATE(16028)] = 698152,
  [SMALL_STATE(16029)] = 698172,
  [SMALL_STATE(16030)] = 698192,
  [SMALL_STATE(16031)] = 698212,
  [SMALL_STATE(16032)] = 698232,
  [SMALL_STATE(16033)] = 698250,
  [SMALL_STATE(16034)] = 698270,
  [SMALL_STATE(16035)] = 698288,
  [SMALL_STATE(16036)] = 698308,
  [SMALL_STATE(16037)] = 698328,
  [SMALL_STATE(16038)] = 698348,
  [SMALL_STATE(16039)] = 698368,
  [SMALL_STATE(16040)] = 698388,
  [SMALL_STATE(16041)] = 698408,
  [SMALL_STATE(16042)] = 698428,
  [SMALL_STATE(16043)] = 698448,
  [SMALL_STATE(16044)] = 698468,
  [SMALL_STATE(16045)] = 698488,
  [SMALL_STATE(16046)] = 698508,
  [SMALL_STATE(16047)] = 698528,
  [SMALL_STATE(16048)] = 698548,
  [SMALL_STATE(16049)] = 698568,
  [SMALL_STATE(16050)] = 698586,
  [SMALL_STATE(16051)] = 698606,
  [SMALL_STATE(16052)] = 698626,
  [SMALL_STATE(16053)] = 698646,
  [SMALL_STATE(16054)] = 698666,
  [SMALL_STATE(16055)] = 698684,
  [SMALL_STATE(16056)] = 698702,
  [SMALL_STATE(16057)] = 698722,
  [SMALL_STATE(16058)] = 698742,
  [SMALL_STATE(16059)] = 698762,
  [SMALL_STATE(16060)] = 698782,
  [SMALL_STATE(16061)] = 698800,
  [SMALL_STATE(16062)] = 698818,
  [SMALL_STATE(16063)] = 698838,
  [SMALL_STATE(16064)] = 698858,
  [SMALL_STATE(16065)] = 698878,
  [SMALL_STATE(16066)] = 698898,
  [SMALL_STATE(16067)] = 698918,
  [SMALL_STATE(16068)] = 698934,
  [SMALL_STATE(16069)] = 698952,
  [SMALL_STATE(16070)] = 698972,
  [SMALL_STATE(16071)] = 698992,
  [SMALL_STATE(16072)] = 699012,
  [SMALL_STATE(16073)] = 699030,
  [SMALL_STATE(16074)] = 699050,
  [SMALL_STATE(16075)] = 699070,
  [SMALL_STATE(16076)] = 699090,
  [SMALL_STATE(16077)] = 699110,
  [SMALL_STATE(16078)] = 699128,
  [SMALL_STATE(16079)] = 699146,
  [SMALL_STATE(16080)] = 699166,
  [SMALL_STATE(16081)] = 699184,
  [SMALL_STATE(16082)] = 699204,
  [SMALL_STATE(16083)] = 699224,
  [SMALL_STATE(16084)] = 699244,
  [SMALL_STATE(16085)] = 699264,
  [SMALL_STATE(16086)] = 699284,
  [SMALL_STATE(16087)] = 699302,
  [SMALL_STATE(16088)] = 699322,
  [SMALL_STATE(16089)] = 699342,
  [SMALL_STATE(16090)] = 699362,
  [SMALL_STATE(16091)] = 699378,
  [SMALL_STATE(16092)] = 699398,
  [SMALL_STATE(16093)] = 699418,
  [SMALL_STATE(16094)] = 699436,
  [SMALL_STATE(16095)] = 699456,
  [SMALL_STATE(16096)] = 699474,
  [SMALL_STATE(16097)] = 699494,
  [SMALL_STATE(16098)] = 699514,
  [SMALL_STATE(16099)] = 699532,
  [SMALL_STATE(16100)] = 699552,
  [SMALL_STATE(16101)] = 699572,
  [SMALL_STATE(16102)] = 699590,
  [SMALL_STATE(16103)] = 699610,
  [SMALL_STATE(16104)] = 699630,
  [SMALL_STATE(16105)] = 699650,
  [SMALL_STATE(16106)] = 699670,
  [SMALL_STATE(16107)] = 699688,
  [SMALL_STATE(16108)] = 699708,
  [SMALL_STATE(16109)] = 699728,
  [SMALL_STATE(16110)] = 699748,
  [SMALL_STATE(16111)] = 699768,
  [SMALL_STATE(16112)] = 699788,
  [SMALL_STATE(16113)] = 699808,
  [SMALL_STATE(16114)] = 699828,
  [SMALL_STATE(16115)] = 699848,
  [SMALL_STATE(16116)] = 699868,
  [SMALL_STATE(16117)] = 699888,
  [SMALL_STATE(16118)] = 699908,
  [SMALL_STATE(16119)] = 699928,
  [SMALL_STATE(16120)] = 699948,
  [SMALL_STATE(16121)] = 699966,
  [SMALL_STATE(16122)] = 699984,
  [SMALL_STATE(16123)] = 700004,
  [SMALL_STATE(16124)] = 700024,
  [SMALL_STATE(16125)] = 700044,
  [SMALL_STATE(16126)] = 700064,
  [SMALL_STATE(16127)] = 700084,
  [SMALL_STATE(16128)] = 700104,
  [SMALL_STATE(16129)] = 700122,
  [SMALL_STATE(16130)] = 700142,
  [SMALL_STATE(16131)] = 700162,
  [SMALL_STATE(16132)] = 700182,
  [SMALL_STATE(16133)] = 700200,
  [SMALL_STATE(16134)] = 700220,
  [SMALL_STATE(16135)] = 700240,
  [SMALL_STATE(16136)] = 700260,
  [SMALL_STATE(16137)] = 700280,
  [SMALL_STATE(16138)] = 700300,
  [SMALL_STATE(16139)] = 700320,
  [SMALL_STATE(16140)] = 700340,
  [SMALL_STATE(16141)] = 700360,
  [SMALL_STATE(16142)] = 700380,
  [SMALL_STATE(16143)] = 700400,
  [SMALL_STATE(16144)] = 700420,
  [SMALL_STATE(16145)] = 700440,
  [SMALL_STATE(16146)] = 700460,
  [SMALL_STATE(16147)] = 700480,
  [SMALL_STATE(16148)] = 700500,
  [SMALL_STATE(16149)] = 700520,
  [SMALL_STATE(16150)] = 700540,
  [SMALL_STATE(16151)] = 700560,
  [SMALL_STATE(16152)] = 700580,
  [SMALL_STATE(16153)] = 700600,
  [SMALL_STATE(16154)] = 700620,
  [SMALL_STATE(16155)] = 700640,
  [SMALL_STATE(16156)] = 700660,
  [SMALL_STATE(16157)] = 700680,
  [SMALL_STATE(16158)] = 700698,
  [SMALL_STATE(16159)] = 700718,
  [SMALL_STATE(16160)] = 700736,
  [SMALL_STATE(16161)] = 700756,
  [SMALL_STATE(16162)] = 700776,
  [SMALL_STATE(16163)] = 700796,
  [SMALL_STATE(16164)] = 700816,
  [SMALL_STATE(16165)] = 700836,
  [SMALL_STATE(16166)] = 700856,
  [SMALL_STATE(16167)] = 700876,
  [SMALL_STATE(16168)] = 700896,
  [SMALL_STATE(16169)] = 700916,
  [SMALL_STATE(16170)] = 700936,
  [SMALL_STATE(16171)] = 700956,
  [SMALL_STATE(16172)] = 700976,
  [SMALL_STATE(16173)] = 700996,
  [SMALL_STATE(16174)] = 701016,
  [SMALL_STATE(16175)] = 701036,
  [SMALL_STATE(16176)] = 701054,
  [SMALL_STATE(16177)] = 701074,
  [SMALL_STATE(16178)] = 701094,
  [SMALL_STATE(16179)] = 701114,
  [SMALL_STATE(16180)] = 701134,
  [SMALL_STATE(16181)] = 701154,
  [SMALL_STATE(16182)] = 701174,
  [SMALL_STATE(16183)] = 701194,
  [SMALL_STATE(16184)] = 701214,
  [SMALL_STATE(16185)] = 701234,
  [SMALL_STATE(16186)] = 701254,
  [SMALL_STATE(16187)] = 701274,
  [SMALL_STATE(16188)] = 701294,
  [SMALL_STATE(16189)] = 701312,
  [SMALL_STATE(16190)] = 701332,
  [SMALL_STATE(16191)] = 701350,
  [SMALL_STATE(16192)] = 701370,
  [SMALL_STATE(16193)] = 701390,
  [SMALL_STATE(16194)] = 701410,
  [SMALL_STATE(16195)] = 701430,
  [SMALL_STATE(16196)] = 701450,
  [SMALL_STATE(16197)] = 701470,
  [SMALL_STATE(16198)] = 701490,
  [SMALL_STATE(16199)] = 701510,
  [SMALL_STATE(16200)] = 701530,
  [SMALL_STATE(16201)] = 701550,
  [SMALL_STATE(16202)] = 701568,
  [SMALL_STATE(16203)] = 701588,
  [SMALL_STATE(16204)] = 701608,
  [SMALL_STATE(16205)] = 701628,
  [SMALL_STATE(16206)] = 701646,
  [SMALL_STATE(16207)] = 701664,
  [SMALL_STATE(16208)] = 701684,
  [SMALL_STATE(16209)] = 701704,
  [SMALL_STATE(16210)] = 701724,
  [SMALL_STATE(16211)] = 701744,
  [SMALL_STATE(16212)] = 701764,
  [SMALL_STATE(16213)] = 701784,
  [SMALL_STATE(16214)] = 701804,
  [SMALL_STATE(16215)] = 701824,
  [SMALL_STATE(16216)] = 701844,
  [SMALL_STATE(16217)] = 701864,
  [SMALL_STATE(16218)] = 701884,
  [SMALL_STATE(16219)] = 701904,
  [SMALL_STATE(16220)] = 701924,
  [SMALL_STATE(16221)] = 701944,
  [SMALL_STATE(16222)] = 701962,
  [SMALL_STATE(16223)] = 701980,
  [SMALL_STATE(16224)] = 702000,
  [SMALL_STATE(16225)] = 702020,
  [SMALL_STATE(16226)] = 702040,
  [SMALL_STATE(16227)] = 702060,
  [SMALL_STATE(16228)] = 702078,
  [SMALL_STATE(16229)] = 702098,
  [SMALL_STATE(16230)] = 702118,
  [SMALL_STATE(16231)] = 702138,
  [SMALL_STATE(16232)] = 702158,
  [SMALL_STATE(16233)] = 702176,
  [SMALL_STATE(16234)] = 702196,
  [SMALL_STATE(16235)] = 702216,
  [SMALL_STATE(16236)] = 702236,
  [SMALL_STATE(16237)] = 702256,
  [SMALL_STATE(16238)] = 702274,
  [SMALL_STATE(16239)] = 702294,
  [SMALL_STATE(16240)] = 702312,
  [SMALL_STATE(16241)] = 702332,
  [SMALL_STATE(16242)] = 702352,
  [SMALL_STATE(16243)] = 702372,
  [SMALL_STATE(16244)] = 702392,
  [SMALL_STATE(16245)] = 702412,
  [SMALL_STATE(16246)] = 702430,
  [SMALL_STATE(16247)] = 702450,
  [SMALL_STATE(16248)] = 702470,
  [SMALL_STATE(16249)] = 702490,
  [SMALL_STATE(16250)] = 702510,
  [SMALL_STATE(16251)] = 702530,
  [SMALL_STATE(16252)] = 702550,
  [SMALL_STATE(16253)] = 702570,
  [SMALL_STATE(16254)] = 702590,
  [SMALL_STATE(16255)] = 702610,
  [SMALL_STATE(16256)] = 702630,
  [SMALL_STATE(16257)] = 702650,
  [SMALL_STATE(16258)] = 702670,
  [SMALL_STATE(16259)] = 702690,
  [SMALL_STATE(16260)] = 702710,
  [SMALL_STATE(16261)] = 702730,
  [SMALL_STATE(16262)] = 702750,
  [SMALL_STATE(16263)] = 702770,
  [SMALL_STATE(16264)] = 702788,
  [SMALL_STATE(16265)] = 702808,
  [SMALL_STATE(16266)] = 702828,
  [SMALL_STATE(16267)] = 702848,
  [SMALL_STATE(16268)] = 702868,
  [SMALL_STATE(16269)] = 702888,
  [SMALL_STATE(16270)] = 702906,
  [SMALL_STATE(16271)] = 702924,
  [SMALL_STATE(16272)] = 702942,
  [SMALL_STATE(16273)] = 702962,
  [SMALL_STATE(16274)] = 702982,
  [SMALL_STATE(16275)] = 703002,
  [SMALL_STATE(16276)] = 703022,
  [SMALL_STATE(16277)] = 703042,
  [SMALL_STATE(16278)] = 703062,
  [SMALL_STATE(16279)] = 703080,
  [SMALL_STATE(16280)] = 703100,
  [SMALL_STATE(16281)] = 703120,
  [SMALL_STATE(16282)] = 703140,
  [SMALL_STATE(16283)] = 703160,
  [SMALL_STATE(16284)] = 703180,
  [SMALL_STATE(16285)] = 703200,
  [SMALL_STATE(16286)] = 703220,
  [SMALL_STATE(16287)] = 703240,
  [SMALL_STATE(16288)] = 703260,
  [SMALL_STATE(16289)] = 703280,
  [SMALL_STATE(16290)] = 703298,
  [SMALL_STATE(16291)] = 703318,
  [SMALL_STATE(16292)] = 703338,
  [SMALL_STATE(16293)] = 703358,
  [SMALL_STATE(16294)] = 703378,
  [SMALL_STATE(16295)] = 703398,
  [SMALL_STATE(16296)] = 703418,
  [SMALL_STATE(16297)] = 703438,
  [SMALL_STATE(16298)] = 703458,
  [SMALL_STATE(16299)] = 703478,
  [SMALL_STATE(16300)] = 703496,
  [SMALL_STATE(16301)] = 703516,
  [SMALL_STATE(16302)] = 703536,
  [SMALL_STATE(16303)] = 703556,
  [SMALL_STATE(16304)] = 703576,
  [SMALL_STATE(16305)] = 703594,
  [SMALL_STATE(16306)] = 703612,
  [SMALL_STATE(16307)] = 703632,
  [SMALL_STATE(16308)] = 703652,
  [SMALL_STATE(16309)] = 703672,
  [SMALL_STATE(16310)] = 703692,
  [SMALL_STATE(16311)] = 703712,
  [SMALL_STATE(16312)] = 703732,
  [SMALL_STATE(16313)] = 703752,
  [SMALL_STATE(16314)] = 703770,
  [SMALL_STATE(16315)] = 703790,
  [SMALL_STATE(16316)] = 703810,
  [SMALL_STATE(16317)] = 703830,
  [SMALL_STATE(16318)] = 703850,
  [SMALL_STATE(16319)] = 703870,
  [SMALL_STATE(16320)] = 703890,
  [SMALL_STATE(16321)] = 703910,
  [SMALL_STATE(16322)] = 703930,
  [SMALL_STATE(16323)] = 703948,
  [SMALL_STATE(16324)] = 703968,
  [SMALL_STATE(16325)] = 703986,
  [SMALL_STATE(16326)] = 704006,
  [SMALL_STATE(16327)] = 704026,
  [SMALL_STATE(16328)] = 704046,
  [SMALL_STATE(16329)] = 704066,
  [SMALL_STATE(16330)] = 704086,
  [SMALL_STATE(16331)] = 704106,
  [SMALL_STATE(16332)] = 704126,
  [SMALL_STATE(16333)] = 704146,
  [SMALL_STATE(16334)] = 704166,
  [SMALL_STATE(16335)] = 704186,
  [SMALL_STATE(16336)] = 704206,
  [SMALL_STATE(16337)] = 704226,
  [SMALL_STATE(16338)] = 704246,
  [SMALL_STATE(16339)] = 704266,
  [SMALL_STATE(16340)] = 704286,
  [SMALL_STATE(16341)] = 704306,
  [SMALL_STATE(16342)] = 704326,
  [SMALL_STATE(16343)] = 704346,
  [SMALL_STATE(16344)] = 704366,
  [SMALL_STATE(16345)] = 704386,
  [SMALL_STATE(16346)] = 704406,
  [SMALL_STATE(16347)] = 704426,
  [SMALL_STATE(16348)] = 704446,
  [SMALL_STATE(16349)] = 704466,
  [SMALL_STATE(16350)] = 704486,
  [SMALL_STATE(16351)] = 704506,
  [SMALL_STATE(16352)] = 704526,
  [SMALL_STATE(16353)] = 704546,
  [SMALL_STATE(16354)] = 704566,
  [SMALL_STATE(16355)] = 704586,
  [SMALL_STATE(16356)] = 704606,
  [SMALL_STATE(16357)] = 704626,
  [SMALL_STATE(16358)] = 704644,
  [SMALL_STATE(16359)] = 704664,
  [SMALL_STATE(16360)] = 704682,
  [SMALL_STATE(16361)] = 704702,
  [SMALL_STATE(16362)] = 704722,
  [SMALL_STATE(16363)] = 704742,
  [SMALL_STATE(16364)] = 704760,
  [SMALL_STATE(16365)] = 704780,
  [SMALL_STATE(16366)] = 704796,
  [SMALL_STATE(16367)] = 704816,
  [SMALL_STATE(16368)] = 704836,
  [SMALL_STATE(16369)] = 704856,
  [SMALL_STATE(16370)] = 704876,
  [SMALL_STATE(16371)] = 704896,
  [SMALL_STATE(16372)] = 704916,
  [SMALL_STATE(16373)] = 704936,
  [SMALL_STATE(16374)] = 704956,
  [SMALL_STATE(16375)] = 704976,
  [SMALL_STATE(16376)] = 704996,
  [SMALL_STATE(16377)] = 705016,
  [SMALL_STATE(16378)] = 705036,
  [SMALL_STATE(16379)] = 705056,
  [SMALL_STATE(16380)] = 705076,
  [SMALL_STATE(16381)] = 705096,
  [SMALL_STATE(16382)] = 705116,
  [SMALL_STATE(16383)] = 705136,
  [SMALL_STATE(16384)] = 705156,
  [SMALL_STATE(16385)] = 705176,
  [SMALL_STATE(16386)] = 705196,
  [SMALL_STATE(16387)] = 705214,
  [SMALL_STATE(16388)] = 705234,
  [SMALL_STATE(16389)] = 705252,
  [SMALL_STATE(16390)] = 705272,
  [SMALL_STATE(16391)] = 705292,
  [SMALL_STATE(16392)] = 705312,
  [SMALL_STATE(16393)] = 705332,
  [SMALL_STATE(16394)] = 705350,
  [SMALL_STATE(16395)] = 705368,
  [SMALL_STATE(16396)] = 705388,
  [SMALL_STATE(16397)] = 705408,
  [SMALL_STATE(16398)] = 705428,
  [SMALL_STATE(16399)] = 705448,
  [SMALL_STATE(16400)] = 705468,
  [SMALL_STATE(16401)] = 705488,
  [SMALL_STATE(16402)] = 705508,
  [SMALL_STATE(16403)] = 705526,
  [SMALL_STATE(16404)] = 705546,
  [SMALL_STATE(16405)] = 705566,
  [SMALL_STATE(16406)] = 705586,
  [SMALL_STATE(16407)] = 705606,
  [SMALL_STATE(16408)] = 705626,
  [SMALL_STATE(16409)] = 705646,
  [SMALL_STATE(16410)] = 705666,
  [SMALL_STATE(16411)] = 705686,
  [SMALL_STATE(16412)] = 705706,
  [SMALL_STATE(16413)] = 705726,
  [SMALL_STATE(16414)] = 705746,
  [SMALL_STATE(16415)] = 705766,
  [SMALL_STATE(16416)] = 705786,
  [SMALL_STATE(16417)] = 705806,
  [SMALL_STATE(16418)] = 705826,
  [SMALL_STATE(16419)] = 705846,
  [SMALL_STATE(16420)] = 705864,
  [SMALL_STATE(16421)] = 705884,
  [SMALL_STATE(16422)] = 705904,
  [SMALL_STATE(16423)] = 705924,
  [SMALL_STATE(16424)] = 705944,
  [SMALL_STATE(16425)] = 705964,
  [SMALL_STATE(16426)] = 705984,
  [SMALL_STATE(16427)] = 706004,
  [SMALL_STATE(16428)] = 706024,
  [SMALL_STATE(16429)] = 706044,
  [SMALL_STATE(16430)] = 706064,
  [SMALL_STATE(16431)] = 706084,
  [SMALL_STATE(16432)] = 706104,
  [SMALL_STATE(16433)] = 706122,
  [SMALL_STATE(16434)] = 706142,
  [SMALL_STATE(16435)] = 706162,
  [SMALL_STATE(16436)] = 706182,
  [SMALL_STATE(16437)] = 706202,
  [SMALL_STATE(16438)] = 706222,
  [SMALL_STATE(16439)] = 706242,
  [SMALL_STATE(16440)] = 706262,
  [SMALL_STATE(16441)] = 706282,
  [SMALL_STATE(16442)] = 706302,
  [SMALL_STATE(16443)] = 706322,
  [SMALL_STATE(16444)] = 706342,
  [SMALL_STATE(16445)] = 706362,
  [SMALL_STATE(16446)] = 706382,
  [SMALL_STATE(16447)] = 706400,
  [SMALL_STATE(16448)] = 706418,
  [SMALL_STATE(16449)] = 706438,
  [SMALL_STATE(16450)] = 706458,
  [SMALL_STATE(16451)] = 706478,
  [SMALL_STATE(16452)] = 706498,
  [SMALL_STATE(16453)] = 706518,
  [SMALL_STATE(16454)] = 706538,
  [SMALL_STATE(16455)] = 706558,
  [SMALL_STATE(16456)] = 706578,
  [SMALL_STATE(16457)] = 706598,
  [SMALL_STATE(16458)] = 706618,
  [SMALL_STATE(16459)] = 706638,
  [SMALL_STATE(16460)] = 706656,
  [SMALL_STATE(16461)] = 706676,
  [SMALL_STATE(16462)] = 706696,
  [SMALL_STATE(16463)] = 706716,
  [SMALL_STATE(16464)] = 706736,
  [SMALL_STATE(16465)] = 706756,
  [SMALL_STATE(16466)] = 706776,
  [SMALL_STATE(16467)] = 706794,
  [SMALL_STATE(16468)] = 706814,
  [SMALL_STATE(16469)] = 706834,
  [SMALL_STATE(16470)] = 706854,
  [SMALL_STATE(16471)] = 706874,
  [SMALL_STATE(16472)] = 706894,
  [SMALL_STATE(16473)] = 706914,
  [SMALL_STATE(16474)] = 706934,
  [SMALL_STATE(16475)] = 706954,
  [SMALL_STATE(16476)] = 706974,
  [SMALL_STATE(16477)] = 706994,
  [SMALL_STATE(16478)] = 707014,
  [SMALL_STATE(16479)] = 707034,
  [SMALL_STATE(16480)] = 707054,
  [SMALL_STATE(16481)] = 707074,
  [SMALL_STATE(16482)] = 707094,
  [SMALL_STATE(16483)] = 707112,
  [SMALL_STATE(16484)] = 707132,
  [SMALL_STATE(16485)] = 707152,
  [SMALL_STATE(16486)] = 707170,
  [SMALL_STATE(16487)] = 707190,
  [SMALL_STATE(16488)] = 707210,
  [SMALL_STATE(16489)] = 707230,
  [SMALL_STATE(16490)] = 707250,
  [SMALL_STATE(16491)] = 707268,
  [SMALL_STATE(16492)] = 707288,
  [SMALL_STATE(16493)] = 707308,
  [SMALL_STATE(16494)] = 707328,
  [SMALL_STATE(16495)] = 707346,
  [SMALL_STATE(16496)] = 707364,
  [SMALL_STATE(16497)] = 707382,
  [SMALL_STATE(16498)] = 707400,
  [SMALL_STATE(16499)] = 707418,
  [SMALL_STATE(16500)] = 707438,
  [SMALL_STATE(16501)] = 707458,
  [SMALL_STATE(16502)] = 707478,
  [SMALL_STATE(16503)] = 707498,
  [SMALL_STATE(16504)] = 707518,
  [SMALL_STATE(16505)] = 707538,
  [SMALL_STATE(16506)] = 707558,
  [SMALL_STATE(16507)] = 707575,
  [SMALL_STATE(16508)] = 707592,
  [SMALL_STATE(16509)] = 707609,
  [SMALL_STATE(16510)] = 707624,
  [SMALL_STATE(16511)] = 707639,
  [SMALL_STATE(16512)] = 707656,
  [SMALL_STATE(16513)] = 707673,
  [SMALL_STATE(16514)] = 707690,
  [SMALL_STATE(16515)] = 707707,
  [SMALL_STATE(16516)] = 707722,
  [SMALL_STATE(16517)] = 707739,
  [SMALL_STATE(16518)] = 707754,
  [SMALL_STATE(16519)] = 707771,
  [SMALL_STATE(16520)] = 707788,
  [SMALL_STATE(16521)] = 707805,
  [SMALL_STATE(16522)] = 707820,
  [SMALL_STATE(16523)] = 707837,
  [SMALL_STATE(16524)] = 707854,
  [SMALL_STATE(16525)] = 707871,
  [SMALL_STATE(16526)] = 707886,
  [SMALL_STATE(16527)] = 707901,
  [SMALL_STATE(16528)] = 707916,
  [SMALL_STATE(16529)] = 707933,
  [SMALL_STATE(16530)] = 707948,
  [SMALL_STATE(16531)] = 707963,
  [SMALL_STATE(16532)] = 707978,
  [SMALL_STATE(16533)] = 707995,
  [SMALL_STATE(16534)] = 708012,
  [SMALL_STATE(16535)] = 708027,
  [SMALL_STATE(16536)] = 708044,
  [SMALL_STATE(16537)] = 708061,
  [SMALL_STATE(16538)] = 708078,
  [SMALL_STATE(16539)] = 708095,
  [SMALL_STATE(16540)] = 708110,
  [SMALL_STATE(16541)] = 708127,
  [SMALL_STATE(16542)] = 708144,
  [SMALL_STATE(16543)] = 708159,
  [SMALL_STATE(16544)] = 708176,
  [SMALL_STATE(16545)] = 708193,
  [SMALL_STATE(16546)] = 708210,
  [SMALL_STATE(16547)] = 708227,
  [SMALL_STATE(16548)] = 708244,
  [SMALL_STATE(16549)] = 708261,
  [SMALL_STATE(16550)] = 708278,
  [SMALL_STATE(16551)] = 708295,
  [SMALL_STATE(16552)] = 708312,
  [SMALL_STATE(16553)] = 708329,
  [SMALL_STATE(16554)] = 708346,
  [SMALL_STATE(16555)] = 708363,
  [SMALL_STATE(16556)] = 708380,
  [SMALL_STATE(16557)] = 708397,
  [SMALL_STATE(16558)] = 708414,
  [SMALL_STATE(16559)] = 708431,
  [SMALL_STATE(16560)] = 708448,
  [SMALL_STATE(16561)] = 708465,
  [SMALL_STATE(16562)] = 708482,
  [SMALL_STATE(16563)] = 708499,
  [SMALL_STATE(16564)] = 708514,
  [SMALL_STATE(16565)] = 708531,
  [SMALL_STATE(16566)] = 708548,
  [SMALL_STATE(16567)] = 708565,
  [SMALL_STATE(16568)] = 708582,
  [SMALL_STATE(16569)] = 708599,
  [SMALL_STATE(16570)] = 708616,
  [SMALL_STATE(16571)] = 708633,
  [SMALL_STATE(16572)] = 708650,
  [SMALL_STATE(16573)] = 708667,
  [SMALL_STATE(16574)] = 708684,
  [SMALL_STATE(16575)] = 708701,
  [SMALL_STATE(16576)] = 708718,
  [SMALL_STATE(16577)] = 708735,
  [SMALL_STATE(16578)] = 708752,
  [SMALL_STATE(16579)] = 708769,
  [SMALL_STATE(16580)] = 708786,
  [SMALL_STATE(16581)] = 708803,
  [SMALL_STATE(16582)] = 708820,
  [SMALL_STATE(16583)] = 708837,
  [SMALL_STATE(16584)] = 708854,
  [SMALL_STATE(16585)] = 708871,
  [SMALL_STATE(16586)] = 708888,
  [SMALL_STATE(16587)] = 708905,
  [SMALL_STATE(16588)] = 708922,
  [SMALL_STATE(16589)] = 708939,
  [SMALL_STATE(16590)] = 708956,
  [SMALL_STATE(16591)] = 708973,
  [SMALL_STATE(16592)] = 708988,
  [SMALL_STATE(16593)] = 709003,
  [SMALL_STATE(16594)] = 709020,
  [SMALL_STATE(16595)] = 709037,
  [SMALL_STATE(16596)] = 709054,
  [SMALL_STATE(16597)] = 709071,
  [SMALL_STATE(16598)] = 709086,
  [SMALL_STATE(16599)] = 709103,
  [SMALL_STATE(16600)] = 709120,
  [SMALL_STATE(16601)] = 709137,
  [SMALL_STATE(16602)] = 709152,
  [SMALL_STATE(16603)] = 709167,
  [SMALL_STATE(16604)] = 709184,
  [SMALL_STATE(16605)] = 709201,
  [SMALL_STATE(16606)] = 709216,
  [SMALL_STATE(16607)] = 709233,
  [SMALL_STATE(16608)] = 709250,
  [SMALL_STATE(16609)] = 709265,
  [SMALL_STATE(16610)] = 709280,
  [SMALL_STATE(16611)] = 709297,
  [SMALL_STATE(16612)] = 709314,
  [SMALL_STATE(16613)] = 709331,
  [SMALL_STATE(16614)] = 709346,
  [SMALL_STATE(16615)] = 709361,
  [SMALL_STATE(16616)] = 709378,
  [SMALL_STATE(16617)] = 709395,
  [SMALL_STATE(16618)] = 709412,
  [SMALL_STATE(16619)] = 709429,
  [SMALL_STATE(16620)] = 709446,
  [SMALL_STATE(16621)] = 709463,
  [SMALL_STATE(16622)] = 709480,
  [SMALL_STATE(16623)] = 709497,
  [SMALL_STATE(16624)] = 709512,
  [SMALL_STATE(16625)] = 709529,
  [SMALL_STATE(16626)] = 709546,
  [SMALL_STATE(16627)] = 709561,
  [SMALL_STATE(16628)] = 709576,
  [SMALL_STATE(16629)] = 709593,
  [SMALL_STATE(16630)] = 709608,
  [SMALL_STATE(16631)] = 709625,
  [SMALL_STATE(16632)] = 709640,
  [SMALL_STATE(16633)] = 709657,
  [SMALL_STATE(16634)] = 709672,
  [SMALL_STATE(16635)] = 709687,
  [SMALL_STATE(16636)] = 709702,
  [SMALL_STATE(16637)] = 709719,
  [SMALL_STATE(16638)] = 709736,
  [SMALL_STATE(16639)] = 709753,
  [SMALL_STATE(16640)] = 709770,
  [SMALL_STATE(16641)] = 709787,
  [SMALL_STATE(16642)] = 709804,
  [SMALL_STATE(16643)] = 709821,
  [SMALL_STATE(16644)] = 709838,
  [SMALL_STATE(16645)] = 709855,
  [SMALL_STATE(16646)] = 709872,
  [SMALL_STATE(16647)] = 709887,
  [SMALL_STATE(16648)] = 709902,
  [SMALL_STATE(16649)] = 709917,
  [SMALL_STATE(16650)] = 709934,
  [SMALL_STATE(16651)] = 709949,
  [SMALL_STATE(16652)] = 709964,
  [SMALL_STATE(16653)] = 709981,
  [SMALL_STATE(16654)] = 709996,
  [SMALL_STATE(16655)] = 710011,
  [SMALL_STATE(16656)] = 710028,
  [SMALL_STATE(16657)] = 710043,
  [SMALL_STATE(16658)] = 710060,
  [SMALL_STATE(16659)] = 710077,
  [SMALL_STATE(16660)] = 710092,
  [SMALL_STATE(16661)] = 710107,
  [SMALL_STATE(16662)] = 710122,
  [SMALL_STATE(16663)] = 710139,
  [SMALL_STATE(16664)] = 710154,
  [SMALL_STATE(16665)] = 710171,
  [SMALL_STATE(16666)] = 710188,
  [SMALL_STATE(16667)] = 710205,
  [SMALL_STATE(16668)] = 710222,
  [SMALL_STATE(16669)] = 710239,
  [SMALL_STATE(16670)] = 710256,
  [SMALL_STATE(16671)] = 710273,
  [SMALL_STATE(16672)] = 710290,
  [SMALL_STATE(16673)] = 710307,
  [SMALL_STATE(16674)] = 710324,
  [SMALL_STATE(16675)] = 710341,
  [SMALL_STATE(16676)] = 710358,
  [SMALL_STATE(16677)] = 710375,
  [SMALL_STATE(16678)] = 710392,
  [SMALL_STATE(16679)] = 710409,
  [SMALL_STATE(16680)] = 710424,
  [SMALL_STATE(16681)] = 710441,
  [SMALL_STATE(16682)] = 710458,
  [SMALL_STATE(16683)] = 710475,
  [SMALL_STATE(16684)] = 710492,
  [SMALL_STATE(16685)] = 710507,
  [SMALL_STATE(16686)] = 710524,
  [SMALL_STATE(16687)] = 710541,
  [SMALL_STATE(16688)] = 710558,
  [SMALL_STATE(16689)] = 710575,
  [SMALL_STATE(16690)] = 710592,
  [SMALL_STATE(16691)] = 710609,
  [SMALL_STATE(16692)] = 710626,
  [SMALL_STATE(16693)] = 710641,
  [SMALL_STATE(16694)] = 710658,
  [SMALL_STATE(16695)] = 710675,
  [SMALL_STATE(16696)] = 710692,
  [SMALL_STATE(16697)] = 710709,
  [SMALL_STATE(16698)] = 710726,
  [SMALL_STATE(16699)] = 710743,
  [SMALL_STATE(16700)] = 710760,
  [SMALL_STATE(16701)] = 710775,
  [SMALL_STATE(16702)] = 710790,
  [SMALL_STATE(16703)] = 710805,
  [SMALL_STATE(16704)] = 710822,
  [SMALL_STATE(16705)] = 710839,
  [SMALL_STATE(16706)] = 710854,
  [SMALL_STATE(16707)] = 710871,
  [SMALL_STATE(16708)] = 710888,
  [SMALL_STATE(16709)] = 710905,
  [SMALL_STATE(16710)] = 710922,
  [SMALL_STATE(16711)] = 710939,
  [SMALL_STATE(16712)] = 710956,
  [SMALL_STATE(16713)] = 710973,
  [SMALL_STATE(16714)] = 710990,
  [SMALL_STATE(16715)] = 711007,
  [SMALL_STATE(16716)] = 711024,
  [SMALL_STATE(16717)] = 711041,
  [SMALL_STATE(16718)] = 711058,
  [SMALL_STATE(16719)] = 711073,
  [SMALL_STATE(16720)] = 711090,
  [SMALL_STATE(16721)] = 711107,
  [SMALL_STATE(16722)] = 711124,
  [SMALL_STATE(16723)] = 711141,
  [SMALL_STATE(16724)] = 711158,
  [SMALL_STATE(16725)] = 711175,
  [SMALL_STATE(16726)] = 711192,
  [SMALL_STATE(16727)] = 711209,
  [SMALL_STATE(16728)] = 711226,
  [SMALL_STATE(16729)] = 711243,
  [SMALL_STATE(16730)] = 711260,
  [SMALL_STATE(16731)] = 711277,
  [SMALL_STATE(16732)] = 711294,
  [SMALL_STATE(16733)] = 711309,
  [SMALL_STATE(16734)] = 711326,
  [SMALL_STATE(16735)] = 711343,
  [SMALL_STATE(16736)] = 711360,
  [SMALL_STATE(16737)] = 711377,
  [SMALL_STATE(16738)] = 711394,
  [SMALL_STATE(16739)] = 711411,
  [SMALL_STATE(16740)] = 711426,
  [SMALL_STATE(16741)] = 711443,
  [SMALL_STATE(16742)] = 711458,
  [SMALL_STATE(16743)] = 711473,
  [SMALL_STATE(16744)] = 711490,
  [SMALL_STATE(16745)] = 711507,
  [SMALL_STATE(16746)] = 711524,
  [SMALL_STATE(16747)] = 711541,
  [SMALL_STATE(16748)] = 711558,
  [SMALL_STATE(16749)] = 711573,
  [SMALL_STATE(16750)] = 711590,
  [SMALL_STATE(16751)] = 711607,
  [SMALL_STATE(16752)] = 711624,
  [SMALL_STATE(16753)] = 711641,
  [SMALL_STATE(16754)] = 711658,
  [SMALL_STATE(16755)] = 711675,
  [SMALL_STATE(16756)] = 711692,
  [SMALL_STATE(16757)] = 711709,
  [SMALL_STATE(16758)] = 711726,
  [SMALL_STATE(16759)] = 711743,
  [SMALL_STATE(16760)] = 711760,
  [SMALL_STATE(16761)] = 711777,
  [SMALL_STATE(16762)] = 711794,
  [SMALL_STATE(16763)] = 711811,
  [SMALL_STATE(16764)] = 711828,
  [SMALL_STATE(16765)] = 711845,
  [SMALL_STATE(16766)] = 711862,
  [SMALL_STATE(16767)] = 711877,
  [SMALL_STATE(16768)] = 711894,
  [SMALL_STATE(16769)] = 711911,
  [SMALL_STATE(16770)] = 711928,
  [SMALL_STATE(16771)] = 711945,
  [SMALL_STATE(16772)] = 711962,
  [SMALL_STATE(16773)] = 711979,
  [SMALL_STATE(16774)] = 711996,
  [SMALL_STATE(16775)] = 712013,
  [SMALL_STATE(16776)] = 712030,
  [SMALL_STATE(16777)] = 712047,
  [SMALL_STATE(16778)] = 712064,
  [SMALL_STATE(16779)] = 712081,
  [SMALL_STATE(16780)] = 712098,
  [SMALL_STATE(16781)] = 712115,
  [SMALL_STATE(16782)] = 712132,
  [SMALL_STATE(16783)] = 712147,
  [SMALL_STATE(16784)] = 712162,
  [SMALL_STATE(16785)] = 712177,
  [SMALL_STATE(16786)] = 712194,
  [SMALL_STATE(16787)] = 712211,
  [SMALL_STATE(16788)] = 712228,
  [SMALL_STATE(16789)] = 712245,
  [SMALL_STATE(16790)] = 712262,
  [SMALL_STATE(16791)] = 712279,
  [SMALL_STATE(16792)] = 712296,
  [SMALL_STATE(16793)] = 712313,
  [SMALL_STATE(16794)] = 712330,
  [SMALL_STATE(16795)] = 712347,
  [SMALL_STATE(16796)] = 712362,
  [SMALL_STATE(16797)] = 712379,
  [SMALL_STATE(16798)] = 712396,
  [SMALL_STATE(16799)] = 712413,
  [SMALL_STATE(16800)] = 712430,
  [SMALL_STATE(16801)] = 712447,
  [SMALL_STATE(16802)] = 712464,
  [SMALL_STATE(16803)] = 712481,
  [SMALL_STATE(16804)] = 712498,
  [SMALL_STATE(16805)] = 712513,
  [SMALL_STATE(16806)] = 712530,
  [SMALL_STATE(16807)] = 712547,
  [SMALL_STATE(16808)] = 712564,
  [SMALL_STATE(16809)] = 712579,
  [SMALL_STATE(16810)] = 712596,
  [SMALL_STATE(16811)] = 712613,
  [SMALL_STATE(16812)] = 712630,
  [SMALL_STATE(16813)] = 712647,
  [SMALL_STATE(16814)] = 712664,
  [SMALL_STATE(16815)] = 712681,
  [SMALL_STATE(16816)] = 712698,
  [SMALL_STATE(16817)] = 712715,
  [SMALL_STATE(16818)] = 712732,
  [SMALL_STATE(16819)] = 712749,
  [SMALL_STATE(16820)] = 712766,
  [SMALL_STATE(16821)] = 712783,
  [SMALL_STATE(16822)] = 712800,
  [SMALL_STATE(16823)] = 712815,
  [SMALL_STATE(16824)] = 712830,
  [SMALL_STATE(16825)] = 712847,
  [SMALL_STATE(16826)] = 712862,
  [SMALL_STATE(16827)] = 712879,
  [SMALL_STATE(16828)] = 712896,
  [SMALL_STATE(16829)] = 712913,
  [SMALL_STATE(16830)] = 712930,
  [SMALL_STATE(16831)] = 712947,
  [SMALL_STATE(16832)] = 712964,
  [SMALL_STATE(16833)] = 712981,
  [SMALL_STATE(16834)] = 712998,
  [SMALL_STATE(16835)] = 713015,
  [SMALL_STATE(16836)] = 713032,
  [SMALL_STATE(16837)] = 713049,
  [SMALL_STATE(16838)] = 713064,
  [SMALL_STATE(16839)] = 713081,
  [SMALL_STATE(16840)] = 713096,
  [SMALL_STATE(16841)] = 713113,
  [SMALL_STATE(16842)] = 713130,
  [SMALL_STATE(16843)] = 713147,
  [SMALL_STATE(16844)] = 713164,
  [SMALL_STATE(16845)] = 713181,
  [SMALL_STATE(16846)] = 713198,
  [SMALL_STATE(16847)] = 713215,
  [SMALL_STATE(16848)] = 713232,
  [SMALL_STATE(16849)] = 713249,
  [SMALL_STATE(16850)] = 713266,
  [SMALL_STATE(16851)] = 713283,
  [SMALL_STATE(16852)] = 713300,
  [SMALL_STATE(16853)] = 713315,
  [SMALL_STATE(16854)] = 713330,
  [SMALL_STATE(16855)] = 713347,
  [SMALL_STATE(16856)] = 713362,
  [SMALL_STATE(16857)] = 713379,
  [SMALL_STATE(16858)] = 713396,
  [SMALL_STATE(16859)] = 713411,
  [SMALL_STATE(16860)] = 713428,
  [SMALL_STATE(16861)] = 713445,
  [SMALL_STATE(16862)] = 713462,
  [SMALL_STATE(16863)] = 713479,
  [SMALL_STATE(16864)] = 713494,
  [SMALL_STATE(16865)] = 713511,
  [SMALL_STATE(16866)] = 713526,
  [SMALL_STATE(16867)] = 713543,
  [SMALL_STATE(16868)] = 713560,
  [SMALL_STATE(16869)] = 713577,
  [SMALL_STATE(16870)] = 713594,
  [SMALL_STATE(16871)] = 713611,
  [SMALL_STATE(16872)] = 713628,
  [SMALL_STATE(16873)] = 713643,
  [SMALL_STATE(16874)] = 713660,
  [SMALL_STATE(16875)] = 713677,
  [SMALL_STATE(16876)] = 713694,
  [SMALL_STATE(16877)] = 713711,
  [SMALL_STATE(16878)] = 713728,
  [SMALL_STATE(16879)] = 713745,
  [SMALL_STATE(16880)] = 713760,
  [SMALL_STATE(16881)] = 713777,
  [SMALL_STATE(16882)] = 713794,
  [SMALL_STATE(16883)] = 713809,
  [SMALL_STATE(16884)] = 713826,
  [SMALL_STATE(16885)] = 713841,
  [SMALL_STATE(16886)] = 713858,
  [SMALL_STATE(16887)] = 713875,
  [SMALL_STATE(16888)] = 713892,
  [SMALL_STATE(16889)] = 713909,
  [SMALL_STATE(16890)] = 713926,
  [SMALL_STATE(16891)] = 713943,
  [SMALL_STATE(16892)] = 713958,
  [SMALL_STATE(16893)] = 713975,
  [SMALL_STATE(16894)] = 713990,
  [SMALL_STATE(16895)] = 714007,
  [SMALL_STATE(16896)] = 714024,
  [SMALL_STATE(16897)] = 714041,
  [SMALL_STATE(16898)] = 714058,
  [SMALL_STATE(16899)] = 714073,
  [SMALL_STATE(16900)] = 714088,
  [SMALL_STATE(16901)] = 714105,
  [SMALL_STATE(16902)] = 714122,
  [SMALL_STATE(16903)] = 714139,
  [SMALL_STATE(16904)] = 714156,
  [SMALL_STATE(16905)] = 714173,
  [SMALL_STATE(16906)] = 714190,
  [SMALL_STATE(16907)] = 714207,
  [SMALL_STATE(16908)] = 714224,
  [SMALL_STATE(16909)] = 714241,
  [SMALL_STATE(16910)] = 714256,
  [SMALL_STATE(16911)] = 714271,
  [SMALL_STATE(16912)] = 714288,
  [SMALL_STATE(16913)] = 714305,
  [SMALL_STATE(16914)] = 714322,
  [SMALL_STATE(16915)] = 714339,
  [SMALL_STATE(16916)] = 714356,
  [SMALL_STATE(16917)] = 714373,
  [SMALL_STATE(16918)] = 714390,
  [SMALL_STATE(16919)] = 714407,
  [SMALL_STATE(16920)] = 714424,
  [SMALL_STATE(16921)] = 714441,
  [SMALL_STATE(16922)] = 714458,
  [SMALL_STATE(16923)] = 714473,
  [SMALL_STATE(16924)] = 714490,
  [SMALL_STATE(16925)] = 714505,
  [SMALL_STATE(16926)] = 714522,
  [SMALL_STATE(16927)] = 714539,
  [SMALL_STATE(16928)] = 714554,
  [SMALL_STATE(16929)] = 714571,
  [SMALL_STATE(16930)] = 714588,
  [SMALL_STATE(16931)] = 714603,
  [SMALL_STATE(16932)] = 714618,
  [SMALL_STATE(16933)] = 714635,
  [SMALL_STATE(16934)] = 714652,
  [SMALL_STATE(16935)] = 714669,
  [SMALL_STATE(16936)] = 714686,
  [SMALL_STATE(16937)] = 714703,
  [SMALL_STATE(16938)] = 714720,
  [SMALL_STATE(16939)] = 714737,
  [SMALL_STATE(16940)] = 714754,
  [SMALL_STATE(16941)] = 714771,
  [SMALL_STATE(16942)] = 714788,
  [SMALL_STATE(16943)] = 714805,
  [SMALL_STATE(16944)] = 714822,
  [SMALL_STATE(16945)] = 714839,
  [SMALL_STATE(16946)] = 714856,
  [SMALL_STATE(16947)] = 714871,
  [SMALL_STATE(16948)] = 714888,
  [SMALL_STATE(16949)] = 714905,
  [SMALL_STATE(16950)] = 714922,
  [SMALL_STATE(16951)] = 714939,
  [SMALL_STATE(16952)] = 714956,
  [SMALL_STATE(16953)] = 714973,
  [SMALL_STATE(16954)] = 714990,
  [SMALL_STATE(16955)] = 715007,
  [SMALL_STATE(16956)] = 715024,
  [SMALL_STATE(16957)] = 715039,
  [SMALL_STATE(16958)] = 715054,
  [SMALL_STATE(16959)] = 715071,
  [SMALL_STATE(16960)] = 715088,
  [SMALL_STATE(16961)] = 715105,
  [SMALL_STATE(16962)] = 715122,
  [SMALL_STATE(16963)] = 715139,
  [SMALL_STATE(16964)] = 715156,
  [SMALL_STATE(16965)] = 715173,
  [SMALL_STATE(16966)] = 715190,
  [SMALL_STATE(16967)] = 715205,
  [SMALL_STATE(16968)] = 715222,
  [SMALL_STATE(16969)] = 715239,
  [SMALL_STATE(16970)] = 715256,
  [SMALL_STATE(16971)] = 715273,
  [SMALL_STATE(16972)] = 715290,
  [SMALL_STATE(16973)] = 715307,
  [SMALL_STATE(16974)] = 715324,
  [SMALL_STATE(16975)] = 715341,
  [SMALL_STATE(16976)] = 715358,
  [SMALL_STATE(16977)] = 715375,
  [SMALL_STATE(16978)] = 715392,
  [SMALL_STATE(16979)] = 715409,
  [SMALL_STATE(16980)] = 715426,
  [SMALL_STATE(16981)] = 715443,
  [SMALL_STATE(16982)] = 715460,
  [SMALL_STATE(16983)] = 715477,
  [SMALL_STATE(16984)] = 715494,
  [SMALL_STATE(16985)] = 715511,
  [SMALL_STATE(16986)] = 715528,
  [SMALL_STATE(16987)] = 715545,
  [SMALL_STATE(16988)] = 715562,
  [SMALL_STATE(16989)] = 715579,
  [SMALL_STATE(16990)] = 715596,
  [SMALL_STATE(16991)] = 715613,
  [SMALL_STATE(16992)] = 715630,
  [SMALL_STATE(16993)] = 715647,
  [SMALL_STATE(16994)] = 715664,
  [SMALL_STATE(16995)] = 715681,
  [SMALL_STATE(16996)] = 715698,
  [SMALL_STATE(16997)] = 715713,
  [SMALL_STATE(16998)] = 715730,
  [SMALL_STATE(16999)] = 715747,
  [SMALL_STATE(17000)] = 715764,
  [SMALL_STATE(17001)] = 715781,
  [SMALL_STATE(17002)] = 715798,
  [SMALL_STATE(17003)] = 715815,
  [SMALL_STATE(17004)] = 715832,
  [SMALL_STATE(17005)] = 715849,
  [SMALL_STATE(17006)] = 715866,
  [SMALL_STATE(17007)] = 715883,
  [SMALL_STATE(17008)] = 715900,
  [SMALL_STATE(17009)] = 715917,
  [SMALL_STATE(17010)] = 715934,
  [SMALL_STATE(17011)] = 715951,
  [SMALL_STATE(17012)] = 715968,
  [SMALL_STATE(17013)] = 715985,
  [SMALL_STATE(17014)] = 716002,
  [SMALL_STATE(17015)] = 716019,
  [SMALL_STATE(17016)] = 716036,
  [SMALL_STATE(17017)] = 716053,
  [SMALL_STATE(17018)] = 716070,
  [SMALL_STATE(17019)] = 716087,
  [SMALL_STATE(17020)] = 716104,
  [SMALL_STATE(17021)] = 716121,
  [SMALL_STATE(17022)] = 716138,
  [SMALL_STATE(17023)] = 716155,
  [SMALL_STATE(17024)] = 716172,
  [SMALL_STATE(17025)] = 716189,
  [SMALL_STATE(17026)] = 716206,
  [SMALL_STATE(17027)] = 716223,
  [SMALL_STATE(17028)] = 716240,
  [SMALL_STATE(17029)] = 716257,
  [SMALL_STATE(17030)] = 716274,
  [SMALL_STATE(17031)] = 716291,
  [SMALL_STATE(17032)] = 716306,
  [SMALL_STATE(17033)] = 716323,
  [SMALL_STATE(17034)] = 716340,
  [SMALL_STATE(17035)] = 716357,
  [SMALL_STATE(17036)] = 716374,
  [SMALL_STATE(17037)] = 716391,
  [SMALL_STATE(17038)] = 716408,
  [SMALL_STATE(17039)] = 716423,
  [SMALL_STATE(17040)] = 716440,
  [SMALL_STATE(17041)] = 716457,
  [SMALL_STATE(17042)] = 716474,
  [SMALL_STATE(17043)] = 716491,
  [SMALL_STATE(17044)] = 716508,
  [SMALL_STATE(17045)] = 716525,
  [SMALL_STATE(17046)] = 716542,
  [SMALL_STATE(17047)] = 716559,
  [SMALL_STATE(17048)] = 716576,
  [SMALL_STATE(17049)] = 716593,
  [SMALL_STATE(17050)] = 716610,
  [SMALL_STATE(17051)] = 716627,
  [SMALL_STATE(17052)] = 716644,
  [SMALL_STATE(17053)] = 716661,
  [SMALL_STATE(17054)] = 716678,
  [SMALL_STATE(17055)] = 716695,
  [SMALL_STATE(17056)] = 716712,
  [SMALL_STATE(17057)] = 716729,
  [SMALL_STATE(17058)] = 716746,
  [SMALL_STATE(17059)] = 716763,
  [SMALL_STATE(17060)] = 716780,
  [SMALL_STATE(17061)] = 716797,
  [SMALL_STATE(17062)] = 716814,
  [SMALL_STATE(17063)] = 716831,
  [SMALL_STATE(17064)] = 716848,
  [SMALL_STATE(17065)] = 716865,
  [SMALL_STATE(17066)] = 716882,
  [SMALL_STATE(17067)] = 716899,
  [SMALL_STATE(17068)] = 716916,
  [SMALL_STATE(17069)] = 716933,
  [SMALL_STATE(17070)] = 716950,
  [SMALL_STATE(17071)] = 716967,
  [SMALL_STATE(17072)] = 716984,
  [SMALL_STATE(17073)] = 717001,
  [SMALL_STATE(17074)] = 717018,
  [SMALL_STATE(17075)] = 717035,
  [SMALL_STATE(17076)] = 717052,
  [SMALL_STATE(17077)] = 717067,
  [SMALL_STATE(17078)] = 717084,
  [SMALL_STATE(17079)] = 717099,
  [SMALL_STATE(17080)] = 717116,
  [SMALL_STATE(17081)] = 717133,
  [SMALL_STATE(17082)] = 717150,
  [SMALL_STATE(17083)] = 717167,
  [SMALL_STATE(17084)] = 717184,
  [SMALL_STATE(17085)] = 717201,
  [SMALL_STATE(17086)] = 717218,
  [SMALL_STATE(17087)] = 717235,
  [SMALL_STATE(17088)] = 717252,
  [SMALL_STATE(17089)] = 717269,
  [SMALL_STATE(17090)] = 717286,
  [SMALL_STATE(17091)] = 717303,
  [SMALL_STATE(17092)] = 717320,
  [SMALL_STATE(17093)] = 717337,
  [SMALL_STATE(17094)] = 717354,
  [SMALL_STATE(17095)] = 717371,
  [SMALL_STATE(17096)] = 717386,
  [SMALL_STATE(17097)] = 717403,
  [SMALL_STATE(17098)] = 717418,
  [SMALL_STATE(17099)] = 717433,
  [SMALL_STATE(17100)] = 717450,
  [SMALL_STATE(17101)] = 717467,
  [SMALL_STATE(17102)] = 717484,
  [SMALL_STATE(17103)] = 717501,
  [SMALL_STATE(17104)] = 717518,
  [SMALL_STATE(17105)] = 717535,
  [SMALL_STATE(17106)] = 717552,
  [SMALL_STATE(17107)] = 717569,
  [SMALL_STATE(17108)] = 717586,
  [SMALL_STATE(17109)] = 717603,
  [SMALL_STATE(17110)] = 717620,
  [SMALL_STATE(17111)] = 717637,
  [SMALL_STATE(17112)] = 717654,
  [SMALL_STATE(17113)] = 717671,
  [SMALL_STATE(17114)] = 717688,
  [SMALL_STATE(17115)] = 717705,
  [SMALL_STATE(17116)] = 717722,
  [SMALL_STATE(17117)] = 717739,
  [SMALL_STATE(17118)] = 717756,
  [SMALL_STATE(17119)] = 717773,
  [SMALL_STATE(17120)] = 717790,
  [SMALL_STATE(17121)] = 717807,
  [SMALL_STATE(17122)] = 717824,
  [SMALL_STATE(17123)] = 717839,
  [SMALL_STATE(17124)] = 717856,
  [SMALL_STATE(17125)] = 717873,
  [SMALL_STATE(17126)] = 717890,
  [SMALL_STATE(17127)] = 717907,
  [SMALL_STATE(17128)] = 717924,
  [SMALL_STATE(17129)] = 717939,
  [SMALL_STATE(17130)] = 717956,
  [SMALL_STATE(17131)] = 717973,
  [SMALL_STATE(17132)] = 717990,
  [SMALL_STATE(17133)] = 718007,
  [SMALL_STATE(17134)] = 718024,
  [SMALL_STATE(17135)] = 718041,
  [SMALL_STATE(17136)] = 718058,
  [SMALL_STATE(17137)] = 718075,
  [SMALL_STATE(17138)] = 718092,
  [SMALL_STATE(17139)] = 718109,
  [SMALL_STATE(17140)] = 718126,
  [SMALL_STATE(17141)] = 718143,
  [SMALL_STATE(17142)] = 718160,
  [SMALL_STATE(17143)] = 718177,
  [SMALL_STATE(17144)] = 718194,
  [SMALL_STATE(17145)] = 718209,
  [SMALL_STATE(17146)] = 718226,
  [SMALL_STATE(17147)] = 718243,
  [SMALL_STATE(17148)] = 718260,
  [SMALL_STATE(17149)] = 718277,
  [SMALL_STATE(17150)] = 718294,
  [SMALL_STATE(17151)] = 718311,
  [SMALL_STATE(17152)] = 718328,
  [SMALL_STATE(17153)] = 718345,
  [SMALL_STATE(17154)] = 718362,
  [SMALL_STATE(17155)] = 718379,
  [SMALL_STATE(17156)] = 718396,
  [SMALL_STATE(17157)] = 718411,
  [SMALL_STATE(17158)] = 718428,
  [SMALL_STATE(17159)] = 718443,
  [SMALL_STATE(17160)] = 718460,
  [SMALL_STATE(17161)] = 718477,
  [SMALL_STATE(17162)] = 718494,
  [SMALL_STATE(17163)] = 718511,
  [SMALL_STATE(17164)] = 718528,
  [SMALL_STATE(17165)] = 718545,
  [SMALL_STATE(17166)] = 718562,
  [SMALL_STATE(17167)] = 718579,
  [SMALL_STATE(17168)] = 718596,
  [SMALL_STATE(17169)] = 718613,
  [SMALL_STATE(17170)] = 718630,
  [SMALL_STATE(17171)] = 718647,
  [SMALL_STATE(17172)] = 718664,
  [SMALL_STATE(17173)] = 718681,
  [SMALL_STATE(17174)] = 718698,
  [SMALL_STATE(17175)] = 718713,
  [SMALL_STATE(17176)] = 718730,
  [SMALL_STATE(17177)] = 718747,
  [SMALL_STATE(17178)] = 718764,
  [SMALL_STATE(17179)] = 718781,
  [SMALL_STATE(17180)] = 718798,
  [SMALL_STATE(17181)] = 718815,
  [SMALL_STATE(17182)] = 718832,
  [SMALL_STATE(17183)] = 718849,
  [SMALL_STATE(17184)] = 718866,
  [SMALL_STATE(17185)] = 718881,
  [SMALL_STATE(17186)] = 718896,
  [SMALL_STATE(17187)] = 718913,
  [SMALL_STATE(17188)] = 718930,
  [SMALL_STATE(17189)] = 718947,
  [SMALL_STATE(17190)] = 718964,
  [SMALL_STATE(17191)] = 718981,
  [SMALL_STATE(17192)] = 718998,
  [SMALL_STATE(17193)] = 719015,
  [SMALL_STATE(17194)] = 719032,
  [SMALL_STATE(17195)] = 719049,
  [SMALL_STATE(17196)] = 719066,
  [SMALL_STATE(17197)] = 719083,
  [SMALL_STATE(17198)] = 719100,
  [SMALL_STATE(17199)] = 719115,
  [SMALL_STATE(17200)] = 719132,
  [SMALL_STATE(17201)] = 719149,
  [SMALL_STATE(17202)] = 719166,
  [SMALL_STATE(17203)] = 719183,
  [SMALL_STATE(17204)] = 719200,
  [SMALL_STATE(17205)] = 719217,
  [SMALL_STATE(17206)] = 719234,
  [SMALL_STATE(17207)] = 719251,
  [SMALL_STATE(17208)] = 719268,
  [SMALL_STATE(17209)] = 719285,
  [SMALL_STATE(17210)] = 719302,
  [SMALL_STATE(17211)] = 719319,
  [SMALL_STATE(17212)] = 719336,
  [SMALL_STATE(17213)] = 719353,
  [SMALL_STATE(17214)] = 719370,
  [SMALL_STATE(17215)] = 719387,
  [SMALL_STATE(17216)] = 719404,
  [SMALL_STATE(17217)] = 719421,
  [SMALL_STATE(17218)] = 719436,
  [SMALL_STATE(17219)] = 719451,
  [SMALL_STATE(17220)] = 719468,
  [SMALL_STATE(17221)] = 719485,
  [SMALL_STATE(17222)] = 719502,
  [SMALL_STATE(17223)] = 719519,
  [SMALL_STATE(17224)] = 719536,
  [SMALL_STATE(17225)] = 719553,
  [SMALL_STATE(17226)] = 719570,
  [SMALL_STATE(17227)] = 719587,
  [SMALL_STATE(17228)] = 719604,
  [SMALL_STATE(17229)] = 719619,
  [SMALL_STATE(17230)] = 719636,
  [SMALL_STATE(17231)] = 719653,
  [SMALL_STATE(17232)] = 719670,
  [SMALL_STATE(17233)] = 719687,
  [SMALL_STATE(17234)] = 719704,
  [SMALL_STATE(17235)] = 719721,
  [SMALL_STATE(17236)] = 719738,
  [SMALL_STATE(17237)] = 719755,
  [SMALL_STATE(17238)] = 719772,
  [SMALL_STATE(17239)] = 719789,
  [SMALL_STATE(17240)] = 719806,
  [SMALL_STATE(17241)] = 719823,
  [SMALL_STATE(17242)] = 719840,
  [SMALL_STATE(17243)] = 719857,
  [SMALL_STATE(17244)] = 719874,
  [SMALL_STATE(17245)] = 719891,
  [SMALL_STATE(17246)] = 719908,
  [SMALL_STATE(17247)] = 719925,
  [SMALL_STATE(17248)] = 719940,
  [SMALL_STATE(17249)] = 719957,
  [SMALL_STATE(17250)] = 719974,
  [SMALL_STATE(17251)] = 719991,
  [SMALL_STATE(17252)] = 720008,
  [SMALL_STATE(17253)] = 720025,
  [SMALL_STATE(17254)] = 720042,
  [SMALL_STATE(17255)] = 720057,
  [SMALL_STATE(17256)] = 720074,
  [SMALL_STATE(17257)] = 720091,
  [SMALL_STATE(17258)] = 720108,
  [SMALL_STATE(17259)] = 720125,
  [SMALL_STATE(17260)] = 720142,
  [SMALL_STATE(17261)] = 720159,
  [SMALL_STATE(17262)] = 720176,
  [SMALL_STATE(17263)] = 720193,
  [SMALL_STATE(17264)] = 720210,
  [SMALL_STATE(17265)] = 720227,
  [SMALL_STATE(17266)] = 720244,
  [SMALL_STATE(17267)] = 720261,
  [SMALL_STATE(17268)] = 720278,
  [SMALL_STATE(17269)] = 720295,
  [SMALL_STATE(17270)] = 720312,
  [SMALL_STATE(17271)] = 720329,
  [SMALL_STATE(17272)] = 720346,
  [SMALL_STATE(17273)] = 720363,
  [SMALL_STATE(17274)] = 720380,
  [SMALL_STATE(17275)] = 720397,
  [SMALL_STATE(17276)] = 720414,
  [SMALL_STATE(17277)] = 720431,
  [SMALL_STATE(17278)] = 720448,
  [SMALL_STATE(17279)] = 720465,
  [SMALL_STATE(17280)] = 720480,
  [SMALL_STATE(17281)] = 720497,
  [SMALL_STATE(17282)] = 720514,
  [SMALL_STATE(17283)] = 720529,
  [SMALL_STATE(17284)] = 720546,
  [SMALL_STATE(17285)] = 720563,
  [SMALL_STATE(17286)] = 720580,
  [SMALL_STATE(17287)] = 720597,
  [SMALL_STATE(17288)] = 720614,
  [SMALL_STATE(17289)] = 720631,
  [SMALL_STATE(17290)] = 720648,
  [SMALL_STATE(17291)] = 720663,
  [SMALL_STATE(17292)] = 720680,
  [SMALL_STATE(17293)] = 720697,
  [SMALL_STATE(17294)] = 720714,
  [SMALL_STATE(17295)] = 720731,
  [SMALL_STATE(17296)] = 720748,
  [SMALL_STATE(17297)] = 720765,
  [SMALL_STATE(17298)] = 720782,
  [SMALL_STATE(17299)] = 720799,
  [SMALL_STATE(17300)] = 720816,
  [SMALL_STATE(17301)] = 720833,
  [SMALL_STATE(17302)] = 720850,
  [SMALL_STATE(17303)] = 720867,
  [SMALL_STATE(17304)] = 720884,
  [SMALL_STATE(17305)] = 720901,
  [SMALL_STATE(17306)] = 720918,
  [SMALL_STATE(17307)] = 720935,
  [SMALL_STATE(17308)] = 720950,
  [SMALL_STATE(17309)] = 720967,
  [SMALL_STATE(17310)] = 720984,
  [SMALL_STATE(17311)] = 721001,
  [SMALL_STATE(17312)] = 721018,
  [SMALL_STATE(17313)] = 721035,
  [SMALL_STATE(17314)] = 721052,
  [SMALL_STATE(17315)] = 721069,
  [SMALL_STATE(17316)] = 721086,
  [SMALL_STATE(17317)] = 721103,
  [SMALL_STATE(17318)] = 721120,
  [SMALL_STATE(17319)] = 721137,
  [SMALL_STATE(17320)] = 721154,
  [SMALL_STATE(17321)] = 721171,
  [SMALL_STATE(17322)] = 721188,
  [SMALL_STATE(17323)] = 721203,
  [SMALL_STATE(17324)] = 721218,
  [SMALL_STATE(17325)] = 721235,
  [SMALL_STATE(17326)] = 721252,
  [SMALL_STATE(17327)] = 721269,
  [SMALL_STATE(17328)] = 721286,
  [SMALL_STATE(17329)] = 721303,
  [SMALL_STATE(17330)] = 721318,
  [SMALL_STATE(17331)] = 721335,
  [SMALL_STATE(17332)] = 721352,
  [SMALL_STATE(17333)] = 721369,
  [SMALL_STATE(17334)] = 721386,
  [SMALL_STATE(17335)] = 721403,
  [SMALL_STATE(17336)] = 721420,
  [SMALL_STATE(17337)] = 721437,
  [SMALL_STATE(17338)] = 721454,
  [SMALL_STATE(17339)] = 721471,
  [SMALL_STATE(17340)] = 721488,
  [SMALL_STATE(17341)] = 721505,
  [SMALL_STATE(17342)] = 721522,
  [SMALL_STATE(17343)] = 721539,
  [SMALL_STATE(17344)] = 721556,
  [SMALL_STATE(17345)] = 721573,
  [SMALL_STATE(17346)] = 721590,
  [SMALL_STATE(17347)] = 721607,
  [SMALL_STATE(17348)] = 721624,
  [SMALL_STATE(17349)] = 721641,
  [SMALL_STATE(17350)] = 721658,
  [SMALL_STATE(17351)] = 721675,
  [SMALL_STATE(17352)] = 721692,
  [SMALL_STATE(17353)] = 721709,
  [SMALL_STATE(17354)] = 721724,
  [SMALL_STATE(17355)] = 721741,
  [SMALL_STATE(17356)] = 721758,
  [SMALL_STATE(17357)] = 721775,
  [SMALL_STATE(17358)] = 721790,
  [SMALL_STATE(17359)] = 721807,
  [SMALL_STATE(17360)] = 721824,
  [SMALL_STATE(17361)] = 721841,
  [SMALL_STATE(17362)] = 721858,
  [SMALL_STATE(17363)] = 721875,
  [SMALL_STATE(17364)] = 721892,
  [SMALL_STATE(17365)] = 721909,
  [SMALL_STATE(17366)] = 721926,
  [SMALL_STATE(17367)] = 721943,
  [SMALL_STATE(17368)] = 721960,
  [SMALL_STATE(17369)] = 721977,
  [SMALL_STATE(17370)] = 721994,
  [SMALL_STATE(17371)] = 722011,
  [SMALL_STATE(17372)] = 722028,
  [SMALL_STATE(17373)] = 722045,
  [SMALL_STATE(17374)] = 722062,
  [SMALL_STATE(17375)] = 722079,
  [SMALL_STATE(17376)] = 722096,
  [SMALL_STATE(17377)] = 722111,
  [SMALL_STATE(17378)] = 722128,
  [SMALL_STATE(17379)] = 722145,
  [SMALL_STATE(17380)] = 722162,
  [SMALL_STATE(17381)] = 722179,
  [SMALL_STATE(17382)] = 722196,
  [SMALL_STATE(17383)] = 722213,
  [SMALL_STATE(17384)] = 722230,
  [SMALL_STATE(17385)] = 722245,
  [SMALL_STATE(17386)] = 722262,
  [SMALL_STATE(17387)] = 722279,
  [SMALL_STATE(17388)] = 722296,
  [SMALL_STATE(17389)] = 722311,
  [SMALL_STATE(17390)] = 722328,
  [SMALL_STATE(17391)] = 722343,
  [SMALL_STATE(17392)] = 722360,
  [SMALL_STATE(17393)] = 722377,
  [SMALL_STATE(17394)] = 722394,
  [SMALL_STATE(17395)] = 722411,
  [SMALL_STATE(17396)] = 722428,
  [SMALL_STATE(17397)] = 722445,
  [SMALL_STATE(17398)] = 722462,
  [SMALL_STATE(17399)] = 722479,
  [SMALL_STATE(17400)] = 722496,
  [SMALL_STATE(17401)] = 722513,
  [SMALL_STATE(17402)] = 722530,
  [SMALL_STATE(17403)] = 722547,
  [SMALL_STATE(17404)] = 722564,
  [SMALL_STATE(17405)] = 722581,
  [SMALL_STATE(17406)] = 722598,
  [SMALL_STATE(17407)] = 722615,
  [SMALL_STATE(17408)] = 722632,
  [SMALL_STATE(17409)] = 722649,
  [SMALL_STATE(17410)] = 722666,
  [SMALL_STATE(17411)] = 722683,
  [SMALL_STATE(17412)] = 722700,
  [SMALL_STATE(17413)] = 722717,
  [SMALL_STATE(17414)] = 722734,
  [SMALL_STATE(17415)] = 722749,
  [SMALL_STATE(17416)] = 722766,
  [SMALL_STATE(17417)] = 722783,
  [SMALL_STATE(17418)] = 722798,
  [SMALL_STATE(17419)] = 722815,
  [SMALL_STATE(17420)] = 722832,
  [SMALL_STATE(17421)] = 722849,
  [SMALL_STATE(17422)] = 722866,
  [SMALL_STATE(17423)] = 722883,
  [SMALL_STATE(17424)] = 722900,
  [SMALL_STATE(17425)] = 722917,
  [SMALL_STATE(17426)] = 722934,
  [SMALL_STATE(17427)] = 722951,
  [SMALL_STATE(17428)] = 722968,
  [SMALL_STATE(17429)] = 722985,
  [SMALL_STATE(17430)] = 723002,
  [SMALL_STATE(17431)] = 723019,
  [SMALL_STATE(17432)] = 723036,
  [SMALL_STATE(17433)] = 723053,
  [SMALL_STATE(17434)] = 723070,
  [SMALL_STATE(17435)] = 723087,
  [SMALL_STATE(17436)] = 723102,
  [SMALL_STATE(17437)] = 723117,
  [SMALL_STATE(17438)] = 723134,
  [SMALL_STATE(17439)] = 723149,
  [SMALL_STATE(17440)] = 723166,
  [SMALL_STATE(17441)] = 723183,
  [SMALL_STATE(17442)] = 723200,
  [SMALL_STATE(17443)] = 723217,
  [SMALL_STATE(17444)] = 723234,
  [SMALL_STATE(17445)] = 723251,
  [SMALL_STATE(17446)] = 723268,
  [SMALL_STATE(17447)] = 723283,
  [SMALL_STATE(17448)] = 723298,
  [SMALL_STATE(17449)] = 723315,
  [SMALL_STATE(17450)] = 723332,
  [SMALL_STATE(17451)] = 723349,
  [SMALL_STATE(17452)] = 723366,
  [SMALL_STATE(17453)] = 723383,
  [SMALL_STATE(17454)] = 723400,
  [SMALL_STATE(17455)] = 723417,
  [SMALL_STATE(17456)] = 723434,
  [SMALL_STATE(17457)] = 723451,
  [SMALL_STATE(17458)] = 723468,
  [SMALL_STATE(17459)] = 723485,
  [SMALL_STATE(17460)] = 723502,
  [SMALL_STATE(17461)] = 723519,
  [SMALL_STATE(17462)] = 723536,
  [SMALL_STATE(17463)] = 723553,
  [SMALL_STATE(17464)] = 723570,
  [SMALL_STATE(17465)] = 723587,
  [SMALL_STATE(17466)] = 723604,
  [SMALL_STATE(17467)] = 723621,
  [SMALL_STATE(17468)] = 723638,
  [SMALL_STATE(17469)] = 723655,
  [SMALL_STATE(17470)] = 723672,
  [SMALL_STATE(17471)] = 723689,
  [SMALL_STATE(17472)] = 723704,
  [SMALL_STATE(17473)] = 723721,
  [SMALL_STATE(17474)] = 723738,
  [SMALL_STATE(17475)] = 723755,
  [SMALL_STATE(17476)] = 723772,
  [SMALL_STATE(17477)] = 723789,
  [SMALL_STATE(17478)] = 723806,
  [SMALL_STATE(17479)] = 723823,
  [SMALL_STATE(17480)] = 723840,
  [SMALL_STATE(17481)] = 723857,
  [SMALL_STATE(17482)] = 723874,
  [SMALL_STATE(17483)] = 723891,
  [SMALL_STATE(17484)] = 723908,
  [SMALL_STATE(17485)] = 723925,
  [SMALL_STATE(17486)] = 723942,
  [SMALL_STATE(17487)] = 723959,
  [SMALL_STATE(17488)] = 723976,
  [SMALL_STATE(17489)] = 723993,
  [SMALL_STATE(17490)] = 724010,
  [SMALL_STATE(17491)] = 724025,
  [SMALL_STATE(17492)] = 724042,
  [SMALL_STATE(17493)] = 724059,
  [SMALL_STATE(17494)] = 724076,
  [SMALL_STATE(17495)] = 724093,
  [SMALL_STATE(17496)] = 724110,
  [SMALL_STATE(17497)] = 724127,
  [SMALL_STATE(17498)] = 724144,
  [SMALL_STATE(17499)] = 724161,
  [SMALL_STATE(17500)] = 724178,
  [SMALL_STATE(17501)] = 724195,
  [SMALL_STATE(17502)] = 724212,
  [SMALL_STATE(17503)] = 724229,
  [SMALL_STATE(17504)] = 724246,
  [SMALL_STATE(17505)] = 724263,
  [SMALL_STATE(17506)] = 724280,
  [SMALL_STATE(17507)] = 724297,
  [SMALL_STATE(17508)] = 724314,
  [SMALL_STATE(17509)] = 724331,
  [SMALL_STATE(17510)] = 724348,
  [SMALL_STATE(17511)] = 724365,
  [SMALL_STATE(17512)] = 724382,
  [SMALL_STATE(17513)] = 724397,
  [SMALL_STATE(17514)] = 724414,
  [SMALL_STATE(17515)] = 724431,
  [SMALL_STATE(17516)] = 724448,
  [SMALL_STATE(17517)] = 724463,
  [SMALL_STATE(17518)] = 724480,
  [SMALL_STATE(17519)] = 724497,
  [SMALL_STATE(17520)] = 724514,
  [SMALL_STATE(17521)] = 724531,
  [SMALL_STATE(17522)] = 724548,
  [SMALL_STATE(17523)] = 724565,
  [SMALL_STATE(17524)] = 724582,
  [SMALL_STATE(17525)] = 724599,
  [SMALL_STATE(17526)] = 724616,
  [SMALL_STATE(17527)] = 724633,
  [SMALL_STATE(17528)] = 724650,
  [SMALL_STATE(17529)] = 724667,
  [SMALL_STATE(17530)] = 724684,
  [SMALL_STATE(17531)] = 724701,
  [SMALL_STATE(17532)] = 724718,
  [SMALL_STATE(17533)] = 724735,
  [SMALL_STATE(17534)] = 724752,
  [SMALL_STATE(17535)] = 724769,
  [SMALL_STATE(17536)] = 724786,
  [SMALL_STATE(17537)] = 724801,
  [SMALL_STATE(17538)] = 724818,
  [SMALL_STATE(17539)] = 724835,
  [SMALL_STATE(17540)] = 724852,
  [SMALL_STATE(17541)] = 724869,
  [SMALL_STATE(17542)] = 724886,
  [SMALL_STATE(17543)] = 724903,
  [SMALL_STATE(17544)] = 724920,
  [SMALL_STATE(17545)] = 724937,
  [SMALL_STATE(17546)] = 724952,
  [SMALL_STATE(17547)] = 724969,
  [SMALL_STATE(17548)] = 724986,
  [SMALL_STATE(17549)] = 725003,
  [SMALL_STATE(17550)] = 725020,
  [SMALL_STATE(17551)] = 725037,
  [SMALL_STATE(17552)] = 725054,
  [SMALL_STATE(17553)] = 725071,
  [SMALL_STATE(17554)] = 725088,
  [SMALL_STATE(17555)] = 725105,
  [SMALL_STATE(17556)] = 725122,
  [SMALL_STATE(17557)] = 725139,
  [SMALL_STATE(17558)] = 725156,
  [SMALL_STATE(17559)] = 725173,
  [SMALL_STATE(17560)] = 725190,
  [SMALL_STATE(17561)] = 725205,
  [SMALL_STATE(17562)] = 725222,
  [SMALL_STATE(17563)] = 725239,
  [SMALL_STATE(17564)] = 725256,
  [SMALL_STATE(17565)] = 725273,
  [SMALL_STATE(17566)] = 725290,
  [SMALL_STATE(17567)] = 725307,
  [SMALL_STATE(17568)] = 725324,
  [SMALL_STATE(17569)] = 725341,
  [SMALL_STATE(17570)] = 725358,
  [SMALL_STATE(17571)] = 725375,
  [SMALL_STATE(17572)] = 725392,
  [SMALL_STATE(17573)] = 725409,
  [SMALL_STATE(17574)] = 725426,
  [SMALL_STATE(17575)] = 725443,
  [SMALL_STATE(17576)] = 725460,
  [SMALL_STATE(17577)] = 725477,
  [SMALL_STATE(17578)] = 725494,
  [SMALL_STATE(17579)] = 725511,
  [SMALL_STATE(17580)] = 725528,
  [SMALL_STATE(17581)] = 725545,
  [SMALL_STATE(17582)] = 725560,
  [SMALL_STATE(17583)] = 725577,
  [SMALL_STATE(17584)] = 725594,
  [SMALL_STATE(17585)] = 725611,
  [SMALL_STATE(17586)] = 725626,
  [SMALL_STATE(17587)] = 725643,
  [SMALL_STATE(17588)] = 725658,
  [SMALL_STATE(17589)] = 725675,
  [SMALL_STATE(17590)] = 725689,
  [SMALL_STATE(17591)] = 725703,
  [SMALL_STATE(17592)] = 725717,
  [SMALL_STATE(17593)] = 725731,
  [SMALL_STATE(17594)] = 725745,
  [SMALL_STATE(17595)] = 725759,
  [SMALL_STATE(17596)] = 725773,
  [SMALL_STATE(17597)] = 725787,
  [SMALL_STATE(17598)] = 725801,
  [SMALL_STATE(17599)] = 725815,
  [SMALL_STATE(17600)] = 725829,
  [SMALL_STATE(17601)] = 725843,
  [SMALL_STATE(17602)] = 725857,
  [SMALL_STATE(17603)] = 725871,
  [SMALL_STATE(17604)] = 725885,
  [SMALL_STATE(17605)] = 725899,
  [SMALL_STATE(17606)] = 725913,
  [SMALL_STATE(17607)] = 725927,
  [SMALL_STATE(17608)] = 725941,
  [SMALL_STATE(17609)] = 725955,
  [SMALL_STATE(17610)] = 725969,
  [SMALL_STATE(17611)] = 725983,
  [SMALL_STATE(17612)] = 725997,
  [SMALL_STATE(17613)] = 726011,
  [SMALL_STATE(17614)] = 726025,
  [SMALL_STATE(17615)] = 726039,
  [SMALL_STATE(17616)] = 726053,
  [SMALL_STATE(17617)] = 726067,
  [SMALL_STATE(17618)] = 726081,
  [SMALL_STATE(17619)] = 726095,
  [SMALL_STATE(17620)] = 726109,
  [SMALL_STATE(17621)] = 726123,
  [SMALL_STATE(17622)] = 726137,
  [SMALL_STATE(17623)] = 726151,
  [SMALL_STATE(17624)] = 726165,
  [SMALL_STATE(17625)] = 726179,
  [SMALL_STATE(17626)] = 726193,
  [SMALL_STATE(17627)] = 726207,
  [SMALL_STATE(17628)] = 726221,
  [SMALL_STATE(17629)] = 726235,
  [SMALL_STATE(17630)] = 726249,
  [SMALL_STATE(17631)] = 726263,
  [SMALL_STATE(17632)] = 726277,
  [SMALL_STATE(17633)] = 726291,
  [SMALL_STATE(17634)] = 726305,
  [SMALL_STATE(17635)] = 726319,
  [SMALL_STATE(17636)] = 726333,
  [SMALL_STATE(17637)] = 726347,
  [SMALL_STATE(17638)] = 726361,
  [SMALL_STATE(17639)] = 726375,
  [SMALL_STATE(17640)] = 726389,
  [SMALL_STATE(17641)] = 726403,
  [SMALL_STATE(17642)] = 726417,
  [SMALL_STATE(17643)] = 726431,
  [SMALL_STATE(17644)] = 726445,
  [SMALL_STATE(17645)] = 726459,
  [SMALL_STATE(17646)] = 726473,
  [SMALL_STATE(17647)] = 726487,
  [SMALL_STATE(17648)] = 726501,
  [SMALL_STATE(17649)] = 726515,
  [SMALL_STATE(17650)] = 726529,
  [SMALL_STATE(17651)] = 726543,
  [SMALL_STATE(17652)] = 726557,
  [SMALL_STATE(17653)] = 726571,
  [SMALL_STATE(17654)] = 726585,
  [SMALL_STATE(17655)] = 726599,
  [SMALL_STATE(17656)] = 726613,
  [SMALL_STATE(17657)] = 726627,
  [SMALL_STATE(17658)] = 726641,
  [SMALL_STATE(17659)] = 726655,
  [SMALL_STATE(17660)] = 726669,
  [SMALL_STATE(17661)] = 726683,
  [SMALL_STATE(17662)] = 726697,
  [SMALL_STATE(17663)] = 726711,
  [SMALL_STATE(17664)] = 726725,
  [SMALL_STATE(17665)] = 726739,
  [SMALL_STATE(17666)] = 726753,
  [SMALL_STATE(17667)] = 726767,
  [SMALL_STATE(17668)] = 726781,
  [SMALL_STATE(17669)] = 726795,
  [SMALL_STATE(17670)] = 726809,
  [SMALL_STATE(17671)] = 726823,
  [SMALL_STATE(17672)] = 726837,
  [SMALL_STATE(17673)] = 726851,
  [SMALL_STATE(17674)] = 726865,
  [SMALL_STATE(17675)] = 726879,
  [SMALL_STATE(17676)] = 726893,
  [SMALL_STATE(17677)] = 726907,
  [SMALL_STATE(17678)] = 726921,
  [SMALL_STATE(17679)] = 726935,
  [SMALL_STATE(17680)] = 726949,
  [SMALL_STATE(17681)] = 726963,
  [SMALL_STATE(17682)] = 726977,
  [SMALL_STATE(17683)] = 726991,
  [SMALL_STATE(17684)] = 727005,
  [SMALL_STATE(17685)] = 727019,
  [SMALL_STATE(17686)] = 727033,
  [SMALL_STATE(17687)] = 727047,
  [SMALL_STATE(17688)] = 727061,
  [SMALL_STATE(17689)] = 727075,
  [SMALL_STATE(17690)] = 727089,
  [SMALL_STATE(17691)] = 727103,
  [SMALL_STATE(17692)] = 727117,
  [SMALL_STATE(17693)] = 727131,
  [SMALL_STATE(17694)] = 727145,
  [SMALL_STATE(17695)] = 727159,
  [SMALL_STATE(17696)] = 727173,
  [SMALL_STATE(17697)] = 727187,
  [SMALL_STATE(17698)] = 727201,
  [SMALL_STATE(17699)] = 727215,
  [SMALL_STATE(17700)] = 727229,
  [SMALL_STATE(17701)] = 727243,
  [SMALL_STATE(17702)] = 727257,
  [SMALL_STATE(17703)] = 727271,
  [SMALL_STATE(17704)] = 727285,
  [SMALL_STATE(17705)] = 727299,
  [SMALL_STATE(17706)] = 727313,
  [SMALL_STATE(17707)] = 727327,
  [SMALL_STATE(17708)] = 727341,
  [SMALL_STATE(17709)] = 727355,
  [SMALL_STATE(17710)] = 727369,
  [SMALL_STATE(17711)] = 727383,
  [SMALL_STATE(17712)] = 727397,
  [SMALL_STATE(17713)] = 727411,
  [SMALL_STATE(17714)] = 727425,
  [SMALL_STATE(17715)] = 727439,
  [SMALL_STATE(17716)] = 727453,
  [SMALL_STATE(17717)] = 727467,
  [SMALL_STATE(17718)] = 727481,
  [SMALL_STATE(17719)] = 727495,
  [SMALL_STATE(17720)] = 727509,
  [SMALL_STATE(17721)] = 727523,
  [SMALL_STATE(17722)] = 727537,
  [SMALL_STATE(17723)] = 727551,
  [SMALL_STATE(17724)] = 727565,
  [SMALL_STATE(17725)] = 727579,
  [SMALL_STATE(17726)] = 727593,
  [SMALL_STATE(17727)] = 727607,
  [SMALL_STATE(17728)] = 727621,
  [SMALL_STATE(17729)] = 727635,
  [SMALL_STATE(17730)] = 727649,
  [SMALL_STATE(17731)] = 727663,
  [SMALL_STATE(17732)] = 727677,
  [SMALL_STATE(17733)] = 727691,
  [SMALL_STATE(17734)] = 727705,
  [SMALL_STATE(17735)] = 727719,
  [SMALL_STATE(17736)] = 727733,
  [SMALL_STATE(17737)] = 727747,
  [SMALL_STATE(17738)] = 727761,
  [SMALL_STATE(17739)] = 727775,
  [SMALL_STATE(17740)] = 727789,
  [SMALL_STATE(17741)] = 727803,
  [SMALL_STATE(17742)] = 727817,
  [SMALL_STATE(17743)] = 727831,
  [SMALL_STATE(17744)] = 727845,
  [SMALL_STATE(17745)] = 727859,
  [SMALL_STATE(17746)] = 727873,
  [SMALL_STATE(17747)] = 727887,
  [SMALL_STATE(17748)] = 727901,
  [SMALL_STATE(17749)] = 727915,
  [SMALL_STATE(17750)] = 727929,
  [SMALL_STATE(17751)] = 727943,
  [SMALL_STATE(17752)] = 727957,
  [SMALL_STATE(17753)] = 727971,
  [SMALL_STATE(17754)] = 727985,
  [SMALL_STATE(17755)] = 727999,
  [SMALL_STATE(17756)] = 728013,
  [SMALL_STATE(17757)] = 728027,
  [SMALL_STATE(17758)] = 728041,
  [SMALL_STATE(17759)] = 728055,
  [SMALL_STATE(17760)] = 728069,
  [SMALL_STATE(17761)] = 728083,
  [SMALL_STATE(17762)] = 728097,
  [SMALL_STATE(17763)] = 728111,
  [SMALL_STATE(17764)] = 728125,
  [SMALL_STATE(17765)] = 728139,
  [SMALL_STATE(17766)] = 728153,
  [SMALL_STATE(17767)] = 728167,
  [SMALL_STATE(17768)] = 728181,
  [SMALL_STATE(17769)] = 728195,
  [SMALL_STATE(17770)] = 728209,
  [SMALL_STATE(17771)] = 728223,
  [SMALL_STATE(17772)] = 728237,
  [SMALL_STATE(17773)] = 728251,
  [SMALL_STATE(17774)] = 728265,
  [SMALL_STATE(17775)] = 728279,
  [SMALL_STATE(17776)] = 728293,
  [SMALL_STATE(17777)] = 728307,
  [SMALL_STATE(17778)] = 728321,
  [SMALL_STATE(17779)] = 728335,
  [SMALL_STATE(17780)] = 728349,
  [SMALL_STATE(17781)] = 728363,
  [SMALL_STATE(17782)] = 728377,
  [SMALL_STATE(17783)] = 728391,
  [SMALL_STATE(17784)] = 728405,
  [SMALL_STATE(17785)] = 728419,
  [SMALL_STATE(17786)] = 728433,
  [SMALL_STATE(17787)] = 728447,
  [SMALL_STATE(17788)] = 728461,
  [SMALL_STATE(17789)] = 728475,
  [SMALL_STATE(17790)] = 728489,
  [SMALL_STATE(17791)] = 728503,
  [SMALL_STATE(17792)] = 728517,
  [SMALL_STATE(17793)] = 728531,
  [SMALL_STATE(17794)] = 728545,
  [SMALL_STATE(17795)] = 728559,
  [SMALL_STATE(17796)] = 728573,
  [SMALL_STATE(17797)] = 728587,
  [SMALL_STATE(17798)] = 728601,
  [SMALL_STATE(17799)] = 728615,
  [SMALL_STATE(17800)] = 728629,
  [SMALL_STATE(17801)] = 728643,
  [SMALL_STATE(17802)] = 728657,
  [SMALL_STATE(17803)] = 728671,
  [SMALL_STATE(17804)] = 728685,
  [SMALL_STATE(17805)] = 728699,
  [SMALL_STATE(17806)] = 728713,
  [SMALL_STATE(17807)] = 728727,
  [SMALL_STATE(17808)] = 728741,
  [SMALL_STATE(17809)] = 728755,
  [SMALL_STATE(17810)] = 728769,
  [SMALL_STATE(17811)] = 728783,
  [SMALL_STATE(17812)] = 728797,
  [SMALL_STATE(17813)] = 728811,
  [SMALL_STATE(17814)] = 728825,
  [SMALL_STATE(17815)] = 728839,
  [SMALL_STATE(17816)] = 728853,
  [SMALL_STATE(17817)] = 728867,
  [SMALL_STATE(17818)] = 728881,
  [SMALL_STATE(17819)] = 728895,
  [SMALL_STATE(17820)] = 728909,
  [SMALL_STATE(17821)] = 728923,
  [SMALL_STATE(17822)] = 728937,
  [SMALL_STATE(17823)] = 728951,
  [SMALL_STATE(17824)] = 728965,
  [SMALL_STATE(17825)] = 728979,
  [SMALL_STATE(17826)] = 728993,
  [SMALL_STATE(17827)] = 729007,
  [SMALL_STATE(17828)] = 729021,
  [SMALL_STATE(17829)] = 729035,
  [SMALL_STATE(17830)] = 729049,
  [SMALL_STATE(17831)] = 729063,
  [SMALL_STATE(17832)] = 729077,
  [SMALL_STATE(17833)] = 729091,
  [SMALL_STATE(17834)] = 729105,
  [SMALL_STATE(17835)] = 729119,
  [SMALL_STATE(17836)] = 729133,
  [SMALL_STATE(17837)] = 729147,
  [SMALL_STATE(17838)] = 729161,
  [SMALL_STATE(17839)] = 729175,
  [SMALL_STATE(17840)] = 729189,
  [SMALL_STATE(17841)] = 729203,
  [SMALL_STATE(17842)] = 729217,
  [SMALL_STATE(17843)] = 729231,
  [SMALL_STATE(17844)] = 729245,
  [SMALL_STATE(17845)] = 729259,
  [SMALL_STATE(17846)] = 729273,
  [SMALL_STATE(17847)] = 729287,
  [SMALL_STATE(17848)] = 729301,
  [SMALL_STATE(17849)] = 729315,
  [SMALL_STATE(17850)] = 729329,
  [SMALL_STATE(17851)] = 729343,
  [SMALL_STATE(17852)] = 729357,
  [SMALL_STATE(17853)] = 729371,
  [SMALL_STATE(17854)] = 729385,
  [SMALL_STATE(17855)] = 729399,
  [SMALL_STATE(17856)] = 729413,
  [SMALL_STATE(17857)] = 729427,
  [SMALL_STATE(17858)] = 729441,
  [SMALL_STATE(17859)] = 729455,
  [SMALL_STATE(17860)] = 729469,
  [SMALL_STATE(17861)] = 729483,
  [SMALL_STATE(17862)] = 729497,
  [SMALL_STATE(17863)] = 729511,
  [SMALL_STATE(17864)] = 729525,
  [SMALL_STATE(17865)] = 729539,
  [SMALL_STATE(17866)] = 729553,
  [SMALL_STATE(17867)] = 729567,
  [SMALL_STATE(17868)] = 729581,
  [SMALL_STATE(17869)] = 729595,
  [SMALL_STATE(17870)] = 729609,
  [SMALL_STATE(17871)] = 729623,
  [SMALL_STATE(17872)] = 729637,
  [SMALL_STATE(17873)] = 729651,
  [SMALL_STATE(17874)] = 729665,
  [SMALL_STATE(17875)] = 729679,
  [SMALL_STATE(17876)] = 729693,
  [SMALL_STATE(17877)] = 729707,
  [SMALL_STATE(17878)] = 729721,
  [SMALL_STATE(17879)] = 729735,
  [SMALL_STATE(17880)] = 729749,
  [SMALL_STATE(17881)] = 729763,
  [SMALL_STATE(17882)] = 729777,
  [SMALL_STATE(17883)] = 729791,
  [SMALL_STATE(17884)] = 729805,
  [SMALL_STATE(17885)] = 729819,
  [SMALL_STATE(17886)] = 729833,
  [SMALL_STATE(17887)] = 729847,
  [SMALL_STATE(17888)] = 729861,
  [SMALL_STATE(17889)] = 729875,
  [SMALL_STATE(17890)] = 729889,
  [SMALL_STATE(17891)] = 729903,
  [SMALL_STATE(17892)] = 729917,
  [SMALL_STATE(17893)] = 729931,
  [SMALL_STATE(17894)] = 729945,
  [SMALL_STATE(17895)] = 729959,
  [SMALL_STATE(17896)] = 729973,
  [SMALL_STATE(17897)] = 729987,
  [SMALL_STATE(17898)] = 730001,
  [SMALL_STATE(17899)] = 730015,
  [SMALL_STATE(17900)] = 730029,
  [SMALL_STATE(17901)] = 730043,
  [SMALL_STATE(17902)] = 730057,
  [SMALL_STATE(17903)] = 730071,
  [SMALL_STATE(17904)] = 730085,
  [SMALL_STATE(17905)] = 730099,
  [SMALL_STATE(17906)] = 730113,
  [SMALL_STATE(17907)] = 730127,
  [SMALL_STATE(17908)] = 730141,
  [SMALL_STATE(17909)] = 730155,
  [SMALL_STATE(17910)] = 730169,
  [SMALL_STATE(17911)] = 730183,
  [SMALL_STATE(17912)] = 730197,
  [SMALL_STATE(17913)] = 730211,
  [SMALL_STATE(17914)] = 730225,
  [SMALL_STATE(17915)] = 730239,
  [SMALL_STATE(17916)] = 730253,
  [SMALL_STATE(17917)] = 730267,
  [SMALL_STATE(17918)] = 730281,
  [SMALL_STATE(17919)] = 730295,
  [SMALL_STATE(17920)] = 730309,
  [SMALL_STATE(17921)] = 730323,
  [SMALL_STATE(17922)] = 730337,
  [SMALL_STATE(17923)] = 730351,
  [SMALL_STATE(17924)] = 730365,
  [SMALL_STATE(17925)] = 730379,
  [SMALL_STATE(17926)] = 730393,
  [SMALL_STATE(17927)] = 730407,
  [SMALL_STATE(17928)] = 730421,
  [SMALL_STATE(17929)] = 730435,
  [SMALL_STATE(17930)] = 730449,
  [SMALL_STATE(17931)] = 730463,
  [SMALL_STATE(17932)] = 730477,
  [SMALL_STATE(17933)] = 730491,
  [SMALL_STATE(17934)] = 730505,
  [SMALL_STATE(17935)] = 730519,
  [SMALL_STATE(17936)] = 730533,
  [SMALL_STATE(17937)] = 730547,
  [SMALL_STATE(17938)] = 730561,
  [SMALL_STATE(17939)] = 730575,
  [SMALL_STATE(17940)] = 730589,
  [SMALL_STATE(17941)] = 730603,
  [SMALL_STATE(17942)] = 730617,
  [SMALL_STATE(17943)] = 730631,
  [SMALL_STATE(17944)] = 730645,
  [SMALL_STATE(17945)] = 730659,
  [SMALL_STATE(17946)] = 730673,
  [SMALL_STATE(17947)] = 730687,
  [SMALL_STATE(17948)] = 730701,
  [SMALL_STATE(17949)] = 730715,
  [SMALL_STATE(17950)] = 730729,
  [SMALL_STATE(17951)] = 730743,
  [SMALL_STATE(17952)] = 730757,
  [SMALL_STATE(17953)] = 730771,
  [SMALL_STATE(17954)] = 730785,
  [SMALL_STATE(17955)] = 730799,
  [SMALL_STATE(17956)] = 730813,
  [SMALL_STATE(17957)] = 730827,
  [SMALL_STATE(17958)] = 730841,
  [SMALL_STATE(17959)] = 730855,
  [SMALL_STATE(17960)] = 730869,
  [SMALL_STATE(17961)] = 730883,
  [SMALL_STATE(17962)] = 730897,
  [SMALL_STATE(17963)] = 730911,
  [SMALL_STATE(17964)] = 730925,
  [SMALL_STATE(17965)] = 730939,
  [SMALL_STATE(17966)] = 730953,
  [SMALL_STATE(17967)] = 730967,
  [SMALL_STATE(17968)] = 730981,
  [SMALL_STATE(17969)] = 730995,
  [SMALL_STATE(17970)] = 731009,
  [SMALL_STATE(17971)] = 731023,
  [SMALL_STATE(17972)] = 731037,
  [SMALL_STATE(17973)] = 731051,
  [SMALL_STATE(17974)] = 731065,
  [SMALL_STATE(17975)] = 731079,
  [SMALL_STATE(17976)] = 731093,
  [SMALL_STATE(17977)] = 731107,
  [SMALL_STATE(17978)] = 731121,
  [SMALL_STATE(17979)] = 731135,
  [SMALL_STATE(17980)] = 731149,
  [SMALL_STATE(17981)] = 731163,
  [SMALL_STATE(17982)] = 731177,
  [SMALL_STATE(17983)] = 731191,
  [SMALL_STATE(17984)] = 731205,
  [SMALL_STATE(17985)] = 731219,
  [SMALL_STATE(17986)] = 731233,
  [SMALL_STATE(17987)] = 731247,
  [SMALL_STATE(17988)] = 731261,
  [SMALL_STATE(17989)] = 731275,
  [SMALL_STATE(17990)] = 731289,
  [SMALL_STATE(17991)] = 731303,
  [SMALL_STATE(17992)] = 731317,
  [SMALL_STATE(17993)] = 731331,
  [SMALL_STATE(17994)] = 731345,
  [SMALL_STATE(17995)] = 731359,
  [SMALL_STATE(17996)] = 731373,
  [SMALL_STATE(17997)] = 731387,
  [SMALL_STATE(17998)] = 731401,
  [SMALL_STATE(17999)] = 731415,
  [SMALL_STATE(18000)] = 731429,
  [SMALL_STATE(18001)] = 731443,
  [SMALL_STATE(18002)] = 731457,
  [SMALL_STATE(18003)] = 731471,
  [SMALL_STATE(18004)] = 731485,
  [SMALL_STATE(18005)] = 731499,
  [SMALL_STATE(18006)] = 731513,
  [SMALL_STATE(18007)] = 731527,
  [SMALL_STATE(18008)] = 731541,
  [SMALL_STATE(18009)] = 731555,
  [SMALL_STATE(18010)] = 731569,
  [SMALL_STATE(18011)] = 731583,
  [SMALL_STATE(18012)] = 731597,
  [SMALL_STATE(18013)] = 731611,
  [SMALL_STATE(18014)] = 731625,
  [SMALL_STATE(18015)] = 731639,
  [SMALL_STATE(18016)] = 731653,
  [SMALL_STATE(18017)] = 731667,
  [SMALL_STATE(18018)] = 731681,
  [SMALL_STATE(18019)] = 731695,
  [SMALL_STATE(18020)] = 731709,
  [SMALL_STATE(18021)] = 731723,
  [SMALL_STATE(18022)] = 731737,
  [SMALL_STATE(18023)] = 731751,
  [SMALL_STATE(18024)] = 731765,
  [SMALL_STATE(18025)] = 731779,
  [SMALL_STATE(18026)] = 731793,
  [SMALL_STATE(18027)] = 731807,
  [SMALL_STATE(18028)] = 731821,
  [SMALL_STATE(18029)] = 731835,
  [SMALL_STATE(18030)] = 731849,
  [SMALL_STATE(18031)] = 731863,
  [SMALL_STATE(18032)] = 731877,
  [SMALL_STATE(18033)] = 731891,
  [SMALL_STATE(18034)] = 731905,
  [SMALL_STATE(18035)] = 731919,
  [SMALL_STATE(18036)] = 731933,
  [SMALL_STATE(18037)] = 731947,
  [SMALL_STATE(18038)] = 731961,
  [SMALL_STATE(18039)] = 731975,
  [SMALL_STATE(18040)] = 731989,
  [SMALL_STATE(18041)] = 732003,
  [SMALL_STATE(18042)] = 732017,
  [SMALL_STATE(18043)] = 732031,
  [SMALL_STATE(18044)] = 732045,
  [SMALL_STATE(18045)] = 732059,
  [SMALL_STATE(18046)] = 732073,
  [SMALL_STATE(18047)] = 732087,
  [SMALL_STATE(18048)] = 732101,
  [SMALL_STATE(18049)] = 732115,
  [SMALL_STATE(18050)] = 732129,
  [SMALL_STATE(18051)] = 732143,
  [SMALL_STATE(18052)] = 732157,
  [SMALL_STATE(18053)] = 732171,
  [SMALL_STATE(18054)] = 732185,
  [SMALL_STATE(18055)] = 732199,
  [SMALL_STATE(18056)] = 732213,
  [SMALL_STATE(18057)] = 732227,
  [SMALL_STATE(18058)] = 732241,
  [SMALL_STATE(18059)] = 732255,
  [SMALL_STATE(18060)] = 732269,
  [SMALL_STATE(18061)] = 732283,
  [SMALL_STATE(18062)] = 732297,
  [SMALL_STATE(18063)] = 732311,
  [SMALL_STATE(18064)] = 732325,
  [SMALL_STATE(18065)] = 732339,
  [SMALL_STATE(18066)] = 732353,
  [SMALL_STATE(18067)] = 732367,
  [SMALL_STATE(18068)] = 732381,
  [SMALL_STATE(18069)] = 732395,
  [SMALL_STATE(18070)] = 732409,
  [SMALL_STATE(18071)] = 732423,
  [SMALL_STATE(18072)] = 732437,
  [SMALL_STATE(18073)] = 732451,
  [SMALL_STATE(18074)] = 732465,
  [SMALL_STATE(18075)] = 732479,
  [SMALL_STATE(18076)] = 732493,
  [SMALL_STATE(18077)] = 732507,
  [SMALL_STATE(18078)] = 732521,
  [SMALL_STATE(18079)] = 732535,
  [SMALL_STATE(18080)] = 732549,
  [SMALL_STATE(18081)] = 732563,
  [SMALL_STATE(18082)] = 732577,
  [SMALL_STATE(18083)] = 732591,
  [SMALL_STATE(18084)] = 732605,
  [SMALL_STATE(18085)] = 732619,
  [SMALL_STATE(18086)] = 732633,
  [SMALL_STATE(18087)] = 732647,
  [SMALL_STATE(18088)] = 732661,
  [SMALL_STATE(18089)] = 732675,
  [SMALL_STATE(18090)] = 732689,
  [SMALL_STATE(18091)] = 732703,
  [SMALL_STATE(18092)] = 732717,
  [SMALL_STATE(18093)] = 732731,
  [SMALL_STATE(18094)] = 732745,
  [SMALL_STATE(18095)] = 732759,
  [SMALL_STATE(18096)] = 732773,
  [SMALL_STATE(18097)] = 732787,
  [SMALL_STATE(18098)] = 732801,
  [SMALL_STATE(18099)] = 732815,
  [SMALL_STATE(18100)] = 732829,
  [SMALL_STATE(18101)] = 732843,
  [SMALL_STATE(18102)] = 732857,
  [SMALL_STATE(18103)] = 732871,
  [SMALL_STATE(18104)] = 732885,
  [SMALL_STATE(18105)] = 732899,
  [SMALL_STATE(18106)] = 732913,
  [SMALL_STATE(18107)] = 732927,
  [SMALL_STATE(18108)] = 732941,
  [SMALL_STATE(18109)] = 732955,
  [SMALL_STATE(18110)] = 732969,
  [SMALL_STATE(18111)] = 732983,
  [SMALL_STATE(18112)] = 732997,
  [SMALL_STATE(18113)] = 733011,
  [SMALL_STATE(18114)] = 733025,
  [SMALL_STATE(18115)] = 733039,
  [SMALL_STATE(18116)] = 733053,
  [SMALL_STATE(18117)] = 733067,
  [SMALL_STATE(18118)] = 733081,
  [SMALL_STATE(18119)] = 733095,
  [SMALL_STATE(18120)] = 733109,
  [SMALL_STATE(18121)] = 733123,
  [SMALL_STATE(18122)] = 733137,
  [SMALL_STATE(18123)] = 733151,
  [SMALL_STATE(18124)] = 733165,
  [SMALL_STATE(18125)] = 733179,
  [SMALL_STATE(18126)] = 733193,
  [SMALL_STATE(18127)] = 733207,
  [SMALL_STATE(18128)] = 733221,
  [SMALL_STATE(18129)] = 733235,
  [SMALL_STATE(18130)] = 733249,
  [SMALL_STATE(18131)] = 733263,
  [SMALL_STATE(18132)] = 733277,
  [SMALL_STATE(18133)] = 733291,
  [SMALL_STATE(18134)] = 733305,
  [SMALL_STATE(18135)] = 733319,
  [SMALL_STATE(18136)] = 733333,
  [SMALL_STATE(18137)] = 733347,
  [SMALL_STATE(18138)] = 733361,
  [SMALL_STATE(18139)] = 733375,
  [SMALL_STATE(18140)] = 733389,
  [SMALL_STATE(18141)] = 733403,
  [SMALL_STATE(18142)] = 733417,
  [SMALL_STATE(18143)] = 733431,
  [SMALL_STATE(18144)] = 733445,
  [SMALL_STATE(18145)] = 733459,
  [SMALL_STATE(18146)] = 733473,
  [SMALL_STATE(18147)] = 733487,
  [SMALL_STATE(18148)] = 733501,
  [SMALL_STATE(18149)] = 733515,
  [SMALL_STATE(18150)] = 733529,
  [SMALL_STATE(18151)] = 733543,
  [SMALL_STATE(18152)] = 733557,
  [SMALL_STATE(18153)] = 733571,
  [SMALL_STATE(18154)] = 733585,
  [SMALL_STATE(18155)] = 733599,
  [SMALL_STATE(18156)] = 733613,
  [SMALL_STATE(18157)] = 733627,
  [SMALL_STATE(18158)] = 733641,
  [SMALL_STATE(18159)] = 733655,
  [SMALL_STATE(18160)] = 733669,
  [SMALL_STATE(18161)] = 733683,
  [SMALL_STATE(18162)] = 733697,
  [SMALL_STATE(18163)] = 733711,
  [SMALL_STATE(18164)] = 733725,
  [SMALL_STATE(18165)] = 733739,
  [SMALL_STATE(18166)] = 733753,
  [SMALL_STATE(18167)] = 733767,
  [SMALL_STATE(18168)] = 733781,
  [SMALL_STATE(18169)] = 733795,
  [SMALL_STATE(18170)] = 733809,
  [SMALL_STATE(18171)] = 733823,
  [SMALL_STATE(18172)] = 733837,
  [SMALL_STATE(18173)] = 733851,
  [SMALL_STATE(18174)] = 733865,
  [SMALL_STATE(18175)] = 733879,
  [SMALL_STATE(18176)] = 733893,
  [SMALL_STATE(18177)] = 733907,
  [SMALL_STATE(18178)] = 733921,
  [SMALL_STATE(18179)] = 733935,
  [SMALL_STATE(18180)] = 733949,
  [SMALL_STATE(18181)] = 733963,
  [SMALL_STATE(18182)] = 733977,
  [SMALL_STATE(18183)] = 733991,
  [SMALL_STATE(18184)] = 734005,
  [SMALL_STATE(18185)] = 734019,
  [SMALL_STATE(18186)] = 734033,
  [SMALL_STATE(18187)] = 734047,
  [SMALL_STATE(18188)] = 734061,
  [SMALL_STATE(18189)] = 734075,
  [SMALL_STATE(18190)] = 734089,
  [SMALL_STATE(18191)] = 734103,
  [SMALL_STATE(18192)] = 734117,
  [SMALL_STATE(18193)] = 734131,
  [SMALL_STATE(18194)] = 734145,
  [SMALL_STATE(18195)] = 734159,
  [SMALL_STATE(18196)] = 734173,
  [SMALL_STATE(18197)] = 734187,
  [SMALL_STATE(18198)] = 734201,
  [SMALL_STATE(18199)] = 734215,
  [SMALL_STATE(18200)] = 734229,
  [SMALL_STATE(18201)] = 734243,
  [SMALL_STATE(18202)] = 734257,
  [SMALL_STATE(18203)] = 734271,
  [SMALL_STATE(18204)] = 734285,
  [SMALL_STATE(18205)] = 734299,
  [SMALL_STATE(18206)] = 734313,
  [SMALL_STATE(18207)] = 734327,
  [SMALL_STATE(18208)] = 734341,
  [SMALL_STATE(18209)] = 734355,
  [SMALL_STATE(18210)] = 734369,
  [SMALL_STATE(18211)] = 734383,
  [SMALL_STATE(18212)] = 734397,
  [SMALL_STATE(18213)] = 734411,
  [SMALL_STATE(18214)] = 734425,
  [SMALL_STATE(18215)] = 734439,
  [SMALL_STATE(18216)] = 734453,
  [SMALL_STATE(18217)] = 734467,
  [SMALL_STATE(18218)] = 734481,
  [SMALL_STATE(18219)] = 734495,
  [SMALL_STATE(18220)] = 734509,
  [SMALL_STATE(18221)] = 734523,
  [SMALL_STATE(18222)] = 734537,
  [SMALL_STATE(18223)] = 734551,
  [SMALL_STATE(18224)] = 734565,
  [SMALL_STATE(18225)] = 734579,
  [SMALL_STATE(18226)] = 734593,
  [SMALL_STATE(18227)] = 734607,
  [SMALL_STATE(18228)] = 734621,
  [SMALL_STATE(18229)] = 734635,
  [SMALL_STATE(18230)] = 734649,
  [SMALL_STATE(18231)] = 734663,
  [SMALL_STATE(18232)] = 734677,
  [SMALL_STATE(18233)] = 734691,
  [SMALL_STATE(18234)] = 734705,
  [SMALL_STATE(18235)] = 734719,
  [SMALL_STATE(18236)] = 734733,
  [SMALL_STATE(18237)] = 734747,
  [SMALL_STATE(18238)] = 734761,
  [SMALL_STATE(18239)] = 734775,
  [SMALL_STATE(18240)] = 734789,
  [SMALL_STATE(18241)] = 734803,
  [SMALL_STATE(18242)] = 734817,
  [SMALL_STATE(18243)] = 734831,
  [SMALL_STATE(18244)] = 734845,
  [SMALL_STATE(18245)] = 734859,
  [SMALL_STATE(18246)] = 734873,
  [SMALL_STATE(18247)] = 734887,
  [SMALL_STATE(18248)] = 734901,
  [SMALL_STATE(18249)] = 734915,
  [SMALL_STATE(18250)] = 734929,
  [SMALL_STATE(18251)] = 734943,
  [SMALL_STATE(18252)] = 734957,
  [SMALL_STATE(18253)] = 734971,
  [SMALL_STATE(18254)] = 734985,
  [SMALL_STATE(18255)] = 734999,
  [SMALL_STATE(18256)] = 735013,
  [SMALL_STATE(18257)] = 735027,
  [SMALL_STATE(18258)] = 735041,
  [SMALL_STATE(18259)] = 735055,
  [SMALL_STATE(18260)] = 735069,
  [SMALL_STATE(18261)] = 735083,
  [SMALL_STATE(18262)] = 735097,
  [SMALL_STATE(18263)] = 735111,
  [SMALL_STATE(18264)] = 735125,
  [SMALL_STATE(18265)] = 735139,
  [SMALL_STATE(18266)] = 735153,
  [SMALL_STATE(18267)] = 735167,
  [SMALL_STATE(18268)] = 735181,
  [SMALL_STATE(18269)] = 735195,
  [SMALL_STATE(18270)] = 735209,
  [SMALL_STATE(18271)] = 735223,
  [SMALL_STATE(18272)] = 735237,
  [SMALL_STATE(18273)] = 735251,
  [SMALL_STATE(18274)] = 735265,
  [SMALL_STATE(18275)] = 735279,
  [SMALL_STATE(18276)] = 735293,
  [SMALL_STATE(18277)] = 735307,
  [SMALL_STATE(18278)] = 735321,
  [SMALL_STATE(18279)] = 735335,
  [SMALL_STATE(18280)] = 735349,
  [SMALL_STATE(18281)] = 735363,
  [SMALL_STATE(18282)] = 735377,
  [SMALL_STATE(18283)] = 735391,
  [SMALL_STATE(18284)] = 735405,
  [SMALL_STATE(18285)] = 735419,
  [SMALL_STATE(18286)] = 735433,
  [SMALL_STATE(18287)] = 735447,
  [SMALL_STATE(18288)] = 735461,
  [SMALL_STATE(18289)] = 735475,
  [SMALL_STATE(18290)] = 735489,
  [SMALL_STATE(18291)] = 735503,
  [SMALL_STATE(18292)] = 735517,
  [SMALL_STATE(18293)] = 735531,
  [SMALL_STATE(18294)] = 735545,
  [SMALL_STATE(18295)] = 735559,
  [SMALL_STATE(18296)] = 735573,
  [SMALL_STATE(18297)] = 735587,
  [SMALL_STATE(18298)] = 735601,
  [SMALL_STATE(18299)] = 735615,
  [SMALL_STATE(18300)] = 735629,
  [SMALL_STATE(18301)] = 735643,
  [SMALL_STATE(18302)] = 735657,
  [SMALL_STATE(18303)] = 735671,
  [SMALL_STATE(18304)] = 735685,
  [SMALL_STATE(18305)] = 735699,
  [SMALL_STATE(18306)] = 735713,
  [SMALL_STATE(18307)] = 735727,
  [SMALL_STATE(18308)] = 735741,
  [SMALL_STATE(18309)] = 735755,
  [SMALL_STATE(18310)] = 735769,
  [SMALL_STATE(18311)] = 735783,
  [SMALL_STATE(18312)] = 735797,
  [SMALL_STATE(18313)] = 735811,
  [SMALL_STATE(18314)] = 735825,
  [SMALL_STATE(18315)] = 735839,
  [SMALL_STATE(18316)] = 735853,
  [SMALL_STATE(18317)] = 735867,
  [SMALL_STATE(18318)] = 735881,
  [SMALL_STATE(18319)] = 735895,
  [SMALL_STATE(18320)] = 735909,
  [SMALL_STATE(18321)] = 735923,
  [SMALL_STATE(18322)] = 735937,
  [SMALL_STATE(18323)] = 735951,
  [SMALL_STATE(18324)] = 735965,
  [SMALL_STATE(18325)] = 735979,
  [SMALL_STATE(18326)] = 735993,
  [SMALL_STATE(18327)] = 736007,
  [SMALL_STATE(18328)] = 736021,
  [SMALL_STATE(18329)] = 736035,
  [SMALL_STATE(18330)] = 736049,
  [SMALL_STATE(18331)] = 736063,
  [SMALL_STATE(18332)] = 736077,
  [SMALL_STATE(18333)] = 736091,
  [SMALL_STATE(18334)] = 736105,
  [SMALL_STATE(18335)] = 736119,
  [SMALL_STATE(18336)] = 736133,
  [SMALL_STATE(18337)] = 736147,
  [SMALL_STATE(18338)] = 736161,
  [SMALL_STATE(18339)] = 736175,
  [SMALL_STATE(18340)] = 736189,
  [SMALL_STATE(18341)] = 736203,
  [SMALL_STATE(18342)] = 736217,
  [SMALL_STATE(18343)] = 736231,
  [SMALL_STATE(18344)] = 736245,
  [SMALL_STATE(18345)] = 736259,
  [SMALL_STATE(18346)] = 736273,
  [SMALL_STATE(18347)] = 736287,
  [SMALL_STATE(18348)] = 736301,
  [SMALL_STATE(18349)] = 736315,
  [SMALL_STATE(18350)] = 736329,
  [SMALL_STATE(18351)] = 736343,
  [SMALL_STATE(18352)] = 736357,
  [SMALL_STATE(18353)] = 736371,
  [SMALL_STATE(18354)] = 736385,
  [SMALL_STATE(18355)] = 736399,
  [SMALL_STATE(18356)] = 736413,
  [SMALL_STATE(18357)] = 736427,
  [SMALL_STATE(18358)] = 736441,
  [SMALL_STATE(18359)] = 736455,
  [SMALL_STATE(18360)] = 736469,
  [SMALL_STATE(18361)] = 736483,
  [SMALL_STATE(18362)] = 736497,
  [SMALL_STATE(18363)] = 736511,
  [SMALL_STATE(18364)] = 736525,
  [SMALL_STATE(18365)] = 736539,
  [SMALL_STATE(18366)] = 736553,
  [SMALL_STATE(18367)] = 736567,
  [SMALL_STATE(18368)] = 736581,
  [SMALL_STATE(18369)] = 736595,
  [SMALL_STATE(18370)] = 736609,
  [SMALL_STATE(18371)] = 736623,
  [SMALL_STATE(18372)] = 736637,
  [SMALL_STATE(18373)] = 736651,
  [SMALL_STATE(18374)] = 736665,
  [SMALL_STATE(18375)] = 736679,
  [SMALL_STATE(18376)] = 736693,
  [SMALL_STATE(18377)] = 736707,
  [SMALL_STATE(18378)] = 736721,
  [SMALL_STATE(18379)] = 736735,
  [SMALL_STATE(18380)] = 736749,
  [SMALL_STATE(18381)] = 736763,
  [SMALL_STATE(18382)] = 736777,
  [SMALL_STATE(18383)] = 736791,
  [SMALL_STATE(18384)] = 736805,
  [SMALL_STATE(18385)] = 736819,
  [SMALL_STATE(18386)] = 736833,
  [SMALL_STATE(18387)] = 736847,
  [SMALL_STATE(18388)] = 736861,
  [SMALL_STATE(18389)] = 736875,
  [SMALL_STATE(18390)] = 736889,
  [SMALL_STATE(18391)] = 736903,
  [SMALL_STATE(18392)] = 736917,
  [SMALL_STATE(18393)] = 736931,
  [SMALL_STATE(18394)] = 736945,
  [SMALL_STATE(18395)] = 736959,
  [SMALL_STATE(18396)] = 736973,
  [SMALL_STATE(18397)] = 736987,
  [SMALL_STATE(18398)] = 737001,
  [SMALL_STATE(18399)] = 737015,
  [SMALL_STATE(18400)] = 737029,
  [SMALL_STATE(18401)] = 737043,
  [SMALL_STATE(18402)] = 737057,
  [SMALL_STATE(18403)] = 737071,
  [SMALL_STATE(18404)] = 737085,
  [SMALL_STATE(18405)] = 737099,
  [SMALL_STATE(18406)] = 737113,
  [SMALL_STATE(18407)] = 737127,
  [SMALL_STATE(18408)] = 737141,
  [SMALL_STATE(18409)] = 737155,
  [SMALL_STATE(18410)] = 737169,
  [SMALL_STATE(18411)] = 737183,
  [SMALL_STATE(18412)] = 737197,
  [SMALL_STATE(18413)] = 737211,
  [SMALL_STATE(18414)] = 737225,
  [SMALL_STATE(18415)] = 737239,
  [SMALL_STATE(18416)] = 737253,
  [SMALL_STATE(18417)] = 737267,
  [SMALL_STATE(18418)] = 737281,
  [SMALL_STATE(18419)] = 737295,
  [SMALL_STATE(18420)] = 737309,
  [SMALL_STATE(18421)] = 737323,
  [SMALL_STATE(18422)] = 737337,
  [SMALL_STATE(18423)] = 737351,
  [SMALL_STATE(18424)] = 737365,
  [SMALL_STATE(18425)] = 737379,
  [SMALL_STATE(18426)] = 737393,
  [SMALL_STATE(18427)] = 737407,
  [SMALL_STATE(18428)] = 737421,
  [SMALL_STATE(18429)] = 737435,
  [SMALL_STATE(18430)] = 737449,
  [SMALL_STATE(18431)] = 737463,
  [SMALL_STATE(18432)] = 737477,
  [SMALL_STATE(18433)] = 737491,
  [SMALL_STATE(18434)] = 737505,
  [SMALL_STATE(18435)] = 737519,
  [SMALL_STATE(18436)] = 737533,
  [SMALL_STATE(18437)] = 737547,
  [SMALL_STATE(18438)] = 737561,
  [SMALL_STATE(18439)] = 737575,
  [SMALL_STATE(18440)] = 737589,
  [SMALL_STATE(18441)] = 737603,
  [SMALL_STATE(18442)] = 737617,
  [SMALL_STATE(18443)] = 737631,
  [SMALL_STATE(18444)] = 737645,
  [SMALL_STATE(18445)] = 737659,
  [SMALL_STATE(18446)] = 737673,
  [SMALL_STATE(18447)] = 737687,
  [SMALL_STATE(18448)] = 737701,
  [SMALL_STATE(18449)] = 737715,
  [SMALL_STATE(18450)] = 737729,
  [SMALL_STATE(18451)] = 737743,
  [SMALL_STATE(18452)] = 737757,
  [SMALL_STATE(18453)] = 737771,
  [SMALL_STATE(18454)] = 737785,
  [SMALL_STATE(18455)] = 737799,
  [SMALL_STATE(18456)] = 737813,
  [SMALL_STATE(18457)] = 737827,
  [SMALL_STATE(18458)] = 737841,
  [SMALL_STATE(18459)] = 737855,
  [SMALL_STATE(18460)] = 737869,
  [SMALL_STATE(18461)] = 737883,
  [SMALL_STATE(18462)] = 737897,
  [SMALL_STATE(18463)] = 737911,
  [SMALL_STATE(18464)] = 737925,
  [SMALL_STATE(18465)] = 737939,
  [SMALL_STATE(18466)] = 737953,
  [SMALL_STATE(18467)] = 737967,
  [SMALL_STATE(18468)] = 737981,
  [SMALL_STATE(18469)] = 737995,
  [SMALL_STATE(18470)] = 738009,
  [SMALL_STATE(18471)] = 738023,
  [SMALL_STATE(18472)] = 738037,
  [SMALL_STATE(18473)] = 738051,
  [SMALL_STATE(18474)] = 738065,
  [SMALL_STATE(18475)] = 738079,
  [SMALL_STATE(18476)] = 738093,
  [SMALL_STATE(18477)] = 738107,
  [SMALL_STATE(18478)] = 738121,
  [SMALL_STATE(18479)] = 738135,
  [SMALL_STATE(18480)] = 738149,
  [SMALL_STATE(18481)] = 738163,
  [SMALL_STATE(18482)] = 738177,
  [SMALL_STATE(18483)] = 738191,
  [SMALL_STATE(18484)] = 738205,
  [SMALL_STATE(18485)] = 738219,
  [SMALL_STATE(18486)] = 738233,
  [SMALL_STATE(18487)] = 738247,
  [SMALL_STATE(18488)] = 738261,
  [SMALL_STATE(18489)] = 738275,
  [SMALL_STATE(18490)] = 738289,
  [SMALL_STATE(18491)] = 738303,
  [SMALL_STATE(18492)] = 738317,
  [SMALL_STATE(18493)] = 738331,
  [SMALL_STATE(18494)] = 738345,
  [SMALL_STATE(18495)] = 738359,
  [SMALL_STATE(18496)] = 738373,
  [SMALL_STATE(18497)] = 738387,
  [SMALL_STATE(18498)] = 738401,
  [SMALL_STATE(18499)] = 738415,
  [SMALL_STATE(18500)] = 738429,
  [SMALL_STATE(18501)] = 738443,
  [SMALL_STATE(18502)] = 738457,
  [SMALL_STATE(18503)] = 738471,
  [SMALL_STATE(18504)] = 738485,
  [SMALL_STATE(18505)] = 738499,
  [SMALL_STATE(18506)] = 738513,
  [SMALL_STATE(18507)] = 738527,
  [SMALL_STATE(18508)] = 738541,
  [SMALL_STATE(18509)] = 738555,
  [SMALL_STATE(18510)] = 738569,
  [SMALL_STATE(18511)] = 738583,
  [SMALL_STATE(18512)] = 738597,
  [SMALL_STATE(18513)] = 738611,
  [SMALL_STATE(18514)] = 738625,
  [SMALL_STATE(18515)] = 738639,
  [SMALL_STATE(18516)] = 738653,
  [SMALL_STATE(18517)] = 738667,
  [SMALL_STATE(18518)] = 738681,
  [SMALL_STATE(18519)] = 738695,
  [SMALL_STATE(18520)] = 738709,
  [SMALL_STATE(18521)] = 738723,
  [SMALL_STATE(18522)] = 738737,
  [SMALL_STATE(18523)] = 738751,
  [SMALL_STATE(18524)] = 738765,
  [SMALL_STATE(18525)] = 738779,
  [SMALL_STATE(18526)] = 738793,
  [SMALL_STATE(18527)] = 738807,
  [SMALL_STATE(18528)] = 738821,
  [SMALL_STATE(18529)] = 738835,
  [SMALL_STATE(18530)] = 738849,
  [SMALL_STATE(18531)] = 738863,
  [SMALL_STATE(18532)] = 738877,
  [SMALL_STATE(18533)] = 738891,
  [SMALL_STATE(18534)] = 738905,
  [SMALL_STATE(18535)] = 738919,
  [SMALL_STATE(18536)] = 738933,
  [SMALL_STATE(18537)] = 738947,
  [SMALL_STATE(18538)] = 738961,
  [SMALL_STATE(18539)] = 738975,
  [SMALL_STATE(18540)] = 738989,
  [SMALL_STATE(18541)] = 739003,
  [SMALL_STATE(18542)] = 739017,
  [SMALL_STATE(18543)] = 739031,
  [SMALL_STATE(18544)] = 739045,
  [SMALL_STATE(18545)] = 739059,
  [SMALL_STATE(18546)] = 739073,
  [SMALL_STATE(18547)] = 739087,
  [SMALL_STATE(18548)] = 739101,
  [SMALL_STATE(18549)] = 739115,
  [SMALL_STATE(18550)] = 739129,
  [SMALL_STATE(18551)] = 739143,
  [SMALL_STATE(18552)] = 739157,
  [SMALL_STATE(18553)] = 739171,
  [SMALL_STATE(18554)] = 739185,
  [SMALL_STATE(18555)] = 739199,
  [SMALL_STATE(18556)] = 739213,
  [SMALL_STATE(18557)] = 739227,
  [SMALL_STATE(18558)] = 739241,
  [SMALL_STATE(18559)] = 739255,
  [SMALL_STATE(18560)] = 739269,
  [SMALL_STATE(18561)] = 739283,
  [SMALL_STATE(18562)] = 739297,
  [SMALL_STATE(18563)] = 739311,
  [SMALL_STATE(18564)] = 739325,
  [SMALL_STATE(18565)] = 739339,
  [SMALL_STATE(18566)] = 739353,
  [SMALL_STATE(18567)] = 739367,
  [SMALL_STATE(18568)] = 739381,
  [SMALL_STATE(18569)] = 739395,
  [SMALL_STATE(18570)] = 739409,
  [SMALL_STATE(18571)] = 739423,
  [SMALL_STATE(18572)] = 739437,
  [SMALL_STATE(18573)] = 739451,
  [SMALL_STATE(18574)] = 739465,
  [SMALL_STATE(18575)] = 739479,
  [SMALL_STATE(18576)] = 739493,
  [SMALL_STATE(18577)] = 739507,
  [SMALL_STATE(18578)] = 739521,
  [SMALL_STATE(18579)] = 739535,
  [SMALL_STATE(18580)] = 739549,
  [SMALL_STATE(18581)] = 739563,
  [SMALL_STATE(18582)] = 739577,
  [SMALL_STATE(18583)] = 739591,
  [SMALL_STATE(18584)] = 739605,
  [SMALL_STATE(18585)] = 739619,
  [SMALL_STATE(18586)] = 739633,
  [SMALL_STATE(18587)] = 739647,
  [SMALL_STATE(18588)] = 739661,
  [SMALL_STATE(18589)] = 739675,
  [SMALL_STATE(18590)] = 739689,
  [SMALL_STATE(18591)] = 739703,
  [SMALL_STATE(18592)] = 739717,
  [SMALL_STATE(18593)] = 739731,
  [SMALL_STATE(18594)] = 739745,
  [SMALL_STATE(18595)] = 739759,
  [SMALL_STATE(18596)] = 739773,
  [SMALL_STATE(18597)] = 739787,
  [SMALL_STATE(18598)] = 739801,
  [SMALL_STATE(18599)] = 739815,
  [SMALL_STATE(18600)] = 739829,
  [SMALL_STATE(18601)] = 739843,
  [SMALL_STATE(18602)] = 739857,
  [SMALL_STATE(18603)] = 739871,
  [SMALL_STATE(18604)] = 739885,
  [SMALL_STATE(18605)] = 739899,
  [SMALL_STATE(18606)] = 739913,
  [SMALL_STATE(18607)] = 739927,
  [SMALL_STATE(18608)] = 739941,
  [SMALL_STATE(18609)] = 739955,
  [SMALL_STATE(18610)] = 739969,
  [SMALL_STATE(18611)] = 739983,
  [SMALL_STATE(18612)] = 739997,
  [SMALL_STATE(18613)] = 740011,
  [SMALL_STATE(18614)] = 740025,
  [SMALL_STATE(18615)] = 740039,
  [SMALL_STATE(18616)] = 740053,
  [SMALL_STATE(18617)] = 740067,
  [SMALL_STATE(18618)] = 740081,
  [SMALL_STATE(18619)] = 740095,
  [SMALL_STATE(18620)] = 740109,
  [SMALL_STATE(18621)] = 740123,
  [SMALL_STATE(18622)] = 740137,
  [SMALL_STATE(18623)] = 740151,
  [SMALL_STATE(18624)] = 740165,
  [SMALL_STATE(18625)] = 740179,
  [SMALL_STATE(18626)] = 740193,
  [SMALL_STATE(18627)] = 740207,
  [SMALL_STATE(18628)] = 740221,
  [SMALL_STATE(18629)] = 740235,
  [SMALL_STATE(18630)] = 740249,
  [SMALL_STATE(18631)] = 740263,
  [SMALL_STATE(18632)] = 740277,
  [SMALL_STATE(18633)] = 740291,
  [SMALL_STATE(18634)] = 740305,
  [SMALL_STATE(18635)] = 740319,
  [SMALL_STATE(18636)] = 740333,
  [SMALL_STATE(18637)] = 740347,
  [SMALL_STATE(18638)] = 740361,
  [SMALL_STATE(18639)] = 740375,
  [SMALL_STATE(18640)] = 740389,
  [SMALL_STATE(18641)] = 740403,
  [SMALL_STATE(18642)] = 740417,
  [SMALL_STATE(18643)] = 740431,
  [SMALL_STATE(18644)] = 740445,
  [SMALL_STATE(18645)] = 740459,
  [SMALL_STATE(18646)] = 740473,
  [SMALL_STATE(18647)] = 740487,
  [SMALL_STATE(18648)] = 740501,
  [SMALL_STATE(18649)] = 740515,
  [SMALL_STATE(18650)] = 740529,
  [SMALL_STATE(18651)] = 740543,
  [SMALL_STATE(18652)] = 740557,
  [SMALL_STATE(18653)] = 740571,
  [SMALL_STATE(18654)] = 740585,
  [SMALL_STATE(18655)] = 740599,
  [SMALL_STATE(18656)] = 740613,
  [SMALL_STATE(18657)] = 740627,
  [SMALL_STATE(18658)] = 740641,
  [SMALL_STATE(18659)] = 740655,
  [SMALL_STATE(18660)] = 740669,
  [SMALL_STATE(18661)] = 740683,
  [SMALL_STATE(18662)] = 740697,
  [SMALL_STATE(18663)] = 740711,
  [SMALL_STATE(18664)] = 740725,
  [SMALL_STATE(18665)] = 740739,
  [SMALL_STATE(18666)] = 740753,
  [SMALL_STATE(18667)] = 740767,
  [SMALL_STATE(18668)] = 740781,
  [SMALL_STATE(18669)] = 740795,
  [SMALL_STATE(18670)] = 740809,
  [SMALL_STATE(18671)] = 740823,
  [SMALL_STATE(18672)] = 740837,
  [SMALL_STATE(18673)] = 740851,
  [SMALL_STATE(18674)] = 740865,
  [SMALL_STATE(18675)] = 740879,
  [SMALL_STATE(18676)] = 740893,
  [SMALL_STATE(18677)] = 740907,
  [SMALL_STATE(18678)] = 740921,
  [SMALL_STATE(18679)] = 740935,
  [SMALL_STATE(18680)] = 740949,
  [SMALL_STATE(18681)] = 740963,
  [SMALL_STATE(18682)] = 740977,
  [SMALL_STATE(18683)] = 740991,
  [SMALL_STATE(18684)] = 741005,
  [SMALL_STATE(18685)] = 741019,
  [SMALL_STATE(18686)] = 741033,
  [SMALL_STATE(18687)] = 741047,
  [SMALL_STATE(18688)] = 741061,
  [SMALL_STATE(18689)] = 741075,
  [SMALL_STATE(18690)] = 741089,
  [SMALL_STATE(18691)] = 741103,
  [SMALL_STATE(18692)] = 741117,
  [SMALL_STATE(18693)] = 741131,
  [SMALL_STATE(18694)] = 741145,
  [SMALL_STATE(18695)] = 741159,
  [SMALL_STATE(18696)] = 741173,
  [SMALL_STATE(18697)] = 741187,
  [SMALL_STATE(18698)] = 741201,
  [SMALL_STATE(18699)] = 741215,
  [SMALL_STATE(18700)] = 741229,
  [SMALL_STATE(18701)] = 741243,
  [SMALL_STATE(18702)] = 741257,
  [SMALL_STATE(18703)] = 741271,
  [SMALL_STATE(18704)] = 741285,
  [SMALL_STATE(18705)] = 741299,
  [SMALL_STATE(18706)] = 741313,
  [SMALL_STATE(18707)] = 741327,
  [SMALL_STATE(18708)] = 741341,
  [SMALL_STATE(18709)] = 741355,
  [SMALL_STATE(18710)] = 741369,
  [SMALL_STATE(18711)] = 741383,
  [SMALL_STATE(18712)] = 741397,
  [SMALL_STATE(18713)] = 741411,
  [SMALL_STATE(18714)] = 741425,
  [SMALL_STATE(18715)] = 741439,
  [SMALL_STATE(18716)] = 741453,
  [SMALL_STATE(18717)] = 741467,
  [SMALL_STATE(18718)] = 741481,
  [SMALL_STATE(18719)] = 741495,
  [SMALL_STATE(18720)] = 741509,
  [SMALL_STATE(18721)] = 741523,
  [SMALL_STATE(18722)] = 741537,
  [SMALL_STATE(18723)] = 741551,
  [SMALL_STATE(18724)] = 741565,
  [SMALL_STATE(18725)] = 741579,
  [SMALL_STATE(18726)] = 741593,
  [SMALL_STATE(18727)] = 741607,
  [SMALL_STATE(18728)] = 741621,
  [SMALL_STATE(18729)] = 741635,
  [SMALL_STATE(18730)] = 741649,
  [SMALL_STATE(18731)] = 741663,
  [SMALL_STATE(18732)] = 741677,
  [SMALL_STATE(18733)] = 741691,
  [SMALL_STATE(18734)] = 741705,
  [SMALL_STATE(18735)] = 741719,
  [SMALL_STATE(18736)] = 741733,
  [SMALL_STATE(18737)] = 741747,
  [SMALL_STATE(18738)] = 741761,
  [SMALL_STATE(18739)] = 741775,
  [SMALL_STATE(18740)] = 741789,
  [SMALL_STATE(18741)] = 741803,
  [SMALL_STATE(18742)] = 741817,
  [SMALL_STATE(18743)] = 741831,
  [SMALL_STATE(18744)] = 741845,
  [SMALL_STATE(18745)] = 741859,
  [SMALL_STATE(18746)] = 741873,
  [SMALL_STATE(18747)] = 741887,
  [SMALL_STATE(18748)] = 741901,
  [SMALL_STATE(18749)] = 741915,
  [SMALL_STATE(18750)] = 741929,
  [SMALL_STATE(18751)] = 741943,
  [SMALL_STATE(18752)] = 741957,
  [SMALL_STATE(18753)] = 741971,
  [SMALL_STATE(18754)] = 741985,
  [SMALL_STATE(18755)] = 741999,
  [SMALL_STATE(18756)] = 742013,
  [SMALL_STATE(18757)] = 742027,
  [SMALL_STATE(18758)] = 742041,
  [SMALL_STATE(18759)] = 742055,
  [SMALL_STATE(18760)] = 742069,
  [SMALL_STATE(18761)] = 742083,
  [SMALL_STATE(18762)] = 742097,
  [SMALL_STATE(18763)] = 742111,
  [SMALL_STATE(18764)] = 742125,
  [SMALL_STATE(18765)] = 742139,
  [SMALL_STATE(18766)] = 742153,
  [SMALL_STATE(18767)] = 742167,
  [SMALL_STATE(18768)] = 742181,
  [SMALL_STATE(18769)] = 742195,
  [SMALL_STATE(18770)] = 742209,
  [SMALL_STATE(18771)] = 742223,
  [SMALL_STATE(18772)] = 742237,
  [SMALL_STATE(18773)] = 742251,
  [SMALL_STATE(18774)] = 742265,
  [SMALL_STATE(18775)] = 742279,
  [SMALL_STATE(18776)] = 742293,
  [SMALL_STATE(18777)] = 742307,
  [SMALL_STATE(18778)] = 742321,
  [SMALL_STATE(18779)] = 742335,
  [SMALL_STATE(18780)] = 742349,
  [SMALL_STATE(18781)] = 742363,
  [SMALL_STATE(18782)] = 742377,
  [SMALL_STATE(18783)] = 742391,
  [SMALL_STATE(18784)] = 742405,
  [SMALL_STATE(18785)] = 742419,
  [SMALL_STATE(18786)] = 742433,
  [SMALL_STATE(18787)] = 742447,
  [SMALL_STATE(18788)] = 742461,
  [SMALL_STATE(18789)] = 742475,
  [SMALL_STATE(18790)] = 742489,
  [SMALL_STATE(18791)] = 742503,
  [SMALL_STATE(18792)] = 742517,
  [SMALL_STATE(18793)] = 742531,
  [SMALL_STATE(18794)] = 742545,
  [SMALL_STATE(18795)] = 742559,
  [SMALL_STATE(18796)] = 742573,
  [SMALL_STATE(18797)] = 742587,
  [SMALL_STATE(18798)] = 742601,
  [SMALL_STATE(18799)] = 742615,
  [SMALL_STATE(18800)] = 742629,
  [SMALL_STATE(18801)] = 742643,
  [SMALL_STATE(18802)] = 742657,
  [SMALL_STATE(18803)] = 742671,
  [SMALL_STATE(18804)] = 742685,
  [SMALL_STATE(18805)] = 742699,
  [SMALL_STATE(18806)] = 742713,
  [SMALL_STATE(18807)] = 742727,
  [SMALL_STATE(18808)] = 742741,
  [SMALL_STATE(18809)] = 742755,
  [SMALL_STATE(18810)] = 742769,
  [SMALL_STATE(18811)] = 742783,
  [SMALL_STATE(18812)] = 742797,
  [SMALL_STATE(18813)] = 742811,
  [SMALL_STATE(18814)] = 742825,
  [SMALL_STATE(18815)] = 742839,
  [SMALL_STATE(18816)] = 742853,
  [SMALL_STATE(18817)] = 742867,
  [SMALL_STATE(18818)] = 742881,
  [SMALL_STATE(18819)] = 742895,
  [SMALL_STATE(18820)] = 742909,
  [SMALL_STATE(18821)] = 742923,
  [SMALL_STATE(18822)] = 742937,
  [SMALL_STATE(18823)] = 742951,
  [SMALL_STATE(18824)] = 742965,
  [SMALL_STATE(18825)] = 742979,
  [SMALL_STATE(18826)] = 742993,
  [SMALL_STATE(18827)] = 743007,
  [SMALL_STATE(18828)] = 743021,
  [SMALL_STATE(18829)] = 743035,
  [SMALL_STATE(18830)] = 743049,
  [SMALL_STATE(18831)] = 743063,
  [SMALL_STATE(18832)] = 743077,
  [SMALL_STATE(18833)] = 743091,
  [SMALL_STATE(18834)] = 743105,
  [SMALL_STATE(18835)] = 743119,
  [SMALL_STATE(18836)] = 743133,
  [SMALL_STATE(18837)] = 743147,
  [SMALL_STATE(18838)] = 743161,
  [SMALL_STATE(18839)] = 743175,
  [SMALL_STATE(18840)] = 743189,
  [SMALL_STATE(18841)] = 743203,
  [SMALL_STATE(18842)] = 743217,
  [SMALL_STATE(18843)] = 743231,
  [SMALL_STATE(18844)] = 743245,
  [SMALL_STATE(18845)] = 743259,
  [SMALL_STATE(18846)] = 743273,
  [SMALL_STATE(18847)] = 743287,
  [SMALL_STATE(18848)] = 743301,
  [SMALL_STATE(18849)] = 743315,
  [SMALL_STATE(18850)] = 743329,
  [SMALL_STATE(18851)] = 743343,
  [SMALL_STATE(18852)] = 743357,
  [SMALL_STATE(18853)] = 743371,
  [SMALL_STATE(18854)] = 743385,
  [SMALL_STATE(18855)] = 743399,
  [SMALL_STATE(18856)] = 743413,
  [SMALL_STATE(18857)] = 743427,
  [SMALL_STATE(18858)] = 743441,
  [SMALL_STATE(18859)] = 743455,
  [SMALL_STATE(18860)] = 743469,
  [SMALL_STATE(18861)] = 743483,
  [SMALL_STATE(18862)] = 743497,
  [SMALL_STATE(18863)] = 743511,
  [SMALL_STATE(18864)] = 743525,
  [SMALL_STATE(18865)] = 743539,
  [SMALL_STATE(18866)] = 743553,
  [SMALL_STATE(18867)] = 743567,
  [SMALL_STATE(18868)] = 743581,
  [SMALL_STATE(18869)] = 743595,
  [SMALL_STATE(18870)] = 743609,
  [SMALL_STATE(18871)] = 743623,
  [SMALL_STATE(18872)] = 743637,
  [SMALL_STATE(18873)] = 743651,
  [SMALL_STATE(18874)] = 743665,
  [SMALL_STATE(18875)] = 743679,
  [SMALL_STATE(18876)] = 743693,
  [SMALL_STATE(18877)] = 743707,
  [SMALL_STATE(18878)] = 743721,
  [SMALL_STATE(18879)] = 743735,
  [SMALL_STATE(18880)] = 743749,
  [SMALL_STATE(18881)] = 743763,
  [SMALL_STATE(18882)] = 743777,
  [SMALL_STATE(18883)] = 743791,
  [SMALL_STATE(18884)] = 743805,
  [SMALL_STATE(18885)] = 743819,
  [SMALL_STATE(18886)] = 743833,
  [SMALL_STATE(18887)] = 743847,
  [SMALL_STATE(18888)] = 743861,
  [SMALL_STATE(18889)] = 743875,
  [SMALL_STATE(18890)] = 743889,
  [SMALL_STATE(18891)] = 743903,
  [SMALL_STATE(18892)] = 743917,
  [SMALL_STATE(18893)] = 743931,
  [SMALL_STATE(18894)] = 743945,
  [SMALL_STATE(18895)] = 743959,
  [SMALL_STATE(18896)] = 743973,
  [SMALL_STATE(18897)] = 743987,
  [SMALL_STATE(18898)] = 744001,
  [SMALL_STATE(18899)] = 744015,
  [SMALL_STATE(18900)] = 744029,
  [SMALL_STATE(18901)] = 744043,
  [SMALL_STATE(18902)] = 744057,
  [SMALL_STATE(18903)] = 744071,
  [SMALL_STATE(18904)] = 744085,
  [SMALL_STATE(18905)] = 744099,
  [SMALL_STATE(18906)] = 744113,
  [SMALL_STATE(18907)] = 744127,
  [SMALL_STATE(18908)] = 744141,
  [SMALL_STATE(18909)] = 744155,
  [SMALL_STATE(18910)] = 744169,
  [SMALL_STATE(18911)] = 744183,
  [SMALL_STATE(18912)] = 744197,
  [SMALL_STATE(18913)] = 744211,
  [SMALL_STATE(18914)] = 744225,
  [SMALL_STATE(18915)] = 744239,
  [SMALL_STATE(18916)] = 744253,
  [SMALL_STATE(18917)] = 744267,
  [SMALL_STATE(18918)] = 744281,
  [SMALL_STATE(18919)] = 744295,
  [SMALL_STATE(18920)] = 744309,
  [SMALL_STATE(18921)] = 744323,
  [SMALL_STATE(18922)] = 744337,
  [SMALL_STATE(18923)] = 744351,
  [SMALL_STATE(18924)] = 744365,
  [SMALL_STATE(18925)] = 744379,
  [SMALL_STATE(18926)] = 744393,
  [SMALL_STATE(18927)] = 744407,
  [SMALL_STATE(18928)] = 744421,
  [SMALL_STATE(18929)] = 744435,
  [SMALL_STATE(18930)] = 744449,
  [SMALL_STATE(18931)] = 744463,
  [SMALL_STATE(18932)] = 744477,
  [SMALL_STATE(18933)] = 744491,
  [SMALL_STATE(18934)] = 744505,
  [SMALL_STATE(18935)] = 744519,
  [SMALL_STATE(18936)] = 744533,
  [SMALL_STATE(18937)] = 744547,
  [SMALL_STATE(18938)] = 744561,
  [SMALL_STATE(18939)] = 744575,
  [SMALL_STATE(18940)] = 744589,
  [SMALL_STATE(18941)] = 744603,
  [SMALL_STATE(18942)] = 744617,
  [SMALL_STATE(18943)] = 744631,
  [SMALL_STATE(18944)] = 744645,
  [SMALL_STATE(18945)] = 744659,
  [SMALL_STATE(18946)] = 744673,
  [SMALL_STATE(18947)] = 744687,
  [SMALL_STATE(18948)] = 744701,
  [SMALL_STATE(18949)] = 744715,
  [SMALL_STATE(18950)] = 744729,
  [SMALL_STATE(18951)] = 744743,
  [SMALL_STATE(18952)] = 744757,
  [SMALL_STATE(18953)] = 744771,
  [SMALL_STATE(18954)] = 744785,
  [SMALL_STATE(18955)] = 744799,
  [SMALL_STATE(18956)] = 744813,
  [SMALL_STATE(18957)] = 744827,
  [SMALL_STATE(18958)] = 744841,
  [SMALL_STATE(18959)] = 744855,
  [SMALL_STATE(18960)] = 744869,
  [SMALL_STATE(18961)] = 744883,
  [SMALL_STATE(18962)] = 744897,
  [SMALL_STATE(18963)] = 744911,
  [SMALL_STATE(18964)] = 744925,
  [SMALL_STATE(18965)] = 744939,
  [SMALL_STATE(18966)] = 744953,
  [SMALL_STATE(18967)] = 744967,
  [SMALL_STATE(18968)] = 744981,
  [SMALL_STATE(18969)] = 744995,
  [SMALL_STATE(18970)] = 745009,
  [SMALL_STATE(18971)] = 745023,
  [SMALL_STATE(18972)] = 745037,
  [SMALL_STATE(18973)] = 745051,
  [SMALL_STATE(18974)] = 745065,
  [SMALL_STATE(18975)] = 745079,
  [SMALL_STATE(18976)] = 745093,
  [SMALL_STATE(18977)] = 745107,
  [SMALL_STATE(18978)] = 745121,
  [SMALL_STATE(18979)] = 745135,
  [SMALL_STATE(18980)] = 745149,
  [SMALL_STATE(18981)] = 745163,
  [SMALL_STATE(18982)] = 745177,
  [SMALL_STATE(18983)] = 745191,
  [SMALL_STATE(18984)] = 745205,
  [SMALL_STATE(18985)] = 745219,
  [SMALL_STATE(18986)] = 745233,
  [SMALL_STATE(18987)] = 745247,
  [SMALL_STATE(18988)] = 745261,
  [SMALL_STATE(18989)] = 745275,
  [SMALL_STATE(18990)] = 745289,
  [SMALL_STATE(18991)] = 745303,
  [SMALL_STATE(18992)] = 745317,
  [SMALL_STATE(18993)] = 745331,
  [SMALL_STATE(18994)] = 745345,
  [SMALL_STATE(18995)] = 745359,
  [SMALL_STATE(18996)] = 745373,
  [SMALL_STATE(18997)] = 745387,
  [SMALL_STATE(18998)] = 745401,
  [SMALL_STATE(18999)] = 745415,
  [SMALL_STATE(19000)] = 745429,
  [SMALL_STATE(19001)] = 745443,
  [SMALL_STATE(19002)] = 745457,
  [SMALL_STATE(19003)] = 745471,
  [SMALL_STATE(19004)] = 745485,
  [SMALL_STATE(19005)] = 745499,
  [SMALL_STATE(19006)] = 745513,
  [SMALL_STATE(19007)] = 745527,
  [SMALL_STATE(19008)] = 745541,
  [SMALL_STATE(19009)] = 745555,
  [SMALL_STATE(19010)] = 745569,
  [SMALL_STATE(19011)] = 745583,
  [SMALL_STATE(19012)] = 745597,
  [SMALL_STATE(19013)] = 745611,
  [SMALL_STATE(19014)] = 745625,
  [SMALL_STATE(19015)] = 745639,
  [SMALL_STATE(19016)] = 745653,
  [SMALL_STATE(19017)] = 745667,
  [SMALL_STATE(19018)] = 745681,
  [SMALL_STATE(19019)] = 745695,
  [SMALL_STATE(19020)] = 745709,
  [SMALL_STATE(19021)] = 745723,
  [SMALL_STATE(19022)] = 745737,
  [SMALL_STATE(19023)] = 745751,
  [SMALL_STATE(19024)] = 745765,
  [SMALL_STATE(19025)] = 745779,
  [SMALL_STATE(19026)] = 745793,
  [SMALL_STATE(19027)] = 745807,
  [SMALL_STATE(19028)] = 745821,
  [SMALL_STATE(19029)] = 745835,
  [SMALL_STATE(19030)] = 745849,
  [SMALL_STATE(19031)] = 745863,
  [SMALL_STATE(19032)] = 745877,
  [SMALL_STATE(19033)] = 745891,
  [SMALL_STATE(19034)] = 745905,
  [SMALL_STATE(19035)] = 745919,
  [SMALL_STATE(19036)] = 745933,
  [SMALL_STATE(19037)] = 745947,
  [SMALL_STATE(19038)] = 745961,
  [SMALL_STATE(19039)] = 745975,
  [SMALL_STATE(19040)] = 745989,
  [SMALL_STATE(19041)] = 746003,
  [SMALL_STATE(19042)] = 746017,
  [SMALL_STATE(19043)] = 746031,
  [SMALL_STATE(19044)] = 746045,
  [SMALL_STATE(19045)] = 746059,
  [SMALL_STATE(19046)] = 746073,
  [SMALL_STATE(19047)] = 746087,
  [SMALL_STATE(19048)] = 746101,
  [SMALL_STATE(19049)] = 746115,
  [SMALL_STATE(19050)] = 746129,
  [SMALL_STATE(19051)] = 746143,
  [SMALL_STATE(19052)] = 746157,
  [SMALL_STATE(19053)] = 746171,
  [SMALL_STATE(19054)] = 746185,
  [SMALL_STATE(19055)] = 746199,
  [SMALL_STATE(19056)] = 746213,
  [SMALL_STATE(19057)] = 746227,
  [SMALL_STATE(19058)] = 746241,
  [SMALL_STATE(19059)] = 746255,
  [SMALL_STATE(19060)] = 746269,
  [SMALL_STATE(19061)] = 746283,
  [SMALL_STATE(19062)] = 746297,
  [SMALL_STATE(19063)] = 746311,
  [SMALL_STATE(19064)] = 746325,
  [SMALL_STATE(19065)] = 746339,
  [SMALL_STATE(19066)] = 746353,
  [SMALL_STATE(19067)] = 746367,
  [SMALL_STATE(19068)] = 746381,
  [SMALL_STATE(19069)] = 746395,
  [SMALL_STATE(19070)] = 746409,
  [SMALL_STATE(19071)] = 746423,
  [SMALL_STATE(19072)] = 746437,
  [SMALL_STATE(19073)] = 746451,
  [SMALL_STATE(19074)] = 746465,
  [SMALL_STATE(19075)] = 746479,
  [SMALL_STATE(19076)] = 746493,
  [SMALL_STATE(19077)] = 746507,
  [SMALL_STATE(19078)] = 746521,
  [SMALL_STATE(19079)] = 746535,
  [SMALL_STATE(19080)] = 746549,
  [SMALL_STATE(19081)] = 746563,
  [SMALL_STATE(19082)] = 746577,
  [SMALL_STATE(19083)] = 746591,
  [SMALL_STATE(19084)] = 746605,
  [SMALL_STATE(19085)] = 746619,
  [SMALL_STATE(19086)] = 746633,
  [SMALL_STATE(19087)] = 746647,
  [SMALL_STATE(19088)] = 746661,
  [SMALL_STATE(19089)] = 746675,
  [SMALL_STATE(19090)] = 746689,
  [SMALL_STATE(19091)] = 746703,
  [SMALL_STATE(19092)] = 746717,
  [SMALL_STATE(19093)] = 746731,
  [SMALL_STATE(19094)] = 746745,
  [SMALL_STATE(19095)] = 746759,
  [SMALL_STATE(19096)] = 746773,
  [SMALL_STATE(19097)] = 746787,
  [SMALL_STATE(19098)] = 746801,
  [SMALL_STATE(19099)] = 746815,
  [SMALL_STATE(19100)] = 746829,
  [SMALL_STATE(19101)] = 746843,
  [SMALL_STATE(19102)] = 746857,
  [SMALL_STATE(19103)] = 746871,
  [SMALL_STATE(19104)] = 746885,
  [SMALL_STATE(19105)] = 746899,
  [SMALL_STATE(19106)] = 746913,
  [SMALL_STATE(19107)] = 746927,
  [SMALL_STATE(19108)] = 746941,
  [SMALL_STATE(19109)] = 746955,
  [SMALL_STATE(19110)] = 746969,
  [SMALL_STATE(19111)] = 746983,
  [SMALL_STATE(19112)] = 746997,
  [SMALL_STATE(19113)] = 747011,
  [SMALL_STATE(19114)] = 747025,
  [SMALL_STATE(19115)] = 747039,
  [SMALL_STATE(19116)] = 747053,
  [SMALL_STATE(19117)] = 747067,
  [SMALL_STATE(19118)] = 747081,
  [SMALL_STATE(19119)] = 747095,
  [SMALL_STATE(19120)] = 747109,
  [SMALL_STATE(19121)] = 747123,
  [SMALL_STATE(19122)] = 747137,
  [SMALL_STATE(19123)] = 747151,
  [SMALL_STATE(19124)] = 747165,
  [SMALL_STATE(19125)] = 747179,
  [SMALL_STATE(19126)] = 747193,
  [SMALL_STATE(19127)] = 747207,
  [SMALL_STATE(19128)] = 747221,
  [SMALL_STATE(19129)] = 747235,
  [SMALL_STATE(19130)] = 747249,
  [SMALL_STATE(19131)] = 747263,
  [SMALL_STATE(19132)] = 747277,
  [SMALL_STATE(19133)] = 747291,
  [SMALL_STATE(19134)] = 747305,
  [SMALL_STATE(19135)] = 747319,
  [SMALL_STATE(19136)] = 747333,
  [SMALL_STATE(19137)] = 747347,
  [SMALL_STATE(19138)] = 747361,
  [SMALL_STATE(19139)] = 747375,
  [SMALL_STATE(19140)] = 747389,
  [SMALL_STATE(19141)] = 747403,
  [SMALL_STATE(19142)] = 747417,
  [SMALL_STATE(19143)] = 747431,
  [SMALL_STATE(19144)] = 747445,
  [SMALL_STATE(19145)] = 747459,
  [SMALL_STATE(19146)] = 747473,
  [SMALL_STATE(19147)] = 747487,
  [SMALL_STATE(19148)] = 747501,
  [SMALL_STATE(19149)] = 747515,
  [SMALL_STATE(19150)] = 747529,
  [SMALL_STATE(19151)] = 747543,
  [SMALL_STATE(19152)] = 747557,
  [SMALL_STATE(19153)] = 747571,
  [SMALL_STATE(19154)] = 747585,
  [SMALL_STATE(19155)] = 747599,
  [SMALL_STATE(19156)] = 747613,
  [SMALL_STATE(19157)] = 747627,
  [SMALL_STATE(19158)] = 747641,
  [SMALL_STATE(19159)] = 747655,
  [SMALL_STATE(19160)] = 747669,
  [SMALL_STATE(19161)] = 747683,
  [SMALL_STATE(19162)] = 747697,
  [SMALL_STATE(19163)] = 747711,
  [SMALL_STATE(19164)] = 747725,
  [SMALL_STATE(19165)] = 747739,
  [SMALL_STATE(19166)] = 747753,
  [SMALL_STATE(19167)] = 747767,
  [SMALL_STATE(19168)] = 747781,
  [SMALL_STATE(19169)] = 747795,
  [SMALL_STATE(19170)] = 747809,
  [SMALL_STATE(19171)] = 747823,
  [SMALL_STATE(19172)] = 747837,
  [SMALL_STATE(19173)] = 747851,
  [SMALL_STATE(19174)] = 747865,
  [SMALL_STATE(19175)] = 747879,
  [SMALL_STATE(19176)] = 747893,
  [SMALL_STATE(19177)] = 747907,
  [SMALL_STATE(19178)] = 747921,
  [SMALL_STATE(19179)] = 747935,
  [SMALL_STATE(19180)] = 747949,
  [SMALL_STATE(19181)] = 747963,
  [SMALL_STATE(19182)] = 747977,
  [SMALL_STATE(19183)] = 747991,
  [SMALL_STATE(19184)] = 748005,
  [SMALL_STATE(19185)] = 748019,
  [SMALL_STATE(19186)] = 748033,
  [SMALL_STATE(19187)] = 748047,
  [SMALL_STATE(19188)] = 748061,
  [SMALL_STATE(19189)] = 748075,
  [SMALL_STATE(19190)] = 748089,
  [SMALL_STATE(19191)] = 748103,
  [SMALL_STATE(19192)] = 748117,
  [SMALL_STATE(19193)] = 748131,
  [SMALL_STATE(19194)] = 748145,
  [SMALL_STATE(19195)] = 748159,
  [SMALL_STATE(19196)] = 748173,
  [SMALL_STATE(19197)] = 748187,
  [SMALL_STATE(19198)] = 748201,
  [SMALL_STATE(19199)] = 748215,
  [SMALL_STATE(19200)] = 748229,
  [SMALL_STATE(19201)] = 748243,
  [SMALL_STATE(19202)] = 748257,
  [SMALL_STATE(19203)] = 748271,
  [SMALL_STATE(19204)] = 748285,
  [SMALL_STATE(19205)] = 748299,
  [SMALL_STATE(19206)] = 748313,
  [SMALL_STATE(19207)] = 748327,
  [SMALL_STATE(19208)] = 748341,
  [SMALL_STATE(19209)] = 748355,
  [SMALL_STATE(19210)] = 748369,
  [SMALL_STATE(19211)] = 748383,
  [SMALL_STATE(19212)] = 748397,
  [SMALL_STATE(19213)] = 748411,
  [SMALL_STATE(19214)] = 748425,
  [SMALL_STATE(19215)] = 748439,
  [SMALL_STATE(19216)] = 748453,
  [SMALL_STATE(19217)] = 748467,
  [SMALL_STATE(19218)] = 748481,
  [SMALL_STATE(19219)] = 748495,
  [SMALL_STATE(19220)] = 748509,
  [SMALL_STATE(19221)] = 748523,
  [SMALL_STATE(19222)] = 748537,
  [SMALL_STATE(19223)] = 748551,
  [SMALL_STATE(19224)] = 748565,
  [SMALL_STATE(19225)] = 748579,
  [SMALL_STATE(19226)] = 748593,
  [SMALL_STATE(19227)] = 748607,
  [SMALL_STATE(19228)] = 748621,
  [SMALL_STATE(19229)] = 748635,
  [SMALL_STATE(19230)] = 748649,
  [SMALL_STATE(19231)] = 748663,
  [SMALL_STATE(19232)] = 748677,
  [SMALL_STATE(19233)] = 748691,
  [SMALL_STATE(19234)] = 748705,
  [SMALL_STATE(19235)] = 748719,
  [SMALL_STATE(19236)] = 748733,
  [SMALL_STATE(19237)] = 748747,
  [SMALL_STATE(19238)] = 748761,
  [SMALL_STATE(19239)] = 748775,
  [SMALL_STATE(19240)] = 748789,
  [SMALL_STATE(19241)] = 748803,
  [SMALL_STATE(19242)] = 748817,
  [SMALL_STATE(19243)] = 748831,
  [SMALL_STATE(19244)] = 748845,
  [SMALL_STATE(19245)] = 748859,
  [SMALL_STATE(19246)] = 748873,
  [SMALL_STATE(19247)] = 748887,
  [SMALL_STATE(19248)] = 748901,
  [SMALL_STATE(19249)] = 748915,
  [SMALL_STATE(19250)] = 748929,
  [SMALL_STATE(19251)] = 748943,
  [SMALL_STATE(19252)] = 748957,
  [SMALL_STATE(19253)] = 748971,
  [SMALL_STATE(19254)] = 748985,
  [SMALL_STATE(19255)] = 748999,
  [SMALL_STATE(19256)] = 749013,
  [SMALL_STATE(19257)] = 749027,
  [SMALL_STATE(19258)] = 749041,
  [SMALL_STATE(19259)] = 749055,
  [SMALL_STATE(19260)] = 749069,
  [SMALL_STATE(19261)] = 749083,
  [SMALL_STATE(19262)] = 749097,
  [SMALL_STATE(19263)] = 749111,
  [SMALL_STATE(19264)] = 749125,
  [SMALL_STATE(19265)] = 749139,
  [SMALL_STATE(19266)] = 749153,
  [SMALL_STATE(19267)] = 749167,
  [SMALL_STATE(19268)] = 749181,
  [SMALL_STATE(19269)] = 749195,
  [SMALL_STATE(19270)] = 749209,
  [SMALL_STATE(19271)] = 749223,
  [SMALL_STATE(19272)] = 749237,
  [SMALL_STATE(19273)] = 749251,
  [SMALL_STATE(19274)] = 749265,
  [SMALL_STATE(19275)] = 749279,
  [SMALL_STATE(19276)] = 749293,
  [SMALL_STATE(19277)] = 749307,
  [SMALL_STATE(19278)] = 749321,
  [SMALL_STATE(19279)] = 749335,
  [SMALL_STATE(19280)] = 749349,
  [SMALL_STATE(19281)] = 749363,
  [SMALL_STATE(19282)] = 749377,
  [SMALL_STATE(19283)] = 749391,
  [SMALL_STATE(19284)] = 749405,
  [SMALL_STATE(19285)] = 749419,
  [SMALL_STATE(19286)] = 749433,
  [SMALL_STATE(19287)] = 749447,
  [SMALL_STATE(19288)] = 749461,
  [SMALL_STATE(19289)] = 749475,
  [SMALL_STATE(19290)] = 749489,
  [SMALL_STATE(19291)] = 749503,
  [SMALL_STATE(19292)] = 749517,
  [SMALL_STATE(19293)] = 749531,
  [SMALL_STATE(19294)] = 749545,
  [SMALL_STATE(19295)] = 749559,
  [SMALL_STATE(19296)] = 749573,
  [SMALL_STATE(19297)] = 749587,
  [SMALL_STATE(19298)] = 749601,
  [SMALL_STATE(19299)] = 749615,
  [SMALL_STATE(19300)] = 749629,
  [SMALL_STATE(19301)] = 749643,
  [SMALL_STATE(19302)] = 749657,
  [SMALL_STATE(19303)] = 749671,
  [SMALL_STATE(19304)] = 749685,
  [SMALL_STATE(19305)] = 749699,
  [SMALL_STATE(19306)] = 749713,
  [SMALL_STATE(19307)] = 749727,
  [SMALL_STATE(19308)] = 749741,
  [SMALL_STATE(19309)] = 749755,
  [SMALL_STATE(19310)] = 749769,
  [SMALL_STATE(19311)] = 749783,
  [SMALL_STATE(19312)] = 749797,
  [SMALL_STATE(19313)] = 749811,
  [SMALL_STATE(19314)] = 749825,
  [SMALL_STATE(19315)] = 749839,
  [SMALL_STATE(19316)] = 749853,
  [SMALL_STATE(19317)] = 749867,
  [SMALL_STATE(19318)] = 749881,
  [SMALL_STATE(19319)] = 749895,
  [SMALL_STATE(19320)] = 749909,
  [SMALL_STATE(19321)] = 749923,
  [SMALL_STATE(19322)] = 749937,
  [SMALL_STATE(19323)] = 749951,
  [SMALL_STATE(19324)] = 749965,
  [SMALL_STATE(19325)] = 749979,
  [SMALL_STATE(19326)] = 749993,
  [SMALL_STATE(19327)] = 750007,
  [SMALL_STATE(19328)] = 750021,
  [SMALL_STATE(19329)] = 750035,
  [SMALL_STATE(19330)] = 750049,
  [SMALL_STATE(19331)] = 750063,
  [SMALL_STATE(19332)] = 750077,
  [SMALL_STATE(19333)] = 750091,
  [SMALL_STATE(19334)] = 750105,
  [SMALL_STATE(19335)] = 750119,
  [SMALL_STATE(19336)] = 750133,
  [SMALL_STATE(19337)] = 750147,
  [SMALL_STATE(19338)] = 750161,
  [SMALL_STATE(19339)] = 750175,
  [SMALL_STATE(19340)] = 750189,
  [SMALL_STATE(19341)] = 750203,
  [SMALL_STATE(19342)] = 750217,
  [SMALL_STATE(19343)] = 750231,
  [SMALL_STATE(19344)] = 750245,
  [SMALL_STATE(19345)] = 750259,
  [SMALL_STATE(19346)] = 750273,
  [SMALL_STATE(19347)] = 750287,
  [SMALL_STATE(19348)] = 750301,
  [SMALL_STATE(19349)] = 750315,
  [SMALL_STATE(19350)] = 750329,
  [SMALL_STATE(19351)] = 750343,
  [SMALL_STATE(19352)] = 750357,
  [SMALL_STATE(19353)] = 750371,
  [SMALL_STATE(19354)] = 750385,
  [SMALL_STATE(19355)] = 750399,
  [SMALL_STATE(19356)] = 750413,
  [SMALL_STATE(19357)] = 750427,
  [SMALL_STATE(19358)] = 750441,
  [SMALL_STATE(19359)] = 750455,
  [SMALL_STATE(19360)] = 750469,
  [SMALL_STATE(19361)] = 750483,
  [SMALL_STATE(19362)] = 750497,
  [SMALL_STATE(19363)] = 750511,
  [SMALL_STATE(19364)] = 750525,
  [SMALL_STATE(19365)] = 750539,
  [SMALL_STATE(19366)] = 750553,
  [SMALL_STATE(19367)] = 750567,
  [SMALL_STATE(19368)] = 750581,
  [SMALL_STATE(19369)] = 750595,
  [SMALL_STATE(19370)] = 750609,
  [SMALL_STATE(19371)] = 750623,
  [SMALL_STATE(19372)] = 750637,
  [SMALL_STATE(19373)] = 750651,
  [SMALL_STATE(19374)] = 750665,
  [SMALL_STATE(19375)] = 750679,
  [SMALL_STATE(19376)] = 750693,
  [SMALL_STATE(19377)] = 750707,
  [SMALL_STATE(19378)] = 750721,
  [SMALL_STATE(19379)] = 750735,
  [SMALL_STATE(19380)] = 750749,
  [SMALL_STATE(19381)] = 750763,
  [SMALL_STATE(19382)] = 750777,
  [SMALL_STATE(19383)] = 750791,
  [SMALL_STATE(19384)] = 750805,
  [SMALL_STATE(19385)] = 750819,
  [SMALL_STATE(19386)] = 750833,
  [SMALL_STATE(19387)] = 750847,
  [SMALL_STATE(19388)] = 750861,
  [SMALL_STATE(19389)] = 750875,
  [SMALL_STATE(19390)] = 750889,
  [SMALL_STATE(19391)] = 750903,
  [SMALL_STATE(19392)] = 750917,
  [SMALL_STATE(19393)] = 750931,
  [SMALL_STATE(19394)] = 750945,
  [SMALL_STATE(19395)] = 750959,
  [SMALL_STATE(19396)] = 750973,
  [SMALL_STATE(19397)] = 750987,
  [SMALL_STATE(19398)] = 751001,
  [SMALL_STATE(19399)] = 751015,
  [SMALL_STATE(19400)] = 751029,
  [SMALL_STATE(19401)] = 751043,
  [SMALL_STATE(19402)] = 751057,
  [SMALL_STATE(19403)] = 751071,
  [SMALL_STATE(19404)] = 751085,
  [SMALL_STATE(19405)] = 751099,
  [SMALL_STATE(19406)] = 751113,
  [SMALL_STATE(19407)] = 751127,
  [SMALL_STATE(19408)] = 751141,
  [SMALL_STATE(19409)] = 751155,
  [SMALL_STATE(19410)] = 751169,
  [SMALL_STATE(19411)] = 751183,
  [SMALL_STATE(19412)] = 751197,
  [SMALL_STATE(19413)] = 751211,
  [SMALL_STATE(19414)] = 751225,
  [SMALL_STATE(19415)] = 751239,
  [SMALL_STATE(19416)] = 751253,
  [SMALL_STATE(19417)] = 751267,
  [SMALL_STATE(19418)] = 751281,
  [SMALL_STATE(19419)] = 751295,
  [SMALL_STATE(19420)] = 751309,
  [SMALL_STATE(19421)] = 751323,
  [SMALL_STATE(19422)] = 751337,
  [SMALL_STATE(19423)] = 751351,
  [SMALL_STATE(19424)] = 751365,
  [SMALL_STATE(19425)] = 751379,
  [SMALL_STATE(19426)] = 751393,
  [SMALL_STATE(19427)] = 751407,
  [SMALL_STATE(19428)] = 751421,
  [SMALL_STATE(19429)] = 751435,
  [SMALL_STATE(19430)] = 751449,
  [SMALL_STATE(19431)] = 751463,
  [SMALL_STATE(19432)] = 751477,
  [SMALL_STATE(19433)] = 751491,
  [SMALL_STATE(19434)] = 751505,
  [SMALL_STATE(19435)] = 751519,
  [SMALL_STATE(19436)] = 751533,
  [SMALL_STATE(19437)] = 751547,
  [SMALL_STATE(19438)] = 751561,
  [SMALL_STATE(19439)] = 751575,
  [SMALL_STATE(19440)] = 751589,
  [SMALL_STATE(19441)] = 751603,
  [SMALL_STATE(19442)] = 751617,
  [SMALL_STATE(19443)] = 751631,
  [SMALL_STATE(19444)] = 751645,
  [SMALL_STATE(19445)] = 751659,
  [SMALL_STATE(19446)] = 751673,
  [SMALL_STATE(19447)] = 751687,
  [SMALL_STATE(19448)] = 751701,
  [SMALL_STATE(19449)] = 751715,
  [SMALL_STATE(19450)] = 751729,
  [SMALL_STATE(19451)] = 751743,
  [SMALL_STATE(19452)] = 751757,
  [SMALL_STATE(19453)] = 751771,
  [SMALL_STATE(19454)] = 751785,
  [SMALL_STATE(19455)] = 751799,
  [SMALL_STATE(19456)] = 751813,
  [SMALL_STATE(19457)] = 751827,
  [SMALL_STATE(19458)] = 751841,
  [SMALL_STATE(19459)] = 751855,
  [SMALL_STATE(19460)] = 751869,
  [SMALL_STATE(19461)] = 751883,
  [SMALL_STATE(19462)] = 751897,
  [SMALL_STATE(19463)] = 751911,
  [SMALL_STATE(19464)] = 751925,
  [SMALL_STATE(19465)] = 751939,
  [SMALL_STATE(19466)] = 751953,
  [SMALL_STATE(19467)] = 751967,
  [SMALL_STATE(19468)] = 751981,
  [SMALL_STATE(19469)] = 751995,
  [SMALL_STATE(19470)] = 752009,
  [SMALL_STATE(19471)] = 752023,
  [SMALL_STATE(19472)] = 752037,
  [SMALL_STATE(19473)] = 752051,
  [SMALL_STATE(19474)] = 752065,
  [SMALL_STATE(19475)] = 752079,
  [SMALL_STATE(19476)] = 752093,
  [SMALL_STATE(19477)] = 752107,
  [SMALL_STATE(19478)] = 752121,
  [SMALL_STATE(19479)] = 752135,
  [SMALL_STATE(19480)] = 752149,
  [SMALL_STATE(19481)] = 752163,
  [SMALL_STATE(19482)] = 752177,
  [SMALL_STATE(19483)] = 752191,
  [SMALL_STATE(19484)] = 752205,
  [SMALL_STATE(19485)] = 752219,
  [SMALL_STATE(19486)] = 752233,
  [SMALL_STATE(19487)] = 752247,
  [SMALL_STATE(19488)] = 752261,
  [SMALL_STATE(19489)] = 752275,
  [SMALL_STATE(19490)] = 752289,
  [SMALL_STATE(19491)] = 752303,
  [SMALL_STATE(19492)] = 752317,
  [SMALL_STATE(19493)] = 752331,
  [SMALL_STATE(19494)] = 752345,
  [SMALL_STATE(19495)] = 752359,
  [SMALL_STATE(19496)] = 752373,
  [SMALL_STATE(19497)] = 752387,
  [SMALL_STATE(19498)] = 752401,
  [SMALL_STATE(19499)] = 752415,
  [SMALL_STATE(19500)] = 752429,
  [SMALL_STATE(19501)] = 752443,
  [SMALL_STATE(19502)] = 752457,
  [SMALL_STATE(19503)] = 752471,
  [SMALL_STATE(19504)] = 752485,
  [SMALL_STATE(19505)] = 752499,
  [SMALL_STATE(19506)] = 752513,
  [SMALL_STATE(19507)] = 752527,
  [SMALL_STATE(19508)] = 752541,
  [SMALL_STATE(19509)] = 752555,
  [SMALL_STATE(19510)] = 752569,
  [SMALL_STATE(19511)] = 752583,
  [SMALL_STATE(19512)] = 752597,
  [SMALL_STATE(19513)] = 752611,
  [SMALL_STATE(19514)] = 752625,
  [SMALL_STATE(19515)] = 752639,
  [SMALL_STATE(19516)] = 752653,
  [SMALL_STATE(19517)] = 752667,
  [SMALL_STATE(19518)] = 752681,
  [SMALL_STATE(19519)] = 752695,
  [SMALL_STATE(19520)] = 752709,
  [SMALL_STATE(19521)] = 752723,
  [SMALL_STATE(19522)] = 752737,
  [SMALL_STATE(19523)] = 752751,
  [SMALL_STATE(19524)] = 752765,
  [SMALL_STATE(19525)] = 752779,
  [SMALL_STATE(19526)] = 752793,
  [SMALL_STATE(19527)] = 752807,
  [SMALL_STATE(19528)] = 752821,
  [SMALL_STATE(19529)] = 752835,
  [SMALL_STATE(19530)] = 752849,
  [SMALL_STATE(19531)] = 752863,
  [SMALL_STATE(19532)] = 752877,
  [SMALL_STATE(19533)] = 752891,
  [SMALL_STATE(19534)] = 752905,
  [SMALL_STATE(19535)] = 752919,
  [SMALL_STATE(19536)] = 752933,
  [SMALL_STATE(19537)] = 752947,
  [SMALL_STATE(19538)] = 752961,
  [SMALL_STATE(19539)] = 752975,
  [SMALL_STATE(19540)] = 752989,
  [SMALL_STATE(19541)] = 753003,
  [SMALL_STATE(19542)] = 753017,
  [SMALL_STATE(19543)] = 753031,
  [SMALL_STATE(19544)] = 753045,
  [SMALL_STATE(19545)] = 753059,
  [SMALL_STATE(19546)] = 753073,
  [SMALL_STATE(19547)] = 753087,
  [SMALL_STATE(19548)] = 753101,
  [SMALL_STATE(19549)] = 753115,
  [SMALL_STATE(19550)] = 753129,
  [SMALL_STATE(19551)] = 753143,
  [SMALL_STATE(19552)] = 753157,
  [SMALL_STATE(19553)] = 753171,
  [SMALL_STATE(19554)] = 753185,
  [SMALL_STATE(19555)] = 753199,
  [SMALL_STATE(19556)] = 753213,
  [SMALL_STATE(19557)] = 753227,
  [SMALL_STATE(19558)] = 753241,
  [SMALL_STATE(19559)] = 753255,
  [SMALL_STATE(19560)] = 753269,
  [SMALL_STATE(19561)] = 753283,
  [SMALL_STATE(19562)] = 753297,
  [SMALL_STATE(19563)] = 753311,
  [SMALL_STATE(19564)] = 753325,
  [SMALL_STATE(19565)] = 753339,
  [SMALL_STATE(19566)] = 753353,
  [SMALL_STATE(19567)] = 753367,
  [SMALL_STATE(19568)] = 753381,
  [SMALL_STATE(19569)] = 753395,
  [SMALL_STATE(19570)] = 753409,
  [SMALL_STATE(19571)] = 753423,
  [SMALL_STATE(19572)] = 753437,
  [SMALL_STATE(19573)] = 753451,
  [SMALL_STATE(19574)] = 753465,
  [SMALL_STATE(19575)] = 753479,
  [SMALL_STATE(19576)] = 753493,
  [SMALL_STATE(19577)] = 753507,
  [SMALL_STATE(19578)] = 753521,
  [SMALL_STATE(19579)] = 753535,
  [SMALL_STATE(19580)] = 753549,
  [SMALL_STATE(19581)] = 753563,
  [SMALL_STATE(19582)] = 753577,
  [SMALL_STATE(19583)] = 753591,
  [SMALL_STATE(19584)] = 753605,
  [SMALL_STATE(19585)] = 753619,
  [SMALL_STATE(19586)] = 753633,
  [SMALL_STATE(19587)] = 753647,
  [SMALL_STATE(19588)] = 753661,
  [SMALL_STATE(19589)] = 753675,
  [SMALL_STATE(19590)] = 753689,
  [SMALL_STATE(19591)] = 753703,
  [SMALL_STATE(19592)] = 753717,
  [SMALL_STATE(19593)] = 753731,
  [SMALL_STATE(19594)] = 753745,
  [SMALL_STATE(19595)] = 753759,
  [SMALL_STATE(19596)] = 753773,
  [SMALL_STATE(19597)] = 753787,
  [SMALL_STATE(19598)] = 753801,
  [SMALL_STATE(19599)] = 753815,
  [SMALL_STATE(19600)] = 753829,
  [SMALL_STATE(19601)] = 753843,
  [SMALL_STATE(19602)] = 753857,
  [SMALL_STATE(19603)] = 753871,
  [SMALL_STATE(19604)] = 753885,
  [SMALL_STATE(19605)] = 753899,
  [SMALL_STATE(19606)] = 753913,
  [SMALL_STATE(19607)] = 753927,
  [SMALL_STATE(19608)] = 753941,
  [SMALL_STATE(19609)] = 753955,
  [SMALL_STATE(19610)] = 753969,
  [SMALL_STATE(19611)] = 753983,
  [SMALL_STATE(19612)] = 753997,
  [SMALL_STATE(19613)] = 754011,
  [SMALL_STATE(19614)] = 754025,
  [SMALL_STATE(19615)] = 754039,
  [SMALL_STATE(19616)] = 754053,
  [SMALL_STATE(19617)] = 754067,
  [SMALL_STATE(19618)] = 754081,
  [SMALL_STATE(19619)] = 754095,
  [SMALL_STATE(19620)] = 754109,
  [SMALL_STATE(19621)] = 754123,
  [SMALL_STATE(19622)] = 754137,
  [SMALL_STATE(19623)] = 754151,
  [SMALL_STATE(19624)] = 754165,
  [SMALL_STATE(19625)] = 754179,
  [SMALL_STATE(19626)] = 754193,
  [SMALL_STATE(19627)] = 754207,
  [SMALL_STATE(19628)] = 754221,
  [SMALL_STATE(19629)] = 754235,
  [SMALL_STATE(19630)] = 754249,
  [SMALL_STATE(19631)] = 754263,
  [SMALL_STATE(19632)] = 754277,
  [SMALL_STATE(19633)] = 754291,
  [SMALL_STATE(19634)] = 754305,
  [SMALL_STATE(19635)] = 754319,
  [SMALL_STATE(19636)] = 754333,
  [SMALL_STATE(19637)] = 754347,
  [SMALL_STATE(19638)] = 754361,
  [SMALL_STATE(19639)] = 754375,
  [SMALL_STATE(19640)] = 754389,
  [SMALL_STATE(19641)] = 754403,
  [SMALL_STATE(19642)] = 754417,
  [SMALL_STATE(19643)] = 754431,
  [SMALL_STATE(19644)] = 754445,
  [SMALL_STATE(19645)] = 754459,
  [SMALL_STATE(19646)] = 754473,
  [SMALL_STATE(19647)] = 754487,
  [SMALL_STATE(19648)] = 754501,
  [SMALL_STATE(19649)] = 754515,
  [SMALL_STATE(19650)] = 754529,
  [SMALL_STATE(19651)] = 754543,
  [SMALL_STATE(19652)] = 754557,
  [SMALL_STATE(19653)] = 754571,
  [SMALL_STATE(19654)] = 754585,
  [SMALL_STATE(19655)] = 754599,
  [SMALL_STATE(19656)] = 754613,
  [SMALL_STATE(19657)] = 754627,
  [SMALL_STATE(19658)] = 754641,
  [SMALL_STATE(19659)] = 754655,
  [SMALL_STATE(19660)] = 754669,
  [SMALL_STATE(19661)] = 754683,
  [SMALL_STATE(19662)] = 754697,
  [SMALL_STATE(19663)] = 754711,
  [SMALL_STATE(19664)] = 754725,
  [SMALL_STATE(19665)] = 754739,
  [SMALL_STATE(19666)] = 754753,
  [SMALL_STATE(19667)] = 754767,
  [SMALL_STATE(19668)] = 754781,
  [SMALL_STATE(19669)] = 754795,
  [SMALL_STATE(19670)] = 754809,
  [SMALL_STATE(19671)] = 754823,
  [SMALL_STATE(19672)] = 754837,
  [SMALL_STATE(19673)] = 754851,
  [SMALL_STATE(19674)] = 754865,
  [SMALL_STATE(19675)] = 754879,
  [SMALL_STATE(19676)] = 754893,
  [SMALL_STATE(19677)] = 754907,
  [SMALL_STATE(19678)] = 754921,
  [SMALL_STATE(19679)] = 754935,
  [SMALL_STATE(19680)] = 754949,
  [SMALL_STATE(19681)] = 754963,
  [SMALL_STATE(19682)] = 754977,
  [SMALL_STATE(19683)] = 754991,
  [SMALL_STATE(19684)] = 755005,
  [SMALL_STATE(19685)] = 755019,
  [SMALL_STATE(19686)] = 755033,
  [SMALL_STATE(19687)] = 755047,
  [SMALL_STATE(19688)] = 755061,
  [SMALL_STATE(19689)] = 755075,
  [SMALL_STATE(19690)] = 755089,
  [SMALL_STATE(19691)] = 755103,
  [SMALL_STATE(19692)] = 755117,
  [SMALL_STATE(19693)] = 755131,
  [SMALL_STATE(19694)] = 755145,
  [SMALL_STATE(19695)] = 755159,
  [SMALL_STATE(19696)] = 755173,
  [SMALL_STATE(19697)] = 755187,
  [SMALL_STATE(19698)] = 755201,
  [SMALL_STATE(19699)] = 755215,
  [SMALL_STATE(19700)] = 755229,
  [SMALL_STATE(19701)] = 755243,
  [SMALL_STATE(19702)] = 755257,
  [SMALL_STATE(19703)] = 755271,
  [SMALL_STATE(19704)] = 755285,
  [SMALL_STATE(19705)] = 755299,
  [SMALL_STATE(19706)] = 755313,
  [SMALL_STATE(19707)] = 755327,
  [SMALL_STATE(19708)] = 755341,
  [SMALL_STATE(19709)] = 755355,
  [SMALL_STATE(19710)] = 755369,
  [SMALL_STATE(19711)] = 755383,
  [SMALL_STATE(19712)] = 755397,
  [SMALL_STATE(19713)] = 755411,
  [SMALL_STATE(19714)] = 755425,
  [SMALL_STATE(19715)] = 755439,
  [SMALL_STATE(19716)] = 755453,
  [SMALL_STATE(19717)] = 755467,
  [SMALL_STATE(19718)] = 755481,
  [SMALL_STATE(19719)] = 755495,
  [SMALL_STATE(19720)] = 755509,
  [SMALL_STATE(19721)] = 755523,
  [SMALL_STATE(19722)] = 755537,
  [SMALL_STATE(19723)] = 755551,
  [SMALL_STATE(19724)] = 755565,
  [SMALL_STATE(19725)] = 755579,
  [SMALL_STATE(19726)] = 755593,
  [SMALL_STATE(19727)] = 755607,
  [SMALL_STATE(19728)] = 755621,
  [SMALL_STATE(19729)] = 755635,
  [SMALL_STATE(19730)] = 755649,
  [SMALL_STATE(19731)] = 755663,
  [SMALL_STATE(19732)] = 755677,
  [SMALL_STATE(19733)] = 755691,
  [SMALL_STATE(19734)] = 755705,
  [SMALL_STATE(19735)] = 755719,
  [SMALL_STATE(19736)] = 755733,
  [SMALL_STATE(19737)] = 755747,
  [SMALL_STATE(19738)] = 755761,
  [SMALL_STATE(19739)] = 755775,
  [SMALL_STATE(19740)] = 755789,
  [SMALL_STATE(19741)] = 755803,
  [SMALL_STATE(19742)] = 755817,
  [SMALL_STATE(19743)] = 755831,
  [SMALL_STATE(19744)] = 755845,
  [SMALL_STATE(19745)] = 755859,
  [SMALL_STATE(19746)] = 755873,
  [SMALL_STATE(19747)] = 755887,
  [SMALL_STATE(19748)] = 755901,
  [SMALL_STATE(19749)] = 755915,
  [SMALL_STATE(19750)] = 755929,
  [SMALL_STATE(19751)] = 755943,
  [SMALL_STATE(19752)] = 755957,
  [SMALL_STATE(19753)] = 755971,
  [SMALL_STATE(19754)] = 755985,
  [SMALL_STATE(19755)] = 755999,
  [SMALL_STATE(19756)] = 756013,
  [SMALL_STATE(19757)] = 756027,
  [SMALL_STATE(19758)] = 756041,
  [SMALL_STATE(19759)] = 756055,
  [SMALL_STATE(19760)] = 756069,
  [SMALL_STATE(19761)] = 756083,
  [SMALL_STATE(19762)] = 756097,
  [SMALL_STATE(19763)] = 756111,
  [SMALL_STATE(19764)] = 756125,
  [SMALL_STATE(19765)] = 756139,
  [SMALL_STATE(19766)] = 756153,
  [SMALL_STATE(19767)] = 756167,
  [SMALL_STATE(19768)] = 756181,
  [SMALL_STATE(19769)] = 756195,
  [SMALL_STATE(19770)] = 756209,
  [SMALL_STATE(19771)] = 756223,
  [SMALL_STATE(19772)] = 756237,
  [SMALL_STATE(19773)] = 756251,
  [SMALL_STATE(19774)] = 756265,
  [SMALL_STATE(19775)] = 756279,
  [SMALL_STATE(19776)] = 756293,
  [SMALL_STATE(19777)] = 756307,
  [SMALL_STATE(19778)] = 756321,
  [SMALL_STATE(19779)] = 756335,
  [SMALL_STATE(19780)] = 756349,
  [SMALL_STATE(19781)] = 756363,
  [SMALL_STATE(19782)] = 756377,
  [SMALL_STATE(19783)] = 756391,
  [SMALL_STATE(19784)] = 756405,
  [SMALL_STATE(19785)] = 756419,
  [SMALL_STATE(19786)] = 756433,
  [SMALL_STATE(19787)] = 756447,
  [SMALL_STATE(19788)] = 756461,
  [SMALL_STATE(19789)] = 756475,
  [SMALL_STATE(19790)] = 756489,
  [SMALL_STATE(19791)] = 756503,
  [SMALL_STATE(19792)] = 756517,
  [SMALL_STATE(19793)] = 756531,
  [SMALL_STATE(19794)] = 756545,
  [SMALL_STATE(19795)] = 756559,
  [SMALL_STATE(19796)] = 756573,
  [SMALL_STATE(19797)] = 756587,
  [SMALL_STATE(19798)] = 756601,
  [SMALL_STATE(19799)] = 756615,
  [SMALL_STATE(19800)] = 756629,
  [SMALL_STATE(19801)] = 756643,
  [SMALL_STATE(19802)] = 756657,
  [SMALL_STATE(19803)] = 756671,
  [SMALL_STATE(19804)] = 756685,
  [SMALL_STATE(19805)] = 756699,
  [SMALL_STATE(19806)] = 756713,
  [SMALL_STATE(19807)] = 756727,
  [SMALL_STATE(19808)] = 756741,
  [SMALL_STATE(19809)] = 756755,
  [SMALL_STATE(19810)] = 756769,
  [SMALL_STATE(19811)] = 756783,
  [SMALL_STATE(19812)] = 756797,
  [SMALL_STATE(19813)] = 756811,
  [SMALL_STATE(19814)] = 756825,
  [SMALL_STATE(19815)] = 756839,
  [SMALL_STATE(19816)] = 756853,
  [SMALL_STATE(19817)] = 756867,
  [SMALL_STATE(19818)] = 756881,
  [SMALL_STATE(19819)] = 756895,
  [SMALL_STATE(19820)] = 756909,
  [SMALL_STATE(19821)] = 756923,
  [SMALL_STATE(19822)] = 756937,
  [SMALL_STATE(19823)] = 756951,
  [SMALL_STATE(19824)] = 756965,
  [SMALL_STATE(19825)] = 756979,
  [SMALL_STATE(19826)] = 756993,
  [SMALL_STATE(19827)] = 757007,
  [SMALL_STATE(19828)] = 757021,
  [SMALL_STATE(19829)] = 757035,
  [SMALL_STATE(19830)] = 757049,
  [SMALL_STATE(19831)] = 757063,
  [SMALL_STATE(19832)] = 757077,
  [SMALL_STATE(19833)] = 757091,
  [SMALL_STATE(19834)] = 757105,
  [SMALL_STATE(19835)] = 757119,
  [SMALL_STATE(19836)] = 757133,
  [SMALL_STATE(19837)] = 757147,
  [SMALL_STATE(19838)] = 757161,
  [SMALL_STATE(19839)] = 757175,
  [SMALL_STATE(19840)] = 757189,
  [SMALL_STATE(19841)] = 757203,
  [SMALL_STATE(19842)] = 757217,
  [SMALL_STATE(19843)] = 757231,
  [SMALL_STATE(19844)] = 757245,
  [SMALL_STATE(19845)] = 757259,
  [SMALL_STATE(19846)] = 757273,
  [SMALL_STATE(19847)] = 757287,
  [SMALL_STATE(19848)] = 757301,
  [SMALL_STATE(19849)] = 757315,
  [SMALL_STATE(19850)] = 757329,
  [SMALL_STATE(19851)] = 757343,
  [SMALL_STATE(19852)] = 757357,
  [SMALL_STATE(19853)] = 757371,
  [SMALL_STATE(19854)] = 757385,
  [SMALL_STATE(19855)] = 757399,
  [SMALL_STATE(19856)] = 757413,
  [SMALL_STATE(19857)] = 757427,
  [SMALL_STATE(19858)] = 757441,
  [SMALL_STATE(19859)] = 757455,
  [SMALL_STATE(19860)] = 757469,
  [SMALL_STATE(19861)] = 757483,
  [SMALL_STATE(19862)] = 757497,
  [SMALL_STATE(19863)] = 757511,
  [SMALL_STATE(19864)] = 757525,
  [SMALL_STATE(19865)] = 757539,
  [SMALL_STATE(19866)] = 757553,
  [SMALL_STATE(19867)] = 757567,
  [SMALL_STATE(19868)] = 757581,
  [SMALL_STATE(19869)] = 757595,
  [SMALL_STATE(19870)] = 757609,
  [SMALL_STATE(19871)] = 757623,
  [SMALL_STATE(19872)] = 757637,
  [SMALL_STATE(19873)] = 757651,
  [SMALL_STATE(19874)] = 757665,
  [SMALL_STATE(19875)] = 757679,
  [SMALL_STATE(19876)] = 757693,
  [SMALL_STATE(19877)] = 757707,
  [SMALL_STATE(19878)] = 757721,
  [SMALL_STATE(19879)] = 757735,
  [SMALL_STATE(19880)] = 757749,
  [SMALL_STATE(19881)] = 757763,
  [SMALL_STATE(19882)] = 757777,
  [SMALL_STATE(19883)] = 757791,
  [SMALL_STATE(19884)] = 757805,
  [SMALL_STATE(19885)] = 757819,
  [SMALL_STATE(19886)] = 757833,
  [SMALL_STATE(19887)] = 757847,
  [SMALL_STATE(19888)] = 757861,
  [SMALL_STATE(19889)] = 757875,
  [SMALL_STATE(19890)] = 757889,
  [SMALL_STATE(19891)] = 757903,
  [SMALL_STATE(19892)] = 757917,
  [SMALL_STATE(19893)] = 757931,
  [SMALL_STATE(19894)] = 757945,
  [SMALL_STATE(19895)] = 757959,
  [SMALL_STATE(19896)] = 757973,
  [SMALL_STATE(19897)] = 757987,
  [SMALL_STATE(19898)] = 758001,
  [SMALL_STATE(19899)] = 758015,
  [SMALL_STATE(19900)] = 758029,
  [SMALL_STATE(19901)] = 758043,
  [SMALL_STATE(19902)] = 758057,
  [SMALL_STATE(19903)] = 758071,
  [SMALL_STATE(19904)] = 758085,
  [SMALL_STATE(19905)] = 758099,
  [SMALL_STATE(19906)] = 758113,
  [SMALL_STATE(19907)] = 758127,
  [SMALL_STATE(19908)] = 758141,
  [SMALL_STATE(19909)] = 758155,
  [SMALL_STATE(19910)] = 758169,
  [SMALL_STATE(19911)] = 758183,
  [SMALL_STATE(19912)] = 758197,
  [SMALL_STATE(19913)] = 758211,
  [SMALL_STATE(19914)] = 758225,
  [SMALL_STATE(19915)] = 758239,
  [SMALL_STATE(19916)] = 758253,
  [SMALL_STATE(19917)] = 758267,
  [SMALL_STATE(19918)] = 758281,
  [SMALL_STATE(19919)] = 758295,
  [SMALL_STATE(19920)] = 758309,
  [SMALL_STATE(19921)] = 758323,
  [SMALL_STATE(19922)] = 758337,
  [SMALL_STATE(19923)] = 758351,
  [SMALL_STATE(19924)] = 758365,
  [SMALL_STATE(19925)] = 758379,
  [SMALL_STATE(19926)] = 758393,
  [SMALL_STATE(19927)] = 758407,
  [SMALL_STATE(19928)] = 758421,
  [SMALL_STATE(19929)] = 758435,
  [SMALL_STATE(19930)] = 758449,
  [SMALL_STATE(19931)] = 758463,
  [SMALL_STATE(19932)] = 758477,
  [SMALL_STATE(19933)] = 758491,
  [SMALL_STATE(19934)] = 758505,
  [SMALL_STATE(19935)] = 758519,
  [SMALL_STATE(19936)] = 758533,
  [SMALL_STATE(19937)] = 758547,
  [SMALL_STATE(19938)] = 758561,
  [SMALL_STATE(19939)] = 758575,
  [SMALL_STATE(19940)] = 758589,
  [SMALL_STATE(19941)] = 758603,
  [SMALL_STATE(19942)] = 758617,
  [SMALL_STATE(19943)] = 758631,
  [SMALL_STATE(19944)] = 758645,
  [SMALL_STATE(19945)] = 758659,
  [SMALL_STATE(19946)] = 758673,
  [SMALL_STATE(19947)] = 758687,
  [SMALL_STATE(19948)] = 758701,
  [SMALL_STATE(19949)] = 758715,
  [SMALL_STATE(19950)] = 758729,
  [SMALL_STATE(19951)] = 758743,
  [SMALL_STATE(19952)] = 758757,
  [SMALL_STATE(19953)] = 758771,
  [SMALL_STATE(19954)] = 758785,
  [SMALL_STATE(19955)] = 758799,
  [SMALL_STATE(19956)] = 758813,
  [SMALL_STATE(19957)] = 758827,
  [SMALL_STATE(19958)] = 758841,
  [SMALL_STATE(19959)] = 758855,
  [SMALL_STATE(19960)] = 758869,
  [SMALL_STATE(19961)] = 758883,
  [SMALL_STATE(19962)] = 758897,
  [SMALL_STATE(19963)] = 758911,
  [SMALL_STATE(19964)] = 758925,
  [SMALL_STATE(19965)] = 758939,
  [SMALL_STATE(19966)] = 758953,
  [SMALL_STATE(19967)] = 758967,
  [SMALL_STATE(19968)] = 758981,
  [SMALL_STATE(19969)] = 758995,
  [SMALL_STATE(19970)] = 759009,
  [SMALL_STATE(19971)] = 759023,
  [SMALL_STATE(19972)] = 759037,
  [SMALL_STATE(19973)] = 759051,
  [SMALL_STATE(19974)] = 759065,
  [SMALL_STATE(19975)] = 759079,
  [SMALL_STATE(19976)] = 759093,
  [SMALL_STATE(19977)] = 759107,
  [SMALL_STATE(19978)] = 759121,
  [SMALL_STATE(19979)] = 759135,
  [SMALL_STATE(19980)] = 759149,
  [SMALL_STATE(19981)] = 759163,
  [SMALL_STATE(19982)] = 759177,
  [SMALL_STATE(19983)] = 759191,
  [SMALL_STATE(19984)] = 759205,
  [SMALL_STATE(19985)] = 759219,
  [SMALL_STATE(19986)] = 759233,
  [SMALL_STATE(19987)] = 759247,
  [SMALL_STATE(19988)] = 759261,
  [SMALL_STATE(19989)] = 759275,
  [SMALL_STATE(19990)] = 759289,
  [SMALL_STATE(19991)] = 759303,
  [SMALL_STATE(19992)] = 759317,
  [SMALL_STATE(19993)] = 759331,
  [SMALL_STATE(19994)] = 759345,
  [SMALL_STATE(19995)] = 759359,
  [SMALL_STATE(19996)] = 759373,
  [SMALL_STATE(19997)] = 759387,
  [SMALL_STATE(19998)] = 759401,
  [SMALL_STATE(19999)] = 759415,
  [SMALL_STATE(20000)] = 759429,
  [SMALL_STATE(20001)] = 759443,
  [SMALL_STATE(20002)] = 759457,
  [SMALL_STATE(20003)] = 759471,
  [SMALL_STATE(20004)] = 759485,
  [SMALL_STATE(20005)] = 759499,
  [SMALL_STATE(20006)] = 759513,
  [SMALL_STATE(20007)] = 759527,
  [SMALL_STATE(20008)] = 759541,
  [SMALL_STATE(20009)] = 759555,
  [SMALL_STATE(20010)] = 759569,
  [SMALL_STATE(20011)] = 759583,
  [SMALL_STATE(20012)] = 759597,
  [SMALL_STATE(20013)] = 759611,
  [SMALL_STATE(20014)] = 759625,
  [SMALL_STATE(20015)] = 759639,
  [SMALL_STATE(20016)] = 759653,
  [SMALL_STATE(20017)] = 759667,
  [SMALL_STATE(20018)] = 759681,
  [SMALL_STATE(20019)] = 759695,
  [SMALL_STATE(20020)] = 759709,
  [SMALL_STATE(20021)] = 759723,
  [SMALL_STATE(20022)] = 759737,
  [SMALL_STATE(20023)] = 759751,
  [SMALL_STATE(20024)] = 759765,
  [SMALL_STATE(20025)] = 759779,
  [SMALL_STATE(20026)] = 759793,
  [SMALL_STATE(20027)] = 759807,
  [SMALL_STATE(20028)] = 759821,
  [SMALL_STATE(20029)] = 759835,
  [SMALL_STATE(20030)] = 759849,
  [SMALL_STATE(20031)] = 759863,
  [SMALL_STATE(20032)] = 759877,
  [SMALL_STATE(20033)] = 759891,
  [SMALL_STATE(20034)] = 759905,
  [SMALL_STATE(20035)] = 759919,
  [SMALL_STATE(20036)] = 759933,
  [SMALL_STATE(20037)] = 759947,
  [SMALL_STATE(20038)] = 759961,
  [SMALL_STATE(20039)] = 759975,
  [SMALL_STATE(20040)] = 759989,
  [SMALL_STATE(20041)] = 760003,
  [SMALL_STATE(20042)] = 760017,
  [SMALL_STATE(20043)] = 760031,
  [SMALL_STATE(20044)] = 760045,
  [SMALL_STATE(20045)] = 760059,
  [SMALL_STATE(20046)] = 760073,
  [SMALL_STATE(20047)] = 760087,
  [SMALL_STATE(20048)] = 760101,
  [SMALL_STATE(20049)] = 760115,
  [SMALL_STATE(20050)] = 760129,
  [SMALL_STATE(20051)] = 760143,
  [SMALL_STATE(20052)] = 760157,
  [SMALL_STATE(20053)] = 760171,
  [SMALL_STATE(20054)] = 760185,
  [SMALL_STATE(20055)] = 760199,
  [SMALL_STATE(20056)] = 760213,
  [SMALL_STATE(20057)] = 760227,
  [SMALL_STATE(20058)] = 760241,
  [SMALL_STATE(20059)] = 760255,
  [SMALL_STATE(20060)] = 760269,
  [SMALL_STATE(20061)] = 760283,
  [SMALL_STATE(20062)] = 760297,
  [SMALL_STATE(20063)] = 760311,
  [SMALL_STATE(20064)] = 760325,
  [SMALL_STATE(20065)] = 760339,
  [SMALL_STATE(20066)] = 760353,
  [SMALL_STATE(20067)] = 760367,
  [SMALL_STATE(20068)] = 760381,
  [SMALL_STATE(20069)] = 760395,
  [SMALL_STATE(20070)] = 760409,
  [SMALL_STATE(20071)] = 760423,
  [SMALL_STATE(20072)] = 760437,
  [SMALL_STATE(20073)] = 760451,
  [SMALL_STATE(20074)] = 760465,
  [SMALL_STATE(20075)] = 760479,
  [SMALL_STATE(20076)] = 760493,
  [SMALL_STATE(20077)] = 760507,
  [SMALL_STATE(20078)] = 760521,
  [SMALL_STATE(20079)] = 760535,
  [SMALL_STATE(20080)] = 760549,
  [SMALL_STATE(20081)] = 760563,
  [SMALL_STATE(20082)] = 760577,
  [SMALL_STATE(20083)] = 760591,
  [SMALL_STATE(20084)] = 760605,
  [SMALL_STATE(20085)] = 760619,
  [SMALL_STATE(20086)] = 760633,
  [SMALL_STATE(20087)] = 760647,
  [SMALL_STATE(20088)] = 760661,
  [SMALL_STATE(20089)] = 760675,
  [SMALL_STATE(20090)] = 760689,
  [SMALL_STATE(20091)] = 760703,
  [SMALL_STATE(20092)] = 760717,
  [SMALL_STATE(20093)] = 760731,
  [SMALL_STATE(20094)] = 760745,
  [SMALL_STATE(20095)] = 760759,
  [SMALL_STATE(20096)] = 760773,
  [SMALL_STATE(20097)] = 760787,
  [SMALL_STATE(20098)] = 760801,
  [SMALL_STATE(20099)] = 760815,
  [SMALL_STATE(20100)] = 760829,
  [SMALL_STATE(20101)] = 760843,
  [SMALL_STATE(20102)] = 760857,
  [SMALL_STATE(20103)] = 760871,
  [SMALL_STATE(20104)] = 760885,
  [SMALL_STATE(20105)] = 760899,
  [SMALL_STATE(20106)] = 760913,
  [SMALL_STATE(20107)] = 760927,
  [SMALL_STATE(20108)] = 760941,
  [SMALL_STATE(20109)] = 760955,
  [SMALL_STATE(20110)] = 760969,
  [SMALL_STATE(20111)] = 760983,
  [SMALL_STATE(20112)] = 760997,
  [SMALL_STATE(20113)] = 761011,
  [SMALL_STATE(20114)] = 761025,
  [SMALL_STATE(20115)] = 761039,
  [SMALL_STATE(20116)] = 761053,
  [SMALL_STATE(20117)] = 761067,
  [SMALL_STATE(20118)] = 761081,
  [SMALL_STATE(20119)] = 761095,
  [SMALL_STATE(20120)] = 761109,
  [SMALL_STATE(20121)] = 761123,
  [SMALL_STATE(20122)] = 761137,
  [SMALL_STATE(20123)] = 761151,
  [SMALL_STATE(20124)] = 761165,
  [SMALL_STATE(20125)] = 761179,
  [SMALL_STATE(20126)] = 761193,
  [SMALL_STATE(20127)] = 761207,
  [SMALL_STATE(20128)] = 761221,
  [SMALL_STATE(20129)] = 761235,
  [SMALL_STATE(20130)] = 761249,
  [SMALL_STATE(20131)] = 761263,
  [SMALL_STATE(20132)] = 761277,
  [SMALL_STATE(20133)] = 761291,
  [SMALL_STATE(20134)] = 761305,
  [SMALL_STATE(20135)] = 761319,
  [SMALL_STATE(20136)] = 761333,
  [SMALL_STATE(20137)] = 761347,
  [SMALL_STATE(20138)] = 761361,
  [SMALL_STATE(20139)] = 761375,
  [SMALL_STATE(20140)] = 761389,
  [SMALL_STATE(20141)] = 761403,
  [SMALL_STATE(20142)] = 761417,
  [SMALL_STATE(20143)] = 761431,
  [SMALL_STATE(20144)] = 761445,
  [SMALL_STATE(20145)] = 761459,
  [SMALL_STATE(20146)] = 761473,
  [SMALL_STATE(20147)] = 761487,
  [SMALL_STATE(20148)] = 761501,
  [SMALL_STATE(20149)] = 761515,
  [SMALL_STATE(20150)] = 761529,
  [SMALL_STATE(20151)] = 761543,
  [SMALL_STATE(20152)] = 761557,
  [SMALL_STATE(20153)] = 761571,
  [SMALL_STATE(20154)] = 761585,
  [SMALL_STATE(20155)] = 761599,
  [SMALL_STATE(20156)] = 761613,
  [SMALL_STATE(20157)] = 761627,
  [SMALL_STATE(20158)] = 761641,
  [SMALL_STATE(20159)] = 761655,
  [SMALL_STATE(20160)] = 761669,
  [SMALL_STATE(20161)] = 761683,
  [SMALL_STATE(20162)] = 761697,
  [SMALL_STATE(20163)] = 761711,
  [SMALL_STATE(20164)] = 761725,
  [SMALL_STATE(20165)] = 761739,
  [SMALL_STATE(20166)] = 761753,
  [SMALL_STATE(20167)] = 761767,
  [SMALL_STATE(20168)] = 761781,
  [SMALL_STATE(20169)] = 761795,
  [SMALL_STATE(20170)] = 761809,
  [SMALL_STATE(20171)] = 761823,
  [SMALL_STATE(20172)] = 761837,
  [SMALL_STATE(20173)] = 761851,
  [SMALL_STATE(20174)] = 761865,
  [SMALL_STATE(20175)] = 761879,
  [SMALL_STATE(20176)] = 761893,
  [SMALL_STATE(20177)] = 761907,
  [SMALL_STATE(20178)] = 761921,
  [SMALL_STATE(20179)] = 761935,
  [SMALL_STATE(20180)] = 761949,
  [SMALL_STATE(20181)] = 761963,
  [SMALL_STATE(20182)] = 761977,
  [SMALL_STATE(20183)] = 761991,
  [SMALL_STATE(20184)] = 762005,
  [SMALL_STATE(20185)] = 762019,
  [SMALL_STATE(20186)] = 762033,
  [SMALL_STATE(20187)] = 762047,
  [SMALL_STATE(20188)] = 762061,
  [SMALL_STATE(20189)] = 762075,
  [SMALL_STATE(20190)] = 762089,
  [SMALL_STATE(20191)] = 762103,
  [SMALL_STATE(20192)] = 762117,
  [SMALL_STATE(20193)] = 762131,
  [SMALL_STATE(20194)] = 762145,
  [SMALL_STATE(20195)] = 762159,
  [SMALL_STATE(20196)] = 762173,
  [SMALL_STATE(20197)] = 762187,
  [SMALL_STATE(20198)] = 762201,
  [SMALL_STATE(20199)] = 762215,
  [SMALL_STATE(20200)] = 762229,
  [SMALL_STATE(20201)] = 762243,
  [SMALL_STATE(20202)] = 762257,
  [SMALL_STATE(20203)] = 762271,
  [SMALL_STATE(20204)] = 762285,
  [SMALL_STATE(20205)] = 762299,
  [SMALL_STATE(20206)] = 762313,
  [SMALL_STATE(20207)] = 762327,
  [SMALL_STATE(20208)] = 762341,
  [SMALL_STATE(20209)] = 762355,
  [SMALL_STATE(20210)] = 762369,
  [SMALL_STATE(20211)] = 762383,
  [SMALL_STATE(20212)] = 762397,
  [SMALL_STATE(20213)] = 762411,
  [SMALL_STATE(20214)] = 762425,
  [SMALL_STATE(20215)] = 762439,
  [SMALL_STATE(20216)] = 762453,
  [SMALL_STATE(20217)] = 762467,
  [SMALL_STATE(20218)] = 762481,
  [SMALL_STATE(20219)] = 762495,
  [SMALL_STATE(20220)] = 762509,
  [SMALL_STATE(20221)] = 762523,
  [SMALL_STATE(20222)] = 762537,
  [SMALL_STATE(20223)] = 762551,
  [SMALL_STATE(20224)] = 762565,
  [SMALL_STATE(20225)] = 762579,
  [SMALL_STATE(20226)] = 762593,
  [SMALL_STATE(20227)] = 762607,
  [SMALL_STATE(20228)] = 762621,
  [SMALL_STATE(20229)] = 762635,
  [SMALL_STATE(20230)] = 762649,
  [SMALL_STATE(20231)] = 762663,
  [SMALL_STATE(20232)] = 762677,
  [SMALL_STATE(20233)] = 762691,
  [SMALL_STATE(20234)] = 762705,
  [SMALL_STATE(20235)] = 762719,
  [SMALL_STATE(20236)] = 762733,
  [SMALL_STATE(20237)] = 762747,
  [SMALL_STATE(20238)] = 762761,
  [SMALL_STATE(20239)] = 762775,
  [SMALL_STATE(20240)] = 762789,
  [SMALL_STATE(20241)] = 762803,
  [SMALL_STATE(20242)] = 762817,
  [SMALL_STATE(20243)] = 762831,
  [SMALL_STATE(20244)] = 762845,
  [SMALL_STATE(20245)] = 762859,
  [SMALL_STATE(20246)] = 762873,
  [SMALL_STATE(20247)] = 762887,
  [SMALL_STATE(20248)] = 762901,
  [SMALL_STATE(20249)] = 762915,
  [SMALL_STATE(20250)] = 762929,
  [SMALL_STATE(20251)] = 762943,
  [SMALL_STATE(20252)] = 762957,
  [SMALL_STATE(20253)] = 762971,
  [SMALL_STATE(20254)] = 762985,
  [SMALL_STATE(20255)] = 762999,
  [SMALL_STATE(20256)] = 763013,
  [SMALL_STATE(20257)] = 763027,
  [SMALL_STATE(20258)] = 763041,
  [SMALL_STATE(20259)] = 763055,
  [SMALL_STATE(20260)] = 763069,
  [SMALL_STATE(20261)] = 763083,
  [SMALL_STATE(20262)] = 763097,
  [SMALL_STATE(20263)] = 763111,
  [SMALL_STATE(20264)] = 763125,
  [SMALL_STATE(20265)] = 763139,
  [SMALL_STATE(20266)] = 763153,
  [SMALL_STATE(20267)] = 763167,
  [SMALL_STATE(20268)] = 763181,
  [SMALL_STATE(20269)] = 763195,
  [SMALL_STATE(20270)] = 763209,
  [SMALL_STATE(20271)] = 763223,
  [SMALL_STATE(20272)] = 763237,
  [SMALL_STATE(20273)] = 763251,
  [SMALL_STATE(20274)] = 763265,
  [SMALL_STATE(20275)] = 763279,
  [SMALL_STATE(20276)] = 763293,
  [SMALL_STATE(20277)] = 763307,
  [SMALL_STATE(20278)] = 763321,
  [SMALL_STATE(20279)] = 763335,
  [SMALL_STATE(20280)] = 763349,
  [SMALL_STATE(20281)] = 763363,
  [SMALL_STATE(20282)] = 763377,
  [SMALL_STATE(20283)] = 763391,
  [SMALL_STATE(20284)] = 763405,
  [SMALL_STATE(20285)] = 763419,
  [SMALL_STATE(20286)] = 763433,
  [SMALL_STATE(20287)] = 763447,
  [SMALL_STATE(20288)] = 763461,
  [SMALL_STATE(20289)] = 763475,
  [SMALL_STATE(20290)] = 763489,
  [SMALL_STATE(20291)] = 763503,
  [SMALL_STATE(20292)] = 763517,
  [SMALL_STATE(20293)] = 763531,
  [SMALL_STATE(20294)] = 763545,
  [SMALL_STATE(20295)] = 763559,
  [SMALL_STATE(20296)] = 763573,
  [SMALL_STATE(20297)] = 763587,
  [SMALL_STATE(20298)] = 763601,
  [SMALL_STATE(20299)] = 763615,
  [SMALL_STATE(20300)] = 763629,
  [SMALL_STATE(20301)] = 763643,
  [SMALL_STATE(20302)] = 763657,
  [SMALL_STATE(20303)] = 763671,
  [SMALL_STATE(20304)] = 763685,
  [SMALL_STATE(20305)] = 763699,
  [SMALL_STATE(20306)] = 763713,
  [SMALL_STATE(20307)] = 763727,
  [SMALL_STATE(20308)] = 763741,
  [SMALL_STATE(20309)] = 763755,
  [SMALL_STATE(20310)] = 763769,
  [SMALL_STATE(20311)] = 763783,
  [SMALL_STATE(20312)] = 763797,
  [SMALL_STATE(20313)] = 763811,
  [SMALL_STATE(20314)] = 763825,
  [SMALL_STATE(20315)] = 763839,
  [SMALL_STATE(20316)] = 763853,
  [SMALL_STATE(20317)] = 763867,
  [SMALL_STATE(20318)] = 763881,
  [SMALL_STATE(20319)] = 763895,
  [SMALL_STATE(20320)] = 763909,
  [SMALL_STATE(20321)] = 763923,
  [SMALL_STATE(20322)] = 763937,
  [SMALL_STATE(20323)] = 763951,
  [SMALL_STATE(20324)] = 763965,
  [SMALL_STATE(20325)] = 763979,
  [SMALL_STATE(20326)] = 763993,
  [SMALL_STATE(20327)] = 764007,
  [SMALL_STATE(20328)] = 764021,
  [SMALL_STATE(20329)] = 764035,
  [SMALL_STATE(20330)] = 764049,
  [SMALL_STATE(20331)] = 764063,
  [SMALL_STATE(20332)] = 764077,
  [SMALL_STATE(20333)] = 764091,
  [SMALL_STATE(20334)] = 764105,
  [SMALL_STATE(20335)] = 764119,
  [SMALL_STATE(20336)] = 764133,
  [SMALL_STATE(20337)] = 764147,
  [SMALL_STATE(20338)] = 764161,
  [SMALL_STATE(20339)] = 764175,
  [SMALL_STATE(20340)] = 764189,
  [SMALL_STATE(20341)] = 764203,
  [SMALL_STATE(20342)] = 764217,
  [SMALL_STATE(20343)] = 764231,
  [SMALL_STATE(20344)] = 764245,
  [SMALL_STATE(20345)] = 764259,
  [SMALL_STATE(20346)] = 764273,
  [SMALL_STATE(20347)] = 764287,
  [SMALL_STATE(20348)] = 764301,
  [SMALL_STATE(20349)] = 764315,
  [SMALL_STATE(20350)] = 764329,
  [SMALL_STATE(20351)] = 764343,
  [SMALL_STATE(20352)] = 764357,
  [SMALL_STATE(20353)] = 764371,
  [SMALL_STATE(20354)] = 764385,
  [SMALL_STATE(20355)] = 764399,
  [SMALL_STATE(20356)] = 764413,
  [SMALL_STATE(20357)] = 764427,
  [SMALL_STATE(20358)] = 764441,
  [SMALL_STATE(20359)] = 764455,
  [SMALL_STATE(20360)] = 764469,
  [SMALL_STATE(20361)] = 764483,
  [SMALL_STATE(20362)] = 764497,
  [SMALL_STATE(20363)] = 764511,
  [SMALL_STATE(20364)] = 764525,
  [SMALL_STATE(20365)] = 764539,
  [SMALL_STATE(20366)] = 764553,
  [SMALL_STATE(20367)] = 764567,
  [SMALL_STATE(20368)] = 764581,
  [SMALL_STATE(20369)] = 764595,
  [SMALL_STATE(20370)] = 764609,
  [SMALL_STATE(20371)] = 764623,
  [SMALL_STATE(20372)] = 764637,
  [SMALL_STATE(20373)] = 764651,
  [SMALL_STATE(20374)] = 764665,
  [SMALL_STATE(20375)] = 764679,
  [SMALL_STATE(20376)] = 764693,
  [SMALL_STATE(20377)] = 764707,
  [SMALL_STATE(20378)] = 764721,
  [SMALL_STATE(20379)] = 764735,
  [SMALL_STATE(20380)] = 764749,
  [SMALL_STATE(20381)] = 764763,
  [SMALL_STATE(20382)] = 764777,
  [SMALL_STATE(20383)] = 764791,
  [SMALL_STATE(20384)] = 764805,
  [SMALL_STATE(20385)] = 764819,
  [SMALL_STATE(20386)] = 764833,
  [SMALL_STATE(20387)] = 764847,
  [SMALL_STATE(20388)] = 764861,
  [SMALL_STATE(20389)] = 764875,
  [SMALL_STATE(20390)] = 764889,
  [SMALL_STATE(20391)] = 764903,
  [SMALL_STATE(20392)] = 764917,
  [SMALL_STATE(20393)] = 764931,
  [SMALL_STATE(20394)] = 764945,
  [SMALL_STATE(20395)] = 764959,
  [SMALL_STATE(20396)] = 764973,
  [SMALL_STATE(20397)] = 764987,
  [SMALL_STATE(20398)] = 765001,
  [SMALL_STATE(20399)] = 765015,
  [SMALL_STATE(20400)] = 765029,
  [SMALL_STATE(20401)] = 765043,
  [SMALL_STATE(20402)] = 765057,
  [SMALL_STATE(20403)] = 765071,
  [SMALL_STATE(20404)] = 765085,
  [SMALL_STATE(20405)] = 765099,
  [SMALL_STATE(20406)] = 765113,
  [SMALL_STATE(20407)] = 765127,
  [SMALL_STATE(20408)] = 765141,
  [SMALL_STATE(20409)] = 765155,
  [SMALL_STATE(20410)] = 765169,
  [SMALL_STATE(20411)] = 765183,
  [SMALL_STATE(20412)] = 765197,
  [SMALL_STATE(20413)] = 765211,
  [SMALL_STATE(20414)] = 765225,
  [SMALL_STATE(20415)] = 765239,
  [SMALL_STATE(20416)] = 765253,
  [SMALL_STATE(20417)] = 765267,
  [SMALL_STATE(20418)] = 765281,
  [SMALL_STATE(20419)] = 765295,
  [SMALL_STATE(20420)] = 765309,
  [SMALL_STATE(20421)] = 765323,
  [SMALL_STATE(20422)] = 765337,
  [SMALL_STATE(20423)] = 765351,
  [SMALL_STATE(20424)] = 765365,
  [SMALL_STATE(20425)] = 765379,
  [SMALL_STATE(20426)] = 765393,
  [SMALL_STATE(20427)] = 765407,
  [SMALL_STATE(20428)] = 765421,
  [SMALL_STATE(20429)] = 765435,
  [SMALL_STATE(20430)] = 765449,
  [SMALL_STATE(20431)] = 765463,
  [SMALL_STATE(20432)] = 765477,
  [SMALL_STATE(20433)] = 765491,
  [SMALL_STATE(20434)] = 765505,
  [SMALL_STATE(20435)] = 765519,
  [SMALL_STATE(20436)] = 765533,
  [SMALL_STATE(20437)] = 765547,
  [SMALL_STATE(20438)] = 765561,
  [SMALL_STATE(20439)] = 765575,
  [SMALL_STATE(20440)] = 765589,
  [SMALL_STATE(20441)] = 765603,
  [SMALL_STATE(20442)] = 765617,
  [SMALL_STATE(20443)] = 765631,
  [SMALL_STATE(20444)] = 765645,
  [SMALL_STATE(20445)] = 765659,
  [SMALL_STATE(20446)] = 765673,
  [SMALL_STATE(20447)] = 765687,
  [SMALL_STATE(20448)] = 765701,
  [SMALL_STATE(20449)] = 765715,
  [SMALL_STATE(20450)] = 765729,
  [SMALL_STATE(20451)] = 765743,
  [SMALL_STATE(20452)] = 765757,
  [SMALL_STATE(20453)] = 765771,
  [SMALL_STATE(20454)] = 765785,
  [SMALL_STATE(20455)] = 765799,
  [SMALL_STATE(20456)] = 765813,
  [SMALL_STATE(20457)] = 765827,
  [SMALL_STATE(20458)] = 765841,
  [SMALL_STATE(20459)] = 765855,
  [SMALL_STATE(20460)] = 765869,
  [SMALL_STATE(20461)] = 765883,
  [SMALL_STATE(20462)] = 765897,
  [SMALL_STATE(20463)] = 765911,
  [SMALL_STATE(20464)] = 765925,
  [SMALL_STATE(20465)] = 765939,
  [SMALL_STATE(20466)] = 765953,
  [SMALL_STATE(20467)] = 765967,
  [SMALL_STATE(20468)] = 765981,
  [SMALL_STATE(20469)] = 765995,
  [SMALL_STATE(20470)] = 766009,
  [SMALL_STATE(20471)] = 766023,
  [SMALL_STATE(20472)] = 766037,
  [SMALL_STATE(20473)] = 766051,
  [SMALL_STATE(20474)] = 766065,
  [SMALL_STATE(20475)] = 766079,
  [SMALL_STATE(20476)] = 766093,
  [SMALL_STATE(20477)] = 766107,
  [SMALL_STATE(20478)] = 766121,
  [SMALL_STATE(20479)] = 766135,
  [SMALL_STATE(20480)] = 766149,
  [SMALL_STATE(20481)] = 766163,
  [SMALL_STATE(20482)] = 766177,
  [SMALL_STATE(20483)] = 766191,
  [SMALL_STATE(20484)] = 766205,
  [SMALL_STATE(20485)] = 766219,
  [SMALL_STATE(20486)] = 766233,
  [SMALL_STATE(20487)] = 766247,
  [SMALL_STATE(20488)] = 766261,
  [SMALL_STATE(20489)] = 766275,
  [SMALL_STATE(20490)] = 766289,
  [SMALL_STATE(20491)] = 766303,
  [SMALL_STATE(20492)] = 766317,
  [SMALL_STATE(20493)] = 766331,
  [SMALL_STATE(20494)] = 766345,
  [SMALL_STATE(20495)] = 766359,
  [SMALL_STATE(20496)] = 766373,
  [SMALL_STATE(20497)] = 766387,
  [SMALL_STATE(20498)] = 766401,
  [SMALL_STATE(20499)] = 766415,
  [SMALL_STATE(20500)] = 766429,
  [SMALL_STATE(20501)] = 766443,
  [SMALL_STATE(20502)] = 766457,
  [SMALL_STATE(20503)] = 766471,
  [SMALL_STATE(20504)] = 766485,
  [SMALL_STATE(20505)] = 766489,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16388),
  [5] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [7] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compilation_unit, 0, 0, 0),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12628),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13997),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12016),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13303),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13499),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11157),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10117),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13512),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13863),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16496),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16495),
  [31] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16494),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4016),
  [35] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5273),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2657),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3313),
  [41] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [43] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13997),
  [45] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12192),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1523),
  [49] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5540),
  [51] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4353),
  [53] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2897),
  [55] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3082),
  [57] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13372),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13630),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11157),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11342),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13579),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10618),
  [69] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4796),
  [71] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1529),
  [73] = {.entry = {.count = 1, .reusable = false}}, SHIFT(497),
  [75] = {.entry = {.count = 1, .reusable = false}}, SHIFT(494),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14111),
  [79] = {.entry = {.count = 1, .reusable = false}}, SHIFT(493),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2639),
  [83] = {.entry = {.count = 1, .reusable = false}}, SHIFT(490),
  [85] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3800),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3837),
  [89] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14115),
  [91] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14199),
  [93] = {.entry = {.count = 1, .reusable = false}}, SHIFT(292),
  [95] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4315),
  [97] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16120),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15805),
  [101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4319),
  [103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8348),
  [105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13392),
  [107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12449),
  [109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4424),
  [111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8348),
  [113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4596),
  [115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1413),
  [117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4471),
  [119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16529),
  [121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16530),
  [123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10462),
  [125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5579),
  [127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7034),
  [129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8726),
  [131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10061),
  [133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11089),
  [135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10097),
  [137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3633),
  [139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6831),
  [141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8888),
  [143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9502),
  [145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4013),
  [147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16008),
  [149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10718),
  [151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5300),
  [153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7760),
  [155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9964),
  [157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7885),
  [159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10063),
  [161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20504),
  [163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7544),
  [165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13203),
  [167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5811),
  [169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5141),
  [171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7621),
  [173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7961),
  [175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5601),
  [177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5336),
  [179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15002),
  [181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6081),
  [183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5454),
  [185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11142),
  [187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7186),
  [189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11734),
  [191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4474),
  [193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12200),
  [195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6906),
  [197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6363),
  [199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9732),
  [201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10230),
  [203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9302),
  [205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7331),
  [207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6156),
  [209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9858),
  [211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6179),
  [213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6201),
  [215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3858),
  [217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6134),
  [219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6636),
  [221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3871),
  [223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9459),
  [225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7491),
  [227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6737),
  [229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13192),
  [231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4889),
  [233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3370),
  [235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7455),
  [237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7236),
  [239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10735),
  [241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4024),
  [243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12633),
  [245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4909),
  [247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7992),
  [249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3205),
  [251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6237),
  [253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6114),
  [255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10236),
  [257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10810),
  [259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3210),
  [261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9791),
  [263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7562),
  [265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7366),
  [267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5572),
  [269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5208),
  [271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3504),
  [273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3515),
  [275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9290),
  [277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9317),
  [279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12917),
  [281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12848),
  [283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9704),
  [285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6638),
  [287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6990),
  [289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10413),
  [291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4206),
  [293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9478),
  [295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2962),
  [297] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sequence_expression, 2, 0, 28),
  [299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2686),
  [301] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sequence_expression, 2, 0, 28),
  [303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1752),
  [307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3177),
  [309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2976),
  [311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10513),
  [313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4853),
  [315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1753),
  [317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(354),
  [319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(338),
  [321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2612),
  [323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(335),
  [325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14028),
  [327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14268),
  [329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(284),
  [331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3052),
  [333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15611),
  [335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15520),
  [337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15907),
  [339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3178),
  [341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13318),
  [343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12266),
  [345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4238),
  [347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4592),
  [349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1026),
  [351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3182),
  [353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16732),
  [355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2956),
  [357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2660),
  [359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1731),
  [363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3120),
  [365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3275),
  [367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10626),
  [369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4832),
  [371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1734),
  [373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(313),
  [375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(328),
  [377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2605),
  [379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(332),
  [381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13913),
  [383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14348),
  [385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(289),
  [387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3176),
  [389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15582),
  [391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15526),
  [393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3121),
  [395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13292),
  [397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12245),
  [399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4457),
  [401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(568),
  [403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3122),
  [405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16784),
  [407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4183),
  [409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5242),
  [411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2666),
  [413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11978),
  [417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1564),
  [419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4275),
  [421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3220),
  [423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13261),
  [425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13614),
  [427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13584),
  [429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8887),
  [431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10515),
  [433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4804),
  [435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1565),
  [437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(478),
  [439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(473),
  [441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2634),
  [443] = {.entry = {.count = 1, .reusable = false}}, SHIFT(472),
  [445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14082),
  [447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14232),
  [449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(254),
  [451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4413),
  [453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16227),
  [455] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16386),
  [457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4304),
  [459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13390),
  [461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12527),
  [463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4211),
  [465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4556),
  [467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1405),
  [469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4357),
  [471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16660),
  [473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16661),
  [475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3087),
  [477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2688),
  [479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1688),
  [483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3395),
  [485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3080),
  [487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10586),
  [489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4820),
  [491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1686),
  [493] = {.entry = {.count = 1, .reusable = false}}, SHIFT(360),
  [495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(373),
  [497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2616),
  [499] = {.entry = {.count = 1, .reusable = false}}, SHIFT(375),
  [501] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13878),
  [503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14376),
  [505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(267),
  [507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3532),
  [509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15671),
  [511] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15323),
  [513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3398),
  [515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13340),
  [517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12314),
  [519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4459),
  [521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1242),
  [523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3399),
  [525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16692),
  [527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3043),
  [529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2671),
  [531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1654),
  [535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3428),
  [537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3098),
  [539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10635),
  [541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4833),
  [543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1651),
  [545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(367),
  [547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(409),
  [549] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2604),
  [551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(416),
  [553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13976),
  [555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14303),
  [557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(274),
  [559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3704),
  [561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15769),
  [563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15307),
  [565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3429),
  [567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13350),
  [569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12322),
  [571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4402),
  [573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1254),
  [575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3431),
  [577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16679),
  [579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3243),
  [581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2674),
  [583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1640),
  [587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3468),
  [589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2966),
  [591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10467),
  [593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4864),
  [595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1516),
  [597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(446),
  [599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(355),
  [601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2631),
  [603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(356),
  [605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13935),
  [607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14332),
  [609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(264),
  [611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3461),
  [613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16159),
  [615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16419),
  [617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3469),
  [619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13300),
  [621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12318),
  [623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4361),
  [625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(982),
  [627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3470),
  [629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17490),
  [631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13197),
  [633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3101),
  [635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2676),
  [637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [639] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1707),
  [641] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3721),
  [643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3304),
  [645] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10428),
  [647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4859),
  [649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1638),
  [651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(385),
  [653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(378),
  [655] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2630),
  [657] = {.entry = {.count = 1, .reusable = false}}, SHIFT(380),
  [659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14062),
  [661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14242),
  [663] = {.entry = {.count = 1, .reusable = false}}, SHIFT(287),
  [665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3727),
  [667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15627),
  [669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15306),
  [671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3696),
  [673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13369),
  [675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12308),
  [677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4462),
  [679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(927),
  [681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3695),
  [683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17436),
  [685] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__structure, 3, 0, 0),
  [687] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__structure, 4, 0, 0),
  [689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3392),
  [691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2682),
  [693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1509),
  [697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3893),
  [699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3057),
  [701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10445),
  [703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4795),
  [705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1642),
  [707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(300),
  [709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(474),
  [711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2641),
  [713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(471),
  [715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13989),
  [717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14296),
  [719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(294),
  [721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3957),
  [723] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15439),
  [725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15699),
  [727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3891),
  [729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13266),
  [731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12255),
  [733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4271),
  [735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(629),
  [737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3887),
  [739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16946),
  [741] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__structure, 3, 0, 0),
  [743] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__structure, 1, 0, 0),
  [745] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__structure, 2, 0, 0),
  [747] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__structure, 1, 0, 0),
  [749] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__structure, 2, 0, 0),
  [751] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__structure, 4, 0, 0),
  [753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3320),
  [755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2658),
  [757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1670),
  [761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3786),
  [763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2994),
  [765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10448),
  [767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4798),
  [769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1671),
  [771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(303),
  [773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(469),
  [775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2643),
  [777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(466),
  [779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13978),
  [781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14294),
  [783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(249),
  [785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3838),
  [787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15495),
  [789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15485),
  [791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3781),
  [793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13378),
  [795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12215),
  [797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4217),
  [799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(621),
  [801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3779),
  [803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16879),
  [805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3908),
  [807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2664),
  [809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1579),
  [813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4134),
  [815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3295),
  [817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10517),
  [819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4809),
  [821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1578),
  [823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(319),
  [825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(381),
  [827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2628),
  [829] = {.entry = {.count = 1, .reusable = false}}, SHIFT(382),
  [831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14097),
  [833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14222),
  [835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(272),
  [837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4161),
  [839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15663),
  [841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16060),
  [843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4171),
  [845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13273),
  [847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12386),
  [849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4296),
  [851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(915),
  [853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4076),
  [855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17438),
  [857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3929),
  [859] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2689),
  [861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1681),
  [865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4020),
  [867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3155),
  [869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10370),
  [871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4818),
  [873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1682),
  [875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(417),
  [877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(362),
  [879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2617),
  [881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(363),
  [883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13939),
  [885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14333),
  [887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(279),
  [889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4041),
  [891] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15933),
  [893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15109),
  [895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4022),
  [897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13337),
  [899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12417),
  [901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4205),
  [903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(967),
  [905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4032),
  [907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17560),
  [909] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2663),
  [911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2683),
  [913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4703),
  [915] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2653),
  [917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [919] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1723),
  [921] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4790),
  [923] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3226),
  [925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10658),
  [927] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4831),
  [929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1724),
  [931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(333),
  [933] = {.entry = {.count = 1, .reusable = false}}, SHIFT(357),
  [935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13892),
  [937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(432),
  [939] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2602),
  [941] = {.entry = {.count = 1, .reusable = false}}, SHIFT(434),
  [943] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3813),
  [945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3811),
  [947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14003),
  [949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14283),
  [951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(276),
  [953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4865),
  [955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15558),
  [957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15549),
  [959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4789),
  [961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13393),
  [963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12244),
  [965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4477),
  [967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(883),
  [969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4788),
  [971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16804),
  [973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2656),
  [975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4883),
  [977] = {.entry = {.count = 1, .reusable = false}}, SHIFT(460),
  [979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(402),
  [981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13934),
  [983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(454),
  [985] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2626),
  [987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(447),
  [989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3802),
  [991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3795),
  [993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(601),
  [995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4829),
  [997] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2677),
  [999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [1001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1545),
  [1003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4913),
  [1005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3130),
  [1007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10700),
  [1009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4860),
  [1011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1544),
  [1013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(426),
  [1015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(310),
  [1017] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2621),
  [1019] = {.entry = {.count = 1, .reusable = false}}, SHIFT(311),
  [1021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13971),
  [1023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14352),
  [1025] = {.entry = {.count = 1, .reusable = false}}, SHIFT(266),
  [1027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4984),
  [1029] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15772),
  [1031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15383),
  [1033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4914),
  [1035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13274),
  [1037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12530),
  [1039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4358),
  [1041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(578),
  [1043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4915),
  [1045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17323),
  [1047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2694),
  [1049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4785),
  [1051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(440),
  [1053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(314),
  [1055] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2609),
  [1057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(320),
  [1059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1050),
  [1061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5093),
  [1063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2662),
  [1065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [1067] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1510),
  [1069] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5225),
  [1071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3045),
  [1073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10480),
  [1075] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4845),
  [1077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1703),
  [1079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(425),
  [1081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(318),
  [1083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2619),
  [1085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(317),
  [1087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14088),
  [1089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14235),
  [1091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(261),
  [1093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5216),
  [1095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16388),
  [1097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15649),
  [1099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15328),
  [1101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5152),
  [1103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13334),
  [1105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12292),
  [1107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4415),
  [1109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1058),
  [1111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5207),
  [1113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16705),
  [1115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4964),
  [1117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2699),
  [1119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [1121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1539),
  [1123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5116),
  [1125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3254),
  [1127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10631),
  [1129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4780),
  [1131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1543),
  [1133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(399),
  [1135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(414),
  [1137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2640),
  [1139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(415),
  [1141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3911),
  [1143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3941),
  [1145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14129),
  [1147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14175),
  [1149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(275),
  [1151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5003),
  [1153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15210),
  [1155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16061),
  [1157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5115),
  [1159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13373),
  [1161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12603),
  [1163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4359),
  [1165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(832),
  [1167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5101),
  [1169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17329),
  [1171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5307),
  [1173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2678),
  [1175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [1177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1553),
  [1179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5343),
  [1181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3249),
  [1183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10646),
  [1185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4791),
  [1187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1554),
  [1189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(377),
  [1191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(420),
  [1193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2603),
  [1195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(421),
  [1197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13866),
  [1199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14380),
  [1201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(262),
  [1203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5411),
  [1205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15226),
  [1207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15979),
  [1209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5333),
  [1211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13413),
  [1213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12615),
  [1215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4242),
  [1217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(821),
  [1219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5358),
  [1221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17282),
  [1223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5011),
  [1225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2668),
  [1227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [1229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1766),
  [1231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5281),
  [1233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3202),
  [1235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10450),
  [1237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4828),
  [1239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1762),
  [1241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(401),
  [1243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(445),
  [1245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2629),
  [1247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(439),
  [1249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14048),
  [1251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14241),
  [1253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(252),
  [1255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5299),
  [1257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15464),
  [1259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15770),
  [1261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5267),
  [1263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13385),
  [1265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12465),
  [1267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4292),
  [1269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1308),
  [1271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5249),
  [1273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16837),
  [1275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15907),
  [1277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5447),
  [1279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2654),
  [1281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [1283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1728),
  [1285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5621),
  [1287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2970),
  [1289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10567),
  [1291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4800),
  [1293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1725),
  [1295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(327),
  [1297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(441),
  [1299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14047),
  [1301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(326),
  [1303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2607),
  [1305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(325),
  [1307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3851),
  [1309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3850),
  [1311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14153),
  [1313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14174),
  [1315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(280),
  [1317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5700),
  [1319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15645),
  [1321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15374),
  [1323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5619),
  [1325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13241),
  [1327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12268),
  [1329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4446),
  [1331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1046),
  [1333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5618),
  [1335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16718),
  [1337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5602),
  [1339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2687),
  [1341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [1343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1524),
  [1345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5838),
  [1347] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3256),
  [1349] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10606),
  [1351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4797),
  [1353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1525),
  [1355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(435),
  [1357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(389),
  [1359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2646),
  [1361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(393),
  [1363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13864),
  [1365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14386),
  [1367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(291),
  [1369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5778),
  [1371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15193),
  [1373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16072),
  [1375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5839),
  [1377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13376),
  [1379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12580),
  [1381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4266),
  [1383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(899),
  [1385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5840),
  [1387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17384),
  [1389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2695),
  [1391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4880),
  [1393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(453),
  [1395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5777),
  [1397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2673),
  [1399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [1401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1768),
  [1403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6002),
  [1405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3065),
  [1407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10457),
  [1409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4893),
  [1411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1770),
  [1413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(486),
  [1415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(348),
  [1417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2623),
  [1419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(345),
  [1421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13968),
  [1423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14310),
  [1425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(271),
  [1427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6138),
  [1429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15607),
  [1431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15523),
  [1433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6003),
  [1435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13317),
  [1437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12265),
  [1439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4437),
  [1441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(995),
  [1443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6004),
  [1445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16748),
  [1447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2670),
  [1449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4843),
  [1451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(296),
  [1453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6020),
  [1455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20370),
  [1457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11374),
  [1459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19889),
  [1461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8165),
  [1463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4011),
  [1465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19771),
  [1467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20475),
  [1469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20477),
  [1471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20475),
  [1473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4532),
  [1475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [1477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7877),
  [1479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20344),
  [1481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11622),
  [1483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17719),
  [1485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3974),
  [1487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17850),
  [1489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4529),
  [1491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(538),
  [1493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9848),
  [1495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20358),
  [1497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11328),
  [1499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19070),
  [1501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4090),
  [1503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18974),
  [1505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4520),
  [1507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(547),
  [1509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7303),
  [1511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20335),
  [1513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11449),
  [1515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18367),
  [1517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4131),
  [1519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18548),
  [1521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4512),
  [1523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [1525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4331),
  [1527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20245),
  [1529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11585),
  [1531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20128),
  [1533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4082),
  [1535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20130),
  [1537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4516),
  [1539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(544),
  [1541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6012),
  [1543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2685),
  [1545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [1547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1713),
  [1549] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6622),
  [1551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2967),
  [1553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10404),
  [1555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4840),
  [1557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1712),
  [1559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(448),
  [1561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(372),
  [1563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2647),
  [1565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(374),
  [1567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13850),
  [1569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14390),
  [1571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(285),
  [1573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6303),
  [1575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15154),
  [1577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15257),
  [1579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6624),
  [1581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13419),
  [1583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12258),
  [1585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4428),
  [1587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(941),
  [1589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6626),
  [1591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17545),
  [1593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5845),
  [1595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20352),
  [1597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11392),
  [1599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18283),
  [1601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4170),
  [1603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18136),
  [1605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4486),
  [1607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(510),
  [1609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6854),
  [1611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20327),
  [1613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11523),
  [1615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19184),
  [1617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4086),
  [1619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19329),
  [1621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4534),
  [1623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(545),
  [1625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4404),
  [1627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20273),
  [1629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11407),
  [1631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19984),
  [1633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4060),
  [1635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19986),
  [1637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4511),
  [1639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(529),
  [1641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6229),
  [1643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20357),
  [1645] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11331),
  [1647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18977),
  [1649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4030),
  [1651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18813),
  [1653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4496),
  [1655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(540),
  [1657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5615),
  [1659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20372),
  [1661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11520),
  [1663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19988),
  [1665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4101),
  [1667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19883),
  [1669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4502),
  [1671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(511),
  [1673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3144),
  [1675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20368),
  [1677] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11302),
  [1679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19737),
  [1681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4135),
  [1683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19654),
  [1685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4550),
  [1687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(546),
  [1689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7694),
  [1691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20365),
  [1693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11233),
  [1695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19482),
  [1697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4157),
  [1699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19505),
  [1701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4521),
  [1703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(507),
  [1705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3007),
  [1707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20371),
  [1709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11429),
  [1711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19943),
  [1713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4182),
  [1715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19845),
  [1717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4526),
  [1719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(500),
  [1721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7380),
  [1723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3190),
  [1725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6774),
  [1727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20366),
  [1729] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11224),
  [1731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19661),
  [1733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4126),
  [1735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19550),
  [1737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4497),
  [1739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(502),
  [1741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3614),
  [1743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20375),
  [1745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11672),
  [1747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20083),
  [1749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4181),
  [1751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20012),
  [1753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4485),
  [1755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(541),
  [1757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9629),
  [1759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4784),
  [1761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20367),
  [1763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11220),
  [1765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19729),
  [1767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4106),
  [1769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19603),
  [1771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4491),
  [1773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(501),
  [1775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4925),
  [1777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20337),
  [1779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11602),
  [1781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18197),
  [1783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4089),
  [1785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18373),
  [1787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4494),
  [1789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [1791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6936),
  [1793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7524),
  [1795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6359),
  [1797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20359),
  [1799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11317),
  [1801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19138),
  [1803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3985),
  [1805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19069),
  [1807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4488),
  [1809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(534),
  [1811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5065),
  [1813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20353),
  [1815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11379),
  [1817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18412),
  [1819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4049),
  [1821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18278),
  [1823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4495),
  [1825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [1827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4100),
  [1829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20346),
  [1831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11592),
  [1833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17615),
  [1835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4039),
  [1837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17725),
  [1839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4547),
  [1841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(548),
  [1843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7032),
  [1845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20330),
  [1847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11250),
  [1849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18912),
  [1851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4012),
  [1853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19047),
  [1855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4500),
  [1857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(513),
  [1859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4165),
  [1861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7073),
  [1863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3435),
  [1865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6545),
  [1867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9260),
  [1869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20351),
  [1871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11414),
  [1873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18541),
  [1875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4083),
  [1877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18039),
  [1879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4498),
  [1881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(499),
  [1883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6460),
  [1885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20356),
  [1887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11341),
  [1889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18814),
  [1891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4109),
  [1893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18688),
  [1895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4510),
  [1897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(550),
  [1899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6682),
  [1901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20364),
  [1903] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11239),
  [1905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19508),
  [1907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4017),
  [1909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19464),
  [1911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4539),
  [1913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(518),
  [1915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4482),
  [1917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6866),
  [1919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20328),
  [1921] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11353),
  [1923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19038),
  [1925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4146),
  [1927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19257),
  [1929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4538),
  [1931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(530),
  [1933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6964),
  [1935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5743),
  [1937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6222),
  [1939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7402),
  [1941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20478),
  [1943] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11543),
  [1945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19403),
  [1947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4149),
  [1949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20476),
  [1951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4523),
  [1953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(509),
  [1955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5018),
  [1957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3125),
  [1959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5236),
  [1961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20373),
  [1963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11625),
  [1965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20014),
  [1967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3976),
  [1969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19941),
  [1971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4501),
  [1973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(519),
  [1975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6509),
  [1977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20369),
  [1979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11327),
  [1981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19852),
  [1983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4069),
  [1985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19725),
  [1987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4541),
  [1989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(535),
  [1991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7167),
  [1993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4916),
  [1995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4222),
  [1997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6738),
  [1999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20347),
  [2001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11558),
  [2003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17715),
  [2005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4023),
  [2007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17660),
  [2009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4484),
  [2011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(539),
  [2013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6066),
  [2015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3948),
  [2017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20363),
  [2019] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11269),
  [2021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19469),
  [2023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3983),
  [2025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19416),
  [2027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4549),
  [2029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(520),
  [2031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5338),
  [2033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20354),
  [2035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11368),
  [2037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18534),
  [2039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4176),
  [2041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18331),
  [2043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4508),
  [2045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(533),
  [2047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3746),
  [2049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20374),
  [2051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11684),
  [2053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20112),
  [2055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4095),
  [2057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19985),
  [2059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4483),
  [2061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(531),
  [2063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6595),
  [2065] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2661),
  [2067] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4805),
  [2069] = {.entry = {.count = 1, .reusable = false}}, SHIFT(350),
  [2071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(423),
  [2073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2611),
  [2075] = {.entry = {.count = 1, .reusable = false}}, SHIFT(424),
  [2077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(813),
  [2079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20329),
  [2081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4034),
  [2083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19187),
  [2085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4519),
  [2087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(521),
  [2089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6403),
  [2091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20360),
  [2093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11310),
  [2095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19221),
  [2097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4105),
  [2099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19136),
  [2101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4533),
  [2103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(532),
  [2105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11975),
  [2107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4879),
  [2109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3776),
  [2111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5978),
  [2113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20362),
  [2115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11277),
  [2117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19418),
  [2119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4050),
  [2121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19368),
  [2123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4552),
  [2125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(522),
  [2127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4019),
  [2129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20350),
  [2131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11461),
  [2133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18137),
  [2135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3991),
  [2137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17868),
  [2139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4513),
  [2141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(516),
  [2143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5322),
  [2145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6888),
  [2147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20342),
  [2149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11711),
  [2151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17845),
  [2153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4004),
  [2155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17978),
  [2157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4514),
  [2159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [2161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6314),
  [2163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8012),
  [2165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6046),
  [2167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5219),
  [2169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20318),
  [2171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11404),
  [2173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19486),
  [2175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4068),
  [2177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19596),
  [2179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4545),
  [2181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(536),
  [2183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6918),
  [2185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7132),
  [2187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20324),
  [2189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11682),
  [2191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19255),
  [2193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4074),
  [2195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19405),
  [2197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4493),
  [2199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(527),
  [2201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7229),
  [2203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5193),
  [2205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3981),
  [2207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7556),
  [2209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6085),
  [2211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20355),
  [2213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11350),
  [2215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18692),
  [2217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4028),
  [2219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18532),
  [2221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4536),
  [2223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(524),
  [2225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6713),
  [2227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9130),
  [2229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3554),
  [2231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20349),
  [2233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11502),
  [2235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18013),
  [2237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4057),
  [2239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17711),
  [2241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4518),
  [2243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(523),
  [2245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3943),
  [2247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20361),
  [2249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11301),
  [2251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19370),
  [2253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4073),
  [2255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19215),
  [2257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4489),
  [2259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [2261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3374),
  [2263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20343),
  [2265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11663),
  [2267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17784),
  [2269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4124),
  [2271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17912),
  [2273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4515),
  [2275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(526),
  [2277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6632),
  [2279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20348),
  [2281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11544),
  [2283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17870),
  [2285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4065),
  [2287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17620),
  [2289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4528),
  [2291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [2293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5900),
  [2295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5821),
  [2297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3408),
  [2299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5892),
  [2301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2692),
  [2303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [2305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1580),
  [2307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6580),
  [2309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3235),
  [2311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10645),
  [2313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4898),
  [2315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1581),
  [2317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(418),
  [2319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(306),
  [2321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2614),
  [2323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(422),
  [2325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13948),
  [2327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14328),
  [2329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(259),
  [2331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6539),
  [2333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15311),
  [2335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15801),
  [2337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6581),
  [2339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13264),
  [2341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12598),
  [2343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4368),
  [2345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1089),
  [2347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6583),
  [2349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17174),
  [2351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5162),
  [2353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5895),
  [2355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2681),
  [2357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [2359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1591),
  [2361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6563),
  [2363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3219),
  [2365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10601),
  [2367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4814),
  [2369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1592),
  [2371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(391),
  [2373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(308),
  [2375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2638),
  [2377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(312),
  [2379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13876),
  [2381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14377),
  [2383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(246),
  [2385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6357),
  [2387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15322),
  [2389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15791),
  [2391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6562),
  [2393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13285),
  [2395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12561),
  [2397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4290),
  [2399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1120),
  [2401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6559),
  [2403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17128),
  [2405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6182),
  [2407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3526),
  [2409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3880),
  [2411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3474),
  [2413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6025),
  [2415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2690),
  [2417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [2419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1612),
  [2421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6389),
  [2423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3150),
  [2425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10504),
  [2427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4793),
  [2429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1614),
  [2431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(387),
  [2433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(336),
  [2435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2635),
  [2437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(349),
  [2439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14083),
  [2441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14239),
  [2443] = {.entry = {.count = 1, .reusable = false}}, SHIFT(268),
  [2445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6162),
  [2447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15396),
  [2449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15759),
  [2451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6388),
  [2453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13278),
  [2455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12404),
  [2457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4333),
  [2459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1172),
  [2461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6383),
  [2463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17031),
  [2465] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5920),
  [2467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2669),
  [2469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [2471] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1750),
  [2473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6528),
  [2475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3204),
  [2477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10447),
  [2479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4778),
  [2481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1751),
  [2483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(484),
  [2485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(339),
  [2487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2648),
  [2489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(346),
  [2491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13845),
  [2493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14398),
  [2495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(255),
  [2497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6258),
  [2499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15585),
  [2501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15524),
  [2503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6523),
  [2505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13304),
  [2507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12251),
  [2509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4389),
  [2511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(591),
  [2513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6521),
  [2515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16766),
  [2517] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5907),
  [2519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2651),
  [2521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [2523] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1628),
  [2525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6660),
  [2527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3086),
  [2529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10494),
  [2531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4839),
  [2533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1629),
  [2535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(379),
  [2537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(359),
  [2539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2625),
  [2541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(361),
  [2543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14133),
  [2545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14190),
  [2547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(250),
  [2549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6255),
  [2551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15414),
  [2553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15704),
  [2555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6503),
  [2557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13243),
  [2559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12290),
  [2561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4314),
  [2563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1178),
  [2565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6491),
  [2567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16996),
  [2569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6427),
  [2571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7216),
  [2573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2672),
  [2575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4872),
  [2577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(386),
  [2579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(461),
  [2581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2636),
  [2583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(463),
  [2585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(736),
  [2587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6546),
  [2589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2667),
  [2591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [2593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1577),
  [2595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6954),
  [2597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3305),
  [2599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10509),
  [2601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4855),
  [2603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1576),
  [2605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(455),
  [2607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(482),
  [2609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2620),
  [2611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(475),
  [2613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13945),
  [2615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14311),
  [2617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(263),
  [2619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7138),
  [2621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16447),
  [2623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16206),
  [2625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6956),
  [2627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13295),
  [2629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12599),
  [2631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4398),
  [2633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(637),
  [2635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6958),
  [2637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17038),
  [2639] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6183),
  [2641] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2693),
  [2643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [2645] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1756),
  [2647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6712),
  [2649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3231),
  [2651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10374),
  [2653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4886),
  [2655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1757),
  [2657] = {.entry = {.count = 1, .reusable = false}}, SHIFT(485),
  [2659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(368),
  [2661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2615),
  [2663] = {.entry = {.count = 1, .reusable = false}}, SHIFT(369),
  [2665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13899),
  [2667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14397),
  [2669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(257),
  [2671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7113),
  [2673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15718),
  [2675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15141),
  [2677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6748),
  [2679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13388),
  [2681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12243),
  [2683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4381),
  [2685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(953),
  [2687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6747),
  [2689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17587),
  [2691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6605),
  [2693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2698),
  [2695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [2697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1594),
  [2699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6898),
  [2701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3276),
  [2703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10617),
  [2705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4896),
  [2707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1593),
  [2709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(398),
  [2711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(468),
  [2713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2645),
  [2715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(476),
  [2717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13947),
  [2719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14396),
  [2721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(256),
  [2723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7067),
  [2725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16322),
  [2727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16324),
  [2729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6887),
  [2731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13319),
  [2733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12311),
  [2735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4289),
  [2737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(714),
  [2739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6869),
  [2741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16957),
  [2743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6617),
  [2745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2696),
  [2747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [2749] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1625),
  [2751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6944),
  [2753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3264),
  [2755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10385),
  [2757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4861),
  [2759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1624),
  [2761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(341),
  [2763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(449),
  [2765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2618),
  [2767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(451),
  [2769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13852),
  [2771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14371),
  [2773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(281),
  [2775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7193),
  [2777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16032),
  [2779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16459),
  [2781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6942),
  [2783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13322),
  [2785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12551),
  [2787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4436),
  [2789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(749),
  [2791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6886),
  [2793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16931),
  [2795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2680),
  [2797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4878),
  [2799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(442),
  [2801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(410),
  [2803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2649),
  [2805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(400),
  [2807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1241),
  [2809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6404),
  [2811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2659),
  [2813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [2815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1666),
  [2817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7144),
  [2819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3244),
  [2821] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10487),
  [2823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4846),
  [2825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1665),
  [2827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(297),
  [2829] = {.entry = {.count = 1, .reusable = false}}, SHIFT(436),
  [2831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2624),
  [2833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(437),
  [2835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13855),
  [2837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14388),
  [2839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(277),
  [2841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7128),
  [2843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15762),
  [2845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15536),
  [2847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7137),
  [2849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13251),
  [2851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12345),
  [2853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4421),
  [2855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(784),
  [2857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6941),
  [2859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16927),
  [2861] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2691),
  [2863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4827),
  [2865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(329),
  [2867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(427),
  [2869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2650),
  [2871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(429),
  [2873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(805),
  [2875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2665),
  [2877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4850),
  [2879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(331),
  [2881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(443),
  [2883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2613),
  [2885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(444),
  [2887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(769),
  [2889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2655),
  [2891] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4799),
  [2893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(438),
  [2895] = {.entry = {.count = 1, .reusable = false}}, SHIFT(496),
  [2897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2622),
  [2899] = {.entry = {.count = 1, .reusable = false}}, SHIFT(498),
  [2901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(647),
  [2903] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2679),
  [2905] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4815),
  [2907] = {.entry = {.count = 1, .reusable = false}}, SHIFT(366),
  [2909] = {.entry = {.count = 1, .reusable = false}}, SHIFT(304),
  [2911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2610),
  [2913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(307),
  [2915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1069),
  [2917] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2675),
  [2919] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4819),
  [2921] = {.entry = {.count = 1, .reusable = false}}, SHIFT(467),
  [2923] = {.entry = {.count = 1, .reusable = false}}, SHIFT(299),
  [2925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2632),
  [2927] = {.entry = {.count = 1, .reusable = false}}, SHIFT(298),
  [2929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1093),
  [2931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2652),
  [2933] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4866),
  [2935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(358),
  [2937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(383),
  [2939] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2606),
  [2941] = {.entry = {.count = 1, .reusable = false}}, SHIFT(371),
  [2943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1191),
  [2945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2697),
  [2947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4842),
  [2949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(337),
  [2951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(316),
  [2953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2608),
  [2955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(315),
  [2957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1108),
  [2959] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7167),
  [2961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6545),
  [2963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8012),
  [2965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3776),
  [2967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6403),
  [2969] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5193),
  [2971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4222),
  [2973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6509),
  [2975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6866),
  [2977] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6738),
  [2979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6595),
  [2981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5236),
  [2983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5338),
  [2985] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6964),
  [2987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3474),
  [2989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6046),
  [2991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4925),
  [2993] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3408),
  [2995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6359),
  [2997] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7556),
  [2999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6888),
  [3001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6020),
  [3003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3981),
  [3005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9260),
  [3007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3435),
  [3009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5065),
  [3011] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4784),
  [3013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7132),
  [3015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6085),
  [3017] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4100),
  [3019] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5615),
  [3021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6936),
  [3023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7524),
  [3025] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7380),
  [3027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3190),
  [3029] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6632),
  [3031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11975),
  [3033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3526),
  [3035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3125),
  [3037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7073),
  [3039] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5845),
  [3041] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4331),
  [3043] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9848),
  [3045] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3880),
  [3047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10607),
  [3049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3088),
  [3051] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0),
  [3053] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0),
  [3055] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17367),
  [3057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13375),
  [3059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18852),
  [3061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4229),
  [3063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12525),
  [3065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8170),
  [3067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16120),
  [3069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15805),
  [3071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8218),
  [3073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15772),
  [3075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15383),
  [3077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2982),
  [3079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17530),
  [3081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13284),
  [3083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18452),
  [3085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4232),
  [3087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15495),
  [3089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15485),
  [3091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15439),
  [3093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15699),
  [3095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16227),
  [3097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16386),
  [3099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16159),
  [3101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16419),
  [3103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15933),
  [3105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15109),
  [3107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15582),
  [3109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15526),
  [3111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15558),
  [3113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15549),
  [3115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15663),
  [3117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16060),
  [3119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15611),
  [3121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15520),
  [3123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15671),
  [3125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15323),
  [3127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15769),
  [3129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15307),
  [3131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15627),
  [3133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15306),
  [3135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9223),
  [3137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3127),
  [3139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4816),
  [3141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7244),
  [3143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4970),
  [3145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8126),
  [3147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3367),
  [3149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17227),
  [3151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13404),
  [3153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18521),
  [3155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4440),
  [3157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3355),
  [3159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17211),
  [3161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13414),
  [3163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19162),
  [3165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4433),
  [3167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7498),
  [3169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7433),
  [3171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9401),
  [3173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5764),
  [3175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5646),
  [3177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5043),
  [3179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6897),
  [3181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8262),
  [3183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5944),
  [3185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4075),
  [3187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7087),
  [3189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7199),
  [3191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5200),
  [3193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3930),
  [3195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7578),
  [3197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6143),
  [3199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3544),
  [3201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6105),
  [3203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3969),
  [3205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3365),
  [3207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7114),
  [3209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6370),
  [3211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4453),
  [3213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6833),
  [3215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3344),
  [3217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6611),
  [3219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5410),
  [3221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6361),
  [3223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6576),
  [3225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5290),
  [3227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10651),
  [3229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8044),
  [3231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6838),
  [3233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6654),
  [3235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3368),
  [3237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3471),
  [3239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17065),
  [3241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13344),
  [3243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18998),
  [3245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4363),
  [3247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7955),
  [3249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4209),
  [3251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6909),
  [3253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3107),
  [3255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9538),
  [3257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4168),
  [3259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3339),
  [3261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17154),
  [3263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13374),
  [3265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19283),
  [3267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4399),
  [3269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6650),
  [3271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3899),
  [3273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17575),
  [3275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13275),
  [3277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17766),
  [3279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4214),
  [3281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3927),
  [3283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17552),
  [3285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13416),
  [3287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17645),
  [3289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4264),
  [3291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3922),
  [3293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5304),
  [3295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9163),
  [3297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9147),
  [3299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9103),
  [3301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9087),
  [3303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6771),
  [3305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3448),
  [3307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9270),
  [3309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6758),
  [3311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6759),
  [3313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3384),
  [3315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3378),
  [3317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6762),
  [3319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4411),
  [3321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5779),
  [3323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5781),
  [3325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6851),
  [3327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4151),
  [3329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17299),
  [3331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13277),
  [3333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18432),
  [3335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4288),
  [3337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6861),
  [3339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4231),
  [3341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5814),
  [3343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5818),
  [3345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4929),
  [3347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4904),
  [3349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5825),
  [3351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3369),
  [3353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5830),
  [3355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4920),
  [3357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4931),
  [3359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5009),
  [3361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3984),
  [3363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3364),
  [3365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3989),
  [3367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5014),
  [3369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4983),
  [3371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4988),
  [3373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5059),
  [3375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5033),
  [3377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5038),
  [3379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5057),
  [3381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7295),
  [3383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4035),
  [3385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7298),
  [3387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5393),
  [3389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5391),
  [3391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7306),
  [3393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7309),
  [3395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7341),
  [3397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4044),
  [3399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7343),
  [3401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5320),
  [3403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5328),
  [3405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5340),
  [3407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5348),
  [3409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4305),
  [3411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4377),
  [3413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5901),
  [3415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5893),
  [3417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7009),
  [3419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7014),
  [3421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7042),
  [3423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7047),
  [3425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5888),
  [3427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5896),
  [3429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5905),
  [3431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5913),
  [3433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7126),
  [3435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7129),
  [3437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4128),
  [3439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4130),
  [3441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6520),
  [3443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6516),
  [3445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4026),
  [3447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17132),
  [3449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13359),
  [3451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18782),
  [3453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4367),
  [3455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7202),
  [3457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7205),
  [3459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7227),
  [3461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7231),
  [3463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6470),
  [3465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6467),
  [3467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6454),
  [3469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6431),
  [3471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6327),
  [3473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6326),
  [3475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7145),
  [3477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7123),
  [3479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6243),
  [3481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6235),
  [3483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6217),
  [3485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6191),
  [3487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8035),
  [3489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9737),
  [3491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3520),
  [3493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3536),
  [3495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9733),
  [3497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8030),
  [3499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4346),
  [3501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4276),
  [3503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9641),
  [3505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9631),
  [3507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9619),
  [3509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9587),
  [3511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7265),
  [3513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6173),
  [3515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3560),
  [3517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6175),
  [3519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6830),
  [3521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4335),
  [3523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3573),
  [3525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6863),
  [3527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6880),
  [3529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4317),
  [3531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6215),
  [3533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6218),
  [3535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4435),
  [3537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7116),
  [3539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7125),
  [3541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6227),
  [3543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6230),
  [3545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6265),
  [3547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6267),
  [3549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6307),
  [3551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6310),
  [3553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3607),
  [3555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3609),
  [3557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6319),
  [3559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6322),
  [3561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3628),
  [3563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3630),
  [3565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3698),
  [3567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5728),
  [3569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3454),
  [3571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9265),
  [3573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3921),
  [3575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7944),
  [3577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7902),
  [3579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3952),
  [3581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7263),
  [3583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3963),
  [3585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7257),
  [3587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3950),
  [3589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7841),
  [3591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3682),
  [3593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7966),
  [3595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3958),
  [3597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3683),
  [3599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7221),
  [3601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7215),
  [3603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6029),
  [3605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6027),
  [3607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6447),
  [3609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3724),
  [3611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3742),
  [3613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6441),
  [3615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5984),
  [3617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5981),
  [3619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7142),
  [3621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7140),
  [3623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5974),
  [3625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5971),
  [3627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3730),
  [3629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3825),
  [3631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3824),
  [3633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3725),
  [3635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6418),
  [3637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3901),
  [3639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3905),
  [3641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3936),
  [3643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3785),
  [3645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6723),
  [3647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6721),
  [3649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6675),
  [3651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4055),
  [3653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4056),
  [3655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6678),
  [3657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6687),
  [3659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6690),
  [3661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3571),
  [3663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7394),
  [3665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3567),
  [3667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7467),
  [3669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7722),
  [3671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6287),
  [3673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7397),
  [3675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5182),
  [3677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7699),
  [3679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5169),
  [3681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7405),
  [3683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7697),
  [3685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5150),
  [3687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7690),
  [3689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7684),
  [3691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7408),
  [3693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5175),
  [3695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5295),
  [3697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6725),
  [3699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6727),
  [3701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4455),
  [3703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3705),
  [3705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5732),
  [3707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7451),
  [3709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7430),
  [3711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6767),
  [3713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6165),
  [3715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6158),
  [3717] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3088),
  [3720] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48),
  [3722] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48),
  [3724] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17367),
  [3727] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(146),
  [3730] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1752),
  [3733] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3177),
  [3736] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(2976),
  [3739] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10513),
  [3742] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1753),
  [3745] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14028),
  [3748] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14268),
  [3751] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(284),
  [3754] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3052),
  [3757] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15611),
  [3760] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15520),
  [3763] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3178),
  [3766] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13318),
  [3769] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12266),
  [3772] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4238),
  [3775] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3182),
  [3778] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16732),
  [3781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6770),
  [3783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5749),
  [3785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4285),
  [3787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4144),
  [3789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5742),
  [3791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3971),
  [3793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6779),
  [3795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6782),
  [3797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4900),
  [3799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4901),
  [3801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5722),
  [3803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4888),
  [3805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4885),
  [3807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5720),
  [3809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4870),
  [3811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4863),
  [3813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3172),
  [3815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4184),
  [3817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4189),
  [3819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3171),
  [3821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4401),
  [3823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3002),
  [3825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3004),
  [3827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3012),
  [3829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3152),
  [3831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3149),
  [3833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6808),
  [3835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5205),
  [3837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5214),
  [3839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3018),
  [3841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3140),
  [3843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3119),
  [3845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5235),
  [3847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6895),
  [3849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6077),
  [3851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6603),
  [3853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6604),
  [3855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3051),
  [3857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3050),
  [3859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5255),
  [3861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6345),
  [3863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7112),
  [3865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7101),
  [3867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6248),
  [3869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5999),
  [3871] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(2982),
  [3874] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17530),
  [3877] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(172),
  [3880] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1731),
  [3883] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3120),
  [3886] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3275),
  [3889] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10626),
  [3892] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1734),
  [3895] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13913),
  [3898] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14348),
  [3901] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(289),
  [3904] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3176),
  [3907] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15582),
  [3910] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15526),
  [3913] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3121),
  [3916] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13292),
  [3919] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12245),
  [3922] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4457),
  [3925] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3122),
  [3928] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16784),
  [3931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6261),
  [3933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5179),
  [3935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6933),
  [3937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6414),
  [3939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5902),
  [3941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5154),
  [3943] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_application_expression, 2, 0, 27),
  [3945] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_application_expression, 2, 0, 27),
  [3947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6093),
  [3949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6978),
  [3951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6087),
  [3953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6073),
  [3955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4472),
  [3957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16668),
  [3959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13360),
  [3961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20100),
  [3963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4395),
  [3965] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3367),
  [3968] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17227),
  [3971] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(219),
  [3974] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1707),
  [3977] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3721),
  [3980] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3304),
  [3983] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10428),
  [3986] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1638),
  [3989] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14062),
  [3992] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14242),
  [3995] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(287),
  [3998] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3727),
  [4001] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15627),
  [4004] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15306),
  [4007] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3696),
  [4010] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13369),
  [4013] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12308),
  [4016] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4462),
  [4019] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3695),
  [4022] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17436),
  [4025] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3355),
  [4028] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17211),
  [4031] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(214),
  [4034] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1688),
  [4037] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3395),
  [4040] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3080),
  [4043] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10586),
  [4046] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1686),
  [4049] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13878),
  [4052] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14376),
  [4055] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(267),
  [4058] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3532),
  [4061] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15671),
  [4064] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15323),
  [4067] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3398),
  [4070] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13340),
  [4073] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12314),
  [4076] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4459),
  [4079] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3399),
  [4082] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16692),
  [4085] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3339),
  [4088] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17154),
  [4091] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(160),
  [4094] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1654),
  [4097] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3428),
  [4100] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3098),
  [4103] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10635),
  [4106] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1651),
  [4109] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13976),
  [4112] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14303),
  [4115] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(274),
  [4118] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3704),
  [4121] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15769),
  [4124] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15307),
  [4127] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3429),
  [4130] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13350),
  [4133] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12322),
  [4136] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4402),
  [4139] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3431),
  [4142] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16679),
  [4145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4251),
  [4147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16565),
  [4149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13421),
  [4151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20427),
  [4153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4400),
  [4155] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3471),
  [4158] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17065),
  [4161] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(221),
  [4164] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1640),
  [4167] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3468),
  [4170] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(2966),
  [4173] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10467),
  [4176] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1516),
  [4179] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13935),
  [4182] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14332),
  [4185] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(264),
  [4188] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3461),
  [4191] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16159),
  [4194] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16419),
  [4197] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3469),
  [4200] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13300),
  [4203] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12318),
  [4206] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4361),
  [4209] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3470),
  [4212] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17490),
  [4215] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3899),
  [4218] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17575),
  [4221] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(189),
  [4224] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1670),
  [4227] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3786),
  [4230] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(2994),
  [4233] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10448),
  [4236] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1671),
  [4239] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13978),
  [4242] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14294),
  [4245] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(249),
  [4248] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3838),
  [4251] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15495),
  [4254] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15485),
  [4257] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3781),
  [4260] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13378),
  [4263] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12215),
  [4266] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4217),
  [4269] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3779),
  [4272] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16879),
  [4275] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3927),
  [4278] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17552),
  [4281] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(220),
  [4284] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1509),
  [4287] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3893),
  [4290] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3057),
  [4293] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10445),
  [4296] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1642),
  [4299] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13989),
  [4302] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14296),
  [4305] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(294),
  [4308] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3957),
  [4311] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15439),
  [4314] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15699),
  [4317] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3891),
  [4320] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13266),
  [4323] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12255),
  [4326] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4271),
  [4329] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3887),
  [4332] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16946),
  [4335] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4151),
  [4338] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17299),
  [4341] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(203),
  [4344] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1579),
  [4347] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4134),
  [4350] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3295),
  [4353] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10517),
  [4356] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1578),
  [4359] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14097),
  [4362] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14222),
  [4365] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(272),
  [4368] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4161),
  [4371] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15663),
  [4374] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16060),
  [4377] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4171),
  [4380] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13273),
  [4383] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12386),
  [4386] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4296),
  [4389] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4076),
  [4392] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17438),
  [4395] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4026),
  [4398] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17132),
  [4401] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(156),
  [4404] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1681),
  [4407] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4020),
  [4410] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3155),
  [4413] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10370),
  [4416] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1682),
  [4419] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13939),
  [4422] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14333),
  [4425] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(279),
  [4428] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4041),
  [4431] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15933),
  [4434] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15109),
  [4437] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4022),
  [4440] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13337),
  [4443] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12417),
  [4446] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4205),
  [4449] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4032),
  [4452] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17560),
  [4455] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4472),
  [4458] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16668),
  [4461] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(177),
  [4464] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1564),
  [4467] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4275),
  [4470] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3220),
  [4473] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10515),
  [4476] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1565),
  [4479] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14082),
  [4482] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14232),
  [4485] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(254),
  [4488] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4413),
  [4491] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16227),
  [4494] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16386),
  [4497] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4304),
  [4500] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13390),
  [4503] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12527),
  [4506] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4211),
  [4509] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4357),
  [4512] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16661),
  [4515] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4251),
  [4518] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16565),
  [4521] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(134),
  [4524] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1523),
  [4527] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4353),
  [4530] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3082),
  [4533] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10618),
  [4536] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1529),
  [4539] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14115),
  [4542] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14199),
  [4545] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(292),
  [4548] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4315),
  [4551] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16120),
  [4554] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15805),
  [4557] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4319),
  [4560] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13392),
  [4563] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12449),
  [4566] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4424),
  [4569] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4471),
  [4572] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16530),
  [4575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4813),
  [4577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17580),
  [4579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13415),
  [4581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18318),
  [4583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4479),
  [4585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4968),
  [4587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16936),
  [4589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13313),
  [4591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19238),
  [4593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4334),
  [4595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5045),
  [4597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17396),
  [4599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13348),
  [4601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18170),
  [4603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4354),
  [4605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5272),
  [4607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16710),
  [4609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13255),
  [4611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19960),
  [4613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4387),
  [4615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5204),
  [4617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17261),
  [4619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13257),
  [4621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19091),
  [4623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4414),
  [4625] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4813),
  [4628] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17580),
  [4631] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(150),
  [4634] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1723),
  [4637] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4790),
  [4640] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3226),
  [4643] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10658),
  [4646] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1724),
  [4649] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14003),
  [4652] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14283),
  [4655] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(276),
  [4658] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4865),
  [4661] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15558),
  [4664] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15549),
  [4667] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4789),
  [4670] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13393),
  [4673] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12244),
  [4676] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4477),
  [4679] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4788),
  [4682] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16804),
  [4685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5396),
  [4687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17425),
  [4689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13342),
  [4691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18094),
  [4693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4262),
  [4695] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4968),
  [4698] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16936),
  [4701] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(151),
  [4704] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1545),
  [4707] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4913),
  [4710] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3130),
  [4713] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10700),
  [4716] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1544),
  [4719] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13971),
  [4722] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14352),
  [4725] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(266),
  [4728] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4984),
  [4731] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15772),
  [4734] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15383),
  [4737] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4914),
  [4740] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13274),
  [4743] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12530),
  [4746] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4358),
  [4749] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4915),
  [4752] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17323),
  [4755] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5045),
  [4758] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17396),
  [4761] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(155),
  [4764] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1539),
  [4767] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5116),
  [4770] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3254),
  [4773] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10631),
  [4776] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1543),
  [4779] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14129),
  [4782] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14175),
  [4785] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(275),
  [4788] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5003),
  [4791] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15210),
  [4794] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16061),
  [4797] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5115),
  [4800] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13373),
  [4803] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12603),
  [4806] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4359),
  [4809] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5101),
  [4812] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17329),
  [4815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5718),
  [4817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17313),
  [4819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13417),
  [4821] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19020),
  [4823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4450),
  [4825] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5272),
  [4828] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16710),
  [4831] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(202),
  [4834] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1766),
  [4837] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5281),
  [4840] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3202),
  [4843] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10450),
  [4846] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1762),
  [4849] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14048),
  [4852] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14241),
  [4855] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(252),
  [4858] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5299),
  [4861] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15464),
  [4864] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15770),
  [4867] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5267),
  [4870] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13385),
  [4873] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12465),
  [4876] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4292),
  [4879] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5249),
  [4882] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16837),
  [4885] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5204),
  [4888] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17261),
  [4891] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(173),
  [4894] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1510),
  [4897] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5225),
  [4900] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3045),
  [4903] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10480),
  [4906] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1703),
  [4909] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14088),
  [4912] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14235),
  [4915] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(261),
  [4918] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5216),
  [4921] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15649),
  [4924] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15328),
  [4927] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5152),
  [4930] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13334),
  [4933] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12292),
  [4936] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4415),
  [4939] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5207),
  [4942] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16705),
  [4945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10369),
  [4947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2471),
  [4949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8041),
  [4951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16561),
  [4953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3217),
  [4955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12009),
  [4957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20341),
  [4959] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13707),
  [4961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2951),
  [4963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14463),
  [4965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14576),
  [4967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17909),
  [4969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3218),
  [4971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2952),
  [4973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19983),
  [4975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5090),
  [4977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16394),
  [4979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16393),
  [4981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12007),
  [4983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16568),
  [4985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13389),
  [4987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12499),
  [4989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18042),
  [4991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8439),
  [4993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16783),
  [4995] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5396),
  [4998] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17425),
  [5001] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(181),
  [5004] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1553),
  [5007] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5343),
  [5010] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3249),
  [5013] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10646),
  [5016] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1554),
  [5019] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13866),
  [5022] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14380),
  [5025] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(262),
  [5028] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5411),
  [5031] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15226),
  [5034] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15979),
  [5037] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5333),
  [5040] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13413),
  [5043] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12615),
  [5046] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4242),
  [5049] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5358),
  [5052] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17282),
  [5055] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5768),
  [5057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17370),
  [5059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13397),
  [5061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18256),
  [5063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4268),
  [5065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7661),
  [5067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20339),
  [5069] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14744),
  [5071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18040),
  [5073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18200),
  [5075] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5499),
  [5077] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__binding_pattern, 1, 0, 0),
  [5079] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__binding_pattern, 1, 0, 0),
  [5081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2529),
  [5083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4577),
  [5085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5415),
  [5087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13672),
  [5089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14699),
  [5091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4578),
  [5093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4503),
  [5095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19593),
  [5097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15748),
  [5099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15953),
  [5101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5421),
  [5103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19718),
  [5105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13341),
  [5107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12334),
  [5109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5301),
  [5111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17098),
  [5113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7517),
  [5115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20336),
  [5117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15040),
  [5119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18282),
  [5121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18376),
  [5123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13735),
  [5125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20333),
  [5127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14957),
  [5129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18717),
  [5131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18720),
  [5133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10179),
  [5135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20321),
  [5137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14728),
  [5139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19327),
  [5141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19488),
  [5143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14608),
  [5145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19594),
  [5147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7768),
  [5149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20290),
  [5151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15027),
  [5153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19853),
  [5155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19859),
  [5157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5526),
  [5159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2531),
  [5161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4597),
  [5163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5365),
  [5165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13792),
  [5167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14949),
  [5169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4598),
  [5171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4530),
  [5173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20119),
  [5175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15750),
  [5177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15429),
  [5179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5388),
  [5181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20118),
  [5183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13343),
  [5185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12326),
  [5187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5155),
  [5189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16742),
  [5191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8727),
  [5193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20345),
  [5195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14488),
  [5197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17658),
  [5199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17787),
  [5201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5673),
  [5203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2530),
  [5205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4605),
  [5207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5451),
  [5209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13733),
  [5211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14934),
  [5213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4611),
  [5215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4522),
  [5217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19037),
  [5219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15987),
  [5221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15839),
  [5223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5449),
  [5225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19181),
  [5227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13296),
  [5229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12395),
  [5231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5405),
  [5233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17417),
  [5235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5860),
  [5237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17416),
  [5239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13346),
  [5241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18737),
  [5243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4386),
  [5245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5657),
  [5247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2532),
  [5249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4614),
  [5251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5544),
  [5253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13619),
  [5255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14686),
  [5257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4616),
  [5259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4537),
  [5261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19253),
  [5263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15871),
  [5265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15423),
  [5267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5546),
  [5269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19323),
  [5271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13320),
  [5273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12498),
  [5275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5335),
  [5277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17376),
  [5279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20469),
  [5281] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5718),
  [5284] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17313),
  [5287] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(141),
  [5290] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1728),
  [5293] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5621),
  [5296] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(2970),
  [5299] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10567),
  [5302] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1725),
  [5305] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14153),
  [5308] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14174),
  [5311] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(280),
  [5314] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5700),
  [5317] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15645),
  [5320] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15374),
  [5323] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5619),
  [5326] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13241),
  [5329] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12268),
  [5332] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4446),
  [5335] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5618),
  [5338] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16718),
  [5341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6577),
  [5343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17524),
  [5345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13347),
  [5347] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17701),
  [5349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4316),
  [5351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6374),
  [5353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17476),
  [5355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13364),
  [5357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17892),
  [5359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4298),
  [5361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6551),
  [5363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17199),
  [5365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13288),
  [5367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18605),
  [5369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4430),
  [5371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6649),
  [5373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17456),
  [5375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13245),
  [5377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17953),
  [5379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4388),
  [5381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6399),
  [5383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17470),
  [5385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13321),
  [5387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18584),
  [5389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4418),
  [5391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18630),
  [5393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6375),
  [5395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17497),
  [5397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13406),
  [5399] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17765),
  [5401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4213),
  [5403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19554),
  [5405] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5768),
  [5408] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17370),
  [5411] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(136),
  [5414] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1524),
  [5417] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5838),
  [5420] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3256),
  [5423] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10606),
  [5426] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1525),
  [5429] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13864),
  [5432] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14386),
  [5435] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(291),
  [5438] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5778),
  [5441] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15193),
  [5444] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16072),
  [5447] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5839),
  [5450] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13376),
  [5453] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12580),
  [5456] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4266),
  [5459] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5840),
  [5462] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17384),
  [5465] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10167),
  [5467] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 1, 0, 18),
  [5469] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 1, 0, 18),
  [5471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8725),
  [5473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(617),
  [5475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15418),
  [5477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2448),
  [5479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4645),
  [5481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4643),
  [5483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3278),
  [5485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10126),
  [5487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7853),
  [5489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13662),
  [5491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15059),
  [5493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14972),
  [5495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4639),
  [5497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3279),
  [5499] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19803),
  [5501] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16132),
  [5503] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15430),
  [5505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15247),
  [5507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10231),
  [5509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19851),
  [5511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13324),
  [5513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12488),
  [5515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8420),
  [5517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16898),
  [5519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7149),
  [5521] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16749),
  [5523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13259),
  [5525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19695),
  [5527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4283),
  [5529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6858),
  [5531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16862),
  [5533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13246),
  [5535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19384),
  [5537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4207),
  [5539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8723),
  [5541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1132),
  [5543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4655),
  [5545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4654),
  [5547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14995),
  [5549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4653),
  [5551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7022),
  [5553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17167),
  [5555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13384),
  [5557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18691),
  [5559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4379),
  [5561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6900),
  [5563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16831),
  [5565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13381),
  [5567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19468),
  [5569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4191),
  [5571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6947),
  [5573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16791),
  [5575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13242),
  [5577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19571),
  [5579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4364),
  [5581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6103),
  [5583] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_expression, 1, 0, 0),
  [5585] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_expression, 1, 0, 0),
  [5587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17107),
  [5589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [5591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1566),
  [5593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6102),
  [5595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3238),
  [5597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10692),
  [5599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1567),
  [5601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14113),
  [5603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14209),
  [5605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(278),
  [5607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5961),
  [5609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15224),
  [5611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15903),
  [5613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6098),
  [5615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13253),
  [5617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12443),
  [5619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4201),
  [5621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6095),
  [5623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17228),
  [5625] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6147),
  [5628] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17264),
  [5631] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(197),
  [5634] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1657),
  [5637] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6086),
  [5640] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3055),
  [5643] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10363),
  [5646] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1658),
  [5649] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13834),
  [5652] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14402),
  [5655] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(265),
  [5658] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6030),
  [5661] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15475),
  [5664] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15633),
  [5667] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6062),
  [5670] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13396),
  [5673] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12218),
  [5676] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4322),
  [5679] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6059),
  [5682] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16899),
  [5685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6147),
  [5687] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_application, 2, 0, 62),
  [5689] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_application, 2, 0, 62),
  [5691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17264),
  [5693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [5695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1657),
  [5697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6086),
  [5699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3055),
  [5701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10363),
  [5703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1658),
  [5705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13834),
  [5707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14402),
  [5709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(265),
  [5711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6030),
  [5713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15475),
  [5715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15633),
  [5717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6062),
  [5719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13396),
  [5721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12218),
  [5723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4322),
  [5725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6059),
  [5727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16899),
  [5729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8705),
  [5731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(761),
  [5733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4631),
  [5735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4633),
  [5737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14521),
  [5739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4637),
  [5741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8590),
  [5743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(586),
  [5745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4652),
  [5747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4634),
  [5749] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14874),
  [5751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4665),
  [5753] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6103),
  [5756] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17107),
  [5759] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(205),
  [5762] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1566),
  [5765] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6102),
  [5768] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3238),
  [5771] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10692),
  [5774] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1567),
  [5777] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14113),
  [5780] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14209),
  [5783] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(278),
  [5786] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5961),
  [5789] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15224),
  [5792] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15903),
  [5795] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6098),
  [5798] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13253),
  [5801] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12443),
  [5804] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4201),
  [5807] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6095),
  [5810] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17228),
  [5813] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(5860),
  [5816] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17416),
  [5819] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(130),
  [5822] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1768),
  [5825] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6002),
  [5828] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3065),
  [5831] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10457),
  [5834] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1770),
  [5837] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13968),
  [5840] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14310),
  [5843] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(271),
  [5846] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6138),
  [5849] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15607),
  [5852] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15523),
  [5855] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6003),
  [5858] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13317),
  [5861] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12265),
  [5864] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4437),
  [5867] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6004),
  [5870] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16748),
  [5873] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6551),
  [5876] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17199),
  [5879] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(211),
  [5882] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1713),
  [5885] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6622),
  [5888] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(2967),
  [5891] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10404),
  [5894] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1712),
  [5897] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13850),
  [5900] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14390),
  [5903] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(285),
  [5906] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6303),
  [5909] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15154),
  [5912] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15257),
  [5915] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6624),
  [5918] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13419),
  [5921] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12258),
  [5924] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4428),
  [5927] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6626),
  [5930] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17545),
  [5933] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6399),
  [5936] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17470),
  [5939] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(174),
  [5942] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1750),
  [5945] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6528),
  [5948] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3204),
  [5951] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10447),
  [5954] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1751),
  [5957] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13845),
  [5960] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14398),
  [5963] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(255),
  [5966] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6258),
  [5969] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15585),
  [5972] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15524),
  [5975] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6523),
  [5978] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13304),
  [5981] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12251),
  [5984] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4389),
  [5987] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6521),
  [5990] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16766),
  [5993] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6649),
  [5996] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17456),
  [5999] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(183),
  [6002] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1580),
  [6005] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6580),
  [6008] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3235),
  [6011] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10645),
  [6014] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1581),
  [6017] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13948),
  [6020] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14328),
  [6023] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(259),
  [6026] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6539),
  [6029] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15311),
  [6032] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15801),
  [6035] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6581),
  [6038] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13264),
  [6041] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12598),
  [6044] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4368),
  [6047] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6583),
  [6050] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17174),
  [6053] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6577),
  [6056] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17524),
  [6059] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(186),
  [6062] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1628),
  [6065] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6660),
  [6068] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3086),
  [6071] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10494),
  [6074] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1629),
  [6077] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14133),
  [6080] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14190),
  [6083] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(250),
  [6086] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6255),
  [6089] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15414),
  [6092] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15704),
  [6095] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6503),
  [6098] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13243),
  [6101] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12290),
  [6104] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4314),
  [6107] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6491),
  [6110] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16996),
  [6113] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6374),
  [6116] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17476),
  [6119] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(161),
  [6122] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1591),
  [6125] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6563),
  [6128] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3219),
  [6131] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10601),
  [6134] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1592),
  [6137] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13876),
  [6140] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14377),
  [6143] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(246),
  [6146] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6357),
  [6149] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15322),
  [6152] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15791),
  [6155] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6562),
  [6158] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13285),
  [6161] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12561),
  [6164] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4290),
  [6167] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6559),
  [6170] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17128),
  [6173] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6375),
  [6176] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17497),
  [6179] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(154),
  [6182] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1612),
  [6185] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6389),
  [6188] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3150),
  [6191] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10504),
  [6194] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1614),
  [6197] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14083),
  [6200] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14239),
  [6203] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(268),
  [6206] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6162),
  [6209] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15396),
  [6212] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15759),
  [6215] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6388),
  [6218] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13278),
  [6221] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12404),
  [6224] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4333),
  [6227] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6383),
  [6230] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17031),
  [6233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6818),
  [6235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17335),
  [6237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [6239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1678),
  [6241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7181),
  [6243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2969),
  [6245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10582),
  [6247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1679),
  [6249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14084),
  [6251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14236),
  [6253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(245),
  [6255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6724),
  [6257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15459),
  [6259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15948),
  [6261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7179),
  [6263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13366),
  [6265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12221),
  [6267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4434),
  [6269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7173),
  [6271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16865),
  [6273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6726),
  [6275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17506),
  [6277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [6279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1704),
  [6281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7082),
  [6283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3076),
  [6285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10560),
  [6287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1705),
  [6289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14090),
  [6291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14237),
  [6293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(290),
  [6295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6715),
  [6297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15541),
  [6299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15568),
  [6301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7080),
  [6303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13270),
  [6305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12220),
  [6307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4378),
  [6309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7076),
  [6311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16822),
  [6313] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(7149),
  [6316] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16749),
  [6319] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(200),
  [6322] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1666),
  [6325] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(7144),
  [6328] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3244),
  [6331] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10487),
  [6334] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1665),
  [6337] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13855),
  [6340] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14388),
  [6343] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(277),
  [6346] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(7128),
  [6349] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15762),
  [6352] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15536),
  [6355] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(7137),
  [6358] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13251),
  [6361] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12345),
  [6364] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4421),
  [6367] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6941),
  [6370] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16927),
  [6373] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6818),
  [6376] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17335),
  [6379] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(175),
  [6382] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1678),
  [6385] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(7181),
  [6388] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(2969),
  [6391] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10582),
  [6394] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1679),
  [6397] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14084),
  [6400] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14236),
  [6403] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(245),
  [6406] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6724),
  [6409] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15459),
  [6412] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15948),
  [6415] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(7179),
  [6418] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13366),
  [6421] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12221),
  [6424] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4434),
  [6427] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(7173),
  [6430] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16865),
  [6433] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6947),
  [6436] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16791),
  [6439] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(152),
  [6442] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1625),
  [6445] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6944),
  [6448] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3264),
  [6451] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10385),
  [6454] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1624),
  [6457] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13852),
  [6460] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14371),
  [6463] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(281),
  [6466] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(7193),
  [6469] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16032),
  [6472] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16459),
  [6475] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6942),
  [6478] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13322),
  [6481] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12551),
  [6484] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4436),
  [6487] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6886),
  [6490] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16931),
  [6493] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6900),
  [6496] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16831),
  [6499] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(166),
  [6502] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1594),
  [6505] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6898),
  [6508] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3276),
  [6511] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10617),
  [6514] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1593),
  [6517] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13947),
  [6520] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14396),
  [6523] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(256),
  [6526] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(7067),
  [6529] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16322),
  [6532] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16324),
  [6535] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6887),
  [6538] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13319),
  [6541] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12311),
  [6544] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4289),
  [6547] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6869),
  [6550] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16957),
  [6553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7117),
  [6555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16892),
  [6557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [6559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1528),
  [6561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6894),
  [6563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3072),
  [6565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10627),
  [6567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1526),
  [6569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13966),
  [6571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14331),
  [6573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(270),
  [6575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6896),
  [6577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15507),
  [6579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15725),
  [6581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6893),
  [6583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13362),
  [6585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12343),
  [6587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4193),
  [6589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6892),
  [6591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17471),
  [6593] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6726),
  [6596] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17506),
  [6599] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(159),
  [6602] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1704),
  [6605] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(7082),
  [6608] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3076),
  [6611] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10560),
  [6614] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1705),
  [6617] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14090),
  [6620] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14237),
  [6623] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(290),
  [6626] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6715),
  [6629] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15541),
  [6632] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15568),
  [6635] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(7080),
  [6638] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13270),
  [6641] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12220),
  [6644] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4378),
  [6647] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(7076),
  [6650] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16822),
  [6653] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(7022),
  [6656] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17167),
  [6659] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(178),
  [6662] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1756),
  [6665] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6712),
  [6668] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3231),
  [6671] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10374),
  [6674] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1757),
  [6677] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13899),
  [6680] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14397),
  [6683] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(257),
  [6686] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(7113),
  [6689] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15718),
  [6692] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15141),
  [6695] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6748),
  [6698] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13388),
  [6701] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12243),
  [6704] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4381),
  [6707] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6747),
  [6710] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17587),
  [6713] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6858),
  [6716] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16862),
  [6719] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(167),
  [6722] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1577),
  [6725] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6954),
  [6728] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3305),
  [6731] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10509),
  [6734] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1576),
  [6737] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13945),
  [6740] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14311),
  [6743] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(263),
  [6746] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(7138),
  [6749] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16447),
  [6752] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16206),
  [6755] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6956),
  [6758] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13295),
  [6761] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12599),
  [6764] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4398),
  [6767] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6958),
  [6770] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17038),
  [6773] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(7117),
  [6776] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16892),
  [6779] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(194),
  [6782] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1528),
  [6785] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6894),
  [6788] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3072),
  [6791] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10627),
  [6794] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1526),
  [6797] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13966),
  [6800] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14331),
  [6803] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(270),
  [6806] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6896),
  [6809] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15507),
  [6812] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15725),
  [6815] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6893),
  [6818] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13362),
  [6821] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12343),
  [6824] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4193),
  [6827] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(6892),
  [6830] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17471),
  [6833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10361),
  [6835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2535),
  [6837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5420),
  [6839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4585),
  [6841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20332),
  [6843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13664),
  [6845] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14848),
  [6847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18806),
  [6849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4583),
  [6851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4540),
  [6853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18810),
  [6855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5438),
  [6857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20340),
  [6859] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14596),
  [6861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17972),
  [6863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18115),
  [6865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5369),
  [6867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20306),
  [6869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14560),
  [6871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19720),
  [6873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19722),
  [6875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5556),
  [6877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20338),
  [6879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14895),
  [6881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18113),
  [6883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18285),
  [6885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8568),
  [6887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20334),
  [6889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15036),
  [6891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18455),
  [6893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18636),
  [6895] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7608),
  [6897] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 5, 0, 60),
  [6899] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 5, 0, 60),
  [6901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9725),
  [6903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15392),
  [6905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2443),
  [6907] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3184),
  [6909] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7633),
  [6911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8072),
  [6913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13617),
  [6915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14867),
  [6917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3191),
  [6919] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19182),
  [6921] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16222),
  [6923] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15919),
  [6925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15742),
  [6927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7631),
  [6929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19252),
  [6931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13371),
  [6933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12555),
  [6935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7375),
  [6937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17390),
  [6939] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7898),
  [6941] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16916),
  [6943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [6945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1599),
  [6947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8026),
  [6949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3079),
  [6951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10402),
  [6953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1604),
  [6955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14074),
  [6957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14246),
  [6959] = {.entry = {.count = 1, .reusable = false}}, SHIFT(248),
  [6961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8043),
  [6963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15702),
  [6965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15174),
  [6967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8019),
  [6969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13256),
  [6971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12263),
  [6973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4332),
  [6975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8018),
  [6977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17516),
  [6979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7648),
  [6981] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 4, 0, 60),
  [6983] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 4, 0, 60),
  [6985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9627),
  [6987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16171),
  [6989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2446),
  [6991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3027),
  [6993] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7624),
  [6995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8004),
  [6997] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13596),
  [6999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14471),
  [7001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3026),
  [7003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19324),
  [7005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15547),
  [7007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15187),
  [7009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7626),
  [7011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19399),
  [7013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13365),
  [7015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12563),
  [7017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7315),
  [7019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17290),
  [7021] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 2, 0, 16),
  [7023] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 2, 0, 16),
  [7025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9621),
  [7027] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(7898),
  [7030] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16916),
  [7033] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(196),
  [7036] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1599),
  [7039] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(8026),
  [7042] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3079),
  [7045] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10402),
  [7048] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1604),
  [7051] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14074),
  [7054] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14246),
  [7057] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(248),
  [7060] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(8043),
  [7063] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15702),
  [7066] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(15174),
  [7069] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(8019),
  [7072] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13256),
  [7075] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12263),
  [7078] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4332),
  [7081] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(8018),
  [7084] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17516),
  [7087] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 5, 0, 80),
  [7089] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 5, 0, 80),
  [7091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9723),
  [7093] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 6, 0, 95),
  [7095] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 6, 0, 95),
  [7097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9847),
  [7099] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 6, 0, 80),
  [7101] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 6, 0, 80),
  [7103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9843),
  [7105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9677),
  [7107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9805),
  [7109] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 3, 0, 16),
  [7111] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 3, 0, 16),
  [7113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9816),
  [7115] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 2, 0, 9),
  [7117] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 2, 0, 9),
  [7119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9810),
  [7121] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 1, 0, 9),
  [7123] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 1, 0, 9),
  [7125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9777),
  [7127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9800),
  [7129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9861),
  [7131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9569),
  [7133] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 7, 0, 95),
  [7135] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 7, 0, 95),
  [7137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9663),
  [7139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9828),
  [7141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9785),
  [7143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9840),
  [7145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9821),
  [7147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9676),
  [7149] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_pattern, 1, 0, 0),
  [7151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2449),
  [7153] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_pattern, 1, 0, 0),
  [7155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14576),
  [7157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19982),
  [7159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7787),
  [7161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9591),
  [7163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16002),
  [7165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2450),
  [7167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3222),
  [7169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7778),
  [7171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7901),
  [7173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13781),
  [7175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14697),
  [7177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3225),
  [7179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20459),
  [7181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15959),
  [7183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16068),
  [7185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7777),
  [7187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20458),
  [7189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13323),
  [7191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12302),
  [7193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7587),
  [7195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16702),
  [7197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9616),
  [7199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8094),
  [7201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9527),
  [7203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15946),
  [7205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2440),
  [7207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3311),
  [7209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8032),
  [7211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7914),
  [7213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13732),
  [7215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14538),
  [7217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3299),
  [7219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18908),
  [7221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16049),
  [7223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15955),
  [7225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8033),
  [7227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19036),
  [7229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13400),
  [7231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12368),
  [7233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7780),
  [7235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17447),
  [7237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9781),
  [7239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9689),
  [7241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9801),
  [7243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9718),
  [7245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9749),
  [7247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9682),
  [7249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9839),
  [7251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9829),
  [7253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9584),
  [7255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9593),
  [7257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9614),
  [7259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9694),
  [7261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9615),
  [7263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9862),
  [7265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9799),
  [7267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9656),
  [7269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9636),
  [7271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9846),
  [7273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9698),
  [7275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9806),
  [7277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9664),
  [7279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9743),
  [7281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9850),
  [7283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9851),
  [7285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9867),
  [7287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9745),
  [7289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9750),
  [7291] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(7648),
  [7294] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0),
  [7296] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0),
  [7298] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(16171),
  [7301] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(2446),
  [7304] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(3027),
  [7307] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(7624),
  [7310] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(13596),
  [7313] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(14471),
  [7316] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(3026),
  [7319] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(19324),
  [7322] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(15547),
  [7325] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(15187),
  [7328] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(7626),
  [7331] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(19399),
  [7334] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(13365),
  [7337] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(12563),
  [7340] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(7315),
  [7343] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(17290),
  [7346] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(7608),
  [7349] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(15392),
  [7352] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(2443),
  [7355] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(3184),
  [7358] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(7633),
  [7361] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(13617),
  [7364] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(14867),
  [7367] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(3191),
  [7370] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(19182),
  [7373] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(15919),
  [7376] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(15742),
  [7379] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(7631),
  [7382] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(19252),
  [7385] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(13371),
  [7388] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(12555),
  [7391] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(7375),
  [7394] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(17390),
  [7397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2945),
  [7399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15028),
  [7401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2943),
  [7403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5052),
  [7405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15252),
  [7407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16101),
  [7409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19982),
  [7411] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(7787),
  [7414] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(16002),
  [7417] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(2450),
  [7420] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(3222),
  [7423] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(7778),
  [7426] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(13781),
  [7429] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(14697),
  [7432] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(3225),
  [7435] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(20459),
  [7438] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(15959),
  [7441] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(16068),
  [7444] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(7777),
  [7447] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(20458),
  [7450] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(13323),
  [7453] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(12302),
  [7456] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(7587),
  [7459] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(16702),
  [7462] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8094),
  [7465] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(15946),
  [7468] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(2440),
  [7471] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(3311),
  [7474] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8032),
  [7477] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(13732),
  [7480] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(14538),
  [7483] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(3299),
  [7486] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(18908),
  [7489] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(16049),
  [7492] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(15955),
  [7495] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8033),
  [7498] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(19036),
  [7501] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(13400),
  [7504] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(12368),
  [7507] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(7780),
  [7510] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(17447),
  [7513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8916),
  [7515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2534),
  [7517] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4569),
  [7519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8565),
  [7521] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13581),
  [7523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14616),
  [7525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4570),
  [7527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4504),
  [7529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19402),
  [7531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15387),
  [7533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15355),
  [7535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8566),
  [7537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19484),
  [7539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13336),
  [7541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12616),
  [7543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8530),
  [7545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17185),
  [7547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13940),
  [7549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2447),
  [7551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3296),
  [7553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13754),
  [7555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13811),
  [7557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2946),
  [7559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15058),
  [7561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3284),
  [7563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2947),
  [7565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19485),
  [7567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5097),
  [7569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15108),
  [7571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15648),
  [7573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13749),
  [7575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19592),
  [7577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13352),
  [7579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12494),
  [7581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9048),
  [7583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17122),
  [7585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2478),
  [7587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8758),
  [7589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1328),
  [7591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15865),
  [7593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2454),
  [7595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3268),
  [7597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8770),
  [7599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7879),
  [7601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13821),
  [7603] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_definition, 5, 0, 89),
  [7605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15029),
  [7607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3266),
  [7609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18805),
  [7611] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 5, 0, 89),
  [7613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16498),
  [7615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15405),
  [7617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8766),
  [7619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18907),
  [7621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13247),
  [7623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12240),
  [7625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8448),
  [7627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17536),
  [7629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3000),
  [7631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15939),
  [7633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3224),
  [7635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3044),
  [7637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3308),
  [7639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3069),
  [7641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3274),
  [7643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3223),
  [7645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3273),
  [7647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3260),
  [7649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3099),
  [7651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3187),
  [7653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3270),
  [7655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3303),
  [7657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3259),
  [7659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3114),
  [7661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3229),
  [7663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3289),
  [7665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3074),
  [7667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3263),
  [7669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1036),
  [7671] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_definition, 2, 0, 43),
  [7673] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 2, 0, 43),
  [7675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3267),
  [7677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3251),
  [7679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3216),
  [7681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3237),
  [7683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1456),
  [7685] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_definition, 4, 0, 69),
  [7687] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 4, 0, 69),
  [7689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3214),
  [7691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3145),
  [7693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1296),
  [7695] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_definition, 3, 0, 43),
  [7697] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 3, 0, 43),
  [7699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3252),
  [7701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3281),
  [7703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1459),
  [7705] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_definition, 4, 0, 89),
  [7707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 4, 0, 89),
  [7709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3300),
  [7711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1290),
  [7713] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_definition, 3, 0, 69),
  [7715] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 3, 0, 69),
  [7717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3227),
  [7719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3199),
  [7721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3240),
  [7723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3282),
  [7725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4587),
  [7727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13401),
  [7729] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13922),
  [7731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11059),
  [7733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16086),
  [7735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4595),
  [7737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15750),
  [7739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15429),
  [7741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4576),
  [7743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15748),
  [7745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15953),
  [7747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8695),
  [7749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(701),
  [7751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4663),
  [7753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4623),
  [7755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14946),
  [7757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4659),
  [7759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15950),
  [7761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15430),
  [7763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15247),
  [7765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9336),
  [7767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16979),
  [7769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [7771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1517),
  [7773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9233),
  [7775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3272),
  [7777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10552),
  [7779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1641),
  [7781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14005),
  [7783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14282),
  [7785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(273),
  [7787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9278),
  [7789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16121),
  [7791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16078),
  [7793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9165),
  [7795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13254),
  [7797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12533),
  [7799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4460),
  [7801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8135),
  [7803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17158),
  [7805] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(9336),
  [7808] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16979),
  [7811] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(162),
  [7814] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1517),
  [7817] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(9233),
  [7820] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(3272),
  [7823] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(10552),
  [7826] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(1641),
  [7829] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14005),
  [7832] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(14282),
  [7835] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(273),
  [7838] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(9278),
  [7841] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16121),
  [7844] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(16078),
  [7847] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(9165),
  [7850] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(13254),
  [7853] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(12533),
  [7856] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(4460),
  [7859] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(8135),
  [7862] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 48), SHIFT_REPEAT(17158),
  [7865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12198),
  [7867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20446),
  [7869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8508),
  [7871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12016),
  [7873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8083),
  [7875] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_payload, 1, 0, 0),
  [7877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13379),
  [7879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13499),
  [7881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10117),
  [7883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13774),
  [7885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13863),
  [7887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7767),
  [7889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8099),
  [7891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9303),
  [7893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14783),
  [7895] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15252),
  [7897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16101),
  [7899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9011),
  [7901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16509),
  [7903] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_get_expression, 3, 0, 0),
  [7905] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_get_expression, 3, 0, 0),
  [7907] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_path, 3, 0, 67),
  [7909] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_path, 3, 0, 67),
  [7911] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_get_expression, 5, 0, 0),
  [7913] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_get_expression, 5, 0, 0),
  [7915] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_path, 1, 0, 22),
  [7917] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_path, 1, 0, 22),
  [7919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13020),
  [7921] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_get_expression, 5, 0, 0),
  [7923] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_get_expression, 5, 0, 0),
  [7925] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bigarray_get_expression, 6, 0, 0),
  [7927] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bigarray_get_expression, 6, 0, 0),
  [7929] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_get_expression, 6, 0, 0),
  [7931] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_get_expression, 6, 0, 0),
  [7933] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_get_expression, 6, 0, 0),
  [7935] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_get_expression, 6, 0, 0),
  [7937] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bigarray_get_expression, 5, 0, 0),
  [7939] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bigarray_get_expression, 5, 0, 0),
  [7941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13975),
  [7943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7679),
  [7945] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8758),
  [7948] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(15865),
  [7951] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(2454),
  [7954] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(3268),
  [7957] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8770),
  [7960] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(13821),
  [7963] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(15029),
  [7966] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(3266),
  [7969] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(18805),
  [7972] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(16498),
  [7975] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(15405),
  [7978] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8766),
  [7981] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(18907),
  [7984] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(13247),
  [7987] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(12240),
  [7990] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8448),
  [7993] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(17536),
  [7996] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__value_name, 1, 0, 1),
  [7998] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__value_name, 1, 0, 1),
  [8000] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__instance_variable_name, 1, 0, 10),
  [8002] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0),
  [8004] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0),
  [8006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2188),
  [8008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7479),
  [8010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8870),
  [8012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7754),
  [8014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1906),
  [8016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8001),
  [8018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10154),
  [8020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13451),
  [8022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [8024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1710),
  [8026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3228),
  [8028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10676),
  [8030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1709),
  [8032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13967),
  [8034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14277),
  [8036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(286),
  [8038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7462),
  [8040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15094),
  [8042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15426),
  [8044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4473),
  [8046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7068),
  [8048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16855),
  [8050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13268),
  [8052] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value_path, 3, 0, 0),
  [8054] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_path, 3, 0, 0),
  [8056] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value_path, 1, 0, 0),
  [8058] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_path, 1, 0, 0),
  [8060] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__value_name, 1, 0, 0),
  [8062] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__value_name, 1, 0, 0),
  [8064] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_expression, 2, 0, 0),
  [8066] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_expression, 2, 0, 0),
  [8068] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_expression, 7, 0, 0),
  [8070] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_expression, 7, 0, 0),
  [8072] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_path, 1, 0, 24),
  [8074] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_path, 1, 0, 24),
  [8076] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_expression, 6, 0, 0),
  [8078] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_expression, 6, 0, 0),
  [8080] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_expression, 3, 0, 0),
  [8082] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_expression, 3, 0, 0),
  [8084] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_coercion_expression, 6, 0, 0),
  [8086] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_coercion_expression, 6, 0, 0),
  [8088] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_package_expression, 6, 0, 0),
  [8090] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_expression, 6, 0, 0),
  [8092] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_open_expression, 5, 0, 0),
  [8094] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_open_expression, 5, 0, 0),
  [8096] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_expression, 4, 0, 0),
  [8098] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_expression, 4, 0, 0),
  [8100] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_argument, 4, 0, 45),
  [8102] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_argument, 4, 0, 45),
  [8104] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_path, 3, 0, 71),
  [8106] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_path, 3, 0, 71),
  [8108] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_copy_expression, 5, 0, 0),
  [8110] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_copy_expression, 5, 0, 0),
  [8112] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_expression, 5, 0, 0),
  [8114] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_expression, 5, 0, 0),
  [8116] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_expression, 5, 0, 0),
  [8118] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_expression, 5, 0, 0),
  [8120] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_expression, 5, 0, 0),
  [8122] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_expression, 5, 0, 0),
  [8124] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_coercion_expression, 5, 0, 0),
  [8126] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_coercion_expression, 5, 0, 0),
  [8128] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_package_expression, 5, 0, 0),
  [8130] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_expression, 5, 0, 0),
  [8132] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_open_expression, 4, 0, 0),
  [8134] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_open_expression, 4, 0, 0),
  [8136] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 4, 0, 0),
  [8138] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 4, 0, 0),
  [8140] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_copy_expression, 4, 0, 0),
  [8142] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_copy_expression, 4, 0, 0),
  [8144] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_expression, 5, 0, 0),
  [8146] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_expression, 5, 0, 0),
  [8148] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_expression, 4, 0, 0),
  [8150] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_expression, 4, 0, 0),
  [8152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7750),
  [8154] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_expression, 4, 0, 0),
  [8156] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_expression, 4, 0, 0),
  [8158] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_expression, 4, 0, 0),
  [8160] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_expression, 4, 0, 0),
  [8162] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_typed_expression, 4, 0, 0),
  [8164] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typed_expression, 4, 0, 0),
  [8166] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_package_expression, 4, 0, 0),
  [8168] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_expression, 4, 0, 0),
  [8170] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_open_expression, 3, 0, 0),
  [8172] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_open_expression, 3, 0, 0),
  [8174] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hash_expression, 3, 0, 47),
  [8176] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hash_expression, 3, 0, 47),
  [8178] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_expression, 6, 0, 0),
  [8180] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_expression, 6, 0, 0),
  [8182] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_invocation, 3, 0, 46),
  [8184] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_invocation, 3, 0, 46),
  [8186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7658),
  [8188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7657),
  [8190] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_expression, 7, 0, 0),
  [8192] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_expression, 7, 0, 0),
  [8194] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_expression, 8, 0, 0),
  [8196] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_expression, 8, 0, 0),
  [8198] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_copy_expression, 3, 0, 0),
  [8200] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_copy_expression, 3, 0, 0),
  [8202] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 3, 0, 0),
  [8204] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 3, 0, 0),
  [8206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7680),
  [8208] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_expression, 3, 0, 0),
  [8210] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_expression, 3, 0, 0),
  [8212] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_expression, 3, 0, 0),
  [8214] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_expression, 3, 0, 0),
  [8216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7746),
  [8218] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_expression, 3, 0, 0),
  [8220] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_expression, 3, 0, 0),
  [8222] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [8224] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [8226] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 1, 0, 26),
  [8228] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 1, 0, 26),
  [8230] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_prefix_expression, 2, 0, 25),
  [8232] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_prefix_expression, 2, 0, 25),
  [8234] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_copy_expression, 2, 0, 0),
  [8236] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_copy_expression, 2, 0, 0),
  [8238] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 2, 0, 0),
  [8240] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 2, 0, 0),
  [8242] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_expression, 2, 0, 0),
  [8244] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_expression, 2, 0, 0),
  [8246] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_expression, 2, 0, 0),
  [8248] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_expression, 2, 0, 0),
  [8250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7667),
  [8252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1795),
  [8254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7664),
  [8256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7687),
  [8258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2304),
  [8260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2101),
  [8262] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_operator, 3, 0, 0),
  [8264] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_operator, 3, 0, 0),
  [8266] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_operator, 6, 0, 0),
  [8268] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_operator, 6, 0, 0),
  [8270] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_operator, 7, 0, 0),
  [8272] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_operator, 7, 0, 0),
  [8274] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_operator, 8, 0, 0),
  [8276] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_operator, 8, 0, 0),
  [8278] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_operator, 9, 0, 0),
  [8280] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_operator, 9, 0, 0),
  [8282] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tag, 2, 0, 0),
  [8284] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tag, 2, 0, 0),
  [8286] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean, 1, 0, 0),
  [8288] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean, 1, 0, 0),
  [8290] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_number, 1, 0, 0),
  [8292] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_number, 1, 0, 0),
  [8294] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__constructor_name, 1, 0, 6),
  [8296] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__constructor_name, 1, 0, 6),
  [8298] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_path, 1, 0, 5),
  [8300] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__constant, 1, 0, 0),
  [8302] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__constant, 1, 0, 0),
  [8304] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_path, 1, 0, 0),
  [8306] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_path, 1, 0, 0),
  [8308] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unit, 2, 0, 0),
  [8310] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unit, 2, 0, 0),
  [8312] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__constructor_name, 3, 0, 34),
  [8314] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__constructor_name, 3, 0, 34),
  [8316] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_quoted_string, 3, 0, 0),
  [8318] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quoted_string, 3, 0, 0),
  [8320] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_character, 3, 0, 0),
  [8322] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_character, 3, 0, 0),
  [8324] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_path, 3, 0, 32),
  [8326] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_path, 3, 0, 0),
  [8328] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_path, 3, 0, 0),
  [8330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13887),
  [8332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14065),
  [8334] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 2, 0, 0),
  [8336] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 2, 0, 0),
  [8338] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 3, 0, 0),
  [8340] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 3, 0, 0),
  [8342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13993),
  [8344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14034),
  [8346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7559),
  [8348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7554),
  [8350] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_extension, 3, 0, 0),
  [8352] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extension, 3, 0, 0),
  [8354] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_extension, 4, 0, 0),
  [8356] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extension, 4, 0, 0),
  [8358] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_quoted_extension, 4, 0, 0),
  [8360] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quoted_extension, 4, 0, 0),
  [8362] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_quoted_extension, 5, 0, 0),
  [8364] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quoted_extension, 5, 0, 0),
  [8366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12960),
  [8368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13112),
  [8370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7766),
  [8372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7771),
  [8374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13126),
  [8376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13028),
  [8378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13052),
  [8380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13083),
  [8382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2302),
  [8384] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13799),
  [8386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4551),
  [8388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8839),
  [8390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8871),
  [8392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8867),
  [8394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8782),
  [8396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8779),
  [8398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8841),
  [8400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7838),
  [8402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10110),
  [8404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10176),
  [8406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7876),
  [8408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7474),
  [8410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14094),
  [8412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7969),
  [8414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7924),
  [8416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7817),
  [8418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10123),
  [8420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10140),
  [8422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13974),
  [8424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7477),
  [8426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7831),
  [8428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7895),
  [8430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10278),
  [8432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10258),
  [8434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7509),
  [8436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7912),
  [8438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7514),
  [8440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1946),
  [8442] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1880),
  [8444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13853),
  [8446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2533),
  [8448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4579),
  [8450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13808),
  [8452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4600),
  [8454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4490),
  [8456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7411),
  [8458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [8460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1559),
  [8462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7386),
  [8464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3248),
  [8466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10481),
  [8468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1557),
  [8470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13960),
  [8472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14313),
  [8474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(283),
  [8476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7348),
  [8478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16190),
  [8480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15265),
  [8482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15164),
  [8484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7385),
  [8486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13328),
  [8488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12587),
  [8490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4393),
  [8492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7448),
  [8494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17218),
  [8496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6873),
  [8498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [8500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7546),
  [8502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3290),
  [8504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(269),
  [8506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7548),
  [8508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13269),
  [8510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12324),
  [8512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4234),
  [8514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7581),
  [8516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [8518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1689),
  [8520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7529),
  [8522] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3022),
  [8524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10503),
  [8526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1690),
  [8528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14139),
  [8530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14186),
  [8532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(282),
  [8534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7725),
  [8536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7528),
  [8538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13326),
  [8540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12237),
  [8542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4256),
  [8544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7481),
  [8546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16839),
  [8548] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_argument, 2, 0, 45),
  [8550] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_argument, 2, 0, 45),
  [8552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4416),
  [8554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4438),
  [8556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9773),
  [8558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [8560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1600),
  [8562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9814),
  [8564] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3203),
  [8566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10522),
  [8568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1603),
  [8570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13977),
  [8572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14304),
  [8574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(293),
  [8576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9740),
  [8578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15384),
  [8580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15764),
  [8582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9813),
  [8584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13387),
  [8586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12522),
  [8588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4311),
  [8590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9736),
  [8592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17078),
  [8594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2074),
  [8596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15161),
  [8598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15570),
  [8600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4203),
  [8602] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2208),
  [8604] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4301),
  [8606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2280),
  [8608] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4589),
  [8610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15871),
  [8612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15423),
  [8614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4567),
  [8616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15987),
  [8618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15839),
  [8620] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1791),
  [8622] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_argument, 5, 0, 105),
  [8624] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_argument, 5, 0, 105),
  [8626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4233),
  [8628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4212),
  [8630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4299),
  [8632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15507),
  [8634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15725),
  [8636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4476),
  [8638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15224),
  [8640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15903),
  [8642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4449),
  [8644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15541),
  [8646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15568),
  [8648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15475),
  [8650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15633),
  [8652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15702),
  [8654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15174),
  [8656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15459),
  [8658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15948),
  [8660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4568),
  [8662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8941),
  [8664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4588),
  [8666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4265),
  [8668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5488),
  [8670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5485),
  [8672] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4601),
  [8674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5686),
  [8676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4610),
  [8678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4291),
  [8680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13308),
  [8682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4559),
  [8684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5624),
  [8686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14087),
  [8688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5455),
  [8690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5459),
  [8692] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4236),
  [8694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8944),
  [8696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13854),
  [8698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5450),
  [8700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8942),
  [8702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13891),
  [8704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8885),
  [8706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8884),
  [8708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5680),
  [8710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5629),
  [8712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5575),
  [8714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14165),
  [8716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5464),
  [8718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5456),
  [8720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14019),
  [8722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13294),
  [8724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13302),
  [8726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13315),
  [8728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14055),
  [8730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13316),
  [8732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13330),
  [8734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5687),
  [8736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5620),
  [8738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5610),
  [8740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5474),
  [8742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5465),
  [8744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5462),
  [8746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5508),
  [8748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14011),
  [8750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5487),
  [8752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8932),
  [8754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5658),
  [8756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5678),
  [8758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5504),
  [8760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5656),
  [8762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5524),
  [8764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5685),
  [8766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8872),
  [8768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5719),
  [8770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4481),
  [8772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5692),
  [8774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13354),
  [8776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8661),
  [8778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(957),
  [8780] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(10167),
  [8783] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(15418),
  [8786] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(2448),
  [8789] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(3278),
  [8792] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(10126),
  [8795] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(13662),
  [8798] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(14972),
  [8801] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(3279),
  [8804] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(19803),
  [8807] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(15430),
  [8810] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(15247),
  [8813] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(10231),
  [8816] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(19851),
  [8819] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(13324),
  [8822] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(12488),
  [8825] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8420),
  [8828] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(16898),
  [8831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8749),
  [8833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(956),
  [8835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8683),
  [8837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(611),
  [8839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8709),
  [8841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1091),
  [8843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8625),
  [8845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(789),
  [8847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10034),
  [8849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1326),
  [8851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19851),
  [8853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(845),
  [8855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(756),
  [8857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1243),
  [8859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(694),
  [8861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1032),
  [8863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1159),
  [8865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(711),
  [8867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1094),
  [8869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1158),
  [8871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(707),
  [8873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(936),
  [8875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(709),
  [8877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(835),
  [8879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(929),
  [8881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1187),
  [8883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1126),
  [8885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(696),
  [8887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(595),
  [8889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(594),
  [8891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(557),
  [8893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1472),
  [8895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(906),
  [8897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1287),
  [8899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1311),
  [8901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(875),
  [8903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1103),
  [8905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1389),
  [8907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(776),
  [8909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(718),
  [8911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(833),
  [8913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(988),
  [8915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(852),
  [8917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1421),
  [8919] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attribute_id, 2, 0, 0),
  [8921] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_id, 2, 0, 0),
  [8923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16525),
  [8925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1190),
  [8927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1304),
  [8929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1203),
  [8931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1131),
  [8933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(880),
  [8935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1149),
  [8937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1458),
  [8939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1248),
  [8941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1492),
  [8943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1034),
  [8945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(983),
  [8947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1922),
  [8949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1150),
  [8951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1490),
  [8953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1505),
  [8955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1075),
  [8957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1441),
  [8959] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_attribute_id_repeat1, 2, 0, 0),
  [8961] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_attribute_id_repeat1, 2, 0, 0),
  [8963] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attribute_id_repeat1, 2, 0, 0), SHIFT_REPEAT(16525),
  [8966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(882),
  [8968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1019),
  [8970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(881),
  [8972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1436),
  [8974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(867),
  [8976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1384),
  [8978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(652),
  [8980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(889),
  [8982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(655),
  [8984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1015),
  [8986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(772),
  [8988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(599),
  [8990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1353),
  [8992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(869),
  [8994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(592),
  [8996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(798),
  [8998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1380),
  [9000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(691),
  [9002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(817),
  [9004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(959),
  [9006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(969),
  [9008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1422),
  [9010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(773),
  [9012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1360),
  [9014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1507),
  [9016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1361),
  [9018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(838),
  [9020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1302),
  [9022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1474),
  [9024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1409),
  [9026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(734),
  [9028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [9030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(715),
  [9032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1237),
  [9034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(836),
  [9036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1336),
  [9038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(737),
  [9040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(758),
  [9042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(740),
  [9044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1124),
  [9046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1239),
  [9048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1044),
  [9050] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attribute_id, 1, 0, 0),
  [9052] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_id, 1, 0, 0),
  [9054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2234),
  [9056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2249),
  [9058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9812),
  [9060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9710),
  [9062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9776),
  [9064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9833),
  [9066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2237),
  [9068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9640),
  [9070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9650),
  [9072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9651),
  [9074] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2348),
  [9076] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__structure_repeat1, 2, 0, 0),
  [9078] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat1, 2, 0, 0), SHIFT_REPEAT(5242),
  [9081] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__structure_repeat1, 2, 0, 0),
  [9083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2960),
  [9085] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat1, 2, 0, 0), SHIFT_REPEAT(5273),
  [9088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4369),
  [9090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1968),
  [9092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4426),
  [9094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2000),
  [9096] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__structure_repeat1, 1, 0, 0),
  [9098] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__structure_repeat1, 1, 0, 0),
  [9100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11752),
  [9102] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_signed_number, 2, 0, 0),
  [9104] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_signed_number, 2, 0, 0),
  [9106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2269),
  [9108] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__signed_constant, 1, 0, 0),
  [9110] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__signed_constant, 1, 0, 0),
  [9112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11895),
  [9114] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sequence_expression, 1, 0, 0),
  [9116] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__sequence_expression, 1, 0, 0),
  [9118] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sequence_expression, 3, 0, 49),
  [9120] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sequence_expression, 3, 0, 49),
  [9122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4312),
  [9124] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sequence_expression, 4, 0, 72),
  [9126] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sequence_expression, 4, 0, 72),
  [9128] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_open_binding_pattern, 3, 0, 0),
  [9130] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_open_binding_pattern, 3, 0, 0),
  [9132] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tag_binding_pattern, 2, 0, 40),
  [9134] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tag_binding_pattern, 2, 0, 40),
  [9136] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_binding_pattern, 6, 0, 0),
  [9138] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_binding_pattern, 6, 0, 0),
  [9140] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_package_pattern, 6, 0, 97),
  [9142] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_pattern, 6, 0, 97),
  [9144] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_package_pattern, 5, 0, 97),
  [9146] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_pattern, 5, 0, 97),
  [9148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11733),
  [9150] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_binding_pattern, 2, 0, 40),
  [9152] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_binding_pattern, 2, 0, 40),
  [9154] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_binding_pattern, 4, 0, 0),
  [9156] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_binding_pattern, 4, 0, 0),
  [9158] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_constructor_path, 1, 0, 4),
  [9160] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_constructor_path, 1, 0, 4),
  [9162] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lazy_binding_pattern, 2, 0, 0),
  [9164] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lazy_binding_pattern, 2, 0, 0),
  [9166] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_binding_pattern, 4, 0, 0),
  [9168] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_binding_pattern, 4, 0, 0),
  [9170] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_binding_pattern, 2, 0, 0),
  [9172] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_binding_pattern, 2, 0, 0),
  [9174] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_package_pattern, 5, 0, 32),
  [9176] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_pattern, 5, 0, 32),
  [9178] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_binding_pattern, 5, 0, 0),
  [9180] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_binding_pattern, 5, 0, 0),
  [9182] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_binding_pattern, 5, 0, 0),
  [9184] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_binding_pattern, 5, 0, 0),
  [9186] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_binding_pattern, 2, 0, 0),
  [9188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_binding_pattern, 2, 0, 0),
  [9190] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_open_binding_pattern, 5, 0, 0),
  [9192] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_open_binding_pattern, 5, 0, 0),
  [9194] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_or_binding_pattern, 3, 0, 0),
  [9196] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_or_binding_pattern, 3, 0, 0),
  [9198] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_binding_pattern, 5, 0, 0),
  [9200] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_binding_pattern, 5, 0, 0),
  [9202] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__binding_pattern, 1, 0, 19),
  [9204] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__binding_pattern, 1, 0, 19),
  [9206] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_polymorphic_variant_pattern, 2, 0, 0),
  [9208] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_polymorphic_variant_pattern, 2, 0, 0),
  [9210] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_typed_binding_pattern, 4, 0, 40),
  [9212] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typed_binding_pattern, 4, 0, 40),
  [9214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11815),
  [9216] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range_pattern, 3, 0, 0),
  [9218] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range_pattern, 3, 0, 0),
  [9220] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_open_binding_pattern, 4, 0, 0),
  [9222] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_open_binding_pattern, 4, 0, 0),
  [9224] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_binding_pattern, 4, 0, 0),
  [9226] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_binding_pattern, 4, 0, 0),
  [9228] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_package_pattern, 4, 0, 32),
  [9230] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_pattern, 4, 0, 32),
  [9232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1794),
  [9234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4405),
  [9236] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_binding_pattern, 7, 0, 0),
  [9238] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_binding_pattern, 7, 0, 0),
  [9240] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__binding_pattern, 1, 0, 21),
  [9242] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__binding_pattern, 1, 0, 21),
  [9244] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__binding_pattern, 1, 0, 20),
  [9246] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__binding_pattern, 1, 0, 20),
  [9248] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_binding_pattern, 3, 0, 0),
  [9250] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_binding_pattern, 3, 0, 0),
  [9252] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_alias_binding_pattern, 3, 0, 0),
  [9254] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_alias_binding_pattern, 3, 0, 0),
  [9256] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_constructor_path, 3, 0, 31),
  [9258] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_constructor_path, 3, 0, 31),
  [9260] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lazy_binding_pattern, 3, 0, 0),
  [9262] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lazy_binding_pattern, 3, 0, 0),
  [9264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4408),
  [9266] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cons_binding_pattern, 3, 0, 0),
  [9268] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cons_binding_pattern, 3, 0, 0),
  [9270] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_binding_pattern, 3, 0, 0),
  [9272] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_binding_pattern, 3, 0, 0),
  [9274] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_binding_pattern, 3, 0, 0),
  [9276] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_binding_pattern, 3, 0, 0),
  [9278] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_binding_pattern, 3, 0, 0),
  [9280] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_binding_pattern, 3, 0, 0),
  [9282] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_binding_pattern, 3, 0, 0),
  [9284] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_binding_pattern, 3, 0, 0),
  [9286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1965),
  [9288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4272),
  [9290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2316),
  [9292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2470),
  [9294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15959),
  [9296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16068),
  [9298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2460),
  [9300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8708),
  [9302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17254),
  [9304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2465),
  [9306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16498),
  [9308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15405),
  [9310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2468),
  [9312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16049),
  [9314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15955),
  [9316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2472),
  [9318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2462),
  [9320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15919),
  [9322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15742),
  [9324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2477),
  [9326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13508),
  [9328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16852),
  [9330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2461),
  [9332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15547),
  [9334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15187),
  [9336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2475),
  [9338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13221),
  [9340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2025),
  [9342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2032),
  [9344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13281),
  [9346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18020),
  [9348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4237),
  [9350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4273),
  [9352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13331),
  [9354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17603),
  [9356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4330),
  [9358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2129),
  [9360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1897),
  [9362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1833),
  [9364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2034),
  [9366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2153),
  [9368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2230),
  [9370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2070),
  [9372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2165),
  [9374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2015),
  [9376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9450),
  [9378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8377),
  [9380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6904),
  [9382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10429),
  [9384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9608),
  [9386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7792),
  [9388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10652),
  [9390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15516),
  [9392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7738),
  [9394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7960),
  [9396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9133),
  [9398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15005),
  [9400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16237),
  [9402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16482),
  [9404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9338),
  [9406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16739),
  [9408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9578),
  [9410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8316),
  [9412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6672),
  [9414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10794),
  [9416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10074),
  [9418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7733),
  [9420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10909),
  [9422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7755),
  [9424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7910),
  [9426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9181),
  [9428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14956),
  [9430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16270),
  [9432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16095),
  [9434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16663),
  [9436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6917),
  [9438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10520),
  [9440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2322),
  [9442] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2030),
  [9444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2368),
  [9446] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7146),
  [9448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10941),
  [9450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2392),
  [9452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2410),
  [9454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9523),
  [9456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8332),
  [9458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7239),
  [9460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10673),
  [9462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9854),
  [9464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7764),
  [9466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10411),
  [9468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7779),
  [9470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8102),
  [9472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9195),
  [9474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15048),
  [9476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16221),
  [9478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15361),
  [9480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16882),
  [9482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7274),
  [9484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10597),
  [9486] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10082),
  [9488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8354),
  [9490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7020),
  [9492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11029),
  [9494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10298),
  [9496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7784),
  [9498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11004),
  [9500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7732),
  [9502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8021),
  [9504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9250),
  [9506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14492),
  [9508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15576),
  [9510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15140),
  [9512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16930),
  [9514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1868),
  [9516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2161),
  [9518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7110),
  [9520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11070),
  [9522] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1920),
  [9524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4327),
  [9526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10863),
  [9528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13276),
  [9530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13289),
  [9532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13386),
  [9534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1872),
  [9536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18184),
  [9538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4384),
  [9540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10516),
  [9542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10539),
  [9544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4445),
  [9546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19160),
  [9548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4204),
  [9550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11060),
  [9552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17920),
  [9554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4431),
  [9556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1835),
  [9558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11104),
  [9560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1851),
  [9562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10742),
  [9564] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2373),
  [9566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4348),
  [9568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10612),
  [9570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4467),
  [9572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10559),
  [9574] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_instantiated_class, 5, 0, 0),
  [9576] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instantiated_class, 5, 0, 0),
  [9578] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_instantiated_class, 4, 0, 0),
  [9580] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instantiated_class, 4, 0, 0),
  [9582] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_typed_class_expression, 4, 0, 0),
  [9584] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typed_class_expression, 4, 0, 0),
  [9586] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_class_expression, 3, 0, 0),
  [9588] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_class_expression, 3, 0, 0),
  [9590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13353),
  [9592] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_class_expression, 1, 0, 0),
  [9594] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_class_expression, 1, 0, 0),
  [9596] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4240),
  [9598] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_value_pattern, 1, 0, 17),
  [9600] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_value_pattern, 1, 0, 17),
  [9602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5774),
  [9604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5763),
  [9606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4412),
  [9608] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4444),
  [9610] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4235),
  [9612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4244),
  [9614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4375),
  [9616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4390),
  [9618] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter, 5, 0, 82),
  [9620] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 5, 0, 82),
  [9622] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_typed_pattern, 4, 0, 0),
  [9624] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typed_pattern, 4, 0, 0),
  [9626] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_pattern, 4, 0, 0),
  [9628] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_pattern, 4, 0, 0),
  [9630] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter, 4, 0, 83),
  [9632] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 4, 0, 83),
  [9634] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_pattern, 4, 0, 0),
  [9636] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_pattern, 4, 0, 0),
  [9638] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter, 4, 0, 82),
  [9640] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 4, 0, 82),
  [9642] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_open_pattern, 4, 0, 0),
  [9644] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_open_pattern, 4, 0, 0),
  [9646] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter, 6, 0, 82),
  [9648] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 6, 0, 82),
  [9650] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter, 7, 0, 82),
  [9652] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 7, 0, 82),
  [9654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4362),
  [9656] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter, 8, 0, 131),
  [9658] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 8, 0, 131),
  [9660] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter, 9, 0, 131),
  [9662] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 9, 0, 131),
  [9664] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_open_pattern, 3, 0, 0),
  [9666] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_open_pattern, 3, 0, 0),
  [9668] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_pattern, 3, 0, 0),
  [9670] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_pattern, 3, 0, 0),
  [9672] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_pattern, 3, 0, 0),
  [9674] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_pattern, 3, 0, 0),
  [9676] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_pattern, 5, 0, 0),
  [9678] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_pattern, 5, 0, 0),
  [9680] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_pattern, 3, 0, 0),
  [9682] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_pattern, 3, 0, 0),
  [9684] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_pattern, 3, 0, 0),
  [9686] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_pattern, 3, 0, 0),
  [9688] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_pattern, 5, 0, 0),
  [9690] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_pattern, 5, 0, 0),
  [9692] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_pattern, 5, 0, 0),
  [9694] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_pattern, 5, 0, 0),
  [9696] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_open_pattern, 5, 0, 0),
  [9698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_open_pattern, 5, 0, 0),
  [9700] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 1, 0, 0),
  [9702] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 1, 0, 0),
  [9704] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4190),
  [9706] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_pattern, 6, 0, 0),
  [9708] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_pattern, 6, 0, 0),
  [9710] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_pattern, 4, 0, 0),
  [9712] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_pattern, 4, 0, 0),
  [9714] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_pattern, 7, 0, 0),
  [9716] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_pattern, 7, 0, 0),
  [9718] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter, 1, 0, 18),
  [9720] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 1, 0, 18),
  [9722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lazy_expression, 3, 0, 0),
  [9724] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lazy_expression, 3, 0, 0),
  [9726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13395),
  [9728] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18050),
  [9730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4463),
  [9732] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assert_expression, 3, 0, 0),
  [9734] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assert_expression, 3, 0, 0),
  [9736] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_pattern, 2, 0, 0),
  [9738] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_pattern, 2, 0, 0),
  [9740] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lazy_expression, 2, 0, 0),
  [9742] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lazy_expression, 2, 0, 0),
  [9744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13382),
  [9746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19832),
  [9748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4243),
  [9750] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assert_expression, 2, 0, 0),
  [9752] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assert_expression, 2, 0, 0),
  [9754] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_pattern, 2, 0, 0),
  [9756] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_pattern, 2, 0, 0),
  [9758] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter, 2, 0, 40),
  [9760] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 2, 0, 40),
  [9762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5758),
  [9764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4318),
  [9766] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__parenthesized_abstract_type, 3, 0, 0),
  [9768] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parenthesized_abstract_type, 3, 0, 0),
  [9770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4456),
  [9772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4339),
  [9774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4306),
  [9776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4372),
  [9778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12198),
  [9780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7874),
  [9782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9951),
  [9784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8189),
  [9786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10997),
  [9788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7871),
  [9790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10873),
  [9792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8086),
  [9794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9400),
  [9796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7837),
  [9798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10899),
  [9800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7875),
  [9802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9152),
  [9804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8085),
  [9806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9707),
  [9808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8078),
  [9810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11032),
  [9812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8113),
  [9814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10407),
  [9816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8049),
  [9818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12600),
  [9820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7878),
  [9822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10904),
  [9824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8057),
  [9826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13577),
  [9828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8031),
  [9830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9371),
  [9832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7996),
  [9834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11775),
  [9836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8181),
  [9838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11009),
  [9840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7950),
  [9842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9422),
  [9844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8098),
  [9846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9637),
  [9848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7945),
  [9850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12891),
  [9852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8279),
  [9854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10637),
  [9856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7911),
  [9858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10114),
  [9860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7933),
  [9862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10636),
  [9864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7864),
  [9866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10260),
  [9868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7866),
  [9870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9125),
  [9872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7859),
  [9874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13157),
  [9876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7846),
  [9878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10852),
  [9880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5761),
  [9882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7839),
  [9884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12695),
  [9886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10960),
  [9888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12629),
  [9890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10217),
  [9892] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16569),
  [9894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20402),
  [9896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8096),
  [9898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11872),
  [9900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15270),
  [9902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15667),
  [9904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10805),
  [9906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8467),
  [9908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7956),
  [9910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7756),
  [9912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7942),
  [9914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9190),
  [9916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14689),
  [9918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15360),
  [9920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15931),
  [9922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16956),
  [9924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8265),
  [9926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10953),
  [9928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8152),
  [9930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8105),
  [9932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8236),
  [9934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13162),
  [9936] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_toplevel_directive, 1, 0, 0),
  [9938] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_toplevel_directive, 1, 0, 0),
  [9940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11699),
  [9942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12287),
  [9944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16560),
  [9946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19719),
  [9948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12288),
  [9950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13412),
  [9952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12286),
  [9954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8653),
  [9956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8284),
  [9958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10002),
  [9960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20280),
  [9962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15746),
  [9964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15497),
  [9966] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_expression, 2, 0, 0),
  [9968] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_expression, 2, 0, 0),
  [9970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10191),
  [9972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9034),
  [9974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10847),
  [9976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13601),
  [9978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16555),
  [9980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20311),
  [9982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8055),
  [9984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10020),
  [9986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9071),
  [9988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10857),
  [9990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11705),
  [9992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8460),
  [9994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7919),
  [9996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7783),
  [9998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7913),
  [10000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9251),
  [10002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14900),
  [10004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15292),
  [10006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15846),
  [10008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17097),
  [10010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8232),
  [10012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10368),
  [10014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20297),
  [10016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15393),
  [10018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16205),
  [10020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8197),
  [10022] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12283),
  [10024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8547),
  [10026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7962),
  [10028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7833),
  [10030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7968),
  [10032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9079),
  [10034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14575),
  [10036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15566),
  [10038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15540),
  [10040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17307),
  [10042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8175),
  [10044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10289),
  [10046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8267),
  [10048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8235),
  [10050] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_expression, 3, 0, 44),
  [10052] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_expression, 3, 0, 44),
  [10054] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_expression, 3, 0, 0),
  [10056] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_expression, 3, 0, 0),
  [10058] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_expression, 3, 0, 0),
  [10060] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_expression, 3, 0, 0),
  [10062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8251),
  [10064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10669),
  [10066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10084),
  [10068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20256),
  [10070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16446),
  [10072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16093),
  [10074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8249),
  [10076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8240),
  [10078] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_exception_expression, 4, 0, 57),
  [10080] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_exception_expression, 4, 0, 57),
  [10082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8206),
  [10084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8233),
  [10086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12854),
  [10088] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_module_expression, 4, 0, 57),
  [10090] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_module_expression, 4, 0, 57),
  [10092] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_open_expression, 4, 0, 57),
  [10094] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_open_expression, 4, 0, 57),
  [10096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9385),
  [10098] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fun_expression, 4, 0, 57),
  [10100] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fun_expression, 4, 0, 57),
  [10102] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 44),
  [10104] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_expression, 4, 0, 44),
  [10106] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_do_clause, 2, 0, 0),
  [10108] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_do_clause, 2, 0, 0),
  [10110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8231),
  [10112] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_expression, 4, 0, 70),
  [10114] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_expression, 4, 0, 70),
  [10116] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_expression, 4, 0, 0),
  [10118] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_expression, 4, 0, 0),
  [10120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8191),
  [10122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8208),
  [10124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8201),
  [10126] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_expression, 4, 0, 0),
  [10128] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_expression, 4, 0, 0),
  [10130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8192),
  [10132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10393),
  [10134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8480),
  [10136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7897),
  [10138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7772),
  [10140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7936),
  [10142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9199),
  [10144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14561),
  [10146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16003),
  [10148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16015),
  [10150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16700),
  [10152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8205),
  [10154] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fun_expression, 5, 0, 91),
  [10156] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fun_expression, 5, 0, 91),
  [10158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8204),
  [10160] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_expression, 5, 0, 70),
  [10162] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_expression, 5, 0, 70),
  [10164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13305),
  [10166] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_do_clause, 3, 0, 0),
  [10168] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_do_clause, 3, 0, 0),
  [10170] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_expression, 5, 0, 0),
  [10172] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_expression, 5, 0, 0),
  [10174] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_expression, 5, 0, 0),
  [10176] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_expression, 5, 0, 0),
  [10178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11799),
  [10180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8141),
  [10182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8196),
  [10184] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fun_expression, 6, 0, 104),
  [10186] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fun_expression, 6, 0, 104),
  [10188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8182),
  [10190] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_expression, 7, 0, 116),
  [10192] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_expression, 7, 0, 116),
  [10194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8183),
  [10196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9440),
  [10198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8151),
  [10200] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_expression, 8, 0, 127),
  [10202] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_expression, 8, 0, 127),
  [10204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8149),
  [10206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12223),
  [10208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16853),
  [10210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8179),
  [10212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8150),
  [10214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13674),
  [10216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8147),
  [10218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8142),
  [10220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18883),
  [10222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4328),
  [10224] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attribute_id_repeat1, 2, 0, 0), SHIFT_REPEAT(16853),
  [10227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11123),
  [10229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8169),
  [10231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8168),
  [10233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9856),
  [10235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9418),
  [10237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8119),
  [10239] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_functor, 4, 0, 57),
  [10241] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_functor, 4, 0, 57),
  [10243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11437),
  [10245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16394),
  [10247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16393),
  [10249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8107),
  [10251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8108),
  [10253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9780),
  [10255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8166),
  [10257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8139),
  [10259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8114),
  [10261] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__tuple_type, 1, 0, 0),
  [10263] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__tuple_type, 1, 0, 0),
  [10265] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_case, 4, 0, 86),
  [10267] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_case, 4, 0, 86),
  [10269] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_expression, 3, 0, 47),
  [10271] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_infix_expression, 3, 0, 47),
  [10273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1956),
  [10275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8291),
  [10277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1955),
  [10279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1941),
  [10281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1916),
  [10283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1915),
  [10285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1914),
  [10287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1911),
  [10289] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 70),
  [10291] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_expression, 4, 0, 70),
  [10293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2270),
  [10295] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 44),
  [10297] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_expression, 3, 0, 44),
  [10299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1850),
  [10301] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_expression, 3, 0, 50),
  [10303] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_set_expression, 3, 0, 50),
  [10305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1957),
  [10307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1910),
  [10309] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__match_cases, 2, 0, 0),
  [10311] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__match_cases, 2, 0, 0),
  [10313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3309),
  [10315] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sign_expression, 2, 0, 25),
  [10317] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sign_expression, 2, 0, 25),
  [10319] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__match_cases, 3, 0, 0),
  [10321] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__match_cases, 3, 0, 0),
  [10323] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0),
  [10325] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0),
  [10327] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3309),
  [10330] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_then_clause, 2, 0, 0),
  [10332] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_then_clause, 2, 0, 0),
  [10334] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_type_of, 4, 0, 0),
  [10336] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_type_of, 4, 0, 0),
  [10338] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_clause, 2, 0, 0),
  [10340] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 2, 0, 0),
  [10342] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_product_expression, 3, 0, 49),
  [10344] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_product_expression, 3, 0, 49),
  [10346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2047),
  [10348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2062),
  [10350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2064),
  [10352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2071),
  [10354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2125),
  [10356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2144),
  [10358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2145),
  [10360] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sign_operator, 1, 0, 0),
  [10362] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sign_operator, 1, 0, 0),
  [10364] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_add_operator, 1, 0, 0),
  [10366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3010),
  [10368] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_refutation_case, 1, 0, 0),
  [10370] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_refutation_case, 1, 0, 0),
  [10372] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3010),
  [10375] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_case, 3, 0, 64),
  [10377] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_case, 3, 0, 64),
  [10379] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__match_cases, 1, 0, 0),
  [10381] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__match_cases, 1, 0, 0),
  [10383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1773),
  [10385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2150),
  [10387] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_aliased_type, 3, 0, 0),
  [10389] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_aliased_type, 3, 0, 0),
  [10391] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type, 1, 0, 0),
  [10393] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type, 1, 0, 0),
  [10395] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cons_expression, 3, 0, 49),
  [10397] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cons_expression, 3, 0, 49),
  [10399] = {.entry = {.count = 1, .reusable = false}}, SHIFT(90),
  [10401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2202),
  [10403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2096),
  [10405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(89),
  [10407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2116),
  [10409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2112),
  [10411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2111),
  [10413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2110),
  [10415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2109),
  [10417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2108),
  [10419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2107),
  [10421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2104),
  [10423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2103),
  [10425] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__attribute, 2, 0, 0),
  [10427] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__attribute, 2, 0, 0),
  [10429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2317),
  [10431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2315),
  [10433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2313),
  [10435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2312),
  [10437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2311),
  [10439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2310),
  [10441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2308),
  [10443] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2307),
  [10445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2306),
  [10447] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_add_operator, 1, 0, 0),
  [10449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2283),
  [10451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2286),
  [10453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2287),
  [10455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2290),
  [10457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2297),
  [10459] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2298),
  [10461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2299),
  [10463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2282),
  [10465] = {.entry = {.count = 1, .reusable = false}}, SHIFT(92),
  [10467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2300),
  [10469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2323),
  [10471] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3236),
  [10473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(96),
  [10475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1876),
  [10477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(94),
  [10479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3105),
  [10481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4397),
  [10483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1806),
  [10485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1804),
  [10487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1803),
  [10489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1802),
  [10491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1798),
  [10493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1775),
  [10495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1777),
  [10497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1779),
  [10499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1780),
  [10501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1799),
  [10503] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10214),
  [10505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3134),
  [10507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1942),
  [10509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10144),
  [10511] = {.entry = {.count = 1, .reusable = false}}, SHIFT(93),
  [10513] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3134),
  [10516] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3236),
  [10519] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3105),
  [10522] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3102),
  [10524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10218),
  [10526] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3102),
  [10529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10187),
  [10531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4037),
  [10533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11978),
  [10535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13261),
  [10537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13614),
  [10539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11342),
  [10541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13584),
  [10543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4557),
  [10545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3269),
  [10547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4021),
  [10549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12192),
  [10551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13372),
  [10553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13630),
  [10555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13579),
  [10557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4619),
  [10559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(121),
  [10561] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(5273),
  [10564] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(4021),
  [10567] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(13997),
  [10570] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(12192),
  [10573] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0),
  [10575] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(13372),
  [10578] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(13630),
  [10581] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(11157),
  [10584] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(11342),
  [10587] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(13579),
  [10590] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(16496),
  [10593] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(16495),
  [10596] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(16494),
  [10599] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(4619),
  [10602] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(16529),
  [10605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2026),
  [10607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(106),
  [10609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1992),
  [10611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1987),
  [10613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1984),
  [10615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1971),
  [10617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1962),
  [10619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1953),
  [10621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1951),
  [10623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1950),
  [10625] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3269),
  [10628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1892),
  [10630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(99),
  [10632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1891),
  [10634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1890),
  [10636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1889),
  [10638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1888),
  [10640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1887),
  [10642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1885),
  [10644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1884),
  [10646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1882),
  [10648] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3294),
  [10650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(123),
  [10652] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3294),
  [10655] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(4037),
  [10658] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(11978),
  [10661] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(13261),
  [10664] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(13614),
  [10667] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(13584),
  [10670] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(4557),
  [10673] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(16660),
  [10676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10195),
  [10678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10223),
  [10680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8463),
  [10682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8671),
  [10684] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7959),
  [10686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10265),
  [10688] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10193),
  [10690] = {.entry = {.count = 1, .reusable = false}}, SHIFT(124),
  [10692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8490),
  [10694] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8691),
  [10696] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7916),
  [10698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8970),
  [10700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8523),
  [10702] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8716),
  [10704] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8087),
  [10706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7753),
  [10708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8101),
  [10710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9220),
  [10712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14730),
  [10714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15774),
  [10716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15211),
  [10718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17353),
  [10720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8539),
  [10722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8694),
  [10724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8091),
  [10726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10212),
  [10728] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9127),
  [10730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8469),
  [10732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8719),
  [10734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7852),
  [10736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7788),
  [10738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7881),
  [10740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9029),
  [10742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14510),
  [10744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15511),
  [10746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15573),
  [10748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17144),
  [10750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10239),
  [10752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3245),
  [10754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2224),
  [10756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2220),
  [10758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2219),
  [10760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2218),
  [10762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2216),
  [10764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2214),
  [10766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2213),
  [10768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2212),
  [10770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2211),
  [10772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13043),
  [10774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8541),
  [10776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8864),
  [10778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7978),
  [10780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7822),
  [10782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7975),
  [10784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9028),
  [10786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14418),
  [10788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15560),
  [10790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15542),
  [10792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17217),
  [10794] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3215),
  [10797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(109),
  [10799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10337),
  [10801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10352),
  [10803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12839),
  [10805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8492),
  [10807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8626),
  [10809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7935),
  [10811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7790),
  [10813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7932),
  [10815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9327),
  [10817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14897),
  [10819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15781),
  [10821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15171),
  [10823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17414),
  [10825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3215),
  [10827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10188),
  [10829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2334),
  [10831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2067),
  [10833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2005),
  [10835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10169),
  [10837] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10228),
  [10839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8620),
  [10841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10178),
  [10843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10252),
  [10845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2089),
  [10847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(108),
  [10849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2087),
  [10851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2086),
  [10853] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2085),
  [10855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2084),
  [10857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2082),
  [10859] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2081),
  [10861] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2077),
  [10863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2076),
  [10865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10152),
  [10867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10141),
  [10869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2189),
  [10871] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3245),
  [10874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10135),
  [10876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5760),
  [10878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10129),
  [10880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(125),
  [10882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9474),
  [10884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8531),
  [10886] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8577),
  [10888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8038),
  [10890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7789),
  [10892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8047),
  [10894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9104),
  [10896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14630),
  [10898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15621),
  [10900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15501),
  [10902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17322),
  [10904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8982),
  [10906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8514),
  [10908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8634),
  [10910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8054),
  [10912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7821),
  [10914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8028),
  [10916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9304),
  [10918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14808),
  [10920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15778),
  [10922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15207),
  [10924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17388),
  [10926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10222),
  [10928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8486),
  [10930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8599),
  [10932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8027),
  [10934] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_binding, 5, 0, 78),
  [10936] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_binding, 5, 0, 78),
  [10938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1781),
  [10940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(111),
  [10942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1782),
  [10944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1783),
  [10946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1784),
  [10948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1785),
  [10950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1786),
  [10952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1787),
  [10954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1788),
  [10956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1789),
  [10958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9474),
  [10960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12839),
  [10962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11705),
  [10964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9450),
  [10966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3230),
  [10968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12283),
  [10970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10082),
  [10972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8982),
  [10974] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3306),
  [10977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8970),
  [10979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3306),
  [10981] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_path, 3, 0, 32),
  [10983] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__module_expression, 1, 0, 0),
  [10985] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__module_expression, 1, 0, 0),
  [10987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20466),
  [10989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2370),
  [10991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2369),
  [10993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2361),
  [10995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2329),
  [10997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2321),
  [10999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2320),
  [11001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2319),
  [11003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2296),
  [11005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2295),
  [11007] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_variable, 2, 0, 0),
  [11009] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_variable, 2, 0, 0),
  [11011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9127),
  [11013] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_path, 1, 0, 5),
  [11015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9523),
  [11017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10805),
  [11019] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3230),
  [11022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9578),
  [11024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(112),
  [11026] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_binding, 4, 0, 56),
  [11028] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_binding, 4, 0, 56),
  [11030] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_binding, 3, 0, 36),
  [11032] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_binding, 3, 0, 36),
  [11034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13043),
  [11036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10393),
  [11038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11863),
  [11040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19309),
  [11042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4253),
  [11044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(137),
  [11046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(191),
  [11048] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_packed_module, 5, 0, 0),
  [11050] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_packed_module, 5, 0, 0),
  [11052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12083),
  [11054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13370),
  [11056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13568),
  [11058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10348),
  [11060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13738),
  [11062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14128),
  [11064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9513),
  [11066] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_application, 2, 0, 15),
  [11068] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_application, 2, 0, 15),
  [11070] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_structure, 2, 0, 0),
  [11072] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_structure, 2, 0, 0),
  [11074] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_open_module, 3, 0, 0),
  [11076] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_open_module, 3, 0, 0),
  [11078] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_packed_module, 7, 0, 0),
  [11080] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_packed_module, 7, 0, 0),
  [11082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13500),
  [11084] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_application, 3, 0, 37),
  [11086] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_application, 3, 0, 37),
  [11088] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_packed_module, 4, 0, 0),
  [11090] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_packed_module, 4, 0, 0),
  [11092] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_module_expression, 1, 0, 0),
  [11094] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_module_expression, 1, 0, 0),
  [11096] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_structure, 3, 0, 0),
  [11098] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_structure, 3, 0, 0),
  [11100] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_open_module, 4, 0, 0),
  [11102] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_open_module, 4, 0, 0),
  [11104] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typed_module_expression, 4, 0, 0),
  [11106] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_typed_module_expression, 4, 0, 0),
  [11108] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_module_expression, 3, 0, 0),
  [11110] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_module_expression, 3, 0, 0),
  [11112] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_packed_module, 6, 0, 0),
  [11114] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_packed_module, 6, 0, 0),
  [11116] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_open_module, 2, 0, 0),
  [11118] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_open_module, 2, 0, 0),
  [11120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9053),
  [11122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14619),
  [11124] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_type, 3, 0, 0),
  [11126] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_type, 3, 0, 0),
  [11128] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_type, 3, 0, 0),
  [11130] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_type, 3, 0, 0),
  [11132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14621),
  [11134] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0),
  [11136] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(12628),
  [11139] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(13997),
  [11142] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(12016),
  [11145] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(13303),
  [11148] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(13499),
  [11151] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(11157),
  [11154] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(10117),
  [11157] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(13512),
  [11160] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(13863),
  [11163] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(16496),
  [11166] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(16495),
  [11169] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(16494),
  [11172] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(12083),
  [11175] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(13370),
  [11178] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(13568),
  [11181] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(10348),
  [11184] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(13738),
  [11187] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(14128),
  [11190] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__signature, 1, 0, 0),
  [11192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13379),
  [11194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13774),
  [11196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9173),
  [11198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14553),
  [11200] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(13379),
  [11203] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(13774),
  [11206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14555),
  [11208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9730),
  [11210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10935),
  [11212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8450),
  [11214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7861),
  [11216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7830),
  [11218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7845),
  [11220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9031),
  [11222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14505),
  [11224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17247),
  [11226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10957),
  [11228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8497),
  [11230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8068),
  [11232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7735),
  [11234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8067),
  [11236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9244),
  [11238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14559),
  [11240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16289),
  [11242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15401),
  [11244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16909),
  [11246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10015),
  [11248] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_include_module, 2, 0, 0),
  [11250] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_include_module, 2, 0, 0),
  [11252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9521),
  [11254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9475),
  [11256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14790),
  [11258] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_type_path, 1, 0, 8),
  [11260] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_type_path, 1, 0, 8),
  [11262] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extended_module_path, 1, 0, 5),
  [11264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8785),
  [11266] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_include_module, 3, 0, 0),
  [11268] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_include_module, 3, 0, 0),
  [11270] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constrain_module, 4, 0, 0),
  [11272] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constrain_module, 4, 0, 0),
  [11274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16536),
  [11276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20309),
  [11278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10710),
  [11280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8543),
  [11282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8082),
  [11284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7752),
  [11286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8081),
  [11288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9158),
  [11290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14671),
  [11292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16313),
  [11294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16304),
  [11296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16795),
  [11298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10201),
  [11300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8493),
  [11302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7939),
  [11304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7793),
  [11306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7963),
  [11308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9063),
  [11310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15081),
  [11312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17156),
  [11314] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__signature, 2, 0, 0),
  [11316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8952),
  [11318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11154),
  [11320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12892),
  [11322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8451),
  [11324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7850),
  [11326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7773),
  [11328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7848),
  [11330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9036),
  [11332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14882),
  [11334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17076),
  [11336] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extended_module_path, 4, 0, 0),
  [11338] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_extended_module_path, 4, 0, 0),
  [11340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9475),
  [11342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9376),
  [11344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14816),
  [11346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9521),
  [11348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14726),
  [11350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14820),
  [11352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10233),
  [11354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8516),
  [11356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8095),
  [11358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7812),
  [11360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8097),
  [11362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9193),
  [11364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14667),
  [11366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17184),
  [11368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10492),
  [11370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8441),
  [11372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7997),
  [11374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7798),
  [11376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8000),
  [11378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9095),
  [11380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14875),
  [11382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16858),
  [11384] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extended_module_path, 3, 0, 32),
  [11386] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_extended_module_path, 3, 0, 32),
  [11388] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_type_path, 3, 0, 38),
  [11390] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_type_path, 3, 0, 38),
  [11392] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_extended_module_path, 1, 0, 5),
  [11394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13762),
  [11396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18561),
  [11398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13176),
  [11400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14793),
  [11402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18599),
  [11404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13159),
  [11406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18870),
  [11408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9419),
  [11410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18511),
  [11412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10855),
  [11414] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_polymorphic_variant_type, 3, 0, 0),
  [11416] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_polymorphic_variant_type, 3, 0, 0),
  [11418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19149),
  [11420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13580),
  [11422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19522),
  [11424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10704),
  [11426] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_type, 4, 0, 0),
  [11428] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_type, 4, 0, 0),
  [11430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19637),
  [11432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10961),
  [11434] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_path, 1, 0, 41),
  [11436] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_path, 1, 0, 41),
  [11438] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_type, 5, 0, 0),
  [11440] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_type, 5, 0, 0),
  [11442] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_open_type, 5, 0, 0),
  [11444] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_open_type, 5, 0, 0),
  [11446] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hash_type, 6, 0, 0),
  [11448] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hash_type, 6, 0, 0),
  [11450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18483),
  [11452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10939),
  [11454] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 3, 0, 6),
  [11456] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 3, 0, 6),
  [11458] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__constructor_argument, 1, 0, 0),
  [11460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10007),
  [11462] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 3, 0, 0),
  [11464] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 3, 0, 0),
  [11466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18472),
  [11468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10950),
  [11470] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hash_type, 5, 0, 0),
  [11472] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hash_type, 5, 0, 0),
  [11474] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_open_type, 3, 0, 0),
  [11476] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_open_type, 3, 0, 0),
  [11478] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_type, 6, 0, 0),
  [11480] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_type, 6, 0, 0),
  [11482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18771),
  [11484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10118),
  [11486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19611),
  [11488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10888),
  [11490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19338),
  [11492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10792),
  [11494] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_polymorphic_variant_type, 7, 0, 0),
  [11496] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_polymorphic_variant_type, 7, 0, 0),
  [11498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16178),
  [11500] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 5, 0, 0),
  [11502] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 5, 0, 0),
  [11504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18421),
  [11506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12776),
  [11508] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructed_type, 5, 0, 0),
  [11510] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructed_type, 5, 0, 0),
  [11512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13280),
  [11514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18346),
  [11516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4407),
  [11518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18399),
  [11520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12666),
  [11522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18386),
  [11524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12702),
  [11526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19561),
  [11528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10638),
  [11530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19509),
  [11532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10682),
  [11534] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hash_type, 2, 0, 0),
  [11536] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hash_type, 2, 0, 0),
  [11538] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_type, 2, 0, 0),
  [11540] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_type, 2, 0, 0),
  [11542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20011),
  [11544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9533),
  [11546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18335),
  [11548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9633),
  [11550] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_polymorphic_variant_type, 4, 0, 0),
  [11552] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_polymorphic_variant_type, 4, 0, 0),
  [11554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18929),
  [11556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11807),
  [11558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14973),
  [11560] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_type, 1, 0, 0),
  [11562] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_type, 1, 0, 0),
  [11564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18941),
  [11566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11820),
  [11568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9788),
  [11570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14490),
  [11572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18644),
  [11574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10148),
  [11576] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_polymorphic_variant_type, 2, 0, 0),
  [11578] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_polymorphic_variant_type, 2, 0, 0),
  [11580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18654),
  [11582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10180),
  [11584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19816),
  [11586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9483),
  [11588] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 5, 0, 6),
  [11590] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 5, 0, 6),
  [11592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19348),
  [11594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10851),
  [11596] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 4, 0, 13),
  [11598] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 4, 0, 13),
  [11600] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hash_type, 3, 0, 0),
  [11602] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hash_type, 3, 0, 0),
  [11604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19097),
  [11606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13711),
  [11608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18310),
  [11610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9535),
  [11612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19266),
  [11614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10045),
  [11616] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_binding_repeat1, 1, 0, 0),
  [11618] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_type_binding_repeat1, 1, 0, 0),
  [11620] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_class_expression, 3, 0, 50),
  [11622] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_class_expression, 3, 0, 50),
  [11624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19681),
  [11626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10901),
  [11628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9730),
  [11630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14740),
  [11632] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructed_type, 4, 0, 0),
  [11634] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructed_type, 4, 0, 0),
  [11636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4394),
  [11638] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructed_type, 2, 0, 0),
  [11640] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructed_type, 2, 0, 0),
  [11642] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_package_type, 4, 0, 0),
  [11644] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_type, 4, 0, 0),
  [11646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20079),
  [11648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9713),
  [11650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14493),
  [11652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19230),
  [11654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11034),
  [11656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18682),
  [11658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10332),
  [11660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19068),
  [11662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13726),
  [11664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19459),
  [11666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9373),
  [11668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18296),
  [11670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9556),
  [11672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19945),
  [11674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10907),
  [11676] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_polymorphic_variant_type, 6, 0, 0),
  [11678] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_polymorphic_variant_type, 6, 0, 0),
  [11680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18745),
  [11682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10341),
  [11684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18247),
  [11686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9100),
  [11688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19415),
  [11690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9490),
  [11692] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_polymorphic_variant_type, 5, 0, 0),
  [11694] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_polymorphic_variant_type, 5, 0, 0),
  [11696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19372),
  [11698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10872),
  [11700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19274),
  [11702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10060),
  [11704] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_type, 3, 0, 0),
  [11706] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_type, 3, 0, 0),
  [11708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19880),
  [11710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10786),
  [11712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19302),
  [11714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9986),
  [11716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18976),
  [11718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11776),
  [11720] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 6, 0, 13),
  [11722] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 6, 0, 13),
  [11724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20179),
  [11726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12487),
  [11728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18838),
  [11730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9358),
  [11732] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_module_binding_repeat1, 2, 0, 0),
  [11734] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_module_binding_repeat1, 2, 0, 0),
  [11736] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(16128),
  [11739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18220),
  [11741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9038),
  [11743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18571),
  [11745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13171),
  [11747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18211),
  [11749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9047),
  [11751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18054),
  [11753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12867),
  [11755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18061),
  [11757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12859),
  [11759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19767),
  [11761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9356),
  [11763] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_path, 3, 0, 84),
  [11765] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_path, 3, 0, 84),
  [11767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20385),
  [11769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12597),
  [11771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18161),
  [11773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9156),
  [11775] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_function, 4, 0, 57),
  [11777] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_function, 4, 0, 57),
  [11779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19427),
  [11781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9472),
  [11783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20029),
  [11785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9758),
  [11787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19208),
  [11789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11094),
  [11791] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_open_class_expression, 4, 0, 57),
  [11793] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_open_class_expression, 4, 0, 57),
  [11795] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_package_type, 5, 0, 0),
  [11797] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_type, 5, 0, 0),
  [11799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18139),
  [11801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9308),
  [11803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19197),
  [11805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11024),
  [11807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18733),
  [11809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10326),
  [11811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20237),
  [11813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12388),
  [11815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18087),
  [11817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12887),
  [11819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19898),
  [11821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10751),
  [11823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18126),
  [11825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9276),
  [11827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19745),
  [11829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9351),
  [11831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18826),
  [11833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9360),
  [11835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12174),
  [11837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15030),
  [11839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1932),
  [11841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1931),
  [11843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1930),
  [11845] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_constructor_declaration_repeat1, 1, 0, 0),
  [11847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10233),
  [11849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14648),
  [11851] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_binding, 1, 0, 7),
  [11853] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_binding, 1, 0, 7),
  [11855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12080),
  [11857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16128),
  [11859] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10740),
  [11861] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_binding, 2, 0, 7),
  [11863] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_binding, 2, 0, 7),
  [11865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11955),
  [11867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10730),
  [11869] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3307),
  [11872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10201),
  [11874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15075),
  [11876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3307),
  [11878] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__module_type, 1, 0, 0),
  [11880] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__module_type, 1, 0, 0),
  [11882] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 1, 0, 3),
  [11884] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 1, 0, 3),
  [11886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6275),
  [11888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8447),
  [11890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8676),
  [11892] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_module_type, 3, 0, 0),
  [11894] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_module_type, 3, 0, 0),
  [11896] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__constructor_argument, 1, 0, 0),
  [11898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9963),
  [11900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1929),
  [11902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1933),
  [11904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1928),
  [11906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1927),
  [11908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1925),
  [11910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1924),
  [11912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [11914] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_signature, 3, 0, 0),
  [11916] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_signature, 3, 0, 0),
  [11918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8785),
  [11920] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 2, 0, 12),
  [11922] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 2, 0, 12),
  [11924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6476),
  [11926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8456),
  [11928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8563),
  [11930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2241),
  [11932] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constrain_module_type, 5, 0, 0),
  [11934] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constrain_module_type, 5, 0, 0),
  [11936] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_module_type_constraint_repeat1, 2, 0, 0),
  [11938] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_module_type_constraint_repeat1, 2, 0, 0),
  [11940] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_expression_item_repeat1, 2, 0, 0),
  [11942] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_expression_item_repeat1, 2, 0, 0),
  [11944] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_expression_item_repeat1, 2, 0, 0), SHIFT_REPEAT(16222),
  [11947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1912),
  [11949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10015),
  [11951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14843),
  [11953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8079),
  [11955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3685),
  [11957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9798),
  [11959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9818),
  [11961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8859),
  [11963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5008),
  [11965] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_signature, 2, 0, 0),
  [11967] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_signature, 2, 0, 0),
  [11969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6298),
  [11971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9890),
  [11973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6446),
  [11975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6855),
  [11977] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3335),
  [11979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9668),
  [11981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8737),
  [11983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5010),
  [11985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2152),
  [11987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2178),
  [11989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2182),
  [11991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2184),
  [11993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2194),
  [11995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2197),
  [11997] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2199),
  [11999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2200),
  [12001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2205),
  [12003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2259),
  [12005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10492),
  [12007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14876),
  [12009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3253),
  [12011] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6280),
  [12013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3570),
  [12015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9832),
  [12017] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8615),
  [12019] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5108),
  [12021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7418),
  [12023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3569),
  [12025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9771),
  [12027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8731),
  [12029] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10388),
  [12031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5114),
  [12033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16363),
  [12035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16188),
  [12037] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_directive, 2, 0, 0),
  [12039] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_directive, 2, 0, 0),
  [12041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15079),
  [12043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2273),
  [12045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2271),
  [12047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2257),
  [12049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2256),
  [12051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2255),
  [12053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2254),
  [12055] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2253),
  [12057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14835),
  [12059] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_item_extension, 4, 0, 0),
  [12061] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_item_extension, 4, 0, 0),
  [12063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2275),
  [12065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [12067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2252),
  [12069] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_class_type, 1, 0, 0),
  [12071] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_class_type, 1, 0, 0),
  [12073] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variant_declaration, 1, 0, 0),
  [12075] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variant_declaration, 1, 0, 0),
  [12077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16813),
  [12079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19630),
  [12081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10652),
  [12083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9705),
  [12085] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0),
  [12087] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0),
  [12089] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_parameter, 2, 0, 0),
  [12091] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_parameter, 2, 0, 0),
  [12093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3577),
  [12095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5120),
  [12097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10025),
  [12099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7372),
  [12101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3433),
  [12103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9774),
  [12105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8631),
  [12107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10484),
  [12109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5035),
  [12111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15928),
  [12113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15437),
  [12115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14590),
  [12117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13291),
  [12119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9046),
  [12121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3710),
  [12123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9738),
  [12125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8586),
  [12127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5099),
  [12129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2395),
  [12131] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quoted_item_extension, 4, 0, 0),
  [12133] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_quoted_item_extension, 4, 0, 0),
  [12135] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_body_type, 3, 0, 0),
  [12137] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_body_type, 3, 0, 0),
  [12139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10809),
  [12141] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_body_type, 6, 0, 0),
  [12143] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_body_type, 6, 0, 0),
  [12145] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_item_extension, 3, 0, 0),
  [12147] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_item_extension, 3, 0, 0),
  [12149] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quoted_item_extension, 6, 0, 0),
  [12151] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_quoted_item_extension, 6, 0, 0),
  [12153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [12155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6277),
  [12157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8453),
  [12159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8733),
  [12161] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_body_type, 5, 0, 0),
  [12163] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_body_type, 5, 0, 0),
  [12165] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instantiated_class_type, 5, 0, 0),
  [12167] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_instantiated_class_type, 5, 0, 0),
  [12169] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3253),
  [12172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9901),
  [12174] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_module_binding_repeat1, 1, 0, 0),
  [12176] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_module_binding_repeat1, 1, 0, 0),
  [12178] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_parameter, 4, 0, 58),
  [12180] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_parameter, 4, 0, 58),
  [12182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6397),
  [12184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17827),
  [12186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4344),
  [12188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_body_type, 2, 0, 0),
  [12190] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_body_type, 2, 0, 0),
  [12192] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instantiated_class_type, 4, 0, 0),
  [12194] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_instantiated_class_type, 4, 0, 0),
  [12196] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_open_class_type, 4, 0, 57),
  [12198] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_open_class_type, 4, 0, 57),
  [12200] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quoted_item_extension, 5, 0, 0),
  [12202] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_quoted_item_extension, 5, 0, 0),
  [12204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4355),
  [12206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9933),
  [12208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16805),
  [12210] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19649),
  [12212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10411),
  [12214] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_item_extension, 5, 0, 0),
  [12216] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_item_extension, 5, 0, 0),
  [12218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10710),
  [12220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14863),
  [12222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2215),
  [12224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2217),
  [12226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2221),
  [12228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2222),
  [12230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2225),
  [12232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2227),
  [12234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2228),
  [12236] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constrain_type, 3, 0, 0),
  [12238] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constrain_type, 3, 0, 0),
  [12240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8825),
  [12242] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 8, 0, 13),
  [12244] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 8, 0, 13),
  [12246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9929),
  [12248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10935),
  [12250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14757),
  [12252] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_external, 5, 0, 0),
  [12254] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_external, 5, 0, 0),
  [12256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12446),
  [12258] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_item_attribute, 4, 0, 0),
  [12260] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_item_attribute, 4, 0, 0),
  [12262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2207),
  [12264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2229),
  [12266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13187),
  [12268] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_expression_item_repeat1, 1, 0, 0),
  [12270] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_expression_item_repeat1, 1, 0, 0),
  [12272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9053),
  [12274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10957),
  [12276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14891),
  [12278] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 7, 0, 6),
  [12280] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 7, 0, 6),
  [12282] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_binding_repeat1, 2, 0, 0),
  [12284] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_type_binding_repeat1, 2, 0, 0),
  [12286] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8825),
  [12289] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_binding, 3, 0, 7),
  [12291] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_binding, 3, 0, 7),
  [12293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12178),
  [12295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6590),
  [12297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8553),
  [12299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8804),
  [12301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14884),
  [12303] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 7, 0, 0),
  [12305] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 7, 0, 0),
  [12307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10071),
  [12309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6572),
  [12311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8857),
  [12313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10009),
  [12315] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constrain_type, 4, 0, 0),
  [12317] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constrain_type, 4, 0, 0),
  [12319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9481),
  [12321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9376),
  [12323] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_external, 6, 0, 0),
  [12325] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_external, 6, 0, 0),
  [12327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [12329] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constrain_type, 5, 0, 0),
  [12331] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constrain_type, 5, 0, 0),
  [12333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9788),
  [12335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10782),
  [12337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16834),
  [12339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19563),
  [12341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10772),
  [12343] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_item_attribute, 3, 0, 0),
  [12345] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_item_attribute, 3, 0, 0),
  [12347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11865),
  [12349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9173),
  [12351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16828),
  [12353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19589),
  [12355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10913),
  [12357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16842),
  [12359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19535),
  [12361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10909),
  [12363] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8857),
  [12366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5762),
  [12368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9498),
  [12370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12653),
  [12372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12874),
  [12374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9900),
  [12376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [12378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9485),
  [12380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10111),
  [12382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9624),
  [12384] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16543),
  [12386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10708),
  [12388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20494),
  [12390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8883),
  [12392] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14947),
  [12394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13720),
  [12396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8952),
  [12398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14703),
  [12400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10845),
  [12402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14478),
  [12404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15498),
  [12406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8969),
  [12408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1960),
  [12410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10005),
  [12412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16884),
  [12414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16913),
  [12416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19326),
  [12418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11049),
  [12420] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 2, 0, 3),
  [12422] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 2, 0, 3),
  [12424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12899),
  [12426] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_constraint, 4, 0, 0),
  [12428] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_constraint, 4, 0, 0),
  [12430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8690),
  [12432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16673),
  [12434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8596),
  [12436] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_equation, 3, 0, 0),
  [12438] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_equation, 3, 0, 0),
  [12440] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 3, 0, 12),
  [12442] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 3, 0, 12),
  [12444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12864),
  [12446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14632),
  [12448] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attribute_id_repeat1, 2, 0, 0), SHIFT_REPEAT(16884),
  [12451] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 5, 0, 0),
  [12453] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 5, 0, 0),
  [12455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2342),
  [12457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12894),
  [12459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9991),
  [12461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9941),
  [12463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14812),
  [12465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9402),
  [12467] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_equation, 2, 0, 0),
  [12469] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_equation, 2, 0, 0),
  [12471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8609),
  [12473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2364),
  [12475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [12477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2363),
  [12479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2358),
  [12481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2357),
  [12483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2356),
  [12485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2355),
  [12487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2352),
  [12489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2351),
  [12491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2350),
  [12493] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 4, 0, 0),
  [12495] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 4, 0, 0),
  [12497] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 3, 0, 0),
  [12499] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 3, 0, 0),
  [12501] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(2995),
  [12504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2995),
  [12506] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attribute_id_repeat1, 2, 0, 0), SHIFT_REPEAT(16782),
  [12509] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_type, 3, 0, 0),
  [12511] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_type, 3, 0, 0),
  [12513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16797),
  [12515] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19668),
  [12517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11004),
  [12519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14750),
  [12521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16782),
  [12523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12910),
  [12525] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8596),
  [12528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14443),
  [12530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9940),
  [12532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10894),
  [12534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14832),
  [12536] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 4, 0, 30),
  [12538] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 4, 0, 30),
  [12540] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_type_constraint, 4, 0, 0),
  [12542] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_type_constraint, 4, 0, 0),
  [12544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14347),
  [12546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3574),
  [12548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8587),
  [12550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14124),
  [12552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5908),
  [12554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9511),
  [12556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14229),
  [12558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(992),
  [12560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15445),
  [12562] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_expression_item_repeat1, 2, 0, 0), SHIFT_REPEAT(16132),
  [12565] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 7, 0, 121),
  [12567] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 7, 0, 121),
  [12569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3291),
  [12571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9366),
  [12573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3713),
  [12575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3973),
  [12577] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_binding, 9, 0, 128),
  [12579] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_binding, 9, 0, 128),
  [12581] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 11, 0, 135),
  [12583] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 11, 0, 135),
  [12585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3333),
  [12587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7090),
  [12589] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 10, 0, 135),
  [12591] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 10, 0, 135),
  [12593] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 10, 0, 130),
  [12595] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 10, 0, 130),
  [12597] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 10, 0, 129),
  [12599] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 10, 0, 129),
  [12601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8651),
  [12603] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 8, 0, 121),
  [12605] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 8, 0, 121),
  [12607] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 9, 0, 95),
  [12609] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 9, 0, 95),
  [12611] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 9, 0, 130),
  [12613] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 9, 0, 130),
  [12615] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 9, 0, 120),
  [12617] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 9, 0, 120),
  [12619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3343),
  [12621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7118),
  [12623] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 9, 0, 129),
  [12625] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 9, 0, 129),
  [12627] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 9, 0, 119),
  [12629] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 9, 0, 119),
  [12631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3314),
  [12633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7370),
  [12635] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 9, 0, 118),
  [12637] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 9, 0, 118),
  [12639] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_binding, 8, 0, 128),
  [12641] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_binding, 8, 0, 128),
  [12643] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_binding, 8, 0, 117),
  [12645] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_binding, 8, 0, 117),
  [12647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_type_constraint, 3, 0, 0),
  [12649] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_type_constraint, 3, 0, 0),
  [12651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14220),
  [12653] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 4, 0, 3),
  [12655] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 4, 0, 3),
  [12657] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 4, 0, 12),
  [12659] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 4, 0, 12),
  [12661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12908),
  [12663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 7, 0, 109),
  [12665] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 7, 0, 109),
  [12667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_function_type, 6, 0, 45),
  [12669] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_function_type, 6, 0, 45),
  [12671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10102),
  [12673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3623),
  [12675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8046),
  [12677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3322),
  [12679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6610),
  [12681] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 8, 0, 95),
  [12683] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 8, 0, 95),
  [12685] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 8, 0, 120),
  [12687] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 8, 0, 120),
  [12689] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 2, 0, 13),
  [12691] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 2, 0, 13),
  [12693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14179),
  [12695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9089),
  [12697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8987),
  [12699] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 1, 0, 0),
  [12701] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 1, 0, 0),
  [12703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14249),
  [12705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9192),
  [12707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8991),
  [12709] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 8, 0, 80),
  [12711] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 8, 0, 80),
  [12713] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 4, 0, 53),
  [12715] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 4, 0, 53),
  [12717] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 1, 0, 6),
  [12719] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 1, 0, 6),
  [12721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14244),
  [12723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9098),
  [12725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9017),
  [12727] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_floating_attribute, 3, 0, 0),
  [12729] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_floating_attribute, 3, 0, 0),
  [12731] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 8, 0, 119),
  [12733] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 8, 0, 119),
  [12735] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 8, 0, 108),
  [12737] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 8, 0, 108),
  [12739] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 8, 0, 118),
  [12741] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 8, 0, 118),
  [12743] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 8, 0, 107),
  [12745] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 8, 0, 107),
  [12747] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_binding, 7, 0, 117),
  [12749] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_binding, 7, 0, 117),
  [12751] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_binding, 7, 0, 106),
  [12753] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_binding, 7, 0, 106),
  [12755] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 8, 0, 93),
  [12757] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 8, 0, 93),
  [12759] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 4, 0, 54),
  [12761] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 4, 0, 54),
  [12763] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 4, 0, 33),
  [12765] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 4, 0, 33),
  [12767] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 6, 0, 109),
  [12769] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 6, 0, 109),
  [12771] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 6, 0, 100),
  [12773] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 6, 0, 100),
  [12775] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_function_type, 5, 0, 66),
  [12777] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_function_type, 5, 0, 66),
  [12779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3327),
  [12781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3493),
  [12783] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 3, 0, 30),
  [12785] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 3, 0, 30),
  [12787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2402),
  [12789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10047),
  [12791] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 7, 0, 96),
  [12793] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 7, 0, 96),
  [12795] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 7, 0, 80),
  [12797] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 7, 0, 80),
  [12799] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 7, 0, 108),
  [12801] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 7, 0, 108),
  [12803] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 7, 0, 60),
  [12805] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 7, 0, 60),
  [12807] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 7, 0, 107),
  [12809] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 7, 0, 107),
  [12811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16818),
  [12813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19610),
  [12815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11641),
  [12817] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 7, 0, 94),
  [12819] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 7, 0, 94),
  [12821] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_binding, 6, 0, 106),
  [12823] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_binding, 6, 0, 106),
  [12825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3537),
  [12827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3961),
  [12829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3641),
  [12831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6341),
  [12833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3712),
  [12835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3964),
  [12837] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 3, 0, 3),
  [12839] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 3, 0, 3),
  [12841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3717),
  [12843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5157),
  [12845] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 5, 0, 86),
  [12847] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 5, 0, 86),
  [12849] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_type_constraint_repeat1, 2, 0, 0), SHIFT_REPEAT(14347),
  [12852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3586),
  [12854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5890),
  [12856] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 7, 0, 93),
  [12858] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 7, 0, 93),
  [12860] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 7, 0, 75),
  [12862] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 7, 0, 75),
  [12864] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 7, 0, 74),
  [12866] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 7, 0, 74),
  [12868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3734),
  [12870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3373),
  [12872] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_binding, 4, 0, 7),
  [12874] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_binding, 4, 0, 7),
  [12876] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_binding, 4, 0, 36),
  [12878] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_binding, 4, 0, 36),
  [12880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11154),
  [12882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14663),
  [12884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3545),
  [12886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5250),
  [12888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3587),
  [12890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7330),
  [12892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1989),
  [12894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3338),
  [12896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7349),
  [12898] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_binding, 3, 0, 59),
  [12900] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_binding, 3, 0, 59),
  [12902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3466),
  [12904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7141),
  [12906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10109),
  [12908] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 4, 0, 61),
  [12910] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 4, 0, 61),
  [12912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2014),
  [12914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [12916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2013),
  [12918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2012),
  [12920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2010),
  [12922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2009),
  [12924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2008),
  [12926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2007),
  [12928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2006),
  [12930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2003),
  [12932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3525),
  [12934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6542),
  [12936] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 4, 0, 16),
  [12938] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 4, 0, 16),
  [12940] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 4, 0, 39),
  [12942] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 4, 0, 39),
  [12944] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 4, 0, 63),
  [12946] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 4, 0, 63),
  [12948] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 5, 0, 100),
  [12950] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 5, 0, 100),
  [12952] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 6, 0, 94),
  [12954] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 6, 0, 94),
  [12956] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 6, 0, 85),
  [12958] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 6, 0, 85),
  [12960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3702),
  [12962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7617),
  [12964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3499),
  [12966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6450),
  [12968] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 3, 0, 33),
  [12970] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 3, 0, 33),
  [12972] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 4, 0, 9),
  [12974] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 4, 0, 9),
  [12976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1980),
  [12978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1979),
  [12980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1977),
  [12982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1976),
  [12984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1975),
  [12986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1974),
  [12988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3438),
  [12990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7127),
  [12992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12893),
  [12994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1983),
  [12996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1973),
  [12998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1972),
  [13000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3580),
  [13002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2985),
  [13004] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8754),
  [13007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3671),
  [13009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4396),
  [13011] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 4, 0, 51),
  [13013] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 4, 0, 51),
  [13015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3362),
  [13017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4031),
  [13019] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 4, 0, 52),
  [13021] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 4, 0, 52),
  [13023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3453),
  [13025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9678),
  [13027] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 5, 0, 51),
  [13029] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 5, 0, 51),
  [13031] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 5, 0, 74),
  [13033] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 5, 0, 74),
  [13035] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 6, 0, 93),
  [13037] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 6, 0, 93),
  [13039] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 6, 0, 75),
  [13041] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 6, 0, 75),
  [13043] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 6, 0, 96),
  [13045] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 6, 0, 96),
  [13047] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 6, 0, 81),
  [13049] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 6, 0, 81),
  [13051] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 6, 0, 74),
  [13053] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 6, 0, 74),
  [13055] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 5, 0, 75),
  [13057] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 5, 0, 75),
  [13059] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 5, 0, 52),
  [13061] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 5, 0, 52),
  [13063] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 6, 0, 60),
  [13065] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 6, 0, 60),
  [13067] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3291),
  [13070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16910),
  [13072] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_binding, 5, 0, 79),
  [13074] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_binding, 5, 0, 79),
  [13076] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 3, 0, 64),
  [13078] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 3, 0, 64),
  [13080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3477),
  [13082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9179),
  [13084] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_binding, 6, 0, 78),
  [13086] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_binding, 6, 0, 78),
  [13088] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 3, 0, 39),
  [13090] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 3, 0, 39),
  [13092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3686),
  [13094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6910),
  [13096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8754),
  [13098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3553),
  [13100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5592),
  [13102] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__polymorphic_typed, 2, 0, 0),
  [13104] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__polymorphic_typed, 2, 0, 0),
  [13106] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 6, 0, 76),
  [13108] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 6, 0, 76),
  [13110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [13112] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 6, 0, 52),
  [13114] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 6, 0, 52),
  [13116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3678),
  [13118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7019),
  [13120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3613),
  [13122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3579),
  [13124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9950),
  [13126] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 6, 0, 51),
  [13128] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 6, 0, 51),
  [13130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14661),
  [13132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3442),
  [13134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6358),
  [13136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3747),
  [13138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5827),
  [13140] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 2, 0, 18),
  [13142] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 2, 0, 18),
  [13144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3319),
  [13146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7143),
  [13148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3711),
  [13150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4195),
  [13152] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_type_constraint_repeat1, 2, 0, 0), SHIFT_REPEAT(14220),
  [13155] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attribute_id_repeat1, 2, 0, 0), SHIFT_REPEAT(16910),
  [13158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3654),
  [13160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3078),
  [13162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3359),
  [13164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6364),
  [13166] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 4, 0, 86),
  [13168] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 4, 0, 86),
  [13170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3646),
  [13172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5111),
  [13174] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 4, 0, 64),
  [13176] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 4, 0, 64),
  [13178] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 5, 0, 85),
  [13180] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 5, 0, 85),
  [13182] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 5, 0, 63),
  [13184] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 5, 0, 63),
  [13186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3670),
  [13188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3495),
  [13190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9267),
  [13192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8966),
  [13194] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_function_type, 3, 0, 0),
  [13196] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_function_type, 3, 0, 0),
  [13198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3420),
  [13200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6266),
  [13202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3391),
  [13204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5397),
  [13206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9119),
  [13208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8994),
  [13210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9117),
  [13212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8996),
  [13214] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 5, 0, 16),
  [13216] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 5, 0, 16),
  [13218] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_type, 1, 0, 0),
  [13220] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_type, 1, 0, 0),
  [13222] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 5, 0, 81),
  [13224] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 5, 0, 81),
  [13226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3666),
  [13228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4821),
  [13230] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_typed, 2, 0, 0),
  [13232] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_typed, 2, 0, 0),
  [13234] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 5, 0, 61),
  [13236] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 5, 0, 61),
  [13238] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_binding, 4, 0, 59),
  [13240] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_binding, 4, 0, 59),
  [13242] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_binding, 4, 0, 79),
  [13244] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_binding, 4, 0, 79),
  [13246] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_external_repeat1, 2, 0, 0),
  [13248] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_external_repeat1, 2, 0, 0),
  [13250] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_external_repeat1, 2, 0, 0), SHIFT_REPEAT(12446),
  [13253] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 5, 0, 30),
  [13255] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 5, 0, 30),
  [13257] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_floating_attribute, 4, 0, 0),
  [13259] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_floating_attribute, 4, 0, 0),
  [13261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3596),
  [13263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7453),
  [13265] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_variant_declaration_repeat1, 2, 0, 0),
  [13267] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_variant_declaration_repeat1, 2, 0, 0),
  [13269] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_binding, 5, 0, 56),
  [13271] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_binding, 5, 0, 56),
  [13273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3409),
  [13275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6145),
  [13277] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__polymorphic_type, 1, 0, 0),
  [13279] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__polymorphic_type, 1, 0, 0),
  [13281] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 5, 0, 54),
  [13283] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 5, 0, 54),
  [13285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3581),
  [13287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4985),
  [13289] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 5, 0, 53),
  [13291] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 5, 0, 53),
  [13293] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 5, 0, 76),
  [13295] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 5, 0, 76),
  [13297] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 5, 0, 12),
  [13299] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 5, 0, 12),
  [13301] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 3, 0, 9),
  [13303] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 3, 0, 9),
  [13305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10982),
  [13307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14536),
  [13309] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_type_definition, 6, 0, 55),
  [13311] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_type_definition, 6, 0, 55),
  [13313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8589),
  [13315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13522),
  [13317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10198),
  [13319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10929),
  [13321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20386),
  [13323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8900),
  [13325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14912),
  [13327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15304),
  [13329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16157),
  [13331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13309),
  [13333] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_type_constraint_repeat1, 2, 0, 0), SHIFT_REPEAT(14273),
  [13336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10837),
  [13338] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14695),
  [13340] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_functor_type, 2, 0, 0),
  [13342] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_functor_type, 2, 0, 0),
  [13344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10744),
  [13346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14337),
  [13348] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__module_typed, 2, 0, 0),
  [13350] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__module_typed, 2, 0, 0),
  [13352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10868),
  [13354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14213),
  [13356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2258),
  [13358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2260),
  [13360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2261),
  [13362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2262),
  [13364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2263),
  [13366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2264),
  [13368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2265),
  [13370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2266),
  [13372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2267),
  [13374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10088),
  [13376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9162),
  [13378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9000),
  [13380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9216),
  [13382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8995),
  [13384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9286),
  [13386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8974),
  [13388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8850),
  [13390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14273),
  [13392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10057),
  [13394] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_external, 7, 0, 0),
  [13396] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_external, 7, 0, 0),
  [13398] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exception_definition, 3, 0, 0),
  [13400] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exception_definition, 3, 0, 0),
  [13402] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_functor_type, 3, 0, 0),
  [13404] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_functor_type, 3, 0, 0),
  [13406] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_type_definition, 7, 0, 77),
  [13408] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_type_definition, 7, 0, 77),
  [13410] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exception_definition, 2, 0, 0),
  [13412] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exception_definition, 2, 0, 0),
  [13414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8744),
  [13416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9166),
  [13418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8959),
  [13420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9136),
  [13422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9001),
  [13424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9185),
  [13426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8997),
  [13428] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_type_definition, 4, 0, 14),
  [13430] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_type_definition, 4, 0, 14),
  [13432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9056),
  [13434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9019),
  [13436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9169),
  [13438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8980),
  [13440] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(9963),
  [13443] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__constructor_argument, 2, 0, 0),
  [13445] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__constructor_argument, 2, 0, 0),
  [13447] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_type_definition, 5, 0, 35),
  [13449] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_type_definition, 5, 0, 35),
  [13451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12897),
  [13453] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_functor_type, 4, 0, 0),
  [13455] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_functor_type, 4, 0, 0),
  [13457] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exception_definition, 4, 0, 0),
  [13459] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exception_definition, 4, 0, 0),
  [13461] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_open_module, 5, 0, 0),
  [13463] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_open_module, 5, 0, 0),
  [13465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12911),
  [13467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [13469] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(9890),
  [13472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9234),
  [13474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9020),
  [13476] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_definition, 5, 0, 0),
  [13478] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_definition, 5, 0, 0),
  [13480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15015),
  [13482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9754),
  [13484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9652),
  [13486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9263),
  [13488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8964),
  [13490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9253),
  [13492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8968),
  [13494] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_type_definition, 4, 0, 35),
  [13496] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_type_definition, 4, 0, 35),
  [13498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10755),
  [13500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3342),
  [13502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7350),
  [13504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9186),
  [13506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8975),
  [13508] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_type_definition_repeat1, 2, 0, 0),
  [13510] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_class_type_definition_repeat1, 2, 0, 0),
  [13512] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_type_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(15015),
  [13515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3508),
  [13517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6472),
  [13519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3530),
  [13521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6564),
  [13523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10749),
  [13525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14300),
  [13527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3585),
  [13529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5856),
  [13531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3665),
  [13533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4834),
  [13535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3703),
  [13537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5183),
  [13539] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_definition, 3, 0, 0),
  [13541] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_definition, 3, 0, 0),
  [13543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8865),
  [13545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1820),
  [13547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1825),
  [13549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1817),
  [13551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1816),
  [13553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1811),
  [13555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1809),
  [13557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1819),
  [13559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1801),
  [13561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1797),
  [13563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3739),
  [13565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4461),
  [13567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3422),
  [13569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7175),
  [13571] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8676),
  [13574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1778),
  [13576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3550),
  [13578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5578),
  [13580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3328),
  [13582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3664),
  [13584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1964),
  [13586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3592),
  [13588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7333),
  [13590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9093),
  [13592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9016),
  [13594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3534),
  [13596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5253),
  [13598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3552),
  [13600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3780),
  [13602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13829),
  [13604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3323),
  [13606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6645),
  [13608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9634),
  [13610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11845),
  [13612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11564),
  [13614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16119),
  [13616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [13618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16466),
  [13620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13139),
  [13622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3500),
  [13624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4058),
  [13626] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variant_declaration, 2, 0, 0),
  [13628] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variant_declaration, 2, 0, 0),
  [13630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3394),
  [13632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7095),
  [13634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3321),
  [13636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7108),
  [13638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11865),
  [13640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14650),
  [13642] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_type_constraint_repeat1, 2, 0, 0), SHIFT_REPEAT(14185),
  [13645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3572),
  [13647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2990),
  [13649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10101),
  [13651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3336),
  [13653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4140),
  [13655] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variant_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(13566),
  [13658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9097),
  [13660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9015),
  [13662] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_external_repeat1, 1, 0, 0),
  [13664] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_external_repeat1, 1, 0, 0),
  [13666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3482),
  [13668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9835),
  [13670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3631),
  [13672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6394),
  [13674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3719),
  [13676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7393),
  [13678] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variant_declaration, 3, 0, 0),
  [13680] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variant_declaration, 3, 0, 0),
  [13682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13566),
  [13684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3591),
  [13686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5954),
  [13688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14185),
  [13690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14652),
  [13692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9189),
  [13694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8998),
  [13696] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attribute_id_repeat1, 2, 0, 0), SHIFT_REPEAT(16701),
  [13699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3330),
  [13701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7031),
  [13703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3738),
  [13705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3419),
  [13707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9834),
  [13709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3326),
  [13711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4469),
  [13713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3748),
  [13715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7003),
  [13717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9827),
  [13719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3041),
  [13721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3687),
  [13723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7964),
  [13725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3707),
  [13727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3894),
  [13729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3568),
  [13731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6353),
  [13733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3445),
  [13735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6380),
  [13737] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(9933),
  [13740] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3041),
  [13743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9665),
  [13745] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_type_definition, 3, 0, 14),
  [13747] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_type_definition, 3, 0, 14),
  [13749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10766),
  [13751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16701),
  [13753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3701),
  [13755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5754),
  [13757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9679),
  [13759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3693),
  [13761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7615),
  [13763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10720),
  [13765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3720),
  [13767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7260),
  [13769] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_definition, 4, 0, 0),
  [13771] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_definition, 4, 0, 0),
  [13773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11866),
  [13775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11283),
  [13777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16395),
  [13779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [13781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3562),
  [13783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9196),
  [13785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10715),
  [13787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9842),
  [13789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9841),
  [13791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3462),
  [13793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5046),
  [13795] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_type_definition, 5, 0, 55),
  [13797] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_type_definition, 5, 0, 55),
  [13799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3644),
  [13801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3075),
  [13803] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(9901),
  [13806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3681),
  [13808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6932),
  [13810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3425),
  [13812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6288),
  [13814] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_type_definition, 6, 0, 77),
  [13816] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_type_definition, 6, 0, 77),
  [13818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [13820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3402),
  [13822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5399),
  [13824] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8563),
  [13827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3566),
  [13829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7422),
  [13831] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variant_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(13829),
  [13834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9779),
  [13836] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(10025),
  [13839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3387),
  [13841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3565),
  [13843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3735),
  [13845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4975),
  [13847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3414),
  [13849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6136),
  [13851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3546),
  [13853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3491),
  [13855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13623),
  [13857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6321),
  [13859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7259),
  [13861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7256),
  [13863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7449),
  [13865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6967),
  [13867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6983),
  [13869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7450),
  [13871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6949),
  [13873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7452),
  [13875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7275),
  [13877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4133),
  [13879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [13881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2264),
  [13883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4051),
  [13885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4014),
  [13887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3988),
  [13889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2024),
  [13891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3980),
  [13893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7463),
  [13895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7262),
  [13897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4441),
  [13899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6953),
  [13901] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_definition, 3, 0, 0),
  [13903] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value_definition, 3, 0, 0),
  [13905] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4580),
  [13907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4580),
  [13909] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_definition, 5, 0, 0),
  [13911] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value_definition, 5, 0, 0),
  [13913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4558),
  [13915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4558),
  [13917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6965),
  [13919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6977),
  [13921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10721),
  [13923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14224),
  [13925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6984),
  [13927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6986),
  [13929] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0),
  [13931] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0),
  [13933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4325),
  [13935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4899),
  [13937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4811),
  [13939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4822),
  [13941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7187),
  [13943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7012),
  [13945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7190),
  [13947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7237),
  [13949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7248),
  [13951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7836),
  [13953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7255),
  [13955] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_definition, 4, 0, 0),
  [13957] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value_definition, 4, 0, 0),
  [13959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8016),
  [13961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7424),
  [13963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7220),
  [13965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1998),
  [13967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1997),
  [13969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1995),
  [13971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1991),
  [13973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1990),
  [13975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1988),
  [13977] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2019),
  [13979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1981),
  [13981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1967),
  [13983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4254),
  [13985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6652),
  [13987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6637),
  [13989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4830),
  [13991] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_include_module_type, 2, 0, 0),
  [13993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6606),
  [13995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6601),
  [13997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6596),
  [13999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4837),
  [14001] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_value_definition_repeat1, 2, 0, 0),
  [14003] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_value_definition_repeat1, 2, 0, 0),
  [14005] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_value_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(4558),
  [14008] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_value_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(4558),
  [14011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3722),
  [14013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3688),
  [14015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3680),
  [14017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4323),
  [14019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7045),
  [14021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3674),
  [14023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3669),
  [14025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7352),
  [14027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7355),
  [14029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3539),
  [14031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3527),
  [14033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7364),
  [14035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7369),
  [14037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3498),
  [14039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7373),
  [14041] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(9900),
  [14044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7353),
  [14046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4098),
  [14048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7354),
  [14050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6152),
  [14052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4166),
  [14054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7368),
  [14056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3490),
  [14058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4138),
  [14060] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_item, 1, 0, 0),
  [14062] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_item, 1, 0, 0),
  [14064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4114),
  [14066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4103),
  [14068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7980),
  [14070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7605),
  [14072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7395),
  [14074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6994),
  [14076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6987),
  [14078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6976),
  [14080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6971),
  [14082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6969),
  [14084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4326),
  [14086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3464),
  [14088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3064),
  [14090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5816),
  [14092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8602),
  [14094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5812),
  [14096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5808),
  [14098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6334),
  [14100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5802),
  [14102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5801),
  [14104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7606),
  [14106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3062),
  [14108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7406),
  [14110] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_definition, 2, 0, 0),
  [14112] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value_definition, 2, 0, 0),
  [14114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9322),
  [14116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8973),
  [14118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10927),
  [14120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5023),
  [14122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3061),
  [14124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9075),
  [14126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9005),
  [14128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9021),
  [14130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9008),
  [14132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4278),
  [14134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5007),
  [14136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3056),
  [14138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5064),
  [14140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6294),
  [14142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3054),
  [14144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4269),
  [14146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7607),
  [14148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7611),
  [14150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4261),
  [14152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8904),
  [14154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2226),
  [14156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6292),
  [14158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5084),
  [14160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7004),
  [14162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6273),
  [14164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6445),
  [14166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7900),
  [14168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5125),
  [14170] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_module_definition_repeat1, 2, 0, 0),
  [14172] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_module_definition_repeat1, 2, 0, 0),
  [14174] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_include_module_type, 3, 0, 0),
  [14176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3796),
  [14178] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_definition_repeat1, 2, 0, 0),
  [14180] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_type_definition_repeat1, 2, 0, 0),
  [14182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6483),
  [14184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3799),
  [14186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [14188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5407),
  [14190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10936),
  [14192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5422),
  [14194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5413),
  [14196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6535),
  [14198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5412),
  [14200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6555),
  [14202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5409),
  [14204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2285),
  [14206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2288),
  [14208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2289),
  [14210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2291),
  [14212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2292),
  [14214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2293),
  [14216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2301),
  [14218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2279),
  [14220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2309),
  [14222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2324),
  [14224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6557),
  [14226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3810),
  [14228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7153),
  [14230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3830),
  [14232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4425),
  [14234] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(8587),
  [14237] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(14124),
  [14240] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_expression_repeat1, 2, 0, 0),
  [14242] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(9511),
  [14245] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(14229),
  [14248] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(992),
  [14251] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(16496),
  [14254] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(16495),
  [14257] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(16494),
  [14260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7154),
  [14262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6865),
  [14264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9176),
  [14266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6133),
  [14268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9160),
  [14270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3841),
  [14272] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variant_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(13623),
  [14275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6128),
  [14277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7162),
  [14279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9146),
  [14281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6122),
  [14283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6116),
  [14285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5858),
  [14287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13239),
  [14289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2204),
  [14291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5884),
  [14293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7872),
  [14295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5906),
  [14297] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(10009),
  [14300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6115),
  [14302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5937),
  [14304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5153),
  [14306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5229),
  [14308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5941),
  [14310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5185),
  [14312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6309),
  [14314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7604),
  [14316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6333),
  [14318] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8733),
  [14321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4919),
  [14323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13599),
  [14325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6340),
  [14327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9113),
  [14329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6056),
  [14331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6055),
  [14333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6342),
  [14335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4196),
  [14337] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_include_module, 4, 0, 0),
  [14339] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_include_module, 4, 0, 0),
  [14341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2997),
  [14343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6044),
  [14345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7334),
  [14347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13786),
  [14349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7203),
  [14351] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(2978),
  [14354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7015),
  [14356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2978),
  [14358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3011),
  [14360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6401),
  [14362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5206),
  [14364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6413),
  [14366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6425),
  [14368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6432),
  [14370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6434),
  [14372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3024),
  [14374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6038),
  [14376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3475),
  [14378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9184),
  [14380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3478),
  [14382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3480),
  [14384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7337),
  [14386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3483),
  [14388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3489),
  [14390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4947),
  [14392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9717),
  [14394] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_value_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(4580),
  [14397] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_value_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(4580),
  [14400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3528),
  [14402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9729),
  [14404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3535),
  [14406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3543),
  [14408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9123),
  [14410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8960),
  [14412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3549),
  [14414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9755),
  [14416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3031),
  [14418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9026),
  [14420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9006),
  [14422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3555),
  [14424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9030),
  [14426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9009),
  [14428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7342),
  [14430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9770),
  [14432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9772),
  [14434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5271),
  [14436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5850),
  [14438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6493),
  [14440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7345),
  [14442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6505),
  [14444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7346),
  [14446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6517),
  [14448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6524),
  [14450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6526),
  [14452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3033),
  [14454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5268),
  [14456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5265),
  [14458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9205),
  [14460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8962),
  [14462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9203),
  [14464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8963),
  [14466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5261),
  [14468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [14470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9112),
  [14472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8999),
  [14474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5259),
  [14476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5254),
  [14478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6974),
  [14480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4940),
  [14482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6585),
  [14484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6597),
  [14486] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variant_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(13786),
  [14489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6609),
  [14491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7228),
  [14493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12291),
  [14495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20331),
  [14497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18915),
  [14499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6741),
  [14501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6616),
  [14503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6618),
  [14505] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variant_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(13599),
  [14508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5690),
  [14510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5684),
  [14512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3889),
  [14514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5648),
  [14516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3879),
  [14518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3758),
  [14520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3876),
  [14522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4937),
  [14524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4939),
  [14526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5649),
  [14528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3935),
  [14530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5623),
  [14532] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_item, 2, 0, 0),
  [14534] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_item, 2, 0, 0),
  [14536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19444),
  [14538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5451),
  [14540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17257),
  [14542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19037),
  [14544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9655),
  [14546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9691),
  [14548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13668),
  [14550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9594),
  [14552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9585),
  [14554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9642),
  [14556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9581),
  [14558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4607),
  [14560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4607),
  [14562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19926),
  [14564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5415),
  [14566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16763),
  [14568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19593),
  [14570] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_specification, 5, 0, 0),
  [14572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12174),
  [14574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14941),
  [14576] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_value_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(4607),
  [14579] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_value_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(4607),
  [14582] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3093),
  [14585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3093),
  [14587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15022),
  [14589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9849),
  [14591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9844),
  [14593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9869),
  [14595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9808),
  [14597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2121),
  [14599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4609),
  [14601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4609),
  [14603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9764),
  [14605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_specification, 3, 0, 0),
  [14607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1978),
  [14609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [14611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1993),
  [14613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1994),
  [14615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1996),
  [14617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2002),
  [14619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2004),
  [14621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2011),
  [14623] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2016),
  [14625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2021),
  [14627] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8804),
  [14630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10092),
  [14632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2060),
  [14634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [14636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2056),
  [14638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2055),
  [14640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2054),
  [14642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2053),
  [14644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2052),
  [14646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2051),
  [14648] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2050),
  [14650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2042),
  [14652] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variant_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(13668),
  [14655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19546),
  [14657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5544),
  [14659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17173),
  [14661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19253),
  [14663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13705),
  [14665] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(9940),
  [14668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10750),
  [14670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10771),
  [14672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20058),
  [14674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12009),
  [14676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16580),
  [14678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19983),
  [14680] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_include_module_type, 4, 0, 0),
  [14682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19797),
  [14684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13754),
  [14686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16933),
  [14688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19485),
  [14690] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(9991),
  [14693] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variant_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(13705),
  [14696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9761),
  [14698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9700),
  [14700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19669),
  [14702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8565),
  [14704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17067),
  [14706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19402),
  [14708] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(9941),
  [14711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9660),
  [14713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8660),
  [14715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8773),
  [14717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14359),
  [14719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9815),
  [14721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12671),
  [14723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14448),
  [14725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9819),
  [14727] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_specification, 4, 0, 0),
  [14729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2057),
  [14731] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_value_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(4609),
  [14734] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_value_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(4609),
  [14737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20292),
  [14739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5365),
  [14741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16562),
  [14743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20119),
  [14745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [14747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2143),
  [14749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [14751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2142),
  [14753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2137),
  [14755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2136),
  [14757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2135),
  [14759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2134),
  [14761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2133),
  [14763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2132),
  [14765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2131),
  [14767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1894),
  [14769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2245),
  [14771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2244),
  [14773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2243),
  [14775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2242),
  [14777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2239),
  [14779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2238),
  [14781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1774),
  [14783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2235),
  [14785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2232),
  [14787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2223),
  [14789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2148),
  [14791] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_definition, 3, 0, 0),
  [14793] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 3, 0, 0),
  [14795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14423),
  [14797] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 3, 0, 0),
  [14799] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_definition, 3, 0, 0),
  [14801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12832),
  [14803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14216),
  [14805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9341),
  [14807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8977),
  [14809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14240),
  [14811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9110),
  [14813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9002),
  [14815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14215),
  [14817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9337),
  [14819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8979),
  [14821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9284),
  [14823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9010),
  [14825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3200),
  [14827] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3200),
  [14830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1959),
  [14832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1985),
  [14834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1949),
  [14836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1945),
  [14838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1919),
  [14840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1918),
  [14842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1917),
  [14844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1913),
  [14846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1904),
  [14848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10925),
  [14850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13211),
  [14852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10804),
  [14854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10951),
  [14856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8908),
  [14858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8774),
  [14860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2138),
  [14862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [14864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2127),
  [14866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2123),
  [14868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2114),
  [14870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2113),
  [14872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2106),
  [14874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2098),
  [14876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2095),
  [14878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2093),
  [14880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2372),
  [14882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [14884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1845),
  [14886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [14888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1844),
  [14890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1843),
  [14892] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1841),
  [14894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1840),
  [14896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1839),
  [14898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1838),
  [14900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1837),
  [14902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1836),
  [14904] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 2, 0, 0),
  [14906] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_definition, 2, 0, 0),
  [14908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9520),
  [14910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13537),
  [14912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12825),
  [14914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14435),
  [14916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14336),
  [14918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14335),
  [14920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9992),
  [14922] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(2971),
  [14925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13757),
  [14927] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_definition, 4, 0, 0),
  [14929] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_definition, 4, 0, 0),
  [14931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15579),
  [14933] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2971),
  [14935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3234),
  [14937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2281),
  [14939] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3234),
  [14942] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3090),
  [14945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9277),
  [14947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8986),
  [14949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9261),
  [14951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8981),
  [14953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2167),
  [14955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [14957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2166),
  [14959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2164),
  [14961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2163),
  [14963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2160),
  [14965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2159),
  [14967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2157),
  [14969] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2156),
  [14971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2155),
  [14973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9690),
  [14975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3090),
  [14977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2028),
  [14979] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_definition, 2, 0, 0),
  [14981] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 2, 0, 0),
  [14983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2045),
  [14985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [14987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2044),
  [14989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2043),
  [14991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2041),
  [14993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2040),
  [14995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2039),
  [14997] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2038),
  [14999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2037),
  [15001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2036),
  [15003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9728),
  [15005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12841),
  [15007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2027),
  [15009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16375),
  [15011] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_definition, 3, 0, 0),
  [15013] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_definition, 3, 0, 0),
  [15015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15744),
  [15017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2394),
  [15019] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_definition, 2, 0, 0),
  [15021] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_definition, 2, 0, 0),
  [15023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1810),
  [15025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9734),
  [15027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2371),
  [15029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [15031] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(14423),
  [15034] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_definition, 4, 0, 0),
  [15036] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 4, 0, 0),
  [15038] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 5, 0, 0),
  [15040] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_definition, 5, 0, 0),
  [15042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12843),
  [15044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12653),
  [15046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14407),
  [15048] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variant_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(13757),
  [15051] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_toplevel_directive, 2, 0, 0),
  [15053] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_toplevel_directive, 2, 0, 0),
  [15055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14207),
  [15057] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 4, 0, 0),
  [15059] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_definition, 4, 0, 0),
  [15061] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(12843),
  [15064] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_definition, 5, 0, 0),
  [15066] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_definition, 5, 0, 0),
  [15068] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(12832),
  [15071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9987),
  [15073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12844),
  [15075] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(15579),
  [15078] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_body_type_repeat1, 2, 0, 0), SHIFT_REPEAT(8773),
  [15081] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_body_type_repeat1, 2, 0, 0), SHIFT_REPEAT(14359),
  [15084] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_body_type_repeat1, 2, 0, 0),
  [15086] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_body_type_repeat1, 2, 0, 0), SHIFT_REPEAT(12671),
  [15089] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_body_type_repeat1, 2, 0, 0), SHIFT_REPEAT(14448),
  [15092] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_body_type_repeat1, 2, 0, 0), SHIFT_REPEAT(16496),
  [15095] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_body_type_repeat1, 2, 0, 0), SHIFT_REPEAT(16495),
  [15098] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_body_type_repeat1, 2, 0, 0), SHIFT_REPEAT(16494),
  [15101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3250),
  [15103] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3250),
  [15106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3179),
  [15108] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3179),
  [15111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14852),
  [15113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2061),
  [15115] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(10109),
  [15118] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_polymorphic_type, 3, 0, 0),
  [15120] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_polymorphic_type, 3, 0, 0),
  [15122] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_polymorphic_type, 3, 0, 73),
  [15124] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_polymorphic_type, 3, 0, 73),
  [15126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14405),
  [15128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2140),
  [15130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3255),
  [15132] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3255),
  [15135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9685),
  [15137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9403),
  [15139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12833),
  [15141] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(15744),
  [15144] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(14852),
  [15147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7711),
  [15149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1694),
  [15151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2344),
  [15153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2180),
  [15155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2179),
  [15157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2177),
  [15159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2176),
  [15161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2175),
  [15163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2174),
  [15165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2173),
  [15167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2172),
  [15169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2169),
  [15171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3763),
  [15173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12923),
  [15175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12923),
  [15177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12909),
  [15179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4297),
  [15181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1735),
  [15183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2115),
  [15185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1647),
  [15187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2100),
  [15189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3787),
  [15191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2099),
  [15193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2097),
  [15195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2092),
  [15197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2088),
  [15199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2073),
  [15201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2069),
  [15203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2059),
  [15205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5927),
  [15207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7037),
  [15209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7070),
  [15211] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3287),
  [15214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3287),
  [15216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1631),
  [15218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6289),
  [15220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6285),
  [15222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1630),
  [15224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7500),
  [15226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8622),
  [15228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8628),
  [15230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1278),
  [15232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8860),
  [15234] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 3, 0, 68),
  [15236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6718),
  [15238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4776),
  [15240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3148),
  [15242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6013),
  [15244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1663),
  [15246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1664),
  [15248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6006),
  [15250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1644),
  [15252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7991),
  [15254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6459),
  [15256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1903),
  [15258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3832),
  [15260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1622),
  [15262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6197),
  [15264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6568),
  [15266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8672),
  [15268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6193),
  [15270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1621),
  [15272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8005),
  [15274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1643),
  [15276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3788),
  [15278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1674),
  [15280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7967),
  [15282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1717),
  [15284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4478),
  [15286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6065),
  [15288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3197),
  [15290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1537),
  [15292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4956),
  [15294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5603),
  [15296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1675),
  [15298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3765),
  [15300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2198),
  [15302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2196),
  [15304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2195),
  [15306] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2193),
  [15308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2192),
  [15310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2191),
  [15312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2190),
  [15314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2187),
  [15316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2183),
  [15318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4969),
  [15320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1538),
  [15322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1636),
  [15324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3653),
  [15326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3659),
  [15328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1637),
  [15330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3209),
  [15332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [15334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1747),
  [15336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5309),
  [15338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5243),
  [15340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1754),
  [15342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11529),
  [15344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1867),
  [15346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16106),
  [15348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12356),
  [15350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6282),
  [15352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5237),
  [15354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1846),
  [15356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1822),
  [15358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1848),
  [15360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1849),
  [15362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2337),
  [15364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [15366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2343),
  [15368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2345),
  [15370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2346),
  [15372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2353),
  [15374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2354),
  [15376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2359),
  [15378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2360),
  [15380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1855),
  [15382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1608),
  [15384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9686),
  [15386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1860),
  [15388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1861),
  [15390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7765),
  [15392] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1863),
  [15394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1814),
  [15396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1864),
  [15398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9702),
  [15400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1607),
  [15402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3589),
  [15404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6844),
  [15406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3436),
  [15408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6679),
  [15410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1680),
  [15412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3522),
  [15414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3097),
  [15416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1683),
  [15418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6669),
  [15420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2206),
  [15422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3463),
  [15424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12838),
  [15426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7560),
  [15428] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5372),
  [15430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2147),
  [15432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7425),
  [15434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1701),
  [15436] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3257),
  [15439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5417),
  [15441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3257),
  [15443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1696),
  [15445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7421),
  [15447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1596),
  [15449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6264),
  [15451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6293),
  [15453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1595),
  [15455] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6864),
  [15457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7120),
  [15459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2379),
  [15461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [15463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2380),
  [15465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2382),
  [15467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2383),
  [15469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2384),
  [15471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2386),
  [15473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2387),
  [15475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2388),
  [15477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2389),
  [15479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4091),
  [15481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1718),
  [15483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1944),
  [15485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1943),
  [15487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1939),
  [15489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1938),
  [15491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1618),
  [15493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7027),
  [15495] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 1, 0, 0),
  [15497] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__structure_repeat2, 1, 0, 0),
  [15499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1720),
  [15501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4110),
  [15503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1588),
  [15505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6484),
  [15507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6496),
  [15509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1587),
  [15511] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8061),
  [15513] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat1, 2, 0, 0), SHIFT_REPEAT(12628),
  [15516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1669),
  [15518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3660),
  [15520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7102),
  [15522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1571),
  [15524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3649),
  [15526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1672),
  [15528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1937),
  [15530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1936),
  [15532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1934),
  [15534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7060),
  [15536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1619),
  [15538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2347),
  [15540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2341),
  [15542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2340),
  [15544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2339),
  [15546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2338),
  [15548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2335),
  [15550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2332),
  [15552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2331),
  [15554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2330),
  [15556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6815),
  [15558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1522),
  [15560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4018),
  [15562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1573),
  [15564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5871),
  [15566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5863),
  [15568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1572),
  [15570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5460),
  [15572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8698),
  [15574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1445),
  [15576] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 4, 0, 88),
  [15578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1947),
  [15580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1926),
  [15582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6304),
  [15584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1901),
  [15586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1561),
  [15588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5375),
  [15590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5378),
  [15592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1560),
  [15594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4092),
  [15596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [15598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2398),
  [15600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2399),
  [15602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2400),
  [15604] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2401),
  [15606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2403),
  [15608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2404),
  [15610] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2405),
  [15612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2407),
  [15614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2408),
  [15616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1519),
  [15618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6807),
  [15620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1697),
  [15622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7709),
  [15624] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__structure_item, 1, 0, 0),
  [15626] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__structure_item, 1, 0, 0),
  [15628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(750),
  [15630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2977),
  [15632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3265),
  [15634] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3097),
  [15637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1547),
  [15639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5130),
  [15641] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(2977),
  [15644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5113),
  [15646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1546),
  [15648] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5876),
  [15650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11100),
  [15652] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4373),
  [15654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2094),
  [15656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2083),
  [15658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2080),
  [15660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2079),
  [15662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2078),
  [15664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2068),
  [15666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2046),
  [15668] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3265),
  [15671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5176),
  [15673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [15675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [15677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2105),
  [15679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2023),
  [15681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1982),
  [15683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10215),
  [15685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1531),
  [15687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5794),
  [15689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13730),
  [15691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5790),
  [15693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1530),
  [15695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1698),
  [15697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5252),
  [15699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5564),
  [15701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11940),
  [15703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7172),
  [15705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1656),
  [15707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7078),
  [15709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1769),
  [15711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5266),
  [15713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1702),
  [15715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1655),
  [15717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7176),
  [15719] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(10088),
  [15722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1555),
  [15724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7324),
  [15726] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3209),
  [15729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1763),
  [15731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7056),
  [15733] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9666),
  [15735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1512),
  [15737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9229),
  [15739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9237),
  [15741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1511),
  [15743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4223),
  [15745] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(12838),
  [15748] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4930),
  [15750] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0),
  [15752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9240),
  [15754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1869),
  [15756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7326),
  [15758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1556),
  [15760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6745),
  [15762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1711),
  [15764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1715),
  [15766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6749),
  [15768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6934),
  [15770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1716),
  [15772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5746),
  [15774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1551),
  [15776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4085),
  [15778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7598),
  [15780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5740),
  [15782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1719),
  [15784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4096),
  [15786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1558),
  [15788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4366),
  [15790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1605),
  [15792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6281),
  [15794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1521),
  [15796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3404),
  [15798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7634),
  [15800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1606),
  [15802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4465),
  [15804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [15806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [15808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(553),
  [15810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1585),
  [15812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7258),
  [15814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3416),
  [15816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1520),
  [15818] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(16106),
  [15821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8593),
  [15823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1027),
  [15825] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 2, 0, 42),
  [15827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5828),
  [15829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1613),
  [15831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3657),
  [15833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1570),
  [15835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7094),
  [15837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4807),
  [15839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1726),
  [15841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3667),
  [15843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1617),
  [15845] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7377),
  [15847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1738),
  [15849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3037),
  [15851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3820),
  [15853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1645),
  [15855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1727),
  [15857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4823),
  [15859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3040),
  [15861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1744),
  [15863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6537),
  [15865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6979),
  [15867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1765),
  [15869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5881),
  [15871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5001),
  [15873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1758),
  [15875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6506),
  [15877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1673),
  [15879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6344),
  [15881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3164),
  [15883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1739),
  [15885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6276),
  [15887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1691),
  [15889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1740),
  [15891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3162),
  [15893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5327),
  [15895] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8569),
  [15897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7270),
  [15899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1586),
  [15901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5869),
  [15903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1759),
  [15905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [15907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [15909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [15911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6665),
  [15913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1755),
  [15915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6551),
  [15917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [15919] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3831),
  [15921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6656),
  [15923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6399),
  [15925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [15927] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3902),
  [15929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6494),
  [15931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4251),
  [15933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [15935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3933),
  [15937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4336),
  [15939] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_content, 1, 0, 0),
  [15941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3471),
  [15943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [15945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3915),
  [15947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3488),
  [15949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1813),
  [15951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1818),
  [15953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1821),
  [15955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1824),
  [15957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4026),
  [15959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [15961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3766),
  [15963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4185),
  [15965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16034),
  [15967] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__instance_variable_name, 1, 0, 10),
  [15969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6103),
  [15971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [15973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3966),
  [15975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6033),
  [15977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1826),
  [15979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1828),
  [15981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1829),
  [15983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3355),
  [15985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [15987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3794),
  [15989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3421),
  [15991] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__signature_item, 1, 0, 0),
  [15993] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 1, 0, 0),
  [15995] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_content_repeat1, 2, 0, 0),
  [15997] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_content_repeat1, 2, 0, 0), SHIFT_REPEAT(12923),
  [16000] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_content_repeat1, 2, 0, 0), SHIFT_REPEAT(12923),
  [16003] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_content_repeat1, 2, 0, 0), SHIFT_REPEAT(12909),
  [16006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6577),
  [16008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [16010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3869),
  [16012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6352),
  [16014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9969),
  [16016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8697),
  [16018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1900),
  [16020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [16022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1899),
  [16024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1896),
  [16026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1893),
  [16028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1886),
  [16030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1879),
  [16032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1877),
  [16034] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1875),
  [16036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1874),
  [16038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14654),
  [16040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3899),
  [16042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [16044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3790),
  [16046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3768),
  [16048] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(14654),
  [16051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1448),
  [16053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8784),
  [16055] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 4, 0, 42),
  [16057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5396),
  [16059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [16061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3761),
  [16063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5353),
  [16065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2367),
  [16067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [16069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2374),
  [16071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2377),
  [16073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2378),
  [16075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2381),
  [16077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2385),
  [16079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2390),
  [16081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2393),
  [16083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2396),
  [16085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1878),
  [16087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [16089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1871),
  [16091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1870),
  [16093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1862),
  [16095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1859),
  [16097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1857),
  [16099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1856),
  [16101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1854),
  [16103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1853),
  [16105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [16107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6858),
  [16109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [16111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3853),
  [16113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7036),
  [16115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6726),
  [16117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [16119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3917),
  [16121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7057),
  [16123] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_expression, 3, 0, 0),
  [16125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5204),
  [16127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [16129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3836),
  [16131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5187),
  [16133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [16135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3367),
  [16137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [16139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3896),
  [16141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3541),
  [16143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12831),
  [16145] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_list_expression_repeat1, 2, 0, 0),
  [16147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4472),
  [16149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [16151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3956),
  [16153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4382),
  [16155] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_expression, 4, 0, 54),
  [16157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6147),
  [16159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [16161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3860),
  [16163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5928),
  [16165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5718),
  [16167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [16169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3900),
  [16171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5608),
  [16173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1812),
  [16175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [16177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1830),
  [16179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6649),
  [16181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [16183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3835),
  [16185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6666),
  [16187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9336),
  [16189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [16191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3918),
  [16193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8156),
  [16195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3088),
  [16197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [16199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3954),
  [16201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3195),
  [16203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1024),
  [16205] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 7, 0, 88),
  [16207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7022),
  [16209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [16211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3934),
  [16213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6731),
  [16215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10067),
  [16217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4813),
  [16219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [16221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3809),
  [16223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4779),
  [16225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [16227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7898),
  [16229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [16231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3814),
  [16233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7981),
  [16235] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(16034),
  [16238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12834),
  [16240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12827),
  [16242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5860),
  [16244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [16246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3939),
  [16248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6045),
  [16250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3339),
  [16252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [16254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3852),
  [16256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3455),
  [16258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5045),
  [16260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [16262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3818),
  [16264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4995),
  [16266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6374),
  [16268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [16270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3792),
  [16272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6513),
  [16274] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(14698),
  [16277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14698),
  [16279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14729),
  [16281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1142),
  [16283] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 6, 0, 88),
  [16285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1164),
  [16287] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 6, 0, 68),
  [16289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12842),
  [16291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1407),
  [16293] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 5, 0, 68),
  [16295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12874),
  [16297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14712),
  [16299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7411),
  [16301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [16303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3807),
  [16305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7456),
  [16307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5272),
  [16309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [16311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3844),
  [16313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5151),
  [16315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6375),
  [16317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [16319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3771),
  [16321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6335),
  [16323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1358),
  [16325] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 5, 0, 42),
  [16327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [16329] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(12834),
  [16332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [16334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6873),
  [16336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [16338] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3793),
  [16340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7242),
  [16342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14714),
  [16344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13477),
  [16346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [16348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7117),
  [16350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [16352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3914),
  [16354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6875),
  [16356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6900),
  [16358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [16360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3895),
  [16362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6922),
  [16364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6818),
  [16366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [16368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3756),
  [16370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7134),
  [16372] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_expression, 3, 0, 33),
  [16374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7149),
  [16376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [16378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3816),
  [16380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6915),
  [16382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12835),
  [16384] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12596),
  [16386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8743),
  [16388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [16390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4151),
  [16392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [16394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3919),
  [16396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4174),
  [16398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3927),
  [16400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [16402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3803),
  [16404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3854),
  [16406] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(14729),
  [16409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7581),
  [16411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [16413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3923),
  [16415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7471),
  [16417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9773),
  [16419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [16421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3770),
  [16423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9752),
  [16425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4968),
  [16427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [16429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3925),
  [16431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4979),
  [16433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6947),
  [16435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [16437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3942),
  [16439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7072),
  [16441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5768),
  [16443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [16445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3932),
  [16447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5809),
  [16449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2982),
  [16451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [16453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3848),
  [16455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3132),
  [16457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16201),
  [16459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__typed, 2, 0, 0),
  [16461] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__typed, 2, 0, 0),
  [16463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8696),
  [16465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1442),
  [16467] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 4, 0, 68),
  [16469] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter_constraint, 4, 0, 0),
  [16471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8629),
  [16473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1285),
  [16475] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 3, 0, 42),
  [16477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8738),
  [16479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1371),
  [16481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 5, 0, 88),
  [16483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1335),
  [16485] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 5, 0, 69),
  [16487] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inheritance_definition, 2, 0, 0),
  [16489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14674),
  [16491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12937),
  [16493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15516),
  [16495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13187),
  [16497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14916),
  [16499] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inheritance_definition, 3, 0, 0),
  [16501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14962),
  [16503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11837),
  [16505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1110),
  [16507] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 6, 0, 89),
  [16509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13076),
  [16511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13037),
  [16513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12955),
  [16515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14914),
  [16517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13057),
  [16519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1465),
  [16521] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 4, 0, 43),
  [16523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13093),
  [16525] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_escape_sequence, 1, 0, 0),
  [16527] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_escape_sequence, 1, 0, 0),
  [16529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13008),
  [16531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13107),
  [16533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8597),
  [16535] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_content_repeat1, 1, 0, 0),
  [16537] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_string_content_repeat1, 1, 0, 0),
  [16539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5807),
  [16541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10804),
  [16543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3709),
  [16545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16825),
  [16547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6225),
  [16549] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 7, 0, 110),
  [16551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3740),
  [16553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10577),
  [16555] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 7, 0, 68),
  [16557] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 7, 0, 122),
  [16559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3884),
  [16561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6213),
  [16563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7701),
  [16565] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 9, 0, 134),
  [16567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10085),
  [16569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7692),
  [16571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7235),
  [16573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3372),
  [16575] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 9, 0, 136),
  [16577] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 6, 0, 101),
  [16579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7300),
  [16581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5258),
  [16583] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 9, 0, 133),
  [16585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11135),
  [16587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5165),
  [16589] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 9, 0, 132),
  [16591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6317),
  [16593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5178),
  [16595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5017),
  [16597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7949),
  [16599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5331),
  [16601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7847),
  [16603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6916),
  [16605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 5, 0, 43),
  [16607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12017),
  [16609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15455),
  [16611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10876),
  [16613] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 10, 0, 136),
  [16615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3634),
  [16617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4178),
  [16619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6706),
  [16621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6305),
  [16623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3156),
  [16625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5986),
  [16627] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tag_pattern, 2, 0, 0),
  [16629] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tag_pattern, 2, 0, 0),
  [16631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5352),
  [16633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 6, 0, 115),
  [16635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4064),
  [16637] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 6, 0, 103),
  [16639] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 8, 0, 134),
  [16641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5070),
  [16643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3945),
  [16645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 8, 0, 126),
  [16647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 8, 0, 125),
  [16649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4419),
  [16651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7399),
  [16653] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lazy_pattern, 2, 0, 0),
  [16655] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lazy_pattern, 2, 0, 0),
  [16657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3611),
  [16659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3386),
  [16661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5976),
  [16663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 6, 0, 114),
  [16665] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 6, 0, 69),
  [16667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 6, 0, 113),
  [16669] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 6, 0, 102),
  [16671] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inheritance_definition, 6, 0, 0),
  [16673] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 4, 0, 90),
  [16675] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 6, 0, 76),
  [16677] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 7, 0, 123),
  [16679] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 7, 0, 111),
  [16681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6765),
  [16683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10561),
  [16685] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 6, 0, 42),
  [16687] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 6, 0, 112),
  [16689] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 5, 0, 103),
  [16691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4010),
  [16693] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 7, 0, 112),
  [16695] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 5, 0, 90),
  [16697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7251),
  [16699] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_initializer, 3, 0, 0),
  [16701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13231),
  [16703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 6, 0, 111),
  [16705] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 8, 0, 124),
  [16707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 8, 0, 123),
  [16709] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 8, 0, 88),
  [16711] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 6, 0, 110),
  [16713] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 7, 0, 124),
  [16715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5146),
  [16717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6245),
  [16719] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__pattern, 1, 0, 0),
  [16721] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__pattern, 1, 0, 0),
  [16723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5745),
  [16725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6836),
  [16727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10528),
  [16729] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inheritance_definition, 4, 0, 0),
  [16731] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attribute_id_repeat1, 2, 0, 0), SHIFT_REPEAT(16825),
  [16734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3540),
  [16736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5737),
  [16738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9106),
  [16740] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_initializer, 2, 0, 0),
  [16742] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 5, 0, 102),
  [16744] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inheritance_definition, 5, 0, 0),
  [16746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9623),
  [16748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6777),
  [16750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8925),
  [16752] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 7, 0, 113),
  [16754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10527),
  [16756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3890),
  [16758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3143),
  [16760] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 7, 0, 125),
  [16762] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 5, 0, 76),
  [16764] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 7, 0, 114),
  [16766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6992),
  [16768] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 7, 0, 126),
  [16770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9647),
  [16772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7212),
  [16774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6742),
  [16776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6532),
  [16778] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 4, 0, 53),
  [16780] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 7, 0, 89),
  [16782] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 7, 0, 115),
  [16784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3946),
  [16786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10849),
  [16788] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 5, 0, 53),
  [16790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3006),
  [16792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7164),
  [16794] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 8, 0, 133),
  [16796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3020),
  [16798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6685),
  [16800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4451),
  [16802] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 8, 0, 132),
  [16804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10716),
  [16806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5886),
  [16808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4255),
  [16810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6071),
  [16812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7052),
  [16814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5903),
  [16816] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 5, 0, 101),
  [16818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5987),
  [16820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4911),
  [16822] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lazy_pattern, 3, 0, 0),
  [16824] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lazy_pattern, 3, 0, 0),
  [16826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4141),
  [16828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11102),
  [16830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5823),
  [16832] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__effect_pattern, 1, 0, 0),
  [16834] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__effect_pattern, 1, 0, 0),
  [16836] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 8, 0, 122),
  [16838] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_effect_pattern, 4, 0, 87),
  [16840] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_effect_pattern, 4, 0, 87),
  [16842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6223),
  [16844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4343),
  [16846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6195),
  [16848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6429),
  [16850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3578),
  [16852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6911),
  [16854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6386),
  [16856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7410),
  [16858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6673),
  [16860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6474),
  [16862] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_alias_pattern, 3, 0, 0),
  [16864] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_alias_pattern, 3, 0, 0),
  [16866] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_pattern, 3, 0, 0),
  [16868] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_pattern, 3, 0, 0),
  [16870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7021),
  [16872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7311),
  [16874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9200),
  [16876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4895),
  [16878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11911),
  [16880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6457),
  [16882] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter_constraint, 5, 0, 0),
  [16884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4876),
  [16886] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_pattern, 2, 0, 0),
  [16888] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_pattern, 2, 0, 0),
  [16890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4933),
  [16892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20126),
  [16894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16741),
  [16896] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inheritance_specification, 2, 0, 0),
  [16898] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_specification, 4, 0, 0),
  [16900] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_specification, 4, 0, 98),
  [16902] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_specification, 4, 0, 46),
  [16904] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_specification, 3, 0, 98),
  [16906] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inheritance_specification, 3, 0, 0),
  [16908] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_specification, 3, 0, 0),
  [16910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9927),
  [16912] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attribute_id_repeat1, 2, 0, 0), SHIFT_REPEAT(16741),
  [16915] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_specification, 5, 0, 46),
  [16917] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_specification, 5, 0, 0),
  [16919] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exception_pattern, 2, 0, 0),
  [16921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3426),
  [16923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3423),
  [16925] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exception_pattern, 2, 0, 0),
  [16927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15044),
  [16929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3417),
  [16931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12892),
  [16933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14430),
  [16935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13383),
  [16937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10440),
  [16939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8776),
  [16941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13380),
  [16943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10161),
  [16945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13391),
  [16947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10053),
  [16949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13301),
  [16951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8791),
  [16953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13249),
  [16955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10072),
  [16957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13411),
  [16959] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exception_pattern, 3, 0, 0),
  [16961] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exception_pattern, 3, 0, 0),
  [16963] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cons_pattern, 3, 0, 0),
  [16965] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cons_pattern, 3, 0, 0),
  [16967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10091),
  [16969] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_pattern, 3, 0, 0),
  [16971] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_pattern, 3, 0, 0),
  [16973] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8776),
  [16976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13408),
  [16978] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_or_pattern, 3, 0, 0),
  [16980] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_or_pattern, 3, 0, 0),
  [16982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13407),
  [16984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8580),
  [16986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16756),
  [16988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20432),
  [16990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20432),
  [16992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20431),
  [16994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6598),
  [16996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(668),
  [16998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(666),
  [17000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(665),
  [17002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15749),
  [17004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6137),
  [17006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1397),
  [17008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1398),
  [17010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1399),
  [17012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6362),
  [17014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(645),
  [17016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(648),
  [17018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(649),
  [17020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4544),
  [17022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14201),
  [17024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5418),
  [17026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2958),
  [17028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14351),
  [17030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7392),
  [17032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5079),
  [17034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1228),
  [17036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1224),
  [17038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1223),
  [17040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5048),
  [17042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1005),
  [17044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1042),
  [17046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1043),
  [17048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6410),
  [17050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(928),
  [17052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(924),
  [17054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(923),
  [17056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16888),
  [17058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19401),
  [17060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11673),
  [17062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10013),
  [17064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2928),
  [17066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14309),
  [17068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13237),
  [17070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13826),
  [17072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13826),
  [17074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20397),
  [17076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2953),
  [17078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14208),
  [17080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9141),
  [17082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2954),
  [17084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8678),
  [17086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3440),
  [17088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1130),
  [17090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1122),
  [17092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1112),
  [17094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6835),
  [17096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(998),
  [17098] = {.entry = {.count = 1, .reusable = false}}, SHIFT(994),
  [17100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(993),
  [17102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3967),
  [17104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1181),
  [17106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1182),
  [17108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1183),
  [17110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9164),
  [17112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1216),
  [17114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1219),
  [17116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1220),
  [17118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6096),
  [17120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1370),
  [17122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1372),
  [17124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1373),
  [17126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2961),
  [17128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14385),
  [17130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7534),
  [17132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2927),
  [17134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(562),
  [17136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(563),
  [17138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(564),
  [17140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4548),
  [17142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14214),
  [17144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5870),
  [17146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1097),
  [17148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1098),
  [17150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1102),
  [17152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6927),
  [17154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(767),
  [17156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(766),
  [17158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(742),
  [17160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4525),
  [17162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14279),
  [17164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5385),
  [17166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9597),
  [17168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1464),
  [17170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1466),
  [17172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1467),
  [17174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2964),
  [17176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14173),
  [17178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7776),
  [17180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16512),
  [17182] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20498),
  [17184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11966),
  [17186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8064),
  [17188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(963),
  [17190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(966),
  [17192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(968),
  [17194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2950),
  [17196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14219),
  [17198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7285),
  [17200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4852),
  [17202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(792),
  [17204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(793),
  [17206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(794),
  [17208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6058),
  [17210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(630),
  [17212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(631),
  [17214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(646),
  [17216] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(15455),
  [17219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5859),
  [17221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1247),
  [17223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1245),
  [17225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1222),
  [17227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4535),
  [17229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14285),
  [17231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8419),
  [17233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4517),
  [17235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14316),
  [17237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5230),
  [17239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5280),
  [17241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1342),
  [17243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1343),
  [17245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1344),
  [17247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3096),
  [17249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(903),
  [17251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(904),
  [17253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(905),
  [17255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2949),
  [17257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8406),
  [17259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5757),
  [17261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(708),
  [17263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(713),
  [17265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(717),
  [17267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6015),
  [17269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1453),
  [17271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1452),
  [17273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1447),
  [17275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4906),
  [17277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1300),
  [17279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1303),
  [17281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1305),
  [17283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14431),
  [17285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7459),
  [17287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(703),
  [17289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(704),
  [17291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(710),
  [17293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2959),
  [17295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14307),
  [17297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8475),
  [17299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3910),
  [17301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1006),
  [17303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1007),
  [17305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1008),
  [17307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4036),
  [17309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1316),
  [17311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1317),
  [17313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1322),
  [17315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6100),
  [17317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1429),
  [17319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1430),
  [17321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1431),
  [17323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4499),
  [17325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14189),
  [17327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8513),
  [17329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16861),
  [17331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19471),
  [17333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12000),
  [17335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16945),
  [17337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19213),
  [17339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11418),
  [17341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3091),
  [17343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1388),
  [17345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1394),
  [17347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1414),
  [17349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2941),
  [17351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(800),
  [17353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(806),
  [17355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(807),
  [17357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2965),
  [17359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14323),
  [17361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16850),
  [17363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19506),
  [17365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11920),
  [17367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6422),
  [17369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(565),
  [17371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(566),
  [17373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(567),
  [17375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7639),
  [17377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1145),
  [17379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1012),
  [17381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1129),
  [17383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6525),
  [17385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1047),
  [17387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1052),
  [17389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1056),
  [17391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6991),
  [17393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(841),
  [17395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(842),
  [17397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(846),
  [17399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4509),
  [17401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14321),
  [17403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5287),
  [17405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7714),
  [17407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(931),
  [17409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(910),
  [17411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(909),
  [17413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5689),
  [17415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1259),
  [17417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1260),
  [17419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1261),
  [17421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16657),
  [17423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20140),
  [17425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14286),
  [17427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14276),
  [17429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16575),
  [17431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20158),
  [17433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_field, 1, 0, 0),
  [17435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2984),
  [17437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1136),
  [17439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1137),
  [17441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1138),
  [17443] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_expression_repeat1, 1, 0, 0),
  [17445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6061),
  [17447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1494),
  [17449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1495),
  [17451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1496),
  [17453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2944),
  [17455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13517),
  [17457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3081),
  [17459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1284),
  [17461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1295),
  [17463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1297),
  [17465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4708),
  [17467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(670),
  [17469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(663),
  [17471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(662),
  [17473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3356),
  [17475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1339),
  [17477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1329),
  [17479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1315),
  [17481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5547),
  [17483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(920),
  [17485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(921),
  [17487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(935),
  [17489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13481),
  [17491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4025),
  [17493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(752),
  [17495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(753),
  [17497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(754),
  [17499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9247),
  [17501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10037),
  [17503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1265),
  [17505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10237),
  [17507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8741),
  [17509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(795),
  [17511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8008),
  [17513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10186),
  [17515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8512),
  [17517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9004),
  [17519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8728),
  [17521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9319),
  [17523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9248),
  [17525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1196),
  [17527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7721),
  [17529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14291),
  [17531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1508),
  [17533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7802),
  [17535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10774),
  [17537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8457),
  [17539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9269),
  [17541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9384),
  [17543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9091),
  [17545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12643),
  [17547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12922),
  [17549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8459),
  [17551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9412),
  [17553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8484),
  [17555] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_body_type_repeat1, 1, 0, 0),
  [17557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9287),
  [17559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12855),
  [17561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10093),
  [17563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8479),
  [17565] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_field_specification, 1, 0, 0),
  [17567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9145),
  [17569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13676),
  [17571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10570),
  [17573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8515),
  [17575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9128),
  [17577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10190),
  [17579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9501),
  [17581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8487),
  [17583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(602),
  [17585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8813),
  [17587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9044),
  [17589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10966),
  [17591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10640),
  [17593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8496),
  [17595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1076),
  [17597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7511),
  [17599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9037),
  [17601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10672),
  [17603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9135),
  [17605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8495),
  [17607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11178),
  [17609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8443),
  [17611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10128),
  [17613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9275),
  [17615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13163),
  [17617] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_quoted_string_content_repeat1, 2, 0, 0), SHIFT_REPEAT(13826),
  [17620] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_quoted_string_content_repeat1, 2, 0, 0), SHIFT_REPEAT(13826),
  [17623] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_quoted_string_content_repeat1, 2, 0, 0),
  [17625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10768),
  [17627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9218),
  [17629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10293),
  [17631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9116),
  [17633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11785),
  [17635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9307),
  [17637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9441),
  [17639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13185),
  [17641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8555),
  [17643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9919),
  [17645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9051),
  [17647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10916),
  [17649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13837),
  [17651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9786),
  [17653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8446),
  [17655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9311),
  [17657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9866),
  [17659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10285),
  [17661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8529),
  [17663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9414),
  [17665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8507),
  [17667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quoted_string_content, 1, 0, 0),
  [17669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10963),
  [17671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10781),
  [17673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8556),
  [17675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10211),
  [17677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9312),
  [17679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11124),
  [17681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11893),
  [17683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8466),
  [17685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12634),
  [17687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8532),
  [17689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9296),
  [17691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9423),
  [17693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9273),
  [17695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9298),
  [17697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9325),
  [17699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12226),
  [17701] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8728),
  [17704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9329),
  [17706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10854),
  [17708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9149),
  [17710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9559),
  [17712] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_type_constraint_repeat1, 2, 0, 0), SHIFT_REPEAT(14291),
  [17715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9775),
  [17717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8527),
  [17719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12870),
  [17721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8470),
  [17723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9138),
  [17725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10846),
  [17727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10887),
  [17729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8491),
  [17731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9170),
  [17733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8517),
  [17735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10803),
  [17737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8549),
  [17739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4624),
  [17741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4627),
  [17743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5650),
  [17745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4572),
  [17747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15062),
  [17749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4636),
  [17751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8722),
  [17753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11376),
  [17755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16402),
  [17757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14467),
  [17759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9688),
  [17761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10875),
  [17763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14180),
  [17765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13481),
  [17767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16845),
  [17769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7531),
  [17771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11586),
  [17773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11225),
  [17775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4626),
  [17777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4625),
  [17779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4573),
  [17781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14623),
  [17783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4622),
  [17785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5641),
  [17787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11688),
  [17789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16622),
  [17791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7747),
  [17793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16773),
  [17795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14096),
  [17797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2564),
  [17799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14152),
  [17801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13565),
  [17803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16523),
  [17805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16772),
  [17807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14149),
  [17809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [17811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1127),
  [17813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11492),
  [17815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16506),
  [17817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8934),
  [17819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14335),
  [17821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11498),
  [17823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11616),
  [17825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16624),
  [17827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5486),
  [17829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5651),
  [17831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4660),
  [17833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4661),
  [17835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14432),
  [17837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4662),
  [17839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(487),
  [17841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4582),
  [17843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13263),
  [17845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3620),
  [17847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3621),
  [17849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3285),
  [17851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14996),
  [17853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3622),
  [17855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8053),
  [17857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13418),
  [17859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4581),
  [17861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(384),
  [17863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16905),
  [17865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8840),
  [17867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [17869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13252),
  [17871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3293),
  [17873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10246),
  [17875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3529),
  [17877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3524),
  [17879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10238),
  [17881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3292),
  [17883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3521),
  [17885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11605),
  [17887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16727),
  [17889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10134),
  [17891] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16846),
  [17893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5691),
  [17895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11562),
  [17897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(431),
  [17899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(464),
  [17901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11378),
  [17903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11241),
  [17905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11576),
  [17907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11606),
  [17909] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16728),
  [17911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13297),
  [17913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11364),
  [17915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11521),
  [17917] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16904),
  [17919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8866),
  [17921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11432),
  [17923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11403),
  [17925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(470),
  [17927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(458),
  [17929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [17931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16357),
  [17933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14482),
  [17935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10058),
  [17937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11369),
  [17939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(465),
  [17941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11447),
  [17943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11726),
  [17945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2550),
  [17947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13654),
  [17949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16658),
  [17951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2549),
  [17953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13553),
  [17955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16711),
  [17957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16815),
  [17959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7665),
  [17961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11361),
  [17963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11358),
  [17965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11723),
  [17967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11719),
  [17969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11401),
  [17971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [17973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [17975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(481),
  [17977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9399),
  [17979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11393),
  [17981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [17983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11846),
  [17985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11343),
  [17987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16730),
  [17989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10261),
  [17991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16847),
  [17993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7513),
  [17995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16848),
  [17997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5679),
  [17999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16305),
  [18001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14537),
  [18003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9375),
  [18005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11700),
  [18007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16874),
  [18009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7943),
  [18011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11536),
  [18013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3261),
  [18015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8817),
  [18017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11397),
  [18019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8814),
  [18021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3262),
  [18023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16731),
  [18025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13332),
  [18027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16875),
  [18029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5627),
  [18031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11695),
  [18033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16767),
  [18035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13857),
  [18037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16278),
  [18039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14528),
  [18041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9355),
  [18043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11242),
  [18045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11643),
  [18047] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tag_specification, 4, 0, 0),
  [18049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16584),
  [18051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8681),
  [18053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(413),
  [18055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11717),
  [18057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11384),
  [18059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11240),
  [18061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [18063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11629),
  [18065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11613),
  [18067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8052),
  [18069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3286),
  [18071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16812),
  [18073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8943),
  [18075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11701),
  [18077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11531),
  [18079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11680),
  [18081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [18083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11265),
  [18085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11222),
  [18087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11662),
  [18089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11261),
  [18091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(406),
  [18093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11675),
  [18095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16809),
  [18097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7686),
  [18099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11657),
  [18101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11338),
  [18103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [18105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11637),
  [18107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11686),
  [18109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11635),
  [18111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11426),
  [18113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11624),
  [18115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16765),
  [18117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13832),
  [18119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12947),
  [18121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12935),
  [18123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3232),
  [18125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [18127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3233),
  [18129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13066),
  [18131] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_type_repeat1, 2, 0, 0),
  [18133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11421),
  [18135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11263),
  [18137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5541),
  [18139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11333),
  [18141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11229),
  [18143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13954),
  [18145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4565),
  [18147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5542),
  [18149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4612),
  [18151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4553),
  [18153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5517),
  [18155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11614),
  [18157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(450),
  [18159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11395),
  [18161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11611),
  [18163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11594),
  [18165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11231),
  [18167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11591),
  [18169] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tag_specification, 3, 0, 0),
  [18171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11471),
  [18173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11572),
  [18175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [18177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11249),
  [18179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4564),
  [18181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8912),
  [18183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11431),
  [18185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11550),
  [18187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8906),
  [18189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4561),
  [18191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8901),
  [18193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3036),
  [18195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7726),
  [18197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2574),
  [18199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13715),
  [18201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16740),
  [18203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16687),
  [18205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13077),
  [18207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11419),
  [18209] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_payload, 2, 0, 0),
  [18211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(639),
  [18213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(428),
  [18215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16699),
  [18217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5489),
  [18219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7803),
  [18221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3039),
  [18223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(411),
  [18225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7723),
  [18227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3083),
  [18229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11321),
  [18231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11556),
  [18233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11268),
  [18235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11210),
  [18237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4590),
  [18239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5704),
  [18241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11359),
  [18243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7904),
  [18245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5711),
  [18247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4618),
  [18249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11590),
  [18251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11579),
  [18253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11465),
  [18255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11271),
  [18257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11252),
  [18259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16641),
  [18261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5511),
  [18263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11216),
  [18265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2584),
  [18267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13680),
  [18269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16625),
  [18271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11319),
  [18273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5714),
  [18275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16689),
  [18277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13080),
  [18279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3297),
  [18281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7507),
  [18283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [18285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11267),
  [18287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7510),
  [18289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3283),
  [18291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3013),
  [18293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7811),
  [18295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(419),
  [18297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [18299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11518),
  [18301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11457),
  [18303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [18305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12128),
  [18307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4562),
  [18309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13969),
  [18311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [18313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [18315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(495),
  [18317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11525),
  [18319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16877),
  [18321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5612),
  [18323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13919),
  [18325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4603),
  [18327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5565),
  [18329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11373),
  [18331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16876),
  [18333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7865),
  [18335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(456),
  [18337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16640),
  [18339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7818),
  [18341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5555),
  [18343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11516),
  [18345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13943),
  [18347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11467),
  [18349] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16690),
  [18351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5458),
  [18353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3180),
  [18355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13930),
  [18357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11305),
  [18359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13927),
  [18361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3181),
  [18363] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_quoted_string_content_repeat1, 1, 0, 0),
  [18365] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_quoted_string_content_repeat1, 1, 0, 0),
  [18367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11298),
  [18369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5557),
  [18371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4563),
  [18373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5911),
  [18375] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_pattern, 3, 0, 0),
  [18377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5935),
  [18379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6469),
  [18381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5061),
  [18383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4313),
  [18385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3726),
  [18387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5245),
  [18389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6346),
  [18391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3104),
  [18393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6439),
  [18395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6189),
  [18397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7124),
  [18399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7156),
  [18401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3106),
  [18403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6392),
  [18405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3938),
  [18407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3126),
  [18409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11898),
  [18411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5826),
  [18413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6381),
  [18415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5398),
  [18417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7268),
  [18419] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_expression_item_repeat1, 2, 0, 0), SHIFT_REPEAT(15950),
  [18422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6840),
  [18424] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_list_pattern_repeat1, 2, 0, 0),
  [18426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3151),
  [18428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9188),
  [18430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3940),
  [18432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6360),
  [18434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6968),
  [18436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3575),
  [18438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6989),
  [18440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4443),
  [18442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9058),
  [18444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4186),
  [18446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7111),
  [18448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5005),
  [18450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3743),
  [18452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9148),
  [18454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5982),
  [18456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10369),
  [18458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3955),
  [18460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14247),
  [18462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8650),
  [18464] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__tag_spec, 1, 0, 0),
  [18466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15065),
  [18468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7155),
  [18470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5202),
  [18472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5192),
  [18474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7252),
  [18476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5973),
  [18478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6302),
  [18480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9033),
  [18482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4329),
  [18484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6837),
  [18486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8575),
  [18488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3077),
  [18490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3715),
  [18492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6241),
  [18494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5962),
  [18496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5170),
  [18498] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_list_binding_pattern_repeat1, 2, 0, 0),
  [18500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4835),
  [18502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15496),
  [18504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13131),
  [18506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3953),
  [18508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4270),
  [18510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4844),
  [18512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6396),
  [18514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5817),
  [18516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6415),
  [18518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3697),
  [18520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7277),
  [18522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5957),
  [18524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6203),
  [18526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4127),
  [18528] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_binding_pattern, 3, 0, 82),
  [18530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4867),
  [18532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6850),
  [18534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5173),
  [18536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6935),
  [18538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6268),
  [18540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7407),
  [18542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7905),
  [18544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3714),
  [18546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4862),
  [18548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6159),
  [18550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6639),
  [18552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4923),
  [18554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7013),
  [18556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7332),
  [18558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6107),
  [18560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6154),
  [18562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6368),
  [18564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6842),
  [18566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6442),
  [18568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6280),
  [18570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7351),
  [18572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5889),
  [18574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5129),
  [18576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4950),
  [18578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5939),
  [18580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3494),
  [18582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9692),
  [18584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3968),
  [18586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7230),
  [18588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5929),
  [18590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7204),
  [18592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14655),
  [18594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5829),
  [18596] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_binding_pattern, 4, 0, 99),
  [18598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4468),
  [18600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3906),
  [18602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7356),
  [18604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6471),
  [18606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6867),
  [18608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7371),
  [18610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6010),
  [18612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7308),
  [18614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4824),
  [18616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6822),
  [18618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9046),
  [18620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6075),
  [18622] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_pattern, 4, 0, 0),
  [18624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6339),
  [18626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6486),
  [18628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6139),
  [18630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6332),
  [18632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7292),
  [18634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4294),
  [18636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4986),
  [18638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4907),
  [18640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9639),
  [18642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6799),
  [18644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4159),
  [18646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2987),
  [18648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6792),
  [18650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3903),
  [18652] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_tag_specification_repeat1, 2, 0, 0),
  [18654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7849),
  [18656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5894),
  [18658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6780),
  [18660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5319),
  [18662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4132),
  [18664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7282),
  [18666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3926),
  [18668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9588),
  [18670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5166),
  [18672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5847),
  [18674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6320),
  [18676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4123),
  [18678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6768),
  [18680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3987),
  [18682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3752),
  [18684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6812),
  [18686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9571),
  [18688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3629),
  [18690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5034),
  [18692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3582),
  [18694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8029),
  [18696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4145),
  [18698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3014),
  [18700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9563),
  [18702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6769),
  [18704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6962),
  [18706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3775),
  [18708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4043),
  [18710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8079),
  [18712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4342),
  [18714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5211),
  [18716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7218),
  [18718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5755),
  [18720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3003),
  [18722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4192),
  [18724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6452),
  [18726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6855),
  [18728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3379),
  [18730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5251),
  [18732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6308),
  [18734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6912),
  [18736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5694),
  [18738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7046),
  [18740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4070),
  [18742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7297),
  [18744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7662),
  [18746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6754),
  [18748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7672),
  [18750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5705),
  [18752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6998),
  [18754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7689),
  [18756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5156),
  [18758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5347),
  [18760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6144),
  [18762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3366),
  [18764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4345),
  [18766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3608),
  [18768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7698),
  [18770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3476),
  [18772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2988),
  [18774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4197),
  [18776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5730),
  [18778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12641),
  [18780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14281),
  [18782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15534),
  [18784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7261),
  [18786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6676),
  [18788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6216),
  [18790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5110),
  [18792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3497),
  [18794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5186),
  [18796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6544),
  [18798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2986),
  [18800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3593),
  [18802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3350),
  [18804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3588),
  [18806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7616),
  [18808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3563),
  [18810] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_typed, 2, 0, 0),
  [18812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6801),
  [18814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4905),
  [18816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6228),
  [18818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5332),
  [18820] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20460),
  [18822] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13761),
  [18824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16548),
  [18826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5584),
  [18828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3345),
  [18830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6707),
  [18832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3523),
  [18834] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_type_constraint_repeat1, 2, 0, 0), SHIFT_REPEAT(14247),
  [18837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6973),
  [18839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6240),
  [18841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6700),
  [18843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4158),
  [18845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7379),
  [18847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5374),
  [18849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6247),
  [18851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6688),
  [18853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5744),
  [18855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7953),
  [18857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10767),
  [18859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14261),
  [18861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13282),
  [18863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14720),
  [18865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12641),
  [18867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19006),
  [18869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5726),
  [18871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18179),
  [18873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5026),
  [18875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14784),
  [18877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14408),
  [18879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20420),
  [18881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12885),
  [18883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16185),
  [18885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5676),
  [18887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12886),
  [18889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16452),
  [18891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18199),
  [18893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7719),
  [18895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10202),
  [18897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17710),
  [18899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6270),
  [18901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9506),
  [18903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7515),
  [18905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1866),
  [18907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8562),
  [18909] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_expression, 1, 0, 23),
  [18911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10305),
  [18913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14821),
  [18915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14642),
  [18917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15076),
  [18919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20434),
  [18921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4228),
  [18923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14433),
  [18925] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_param, 2, 0, 11),
  [18927] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_param, 2, 0, 0),
  [18929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14620),
  [18931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14458),
  [18933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10361),
  [18935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11856),
  [18937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8632),
  [18939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18031),
  [18941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6017),
  [18943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10184),
  [18945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12873),
  [18947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16493),
  [18949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18442),
  [18951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4117),
  [18953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8948),
  [18955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2627),
  [18957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15596),
  [18959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14878),
  [18961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7663),
  [18963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13351),
  [18965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20105),
  [18967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4259),
  [18969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14641),
  [18971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19081),
  [18973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5289),
  [18975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17905),
  [18977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6719),
  [18979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18158),
  [18981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6730),
  [18983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15080),
  [18985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17772),
  [18987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6178),
  [18989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19968),
  [18991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5240),
  [18993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18527),
  [18995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3692),
  [18997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11097),
  [18999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12062),
  [19001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18893),
  [19003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8024),
  [19005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12916),
  [19007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16443),
  [19009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8930),
  [19011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10210),
  [19013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20098),
  [19015] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tag_specification_repeat1, 2, 0, 0), SHIFT_REPEAT(8681),
  [19018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14659),
  [19020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14496),
  [19022] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_expression_item_repeat1, 2, 0, 0), SHIFT_REPEAT(16201),
  [19025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9658),
  [19027] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tag_specification, 5, 0, 0),
  [19029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9167),
  [19031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18743),
  [19033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3048),
  [19035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14894),
  [19037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14622),
  [19039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14670),
  [19041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12849),
  [19043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15295),
  [19045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12762),
  [19047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19837),
  [19049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7442),
  [19051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18357),
  [19053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9245),
  [19055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18305),
  [19057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4902),
  [19059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14255),
  [19061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9264),
  [19063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8983),
  [19065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9589),
  [19067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14917),
  [19069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14739),
  [19071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17742),
  [19073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3815),
  [19075] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_instantiated_class_type_repeat1, 2, 0, 0),
  [19077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17651),
  [19079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3916),
  [19081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14747),
  [19083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19256),
  [19085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3677),
  [19087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17837),
  [19089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9720),
  [19091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14357),
  [19093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9239),
  [19095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8985),
  [19097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9962),
  [19099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18585),
  [19101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5963),
  [19103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19389),
  [19105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7121),
  [19107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15032),
  [19109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19314),
  [19111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7339),
  [19113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16715),
  [19115] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_param, 1, 0, 0),
  [19117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9187),
  [19119] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_param, 3, 0, 0),
  [19121] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_param, 3, 0, 29),
  [19123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10344),
  [19125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17962),
  [19127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6514),
  [19129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19167),
  [19131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6845),
  [19133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19009),
  [19135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3446),
  [19137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18791),
  [19139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4061),
  [19141] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_param, 1, 0, 2),
  [19143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16235),
  [19145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14203),
  [19147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12890),
  [19149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16492),
  [19151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14889),
  [19153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8967),
  [19155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12866),
  [19157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14503),
  [19159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11764),
  [19161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18437),
  [19163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3169),
  [19165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3744),
  [19167] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_pattern, 1, 0, 0),
  [19169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8990),
  [19171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19243),
  [19173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4990),
  [19175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8838),
  [19177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7816),
  [19179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8958),
  [19181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14841),
  [19183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14302),
  [19185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9069),
  [19187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9018),
  [19189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14718),
  [19191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10592),
  [19193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5512),
  [19195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14556),
  [19197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14635),
  [19199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19576),
  [19201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7107),
  [19203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8992),
  [19205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19153),
  [19207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3600),
  [19209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17898),
  [19211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6316),
  [19213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18103),
  [19215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5387),
  [19217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5607),
  [19219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7840),
  [19221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14991),
  [19223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5467),
  [19225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18268),
  [19227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5783),
  [19229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4666),
  [19231] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_binding_pattern, 1, 0, 0),
  [19233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19704),
  [19235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7148),
  [19237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13907),
  [19239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18614),
  [19241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6168),
  [19243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14102),
  [19245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13086),
  [19247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14809),
  [19249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19475),
  [19251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7183),
  [19253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18702),
  [19255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7096),
  [19257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18551),
  [19259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6640),
  [19261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17608),
  [19263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6024),
  [19265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5158),
  [19267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6428),
  [19269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12730),
  [19271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10830),
  [19273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8214),
  [19275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16063),
  [19277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10132),
  [19279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10864),
  [19281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8588),
  [19283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6271),
  [19285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10769),
  [19287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10793),
  [19289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10143),
  [19291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13420),
  [19293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14193),
  [19295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4406),
  [19297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13184),
  [19299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8747),
  [19301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6014),
  [19303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14271),
  [19305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15343),
  [19307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9094),
  [19309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14234),
  [19311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9088),
  [19313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5224),
  [19315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7372),
  [19317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13796),
  [19319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15578),
  [19321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9794),
  [19323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16659),
  [19325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6419),
  [19327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(609),
  [19329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8560),
  [19331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8741),
  [19333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3959),
  [19335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10921),
  [19337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7007),
  [19339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14253),
  [19341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10156),
  [19343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10892),
  [19345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16632),
  [19347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9485),
  [19349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13170),
  [19351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15538),
  [19353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16330),
  [19355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15586),
  [19357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5980),
  [19359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10826),
  [19361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15342),
  [19363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9323),
  [19365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15755),
  [19367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15792),
  [19369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3965),
  [19371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16497),
  [19373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6455),
  [19375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11411),
  [19377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16098),
  [19379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13175),
  [19381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15528),
  [19383] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(10013),
  [19386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7537),
  [19388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1211),
  [19390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7478),
  [19392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5970),
  [19394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10779),
  [19396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9254),
  [19398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1169),
  [19400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7739),
  [19402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13180),
  [19404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11821),
  [19406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13182),
  [19408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8818),
  [19410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7328),
  [19412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16085),
  [19414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7035),
  [19416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9714),
  [19418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14176),
  [19420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9930),
  [19422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12024),
  [19424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9291),
  [19426] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attribute_id_repeat1, 2, 0, 0), SHIFT_REPEAT(16659),
  [19429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8573),
  [19431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3668),
  [19433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8739),
  [19435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3821),
  [19437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9283),
  [19439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10994),
  [19441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8801),
  [19443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6813),
  [19445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15308),
  [19447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9027),
  [19449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9427),
  [19451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9274),
  [19453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4566),
  [19455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4566),
  [19457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14366),
  [19459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6668),
  [19461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15376),
  [19463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15684),
  [19465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10968),
  [19467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15591),
  [19469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5673),
  [19471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11883),
  [19473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3557),
  [19475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8659),
  [19477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7835),
  [19479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8752),
  [19481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3789),
  [19483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9262),
  [19485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9022),
  [19487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7305),
  [19489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11143),
  [19491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10938),
  [19493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15315),
  [19495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10871),
  [19497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7887),
  [19499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11150),
  [19501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7889),
  [19503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9454),
  [19505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3518),
  [19507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10948),
  [19509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15298),
  [19511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10181),
  [19513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15738),
  [19515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9131),
  [19517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10959),
  [19519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10971),
  [19521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9201),
  [19523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14223),
  [19525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10070),
  [19527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15693),
  [19529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10722),
  [19531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15223),
  [19533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3804),
  [19535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [19537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7926),
  [19539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9301),
  [19541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10697),
  [19543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15330),
  [19545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8598),
  [19547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5232),
  [19549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14326),
  [19551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7223),
  [19553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7293),
  [19555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8594),
  [19557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4097),
  [19559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8604),
  [19561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6323),
  [19563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6931),
  [19565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3784),
  [19567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8732),
  [19569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7105),
  [19571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15623),
  [19573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10752),
  [19575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16047),
  [19577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15119),
  [19579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4029),
  [19581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14308),
  [19583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12665),
  [19585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15091),
  [19587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10122),
  [19589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3982),
  [19591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12383),
  [19593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15299),
  [19595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10022),
  [19597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15700),
  [19599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9168),
  [19601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15386),
  [19603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6312),
  [19605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9514),
  [19607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6872),
  [19609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12691),
  [19611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15093),
  [19613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9067),
  [19615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14248),
  [19617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12572),
  [19619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14182),
  [19621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16380),
  [19623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12717),
  [19625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12727),
  [19627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11941),
  [19629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10104),
  [19631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8889),
  [19633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10075),
  [19635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5201),
  [19637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9045),
  [19639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13853),
  [19641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11748),
  [19643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9023),
  [19645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8608),
  [19647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9238),
  [19649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8763),
  [19651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6710),
  [19653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10761),
  [19655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10811),
  [19657] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_value_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(4566),
  [19660] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_value_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(4566),
  [19663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14280),
  [19665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14228),
  [19667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9306),
  [19669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9309),
  [19671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15196),
  [19673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8666),
  [19675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15838),
  [19677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8735),
  [19679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6284),
  [19681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11822),
  [19683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9365),
  [19685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16281),
  [19687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9142),
  [19689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12596),
  [19691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9553),
  [19693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15213),
  [19695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11111),
  [19697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6680),
  [19699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9503),
  [19701] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_instance_variable_specification_repeat1, 2, 0, 0),
  [19703] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_instance_variable_specification_repeat1, 2, 0, 0), SHIFT_REPEAT(15534),
  [19706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10760),
  [19708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9084),
  [19710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8828),
  [19712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7171),
  [19714] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2642),
  [19716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14400),
  [19718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10683),
  [19720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15327),
  [19722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6691),
  [19724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8624),
  [19726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7079),
  [19728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9495),
  [19730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5595),
  [19732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8803),
  [19734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4971),
  [19736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9489),
  [19738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15135),
  [19740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7977),
  [19742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9960),
  [19744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9820),
  [19746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15216),
  [19748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11819),
  [19750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7810),
  [19752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5452),
  [19754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6860),
  [19756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9565),
  [19758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11813),
  [19760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6231),
  [19762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14256),
  [19764] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_method_specification_repeat1, 2, 0, 0),
  [19766] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_method_specification_repeat1, 2, 0, 0), SHIFT_REPEAT(15596),
  [19769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9667),
  [19771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14211),
  [19773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12904),
  [19775] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__type_params_repeat1, 2, 0, 0),
  [19777] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__type_params_repeat1, 2, 0, 0), SHIFT_REPEAT(13542),
  [19780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6220),
  [19782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16054),
  [19784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10785),
  [19786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16039),
  [19788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9504),
  [19790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9090),
  [19792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9076),
  [19794] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_constructor_declaration_repeat1, 2, 0, 0),
  [19796] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_constructor_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(16509),
  [19799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11806),
  [19801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8621),
  [19803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5789),
  [19805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16501),
  [19807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15329),
  [19809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8767),
  [19811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7712),
  [19813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12538),
  [19815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15359),
  [19817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15952),
  [19819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5819),
  [19821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15877),
  [19823] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__abstract_type, 2, 0, 0),
  [19825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7195),
  [19827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9716),
  [19829] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_polymorphic_variant_type_repeat2, 2, 0, 0),
  [19831] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_polymorphic_variant_type_repeat2, 2, 0, 0), SHIFT_REPEAT(16855),
  [19834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15847),
  [19836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9108),
  [19838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15371),
  [19840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4918),
  [19842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14320),
  [19844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3363),
  [19846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5831),
  [19848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9471),
  [19850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15136),
  [19852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11110),
  [19854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15971),
  [19856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14184),
  [19858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8740),
  [19860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4295),
  [19862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10303),
  [19864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9242),
  [19866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15378),
  [19868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7696),
  [19870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10319),
  [19872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4943),
  [19874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10653),
  [19876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11798),
  [19878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16500),
  [19880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9314),
  [19882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10840),
  [19884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14267),
  [19886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9068),
  [19888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11027),
  [19890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15977),
  [19892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7683),
  [19894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9463),
  [19896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14379),
  [19898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10712),
  [19900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14318),
  [19902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9271),
  [19904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9969),
  [19906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11010),
  [19908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11197),
  [19910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10690),
  [19912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9436),
  [19914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14298),
  [19916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3376),
  [19918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8638),
  [19920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5103),
  [19922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8717),
  [19924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6192),
  [19926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10327),
  [19928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4432),
  [19930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15996),
  [19932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9151),
  [19934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10917),
  [19936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3606),
  [19938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9042),
  [19940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15521),
  [19942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3626),
  [19944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4218),
  [19946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7224),
  [19948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16476),
  [19950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7391),
  [19952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14315),
  [19954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8772),
  [19956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6744),
  [19958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5024),
  [19960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9209),
  [19962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9359),
  [19964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9206),
  [19966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4187),
  [19968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8729),
  [19970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3662),
  [19972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15773),
  [19974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16593),
  [19976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10234),
  [19978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20313),
  [19980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9430),
  [19982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16193),
  [19984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9299),
  [19986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15529),
  [19988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15151),
  [19990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14375),
  [19992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7418),
  [19994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5067),
  [19996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3733),
  [19998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9586),
  [20000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9280),
  [20002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15531),
  [20004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3736),
  [20006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6772),
  [20008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9217),
  [20010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9346),
  [20012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7561),
  [20014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15861),
  [20016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9370),
  [20018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9204),
  [20020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2644),
  [20022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5657),
  [20024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11850),
  [20026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10519),
  [20028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8761),
  [20030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3647),
  [20032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8710),
  [20034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6816),
  [20036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14340),
  [20038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6783),
  [20040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9672),
  [20042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10343),
  [20044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16006),
  [20046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10199),
  [20048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8655),
  [20050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5379),
  [20052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16214),
  [20054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5149),
  [20056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9388),
  [20058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8797),
  [20060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9293),
  [20062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14251),
  [20064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8687),
  [20066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3418),
  [20068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9292),
  [20070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15660),
  [20072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1111),
  [20074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7599),
  [20076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9363),
  [20078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15869),
  [20080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8786),
  [20082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5279),
  [20084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5326),
  [20086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10765),
  [20088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8700),
  [20090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9703),
  [20092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16203),
  [20094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9041),
  [20096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12858),
  [20098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15687),
  [20100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14202),
  [20102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15354),
  [20104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5727),
  [20106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8781),
  [20108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4849),
  [20110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5351),
  [20112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5574),
  [20114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12020),
  [20116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5750),
  [20118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12865),
  [20120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15695),
  [20122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14370),
  [20124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10843),
  [20126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4155),
  [20128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14365),
  [20130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8916),
  [20132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11788),
  [20134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9864),
  [20136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5520),
  [20138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14353),
  [20140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16280),
  [20142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6709),
  [20144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8816),
  [20146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5739),
  [20148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8558),
  [20150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4442),
  [20152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9126),
  [20154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16462),
  [20156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12895),
  [20158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15599),
  [20160] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__abstract_type_repeat1, 2, 0, 0), SHIFT_REPEAT(15877),
  [20163] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__abstract_type_repeat1, 2, 0, 0),
  [20165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4884),
  [20167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12902),
  [20169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9281),
  [20171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9139),
  [20173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16004),
  [20175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12480),
  [20177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14392),
  [20179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10209),
  [20181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3001),
  [20183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6187),
  [20185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13703),
  [20187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16256),
  [20189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8821),
  [20191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14250),
  [20193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4857),
  [20195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9150),
  [20197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3009),
  [20199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9334),
  [20201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9340),
  [20203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8662),
  [20205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5862),
  [20207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6775),
  [20209] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tag_specification, 1, 0, 0),
  [20211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8494),
  [20213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14217),
  [20215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9107),
  [20217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14227),
  [20219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8855),
  [20221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3042),
  [20223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6233),
  [20225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9746),
  [20227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5499),
  [20229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11795),
  [20231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13940),
  [20233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16033),
  [20235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8858),
  [20237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7427),
  [20239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15901),
  [20241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16254),
  [20243] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_polymorphic_variant_type_repeat1, 2, 0, 0), SHIFT_REPEAT(8214),
  [20246] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_polymorphic_variant_type_repeat1, 2, 0, 0),
  [20248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14330),
  [20250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5898),
  [20252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14362),
  [20254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4239),
  [20256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13830),
  [20258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16259),
  [20260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6079),
  [20262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7404),
  [20264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16654),
  [20266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14322),
  [20268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9061),
  [20270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6057),
  [20272] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_instantiated_class_type_repeat1, 2, 0, 0), SHIFT_REPEAT(8650),
  [20275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5914),
  [20277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1341),
  [20279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10151),
  [20281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8863),
  [20283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7064),
  [20285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8854),
  [20287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5864),
  [20289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8788),
  [20291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3165),
  [20293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16377),
  [20295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8856),
  [20297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8684),
  [20299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6295),
  [20301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13506),
  [20303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9154),
  [20305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15751),
  [20307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14284),
  [20309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9537),
  [20311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16382),
  [20313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9143),
  [20315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13755),
  [20317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8584),
  [20319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16287),
  [20321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14218),
  [20323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6436),
  [20325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8646),
  [20327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7272),
  [20329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15883),
  [20331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9759),
  [20333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16275),
  [20335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9121),
  [20337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6468),
  [20339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8675),
  [20341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6497),
  [20343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5526),
  [20345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11844),
  [20347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3147),
  [20349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14274),
  [20351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13799),
  [20353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4284),
  [20355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14367),
  [20357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9118),
  [20359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8822),
  [20361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6661),
  [20363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16656),
  [20365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14212),
  [20367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6463),
  [20369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14260),
  [20371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8648),
  [20373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4088),
  [20375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10253),
  [20377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3118),
  [20379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16638),
  [20381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1515),
  [20383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8649),
  [20385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14789),
  [20387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6130),
  [20389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15533),
  [20391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12034),
  [20393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3112),
  [20395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14700),
  [20397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6999),
  [20399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13848),
  [20401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13542),
  [20403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19254),
  [20405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4772),
  [20407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3241),
  [20409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13859),
  [20411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17024),
  [20413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17166),
  [20415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17164),
  [20417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17163),
  [20419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17259),
  [20421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6402),
  [20423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14886),
  [20425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5440),
  [20427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [20429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(571),
  [20431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(572),
  [20433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13865),
  [20435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13675),
  [20437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13929),
  [20439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14485),
  [20441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17127),
  [20443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13543),
  [20445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5709),
  [20447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8471),
  [20449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13215),
  [20451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17276),
  [20453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17277),
  [20455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17278),
  [20457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13524),
  [20459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5559),
  [20461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14404),
  [20463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1506),
  [20465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15014),
  [20467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1590),
  [20469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14259),
  [20471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13856),
  [20473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17381),
  [20475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17380),
  [20477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17379),
  [20479] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_record_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(14263),
  [20482] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_record_pattern_repeat1, 2, 0, 0),
  [20484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13903),
  [20486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6591),
  [20488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14066),
  [20490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4099),
  [20492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13849),
  [20494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3142),
  [20496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1589),
  [20498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17455),
  [20500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13629),
  [20502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13957),
  [20504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3996),
  [20506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15056),
  [20508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6502),
  [20510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17152),
  [20512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17151),
  [20514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17150),
  [20516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(868),
  [20518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(829),
  [20520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(824),
  [20522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4447),
  [20524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(650),
  [20526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(651),
  [20528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(653),
  [20530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15072),
  [20532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6481),
  [20534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9542),
  [20536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15077),
  [20538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13992),
  [20540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7051),
  [20542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1761),
  [20544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1692),
  [20546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13931),
  [20548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16958),
  [20550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16959),
  [20552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16960),
  [20554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13835),
  [20556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6489),
  [20558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13881),
  [20560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1764),
  [20562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1348),
  [20564] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1349),
  [20566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1351),
  [20568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9102),
  [20570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15049),
  [20572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14369),
  [20574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13510),
  [20576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7809),
  [20578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1746),
  [20580] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(3684),
  [20583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10549),
  [20585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6356),
  [20587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13956),
  [20589] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_binding_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(4628),
  [20592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13862),
  [20594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14206),
  [20596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9769),
  [20598] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_record_binding_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(14297),
  [20601] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_record_binding_pattern_repeat1, 2, 0, 0),
  [20603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4245),
  [20605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1745),
  [20607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2925),
  [20609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14368),
  [20611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14944),
  [20613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4112),
  [20615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6635),
  [20617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14163),
  [20619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13963),
  [20621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1412),
  [20623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(657),
  [20625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(658),
  [20627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(659),
  [20629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17035),
  [20631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7729),
  [20633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1347),
  [20635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13502),
  [20637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7508),
  [20639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1687),
  [20641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8616),
  [20643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15013),
  [20645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7419),
  [20647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8630),
  [20649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15060),
  [20651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3160),
  [20653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9561),
  [20655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4555),
  [20657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13820),
  [20659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1313),
  [20661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1318),
  [20663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1319),
  [20665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14810),
  [20667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13924),
  [20669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17028),
  [20671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4594),
  [20673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4475),
  [20675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13872),
  [20677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3163),
  [20679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3239),
  [20681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13777),
  [20683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13972),
  [20685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5922),
  [20687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13915),
  [20689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6283),
  [20691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17365),
  [20693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17364),
  [20695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17363),
  [20697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13999),
  [20699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5874),
  [20701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(939),
  [20703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(940),
  [20705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(948),
  [20707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5543),
  [20709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14993),
  [20711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6259),
  [20713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8390),
  [20715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7973),
  [20717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13513),
  [20719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15019),
  [20721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5885),
  [20723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12476),
  [20725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5163),
  [20727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17175),
  [20729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17019),
  [20731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8458),
  [20733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17474),
  [20735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1378),
  [20737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1379),
  [20739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1381),
  [20741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17136),
  [20743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17135),
  [20745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17134),
  [20747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17428),
  [20749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1732),
  [20751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16652),
  [20753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1772),
  [20755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13980),
  [20757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14006),
  [20759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13964),
  [20761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(726),
  [20763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(745),
  [20765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(746),
  [20767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1749),
  [20769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20303),
  [20771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17070),
  [20773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17068),
  [20775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17066),
  [20777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15012),
  [20779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13729),
  [20781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13949),
  [20783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7423),
  [20785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6456),
  [20787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16999),
  [20789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5904),
  [20791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6072),
  [20793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15069),
  [20795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16653),
  [20797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14013),
  [20799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17402),
  [20801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17401),
  [20803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17400),
  [20805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1706),
  [20807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(622),
  [20809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(620),
  [20811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(596),
  [20813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15063),
  [20815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13196),
  [20817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20304),
  [20819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6016),
  [20821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19278),
  [20823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1597),
  [20825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6112),
  [20827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13961),
  [20829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14824),
  [20831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13717),
  [20833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1620),
  [20835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6805),
  [20837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15021),
  [20839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13906),
  [20841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17178),
  [20843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17177),
  [20845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17176),
  [20847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5628),
  [20849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17014),
  [20851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17125),
  [20853] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17124),
  [20855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17123),
  [20857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13938),
  [20859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14544),
  [20861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14358),
  [20863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1575),
  [20865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1598),
  [20867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(874),
  [20869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(887),
  [20871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(892),
  [20873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1616),
  [20875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13831),
  [20877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17009),
  [20879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4826),
  [20881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1574),
  [20883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14975),
  [20885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14067),
  [20887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3038),
  [20889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13745),
  [20891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5566),
  [20893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13921),
  [20895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17003),
  [20897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7401),
  [20899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15007),
  [20901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5873),
  [20903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14982),
  [20905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3034),
  [20907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13739),
  [20909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12928),
  [20911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10340),
  [20913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3141),
  [20915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14749),
  [20917] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9817),
  [20920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20221),
  [20922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4847),
  [20924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1737),
  [20926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14037),
  [20928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5868),
  [20930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14081),
  [20932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13979),
  [20934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7264),
  [20936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17116),
  [20938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17115),
  [20940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17114),
  [20942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1736),
  [20944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6960),
  [20946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14270),
  [20948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13884),
  [20950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14974),
  [20952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12489),
  [20954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14004),
  [20956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6219),
  [20958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13953),
  [20960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3005),
  [20962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9194),
  [20964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14121),
  [20966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3139),
  [20968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13311),
  [20970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17043),
  [20972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14177),
  [20974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5756),
  [20976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13839),
  [20978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13700),
  [20980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2991),
  [20982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14134),
  [20984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6752),
  [20986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13928),
  [20988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15010),
  [20990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4371),
  [20992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1733),
  [20994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4875),
  [20996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4584),
  [20998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5622),
  [21000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6129),
  [21002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16992),
  [21004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1481),
  [21006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17105),
  [21008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17103),
  [21010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17102),
  [21012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7431),
  [21014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16776),
  [21016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14980),
  [21018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17349),
  [21020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17348),
  [21022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17347),
  [21024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1059),
  [21026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1070),
  [21028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1088),
  [21030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14016),
  [21032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4210),
  [21034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1730),
  [21036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17048),
  [21038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16991),
  [21040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8792),
  [21042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(730),
  [21044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(729),
  [21046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(727),
  [21048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14986),
  [21050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6171),
  [21052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13944),
  [21054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13962),
  [21056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14168),
  [21058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5741),
  [21060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17408),
  [21062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1729),
  [21064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14822),
  [21066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7250),
  [21068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17191),
  [21070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17190),
  [21072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17189),
  [21074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10081),
  [21076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16556),
  [21078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14936),
  [21080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5748),
  [21082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17093),
  [21084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17092),
  [21086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17088),
  [21088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1400),
  [21090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1401),
  [21092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1408),
  [21094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16989),
  [21096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14839),
  [21098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14151),
  [21100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1334),
  [21102] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1340),
  [21104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1350),
  [21106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12871),
  [21108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1708),
  [21110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13511),
  [21112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14123),
  [21114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8926),
  [21116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13734),
  [21118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14963),
  [21120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4838),
  [21122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1639),
  [21124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1615),
  [21126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14928),
  [21128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17069),
  [21130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12931),
  [21132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12860),
  [21134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5368),
  [21136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4574),
  [21138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4936),
  [21140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5735),
  [21142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17063),
  [21144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17062),
  [21146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17061),
  [21148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14105),
  [21150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1270),
  [21152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1271),
  [21154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1272),
  [21156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13509),
  [21158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16573),
  [21160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8984),
  [21162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19295),
  [21164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13952),
  [21166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4794),
  [21168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14164),
  [21170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9285),
  [21172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17052),
  [21174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2942),
  [21176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16987),
  [21178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5706),
  [21180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17491),
  [21182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14091),
  [21184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14070),
  [21186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17337),
  [21188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12888),
  [21190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5312),
  [21192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16968),
  [21194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17083),
  [21196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17082),
  [21198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17080),
  [21200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16490),
  [21202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14122),
  [21204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16985),
  [21206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7398),
  [21208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9386),
  [21210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14931),
  [21212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14021),
  [21214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9696),
  [21216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1518),
  [21218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1424),
  [21220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1460),
  [21222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1462),
  [21224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6778),
  [21226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2247),
  [21228] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_expression, 2, 0, 23),
  [21230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13151),
  [21232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8753),
  [21234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14058),
  [21236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14883),
  [21238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9673),
  [21240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17057),
  [21242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13946),
  [21244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5263),
  [21246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1563),
  [21248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17424),
  [21250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17423),
  [21252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17421),
  [21254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14112),
  [21256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16982),
  [21258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14403),
  [21260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5220),
  [21262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13996),
  [21264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8635),
  [21266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14361),
  [21268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1562),
  [21270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9331),
  [21272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1695),
  [21274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13917),
  [21276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14918),
  [21278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5366),
  [21280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1693),
  [21282] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indexing_operator_path, 3, 0, 0),
  [21284] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indexing_operator_path, 3, 0, 0),
  [21286] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_instance_variable_specification_repeat1, 1, 0, 0),
  [21288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16981),
  [21290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14896),
  [21292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16592),
  [21294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10351),
  [21296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5167),
  [21298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13482),
  [21300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13898),
  [21302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14039),
  [21304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5377),
  [21306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1609),
  [21308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14044),
  [21310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1610),
  [21312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16980),
  [21314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5516),
  [21316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16978),
  [21318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5191),
  [21320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8688),
  [21322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13897),
  [21324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16977),
  [21326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14952),
  [21328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6803),
  [21330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13616),
  [21332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8014),
  [21334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14086),
  [21336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3407),
  [21338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1234),
  [21340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1236),
  [21342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1238),
  [21344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16974),
  [21346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17451),
  [21348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17450),
  [21350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17449),
  [21352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17389),
  [21354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14022),
  [21356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10138),
  [21358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6791),
  [21360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14100),
  [21362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6810),
  [21364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16971),
  [21366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14888),
  [21368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16598),
  [21370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16589),
  [21372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16590),
  [21374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7693),
  [21376] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_record_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(16096),
  [21379] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_record_declaration_repeat1, 2, 0, 0),
  [21381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14858),
  [21383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13627),
  [21385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5647),
  [21387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14299),
  [21389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7376),
  [21391] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_method_specification_repeat1, 1, 0, 0),
  [21393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16969),
  [21395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13842),
  [21397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3650),
  [21399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9381),
  [21401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14178),
  [21403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14029),
  [21405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14429),
  [21407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14862),
  [21409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3663),
  [21411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8537),
  [21413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16963),
  [21415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16967),
  [21417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9324),
  [21419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9350),
  [21421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9526),
  [21423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14059),
  [21425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1661),
  [21427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17141),
  [21429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13888),
  [21431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14161),
  [21433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1660),
  [21435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14798),
  [21437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3401),
  [21439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14881),
  [21441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14857),
  [21443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14269),
  [21445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9382),
  [21447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13838),
  [21449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9232),
  [21451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13990),
  [21453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3741),
  [21455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1623),
  [21457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13914),
  [21459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17064),
  [21461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9315),
  [21463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16965),
  [21465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1722),
  [21467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5000),
  [21469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5040),
  [21471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1584),
  [21473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2248),
  [21475] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_expression, 1, 0, 0),
  [21477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3716),
  [21479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1184),
  [21481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1185),
  [21483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1186),
  [21485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13951),
  [21487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16962),
  [21489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5671),
  [21491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14819),
  [21493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4248),
  [21495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17468),
  [21497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17467),
  [21499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17464),
  [21501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6083),
  [21503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14038),
  [21505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9572),
  [21507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1143),
  [21509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1147),
  [21511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1148),
  [21513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13886),
  [21515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1721),
  [21517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8899),
  [21519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9330),
  [21521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14068),
  [21523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14258),
  [21525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17119),
  [21527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9282),
  [21529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14036),
  [21531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13981),
  [21533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9361),
  [21535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5105),
  [21537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1583),
  [21539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14060),
  [21541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3656),
  [21543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8746),
  [21545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14864),
  [21547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6751),
  [21549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4179),
  [21551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14856),
  [21553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17071),
  [21555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14818),
  [21557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3645),
  [21559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14054),
  [21561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6746),
  [21563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17486),
  [21565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17485),
  [21567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17482),
  [21569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1549),
  [21571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1535),
  [21573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1633),
  [21575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17334),
  [21577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17333),
  [21579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17331),
  [21581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14118),
  [21583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14738),
  [21585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13970),
  [21587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1437),
  [21589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1438),
  [21591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1439),
  [21593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1632),
  [21595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14814),
  [21597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14803),
  [21599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7915),
  [21601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1548),
  [21603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17371),
  [21605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3610),
  [21607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14833),
  [21609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5136),
  [21611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14135),
  [21613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4167),
  [21615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17513),
  [21617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16935),
  [21619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1113),
  [21621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1114),
  [21623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1115),
  [21625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10330),
  [21627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14114),
  [21629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3970),
  [21631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14061),
  [21633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5127),
  [21635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3085),
  [21637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5824),
  [21639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3599),
  [21641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14138),
  [21643] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indexing_operator_path, 1, 0, 0),
  [21645] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indexing_operator_path, 1, 0, 0),
  [21647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8873),
  [21649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1541),
  [21651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3280),
  [21653] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_copy_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(15707),
  [21656] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_copy_expression_repeat1, 2, 0, 0),
  [21658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13812),
  [21660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13988),
  [21662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4365),
  [21664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3277),
  [21666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8065),
  [21668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14753),
  [21670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4591),
  [21672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16955),
  [21674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13805),
  [21676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10325),
  [21678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1082),
  [21680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1083),
  [21682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1084),
  [21684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16953),
  [21686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14099),
  [21688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16951),
  [21690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16950),
  [21692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16997),
  [21694] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16995),
  [21696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16994),
  [21698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16947),
  [21700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14127),
  [21702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6194),
  [21704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14146),
  [21706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7675),
  [21708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14053),
  [21710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11022),
  [21712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7165),
  [21714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6868),
  [21716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7851),
  [21718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17415),
  [21720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4769),
  [21722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3094),
  [21724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17002),
  [21726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17001),
  [21728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17000),
  [21730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11058),
  [21732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4966),
  [21734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7512),
  [21736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3371),
  [21738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17350),
  [21740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(580),
  [21742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(581),
  [21744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(582),
  [21746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7465),
  [21748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11794),
  [21750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17008),
  [21752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17007),
  [21754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17006),
  [21756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14101),
  [21758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7691),
  [21760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14715),
  [21762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6199),
  [21764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14080),
  [21766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7206),
  [21768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9466),
  [21770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9049),
  [21772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9109),
  [21774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14782),
  [21776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9326),
  [21778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14017),
  [21780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9321),
  [21782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17318),
  [21784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17317),
  [21786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17316),
  [21788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5835),
  [21790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14136),
  [21792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9177),
  [21794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1700),
  [21796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1468),
  [21798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1470),
  [21800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1475),
  [21802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11207),
  [21804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14107),
  [21806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4910),
  [21808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14290),
  [21810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7484),
  [21812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17012),
  [21814] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17011),
  [21816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17010),
  [21818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9230),
  [21820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14050),
  [21822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1699),
  [21824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9279),
  [21826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14768),
  [21828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1626),
  [21830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14148),
  [21832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3092),
  [21834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8669),
  [21836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(830),
  [21838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13885),
  [21840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9175),
  [21842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8528),
  [21844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17072),
  [21846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1532),
  [21848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6972),
  [21850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17089),
  [21852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17090),
  [21854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17091),
  [21856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(825),
  [21858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1449),
  [21860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14855),
  [21862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14018),
  [21864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8454),
  [21866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14765),
  [21868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7707),
  [21870] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__abstract_type_repeat1, 1, 0, 4),
  [21872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14754),
  [21874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17086),
  [21876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8093),
  [21878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14109),
  [21880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14395),
  [21882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1536),
  [21884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17338),
  [21886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(814),
  [21888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13985),
  [21890] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(16490),
  [21893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19777),
  [21895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3357),
  [21897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17056),
  [21899] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17055),
  [21901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17053),
  [21903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14119),
  [21905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7710),
  [21907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1534),
  [21909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17528),
  [21911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17527),
  [21913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17526),
  [21915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1533),
  [21917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6444),
  [21919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14736),
  [21921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5796),
  [21923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8051),
  [21925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1118),
  [21927] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1117),
  [21929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1116),
  [21931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13932),
  [21933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5792),
  [21935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11792),
  [21937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17505),
  [21939] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17504),
  [21941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17503),
  [21943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1627),
  [21945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10791),
  [21947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19800),
  [21949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17321),
  [21951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8623),
  [21953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17157),
  [21955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17302),
  [21957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17301),
  [21959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17300),
  [21961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8890),
  [21963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11808),
  [21965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14154),
  [21967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1611),
  [21969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6226),
  [21971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14159),
  [21973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10758),
  [21975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14200),
  [21977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14748),
  [21979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4953),
  [21981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10159),
  [21983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7166),
  [21985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17051),
  [21987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17050),
  [21989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17049),
  [21991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19821),
  [21993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16770),
  [21995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7832),
  [21997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16939),
  [21999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5188),
  [22001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13874),
  [22003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9560),
  [22005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9659),
  [22007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14704),
  [22009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9486),
  [22011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16546),
  [22013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16545),
  [22015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16544),
  [22017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14106),
  [22019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14166),
  [22021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13958),
  [22023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4963),
  [22025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14155),
  [22027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6699),
  [22029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14844),
  [22031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10255),
  [22033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9531),
  [22035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4593),
  [22037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9070),
  [22039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13896),
  [22041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17018),
  [22043] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17017),
  [22045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17016),
  [22047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1061),
  [22049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1062),
  [22051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1065),
  [22053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3548),
  [22055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16798),
  [22057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16799),
  [22059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16800),
  [22061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9491),
  [22063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3960),
  [22065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1497),
  [22067] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1498),
  [22069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1499),
  [22071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17532),
  [22073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10681),
  [22075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14160),
  [22077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6686),
  [22079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10688),
  [22081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14079),
  [22083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7174),
  [22085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13882),
  [22087] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_record_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(14181),
  [22090] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_record_expression_repeat1, 2, 0, 0),
  [22092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9198),
  [22094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14063),
  [22096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14682),
  [22098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7571),
  [22100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16566),
  [22102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1685),
  [22104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9332),
  [22106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9555),
  [22108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9105),
  [22110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17305),
  [22112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14568),
  [22114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7178),
  [22116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14600),
  [22118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14071),
  [22120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7062),
  [22122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14673),
  [22124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14167),
  [22126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1016),
  [22128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1017),
  [22130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1020),
  [22132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17547),
  [22134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17544),
  [22136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17543),
  [22138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17022),
  [22140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17021),
  [22142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17020),
  [22144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1684),
  [22146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20410),
  [22148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1514),
  [22150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13905),
  [22152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12969),
  [22154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14089),
  [22156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6286),
  [22158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7730),
  [22160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14665),
  [22162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6677),
  [22164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1513),
  [22166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(660),
  [22168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14075),
  [22170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(640),
  [22172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(625),
  [22174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(612),
  [22176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9368),
  [22178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14653),
  [22180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9226),
  [22182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13659),
  [22184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7727),
  [22186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14025),
  [22188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(644),
  [22190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17286),
  [22192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17285),
  [22194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17283),
  [22196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13889),
  [22198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9231),
  [22200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14752),
  [22202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14197),
  [22204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8535),
  [22206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13646),
  [22208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8910),
  [22210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14126),
  [22212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6689),
  [22214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14574),
  [22216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7053),
  [22218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9413),
  [22220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17027),
  [22222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17026),
  [22224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17025),
  [22226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17292),
  [22228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14172),
  [22230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17492),
  [22232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(633),
  [22234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14598),
  [22236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6291),
  [22238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17034),
  [22240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17032),
  [22242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17030),
  [22244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5015),
  [22246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1446),
  [22248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1444),
  [22250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1427),
  [22252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19910),
  [22254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7842),
  [22256] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(10007),
  [22259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16564),
  [22261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1634),
  [22263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1330),
  [22265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1331),
  [22267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1332),
  [22269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14052),
  [22271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8664),
  [22273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10318),
  [22275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9259),
  [22277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1635),
  [22279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1748),
  [22281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14023),
  [22283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(894),
  [22285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(893),
  [22287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(890),
  [22289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12707),
  [22291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14015),
  [22293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19930),
  [22295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14132),
  [22297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10050),
  [22299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8668),
  [22301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6570),
  [22303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17210),
  [22305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17209),
  [22307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17208),
  [22309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9249),
  [22311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12680),
  [22313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4116),
  [22315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14573),
  [22317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3990),
  [22319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16563),
  [22321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3032),
  [22323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17273),
  [22325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14008),
  [22327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17168),
  [22329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16543),
  [22331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9965),
  [22333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14041),
  [22335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9092),
  [22337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7283),
  [22339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14072),
  [22341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5583),
  [22343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6239),
  [22345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16558),
  [22347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20088),
  [22349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12651),
  [22351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(973),
  [22353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(985),
  [22355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(986),
  [22357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17241),
  [22359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14591),
  [22361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3754),
  [22363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1540),
  [22365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14056),
  [22367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14014),
  [22369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5853),
  [22371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1542),
  [22373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14144),
  [22375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14584),
  [22377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4080),
  [22379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17042),
  [22381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17041),
  [22383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17039),
  [22385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14125),
  [22387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17566),
  [22389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17569),
  [22391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17571),
  [22393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1646),
  [22395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1741),
  [22397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14158),
  [22399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14073),
  [22401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4087),
  [22403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6338),
  [22405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17258),
  [22407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7429),
  [22409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16594),
  [22411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17354),
  [22413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17355),
  [22415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17356),
  [22417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9096),
  [22419] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(2149),
  [22422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14057),
  [22424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14507),
  [22426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8607),
  [22428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3937),
  [22430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10753),
  [22432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19953),
  [22434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16588),
  [22436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14515),
  [22438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14546),
  [22440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20063),
  [22442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(991),
  [22444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(977),
  [22446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(951),
  [22448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7307),
  [22450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14272),
  [22452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5496),
  [22454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14579),
  [22456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17223),
  [22458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17222),
  [22460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17221),
  [22462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3053),
  [22464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13586),
  [22466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14042),
  [22468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14095),
  [22470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7099),
  [22472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9153),
  [22474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3059),
  [22476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13844),
  [22478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5247),
  [22480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10089),
  [22482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4615),
  [22484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7299),
  [22486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1677),
  [22488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5580),
  [22490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10695),
  [22492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5215),
  [22494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1648),
  [22496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8673),
  [22498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6913),
  [22500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13518),
  [22502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10185),
  [22504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4604),
  [22506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14043),
  [22508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6039),
  [22510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1676),
  [22512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8464),
  [22514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17553),
  [22516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14325),
  [22518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20041),
  [22520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14489),
  [22522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7092),
  [22524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14120),
  [22526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10952),
  [22528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1048),
  [22530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6331),
  [22532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16615),
  [22534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10942),
  [22536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3502),
  [22538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5866),
  [22540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9124),
  [22542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14383),
  [22544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10168),
  [22546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14293),
  [22548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13910),
  [22550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14130),
  [22552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17100),
  [22554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9055),
  [22556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7253),
  [22558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14562),
  [22560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3759),
  [22562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14691),
  [22564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15009),
  [22566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1653),
  [22568] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(3699),
  [22571] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_binding_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(4664),
  [22574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1023),
  [22576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6834),
  [22578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14428),
  [22580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5297),
  [22582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14569),
  [22584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10932),
  [22586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3538),
  [22588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12376),
  [22590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14033),
  [22592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3769),
  [22594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(916),
  [22596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14540),
  [22598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13557),
  [22600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8815),
  [22602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1550),
  [22604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10878),
  [22606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20257),
  [22608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14098),
  [22610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1601),
  [22612] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(2048),
  [22615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14156),
  [22617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9064),
  [22619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1652),
  [22621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17582),
  [22623] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17583),
  [22625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17584),
  [22627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1552),
  [22629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13936),
  [22631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1602),
  [22633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1569),
  [22635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1087),
  [22637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1085),
  [22639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1077),
  [22641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6318),
  [22643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17225),
  [22645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14522),
  [22647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3652),
  [22649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17047),
  [22651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17046),
  [22653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17045),
  [22655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6634),
  [22657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4452),
  [22659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16551),
  [22661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14140),
  [22663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3658),
  [22665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17238),
  [22667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17237),
  [22669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17236),
  [22671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4606),
  [22673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20255),
  [22675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13626),
  [22677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14238),
  [22679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(856),
  [22681] = {.entry = {.count = 1, .reusable = false}}, SHIFT(857),
  [22683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(858),
  [22685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4620),
  [22687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13959),
  [22689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14527),
  [22691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7321),
  [22693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5513),
  [22695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17509),
  [22697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17510),
  [22699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17511),
  [22701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(912),
  [22703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(914),
  [22705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(917),
  [22707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7519),
  [22709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7279),
  [22711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1568),
  [22713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13923),
  [22715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3808),
  [22717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10912),
  [22719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14169),
  [22721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14000),
  [22723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7325),
  [22725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13613),
  [22727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14464),
  [22729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3782),
  [22731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13950),
  [22733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7994),
  [22735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3302),
  [22737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13611),
  [22739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17565),
  [22741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4571),
  [22743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1649),
  [22745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14444),
  [22747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13893),
  [22749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3817),
  [22751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13937),
  [22753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3301),
  [22755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6829),
  [22757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5964),
  [22759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17271),
  [22761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17270),
  [22763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17269),
  [22765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1226),
  [22767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17213),
  [22769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3642),
  [22771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14009),
  [22773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13177),
  [22775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7744),
  [22777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3310),
  [22779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13539),
  [22781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10243),
  [22783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13108),
  [22785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17193),
  [22787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17194),
  [22789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17195),
  [22791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7602),
  [22793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3271),
  [22795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10100),
  [22797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13531),
  [22799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3258),
  [22801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13172),
  [22803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6466),
  [22805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1218),
  [22807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1217),
  [22809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1215),
  [22811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1314),
  [22813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1312),
  [22815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1309),
  [22817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6558),
  [22819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7018),
  [22821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13916),
  [22823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3298),
  [22825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5975),
  [22827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13991),
  [22829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10825),
  [22831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14442),
  [22833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4586),
  [22835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9024),
  [22837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9065),
  [22839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13554),
  [22841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13260),
  [22843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13880),
  [22845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14474),
  [22847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3947),
  [22849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4608),
  [22851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13875),
  [22853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1668),
  [22855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13168),
  [22857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6440),
  [22859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14534),
  [22861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7940),
  [22863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16507),
  [22865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13902),
  [22867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4642),
  [22869] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_binding_pattern, 2, 0, 0),
  [22871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1667),
  [22873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14466),
  [22875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13772),
  [22877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4599),
  [22879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7601),
  [22881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5977),
  [22883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1659),
  [22885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7592),
  [22887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1650),
  [22889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10885),
  [22891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14453),
  [22893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13965),
  [22895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3749),
  [22897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13867),
  [22899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10146),
  [22901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14451),
  [22903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1662),
  [22905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3312),
  [22907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17197),
  [22909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13869),
  [22911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6995),
  [22913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10798),
  [22915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(802),
  [22917] = {.entry = {.count = 1, .reusable = false}}, SHIFT(803),
  [22919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(804),
  [22921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13860),
  [22923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13983),
  [22925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(721),
  [22927] = {.entry = {.count = 1, .reusable = false}}, SHIFT(722),
  [22929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(725),
  [22931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14457),
  [22933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6000),
  [22935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14440),
  [22937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6407),
  [22939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11146),
  [22941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14196),
  [22943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14618),
  [22945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13612),
  [22947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1742),
  [22949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17109),
  [22951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17432),
  [22953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17433),
  [22955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17434),
  [22957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13933),
  [22959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6170),
  [22961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13877),
  [22963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10790),
  [22965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16617),
  [22967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16618),
  [22969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16619),
  [22971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13890),
  [22973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6007),
  [22975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13815),
  [22977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1743),
  [22979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3505),
  [22981] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_pattern, 2, 0, 0),
  [22983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3288),
  [22985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17180),
  [22987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1202),
  [22989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1200),
  [22991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1189),
  [22993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14450),
  [22995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14449),
  [22997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17252),
  [22999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17251),
  [23001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17248),
  [23003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14077),
  [23005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19613),
  [23007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8898),
  [23009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7853),
  [23011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11854),
  [23013] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_params, 1, 0, 0),
  [23015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16538),
  [23017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12075),
  [23019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1776),
  [23021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10828),
  [23023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2122),
  [23025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10977),
  [23027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2284),
  [23029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11832),
  [23031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16547),
  [23033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2577),
  [23035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13771),
  [23037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7972),
  [23039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4903),
  [23041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10800),
  [23043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11159),
  [23045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9804),
  [23047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4383),
  [23049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10976),
  [23051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11005),
  [23053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11464),
  [23055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16703),
  [23057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8685),
  [23059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15103),
  [23061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19286),
  [23063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16682),
  [23065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19285),
  [23067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19284),
  [23069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9496),
  [23071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9007),
  [23073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20388),
  [23075] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13714),
  [23077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16680),
  [23079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13472),
  [23081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13474),
  [23083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11059),
  [23085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2203),
  [23087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(504),
  [23089] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_params, 3, 0, 0),
  [23091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4560),
  [23093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20322),
  [23095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2272),
  [23097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12883),
  [23099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7844),
  [23101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1842),
  [23103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7892),
  [23105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13449),
  [23107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8654),
  [23109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4225),
  [23111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16664),
  [23113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16603),
  [23115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16662),
  [23117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4263),
  [23119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16611),
  [23121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20266),
  [23123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20265),
  [23125] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_params, 4, 0, 0),
  [23127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10723),
  [23129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8880),
  [23131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13455),
  [23133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15189),
  [23135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20267),
  [23137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8614),
  [23139] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_guard, 2, 0, 0),
  [23141] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_type, 2, 0, 65),
  [23143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12392),
  [23145] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typed_label, 3, 0, 66),
  [23147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16721),
  [23149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1307),
  [23151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9357),
  [23153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20229),
  [23155] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 2, 0, 22),
  [23157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10883),
  [23159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8795),
  [23161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16723),
  [23163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19378),
  [23165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19379),
  [23167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19380),
  [23169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1376),
  [23171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7825),
  [23173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7843),
  [23175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20209),
  [23177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20204),
  [23179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2566),
  [23181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13763),
  [23183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16029),
  [23185] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typed_label, 4, 0, 45),
  [23187] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_polymorphic_variant_type_repeat2, 1, 0, 0),
  [23189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8689),
  [23191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7907),
  [23193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1469),
  [23195] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 3, 0, 92),
  [23197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7921),
  [23199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20184),
  [23201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7807),
  [23203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20183),
  [23205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5430),
  [23207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9492),
  [23209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20178),
  [23211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1209),
  [23213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7745),
  [23215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1883),
  [23217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13327),
  [23219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1390),
  [23221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10116),
  [23223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14360),
  [23225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2539),
  [23227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13794),
  [23229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16359),
  [23231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9570),
  [23233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4356),
  [23235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7819),
  [23237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9035),
  [23239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13598),
  [23241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13399),
  [23243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13467),
  [23245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(543),
  [23247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4617),
  [23249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19264),
  [23251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7934),
  [23253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8750),
  [23255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4246),
  [23257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16823),
  [23259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4250),
  [23261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10890),
  [23263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13226),
  [23265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8559),
  [23267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3410),
  [23269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9757),
  [23271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3382),
  [23273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20059),
  [23275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4320),
  [23277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20024),
  [23279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3380),
  [23281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20056),
  [23283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10724),
  [23285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1382),
  [23287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10254),
  [23289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8003),
  [23291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20015),
  [23293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8020),
  [23295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20003),
  [23297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13016),
  [23299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20002),
  [23301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5500),
  [23303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3390),
  [23305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4267),
  [23307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20000),
  [23309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3353),
  [23311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20010),
  [23313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3351),
  [23315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20009),
  [23317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2333),
  [23319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1195),
  [23321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7688),
  [23323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20013),
  [23325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10170),
  [23327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11707),
  [23329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7761),
  [23331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5521),
  [23333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13473),
  [23335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5238),
  [23337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5218),
  [23339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19972),
  [23341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(537),
  [23343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5212),
  [23345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19970),
  [23347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5507),
  [23349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19361),
  [23351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2545),
  [23353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13519),
  [23355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7971),
  [23357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8583),
  [23359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5257),
  [23361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5625),
  [23363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6390),
  [23365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5643),
  [23367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19940),
  [23369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10748),
  [23371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5645),
  [23373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19938),
  [23375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4470),
  [23377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19893),
  [23379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16743),
  [23381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1206),
  [23383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7468),
  [23385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7930),
  [23387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19885),
  [23389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19882),
  [23391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7862),
  [23393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19876),
  [23395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10269),
  [23397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19875),
  [23399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13349),
  [23401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3166),
  [23403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4282),
  [23405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19870),
  [23407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3137),
  [23409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19881),
  [23411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3135),
  [23413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19878),
  [23415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1800),
  [23417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9013),
  [23419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2569),
  [23421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13783),
  [23423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13228),
  [23425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5373),
  [23427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10115),
  [23429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1071),
  [23431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7473),
  [23433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13445),
  [23435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(514),
  [23437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5972),
  [23439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7612),
  [23441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19435),
  [23443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5949),
  [23445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19838),
  [23447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8011),
  [23449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5946),
  [23451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19833),
  [23453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8809),
  [23455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7409),
  [23457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17446),
  [23459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5302),
  [23461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9982),
  [23463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7797),
  [23465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19757),
  [23467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1079),
  [23469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7620),
  [23471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7909),
  [23473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19752),
  [23475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6534),
  [23477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19750),
  [23479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6567),
  [23481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19770),
  [23483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7884),
  [23485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6575),
  [23487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19769),
  [23489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19739),
  [23491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13873),
  [23493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19727),
  [23495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13879),
  [23497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7808),
  [23499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19736),
  [23501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13459),
  [23503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2171),
  [23505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(791),
  [23507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7899),
  [23509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10367),
  [23511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8445),
  [23513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3116),
  [23515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3110),
  [23517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19724),
  [23519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13431),
  [23521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16760),
  [23523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3108),
  [23525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19721),
  [23527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7660),
  [23529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19491),
  [23531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8036),
  [23533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8802),
  [23535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7214),
  [23537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10307),
  [23539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7329),
  [23541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16761),
  [23543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19452),
  [23545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19453),
  [23547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19454),
  [23549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9391),
  [23551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5529),
  [23553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19632),
  [23555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(809),
  [23557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7867),
  [23559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4792),
  [23561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8034),
  [23563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4803),
  [23565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19648),
  [23567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15580),
  [23569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19620),
  [23571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4808),
  [23573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19642),
  [23575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8572),
  [23577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19618),
  [23579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7873),
  [23581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19614),
  [23583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7644),
  [23585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2325),
  [23587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5493),
  [23589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19612),
  [23591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11632),
  [23593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2072),
  [23595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1162),
  [23597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8868),
  [23599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7161),
  [23601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8647),
  [23603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7210),
  [23605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19601),
  [23607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13166),
  [23609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7213),
  [23611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19600),
  [23613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10920),
  [23615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13443),
  [23617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7527),
  [23619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19525),
  [23621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8706),
  [23623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6883),
  [23625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10788),
  [23627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8080),
  [23629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5174),
  [23631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10709),
  [23633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7485),
  [23635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5296),
  [23637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19517),
  [23639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7488),
  [23641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19544),
  [23643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7490),
  [23645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19538),
  [23647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(603),
  [23649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8564),
  [23651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19513),
  [23653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19511),
  [23655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19504),
  [23657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7530),
  [23659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19503),
  [23661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5672),
  [23663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5278),
  [23665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19502),
  [23667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11921),
  [23669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1902),
  [23671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13846),
  [23673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8122),
  [23675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7273),
  [23677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19495),
  [23679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7188),
  [23681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7280),
  [23683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19493),
  [23685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5533),
  [23687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10078),
  [23689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13470),
  [23691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11923),
  [23693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7685),
  [23695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19553),
  [23697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1078),
  [23699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8663),
  [23701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7232),
  [23703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7196),
  [23705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3904),
  [23707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19461),
  [23709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1832),
  [23711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3912),
  [23713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19460),
  [23715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7225),
  [23717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3487),
  [23719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1095),
  [23721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10160),
  [23723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19422),
  [23725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19419),
  [23727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19417),
  [23729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19413),
  [23731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7855),
  [23733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19412),
  [23735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5606),
  [23737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10142),
  [23739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19411),
  [23741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3828),
  [23743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1908),
  [23745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5875),
  [23747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19414),
  [23749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9012),
  [23751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5942),
  [23753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19410),
  [23755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10381),
  [23757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10441),
  [23759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3551),
  [23761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11678),
  [23763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13493),
  [23765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1197),
  [23767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7623),
  [23769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19579),
  [23771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1210),
  [23773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8745),
  [23775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7050),
  [23777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2278),
  [23779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7038),
  [23781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8444),
  [23783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6101),
  [23785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8724),
  [23787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3632),
  [23789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3846),
  [23791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19639),
  [23793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16785),
  [23795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9505),
  [23797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19340),
  [23799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19336),
  [23801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8793),
  [23803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6966),
  [23805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19335),
  [23807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2246),
  [23809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3826),
  [23811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19362),
  [23813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10227),
  [23815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10739),
  [23817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7000),
  [23819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19343),
  [23821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8896),
  [23823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11099),
  [23825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13440),
  [23827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8311),
  [23829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19604),
  [23831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8848),
  [23833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7310),
  [23835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5256),
  [23837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6908),
  [23839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1383),
  [23841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10824),
  [23843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1346),
  [23845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6907),
  [23847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19269),
  [23849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6930),
  [23851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6903),
  [23853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19263),
  [23855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2375),
  [23857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9372),
  [23859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6839),
  [23861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7705),
  [23863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13454),
  [23865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5184),
  [23867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19624),
  [23869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8796),
  [23871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4932),
  [23873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13466),
  [23875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9872),
  [23877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6800),
  [23879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19202),
  [23881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11410),
  [23883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3931),
  [23885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16801),
  [23887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6569),
  [23889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19212),
  [23891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6848),
  [23893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19194),
  [23895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6708),
  [23897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10477),
  [23899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6889),
  [23901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16802),
  [23903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19499),
  [23905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19500),
  [23907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19501),
  [23909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6586),
  [23911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19204),
  [23913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5599),
  [23915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16337),
  [23917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13435),
  [23919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5633),
  [23921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8734),
  [23923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3723),
  [23925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9826),
  [23927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19643),
  [23929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8704),
  [23931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6753),
  [23933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9219),
  [23935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11175),
  [23937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20217),
  [23939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16683),
  [23941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20216),
  [23943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6278),
  [23945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20215),
  [23947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6556),
  [23949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19131),
  [23951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20212),
  [23953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16696),
  [23955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20211),
  [23957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20210),
  [23959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6522),
  [23961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19130),
  [23963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7575),
  [23965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19078),
  [23967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20207),
  [23969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16709),
  [23971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20206),
  [23973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20205),
  [23975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20202),
  [23977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16722),
  [23979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20201),
  [23981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20200),
  [23983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2999),
  [23985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8780),
  [23987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5177),
  [23989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20197),
  [23991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16737),
  [23993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20196),
  [23995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20195),
  [23997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20192),
  [23999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16752),
  [24001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20191),
  [24003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20190),
  [24005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5855),
  [24007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20187),
  [24009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16771),
  [24011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20186),
  [24013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20185),
  [24015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7573),
  [24017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19066),
  [24019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20182),
  [24021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16789),
  [24023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6412),
  [24025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20181),
  [24027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9645),
  [24029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19062),
  [24031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20180),
  [24033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16827),
  [24035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6980),
  [24037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20177),
  [24039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16810),
  [24041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9626),
  [24043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19061),
  [24045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20176),
  [24047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20175),
  [24049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7582),
  [24051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20172),
  [24053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16826),
  [24055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20171),
  [24057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20170),
  [24059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20167),
  [24061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16843),
  [24063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20166),
  [24065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20165),
  [24067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20162),
  [24069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16856),
  [24071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8808),
  [24073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5738),
  [24075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20161),
  [24077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20160),
  [24079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13476),
  [24081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20157),
  [24083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16869),
  [24085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20156),
  [24087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20155),
  [24089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3975),
  [24091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19662),
  [24093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20150),
  [24095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16883),
  [24097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20149),
  [24099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20148),
  [24101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8686),
  [24103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3385),
  [24105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13299),
  [24107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7335),
  [24109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9674),
  [24111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16838),
  [24113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20138),
  [24115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16908),
  [24117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6263),
  [24119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18968),
  [24121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20137),
  [24123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20136),
  [24125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13795),
  [24127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6937),
  [24129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18932),
  [24131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6950),
  [24133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18922),
  [24135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20124),
  [24137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16961),
  [24139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16840),
  [24141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19529),
  [24143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19530),
  [24145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19531),
  [24147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20123),
  [24149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20122),
  [24151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6256),
  [24153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18961),
  [24155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16046),
  [24157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11026),
  [24159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5416),
  [24161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5577),
  [24163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13436),
  [24165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20110),
  [24167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17004),
  [24169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20109),
  [24171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20108),
  [24173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6448),
  [24175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7243),
  [24177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19680),
  [24179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8835),
  [24181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3019),
  [24183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8656),
  [24185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7946),
  [24187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7374),
  [24189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11809),
  [24191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20096),
  [24193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17040),
  [24195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20095),
  [24197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20094),
  [24199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12316),
  [24201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18829),
  [24203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12350),
  [24205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18820),
  [24207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2181),
  [24209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9411),
  [24211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20082),
  [24213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17094),
  [24215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20081),
  [24217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20080),
  [24219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8077),
  [24221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6608),
  [24223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13425),
  [24225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6349),
  [24227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18802),
  [24229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4507),
  [24231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19696),
  [24233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20068),
  [24235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17137),
  [24237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20067),
  [24239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20066),
  [24241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6615),
  [24243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18795),
  [24245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8643),
  [24247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4142),
  [24249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4965),
  [24251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9524),
  [24253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16857),
  [24255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9398),
  [24257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5441),
  [24259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18734),
  [24261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3063),
  [24263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5912),
  [24265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18663),
  [24267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8869),
  [24269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5994),
  [24271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20053),
  [24273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17187),
  [24275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20052),
  [24277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20051),
  [24279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5439),
  [24281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18729),
  [24283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4072),
  [24285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20064),
  [24287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9575),
  [24289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8199),
  [24291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13469),
  [24293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20038),
  [24295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17239),
  [24297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20037),
  [24299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20036),
  [24301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7501),
  [24303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19712),
  [24305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8617),
  [24307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6982),
  [24309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10171),
  [24311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6350),
  [24313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20023),
  [24315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17297),
  [24317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20022),
  [24319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20021),
  [24321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14032),
  [24323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18645),
  [24325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14026),
  [24327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18641),
  [24329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2058),
  [24331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16885),
  [24333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9711),
  [24335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8571),
  [24337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5936),
  [24339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18661),
  [24341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20008),
  [24343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17342),
  [24345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20007),
  [24347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20006),
  [24349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13463),
  [24351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16873),
  [24353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19557),
  [24355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19558),
  [24357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19559),
  [24359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15924),
  [24361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7361),
  [24363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19728),
  [24365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7426),
  [24367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7005),
  [24369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4858),
  [24371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8578),
  [24373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6406),
  [24375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8824),
  [24377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6384),
  [24379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19993),
  [24381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17394),
  [24383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19992),
  [24385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19991),
  [24387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4148),
  [24389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20049),
  [24391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8921),
  [24393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18562),
  [24395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8907),
  [24397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18559),
  [24399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17430),
  [24401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13183),
  [24403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7441),
  [24405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8823),
  [24407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19978),
  [24409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17453),
  [24411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19977),
  [24413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19976),
  [24415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13495),
  [24417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10220),
  [24419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4079),
  [24421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19744),
  [24423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5923),
  [24425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16887),
  [24427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17483),
  [24429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5323),
  [24431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18522),
  [24433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8576),
  [24435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3576),
  [24437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3558),
  [24439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19963),
  [24441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17501),
  [24443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19962),
  [24445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19961),
  [24447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5317),
  [24449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18518),
  [24451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13186),
  [24453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7434),
  [24455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18477),
  [24457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17542),
  [24459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7436),
  [24461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18470),
  [24463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1940),
  [24465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10256),
  [24467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19948),
  [24469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17556),
  [24471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6955),
  [24473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19947),
  [24475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19946),
  [24477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8789),
  [24479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3153),
  [24481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12826),
  [24483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13478),
  [24485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5528),
  [24487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20034),
  [24489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17579),
  [24491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7233),
  [24493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19760),
  [24495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16903),
  [24497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8600),
  [24499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4063),
  [24501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19933),
  [24503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17576),
  [24505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19932),
  [24507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19931),
  [24509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4033),
  [24511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10922),
  [24513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7487),
  [24515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18388),
  [24517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16911),
  [24519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19583),
  [24521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19584),
  [24523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19585),
  [24525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16440),
  [24527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17586),
  [24529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5361),
  [24531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19918),
  [24533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17554),
  [24535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5145),
  [24537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18389),
  [24539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19917),
  [24541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19916),
  [24543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7469),
  [24545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18380),
  [24547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7568),
  [24549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7610),
  [24551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13488),
  [24553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17538),
  [24555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5063),
  [24557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18385),
  [24559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4531),
  [24561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19776),
  [24563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19903),
  [24565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17533),
  [24567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19902),
  [24569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19901),
  [24571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8612),
  [24573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9197),
  [24575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3840),
  [24577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12057),
  [24579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8783),
  [24581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4890),
  [24583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16912),
  [24585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12697),
  [24587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17518),
  [24589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4978),
  [24591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18299),
  [24593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5897),
  [24595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20019),
  [24597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7201),
  [24599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19888),
  [24601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17507),
  [24603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19887),
  [24605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19886),
  [24607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4973),
  [24609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18294),
  [24611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1827),
  [24613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9670),
  [24615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4908),
  [24617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17494),
  [24619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13494),
  [24621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5121),
  [24623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19873),
  [24625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17481),
  [24627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5772),
  [24629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18269),
  [24631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19872),
  [24633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19871),
  [24635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7466),
  [24637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19792),
  [24639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8627),
  [24641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5810),
  [24643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6490),
  [24645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9852),
  [24647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5770),
  [24649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18263),
  [24651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17473),
  [24653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16923),
  [24655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5688),
  [24657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18213),
  [24659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19858),
  [24661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17460),
  [24663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19857),
  [24665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19856),
  [24667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5707),
  [24669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18206),
  [24671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9085),
  [24673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16926),
  [24675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19606),
  [24677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19607),
  [24679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19608),
  [24681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16137),
  [24683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17448),
  [24685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8775),
  [24687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6766),
  [24689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13453),
  [24691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19843),
  [24693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17439),
  [24695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19842),
  [24697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19841),
  [24699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3827),
  [24701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20004),
  [24703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17437),
  [24705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6607),
  [24707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19808),
  [24709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8642),
  [24711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5068),
  [24713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3547),
  [24715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17418),
  [24717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5425),
  [24719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7668),
  [24721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18128),
  [24723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19828),
  [24725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17410),
  [24727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19827),
  [24729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19826),
  [24731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17431),
  [24733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7673),
  [24735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18124),
  [24737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5813),
  [24739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1858),
  [24741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9129),
  [24743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18125),
  [24745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16932),
  [24747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9202),
  [24749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7655),
  [24751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13490),
  [24753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9083),
  [24755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18123),
  [24757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17391),
  [24759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5395),
  [24761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19824),
  [24763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8657),
  [24765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5330),
  [24767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19812),
  [24769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17378),
  [24771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19811),
  [24773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19810),
  [24775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4040),
  [24777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9310),
  [24779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6022),
  [24781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17404),
  [24783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8768),
  [24785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7700),
  [24787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5593),
  [24789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18055),
  [24791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5576),
  [24793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18052),
  [24795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17358),
  [24797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12903),
  [24799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6938),
  [24801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19989),
  [24803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5478),
  [24805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19796),
  [24807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17346),
  [24809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16943),
  [24811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19795),
  [24813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19794),
  [24815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5660),
  [24817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19839),
  [24819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17341),
  [24821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8670),
  [24823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5887),
  [24825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5815),
  [24827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9297),
  [24829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16944),
  [24831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19626),
  [24833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19627),
  [24835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19628),
  [24837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15802),
  [24839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3700),
  [24841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12905),
  [24843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3997),
  [24845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7883),
  [24847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17987),
  [24849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4084),
  [24851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18005),
  [24853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17324),
  [24855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7893),
  [24857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17984),
  [24859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13398),
  [24861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7974),
  [24863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19780),
  [24865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17312),
  [24867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19779),
  [24869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19778),
  [24871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17310),
  [24873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3986),
  [24875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17998),
  [24877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7437),
  [24879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19854),
  [24881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8677),
  [24883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6473),
  [24885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17293),
  [24887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5013),
  [24889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7040),
  [24891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17924),
  [24893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3888),
  [24895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7026),
  [24897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17918),
  [24899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19764),
  [24901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17275),
  [24903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16964),
  [24905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8765),
  [24907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6674),
  [24909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19763),
  [24911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19762),
  [24913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7447),
  [24915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19974),
  [24917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6957),
  [24919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17274),
  [24921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7446),
  [24923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19869),
  [24925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8692),
  [24927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6244),
  [24929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17256),
  [24931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5380),
  [24933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3360),
  [24935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17858),
  [24937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19748),
  [24939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17242),
  [24941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19747),
  [24943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19746),
  [24945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17240),
  [24947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3331),
  [24949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17818),
  [24951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3393),
  [24953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3458),
  [24955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17853),
  [24957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17220),
  [24959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7458),
  [24961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19884),
  [24963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8703),
  [24965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9644),
  [24967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16993),
  [24969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3481),
  [24971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17851),
  [24973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6132),
  [24975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19732),
  [24977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17212),
  [24979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19731),
  [24981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19730),
  [24983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7586),
  [24985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8088),
  [24987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17796),
  [24989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17226),
  [24991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17005),
  [24993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19645),
  [24995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19646),
  [24997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19647),
  [24999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15289),
  [25001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8076),
  [25003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17791),
  [25005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8050),
  [25007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6587),
  [25009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17186),
  [25011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8755),
  [25013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3892),
  [25015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7464),
  [25017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19899),
  [25019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8730),
  [25021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6214),
  [25023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19716),
  [25025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17179),
  [25027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19715),
  [25029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19714),
  [25031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6311),
  [25033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3845),
  [25035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19959),
  [25037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17171),
  [25039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8820),
  [25041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17733),
  [25043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8806),
  [25045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17730),
  [25047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8799),
  [25049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17159),
  [25051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17044),
  [25053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19700),
  [25055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17145),
  [25057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19699),
  [25059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6549),
  [25061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19698),
  [25063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8736),
  [25065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6306),
  [25067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6433),
  [25069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17705),
  [25071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17142),
  [25073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6343),
  [25075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4198),
  [25077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19914),
  [25079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4156),
  [25081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17671),
  [25083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17126),
  [25085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6421),
  [25087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17696),
  [25089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4153),
  [25091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17665),
  [25093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4173),
  [25095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6820),
  [25097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17622),
  [25099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8742),
  [25101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3951),
  [25103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17117),
  [25105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19682),
  [25107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17099),
  [25109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19683),
  [25111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6495),
  [25113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19684),
  [25115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17084),
  [25117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9727),
  [25119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8751),
  [25121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5985),
  [25123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4300),
  [25125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19929),
  [25127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6823),
  [25129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17623),
  [25131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17113),
  [25133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5142),
  [25135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19944),
  [25137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15084),
  [25139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17085),
  [25141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19664),
  [25143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19665),
  [25145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19666),
  [25147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15881),
  [25149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6776),
  [25151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3347),
  [25153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2129),
  [25155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17077),
  [25157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3750),
  [25159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(712),
  [25161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3651),
  [25163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5979),
  [25165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [25167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2894),
  [25169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3506),
  [25171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2895),
  [25173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3503),
  [25175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5993),
  [25177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15789),
  [25179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6684),
  [25181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6653),
  [25183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6651),
  [25185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(699),
  [25187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(706),
  [25189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(705),
  [25191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(702),
  [25193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4113),
  [25195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11725),
  [25197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17087),
  [25199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2188),
  [25201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6819),
  [25203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6821),
  [25205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3590),
  [25207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3595),
  [25209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3598),
  [25211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4487),
  [25213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3949),
  [25215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3962),
  [25217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3612),
  [25219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12636),
  [25221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3618),
  [25223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3619),
  [25225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(770),
  [25227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9257),
  [25229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7906),
  [25231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [25233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2909),
  [25235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2910),
  [25237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17112),
  [25239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9268),
  [25241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9266),
  [25243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3762),
  [25245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3993),
  [25247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6733),
  [25249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2911),
  [25251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2912),
  [25253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6734),
  [25255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15857),
  [25257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(823),
  [25259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(777),
  [25261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(787),
  [25263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(788),
  [25265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8721),
  [25267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5276),
  [25269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2249),
  [25271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5968),
  [25273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5967),
  [25275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4152),
  [25277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11511),
  [25279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17120),
  [25281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2889),
  [25283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4154),
  [25285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5969),
  [25287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6070),
  [25289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6074),
  [25291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6076),
  [25293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4542),
  [25295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6330),
  [25297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12709),
  [25299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5965),
  [25301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6328),
  [25303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6078),
  [25305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6080),
  [25307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6082),
  [25309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1021),
  [25311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2921),
  [25313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2919),
  [25315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17140),
  [25317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3485),
  [25319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5960),
  [25321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6313),
  [25323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5959),
  [25325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [25327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5958),
  [25329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6430),
  [25331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7925),
  [25333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2864),
  [25335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2794),
  [25337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7927),
  [25339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6296),
  [25341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(573),
  [25343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15724),
  [25345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12713),
  [25347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6435),
  [25349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1833),
  [25351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8658),
  [25353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4139),
  [25355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4122),
  [25357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1009),
  [25359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6736),
  [25361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1014),
  [25363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1013),
  [25365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1011),
  [25367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8006),
  [25369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11335),
  [25371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17153),
  [25373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1139),
  [25375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1140),
  [25377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2234),
  [25379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1144),
  [25381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1135),
  [25383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8805),
  [25385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3443),
  [25387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12624),
  [25389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8811),
  [25391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6119),
  [25393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6120),
  [25395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6121),
  [25397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7499),
  [25399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6238),
  [25401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2737),
  [25403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2779),
  [25405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17200),
  [25407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6236),
  [25409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6124),
  [25411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6125),
  [25413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6126),
  [25415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(554),
  [25417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3760),
  [25419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5588),
  [25421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2916),
  [25423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2917),
  [25425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6221),
  [25427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6488),
  [25429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(405),
  [25431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16358),
  [25433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17029),
  [25435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11278),
  [25437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5586),
  [25439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5585),
  [25441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6204),
  [25443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3842),
  [25445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7931),
  [25447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9406),
  [25449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8715),
  [25451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9508),
  [25453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11217),
  [25455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17181),
  [25457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8718),
  [25459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(638),
  [25461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9630),
  [25463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(600),
  [25465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(632),
  [25467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3479),
  [25469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12683),
  [25471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8760),
  [25473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1946),
  [25475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [25477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3872),
  [25479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8066),
  [25481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9499),
  [25483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2899),
  [25485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2920),
  [25487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17202),
  [25489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8058),
  [25491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9662),
  [25493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9566),
  [25495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9567),
  [25497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7532),
  [25499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9573),
  [25501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1151),
  [25503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15313),
  [25505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9577),
  [25507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2914),
  [25509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2913),
  [25511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9579),
  [25513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9580),
  [25515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9583),
  [25517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16400),
  [25519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3348),
  [25521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3346),
  [25523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2842),
  [25525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(690),
  [25527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7541),
  [25529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3316),
  [25531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1240),
  [25533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [25535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2871),
  [25537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3755),
  [25539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7542),
  [25541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7543),
  [25543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9675),
  [25545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11235),
  [25547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17214),
  [25549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4147),
  [25551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3584),
  [25553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3318),
  [25555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7982),
  [25557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3317),
  [25559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7989),
  [25561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12793),
  [25563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(790),
  [25565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(781),
  [25567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(782),
  [25569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(786),
  [25571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6882),
  [25573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3315),
  [25575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2905),
  [25577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2904),
  [25579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17235),
  [25581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3465),
  [25583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1880),
  [25585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3456),
  [25587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16990),
  [25589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6036),
  [25591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2870),
  [25593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5966),
  [25595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3332),
  [25597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6148),
  [25599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2903),
  [25601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2902),
  [25603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6149),
  [25605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6150),
  [25607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7540),
  [25609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16250),
  [25611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2025),
  [25613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2869),
  [25615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6174),
  [25617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6648),
  [25619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6181),
  [25621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6142),
  [25623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6141),
  [25625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6140),
  [25627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(826),
  [25629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1232),
  [25631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5587),
  [25633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6232),
  [25635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1233),
  [25637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11274),
  [25639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17244),
  [25641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(403),
  [25643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1235),
  [25645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1231),
  [25647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5589),
  [25649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5590),
  [25651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6254),
  [25653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13410),
  [25655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12704),
  [25657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6857),
  [25659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3486),
  [25661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4102),
  [25663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3484),
  [25665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2898),
  [25667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2896),
  [25669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17272),
  [25671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(850),
  [25673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(839),
  [25675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(844),
  [25677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(848),
  [25679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8048),
  [25681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12632),
  [25683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2322),
  [25685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2891),
  [25687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2900),
  [25689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4143),
  [25691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3501),
  [25693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7023),
  [25695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16124),
  [25697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6701),
  [25699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10829),
  [25701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10832),
  [25703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7030),
  [25705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6053),
  [25707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6052),
  [25709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6051),
  [25711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7539),
  [25713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6405),
  [25715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(489),
  [25717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6681),
  [25719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6426),
  [25721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6037),
  [25723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10891),
  [25725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11307),
  [25727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17287),
  [25729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6035),
  [25731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(870),
  [25733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4934),
  [25735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6461),
  [25737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5899),
  [25739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [25741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12820),
  [25743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2844),
  [25745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4928),
  [25747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4927),
  [25749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6479),
  [25751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6693),
  [25753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2885),
  [25755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2877),
  [25757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17315),
  [25759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8059),
  [25761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6694),
  [25763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6878),
  [25765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6695),
  [25767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6879),
  [25769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6696),
  [25771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(861),
  [25773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(866),
  [25775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2875),
  [25777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2874),
  [25779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(865),
  [25781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(864),
  [25783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5427),
  [25785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15982),
  [25787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16952),
  [25789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11656),
  [25791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2015),
  [25793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6698),
  [25795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7555),
  [25797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6703),
  [25799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7894),
  [25801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6704),
  [25803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6705),
  [25805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7891),
  [25807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5934),
  [25809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5933),
  [25811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11325),
  [25813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17319),
  [25815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5932),
  [25817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5769),
  [25819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5921),
  [25821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3995),
  [25823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5919),
  [25825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5918),
  [25827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5917),
  [25829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12721),
  [25831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5916),
  [25833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(851),
  [25835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3994),
  [25837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8009),
  [25839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1906),
  [25841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2858),
  [25843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2855),
  [25845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17340),
  [25847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15807),
  [25849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3437),
  [25851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [25853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(876),
  [25855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8002),
  [25857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7999),
  [25859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2852),
  [25861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5878),
  [25863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(877),
  [25865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2846),
  [25867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2843),
  [25869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5470),
  [25871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8063),
  [25873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15835),
  [25875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2851),
  [25877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(879),
  [25879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(871),
  [25881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9101),
  [25883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8062),
  [25885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(901),
  [25887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(888),
  [25889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(896),
  [25891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(897),
  [25893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7622),
  [25895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7857),
  [25897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2410),
  [25899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11340),
  [25901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17351),
  [25903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9039),
  [25905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4002),
  [25907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7704),
  [25909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7445),
  [25911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5568),
  [25913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16954),
  [25915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12900),
  [25917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5567),
  [25919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12667),
  [25921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5310),
  [25923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5308),
  [25925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5305),
  [25927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5479),
  [25929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5362),
  [25931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2823),
  [25933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2816),
  [25935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17374),
  [25937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2847),
  [25939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7444),
  [25941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5354),
  [25943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5286),
  [25945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5285),
  [25947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5284),
  [25949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(698),
  [25951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7695),
  [25953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5311),
  [25955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2814),
  [25957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2813),
  [25959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7609),
  [25961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6773),
  [25963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15658),
  [25965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7439),
  [25967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(884),
  [25969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [25971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7682),
  [25973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13267),
  [25975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7625),
  [25977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7613),
  [25979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7681),
  [25981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5350),
  [25983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7678),
  [25985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7595),
  [25987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5426),
  [25989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11366),
  [25991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17383),
  [25993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12769),
  [25995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7677),
  [25997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5495),
  [25999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7676),
  [26001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(685),
  [26003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(693),
  [26005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12642),
  [26007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(692),
  [26009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(688),
  [26011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5525),
  [26013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7416),
  [26015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5677),
  [26017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1868),
  [26019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2751),
  [26021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2797),
  [26023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17403),
  [26025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7670),
  [26027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7669),
  [26029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7666),
  [26031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9115),
  [26033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7674),
  [26035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9134),
  [26037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9214),
  [26039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2316),
  [26041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7671),
  [26043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4982),
  [26045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2791),
  [26047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2790),
  [26049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4993),
  [26051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4987),
  [26053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6975),
  [26055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15449),
  [26057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4048),
  [26059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1293),
  [26061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4999),
  [26063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1294),
  [26065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4997),
  [26067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4977),
  [26069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4967),
  [26071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1298),
  [26073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4958),
  [26075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(908),
  [26077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1291),
  [26079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11382),
  [26081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17411),
  [26083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8939),
  [26085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5020),
  [26087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5841),
  [26089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [26091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16928),
  [26093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12701),
  [26095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8927),
  [26097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8924),
  [26099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2757),
  [26101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2756),
  [26103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17429),
  [26105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5123),
  [26107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11439),
  [26109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11106),
  [26111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7618),
  [26113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2786),
  [26115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2755),
  [26117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5822),
  [26119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7619),
  [26121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15231),
  [26123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9066),
  [26125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6756),
  [26127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10051),
  [26129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(945),
  [26131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10038),
  [26133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(932),
  [26135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(942),
  [26137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(943),
  [26139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11399),
  [26141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17442),
  [26143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4942),
  [26145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7636),
  [26147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2392),
  [26149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5667),
  [26151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8764),
  [26153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12722),
  [26155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16169),
  [26157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5710),
  [26159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9905),
  [26161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2723),
  [26163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2719),
  [26165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17459),
  [26167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9060),
  [26169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5698),
  [26171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5683),
  [26173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5682),
  [26175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5681),
  [26177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2717),
  [26179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2715),
  [26181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7786),
  [26183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5834),
  [26185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15086),
  [26187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1306),
  [26189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2812),
  [26191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6785),
  [26193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2811),
  [26195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5833),
  [26197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6786),
  [26199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4602),
  [26201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5666),
  [26203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5665),
  [26205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11445),
  [26207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17463),
  [26209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(683),
  [26211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6787),
  [26213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6788),
  [26215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7890),
  [26217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5820),
  [26219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6790),
  [26221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12804),
  [26223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(457),
  [26225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2712),
  [26227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2714),
  [26229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17479),
  [26231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4066),
  [26233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6795),
  [26235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6796),
  [26237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7888),
  [26239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7886),
  [26241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5797),
  [26243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2716),
  [26245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2728),
  [26247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6797),
  [26249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5491),
  [26251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5492),
  [26253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15388),
  [26255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5771),
  [26257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16921),
  [26259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2808),
  [26261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5773),
  [26263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2807),
  [26265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5497),
  [26267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2348),
  [26269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11470),
  [26271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17488),
  [26273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(731),
  [26275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(719),
  [26277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(724),
  [26279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(728),
  [26281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7638),
  [26283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5848),
  [26285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12748),
  [26287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5659),
  [26289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2161),
  [26291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(747),
  [26293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2747),
  [26295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2750),
  [26297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17502),
  [26299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(739),
  [26301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(738),
  [26303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13272),
  [26305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4972),
  [26307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(624),
  [26309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9643),
  [26311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2762),
  [26313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2763),
  [26315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4974),
  [26317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9040),
  [26319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9043),
  [26321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15662),
  [26323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5081),
  [26325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12809),
  [26327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9081),
  [26329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5128),
  [26331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9074),
  [26333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5843),
  [26335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11528),
  [26337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17514),
  [26339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9077),
  [26341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4856),
  [26343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9078),
  [26345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9080),
  [26347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9159),
  [26349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(955),
  [26351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8759),
  [26353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12656),
  [26355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12880),
  [26357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9132),
  [26359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2824),
  [26361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2828),
  [26363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17529),
  [26365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(430),
  [26367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4882),
  [26369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2701),
  [26371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2835),
  [26373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8790),
  [26375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12878),
  [26377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12875),
  [26379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15954),
  [26381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(732),
  [26383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4690),
  [26385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9224),
  [26387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4683),
  [26389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4681),
  [26391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4961),
  [26393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4957),
  [26395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11567),
  [26397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17534),
  [26399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4851),
  [26401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16906),
  [26403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4951),
  [26405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(989),
  [26407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(972),
  [26409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12794),
  [26411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(975),
  [26413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(987),
  [26415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7461),
  [26417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2884),
  [26419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2888),
  [26421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17551),
  [26423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11215),
  [26425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2368),
  [26427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4848),
  [26429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7564),
  [26431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2892),
  [26433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2893),
  [26435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4689),
  [26437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7493),
  [26439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4692),
  [26441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16229),
  [26443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4698),
  [26445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5126),
  [26447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12725),
  [26449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7475),
  [26451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5122),
  [26453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3834),
  [26455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3833),
  [26457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3829),
  [26459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11597),
  [26461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17558),
  [26463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7347),
  [26465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2070),
  [26467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4107),
  [26469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7495),
  [26471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4188),
  [26473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3798),
  [26475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12698),
  [26477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3751),
  [26479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3753),
  [26481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1473),
  [26483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2863),
  [26485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2853),
  [26487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17573),
  [26489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16437),
  [26491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5075),
  [26493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10165),
  [26495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4027),
  [26497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1356),
  [26499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2849),
  [26501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2809),
  [26503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [26505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16438),
  [26507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1357),
  [26509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2780),
  [26511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1359),
  [26513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2778),
  [26515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1355),
  [26517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5313),
  [26519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10204),
  [26521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10205),
  [26523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4078),
  [26525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11645),
  [26527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17563),
  [26529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7647),
  [26531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7646),
  [26533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5314),
  [26535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12661),
  [26537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7632),
  [26539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5022),
  [26541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1090),
  [26543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2725),
  [26545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2868),
  [26547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17570),
  [26549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(997),
  [26551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3159),
  [26553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1025),
  [26555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1055),
  [26557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8619),
  [26559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7494),
  [26561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2908),
  [26563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2918),
  [26565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1920),
  [26567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4006),
  [26569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16897),
  [26571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16373),
  [26573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2771),
  [26575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2766),
  [26577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3146),
  [26579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7497),
  [26581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7438),
  [26583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1366),
  [26585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10970),
  [26587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11665),
  [26589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17549),
  [26591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7435),
  [26593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2936),
  [26595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2973),
  [26597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2974),
  [26599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2975),
  [26601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4247),
  [26603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12772),
  [26605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3507),
  [26607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2935),
  [26609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3513),
  [26611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2881),
  [26613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2880),
  [26615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17517),
  [26617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2979),
  [26619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13356),
  [26621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2980),
  [26623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2981),
  [26625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1092),
  [26627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2934),
  [26629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2879),
  [26631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2876),
  [26633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6643),
  [26635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3556),
  [26637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16154),
  [26639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3115),
  [26641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12743),
  [26643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3113),
  [26645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5675),
  [26647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [26649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2932),
  [26651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2931),
  [26653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11703),
  [26655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17493),
  [26657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2930),
  [26659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5318),
  [26661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6662),
  [26663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6664),
  [26665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3643),
  [26667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5324),
  [26669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7362),
  [26671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12801),
  [26673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7363),
  [26675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2861),
  [26677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2860),
  [26679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17462),
  [26681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2230),
  [26683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7365),
  [26685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5360),
  [26687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1173),
  [26689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1152),
  [26691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2840),
  [26693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2830),
  [26695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1154),
  [26697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1166),
  [26699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8109),
  [26701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15978),
  [26703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(676),
  [26705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(675),
  [26707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(656),
  [26709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6408),
  [26711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6048),
  [26713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1968),
  [26715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11729),
  [26717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17440),
  [26719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6040),
  [26721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5329),
  [26723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8905),
  [26725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16878),
  [26727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13181),
  [26729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8911),
  [26731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5988),
  [26733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12677),
  [26735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5990),
  [26737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5997),
  [26739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7614),
  [26741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2795),
  [26743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2820),
  [26745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17405),
  [26747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6464),
  [26749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6462),
  [26751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6018),
  [26753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2793),
  [26755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2792),
  [26757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6019),
  [26759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6021),
  [26761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1227),
  [26763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15790),
  [26765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11501),
  [26767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6599),
  [26769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4003),
  [26771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5433),
  [26773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6420),
  [26775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11565),
  [26777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17386),
  [26779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(483),
  [26781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6160),
  [26783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3992),
  [26785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5494),
  [26787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12711),
  [26789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5442),
  [26791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6351),
  [26793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2770),
  [26795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2764),
  [26797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17306),
  [26799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8582),
  [26801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(642),
  [26803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8592),
  [26805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5952),
  [26807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2746),
  [26809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2741),
  [26811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8581),
  [26813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9709),
  [26815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1395),
  [26817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15589),
  [26819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15905),
  [26821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5948),
  [26823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5945),
  [26825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1267),
  [26827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1269),
  [26829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6579),
  [26831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1275),
  [26833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12933),
  [26835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2739),
  [26837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11458),
  [26839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17332),
  [26841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8940),
  [26843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2000),
  [26845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2738),
  [26847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6630),
  [26849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4423),
  [26851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14012),
  [26853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12824),
  [26855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5867),
  [26857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10139),
  [26859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14031),
  [26861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2833),
  [26863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2703),
  [26865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17291),
  [26867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6453),
  [26869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5865),
  [26871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6480),
  [26873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6485),
  [26875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7748),
  [26877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2705),
  [26879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2706),
  [26881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6828),
  [26883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5956),
  [26885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6817),
  [26887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15345),
  [26889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5924),
  [26891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(680),
  [26893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5910),
  [26895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6507),
  [26897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6512),
  [26899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9568),
  [26901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6538),
  [26903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1415),
  [26905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2153),
  [26907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11372),
  [26909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17284),
  [26911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10743),
  [26913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6919),
  [26915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1491),
  [26917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(408),
  [26919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12625),
  [26921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16870),
  [26923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2711),
  [26925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2713),
  [26927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17250),
  [26929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2727),
  [26931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10807),
  [26933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10737),
  [26935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7048),
  [26937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6063),
  [26939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2720),
  [26941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2721),
  [26943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13724),
  [26945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13727),
  [26947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15794),
  [26949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2726),
  [26951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1432),
  [26953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1434),
  [26955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1435),
  [26957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1426),
  [26959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13764),
  [26961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6646),
  [26963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11256),
  [26965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17231),
  [26967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1477),
  [26969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3862),
  [26971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1493),
  [26973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1504),
  [26975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9500),
  [26977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12719),
  [26979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7208),
  [26981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14131),
  [26983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2032),
  [26985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2731),
  [26987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2732),
  [26989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17203),
  [26991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13248),
  [26993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6657),
  [26995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13298),
  [26997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5432),
  [26999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5851),
  [27001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2734),
  [27003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2736),
  [27005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10304),
  [27007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5436),
  [27009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3885),
  [27011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15178),
  [27013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5925),
  [27015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12676),
  [27017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7207),
  [27019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3883),
  [27021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3882),
  [27023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4554),
  [27025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4172),
  [27027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11303),
  [27029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17148),
  [27031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6064),
  [27033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4180),
  [27035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3866),
  [27037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7219),
  [27039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3861),
  [27041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12706),
  [27043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1476),
  [27045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2744),
  [27047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2745),
  [27049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17147),
  [27051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9530),
  [27053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1443),
  [27055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4162),
  [27057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5799),
  [27059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(488),
  [27061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2748),
  [27063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2749),
  [27065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5793),
  [27067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5791),
  [27069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15274),
  [27071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6106),
  [27073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6108),
  [27075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4208),
  [27077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9592),
  [27079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9600),
  [27081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5787),
  [27083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4119),
  [27085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5785),
  [27087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5400),
  [27089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11424),
  [27091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17130),
  [27093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5401),
  [27095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5780),
  [27097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5402),
  [27099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12699),
  [27101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6212),
  [27103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1450),
  [27105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2709),
  [27107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2752),
  [27109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17106),
  [27111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1455),
  [27113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6188),
  [27115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1454),
  [27117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1451),
  [27119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5321),
  [27121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2753),
  [27123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2754),
  [27125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2034),
  [27127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5466),
  [27129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2074),
  [27131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15369),
  [27133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6623),
  [27135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1486),
  [27137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1487),
  [27139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9938),
  [27141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1489),
  [27143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12354),
  [27145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1479),
  [27147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11484),
  [27149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17081),
  [27151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9374),
  [27153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8644),
  [27155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9915),
  [27157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12355),
  [27159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7970),
  [27161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12681),
  [27163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7993),
  [27165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7998),
  [27167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7344),
  [27169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2759),
  [27171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2760),
  [27173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17023),
  [27175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6594),
  [27177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8070),
  [27179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8606),
  [27181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2304),
  [27183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9939),
  [27185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2767),
  [27187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2772),
  [27189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8090),
  [27191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8071),
  [27193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15463),
  [27195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6531),
  [27197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6527),
  [27199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3025),
  [27201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8042),
  [27203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7903),
  [27205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1440),
  [27207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16849),
  [27209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11541),
  [27211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17033),
  [27213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7269),
  [27215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9913),
  [27217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7882),
  [27219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [27221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12646),
  [27223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2782),
  [27225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2783),
  [27227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17013),
  [27229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11441),
  [27231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6619),
  [27233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7249),
  [27235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7247),
  [27237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9983),
  [27239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9999),
  [27241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2784),
  [27243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2788),
  [27245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7985),
  [27247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6620),
  [27249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12361),
  [27251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15557),
  [27253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3008),
  [27255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6641),
  [27257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12315),
  [27259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3361),
  [27261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12310),
  [27263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11652),
  [27265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16998),
  [27267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1417),
  [27269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1420),
  [27271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1419),
  [27273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12720),
  [27275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1418),
  [27277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8701),
  [27279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2801),
  [27281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2803),
  [27283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16972),
  [27285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7234),
  [27287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1500),
  [27289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12305),
  [27291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2101),
  [27293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2926),
  [27295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2804),
  [27297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2781),
  [27299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2929),
  [27301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2933),
  [27303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6952),
  [27305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15650),
  [27307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2996),
  [27309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2992),
  [27311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9837),
  [27313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16109),
  [27315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11814),
  [27317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7938),
  [27319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10083),
  [27321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6946),
  [27323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11714),
  [27325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16949),
  [27327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3173),
  [27329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3174),
  [27331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3175),
  [27333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4380),
  [27335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3358),
  [27337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8100),
  [27339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10065),
  [27341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2826),
  [27343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2827),
  [27345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16920),
  [27347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9970),
  [27349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2938),
  [27351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(477),
  [27353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3183),
  [27355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3185),
  [27357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2829),
  [27359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2832),
  [27361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3186),
  [27363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1410),
  [27365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2939),
  [27367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15741),
  [27369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2768),
  [27371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6200),
  [27373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2769),
  [27375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7159),
  [27377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9884),
  [27379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3375),
  [27381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6279),
  [27383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11670),
  [27385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16901),
  [27387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6157),
  [27389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6533),
  [27391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1258),
  [27393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7044),
  [27395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2799),
  [27397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2838),
  [27399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16886),
  [27401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1207),
  [27403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7043),
  [27405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2839),
  [27407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2841),
  [27409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15797),
  [27411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9822),
  [27413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1204),
  [27415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1262),
  [27417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9896),
  [27419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11626),
  [27421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16881),
  [27423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9897),
  [27425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3397),
  [27427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9582),
  [27429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7011),
  [27431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7010),
  [27433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16871),
  [27435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16836),
  [27437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2787),
  [27439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11609),
  [27441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16867),
  [27443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2789),
  [27445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7008),
  [27447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9609),
  [27449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1367),
  [27451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6451),
  [27453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5752),
  [27455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3706),
  [27457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3708),
  [27459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16854),
  [27461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1377),
  [27463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1375),
  [27465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1374),
  [27467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13290),
  [27469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2937),
  [27471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13250),
  [27473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16841),
  [27475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8007),
  [27477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6981),
  [27479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5751),
  [27481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3732),
  [27483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12770),
  [27485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16824),
  [27487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1174),
  [27489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2890),
  [27491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5473),
  [27493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5472),
  [27495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5469),
  [27497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5712),
  [27499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16807),
  [27501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5708),
  [27503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6804),
  [27505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5437),
  [27507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5435),
  [27509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5429),
  [27511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9632),
  [27513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9649),
  [27515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16786),
  [27517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7572),
  [27519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1795),
  [27521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13752),
  [27523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9741),
  [27525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1029),
  [27527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1030),
  [27529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16768),
  [27531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5630),
  [27533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9911),
  [27535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7574),
  [27537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1031),
  [27539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1028),
  [27541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16750),
  [27543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6826),
  [27545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6825),
  [27547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6824),
  [27549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9518),
  [27551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9681),
  [27553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5195),
  [27555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9517),
  [27557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16735),
  [27559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9892),
  [27561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(855),
  [27563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5161),
  [27565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9428),
  [27567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16720),
  [27569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5631),
  [27571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9912),
  [27573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9914),
  [27575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1035),
  [27577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5104),
  [27579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5102),
  [27581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16707),
  [27583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5100),
  [27585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6798),
  [27587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6793),
  [27589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5189),
  [27591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5190),
  [27593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5095),
  [27595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5086),
  [27597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16694),
  [27599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6784),
  [27601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6781),
  [27603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1362),
  [27605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5083),
  [27607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6543),
  [27609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6574),
  [27611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1922),
  [27613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16681),
  [27615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6172),
  [27617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6943),
  [27619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9928),
  [27621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1155),
  [27623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6711),
  [27625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1156),
  [27627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1157),
  [27629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [27631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16817),
  [27633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11211),
  [27635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1153),
  [27637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6184),
  [27639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6928),
  [27641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6926),
  [27643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9932),
  [27645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9953),
  [27647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6202),
  [27649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6789),
  [27651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6153),
  [27653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3672),
  [27655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7570),
  [27657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7567),
  [27659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10762),
  [27661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10763),
  [27663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7566),
  [27665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6166),
  [27667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10776),
  [27669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1323),
  [27671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1333),
  [27673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1327),
  [27675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1324),
  [27677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1161),
  [27679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5501),
  [27681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3015),
  [27683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6899),
  [27685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3016),
  [27687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3017),
  [27689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2165),
  [27691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9654),
  [27693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3729),
  [27695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16320),
  [27697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3731),
  [27699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3028),
  [27701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6852),
  [27703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3029),
  [27705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2867),
  [27707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11013),
  [27709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3030),
  [27711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7535),
  [27713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9945),
  [27715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2865),
  [27717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6827),
  [27719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4869),
  [27721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6573),
  [27723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4871),
  [27725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4873),
  [27727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5316),
  [27729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4960),
  [27731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7505),
  [27733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9943),
  [27735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6565),
  [27737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9942),
  [27739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4952),
  [27741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4891),
  [27743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4894),
  [27745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4773),
  [27747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1320),
  [27749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6252),
  [27751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6739),
  [27753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9870),
  [27755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4917),
  [27757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3073),
  [27759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(397),
  [27761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(853),
  [27763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(847),
  [27765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9697),
  [27767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6697),
  [27769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6683),
  [27771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9937),
  [27773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9934),
  [27775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1416),
  [27777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4946),
  [27779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(872),
  [27781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6794),
  [27783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6802),
  [27785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9961),
  [27787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6809),
  [27789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3867),
  [27791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1250),
  [27793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1268),
  [27795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1266),
  [27797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1171),
  [27799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7523),
  [27801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2579),
  [27803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6832),
  [27805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2208),
  [27807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16796),
  [27809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2850),
  [27811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8268),
  [27813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6902),
  [27815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16537),
  [27817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3857),
  [27819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10105),
  [27821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5581),
  [27823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9977),
  [27825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6905),
  [27827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7291),
  [27829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7286),
  [27831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7281),
  [27833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8412),
  [27835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7284),
  [27837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5591),
  [27839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9974),
  [27841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2576),
  [27843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9342),
  [27845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6299),
  [27847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2822),
  [27849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7287),
  [27851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3640),
  [27853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20474),
  [27855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20482),
  [27857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20488),
  [27859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7288),
  [27861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7289),
  [27863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7290),
  [27865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1163),
  [27867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7313),
  [27869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10163),
  [27871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9873),
  [27873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2560),
  [27875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7304),
  [27877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7312),
  [27879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3737),
  [27881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [27883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3615),
  [27885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13367),
  [27887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10280),
  [27889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10282),
  [27891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9887),
  [27893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9889),
  [27895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7317),
  [27897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7301),
  [27899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6920),
  [27901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6921),
  [27903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13307),
  [27905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6925),
  [27907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1054),
  [27909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1081),
  [27911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1073),
  [27913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1072),
  [27915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5510),
  [27917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(834),
  [27919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8504),
  [27921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3066),
  [27923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2302),
  [27925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3067),
  [27927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12814),
  [27929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3068),
  [27931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3603),
  [27933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6948),
  [27935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8777),
  [27937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3601),
  [27939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10777),
  [27941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3070),
  [27943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7589),
  [27945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10000),
  [27947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6929),
  [27949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6369),
  [27951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6371),
  [27953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6372),
  [27955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7590),
  [27957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6996),
  [27959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3071),
  [27961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7594),
  [27963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10001),
  [27965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10003),
  [27967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5992),
  [27969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7001),
  [27971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6376),
  [27973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6377),
  [27975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6378),
  [27977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8224),
  [27979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(970),
  [27981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16639),
  [27983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3839),
  [27985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7400),
  [27987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10004),
  [27989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7033),
  [27991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [27993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3868),
  [27995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(606),
  [27997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(605),
  [27999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9407),
  [28001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7396),
  [28003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(597),
  [28005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20153),
  [28007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20152),
  [28009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20151),
  [28011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7389),
  [28013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10008),
  [28015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10012),
  [28017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7085),
  [28019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(618),
  [28021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7086),
  [28023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7088),
  [28025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10054),
  [28027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5940),
  [28029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7097),
  [28031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3812),
  [28033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(755),
  [28035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(822),
  [28037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [28039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(811),
  [28041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7635),
  [28043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10017),
  [28045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7357),
  [28047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10018),
  [28049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2237),
  [28051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10035),
  [28053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(589),
  [28055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5880),
  [28057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10158),
  [28059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5604),
  [28061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7856),
  [28063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5861),
  [28065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9497),
  [28067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6028),
  [28069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8874),
  [28071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10033),
  [28073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10130),
  [28075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6348),
  [28077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6151),
  [28079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6663),
  [28081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7827),
  [28083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7180),
  [28085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3773),
  [28087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3772),
  [28089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8891),
  [28091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10056),
  [28093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8173),
  [28095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10059),
  [28097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16820),
  [28099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5930),
  [28101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7192),
  [28103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6411),
  [28105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6423),
  [28107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6424),
  [28109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(561),
  [28111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(604),
  [28113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5632),
  [28115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12132),
  [28117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10073),
  [28119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9512),
  [28121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7217),
  [28123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4000),
  [28125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19565),
  [28127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19564),
  [28129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19562),
  [28131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3999),
  [28133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(412),
  [28135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3998),
  [28137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3907),
  [28139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3898),
  [28141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8699),
  [28143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12155),
  [28145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12158),
  [28147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10077),
  [28149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10087),
  [28151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7246),
  [28153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3774),
  [28155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7152),
  [28157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10251),
  [28159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10257),
  [28161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7139),
  [28163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10291),
  [28165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3757),
  [28167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(553),
  [28169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(607),
  [28171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7472),
  [28173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(608),
  [28175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8667),
  [28177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5241),
  [28179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10028),
  [28181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10290),
  [28183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8193),
  [28185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1835),
  [28187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16976),
  [28189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9984),
  [28191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7276),
  [28193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9925),
  [28195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7271),
  [28197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8605),
  [28199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8601),
  [28201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9462),
  [28203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19148),
  [28205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19147),
  [28207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19146),
  [28209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5274),
  [28211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5670),
  [28213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7536),
  [28215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8595),
  [28217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7158),
  [28219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10649),
  [28221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7521),
  [28223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7520),
  [28225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14064),
  [28227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8579),
  [28229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9918),
  [28231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5283),
  [28233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6552),
  [28235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6553),
  [28237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6554),
  [28239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7740),
  [28241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8128),
  [28243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6970),
  [28245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17104),
  [28247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7058),
  [28249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11091),
  [28251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14024),
  [28253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18871),
  [28255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18866),
  [28257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18857),
  [28259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11088),
  [28261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7736),
  [28263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11096),
  [28265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9921),
  [28267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9922),
  [28269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7489),
  [28271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6877),
  [28273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6560),
  [28275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6561),
  [28277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6540),
  [28279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(686),
  [28281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7486),
  [28283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5693),
  [28285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5306),
  [28287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8118),
  [28289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6856),
  [28291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17207),
  [28293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14076),
  [28295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(492),
  [28297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7061),
  [28299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18574),
  [28301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18572),
  [28303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18560),
  [28305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16775),
  [28307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7941),
  [28309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5172),
  [28311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5171),
  [28313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9931),
  [28315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9936),
  [28317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6988),
  [28319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7059),
  [28321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5260),
  [28323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5262),
  [28325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8160),
  [28327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11355),
  [28329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17288),
  [28331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5303),
  [28333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7496),
  [28335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18371),
  [28337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18361),
  [28339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18359),
  [28341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(750),
  [28343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(762),
  [28345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7028),
  [28347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(763),
  [28349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(765),
  [28351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13797),
  [28353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8521),
  [28355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7025),
  [28357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2373),
  [28359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7917),
  [28361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7017),
  [28363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7211),
  [28365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7209),
  [28367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8198),
  [28369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17366),
  [28371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7918),
  [28373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18171),
  [28375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18164),
  [28377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18162),
  [28379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6498),
  [28381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10861),
  [28383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5490),
  [28385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8920),
  [28387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7630),
  [28389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7896),
  [28391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4782),
  [28393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4781),
  [28395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7029),
  [28397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8260),
  [28399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5530),
  [28401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17444),
  [28403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7870),
  [28405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17976),
  [28407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17975),
  [28409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17974),
  [28411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10468),
  [28413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9910),
  [28415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5502),
  [28417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6612),
  [28419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6613),
  [28421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6614),
  [28423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7820),
  [28425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7278),
  [28427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3856),
  [28429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10471),
  [28431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8111),
  [28433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4806),
  [28435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17521),
  [28437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5481),
  [28439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17760),
  [28441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17759),
  [28443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17758),
  [28445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4802),
  [28447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9809),
  [28449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7302),
  [28451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9909),
  [28453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9908),
  [28455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7267),
  [28457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6625),
  [28459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6627),
  [28461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6628),
  [28463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(863),
  [28465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8250),
  [28467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7066),
  [28469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17567),
  [28471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17617),
  [28473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17618),
  [28475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17619),
  [28477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3129),
  [28479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8945),
  [28481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5532),
  [28483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9906),
  [28485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7226),
  [28487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15545),
  [28489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [28491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3131),
  [28493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8229),
  [28495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17561),
  [28497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17667),
  [28499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17668),
  [28501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17669),
  [28503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4775),
  [28505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10469),
  [28507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2837),
  [28509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7716),
  [28511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5550),
  [28513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5552),
  [28515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9903),
  [28517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9902),
  [28519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8665),
  [28521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8154),
  [28523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7182),
  [28525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17540),
  [28527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13206),
  [28529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17721),
  [28531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17722),
  [28533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17723),
  [28535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11974),
  [28537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11973),
  [28539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2831),
  [28541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11971),
  [28543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13207),
  [28545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(619),
  [28547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8153),
  [28549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(944),
  [28551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17523),
  [28553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(946),
  [28555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17775),
  [28557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17776),
  [28559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17777),
  [28561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(947),
  [28563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5325),
  [28565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5345),
  [28567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3109),
  [28569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5536),
  [28571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1851),
  [28573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3111),
  [28575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8209),
  [28577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13904),
  [28579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17500),
  [28581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4783),
  [28583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17829),
  [28585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17830),
  [28587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17831),
  [28589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6500),
  [28591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7645),
  [28593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7643),
  [28595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7814),
  [28597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3128),
  [28599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7642),
  [28601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14040),
  [28603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14664),
  [28605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3154),
  [28607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8234),
  [28609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9751),
  [28611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17480),
  [28613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9451),
  [28615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17883),
  [28617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17884),
  [28619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17885),
  [28621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5805),
  [28623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5804),
  [28625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5803),
  [28627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10349),
  [28629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7640),
  [28631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9966),
  [28633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7806),
  [28635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8174),
  [28637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7359),
  [28639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17461),
  [28641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7360),
  [28643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17937),
  [28645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17938),
  [28647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17939),
  [28649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7367),
  [28651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7805),
  [28653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7378),
  [28655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6571),
  [28657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6578),
  [28659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10306),
  [28661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5341),
  [28663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8115),
  [28665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7382),
  [28667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17443),
  [28669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2571),
  [28671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17991),
  [28673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17992),
  [28675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17993),
  [28677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9967),
  [28679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9975),
  [28681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6042),
  [28683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7384),
  [28685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7387),
  [28687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7388),
  [28689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7390),
  [28691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8281),
  [28693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1074),
  [28695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8158),
  [28697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16759),
  [28699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17419),
  [28701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18045),
  [28703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18046),
  [28705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18047),
  [28707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13925),
  [28709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14046),
  [28711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2587),
  [28713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7785),
  [28715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9985),
  [28717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7403),
  [28719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2817),
  [28721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8223),
  [28723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [28725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17397),
  [28727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6043),
  [28729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18099),
  [28731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18100),
  [28733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18101),
  [28735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6395),
  [28737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2798),
  [28739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5139),
  [28741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5137),
  [28743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5132),
  [28745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7591),
  [28747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2583),
  [28749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8253),
  [28751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7782),
  [28753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17377),
  [28755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7781),
  [28757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18152),
  [28759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18153),
  [28761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18154),
  [28763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9994),
  [28765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9996),
  [28767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8585),
  [28769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7415),
  [28771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5947),
  [28773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5406),
  [28775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5404),
  [28777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5951),
  [28779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17360),
  [28781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13287),
  [28783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18194),
  [28785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18195),
  [28787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18196),
  [28789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5403),
  [28791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(779),
  [28793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1198),
  [28795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1199),
  [28797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1201),
  [28799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10312),
  [28801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6501),
  [28803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7759),
  [28805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17345),
  [28807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13271),
  [28809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18234),
  [28811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18235),
  [28813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18236),
  [28815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7758),
  [28817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1872),
  [28819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3193),
  [28821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3194),
  [28823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6069),
  [28825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5339),
  [28827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3413),
  [28829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1292),
  [28831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7504),
  [28833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7503),
  [28835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17330),
  [28837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4410),
  [28839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18274),
  [28841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18275),
  [28843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18276),
  [28845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5355),
  [28847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13409),
  [28849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10308),
  [28851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7492),
  [28853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3136),
  [28855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12781),
  [28857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10842),
  [28859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3138),
  [28861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17314),
  [28863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18314),
  [28865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18315),
  [28867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18316),
  [28869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6034),
  [28871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12977),
  [28873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7483),
  [28875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9959),
  [28877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4221),
  [28879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5109),
  [28881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5107),
  [28883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5106),
  [28885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5600),
  [28887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17298),
  [28889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5194),
  [28891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18354),
  [28893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18355),
  [28895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18356),
  [28897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5613),
  [28899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5611),
  [28901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3198),
  [28903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12983),
  [28905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6090),
  [28907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9980),
  [28909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2558),
  [28911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9958),
  [28913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9956),
  [28915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6091),
  [28917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17281),
  [28919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5196),
  [28921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18394),
  [28923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18395),
  [28925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18396),
  [28927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5091),
  [28929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5089),
  [28931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5088),
  [28933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10460),
  [28935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9944),
  [28937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6092),
  [28939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13286),
  [28941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17265),
  [28943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2541),
  [28945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18434),
  [28947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18435),
  [28949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18436),
  [28951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4422),
  [28953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9952),
  [28955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16365),
  [28957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5223),
  [28959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5644),
  [28961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(452),
  [28963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5642),
  [28965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3192),
  [28967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17245),
  [28969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18474),
  [28971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18475),
  [28973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18476),
  [28975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5291),
  [28977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5164),
  [28979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5596),
  [28981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11006),
  [28983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2555),
  [28985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4277),
  [28987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4274),
  [28989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9946),
  [28991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11742),
  [28993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8800),
  [28995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17234),
  [28997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5226),
  [28999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18514),
  [29001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18515),
  [29003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18516),
  [29005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11741),
  [29007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7749),
  [29009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7769),
  [29011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11740),
  [29013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5213),
  [29015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7757),
  [29017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5222),
  [29019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17219),
  [29021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(964),
  [29023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18554),
  [29025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18555),
  [29027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18556),
  [29029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1402),
  [29031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1403),
  [29033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1404),
  [29035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4464),
  [29037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2269),
  [29039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5614),
  [29041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17204),
  [29043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3412),
  [29045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18594),
  [29047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18595),
  [29049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18596),
  [29051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3865),
  [29053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5209),
  [29055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6234),
  [29057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6211),
  [29059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10283),
  [29061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10284),
  [29063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4260),
  [29065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6196),
  [29067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5509),
  [29069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12979),
  [29071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17188),
  [29073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10153),
  [29075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18633),
  [29077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18634),
  [29079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18635),
  [29081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3352),
  [29083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3354),
  [29085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9747),
  [29087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5239),
  [29089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3449),
  [29091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5434),
  [29093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10119),
  [29095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17172),
  [29097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9954),
  [29099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18672),
  [29101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18673),
  [29103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18674),
  [29105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4341),
  [29107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4071),
  [29109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4093),
  [29111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4008),
  [29113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4640),
  [29115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4448),
  [29117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [29119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3450),
  [29121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3452),
  [29123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17161),
  [29125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5457),
  [29127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18710),
  [29129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18711),
  [29131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18712),
  [29133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6161),
  [29135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8407),
  [29137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2542),
  [29139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6163),
  [29141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10099),
  [29143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10103),
  [29145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6164),
  [29147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4286),
  [29149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4121),
  [29151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4129),
  [29153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17146),
  [29155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4150),
  [29157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18748),
  [29159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18749),
  [29161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18750),
  [29163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7987),
  [29165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1411),
  [29167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3381),
  [29169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3383),
  [29171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5545),
  [29173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12789),
  [29175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13136),
  [29177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2556),
  [29179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17133),
  [29181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4352),
  [29183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18786),
  [29185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18787),
  [29187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18788),
  [29189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13204),
  [29191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9881),
  [29193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11165),
  [29195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4215),
  [29197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3467),
  [29199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1214),
  [29201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9863),
  [29203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9868),
  [29205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9859),
  [29207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18823),
  [29209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18824),
  [29211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18825),
  [29213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3444),
  [29215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6409),
  [29217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6185),
  [29219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6186),
  [29221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10235),
  [29223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2538),
  [29225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13562),
  [29227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4224),
  [29229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4227),
  [29231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13210),
  [29233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9997),
  [29235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18860),
  [29237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18861),
  [29239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18862),
  [29241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10006),
  [29243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8827),
  [29245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4230),
  [29247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6206),
  [29249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4303),
  [29251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4324),
  [29253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6207),
  [29255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6210),
  [29257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18897),
  [29259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18898),
  [29261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18899),
  [29263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4458),
  [29265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3411),
  [29267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12022),
  [29269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(700),
  [29271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(689),
  [29273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(674),
  [29275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5394),
  [29277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3864),
  [29279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13670),
  [29281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18934),
  [29283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18935),
  [29285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18936),
  [29287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3206),
  [29289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13138),
  [29291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13233),
  [29293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4199),
  [29295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5849),
  [29297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1791),
  [29299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12766),
  [29301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6131),
  [29303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6127),
  [29305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3873),
  [29307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18970),
  [29309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18971),
  [29311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18972),
  [29313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3874),
  [29315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3875),
  [29317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9438),
  [29319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9435),
  [29321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9461),
  [29323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18994),
  [29325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18995),
  [29327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18996),
  [29329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16734),
  [29331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6735),
  [29333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19011),
  [29335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19012),
  [29337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19013),
  [29339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13244),
  [29341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11547),
  [29343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19023),
  [29345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19024),
  [29347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19025),
  [29349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6716),
  [29351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6714),
  [29353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19033),
  [29355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19034),
  [29357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19035),
  [29359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4881),
  [29361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4874),
  [29363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19043),
  [29365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19044),
  [29367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19045),
  [29369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7828),
  [29371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7824),
  [29373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19053),
  [29375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19054),
  [29377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19055),
  [29379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9515),
  [29381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12544),
  [29383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19063),
  [29385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19064),
  [29387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19065),
  [29389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5549),
  [29391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7823),
  [29393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19073),
  [29395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19074),
  [29397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19075),
  [29399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4868),
  [29401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7834),
  [29403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19083),
  [29405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19084),
  [29407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19085),
  [29409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12692),
  [29411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13191),
  [29413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19093),
  [29415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19094),
  [29417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19095),
  [29419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13190),
  [29421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11322),
  [29423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19103),
  [29425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19104),
  [29427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19105),
  [29429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13188),
  [29431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19113),
  [29433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19114),
  [29435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19115),
  [29437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12637),
  [29439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19123),
  [29441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19124),
  [29443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19125),
  [29445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12638),
  [29447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12639),
  [29449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19133),
  [29451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19134),
  [29453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19135),
  [29455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7795),
  [29457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7815),
  [29459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20193),
  [29461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12811),
  [29463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10055),
  [29465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3213),
  [29467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3207),
  [29469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16643),
  [29471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9446),
  [29473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4137),
  [29475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4163),
  [29477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4108),
  [29479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4658),
  [29481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3208),
  [29483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6242),
  [29485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6246),
  [29487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6249),
  [29489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6113),
  [29491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4216),
  [29493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6111),
  [29495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13232),
  [29497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6110),
  [29499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3211),
  [29501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15958),
  [29503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13205),
  [29505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9778),
  [29507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3212),
  [29509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16401),
  [29511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9792),
  [29513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9795),
  [29515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7829),
  [29517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1301),
  [29519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7653),
  [29521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2589),
  [29523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19279),
  [29525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20222),
  [29527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12657),
  [29529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16074),
  [29531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9803),
  [29533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9882),
  [29535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9878),
  [29537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5571),
  [29539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5570),
  [29541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20226),
  [29543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20227),
  [29545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20228),
  [29547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2702),
  [29549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4417),
  [29551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4009),
  [29553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4005),
  [29555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13229),
  [29557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16480),
  [29559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13212),
  [29561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4001),
  [29563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5569),
  [29565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2710),
  [29567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5217),
  [29569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8202),
  [29571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19375),
  [29573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5234),
  [29575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5246),
  [29577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3509),
  [29579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3512),
  [29581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3514),
  [29583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3516),
  [29585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13216),
  [29587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15980),
  [29589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13195),
  [29591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5767),
  [29593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5477),
  [29595] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__quoted_string, 3, 0, 0),
  [29597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3517),
  [29599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19449),
  [29601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9444),
  [29603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12775),
  [29605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3519),
  [29607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9646),
  [29609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2570),
  [29611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20258),
  [29613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7516),
  [29615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15149),
  [29617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9295),
  [29619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9888),
  [29621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9916),
  [29623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19498),
  [29625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9300),
  [29627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16612),
  [29629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9855),
  [29631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9316),
  [29633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9318),
  [29635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9333),
  [29637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15868),
  [29639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1057),
  [29641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15737),
  [29643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16381),
  [29645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16610),
  [29647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4309),
  [29649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15114),
  [29651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9335),
  [29653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2805),
  [29655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16172),
  [29657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16474),
  [29659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16338),
  [29661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16309),
  [29663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16163),
  [29665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16022),
  [29667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15902),
  [29669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15911),
  [29671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15705),
  [29673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15661),
  [29675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15574),
  [29677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15508),
  [29679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15264),
  [29681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15123),
  [29683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15220),
  [29685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15395),
  [29687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15710),
  [29689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15831),
  [29691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15923),
  [29693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16050),
  [29695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16368),
  [29697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16504),
  [29699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16326),
  [29701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16195),
  [29703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16110),
  [29705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15417),
  [29707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15287),
  [29709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15098),
  [29711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15134),
  [29713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15237),
  [29715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15291),
  [29717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15341),
  [29719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15391),
  [29721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15420),
  [29723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15481),
  [29725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15253),
  [29727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15451),
  [29729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15898),
  [29731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15943),
  [29733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16319),
  [29735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16161),
  [29737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16073),
  [29739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16062),
  [29741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16024),
  [29743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15975),
  [29745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15848),
  [29747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15811),
  [29749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15798),
  [29751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15782),
  [29753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [29755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2819),
  [29757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8222),
  [29759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1503),
  [29761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12914),
  [29763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12913),
  [29765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12912),
  [29767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1146),
  [29769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20114),
  [29771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1105),
  [29773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12761),
  [29775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8652),
  [29777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16719),
  [29779] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_payload, 3, 0, 0),
  [29781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5759),
  [29783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2722),
  [29785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9825),
  [29787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1022),
  [29789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20295),
  [29791] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__quoted_string, 2, 0, 0),
  [29793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1004),
  [29795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16606),
  [29797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12693),
  [29799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2724),
  [29801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20298),
  [29803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3863),
  [29805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7800),
  [29807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(895),
  [29809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13338),
  [29811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(878),
  [29813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9802),
  [29815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2580),
  [29817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2857),
  [29819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9787),
  [29821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7713),
  [29823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2856),
  [29825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7717),
  [29827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8922),
  [29829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10069),
  [29831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10086),
  [29833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16071),
  [29835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13335),
  [29837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8798),
  [29839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16676),
  [29841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15856),
  [29843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13377),
  [29845] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compilation_unit, 1, 0, 0),
  [29847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4337),
  [29849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9684),
  [29851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4241),
  [29853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4194),
  [29855] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_character_content, 1, 0, 0),
  [29857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16587),
  [29859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2777),
  [29861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2774),
  [29863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(723),
  [29865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8603),
  [29867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15248),
  [29869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12763),
  [29871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4370),
  [29873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9807),
  [29875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20389),
  [29877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1423),
  [29879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13394),
  [29881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(615),
  [29883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(614),
  [29885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(613),
  [29887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20505),
  [29889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5775),
  [29891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9618),
  [29893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10671),
  [29895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12747),
  [29897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13283),
  [29899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7728),
  [29901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12705),
  [29903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2848),
  [29905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2845),
  [29907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9442),
  [29909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11935),
  [29911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15132),
  [29913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8918),
  [29915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9635),
  [29917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8787),
  [29919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13345),
  [29921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13208),
  [29923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15550),
  [29925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16693),
  [29927] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__infix_operator, 1, 0, 0),
  [29929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15588),
  [29931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2280),
  [29933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12626),
  [29935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1794),
  [29937] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [29939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(797),
  [29941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2030),
  [29943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1125),
  [29945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(819),
  [29947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(900),
  [29949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(938),
  [29951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1897),
  [29953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20464),
  [29955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1965),
  [29957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11530),
  [29959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12758),
  [29961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1502),
  [29963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13199),
  [29965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1485),
  [29967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1482),
  [29969] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 3, 0, 0),
  [29971] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 4, 0, 0),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token_comment = 0,
  ts_external_token__left_quoted_string_delimiter = 1,
  ts_external_token__right_quoted_string_delimiter = 2,
  ts_external_token_DQUOTE = 3,
  ts_external_token_line_number_directive = 4,
  ts_external_token__null = 5,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token_comment] = sym_comment,
  [ts_external_token__left_quoted_string_delimiter] = sym__left_quoted_string_delimiter,
  [ts_external_token__right_quoted_string_delimiter] = sym__right_quoted_string_delimiter,
  [ts_external_token_DQUOTE] = anon_sym_DQUOTE,
  [ts_external_token_line_number_directive] = sym_line_number_directive,
  [ts_external_token__null] = sym__null,
};

static const bool ts_external_scanner_states[10][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token_comment] = true,
    [ts_external_token__left_quoted_string_delimiter] = true,
    [ts_external_token__right_quoted_string_delimiter] = true,
    [ts_external_token_DQUOTE] = true,
    [ts_external_token_line_number_directive] = true,
    [ts_external_token__null] = true,
  },
  [2] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_number_directive] = true,
  },
  [3] = {
    [ts_external_token_comment] = true,
    [ts_external_token_DQUOTE] = true,
    [ts_external_token_line_number_directive] = true,
  },
  [4] = {
    [ts_external_token_comment] = true,
    [ts_external_token__left_quoted_string_delimiter] = true,
    [ts_external_token_DQUOTE] = true,
    [ts_external_token_line_number_directive] = true,
  },
  [5] = {
    [ts_external_token_comment] = true,
    [ts_external_token_DQUOTE] = true,
    [ts_external_token_line_number_directive] = true,
    [ts_external_token__null] = true,
  },
  [6] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_number_directive] = true,
    [ts_external_token__null] = true,
  },
  [7] = {
    [ts_external_token_comment] = true,
    [ts_external_token__right_quoted_string_delimiter] = true,
    [ts_external_token_line_number_directive] = true,
    [ts_external_token__null] = true,
  },
  [8] = {
    [ts_external_token_comment] = true,
    [ts_external_token__left_quoted_string_delimiter] = true,
    [ts_external_token_line_number_directive] = true,
  },
  [9] = {
    [ts_external_token_comment] = true,
    [ts_external_token__right_quoted_string_delimiter] = true,
    [ts_external_token_line_number_directive] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_ocaml_interface_external_scanner_create(void);
void tree_sitter_ocaml_interface_external_scanner_destroy(void *);
bool tree_sitter_ocaml_interface_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_ocaml_interface_external_scanner_serialize(void *, char *);
void tree_sitter_ocaml_interface_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_ocaml_interface(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym__lowercase_identifier,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_ocaml_interface_external_scanner_create,
      tree_sitter_ocaml_interface_external_scanner_destroy,
      tree_sitter_ocaml_interface_external_scanner_scan,
      tree_sitter_ocaml_interface_external_scanner_serialize,
      tree_sitter_ocaml_interface_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
